/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_2 = { 6 | NIM_STRLIT_FLAG, "nkNone" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_3 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_2};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_4 = { 7 | NIM_STRLIT_FLAG, "nkEmpty" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_5 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_4};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_6 = { 7 | NIM_STRLIT_FLAG, "nkIdent" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_7 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_6};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_8 = { 5 | NIM_STRLIT_FLAG, "nkSym" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_9 = {5, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_8};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_10 = { 6 | NIM_STRLIT_FLAG, "nkType" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_11 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_10};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_12 = { 9 | NIM_STRLIT_FLAG, "nkCharLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_13 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_12};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_14 = { 8 | NIM_STRLIT_FLAG, "nkIntLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_15 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_14};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_16 = { 9 | NIM_STRLIT_FLAG, "nkInt8Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_17 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_16};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_18 = { 10 | NIM_STRLIT_FLAG, "nkInt16Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_19 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_18};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_20 = { 10 | NIM_STRLIT_FLAG, "nkInt32Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_21 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_20};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_22 = { 10 | NIM_STRLIT_FLAG, "nkInt64Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_23 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_22};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_24 = { 9 | NIM_STRLIT_FLAG, "nkUIntLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_25 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_24};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_26 = { 10 | NIM_STRLIT_FLAG, "nkUInt8Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_27 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_26};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_28 = { 11 | NIM_STRLIT_FLAG, "nkUInt16Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_29 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_28};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_30 = { 11 | NIM_STRLIT_FLAG, "nkUInt32Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_31 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_30};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_32 = { 11 | NIM_STRLIT_FLAG, "nkUInt64Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_33 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_32};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_34 = { 10 | NIM_STRLIT_FLAG, "nkFloatLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_35 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_34};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_36 = { 12 | NIM_STRLIT_FLAG, "nkFloat32Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_37 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_36};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_38 = { 12 | NIM_STRLIT_FLAG, "nkFloat64Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_39 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_38};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_40 = { 13 | NIM_STRLIT_FLAG, "nkFloat128Lit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_41 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_40};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_42 = { 8 | NIM_STRLIT_FLAG, "nkStrLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_43 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_42};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_44 = { 9 | NIM_STRLIT_FLAG, "nkRStrLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_45 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_44};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_46 = { 14 | NIM_STRLIT_FLAG, "nkTripleStrLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_47 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_46};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_48 = { 8 | NIM_STRLIT_FLAG, "nkNilLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_49 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_48};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_50 = { 11 | NIM_STRLIT_FLAG, "nkComesFrom" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_51 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_50};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_52 = { 9 | NIM_STRLIT_FLAG, "nkDotCall" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_53 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_52};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_54 = { 9 | NIM_STRLIT_FLAG, "nkCommand" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_55 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_54};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_56 = { 6 | NIM_STRLIT_FLAG, "nkCall" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_57 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_56};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_58 = { 12 | NIM_STRLIT_FLAG, "nkCallStrLit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_59 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_58};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_60 = { 7 | NIM_STRLIT_FLAG, "nkInfix" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_61 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_60};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_62 = { 8 | NIM_STRLIT_FLAG, "nkPrefix" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_63 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_62};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_64 = { 9 | NIM_STRLIT_FLAG, "nkPostfix" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_65 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_64};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_66 = { 16 | NIM_STRLIT_FLAG, "nkHiddenCallConv" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_67 = {16, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_66};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_68 = { 12 | NIM_STRLIT_FLAG, "nkExprEqExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_69 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_68};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_70 = { 15 | NIM_STRLIT_FLAG, "nkExprColonExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_71 = {15, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_70};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_72 = { 11 | NIM_STRLIT_FLAG, "nkIdentDefs" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_73 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_72};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_74 = { 10 | NIM_STRLIT_FLAG, "nkVarTuple" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_75 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_74};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_76 = { 5 | NIM_STRLIT_FLAG, "nkPar" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_77 = {5, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_76};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_78 = { 11 | NIM_STRLIT_FLAG, "nkObjConstr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_79 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_78};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_80 = { 7 | NIM_STRLIT_FLAG, "nkCurly" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_81 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_80};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_82 = { 11 | NIM_STRLIT_FLAG, "nkCurlyExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_83 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_82};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_84 = { 9 | NIM_STRLIT_FLAG, "nkBracket" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_85 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_84};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_86 = { 13 | NIM_STRLIT_FLAG, "nkBracketExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_87 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_86};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_88 = { 12 | NIM_STRLIT_FLAG, "nkPragmaExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_89 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_88};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_90 = { 7 | NIM_STRLIT_FLAG, "nkRange" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_91 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_90};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_92 = { 9 | NIM_STRLIT_FLAG, "nkDotExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_93 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_92};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_94 = { 18 | NIM_STRLIT_FLAG, "nkCheckedFieldExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_95 = {18, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_94};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_96 = { 11 | NIM_STRLIT_FLAG, "nkDerefExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_97 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_96};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_98 = { 8 | NIM_STRLIT_FLAG, "nkIfExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_99 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_98};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_100 = { 10 | NIM_STRLIT_FLAG, "nkElifExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_101 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_100};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_102 = { 10 | NIM_STRLIT_FLAG, "nkElseExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_103 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_102};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_104 = { 8 | NIM_STRLIT_FLAG, "nkLambda" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_105 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_104};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_106 = { 4 | NIM_STRLIT_FLAG, "nkDo" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_107 = {4, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_106};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_108 = { 11 | NIM_STRLIT_FLAG, "nkAccQuoted" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_109 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_108};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_110 = { 13 | NIM_STRLIT_FLAG, "nkTableConstr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_111 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_110};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_112 = { 6 | NIM_STRLIT_FLAG, "nkBind" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_113 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_112};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_114 = { 17 | NIM_STRLIT_FLAG, "nkClosedSymChoice" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_115 = {17, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_114};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_116 = { 15 | NIM_STRLIT_FLAG, "nkOpenSymChoice" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_117 = {15, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_116};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_118 = { 15 | NIM_STRLIT_FLAG, "nkHiddenStdConv" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_119 = {15, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_118};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_120 = { 15 | NIM_STRLIT_FLAG, "nkHiddenSubConv" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_121 = {15, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_120};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_122 = { 6 | NIM_STRLIT_FLAG, "nkConv" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_123 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_122};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_124 = { 6 | NIM_STRLIT_FLAG, "nkCast" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_125 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_124};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_126 = { 12 | NIM_STRLIT_FLAG, "nkStaticExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_127 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_126};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_128 = { 6 | NIM_STRLIT_FLAG, "nkAddr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_129 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_128};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_130 = { 12 | NIM_STRLIT_FLAG, "nkHiddenAddr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_131 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_130};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_132 = { 13 | NIM_STRLIT_FLAG, "nkHiddenDeref" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_133 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_132};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_134 = { 13 | NIM_STRLIT_FLAG, "nkObjDownConv" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_135 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_134};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_136 = { 11 | NIM_STRLIT_FLAG, "nkObjUpConv" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_137 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_136};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_138 = { 12 | NIM_STRLIT_FLAG, "nkChckRangeF" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_139 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_138};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_140 = { 13 | NIM_STRLIT_FLAG, "nkChckRange64" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_141 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_140};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_142 = { 11 | NIM_STRLIT_FLAG, "nkChckRange" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_143 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_142};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_144 = { 17 | NIM_STRLIT_FLAG, "nkStringToCString" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_145 = {17, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_144};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_146 = { 17 | NIM_STRLIT_FLAG, "nkCStringToString" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_147 = {17, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_146};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_148 = { 6 | NIM_STRLIT_FLAG, "nkAsgn" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_149 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_148};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_150 = { 10 | NIM_STRLIT_FLAG, "nkFastAsgn" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_151 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_150};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_152 = { 15 | NIM_STRLIT_FLAG, "nkGenericParams" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_153 = {15, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_152};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_154 = { 14 | NIM_STRLIT_FLAG, "nkFormalParams" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_155 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_154};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_156 = { 11 | NIM_STRLIT_FLAG, "nkOfInherit" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_157 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_156};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_158 = { 10 | NIM_STRLIT_FLAG, "nkImportAs" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_159 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_158};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_160 = { 9 | NIM_STRLIT_FLAG, "nkProcDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_161 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_160};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_162 = { 11 | NIM_STRLIT_FLAG, "nkMethodDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_163 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_162};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_164 = { 14 | NIM_STRLIT_FLAG, "nkConverterDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_165 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_164};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_166 = { 10 | NIM_STRLIT_FLAG, "nkMacroDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_167 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_166};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_168 = { 13 | NIM_STRLIT_FLAG, "nkTemplateDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_169 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_168};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_170 = { 13 | NIM_STRLIT_FLAG, "nkIteratorDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_171 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_170};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_172 = { 10 | NIM_STRLIT_FLAG, "nkOfBranch" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_173 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_172};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_174 = { 12 | NIM_STRLIT_FLAG, "nkElifBranch" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_175 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_174};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_176 = { 14 | NIM_STRLIT_FLAG, "nkExceptBranch" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_177 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_176};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_178 = { 6 | NIM_STRLIT_FLAG, "nkElse" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_179 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_178};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_180 = { 9 | NIM_STRLIT_FLAG, "nkAsmStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_181 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_180};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_182 = { 8 | NIM_STRLIT_FLAG, "nkPragma" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_183 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_182};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_184 = { 13 | NIM_STRLIT_FLAG, "nkPragmaBlock" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_185 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_184};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_186 = { 8 | NIM_STRLIT_FLAG, "nkIfStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_187 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_186};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_188 = { 10 | NIM_STRLIT_FLAG, "nkWhenStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_189 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_188};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_190 = { 9 | NIM_STRLIT_FLAG, "nkForStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_191 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_190};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_192 = { 12 | NIM_STRLIT_FLAG, "nkParForStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_193 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_192};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_194 = { 11 | NIM_STRLIT_FLAG, "nkWhileStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_195 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_194};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_196 = { 10 | NIM_STRLIT_FLAG, "nkCaseStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_197 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_196};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_198 = { 13 | NIM_STRLIT_FLAG, "nkTypeSection" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_199 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_198};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_200 = { 12 | NIM_STRLIT_FLAG, "nkVarSection" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_201 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_200};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_202 = { 12 | NIM_STRLIT_FLAG, "nkLetSection" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_203 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_202};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_204 = { 14 | NIM_STRLIT_FLAG, "nkConstSection" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_205 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_204};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_206 = { 10 | NIM_STRLIT_FLAG, "nkConstDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_207 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_206};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_208 = { 9 | NIM_STRLIT_FLAG, "nkTypeDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_209 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_208};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_210 = { 11 | NIM_STRLIT_FLAG, "nkYieldStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_211 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_210};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_212 = { 7 | NIM_STRLIT_FLAG, "nkDefer" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_213 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_212};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_214 = { 9 | NIM_STRLIT_FLAG, "nkTryStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_215 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_214};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_216 = { 9 | NIM_STRLIT_FLAG, "nkFinally" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_217 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_216};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_218 = { 11 | NIM_STRLIT_FLAG, "nkRaiseStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_219 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_218};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_220 = { 12 | NIM_STRLIT_FLAG, "nkReturnStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_221 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_220};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_222 = { 11 | NIM_STRLIT_FLAG, "nkBreakStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_223 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_222};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_224 = { 14 | NIM_STRLIT_FLAG, "nkContinueStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_225 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_224};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_226 = { 11 | NIM_STRLIT_FLAG, "nkBlockStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_227 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_226};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_228 = { 12 | NIM_STRLIT_FLAG, "nkStaticStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_229 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_228};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_230 = { 13 | NIM_STRLIT_FLAG, "nkDiscardStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_231 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_230};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_232 = { 10 | NIM_STRLIT_FLAG, "nkStmtList" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_233 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_232};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_234 = { 12 | NIM_STRLIT_FLAG, "nkImportStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_235 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_234};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_236 = { 18 | NIM_STRLIT_FLAG, "nkImportExceptStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_237 = {18, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_236};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_238 = { 12 | NIM_STRLIT_FLAG, "nkExportStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_239 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_238};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_240 = { 18 | NIM_STRLIT_FLAG, "nkExportExceptStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_241 = {18, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_240};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_242 = { 10 | NIM_STRLIT_FLAG, "nkFromStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_243 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_242};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_244 = { 13 | NIM_STRLIT_FLAG, "nkIncludeStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_245 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_244};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_246 = { 10 | NIM_STRLIT_FLAG, "nkBindStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_247 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_246};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_248 = { 11 | NIM_STRLIT_FLAG, "nkMixinStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_249 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_248};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_250 = { 11 | NIM_STRLIT_FLAG, "nkUsingStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_251 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_250};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_252 = { 13 | NIM_STRLIT_FLAG, "nkCommentStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_253 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_252};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_254 = { 14 | NIM_STRLIT_FLAG, "nkStmtListExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_255 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_254};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_256 = { 11 | NIM_STRLIT_FLAG, "nkBlockExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_257 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_256};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_258 = { 14 | NIM_STRLIT_FLAG, "nkStmtListType" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_259 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_258};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_260 = { 11 | NIM_STRLIT_FLAG, "nkBlockType" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_261 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_260};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_262 = { 6 | NIM_STRLIT_FLAG, "nkWith" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_263 = {6, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_262};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_264 = { 9 | NIM_STRLIT_FLAG, "nkWithout" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_265 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_264};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_266 = { 12 | NIM_STRLIT_FLAG, "nkTypeOfExpr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_267 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_266};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_268 = { 10 | NIM_STRLIT_FLAG, "nkObjectTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_269 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_268};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_270 = { 9 | NIM_STRLIT_FLAG, "nkTupleTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_271 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_270};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_272 = { 14 | NIM_STRLIT_FLAG, "nkTupleClassTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_273 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_272};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_274 = { 13 | NIM_STRLIT_FLAG, "nkTypeClassTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_275 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_274};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_276 = { 10 | NIM_STRLIT_FLAG, "nkStaticTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_277 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_276};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_278 = { 9 | NIM_STRLIT_FLAG, "nkRecList" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_279 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_278};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_280 = { 9 | NIM_STRLIT_FLAG, "nkRecCase" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_281 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_280};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_282 = { 9 | NIM_STRLIT_FLAG, "nkRecWhen" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_283 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_282};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_284 = { 7 | NIM_STRLIT_FLAG, "nkRefTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_285 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_284};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_286 = { 7 | NIM_STRLIT_FLAG, "nkPtrTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_287 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_286};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_288 = { 7 | NIM_STRLIT_FLAG, "nkVarTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_289 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_288};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_290 = { 9 | NIM_STRLIT_FLAG, "nkConstTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_291 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_290};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_292 = { 7 | NIM_STRLIT_FLAG, "nkOutTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_293 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_292};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_294 = { 12 | NIM_STRLIT_FLAG, "nkDistinctTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_295 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_294};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_296 = { 8 | NIM_STRLIT_FLAG, "nkProcTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_297 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_296};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_298 = { 12 | NIM_STRLIT_FLAG, "nkIteratorTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_299 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_298};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_300 = { 10 | NIM_STRLIT_FLAG, "nkSinkAsgn" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_301 = {10, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_300};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_302 = { 8 | NIM_STRLIT_FLAG, "nkEnumTy" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_303 = {8, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_302};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_304 = { 14 | NIM_STRLIT_FLAG, "nkEnumFieldDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_305 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_304};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_306 = { 9 | NIM_STRLIT_FLAG, "nkArgList" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_307 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_306};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_308 = { 9 | NIM_STRLIT_FLAG, "nkPattern" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_309 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_308};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_310 = { 15 | NIM_STRLIT_FLAG, "nkHiddenTryStmt" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_311 = {15, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_310};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_312 = { 9 | NIM_STRLIT_FLAG, "nkClosure" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_313 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_312};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_314 = { 11 | NIM_STRLIT_FLAG, "nkGotoState" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_315 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_314};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_316 = { 7 | NIM_STRLIT_FLAG, "nkState" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_317 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_316};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_318 = { 12 | NIM_STRLIT_FLAG, "nkBreakState" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_319 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_318};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_320 = { 9 | NIM_STRLIT_FLAG, "nkFuncDef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_321 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_320};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_322 = { 13 | NIM_STRLIT_FLAG, "nkTupleConstr" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_323 = {13, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_322};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_324 = { 7 | NIM_STRLIT_FLAG, "nkError" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_325 = {7, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_324};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_326 = { 11 | NIM_STRLIT_FLAG, "nkModuleRef" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_327 = {11, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_326};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_328 = { 14 | NIM_STRLIT_FLAG, "nkReplayAction" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_329 = {14, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_328};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_330 = { 12 | NIM_STRLIT_FLAG, "nkNilRodNode" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_331 = {12, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_330};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_332 = { 9 | NIM_STRLIT_FLAG, "nkOpenSym" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_333 = {9, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_332};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__zwnesofz9b9bSbxyBtNYFKcQ_334 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__zwnesofz9b9bSbxyBtNYFKcQ_335 = {0, (NimStrPayload*)&TM__zwnesofz9b9bSbxyBtNYFKcQ_334};
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___nodekinds_u168)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_3;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_5;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_7;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_9;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_11;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_13;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_15;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)7):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_17;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)8):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_19;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)9):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_21;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)10):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_23;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)11):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_25;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)12):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_27;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)13):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_29;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)14):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_31;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_33;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_35;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)17):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_37;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)18):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_39;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_41;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_43;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)21):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_45;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_47;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_49;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)24):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_51;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)25):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_53;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_55;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_57;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_59;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_61;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_63;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_65;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_67;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)33):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_69;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_71;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)35):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_73;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)36):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_75;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_77;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_79;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_81;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)40):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_83;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_85;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_87;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)43):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_89;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_91;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_93;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_95;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_97;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)48):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_99;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)49):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_101;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)50):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_103;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)51):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_105;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)52):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_107;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_109;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)54):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_111;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)55):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_113;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_115;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_117;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_119;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_121;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)60):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_123;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)61):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_125;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)62):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_127;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_129;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_131;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_133;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_135;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)67):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_137;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)68):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_139;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)69):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_141;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)70):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_143;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)71):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_145;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)72):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_147;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_149;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)74):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_151;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)75):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_153;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_155;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)77):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_157;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)78):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_159;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_161;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_163;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_165;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_167;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_169;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_171;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_173;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)86):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_175;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_177;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)88):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_179;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)89):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_181;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_183;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)91):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_185;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)92):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_187;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)93):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_189;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)94):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_191;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)95):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_193;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)96):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_195;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)97):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_197;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_199;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_201;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_203;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_205;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)102):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_207;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)103):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_209;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)104):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_211;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)105):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_213;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)106):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_215;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_217;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)108):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_219;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)109):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_221;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)110):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_223;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)111):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_225;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)112):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_227;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)113):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_229;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)114):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_231;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_233;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_235;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)117):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_237;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)118):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_239;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)119):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_241;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)120):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_243;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)121):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_245;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)122):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_247;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)123):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_249;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)124):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_251;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_253;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_255;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)127):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_257;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)128):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_259;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)129):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_261;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)130):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_263;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)131):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_265;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)132):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_267;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)133):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_269;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)134):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_271;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)135):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_273;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)136):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_275;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)137):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_277;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_279;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_281;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)140):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_283;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)141):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_285;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)142):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_287;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)143):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_289;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)144):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_291;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)145):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_293;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)146):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_295;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)147):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_297;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)148):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_299;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_301;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)150):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_303;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)151):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_305;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)152):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_307;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)153):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_309;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)154):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_311;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)155):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_313;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)156):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_315;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)157):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_317;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)158):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_319;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_321;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_323;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)161):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_325;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)162):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_327;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)163):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_329;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)164):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_331;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_333;
	}
	break;
	default:
	{
		result = TM__zwnesofz9b9bSbxyBtNYFKcQ_335;
	}
	break;
	}
	return result;
}
