/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32

#include "nimbase.h"
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g;
typedef NimStringV2 tyArray__z9cAtaKXVtQ2xtAG27z4jNg[20];
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_2 = { 16 | NIM_STRLIT_FLAG, "meCannotOpenFile" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_3 = { 10 | NIM_STRLIT_FLAG, "meExpected" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_4 = { 16 | NIM_STRLIT_FLAG, "meMissingClosing" };
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_5 = { 25 | NIM_STRLIT_FLAG, "meGridTableNotImplemented" };
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_6 = { 24 | NIM_STRLIT_FLAG, "meMarkdownIllformedTable" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_7 = { 16 | NIM_STRLIT_FLAG, "meIllformedTable" };
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_8 = { 20 | NIM_STRLIT_FLAG, "meNewSectionExpected" };
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_9 = { 19 | NIM_STRLIT_FLAG, "meGeneralParseError" };
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_10 = { 18 | NIM_STRLIT_FLAG, "meInvalidDirective" };
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_11 = { 14 | NIM_STRLIT_FLAG, "meInvalidField" };
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_12 = { 18 | NIM_STRLIT_FLAG, "meFootnoteMismatch" };
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_13 = { 21 | NIM_STRLIT_FLAG, "mwRedefinitionOfLabel" };
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_14 = { 21 | NIM_STRLIT_FLAG, "mwUnknownSubstitution" };
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_15 = { 15 | NIM_STRLIT_FLAG, "mwAmbiguousLink" };
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_16 = { 12 | NIM_STRLIT_FLAG, "mwBrokenLink" };
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_17 = { 21 | NIM_STRLIT_FLAG, "mwUnsupportedLanguage" };
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_18 = { 18 | NIM_STRLIT_FLAG, "mwUnsupportedField" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_19 = { 10 | NIM_STRLIT_FLAG, "mwRstStyle" };
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_20 = { 17 | NIM_STRLIT_FLAG, "mwUnusedImportdoc" };
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__maw2pc4xuFyUqn39bqA2rNQ_21 = { 20 | NIM_STRLIT_FLAG, "meSandboxedDirective" };
N_LIB_PRIVATE NIM_CONST tyArray__z9cAtaKXVtQ2xtAG27z4jNg names__packagesZdocutilsZrst_u625 = {{16, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_2},
{10, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_3},
{16, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_4},
{25, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_5},
{24, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_6},
{16, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_7},
{20, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_8},
{19, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_9},
{18, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_10},
{14, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_11},
{18, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_12},
{21, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_13},
{21, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_14},
{15, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_15},
{12, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_16},
{21, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_17},
{18, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_18},
{10, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_19},
{17, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_20},
{20, (NimStrPayload*)&TM__maw2pc4xuFyUqn39bqA2rNQ_21}}
;
N_LIB_PRIVATE N_NIMCALL(NimStringV2, symbolName__packagesZdocutilsZrst_u611)(tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g a_p0) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), names__packagesZdocutilsZrst_u625[((NI)(a_p0 - ((NI)0)))- 0]);
	return result;
}
