/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32

#include "nimbase.h"
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_u1538)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZenumutils_u116)(NI* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, addUnique__importer_u3514)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI x_p1) {
	NI blitTmp_1;
{	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*s_p0).len-1);
		colontmp_ = T2_;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				{
					if (!((*s_p0).p->data[i_1] == x_p1)) goto LA7_;
					goto BeforeRet_;
				}
LA7_: ;
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	blitTmp_1 = x_p1;
	eqwasMoved___stdZenumutils_u116((&x_p1));
	add__varpartitions_u1538((&(*s_p0)), blitTmp_1);
	}BeforeRet_: ;
}
