/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32

#include "nimbase.h"
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyTuple__qsoB9cWzItmjtA8wRSiKBbA tyTuple__qsoB9cWzItmjtA8wRSiKBbA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyTuple__qsoB9cWzItmjtA8wRSiKBbA {
	NIM_CHAR Field0;
	NimStringV2 Field1;
};
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u30646)(tyTuple__qsoB9cWzItmjtA8wRSiKBbA dest_p0) {
	eqdestroy___system_u2691(dest_p0.Field1);
}
