/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1, NimStringV2 val_p2);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, del__pureZstrtabs_u622)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_u4)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1, NimStringV2 value_p2);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u265)(tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___lineinfos_u134)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA e_p0);
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_2 = { 10 | NIM_STRLIT_FLAG, "nimhygiene" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_3 = {10, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_2};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_4 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_5 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_6 = { 14 | NIM_STRLIT_FLAG, "niminheritable" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_7 = {14, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_6};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_8 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_9 = { 8 | NIM_STRLIT_FLAG, "nimmixin" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_10 = {8, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_9};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_11 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_12 = { 10 | NIM_STRLIT_FLAG, "nimeffects" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_13 = {10, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_12};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_14 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_15 = { 8 | NIM_STRLIT_FLAG, "nimbabel" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_16 = {8, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_15};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_17 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_18 = { 15 | NIM_STRLIT_FLAG, "nimcomputedgoto" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_19 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_18};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_20 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_21 = { 8 | NIM_STRLIT_FLAG, "nimunion" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_22 = {8, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_21};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_23 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_24 = { 12 | NIM_STRLIT_FLAG, "nimnewshared" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_25 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_24};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_26 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_27 = { 14 | NIM_STRLIT_FLAG, "nimNewTypedesc" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_28 = {14, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_27};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_29 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_30 = { 19 | NIM_STRLIT_FLAG, "nimrequiresnimframe" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_31 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_30};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_32 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_33 = { 25 | NIM_STRLIT_FLAG, "nimparsebiggestfloatmagic" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_34 = {25, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_33};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_35 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_36 = { 8 | NIM_STRLIT_FLAG, "nimlocks" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_37 = {8, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_36};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_38 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_39 = { 7 | NIM_STRLIT_FLAG, "nimnode" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_40 = {7, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_39};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_41 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_42 = { 15 | NIM_STRLIT_FLAG, "nimvarargstyped" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_43 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_42};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_44 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_45 = { 16 | NIM_STRLIT_FLAG, "nimtypedescfixed" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_46 = {16, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_45};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_47 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_48 = { 13 | NIM_STRLIT_FLAG, "nimKnowsNimvm" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_49 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_48};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_50 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_51 = { 9 | NIM_STRLIT_FLAG, "nimArrIdx" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_52 = {9, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_51};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_53 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_54 = { 13 | NIM_STRLIT_FLAG, "nimHasalignOf" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_55 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_54};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_56 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_57 = { 10 | NIM_STRLIT_FLAG, "nimDistros" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_58 = {10, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_57};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_59 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_60 = { 15 | NIM_STRLIT_FLAG, "nimHasCppDefine" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_61 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_60};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_62 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_63 = { 20 | NIM_STRLIT_FLAG, "nimGenericInOutFlags" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_64 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_63};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_65 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_66 = { 29 | NIM_STRLIT_FLAG, "nimNoArrayToCstringConversion" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_67 = {29, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_66};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_68 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_69 = { 22 | NIM_STRLIT_FLAG, "nimHasRunnableExamples" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_70 = {22, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_69};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_71 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_72 = { 9 | NIM_STRLIT_FLAG, "nimNewDot" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_73 = {9, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_72};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_74 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_75 = { 15 | NIM_STRLIT_FLAG, "nimHasNilChecks" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_76 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_75};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_77 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_78 = { 10 | NIM_STRLIT_FLAG, "nimSymKind" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_79 = {10, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_78};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_80 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_81 = { 12 | NIM_STRLIT_FLAG, "nimVmEqIdent" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_82 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_81};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_83 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_84 = { 8 | NIM_STRLIT_FLAG, "nimNoNil" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_85 = {8, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_84};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_86 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_87 = { 19 | NIM_STRLIT_FLAG, "nimNoZeroTerminator" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_88 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_87};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_89 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_90 = { 9 | NIM_STRLIT_FLAG, "nimNotNil" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_91 = {9, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_90};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_92 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_93 = { 16 | NIM_STRLIT_FLAG, "nimVmExportFixed" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_94 = {16, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_93};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_95 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_96 = { 21 | NIM_STRLIT_FLAG, "nimHasSymOwnerInMacro" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_97 = {21, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_96};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_98 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_99 = { 13 | NIM_STRLIT_FLAG, "nimNewRuntime" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_100 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_99};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_101 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_102 = { 12 | NIM_STRLIT_FLAG, "nimIncrSeqV3" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_103 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_102};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_104 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_105 = { 7 | NIM_STRLIT_FLAG, "nimAshr" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_106 = {7, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_105};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_107 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_108 = { 12 | NIM_STRLIT_FLAG, "nimNoNilSeqs" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_109 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_108};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_110 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_111 = { 13 | NIM_STRLIT_FLAG, "nimNoNilSeqs2" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_112 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_111};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_113 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_114 = { 16 | NIM_STRLIT_FLAG, "nimHasUserErrors" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_115 = {16, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_114};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_116 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_117 = { 20 | NIM_STRLIT_FLAG, "nimUncheckedArrayTyp" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_118 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_117};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_119 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_120 = { 12 | NIM_STRLIT_FLAG, "nimHasTypeof" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_121 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_120};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_122 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_123 = { 23 | NIM_STRLIT_FLAG, "nimErrorProcCanHaveBody" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_124 = {23, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_123};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_125 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_126 = { 28 | NIM_STRLIT_FLAG, "nimHasInstantiationOfInMacro" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_127 = {28, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_126};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_128 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_129 = { 22 | NIM_STRLIT_FLAG, "nimHasHotCodeReloading" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_130 = {22, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_129};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_131 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_132 = { 13 | NIM_STRLIT_FLAG, "nimHasNilSeqs" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_133 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_132};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_134 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_135 = { 26 | NIM_STRLIT_FLAG, "nimHasSignatureHashInMacro" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_136 = {26, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_135};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_137 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_138 = { 13 | NIM_STRLIT_FLAG, "nimHasDefault" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_139 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_138};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_140 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_141 = { 20 | NIM_STRLIT_FLAG, "nimMacrosSizealignof" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_142 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_141};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_143 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_144 = { 20 | NIM_STRLIT_FLAG, "nimNoZeroExtendMagic" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_145 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_144};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_146 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_147 = { 18 | NIM_STRLIT_FLAG, "nimMacrosGetNodeId" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_148 = {18, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_147};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_149 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_150 = { 22 | NIM_STRLIT_FLAG, "nimFixedForwardGeneric" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_151 = {22, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_150};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_152 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_153 = { 21 | NIM_STRLIT_FLAG, "nimToOpenArrayCString" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_154 = {21, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_153};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_155 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_156 = { 10 | NIM_STRLIT_FLAG, "nimHasUsed" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_157 = {10, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_156};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_158 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_159 = { 12 | NIM_STRLIT_FLAG, "nimnomagic64" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_160 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_159};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_161 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_162 = { 14 | NIM_STRLIT_FLAG, "nimNewShiftOps" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_163 = {14, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_162};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_164 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_165 = { 12 | NIM_STRLIT_FLAG, "nimHasCursor" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_166 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_165};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_167 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_168 = { 14 | NIM_STRLIT_FLAG, "nimAlignPragma" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_169 = {14, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_168};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_170 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_171 = { 21 | NIM_STRLIT_FLAG, "nimHasExceptionsQuery" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_172 = {21, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_171};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_173 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_174 = { 18 | NIM_STRLIT_FLAG, "nimHasIsNamedTuple" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_175 = {18, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_174};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_176 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_177 = { 19 | NIM_STRLIT_FLAG, "nimHashOrdinalFixed" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_178 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_177};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_179 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_180 = { 19 | NIM_STRLIT_FLAG, "nimHasSinkInference" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_181 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_180};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_182 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_183 = { 16 | NIM_STRLIT_FLAG, "nimNewIntegerOps" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_184 = {16, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_183};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_185 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_186 = { 15 | NIM_STRLIT_FLAG, "nimHasInvariant" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_187 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_186};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_188 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_189 = { 6 | NIM_STRLIT_FLAG, "nimHas" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_190 = {6, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_189};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_191 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_192 = { 13 | NIM_STRLIT_FLAG, "nimHasWarning" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_193 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_192};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_194 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_195 = { 10 | NIM_STRLIT_FLAG, "nimHasHint" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_196 = {10, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_195};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_197 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_198 = { 13 | NIM_STRLIT_FLAG, "nimFixedOwned" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_199 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_198};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_200 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_201 = { 17 | NIM_STRLIT_FLAG, "nimHasStyleChecks" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_202 = {17, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_201};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_203 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_204 = { 20 | NIM_STRLIT_FLAG, "nimHasStacktraceMsgs" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_205 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_204};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_206 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_207 = { 21 | NIM_STRLIT_FLAG, "nimDoesntTrackDefects" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_208 = {21, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_207};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_209 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_210 = { 19 | NIM_STRLIT_FLAG, "nimHasLentIterators" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_211 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_210};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_212 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_213 = { 19 | NIM_STRLIT_FLAG, "nimHasDeclaredMagic" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_214 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_213};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_215 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_216 = { 23 | NIM_STRLIT_FLAG, "nimHasStacktracesModule" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_217 = {23, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_216};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_218 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_219 = { 24 | NIM_STRLIT_FLAG, "nimHasEffectTraitsModule" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_220 = {24, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_219};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_221 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_222 = { 22 | NIM_STRLIT_FLAG, "nimHasCastPragmaBlocks" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_223 = {22, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_222};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_224 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_225 = { 18 | NIM_STRLIT_FLAG, "nimHasDeclaredLocs" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_226 = {18, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_225};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_227 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_228 = { 21 | NIM_STRLIT_FLAG, "nimHasJsBigIntBackend" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_229 = {21, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_228};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_230 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_231 = { 20 | NIM_STRLIT_FLAG, "nimHasWarningAsError" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_232 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_231};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_233 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_234 = { 17 | NIM_STRLIT_FLAG, "nimHasHintAsError" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_235 = {17, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_234};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_236 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_237 = { 18 | NIM_STRLIT_FLAG, "nimHasSpellSuggest" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_238 = {18, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_237};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_239 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_240 = { 20 | NIM_STRLIT_FLAG, "nimHasCustomLiterals" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_241 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_240};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_242 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_243 = { 18 | NIM_STRLIT_FLAG, "nimHasUnifiedTuple" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_244 = {18, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_243};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_245 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_246 = { 14 | NIM_STRLIT_FLAG, "nimHasIterable" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_247 = {14, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_246};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_248 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_249 = { 16 | NIM_STRLIT_FLAG, "nimHasTypeofVoid" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_250 = {16, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_249};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_251 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_252 = { 15 | NIM_STRLIT_FLAG, "nimHasDragonBox" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_253 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_252};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_254 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_255 = { 13 | NIM_STRLIT_FLAG, "nimHasHintAll" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_256 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_255};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_257 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_258 = { 11 | NIM_STRLIT_FLAG, "nimHasTrace" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_259 = {11, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_258};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_260 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_261 = { 15 | NIM_STRLIT_FLAG, "nimHasEffectsOf" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_262 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_261};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_263 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_264 = { 21 | NIM_STRLIT_FLAG, "nimHasEnforceNoRaises" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_265 = {21, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_264};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_266 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_267 = { 22 | NIM_STRLIT_FLAG, "nimHasTopDownInference" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_268 = {22, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_267};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_269 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_270 = { 32 | NIM_STRLIT_FLAG, "nimHasTemplateRedefinitionPragma" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_271 = {32, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_270};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_272 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_273 = { 17 | NIM_STRLIT_FLAG, "nimHasCstringCase" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_274 = {17, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_273};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_275 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_276 = { 20 | NIM_STRLIT_FLAG, "nimHasCallsitePragma" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_277 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_276};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_278 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_279 = { 19 | NIM_STRLIT_FLAG, "nimHasWarnCastSizes" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_280 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_279};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_281 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_282 = { 15 | NIM_STRLIT_FLAG, "nimHasOutParams" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_283 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_282};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_284 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_285 = { 24 | NIM_STRLIT_FLAG, "nimHasSystemRaisesDefect" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_286 = {24, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_285};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_287 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_288 = { 22 | NIM_STRLIT_FLAG, "nimHasWarnUnnamedBreak" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_289 = {22, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_288};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_290 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_291 = { 19 | NIM_STRLIT_FLAG, "nimHasGenericDefine" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_292 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_291};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_293 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_294 = { 19 | NIM_STRLIT_FLAG, "nimHasDefineAliases" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_295 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_294};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_296 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_297 = { 20 | NIM_STRLIT_FLAG, "nimHasWarnBareExcept" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_298 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_297};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_299 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_300 = { 9 | NIM_STRLIT_FLAG, "nimHasDup" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_301 = {9, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_300};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_302 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_303 = { 15 | NIM_STRLIT_FLAG, "nimHasChecksums" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_304 = {15, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_303};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_305 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_306 = { 14 | NIM_STRLIT_FLAG, "nimHasSendable" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_307 = {14, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_306};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_308 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_309 = { 24 | NIM_STRLIT_FLAG, "nimAllowNonVarDestructor" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_310 = {24, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_309};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_311 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_312 = { 12 | NIM_STRLIT_FLAG, "nimHasQuirky" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_313 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_312};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_314 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_315 = { 16 | NIM_STRLIT_FLAG, "nimHasEnsureMove" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_316 = {16, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_315};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_317 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_318 = { 19 | NIM_STRLIT_FLAG, "nimHasNoReturnError" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_319 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_318};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_320 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_321 = { 16 | NIM_STRLIT_FLAG, "nimUseStrictDefs" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_322 = {16, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_321};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_323 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_324 = { 19 | NIM_STRLIT_FLAG, "nimHasNolineTooLong" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_325 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_324};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_326 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_327 = { 20 | NIM_STRLIT_FLAG, "nimHasCastExtendedVm" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_328 = {20, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_327};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_329 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_330 = { 19 | NIM_STRLIT_FLAG, "nimHasWarnStdPrefix" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_331 = {19, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_330};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_332 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_333 = { 13 | NIM_STRLIT_FLAG, "nimHasVtables" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_334 = {13, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_333};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_335 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_336 = { 22 | NIM_STRLIT_FLAG, "nimHasGenericsOpenSym2" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_337 = {22, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_336};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_338 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_339 = { 22 | NIM_STRLIT_FLAG, "nimHasGenericsOpenSym3" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_340 = {22, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_339};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_341 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_342 = { 23 | NIM_STRLIT_FLAG, "nimHasJsNoLambdaLifting" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_343 = {23, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_342};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_344 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_345 = { 27 | NIM_STRLIT_FLAG, "nimHasDefaultFloatRoundtrip" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_346 = {27, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_345};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_347 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_348 = { 12 | NIM_STRLIT_FLAG, "nimHasXorSet" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_349 = {12, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_348};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_350 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_351 = { 33 | NIM_STRLIT_FLAG, "nimHasPreviewDuplicateModuleError" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_352 = {33, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_351};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_353 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_354 = { 29 | NIM_STRLIT_FLAG, "nimHasSetLengthSeqUninitMagic" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_355 = {29, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_354};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_356 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__UpH3CWy69aOHB2xkQBDirlg_357 = { 29 | NIM_STRLIT_FLAG, "nimHasImplicitRangeConversion" };
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_358 = {29, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_357};
static const NimStringV2 TM__UpH3CWy69aOHB2xkQBDirlg_359 = {4, (NimStrPayload*)&TM__UpH3CWy69aOHB2xkQBDirlg_4};
extern NIM_BOOL nimInErrorMode__system_u4146;
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4146);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_u4)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1, NimStringV2 value_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nstPut(symbols_p0, symbol_p1, value_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_u8)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	del__pureZstrtabs_u622(symbols_p0, symbol_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initDefines__condsyms_u17)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_3, TM__UpH3CWy69aOHB2xkQBDirlg_5);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_7, TM__UpH3CWy69aOHB2xkQBDirlg_8);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_10, TM__UpH3CWy69aOHB2xkQBDirlg_11);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_13, TM__UpH3CWy69aOHB2xkQBDirlg_14);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_16, TM__UpH3CWy69aOHB2xkQBDirlg_17);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_19, TM__UpH3CWy69aOHB2xkQBDirlg_20);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_22, TM__UpH3CWy69aOHB2xkQBDirlg_23);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_25, TM__UpH3CWy69aOHB2xkQBDirlg_26);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_28, TM__UpH3CWy69aOHB2xkQBDirlg_29);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_31, TM__UpH3CWy69aOHB2xkQBDirlg_32);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_34, TM__UpH3CWy69aOHB2xkQBDirlg_35);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_37, TM__UpH3CWy69aOHB2xkQBDirlg_38);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_40, TM__UpH3CWy69aOHB2xkQBDirlg_41);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_43, TM__UpH3CWy69aOHB2xkQBDirlg_44);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_46, TM__UpH3CWy69aOHB2xkQBDirlg_47);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_49, TM__UpH3CWy69aOHB2xkQBDirlg_50);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_52, TM__UpH3CWy69aOHB2xkQBDirlg_53);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_55, TM__UpH3CWy69aOHB2xkQBDirlg_56);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_58, TM__UpH3CWy69aOHB2xkQBDirlg_59);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_61, TM__UpH3CWy69aOHB2xkQBDirlg_62);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_64, TM__UpH3CWy69aOHB2xkQBDirlg_65);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_67, TM__UpH3CWy69aOHB2xkQBDirlg_68);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_70, TM__UpH3CWy69aOHB2xkQBDirlg_71);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_73, TM__UpH3CWy69aOHB2xkQBDirlg_74);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_76, TM__UpH3CWy69aOHB2xkQBDirlg_77);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_79, TM__UpH3CWy69aOHB2xkQBDirlg_80);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_82, TM__UpH3CWy69aOHB2xkQBDirlg_83);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_85, TM__UpH3CWy69aOHB2xkQBDirlg_86);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_88, TM__UpH3CWy69aOHB2xkQBDirlg_89);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_91, TM__UpH3CWy69aOHB2xkQBDirlg_92);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_94, TM__UpH3CWy69aOHB2xkQBDirlg_95);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_97, TM__UpH3CWy69aOHB2xkQBDirlg_98);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_100, TM__UpH3CWy69aOHB2xkQBDirlg_101);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_103, TM__UpH3CWy69aOHB2xkQBDirlg_104);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_106, TM__UpH3CWy69aOHB2xkQBDirlg_107);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_109, TM__UpH3CWy69aOHB2xkQBDirlg_110);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_112, TM__UpH3CWy69aOHB2xkQBDirlg_113);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_115, TM__UpH3CWy69aOHB2xkQBDirlg_116);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_118, TM__UpH3CWy69aOHB2xkQBDirlg_119);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_121, TM__UpH3CWy69aOHB2xkQBDirlg_122);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_124, TM__UpH3CWy69aOHB2xkQBDirlg_125);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_127, TM__UpH3CWy69aOHB2xkQBDirlg_128);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_130, TM__UpH3CWy69aOHB2xkQBDirlg_131);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_133, TM__UpH3CWy69aOHB2xkQBDirlg_134);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_136, TM__UpH3CWy69aOHB2xkQBDirlg_137);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_139, TM__UpH3CWy69aOHB2xkQBDirlg_140);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_142, TM__UpH3CWy69aOHB2xkQBDirlg_143);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_145, TM__UpH3CWy69aOHB2xkQBDirlg_146);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_148, TM__UpH3CWy69aOHB2xkQBDirlg_149);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_151, TM__UpH3CWy69aOHB2xkQBDirlg_152);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_154, TM__UpH3CWy69aOHB2xkQBDirlg_155);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_157, TM__UpH3CWy69aOHB2xkQBDirlg_158);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_160, TM__UpH3CWy69aOHB2xkQBDirlg_161);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_163, TM__UpH3CWy69aOHB2xkQBDirlg_164);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_166, TM__UpH3CWy69aOHB2xkQBDirlg_167);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_169, TM__UpH3CWy69aOHB2xkQBDirlg_170);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_172, TM__UpH3CWy69aOHB2xkQBDirlg_173);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_175, TM__UpH3CWy69aOHB2xkQBDirlg_176);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_178, TM__UpH3CWy69aOHB2xkQBDirlg_179);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_181, TM__UpH3CWy69aOHB2xkQBDirlg_182);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_184, TM__UpH3CWy69aOHB2xkQBDirlg_185);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_187, TM__UpH3CWy69aOHB2xkQBDirlg_188);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ f_1;
		f_1 = (tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)0;
		{
			tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ v_1;
			NI res_1;
			v_1 = (tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)0;
			res_1 = ((NI)0);
			{
				while (1) {
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					NimStringV2 T5_;
					if (!(res_1 <= ((NI)24))) goto LA4;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					v_1 = ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ) (res_1));
					f_1 = v_1;
					T5_.len = 0; T5_.p = NIM_NIL;
					colontmpD_ = dollar___options_u265(f_1);
					T5_ = rawNewString(colontmpD_.len + 6);
appendString((&T5_), TM__UpH3CWy69aOHB2xkQBDirlg_190);
appendString((&T5_), colontmpD_);
					colontmpD__2 = T5_;
					defineSymbol__condsyms_u4(symbols_p0, colontmpD__2, TM__UpH3CWy69aOHB2xkQBDirlg_191);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
				} LA4: ;
			}
		}
	}
	{
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA s_1;
		NI res_2;
		s_1 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		res_2 = ((NI)20);
		{
			while (1) {
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				NimStringV2 T9_;
				if (!(res_2 <= ((NI)88))) goto LA8;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				s_1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (res_2));
				T9_.len = 0; T9_.p = NIM_NIL;
				colontmpD__3 = dollar___lineinfos_u134(s_1);
				T9_ = rawNewString(colontmpD__3.len + 13);
appendString((&T9_), TM__UpH3CWy69aOHB2xkQBDirlg_193);
appendString((&T9_), colontmpD__3);
				colontmpD__4 = T9_;
				defineSymbol__condsyms_u4(symbols_p0, colontmpD__4, TM__UpH3CWy69aOHB2xkQBDirlg_194);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_2 += ((NI)1);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
			} LA8: ;
		}
	}
	{
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA s_2;
		NI res_3;
		s_2 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		res_3 = ((NI)89);
		{
			while (1) {
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				NimStringV2 T13_;
				if (!(res_3 <= ((NI)123))) goto LA12;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				s_2 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (res_3));
				T13_.len = 0; T13_.p = NIM_NIL;
				colontmpD__5 = dollar___lineinfos_u134(s_2);
				T13_ = rawNewString(colontmpD__5.len + 10);
appendString((&T13_), TM__UpH3CWy69aOHB2xkQBDirlg_196);
appendString((&T13_), colontmpD__5);
				colontmpD__6 = T13_;
				defineSymbol__condsyms_u4(symbols_p0, colontmpD__6, TM__UpH3CWy69aOHB2xkQBDirlg_197);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_3 += ((NI)1);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
			} LA12: ;
		}
	}
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_199, TM__UpH3CWy69aOHB2xkQBDirlg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_202, TM__UpH3CWy69aOHB2xkQBDirlg_203);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_205, TM__UpH3CWy69aOHB2xkQBDirlg_206);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_208, TM__UpH3CWy69aOHB2xkQBDirlg_209);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_211, TM__UpH3CWy69aOHB2xkQBDirlg_212);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_214, TM__UpH3CWy69aOHB2xkQBDirlg_215);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_217, TM__UpH3CWy69aOHB2xkQBDirlg_218);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_220, TM__UpH3CWy69aOHB2xkQBDirlg_221);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_223, TM__UpH3CWy69aOHB2xkQBDirlg_224);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_226, TM__UpH3CWy69aOHB2xkQBDirlg_227);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_229, TM__UpH3CWy69aOHB2xkQBDirlg_230);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_232, TM__UpH3CWy69aOHB2xkQBDirlg_233);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_235, TM__UpH3CWy69aOHB2xkQBDirlg_236);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_238, TM__UpH3CWy69aOHB2xkQBDirlg_239);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_241, TM__UpH3CWy69aOHB2xkQBDirlg_242);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_244, TM__UpH3CWy69aOHB2xkQBDirlg_245);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_247, TM__UpH3CWy69aOHB2xkQBDirlg_248);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_250, TM__UpH3CWy69aOHB2xkQBDirlg_251);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_253, TM__UpH3CWy69aOHB2xkQBDirlg_254);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_256, TM__UpH3CWy69aOHB2xkQBDirlg_257);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_259, TM__UpH3CWy69aOHB2xkQBDirlg_260);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_262, TM__UpH3CWy69aOHB2xkQBDirlg_263);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_265, TM__UpH3CWy69aOHB2xkQBDirlg_266);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_268, TM__UpH3CWy69aOHB2xkQBDirlg_269);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_271, TM__UpH3CWy69aOHB2xkQBDirlg_272);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_274, TM__UpH3CWy69aOHB2xkQBDirlg_275);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_277, TM__UpH3CWy69aOHB2xkQBDirlg_278);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_280, TM__UpH3CWy69aOHB2xkQBDirlg_281);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_283, TM__UpH3CWy69aOHB2xkQBDirlg_284);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_286, TM__UpH3CWy69aOHB2xkQBDirlg_287);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_289, TM__UpH3CWy69aOHB2xkQBDirlg_290);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_292, TM__UpH3CWy69aOHB2xkQBDirlg_293);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_295, TM__UpH3CWy69aOHB2xkQBDirlg_296);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_298, TM__UpH3CWy69aOHB2xkQBDirlg_299);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_301, TM__UpH3CWy69aOHB2xkQBDirlg_302);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_304, TM__UpH3CWy69aOHB2xkQBDirlg_305);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_307, TM__UpH3CWy69aOHB2xkQBDirlg_308);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_310, TM__UpH3CWy69aOHB2xkQBDirlg_311);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_313, TM__UpH3CWy69aOHB2xkQBDirlg_314);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_316, TM__UpH3CWy69aOHB2xkQBDirlg_317);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_319, TM__UpH3CWy69aOHB2xkQBDirlg_320);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_322, TM__UpH3CWy69aOHB2xkQBDirlg_323);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_325, TM__UpH3CWy69aOHB2xkQBDirlg_326);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_328, TM__UpH3CWy69aOHB2xkQBDirlg_329);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_331, TM__UpH3CWy69aOHB2xkQBDirlg_332);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_334, TM__UpH3CWy69aOHB2xkQBDirlg_335);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_337, TM__UpH3CWy69aOHB2xkQBDirlg_338);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_340, TM__UpH3CWy69aOHB2xkQBDirlg_341);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_343, TM__UpH3CWy69aOHB2xkQBDirlg_344);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_346, TM__UpH3CWy69aOHB2xkQBDirlg_347);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_349, TM__UpH3CWy69aOHB2xkQBDirlg_350);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_352, TM__UpH3CWy69aOHB2xkQBDirlg_353);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_355, TM__UpH3CWy69aOHB2xkQBDirlg_356);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4(symbols_p0, TM__UpH3CWy69aOHB2xkQBDirlg_358, TM__UpH3CWy69aOHB2xkQBDirlg_359);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
