/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyTuple__NF6bgG5XEXlP7DfqszlNdg tyTuple__NF6bgG5XEXlP7DfqszlNdg;
typedef struct tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg;
typedef struct tyTuple__RICk09aVWvF6a15iJKyZfFQ tyTuple__RICk09aVWvF6a15iJKyZfFQ;
typedef struct tyTuple__axVdnKAd4XGmBNrMsqQ7kw tyTuple__axVdnKAd4XGmBNrMsqQ7kw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyTuple__mwCuj9awZDY9chWmMUlUHDfA tyTuple__mwCuj9awZDY9chWmMUlUHDfA;
typedef struct tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyTuple__M7ImznM2hk9a9beBDTxcwGeg;
typedef struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NI tyArray__9amfx9bz9cceXzfkb1XgPls3w[2];
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tyTuple__NF6bgG5XEXlP7DfqszlNdg {
	NimStringV2 Field0;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NI Field5;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
struct tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg {
	NimStringV2 Field0;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg Field1;
};
typedef NU8 tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw[38];
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
struct tyTuple__RICk09aVWvF6a15iJKyZfFQ {
	NimStringV2 Field0;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q Field1;
};
typedef NU8 tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg;
struct tyTuple__axVdnKAd4XGmBNrMsqQ7kw {
	NimStringV2 Field0;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg Field1;
	tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg Field2;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
typedef NU16 tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg;
struct tyTuple__mwCuj9awZDY9chWmMUlUHDfA {
	NimStringV2 Field0;
	tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg Field1;
};
typedef NU8 tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg;
struct tyTuple__M7ImznM2hk9a9beBDTxcwGeg {
	NimStringV2 Field0;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field1;
};
typedef NU8 tySet_tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA;
typedef NU8 tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA;
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, collectionToString__astyaml_u129)(tyArray__9amfx9bz9cceXzfkb1XgPls3w x_p0, NimStringV2 prefix_p1, NimStringV2 separator_p2, NimStringV2 suffix_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__astyaml_u173)(NimStringV2* s_p0, NI x_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZprivateZoscommon_u120)(NimStringV2* s_p0, NimStringV2 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u184)(NimStringV2* result_p0, NU64 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__ast_u3977)(NimStringV2* s_p0, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__vm_u1649)(NimStringV2* s_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__vm_u1863)(NimStringV2* s_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg x_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, collectionToString__importer_u3576)(tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw x_p0, NimStringV2 prefix_p1, NimStringV2 separator_p2, NimStringV2 suffix_p3);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__importer_u3610)(NimStringV2* s_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__jsgen_u4028)(NimStringV2* s_p0, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__jsgen_u3587)(NimStringV2* s_p0, tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZprivateZosfiles_u238)(NimStringV2* s_p0, tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg x_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, collectionToString__stdZprivateZosfiles_u248)(tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg x_p0, NimStringV2 prefix_p1, NimStringV2 separator_p2, NimStringV2 suffix_p3);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZprivateZosfiles_u282)(NimStringV2* s_p0, tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZjsonutils_u491)(NimStringV2* s_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* x_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, collectionToString__pureZjson_u5710)(tySet_tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA x_p0, NimStringV2 prefix_p1, NimStringV2 separator_p2, NimStringV2 suffix_p3);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pureZjson_u5744)(NimStringV2* s_p0, tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA x_p1);
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_2 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_3 = {0, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_4 = { 1 | NIM_STRLIT_FLAG, "[" };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_5 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_4};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_6 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_7 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_8 = { 1 | NIM_STRLIT_FLAG, "]" };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_9 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_8};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_10 = {0, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_11 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_12 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_13 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_14 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_15 = { 1 | NIM_STRLIT_FLAG, "," };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_16 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_17 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_18 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_19 = {0, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_2};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_20 = {0, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_2};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_21 = {0, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_2};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_22 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_23 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_24 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_25 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_26 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_27 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_28 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_29 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_30 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_31 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_32 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_33 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_34 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_35 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_36 = {0, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_37 = { 1 | NIM_STRLIT_FLAG, "{" };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_38 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_37};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_39 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_40 = { 1 | NIM_STRLIT_FLAG, "}" };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_41 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_40};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_42 = {0, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_2};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_43 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_44 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_45 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_46 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_47 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_48 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_49 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_50 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_51 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_52 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_53 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_54 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_55 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_56 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_57 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_58 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_59 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_60 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_61 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_62 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_63 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_64 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_65 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_66 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_67 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_68 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_69 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_37};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_70 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_71 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_40};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_72 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_73 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_74 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_11};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_75 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_76 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__n49a9aYp5BrbXv9a6OCpJYm0g_77 = { 3 | NIM_STRLIT_FLAG, "nil" };
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_78 = {3, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_77};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_79 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_15};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_80 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_17};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_81 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_37};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_82 = {2, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_6};
static const NimStringV2 TM__n49a9aYp5BrbXv9a6OCpJYm0g_83 = {1, (NimStrPayload*)&TM__n49a9aYp5BrbXv9a6OCpJYm0g_40};
extern NIM_BOOL nimInErrorMode__system_u4143;
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0) {
	NimStringV2 result;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_3;
	addInt__stdZprivateZdigitsutils_u204((&result), xX60gensym0__p0);
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, collectionToString__astyaml_u129)(tyArray__9amfx9bz9cceXzfkb1XgPls3w x_p0, NimStringV2 prefix_p1, NimStringV2 separator_p2, NimStringV2 suffix_p3) {
	NimStringV2 result;
	NIM_BOOL firstElement_1;
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), prefix_p1);
	firstElement_1 = NIM_TRUE;
	{
		NI value_1;
		NI i_1;
		value_1 = (NI)0;
		i_1 = ((NI)0);
		{
			while (1) {
				value_1 = x_p0[(i_1)- 0];
				{
					if (!firstElement_1) goto LA6_;
					firstElement_1 = NIM_FALSE;
				}
				goto LA4_;
LA6_: ;
				{
					prepareAdd((&result), separator_p2.len + 0);
appendString((&result), separator_p2);
				}
LA4_: ;
				addQuoted__astyaml_u173((&result), value_1);
				{
					if (!(((NI)1) <= i_1)) goto LA11_;
					goto LA2;
				}
LA11_: ;
				i_1 += ((NI)1);
			}
		} LA2: ;
	}
	prepareAdd((&result), suffix_p3.len + 0);
appendString((&result), suffix_p3);
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___astyaml_u124)(tyArray__9amfx9bz9cceXzfkb1XgPls3w x_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = collectionToString__astyaml_u129(x_p0, TM__n49a9aYp5BrbXv9a6OCpJYm0g_5, TM__n49a9aYp5BrbXv9a6OCpJYm0g_7, TM__n49a9aYp5BrbXv9a6OCpJYm0g_9);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u24)(NI32 xX60gensym3__p0) {
	NimStringV2 result;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_10;
	addInt__stdZprivateZdigitsutils_u204((&result), ((NI) (xX60gensym3__p0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___stdZprivateZoscommon_u94)(tyTuple__UV3llMMYFckfui8YMBuUZA* x_p0) {
	NimStringV2 result;
	NI countX60gensym3__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_12;
	countX60gensym3__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym3__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_13);
		}
LA7_: ;
		countX60gensym3__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym3__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_14);
		}
LA15_: ;
		countX60gensym3__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field1);
	}
LA11_: ;
	{
		if (!(countX60gensym3__1 == ((NI)1))) goto LA19_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_16);
	}
LA19_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_18);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u29)(NI64 xX60gensym4__p0) {
	NimStringV2 result;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_19;
	addInt__stdZprivateZdigitsutils_u187((&result), xX60gensym4__p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u54)(NU64 xX60gensym9__p0) {
	NimStringV2 result;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_20;
	addInt__stdZprivateZdigitsutils_u184((&result), xX60gensym9__p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u44)(NU16 xX60gensym7__p0) {
	NimStringV2 result;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_21;
	addInt__stdZprivateZdigitsutils_u184((&result), ((NU64) (xX60gensym7__p0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___vm_u1560)(tyTuple__NF6bgG5XEXlP7DfqszlNdg* x_p0) {
	NimStringV2 result;
	NI countX60gensym402__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_22;
	countX60gensym402__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym402__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_23);
		}
LA7_: ;
		countX60gensym402__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym402__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_24);
		}
LA15_: ;
		countX60gensym402__1 += ((NI)1);
		addQuoted__ast_u3977((&result), (*x_p0).Field1);
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA19_;
		{
			if (!(((NI)0) < countX60gensym402__1)) goto LA23_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_25);
		}
LA23_: ;
		countX60gensym402__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field2);
	}
LA19_: ;
	{
		if (!NIM_TRUE) goto LA27_;
		{
			if (!(((NI)0) < countX60gensym402__1)) goto LA31_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_26);
		}
LA31_: ;
		countX60gensym402__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field3);
	}
LA27_: ;
	{
		if (!NIM_TRUE) goto LA35_;
		{
			if (!(((NI)0) < countX60gensym402__1)) goto LA39_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_27);
		}
LA39_: ;
		countX60gensym402__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field4);
	}
LA35_: ;
	{
		if (!NIM_TRUE) goto LA43_;
		{
			if (!(((NI)0) < countX60gensym402__1)) goto LA47_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_28);
		}
LA47_: ;
		countX60gensym402__1 += ((NI)1);
		addQuoted__vm_u1649((&result), (*x_p0).Field5);
	}
LA43_: ;
	{
		if (!(countX60gensym402__1 == ((NI)1))) goto LA51_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_29);
	}
LA51_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_30);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___vm_u1822)(tyTuple__dsvP9bgd7x7RN0ykJDjb3Sg x_p0) {
	NimStringV2 result;
	NI countX60gensym529__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_31;
	countX60gensym529__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym529__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_32);
		}
LA7_: ;
		countX60gensym529__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), x_p0.Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym529__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_33);
		}
LA15_: ;
		countX60gensym529__1 += ((NI)1);
		addQuoted__vm_u1863((&result), x_p0.Field1);
	}
LA11_: ;
	{
		if (!(countX60gensym529__1 == ((NI)1))) goto LA19_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_34);
	}
LA19_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_35);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u19)(NI16 xX60gensym2__p0) {
	NimStringV2 result;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_36;
	addInt__stdZprivateZdigitsutils_u204((&result), ((NI) (xX60gensym2__p0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, collectionToString__importer_u3576)(tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw x_p0, NimStringV2 prefix_p1, NimStringV2 separator_p2, NimStringV2 suffix_p3) {
	NimStringV2 result;
	NIM_BOOL firstElement_1;
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), prefix_p1);
	firstElement_1 = NIM_TRUE;
	{
		tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw value_1;
		NI i_1;
		value_1 = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 <= ((NI)303))) goto LA3;
				{
					if (!((x_p0[(NU)((((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw) (i_1))))>>3] &(1U<<((NU)((((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw) (i_1))))&7U)))!=0)) goto LA6_;
					value_1 = ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw) (i_1));
					{
						if (!firstElement_1) goto LA10_;
						firstElement_1 = NIM_FALSE;
					}
					goto LA8_;
LA10_: ;
					{
						prepareAdd((&result), separator_p2.len + 0);
appendString((&result), separator_p2);
					}
LA8_: ;
					addQuoted__importer_u3610((&result), value_1);
				}
LA6_: ;
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	prepareAdd((&result), suffix_p3.len + 0);
appendString((&result), suffix_p3);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___importer_u3572)(tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw x_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = collectionToString__importer_u3576(x_p0, TM__n49a9aYp5BrbXv9a6OCpJYm0g_38, TM__n49a9aYp5BrbXv9a6OCpJYm0g_39, TM__n49a9aYp5BrbXv9a6OCpJYm0g_41);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u49)(NU32 xX60gensym8__p0) {
	NimStringV2 result;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_42;
	addInt__stdZprivateZdigitsutils_u184((&result), ((NU64) (xX60gensym8__p0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___jsgen_u3987)(tyTuple__RICk09aVWvF6a15iJKyZfFQ x_p0) {
	NimStringV2 result;
	NI countX60gensym817__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_43;
	countX60gensym817__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym817__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_44);
		}
LA7_: ;
		countX60gensym817__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), x_p0.Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym817__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_45);
		}
LA15_: ;
		countX60gensym817__1 += ((NI)1);
		addQuoted__jsgen_u4028((&result), x_p0.Field1);
	}
LA11_: ;
	{
		if (!(countX60gensym817__1 == ((NI)1))) goto LA19_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_46);
	}
LA19_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_47);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___jsgen_u3546)(tyTuple__axVdnKAd4XGmBNrMsqQ7kw x_p0) {
	NimStringV2 result;
	NI countX60gensym702__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_48;
	countX60gensym702__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym702__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_49);
		}
LA7_: ;
		countX60gensym702__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), x_p0.Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym702__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_50);
		}
LA15_: ;
		countX60gensym702__1 += ((NI)1);
		addQuoted__jsgen_u3587((&result), x_p0.Field1);
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA19_;
		{
			if (!(((NI)0) < countX60gensym702__1)) goto LA23_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_51);
		}
LA23_: ;
		countX60gensym702__1 += ((NI)1);
		addQuoted__jsgen_u3587((&result), x_p0.Field2);
	}
LA19_: ;
	{
		if (!(countX60gensym702__1 == ((NI)1))) goto LA27_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_52);
	}
LA27_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_53);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___docgen_u4140)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* x_p0) {
	NimStringV2 result;
	NI countX60gensym137__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_54;
	countX60gensym137__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym137__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_55);
		}
LA7_: ;
		countX60gensym137__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym137__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_56);
		}
LA15_: ;
		countX60gensym137__1 += ((NI)1);
		addQuoted__astyaml_u173((&result), (*x_p0).Field1);
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA19_;
		{
			if (!(((NI)0) < countX60gensym137__1)) goto LA23_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_57);
		}
LA23_: ;
		countX60gensym137__1 += ((NI)1);
		addQuoted__astyaml_u173((&result), (*x_p0).Field2);
	}
LA19_: ;
	{
		if (!(countX60gensym137__1 == ((NI)1))) goto LA27_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_58);
	}
LA27_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_59);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___nimpaths_u31)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* x_p0) {
	NimStringV2 result;
	NI countX60gensym0__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_60;
	countX60gensym0__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym0__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_61);
		}
LA7_: ;
		countX60gensym0__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym0__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_62);
		}
LA15_: ;
		countX60gensym0__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field1);
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA19_;
		{
			if (!(((NI)0) < countX60gensym0__1)) goto LA23_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_63);
		}
LA23_: ;
		countX60gensym0__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), (*x_p0).Field2);
	}
LA19_: ;
	{
		if (!(countX60gensym0__1 == ((NI)1))) goto LA27_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_64);
	}
LA27_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_65);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, collectionToString__stdZprivateZosfiles_u248)(tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg x_p0, NimStringV2 prefix_p1, NimStringV2 separator_p2, NimStringV2 suffix_p3) {
	NimStringV2 result;
	NIM_BOOL firstElement_1;
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), prefix_p1);
	firstElement_1 = NIM_TRUE;
	{
		tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg value_1;
		NI i_1;
		value_1 = (tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg)0;
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 <= ((NI)8))) goto LA3;
				{
					if (!((x_p0 &((NU16)1<<((NU)((((tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg) (i_1))))&15U)))!=0)) goto LA6_;
					value_1 = ((tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg) (i_1));
					{
						if (!firstElement_1) goto LA10_;
						firstElement_1 = NIM_FALSE;
					}
					goto LA8_;
LA10_: ;
					{
						prepareAdd((&result), separator_p2.len + 0);
appendString((&result), separator_p2);
					}
LA8_: ;
					addQuoted__stdZprivateZosfiles_u282((&result), value_1);
				}
LA6_: ;
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	prepareAdd((&result), suffix_p3.len + 0);
appendString((&result), suffix_p3);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___stdZprivateZosfiles_u244)(tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg x_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = collectionToString__stdZprivateZosfiles_u248(x_p0, TM__n49a9aYp5BrbXv9a6OCpJYm0g_69, TM__n49a9aYp5BrbXv9a6OCpJYm0g_70, TM__n49a9aYp5BrbXv9a6OCpJYm0g_71);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___stdZprivateZosfiles_u134)(tyTuple__mwCuj9awZDY9chWmMUlUHDfA x_p0) {
	NimStringV2 result;
	NI countX60gensym19__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_66;
	countX60gensym19__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym19__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_67);
		}
LA7_: ;
		countX60gensym19__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), x_p0.Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym19__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_68);
		}
LA15_: ;
		countX60gensym19__1 += ((NI)1);
		addQuoted__stdZprivateZosfiles_u238((&result), x_p0.Field1);
	}
LA11_: ;
	{
		if (!(countX60gensym19__1 == ((NI)1))) goto LA19_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_72);
	}
LA19_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_73);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___stdZjsonutils_u447)(tyTuple__M7ImznM2hk9a9beBDTxcwGeg x_p0) {
	NimStringV2 result;
	NI countX60gensym23__1;
	result = TM__n49a9aYp5BrbXv9a6OCpJYm0g_74;
	countX60gensym23__1 = ((NI)0);
	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!(((NI)0) < countX60gensym23__1)) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_75);
		}
LA7_: ;
		countX60gensym23__1 += ((NI)1);
		addQuoted__stdZprivateZoscommon_u120((&result), x_p0.Field0);
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!(((NI)0) < countX60gensym23__1)) goto LA15_;
			prepareAdd((&result), 2);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_76);
		}
LA15_: ;
		countX60gensym23__1 += ((NI)1);
		{
			if (!(x_p0.Field1 == 0)) goto LA19_;
			prepareAdd((&result), 3);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_78);
		}
		goto LA17_;
LA19_: ;
		{
			addQuoted__stdZjsonutils_u491((&result), x_p0.Field1);
		}
LA17_: ;
	}
LA11_: ;
	{
		if (!(countX60gensym23__1 == ((NI)1))) goto LA24_;
		prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_79);
	}
LA24_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__n49a9aYp5BrbXv9a6OCpJYm0g_80);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, collectionToString__pureZjson_u5710)(tySet_tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA x_p0, NimStringV2 prefix_p1, NimStringV2 separator_p2, NimStringV2 suffix_p3) {
	NimStringV2 result;
	NIM_BOOL firstElement_1;
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), prefix_p1);
	firstElement_1 = NIM_TRUE;
	{
		tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA value_1;
		NI i_1;
		value_1 = (tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA)0;
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 <= ((NI)6))) goto LA3;
				{
					if (!((x_p0 &((NU8)1<<((NU)((((tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA) (i_1))))&7U)))!=0)) goto LA6_;
					value_1 = ((tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA) (i_1));
					{
						if (!firstElement_1) goto LA10_;
						firstElement_1 = NIM_FALSE;
					}
					goto LA8_;
LA10_: ;
					{
						prepareAdd((&result), separator_p2.len + 0);
appendString((&result), separator_p2);
					}
LA8_: ;
					addQuoted__pureZjson_u5744((&result), value_1);
				}
LA6_: ;
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	prepareAdd((&result), suffix_p3.len + 0);
appendString((&result), suffix_p3);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___pureZjson_u5706)(tySet_tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA x_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = collectionToString__pureZjson_u5710(x_p0, TM__n49a9aYp5BrbXv9a6OCpJYm0g_81, TM__n49a9aYp5BrbXv9a6OCpJYm0g_82, TM__n49a9aYp5BrbXv9a6OCpJYm0g_83);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
