/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <dirent.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#include <unistd.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct RootObj RootObj;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA tySequence__TLbZ2GqL3Zio1f8bNpj2NA;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content;
typedef struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w tySequence__GH1mmNKNA2QP4n1tnxJf1w;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA tySequence__TEgqV1E9aHqnwBUoeXjBI9aA;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content;
typedef struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ tyObject_Table__tro5f9chxPVpES1mQpDwZtQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content;
typedef struct tyObject_Profiler__YI4zs2CaXXndlYireD0I8A tyObject_Profiler__YI4zs2CaXXndlYireD0I8A;
typedef struct tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw tySequence__fnH5Zt4fsGx0AgDTOw8pKw;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content;
typedef struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ tyObject_Table__lPs28yjGTxD0LzUoPspSBQ;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q tySequence__Fc8Q26tsngy2yxcpyrnT4Q;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content;
typedef struct tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg;
typedef struct tyTuple__wjbnfGBIEcH6aaevyJWrgw tyTuple__wjbnfGBIEcH6aaevyJWrgw;
typedef struct Exception Exception;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ;
typedef struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g tyTuple__y6bKAf9a9aaVwun6lVDxSX7g;
typedef struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg;
typedef struct tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  NI len; tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content* p;
};
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA {
  NI len; tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content* p;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w {
  NI len; tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content* p;
};
struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g {
	NI counter;
	tySequence__GH1mmNKNA2QP4n1tnxJf1w data;
	NIM_BOOL ignoreTypes;
};
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
typedef NU8 tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg;
typedef NU8 tySet_tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g;
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA {
  NI len; tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content* p;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  NI len; tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content* p;
};
struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og data;
	NI counter;
};
struct tyObject_Profiler__YI4zs2CaXXndlYireD0I8A {
	NF tEnter;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos;
};
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw {
  NI len; tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content* p;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q {
  NI len; tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content* p;
};
struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ {
	tySequence__Fc8Q26tsngy2yxcpyrnT4Q data;
	NI counter;
};
struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tySequence__YdLNCDKYeipzJx3I8Xw82Q code;
	tySequence__TLbZ2GqL3Zio1f8bNpj2NA debug;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* globals;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constants;
	tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g contstantTab;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg types;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentExceptionA;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentExceptionB;
	NI exceptionInstr;
	tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* prc;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* callsite;
	tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg mode;
	tySet_tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g features;
	NIM_BOOL traceActive;
	NI loopIterations;
	NI callDepth;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA comesFromHeuristic;
	tySequence__TEgqV1E9aHqnwBUoeXjBI9aA callbacks;
	tyObject_Table__tro5f9chxPVpES1mQpDwZtQ callbackIndex;
	NimStringV2 errorFlag;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	NI oldErrorCount;
	tyObject_Profiler__YI4zs2CaXXndlYireD0I8A profiler;
	NI* templInstCounter;
	tySequence__fnH5Zt4fsGx0AgDTOw8pKw vmstateDiff;
	tyObject_Table__lPs28yjGTxD0LzUoPspSBQ procToCodePos;
	NIM_BOOL cannotEval;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA locals;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
struct tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw {
	RootObj Sup;
	NimStringV2 errorMsg0;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph1;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf2;
	NimStringV2 vthisDir3;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module4;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
void* ClE_0;
} tyProc__c9bXGQkBnyyGGVw063jrwZw;
typedef NU8 tySet_tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ;
typedef NU8 tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ;
typedef NIM_CHAR tyArray__bErjiHmvISNmC2iIqkq21Q[256];
struct tyTuple__wjbnfGBIEcH6aaevyJWrgw {
	tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ Field0;
	NIM_BOOL Field1;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
typedef NU8 tySet_tyEnum_CopyFlag__1j5oUmplkZXgil3SrVhR7g;
struct tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA {
	NI64 seconds;
	NI nanosecond;
};
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_62) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_65) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_68) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_71) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_74) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_77) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_97) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_100) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_103) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_106) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
typedef NU8 tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw;
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef N_CLOSURE_PTR(void, TM__FA6jNt3IW9afkuZFmR0bnUQ_126) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content { NI cap; NU64 data[SEQ_DECL_SIZE]; };
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content { NI cap; tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA data[SEQ_DECL_SIZE]; };
struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ {
	NI h;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key;
	NI val;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content { NI cap; tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content { NI cap; tyProc__c9bXGQkBnyyGGVw063jrwZw data[SEQ_DECL_SIZE]; };
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
	NI Field0;
	NimStringV2 Field1;
	NI Field2;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content { NI cap; tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE]; };
struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
};
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content { NI cap; tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ data[SEQ_DECL_SIZE]; };
struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg {
	NI32 pc;
	NI32 usedRegisters;
};
struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g {
	NI Field0;
	NI Field1;
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg Field2;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content { NI cap; tyTuple__y6bKAf9a9aaVwun6lVDxSX7g data[SEQ_DECL_SIZE]; };
struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg {
	NI ra;
	NI rb;
	NI rc;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* slots;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentException;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA currentLineInfo;
};
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw*, newModuleGraph__modulegraphs_u13525)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1);
N_LIB_PRIVATE N_NIMCALL(void, connectPipelineCallbacks__pipelines_u1647)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(void, initDefines__condsyms_u17)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_u4)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1, NimStringV2 value_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__commands_u1640)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, unregisterArcOrc__commands_u1313)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, makeModule__modules_u44)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*, setupVM__scriptconfig_u40)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, NimStringV2 scriptName_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p3, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p4);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__scriptconfig_u364)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___scriptconfig_u280)(tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13532)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u14756)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw** dest_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*, newCtx__vmdef_u383)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3);
N_LIB_PRIVATE N_NIMCALL(void, registerAdditionalOps__vm_u13299)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u2138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg** dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringV2 path_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, registerCallback__vmdef_u2258)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NimStringV2 name_p1, tyProc__c9bXGQkBnyyGGVw063jrwZw callback_p2);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u60)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, listDirs__scriptconfig_u21)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tySet_tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ filter_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getString__vm_u400)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NOINLINE(void, raiseOSError__stdZoserrors_u119)(NI32 errorCode_p0, NimStringV2 additionalInfo_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, osLastError__stdZoserrors_u122)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cstrToNimstr)(NCSTRING str_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosjoinPath)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(tyTuple__wjbnfGBIEcH6aaevyJWrgw, getSymlinkFileKind__stdZprivateZoscommon_u20)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u280)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ v_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5506)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(NimStringV2, getCurrentExceptionMsg__system_u7940)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3661)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u62)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u64)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosremoveDir)(NimStringV2 dir_p0, NIM_BOOL checkDir_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, getBool__vm_u346)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u70)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosremoveFile)(NimStringV2 file_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u76)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringV2 dir_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u78)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u271)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NimStringV2 v_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u80)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
static N_INLINE(void, setCurrentDir__stdZprivateZosdirs_u501)(NimStringV2 newDir_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u82)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u84)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nosmoveFile)(NimStringV2 source_p0, NimStringV2 dest_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u90)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, moveDir__stdZprivateZosdirs_u498)(NimStringV2 source_p0, NimStringV2 dest_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u96)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscopyFile)(NimStringV2 source_p0, NimStringV2 dest_p1, tySet_tyEnum_CopyFlag__1j5oUmplkZXgil3SrVhR7g options_p2, NI bufferSize_p3);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u102)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, noscopyDir)(NimStringV2 source_p0, NimStringV2 dest_p1, NIM_BOOL skipSpecial_p2);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u108)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u258)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI64 v_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, toUnix__pureZtimes_u1240)(tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA, nosgetLastModificationTime)(NimStringV2 file_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u110)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findExe__pureZos_u76)(NimStringV2 exe_p0, NIM_BOOL followSymlinks_p1, NimStringV2* extensions_p2, NI extensions_p2Len_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u112)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NI, nospexecCmd)(NimStringV2 command_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u118)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getEnv__stdZenvvars_u16)(NimStringV2 key_p0, NimStringV2 default_p1);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u120)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, setResult__vm_u264)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NIM_BOOL v_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsEnv__stdZenvvars_u21)(NimStringV2 key_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u122)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, putEnv__stdZenvvars_u24)(NimStringV2 key_p0, NimStringV2 val_p1);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u124)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, delEnv__stdZenvvars_u30)(NimStringV2 key_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u126)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringV2 dir_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u128)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u130)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u132)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u134)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u136)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u138)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setConfigVar__options_u3608)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, NimStringV2 val_p2);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u140)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getConfigVar__options_u3603)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, NimStringV2 default_p2);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u142)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsConfigVar__options_u3599)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u144)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimcacheDir__options_u3737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u146)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, paramStr__stdZcmdline_u56)(NI i_p0);
N_LIB_PRIVATE N_NIMCALL(NI64, getInt__vm_u301)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u148)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NI, paramCount__stdZcmdline_u62)(void);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u150)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u152)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreCase)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u154)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setCommandEarly__commands_u1214)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 command_p1);
N_LIB_PRIVATE N_NIMCALL(void, setFromProjectName__options_u3673)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 projectName_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u161)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u163)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_u1361)(NimStringV2 switch_p0, NimStringV2 arg_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p4);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u165)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__commands_u290)(NimStringV2 arg_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw state_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, NimStringV2 orig_p4, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p5);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u167)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u169)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosaddFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1837)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, pathSubs__options_u3759)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 p_p1, NimStringV2 config_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1, NimStringV2 val_p2);
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u173)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetAppFilename)(void);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u175)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_u2159)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* c_p0, NimStringV2 define_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u177)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, readLine__stdZsyncio_u319)(FILE* f_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u183)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, readAll__stdZsyncio_u381)(FILE* file_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZos_u200)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___scriptconfig_u329)(tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4955)(RootObj** dest_p0, RootObj* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*, eqdup___vmdef_u2213)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, setPipeLinePass__pipelines_u36)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pass_p1);
N_LIB_PRIVATE N_NIMCALL(void, compilePipelineSystemModule__pipelines_u1687)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processPipelineModule__pipelines_u418)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg* stream_p3);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, resetSystemArtifacts__modules_u13)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_u8)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u2206)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14753)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_2 = { 9 | NIM_STRLIT_FLAG, "nimscript" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_3 = {9, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_2};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_4 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_5 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_6 = { 9 | NIM_STRLIT_FLAG, "nimconfig" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_7 = {9, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_6};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_8 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
N_LIB_PRIVATE TNimTypeV2 NTIv2__khCJxQctW1B7wDWphVipqw_;
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_10 = { 27 | NIM_STRLIT_FLAG, "stdlib.system.listFilesImpl" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_11 = {27, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_10};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_12 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_13 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_14 = { 1 | NIM_STRLIT_FLAG, "." };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_15 = {1, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_14};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_16 = { 2 | NIM_STRLIT_FLAG, ".." };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_17 = {2, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_16};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_18 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_19 = { 26 | NIM_STRLIT_FLAG, "stdlib.system.listDirsImpl" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_20 = {26, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_19};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_21 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_22 = { 23 | NIM_STRLIT_FLAG, "stdlib.system.removeDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_23 = {23, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_22};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_24 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_25 = { 24 | NIM_STRLIT_FLAG, "stdlib.system.removeFile" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_26 = {24, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_25};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_27 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_28 = { 23 | NIM_STRLIT_FLAG, "stdlib.system.createDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_29 = {23, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_28};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_30 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_31 = { 22 | NIM_STRLIT_FLAG, "stdlib.system.getError" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_32 = {22, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_31};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_33 = { 27 | NIM_STRLIT_FLAG, "stdlib.system.setCurrentDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_34 = {27, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_33};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_35 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_36 = { 27 | NIM_STRLIT_FLAG, "stdlib.system.getCurrentDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_37 = {27, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_36};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_38 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_39 = { 22 | NIM_STRLIT_FLAG, "stdlib.system.moveFile" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_40 = {22, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_39};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_41 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_42 = { 21 | NIM_STRLIT_FLAG, "stdlib.system.moveDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_43 = {21, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_42};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_44 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_45 = { 22 | NIM_STRLIT_FLAG, "stdlib.system.copyFile" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_46 = {22, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_45};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_47 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_48 = { 21 | NIM_STRLIT_FLAG, "stdlib.system.copyDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_49 = {21, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_48};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_50 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_51 = { 37 | NIM_STRLIT_FLAG, "stdlib.system.getLastModificationTime" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_52 = {37, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_51};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_53 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_54 = { 21 | NIM_STRLIT_FLAG, "stdlib.system.findExe" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_55 = {21, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_54};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_56 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_57 = { 21 | NIM_STRLIT_FLAG, "stdlib.system.rawExec" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_58 = {21, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_57};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_59 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_60 = { 20 | NIM_STRLIT_FLAG, "stdlib.system.getEnv" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_61 = {20, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_60};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_63 = { 23 | NIM_STRLIT_FLAG, "stdlib.system.existsEnv" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_64 = {23, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_63};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_66 = { 20 | NIM_STRLIT_FLAG, "stdlib.system.putEnv" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_67 = {20, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_66};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_69 = { 20 | NIM_STRLIT_FLAG, "stdlib.system.delEnv" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_70 = {20, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_69};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_72 = { 23 | NIM_STRLIT_FLAG, "stdlib.system.dirExists" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_73 = {23, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_72};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_75 = { 24 | NIM_STRLIT_FLAG, "stdlib.system.fileExists" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_76 = {24, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_75};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_78 = { 25 | NIM_STRLIT_FLAG, "stdlib.system.projectName" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_79 = {25, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_78};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_80 = { 24 | NIM_STRLIT_FLAG, "stdlib.system.projectDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_81 = {24, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_80};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_82 = { 25 | NIM_STRLIT_FLAG, "stdlib.system.projectPath" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_83 = {25, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_82};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_84 = { 21 | NIM_STRLIT_FLAG, "stdlib.system.thisDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_85 = {21, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_84};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_86 = { 17 | NIM_STRLIT_FLAG, "stdlib.system.put" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_87 = {17, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_86};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_88 = { 17 | NIM_STRLIT_FLAG, "stdlib.system.get" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_89 = {17, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_88};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_90 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_91 = { 20 | NIM_STRLIT_FLAG, "stdlib.system.exists" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_92 = {20, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_91};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_93 = { 25 | NIM_STRLIT_FLAG, "stdlib.system.nimcacheDir" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_94 = {25, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_93};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_95 = { 22 | NIM_STRLIT_FLAG, "stdlib.system.paramStr" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_96 = {22, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_95};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_98 = { 24 | NIM_STRLIT_FLAG, "stdlib.system.paramCount" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_99 = {24, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_98};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_101 = { 28 | NIM_STRLIT_FLAG, "stdlib.system.cmpIgnoreStyle" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_102 = {28, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_101};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_104 = { 27 | NIM_STRLIT_FLAG, "stdlib.system.cmpIgnoreCase" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_105 = {27, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_104};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_107 = { 24 | NIM_STRLIT_FLAG, "stdlib.system.setCommand" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_108 = {24, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_107};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_109 = { 24 | NIM_STRLIT_FLAG, "stdlib.system.getCommand" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_110 = {24, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_109};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_111 = { 20 | NIM_STRLIT_FLAG, "stdlib.system.switch" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_112 = {20, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_111};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_113 = { 22 | NIM_STRLIT_FLAG, "stdlib.system.hintImpl" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_114 = {22, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_113};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_115 = { 25 | NIM_STRLIT_FLAG, "stdlib.system.warningImpl" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_116 = {25, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_115};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_117 = { 23 | NIM_STRLIT_FLAG, "stdlib.system.patchFile" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_118 = {23, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_117};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_119 = { 1 | NIM_STRLIT_FLAG, "_" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_120 = {1, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_119};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_121 = { 3 | NIM_STRLIT_FLAG, "nim" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_122 = {3, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_121};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__FA6jNt3IW9afkuZFmR0bnUQ_123 = {
0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x40,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_124 = { 21 | NIM_STRLIT_FLAG, "stdlib.system.selfExe" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_125 = {21, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_124};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_127 = { 23 | NIM_STRLIT_FLAG, "stdlib.system.cppDefine" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_128 = {23, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_127};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_129 = { 27 | NIM_STRLIT_FLAG, "stdlib.system.stdinReadLine" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_130 = {27, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_129};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_131 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_132 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_133 = { 26 | NIM_STRLIT_FLAG, "stdlib.system.stdinReadAll" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_134 = {26, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_133};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_135 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_136 = {0, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_12};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_137 = { 5 | NIM_STRLIT_FLAG, "nimv2" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_138 = {5, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_137};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_139 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_140 = {5, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_137};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_141 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_142 = { 13 | NIM_STRLIT_FLAG, "gcdestructors" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_143 = {13, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_142};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_144 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_145 = { 9 | NIM_STRLIT_FLAG, "nimSeqsV2" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_146 = {9, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_145};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_147 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_148 = { 5 | NIM_STRLIT_FLAG, "gcarc" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_149 = {5, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_148};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_150 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_151 = { 5 | NIM_STRLIT_FLAG, "gcorc" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_152 = {5, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_151};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_153 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_154 = { 11 | NIM_STRLIT_FLAG, "gcatomicarc" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_155 = {11, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_154};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_156 = {4, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_4};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__FA6jNt3IW9afkuZFmR0bnUQ_157 = { 11 | NIM_STRLIT_FLAG, "unreachable" };
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_158 = {11, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_157};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_159 = {9, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_2};
static const NimStringV2 TM__FA6jNt3IW9afkuZFmR0bnUQ_160 = {9, (NimStrPayload*)&TM__FA6jNt3IW9afkuZFmR0bnUQ_6};
extern NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA ExeExts__pureZos_u75;
extern NIM_BOOL nimInErrorMode__system_u4143;
static NIM_CONST NU32 TM__FA6jNt3IW9afkuZFmR0bnUQ_9[2] = {3701606400, 277464320};
N_LIB_PRIVATE TNimTypeV2 NTIv2__khCJxQctW1B7wDWphVipqw_ = {.destructor = (void*)rttiDestroy__scriptconfig_u364, .size = sizeof(tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw), .align = (NI16) NIM_ALIGNOF(tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw), .depth = 1, .display = TM__FA6jNt3IW9afkuZFmR0bnUQ_9, .traceImpl = (void*)NIM_NIL, .flags = 0};
extern Exception* currException__system_u3628;
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___scriptconfig_u280)(tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).module4);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).module4)));
		nimRawDispose((*dest_p0).module4, ((NI)8));
	}
LA4_: ;
	eqdestroy___system_u2691((*dest_p0).vthisDir3);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).conf2);
		if (!T8_) goto LA9_;
		eqdestroy___options_u1751((&(*(*dest_p0).conf2)));
		nimRawDispose((*dest_p0).conf2, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).graph1);
		if (!T13_) goto LA14_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0).graph1)));
		nimRawDispose((*dest_p0).graph1, ((NI)8));
	}
LA14_: ;
	eqdestroy___system_u2691((*dest_p0).errorMsg0);
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__scriptconfig_u364)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___scriptconfig_u280((&(*((tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0) {
	NCSTRING result;
	{
		if (!(s_p0.len == ((NI)0))) goto LA3_;
		result = "";
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NCSTRING) ((*s_p0.p).data));
	}
LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosjoinPath(head_p0, tail_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, listDirs__scriptconfig_u21)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, tySet_tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ filter_p1) {
	NimStringV2 dir_1;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ result_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	dir_1.len = 0; dir_1.p = NIM_NIL;
	result_1.len = 0; result_1.p = NIM_NIL;
	dir_1 = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result_1.len = 0; result_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	{
		NimStringV2 path_1;
		tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ kind_1;
		DIR* d_1;
		path_1.len = 0; path_1.p = NIM_NIL;
		kind_1 = (tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)0;
		d_1 = opendir(nimToCStringConv(dir_1));
		{
			if (!(d_1 == ((DIR*) NIM_NIL))) goto LA6_;
			{
				NI32 T12_;
				if (!NIM_FALSE) goto LA10_;
				T12_ = (NI32)0;
				T12_ = osLastError__stdZoserrors_u122();
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				raiseOSError__stdZoserrors_u119(T12_, dir_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			}
LA10_: ;
		}
		goto LA4_;
LA6_: ;
		{
			{
				while (1) {
					{
						NimStringV2 y_1;
						struct dirent* x_1;
						y_1.len = 0; y_1.p = NIM_NIL;
						x_1 = readdir(d_1);
						{
							if (!(x_1 == ((struct dirent*) NIM_NIL))) goto LA21_;
							eqdestroy___system_u2691(y_1);
							goto LA15;
						}
LA21_: ;
						y_1 = cstrToNimstr(((NCSTRING) ((*x_1).d_name)));
						{
							NIM_BOOL T25_;
							NimStringV2 path_2;
							struct stat s_1;
							tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ k_1;
							T25_ = (NIM_BOOL)0;
							T25_ = !(eqStrings(y_1, TM__FA6jNt3IW9afkuZFmR0bnUQ_15));
							if (!(T25_)) goto LA26_;
							T25_ = !(eqStrings(y_1, TM__FA6jNt3IW9afkuZFmR0bnUQ_17));
LA26_: ;
							if (!T25_) goto LA27_;
							path_2.len = 0; path_2.p = NIM_NIL;
							nimZeroMem((void*)(&s_1), sizeof(struct stat));
							path_2 = slash___stdZprivateZospaths2_u91(dir_1, y_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							{
								if (!NIM_TRUE) goto LA32_;
								eqcopy___system_u2694((&y_1), path_2);
							}
LA32_: ;
							k_1 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)0);
							switch ((*x_1).d_type) {
							case ((NI8)4):
							{
								k_1 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)2);
							}
							break;
							case ((NI8)10):
							{
								NIM_BOOL isSpecialX60gensym19__1;
								tyTuple__wjbnfGBIEcH6aaevyJWrgw tmpTupleAsgn;
								isSpecialX60gensym19__1 = (NIM_BOOL)0;
								tmpTupleAsgn = getSymlinkFileKind__stdZprivateZoscommon_u20(path_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
								k_1 = tmpTupleAsgn.Field0;
								isSpecialX60gensym19__1 = tmpTupleAsgn.Field1;
								{
									NIM_BOOL T38_;
									T38_ = (NIM_BOOL)0;
									T38_ = NIM_FALSE;
									if (!(T38_)) goto LA39_;
									T38_ = isSpecialX60gensym19__1;
LA39_: ;
									if (!T38_) goto LA40_;
									eqdestroy___system_u2691(path_2);
									eqdestroy___system_u2691(y_1);
									goto LA17;
								}
LA40_: ;
							}
							break;
							case ((NI8)0):
							{
								{
									int T45_;
									T45_ = (int)0;
									T45_ = lstat(nimToCStringConv(path_2), (&s_1));
									if (!(T45_ < ((NI32)0))) goto LA46_;
									eqdestroy___system_u2691(path_2);
									eqdestroy___system_u2691(y_1);
									goto LA17;
								}
								goto LA43_;
LA46_: ;
								{
									NIM_BOOL T49_;
									T49_ = (NIM_BOOL)0;
									T49_ = S_ISDIR(s_1.st_mode);
									if (!T49_) goto LA50_;
									k_1 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)2);
								}
								goto LA43_;
LA50_: ;
								{
									NIM_BOOL T53_;
									NIM_BOOL isSpecialX60gensym21__1;
									tyTuple__wjbnfGBIEcH6aaevyJWrgw tmpTupleAsgn_2;
									T53_ = (NIM_BOOL)0;
									T53_ = S_ISLNK(s_1.st_mode);
									if (!T53_) goto LA54_;
									isSpecialX60gensym21__1 = (NIM_BOOL)0;
									tmpTupleAsgn_2 = getSymlinkFileKind__stdZprivateZoscommon_u20(path_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
									k_1 = tmpTupleAsgn_2.Field0;
									isSpecialX60gensym21__1 = tmpTupleAsgn_2.Field1;
									{
										NIM_BOOL T58_;
										T58_ = (NIM_BOOL)0;
										T58_ = NIM_FALSE;
										if (!(T58_)) goto LA59_;
										T58_ = isSpecialX60gensym21__1;
LA59_: ;
										if (!T58_) goto LA60_;
										eqdestroy___system_u2691(path_2);
										eqdestroy___system_u2691(y_1);
										goto LA17;
									}
LA60_: ;
								}
								goto LA43_;
LA54_: ;
								{
									NIM_BOOL T63_;
									NIM_BOOL T65_;
									T63_ = (NIM_BOOL)0;
									T63_ = NIM_FALSE;
									if (!(T63_)) goto LA64_;
									T65_ = (NIM_BOOL)0;
									T65_ = S_ISREG(s_1.st_mode);
									T63_ = !(T65_);
LA64_: ;
									if (!T63_) goto LA66_;
									eqdestroy___system_u2691(path_2);
									eqdestroy___system_u2691(y_1);
									goto LA17;
								}
								goto LA43_;
LA66_: ;
LA43_: ;
							}
							break;
							default:
							{
								{
									NIM_BOOL T71_;
									T71_ = (NIM_BOOL)0;
									T71_ = NIM_FALSE;
									if (!(T71_)) goto LA72_;
									T71_ = !(((*x_1).d_type == ((NI8)8)));
LA72_: ;
									if (!T71_) goto LA73_;
									eqdestroy___system_u2691(path_2);
									eqdestroy___system_u2691(y_1);
									goto LA17;
								}
								goto LA69_;
LA73_: ;
								{
								}
LA69_: ;
							}
							break;
							}
							kind_1 = k_1;
							eqsink___system_u2700((&path_1), y_1);
							eqwasMoved___system_u2688((&y_1));
							{
								NimStringV2 blitTmp_1;
								if (!((filter_p1 &((NU8)1<<((NU)((kind_1))&7U)))!=0)) goto LA78_;
								blitTmp_1 = path_1;
								eqwasMoved___system_u2688((&path_1));
								add__stdZenumutils_u71((&result_1), blitTmp_1);
							}
LA78_: ;
							{
								LA29_:;
							}
							{
								eqdestroy___system_u2691(path_2);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						}
LA27_: ;
						{
							LA18_:;
						}
						{
							eqdestroy___system_u2691(y_1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					} LA17: ;
				}
			} LA15: ;
			{
				LA14_:;
			}
			{
				int T86_;
				T86_ = (int)0;
				T86_ = closedir(d_1);
				(void)(T86_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
LA4_: ;
		{
			LA3_:;
		}
		{
			eqdestroy___system_u2691(path_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	setResult__vm_u280(a_p0, result_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u5506(result_1);
		eqdestroy___system_u2691(dir_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (targetDepth_p1 <= (*source_p0).depth);
	if (!(T1_)) goto LA2_;
	T1_ = ((*source_p0).display[targetDepth_p1] == token_p2);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = currException__system_u3628;
	return result;
}
static N_INLINE(NimStringV2, getCurrentExceptionMsg__system_u7940)(void) {
	NimStringV2 result;
	NimStringV2 T1_;
{	result.len = 0; result.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		if (!(currException__system_u3628 == ((Exception*) NIM_NIL))) goto LA4_;
		result = TM__FA6jNt3IW9afkuZFmR0bnUQ_18;
	}
	goto LA2_;
LA4_: ;
	{
		eqcopy___system_u2694((&result), (*currException__system_u3628).message);
	}
LA2_: ;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	eqcopy___system_u3661(&currException__system_u3628, (*currException__system_u3628).up, NIM_FALSE);
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u60)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_13);
	listDirs__scriptconfig_u21(a_p0, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T5_;
			*nimErr_ = NIM_FALSE;
			T5_.len = 0; T5_.p = NIM_NIL;
			T5_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T5_);
			popCurrentException();
			LA3_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u62)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_21);
	listDirs__scriptconfig_u21(a_p0, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T5_;
			*nimErr_ = NIM_FALSE;
			T5_.len = 0; T5_.p = NIM_NIL;
			T5_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T5_);
			popCurrentException();
			LA3_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u64)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_24);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T10_;
		NIM_BOOL T11_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = getString__vm_u400(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		colontmpD_ = T10_;
		T11_ = (NIM_BOOL)0;
		T11_ = getBool__vm_u346(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		nosremoveDir(colontmpD_, T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T17_;
			*nimErr_ = NIM_FALSE;
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T17_);
			popCurrentException();
			LA15_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u70)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_27);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T10_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = getString__vm_u400(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		colontmpD_ = T10_;
		nosremoveFile(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T16_;
			*nimErr_ = NIM_FALSE;
			T16_.len = 0; T16_.p = NIM_NIL;
			T16_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T16_);
			popCurrentException();
			LA14_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u76)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_30);
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA2_;}
	colontmpD_ = T3_;
	noscreateDir(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	{
		LA2_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T9_;
			*nimErr_ = NIM_FALSE;
			T9_.len = 0; T9_.p = NIM_NIL;
			T9_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T9_);
			popCurrentException();
			LA7_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u78)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	setResult__vm_u271(a_p0, (*colonenvP__1).errorMsg0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, setCurrentDir__stdZprivateZosdirs_u501)(NimStringV2 newDir_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		int T3_;
		NI32 T6_;
		T3_ = (int)0;
		T3_ = chdir(nimToCStringConv(newDir_p0));
		if (!!((T3_ == ((NI32)0)))) goto LA4_;
		T6_ = (NI32)0;
		T6_ = osLastError__stdZoserrors_u122();
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		raiseOSError__stdZoserrors_u119(T6_, newDir_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u80)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_35);
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA2_;}
	colontmpD_ = T3_;
	setCurrentDir__stdZprivateZosdirs_u501(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	{
		LA2_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T9_;
			*nimErr_ = NIM_FALSE;
			T9_.len = 0; T9_.p = NIM_NIL;
			T9_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T9_);
			popCurrentException();
			LA7_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u82)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_38);
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = nosgetCurrentDir();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA2_;}
	colontmpD_ = T3_;
	setResult__vm_u271(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	{
		LA2_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T9_;
			*nimErr_ = NIM_FALSE;
			T9_.len = 0; T9_.p = NIM_NIL;
			T9_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T9_);
			popCurrentException();
			LA7_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u84)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_41);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T10_;
		NimStringV2 T11_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = getString__vm_u400(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		colontmpD_ = T10_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = getString__vm_u400(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA9_;}
		colontmpD__2 = T11_;
		nosmoveFile(colontmpD_, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T17_;
			*nimErr_ = NIM_FALSE;
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T17_);
			popCurrentException();
			LA15_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u90)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_44);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T10_;
		NimStringV2 T11_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = getString__vm_u400(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		colontmpD_ = T10_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = getString__vm_u400(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA9_;}
		colontmpD__2 = T11_;
		moveDir__stdZprivateZosdirs_u498(colontmpD_, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T17_;
			*nimErr_ = NIM_FALSE;
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T17_);
			popCurrentException();
			LA15_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u96)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_47);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T10_;
		NimStringV2 T11_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = getString__vm_u400(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		colontmpD_ = T10_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = getString__vm_u400(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA9_;}
		colontmpD__2 = T11_;
		noscopyFile(colontmpD_, colontmpD__2, 2, ((NI)16384));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T17_;
			*nimErr_ = NIM_FALSE;
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T17_);
			popCurrentException();
			LA15_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u102)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_50);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T10_;
		NimStringV2 T11_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = getString__vm_u400(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		colontmpD_ = T10_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = getString__vm_u400(a_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA9_;}
		colontmpD__2 = T11_;
		noscopyDir(colontmpD_, colontmpD__2, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T17_;
			*nimErr_ = NIM_FALSE;
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T17_);
			popCurrentException();
			LA15_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u108)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 T3_;
	tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA T4_;
	NI64 T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_53);
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA2_;}
	colontmpD_ = T3_;
	T4_ = nosgetLastModificationTime(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	T5_ = (NI64)0;
	T5_ = toUnix__pureZtimes_u1240(T4_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	setResult__vm_u258(a_p0, T5_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	{
		LA2_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T11_;
			*nimErr_ = NIM_FALSE;
			T11_.len = 0; T11_.p = NIM_NIL;
			T11_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T11_);
			popCurrentException();
			LA9_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u110)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T3_;
	NimStringV2 T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_56);
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA2_;}
	colontmpD_ = T3_;
	T4_.len = 0; T4_.p = NIM_NIL;
	T4_ = findExe__pureZos_u76(colontmpD_, NIM_TRUE, ExeExts__pureZos_u75, 1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T4_); goto LA2_;}
	colontmpD__2 = T4_;
	setResult__vm_u271(a_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	{
		LA2_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T10_;
			*nimErr_ = NIM_FALSE;
			T10_.len = 0; T10_.p = NIM_NIL;
			T10_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T10_);
			popCurrentException();
			LA8_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u112)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_59);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T9_;
		NI T10_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T9_.len = 0; T9_.p = NIM_NIL;
		T9_ = getString__vm_u400(a_p0, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T9_); goto LA1_;}
		colontmpD_ = T9_;
		T10_ = (NI)0;
		T10_ = nospexecCmd(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		setResult__vm_u258(a_p0, ((NI64) (T10_)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(colontmpD_);
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 T14_;
			*nimErr_ = NIM_FALSE;
			T14_.len = 0; T14_.p = NIM_NIL;
			T14_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T14_);
			popCurrentException();
			LA12_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u118)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__3 = getEnv__stdZenvvars_u16(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u271(a_p0, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__3);
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u120)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = existsEnv__stdZenvvars_u21(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u264(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u122)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	putEnv__stdZenvvars_u24(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u124)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	delEnv__stdZenvvars_u30(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u126)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = nosdirExists(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u264(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u128)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = nosfileExists(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u264(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u130)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	setResult__vm_u271(a_p0, (*(*colonenvP__1).conf2).projectName);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u132)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	setResult__vm_u271(a_p0, (*(*colonenvP__1).conf2).projectPath);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u134)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	setResult__vm_u271(a_p0, (*(*colonenvP__1).conf2).projectFull);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u136)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	setResult__vm_u271(a_p0, (*colonenvP__1).vthisDir3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u138)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setConfigVar__options_u3608((*colonenvP__1).conf2, colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u140)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = getConfigVar__options_u3603((*colonenvP__1).conf2, colontmpD_, TM__FA6jNt3IW9afkuZFmR0bnUQ_90);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u271(a_p0, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u142)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = existsConfigVar__options_u3599((*colonenvP__1).conf2, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u264(a_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u144)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getNimcacheDir__options_u3737((*colonenvP__1).conf2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setResult__vm_u271(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u146)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NI64 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_ = (NI64)0;
	T1_ = getInt__vm_u301(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = paramStr__stdZcmdline_u56(((NI) (T1_)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u271(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u148)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI)0;
	T1_ = paramCount__stdZcmdline_u62();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u258(a_p0, ((NI64) (T1_)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u150)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	T1_ = nsuCmpIgnoreStyle(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u258(a_p0, ((NI64) (T1_)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u152)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	T1_ = nsuCmpIgnoreCase(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u258(a_p0, ((NI64) (T1_)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u154)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 arg_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	arg_1.len = 0; arg_1.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setCommandEarly__commands_u1214((*colonenvP__1).conf2, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	arg_1 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*(*colonenvP__1).conf2).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)2))) & 63);
	{
		if (!(((NI)0) < arg_1.len)) goto LA4_;
		setFromProjectName__options_u3673((*colonenvP__1).conf2, arg_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(arg_1);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u161)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	setResult__vm_u271(a_p0, (*(*colonenvP__1).conf2).command);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u163)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	eqcopy___system_u2694((&(*(*colonenvP__1).conf2).currentConfigDir), (*colonenvP__1).vthisDir3);
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	processSwitch__commands_u1361(colontmpD_, colontmpD__2, ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2), (*(*colonenvP__1).module4).info, (*colonenvP__1).conf2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u165)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	processSpecificNote__commands_u290(colontmpD_, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)125), ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2), (*(*colonenvP__1).module4).info, colontmpD__2, (*colonenvP__1).conf2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u167)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	processSpecificNote__commands_u290(colontmpD_, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)124), ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2), (*(*colonenvP__1).module4).info, colontmpD__2, (*colonenvP__1).conf2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u169)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 key_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 val_1;
	NimStringV2 colontmpD__3;
	NimStringV2 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	key_1.len = 0; key_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	val_1.len = 0; val_1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getString__vm_u400(a_p0, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + colontmpD__2.len + 1);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__FA6jNt3IW9afkuZFmR0bnUQ_120);
appendString((&T2_), colontmpD__2);
	key_1 = T2_;
	colontmpD__3 = getString__vm_u400(a_p0, ((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	val_1 = nosaddFileExt(colontmpD__3, TM__FA6jNt3IW9afkuZFmR0bnUQ_122);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		NimStringV2 T8_;
		T5_ = (NIM_BOOL)0;
		T5_ = contains__pureZstrutils_u1837(val_1, TM__FA6jNt3IW9afkuZFmR0bnUQ_123);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T5_) goto LA6_;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = pathSubs__options_u3759((*colonenvP__1).conf2, val_1, (*colonenvP__1).vthisDir3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T8_); goto LA1_;}
		eqsink___system_u2700((&val_1), T8_);
	}
	goto LA3_;
LA6_: ;
	{
		NIM_BOOL T10_;
		NimStringV2 T13_;
		T10_ = (NIM_BOOL)0;
		T10_ = nosisAbsolute(val_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T10_)) goto LA11_;
		T13_.len = 0; T13_.p = NIM_NIL;
		T13_ = slash___stdZprivateZospaths2_u91((*colonenvP__1).vthisDir3, val_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T13_); goto LA1_;}
		eqsink___system_u2700((&val_1), T13_);
	}
	goto LA3_;
LA11_: ;
LA3_: ;
	nstPut((*(*colonenvP__1).conf2).moduleOverrides, key_1, val_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(val_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(key_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, colonanonymous___scriptconfig_u173)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nosgetAppFilename();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setResult__vm_u271(a_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u175)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getString__vm_u400(a_p0, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	cppDefine__options_u2159((*colonenvP__1).conf2, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u177)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_131);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
		setResult__vm_u271(a_p0, TM__FA6jNt3IW9afkuZFmR0bnUQ_132);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T10_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = readLine__stdZsyncio_u319(stdin);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		colontmpD_ = T10_;
		setResult__vm_u271(a_p0, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 4, 4262491648)) {
			NimStringV2 T16_;
			*nimErr_ = NIM_FALSE;
			T16_.len = 0; T16_.p = NIM_NIL;
			T16_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T16_);
			popCurrentException();
			LA14_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___scriptconfig_u183)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* a_p0, void* ClE_0) {
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) ClE_0;
	eqsink___system_u2700((&(*colonenvP__1).errorMsg0), TM__FA6jNt3IW9afkuZFmR0bnUQ_135);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = NIM_FALSE;
		if (T4_) goto LA5_;
		T4_ = ((*(*(*colonenvP__1).graph1).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
LA5_: ;
		if (!T4_) goto LA6_;
		setResult__vm_u271(a_p0, TM__FA6jNt3IW9afkuZFmR0bnUQ_136);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T10_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = readAll__stdZsyncio_u381(stdin);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		colontmpD_ = T10_;
		setResult__vm_u271(a_p0, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 4, 4262491648)) {
			NimStringV2 T16_;
			*nimErr_ = NIM_FALSE;
			T16_.len = 0; T16_.p = NIM_NIL;
			T16_ = getCurrentExceptionMsg__system_u7940();
			eqsink___system_u2700((&(*colonenvP__1).errorMsg0), T16_);
			popCurrentException();
			LA14_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___scriptconfig_u329)(tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__khCJxQctW1B7wDWphVipqw_))));
		if (!T3_) goto LA4_;
		eqdestroy___scriptconfig_u280((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*, setupVM__scriptconfig_u40)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, NimStringV2 scriptName_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p3, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p4) {
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* result;
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* colonenv__1;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD_;
	tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw* T1_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T2_;
	NI T3_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T4_;
	NI T5_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T6_;
	NI T7_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T8_;
	NI T9_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T10_;
	NI T11_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T12_;
	NI T13_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T14_;
	NI T15_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T16_;
	NI T17_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T18_;
	NI T19_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T20_;
	NI T21_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T22_;
	NI T23_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T24_;
	NI T25_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T26_;
	NI T27_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T28_;
	NI T29_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T30_;
	NI T31_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T32_;
	NI T33_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T34_;
	NI T35_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T36_;
	NI T37_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T38_;
	NI T39_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T40_;
	NI T41_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T42_;
	NI T43_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T44_;
	NI T45_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T46_;
	NI T47_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T48_;
	NI T49_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T50_;
	NI T51_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T52_;
	NI T53_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T54_;
	NI T55_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T56_;
	NI T57_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T58_;
	NI T59_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T60_;
	NI T61_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T62_;
	NI T63_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T64_;
	NI T65_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T66_;
	NI T67_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T68_;
	NI T69_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T70_;
	NI T71_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T72_;
	NI T73_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T74_;
	NI T75_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T76_;
	NI T77_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T78_;
	NI T79_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T80_;
	NI T81_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T82_;
	NI T83_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T84_;
	NI T85_;
	tyProc__c9bXGQkBnyyGGVw063jrwZw T86_;
	NI T87_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colonenv__1 = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	T1_ = NIM_NIL;
	T1_ = (tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw*) nimNewObj(sizeof(tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw), NIM_ALIGNOF(tyObject_Env_scriptconfigdotnim_setupVM___khCJxQctW1B7wDWphVipqw));
	(*T1_).Sup.m_type = (&NTIv2__khCJxQctW1B7wDWphVipqw_);
	colonenv__1 = T1_;
	eqcopy___ast_u4577(&(*colonenv__1).module4, module_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___modulegraphs_u14756(&(*colonenv__1).graph1, graph_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newCtx__vmdef_u383((*colonenv__1).module4, cache_p1, (*colonenv__1).graph1, idgen_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).mode = ((tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg)0);
	registerAdditionalOps__vm_u13299(result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___options_u2138(&(*colonenv__1).conf2, (*(*colonenv__1).graph1).config);
	nossplitFile(scriptName_p2, (&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___system_u2700((&(*colonenv__1).vthisDir3), colontmpD_.Field0);
	eqwasMoved___system_u2688((&colontmpD_.Field0));
	nimZeroMem((void*)(&T2_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T2_.ClP_0 = colonanonymous___scriptconfig_u60; T2_.ClE_0 = colonenv__1;
	T3_ = (NI)0;
	T3_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_11, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T4_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T4_.ClP_0 = colonanonymous___scriptconfig_u62; T4_.ClE_0 = colonenv__1;
	T5_ = (NI)0;
	T5_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_20, T4_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T6_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T6_.ClP_0 = colonanonymous___scriptconfig_u64; T6_.ClE_0 = colonenv__1;
	T7_ = (NI)0;
	T7_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_23, T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T8_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T8_.ClP_0 = colonanonymous___scriptconfig_u70; T8_.ClE_0 = colonenv__1;
	T9_ = (NI)0;
	T9_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_26, T8_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T10_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T10_.ClP_0 = colonanonymous___scriptconfig_u76; T10_.ClE_0 = colonenv__1;
	T11_ = (NI)0;
	T11_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_29, T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T12_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T12_.ClP_0 = colonanonymous___scriptconfig_u78; T12_.ClE_0 = colonenv__1;
	T13_ = (NI)0;
	T13_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_32, T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T14_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T14_.ClP_0 = colonanonymous___scriptconfig_u80; T14_.ClE_0 = colonenv__1;
	T15_ = (NI)0;
	T15_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_34, T14_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T16_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T16_.ClP_0 = colonanonymous___scriptconfig_u82; T16_.ClE_0 = colonenv__1;
	T17_ = (NI)0;
	T17_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_37, T16_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T18_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T18_.ClP_0 = colonanonymous___scriptconfig_u84; T18_.ClE_0 = colonenv__1;
	T19_ = (NI)0;
	T19_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_40, T18_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T20_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T20_.ClP_0 = colonanonymous___scriptconfig_u90; T20_.ClE_0 = colonenv__1;
	T21_ = (NI)0;
	T21_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_43, T20_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T22_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T22_.ClP_0 = colonanonymous___scriptconfig_u96; T22_.ClE_0 = colonenv__1;
	T23_ = (NI)0;
	T23_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_46, T22_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T24_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T24_.ClP_0 = colonanonymous___scriptconfig_u102; T24_.ClE_0 = colonenv__1;
	T25_ = (NI)0;
	T25_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_49, T24_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T26_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T26_.ClP_0 = colonanonymous___scriptconfig_u108; T26_.ClE_0 = colonenv__1;
	T27_ = (NI)0;
	T27_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_52, T26_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T28_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T28_.ClP_0 = colonanonymous___scriptconfig_u110; T28_.ClE_0 = colonenv__1;
	T29_ = (NI)0;
	T29_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_55, T28_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T30_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T30_.ClP_0 = colonanonymous___scriptconfig_u112; T30_.ClE_0 = colonenv__1;
	T31_ = (NI)0;
	T31_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_58, T30_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T32_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T32_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_62) (colonanonymous___scriptconfig_u118)); T32_.ClE_0 = NIM_NIL;
	T33_ = (NI)0;
	T33_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_61, T32_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T34_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T34_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_65) (colonanonymous___scriptconfig_u120)); T34_.ClE_0 = NIM_NIL;
	T35_ = (NI)0;
	T35_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_64, T34_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T36_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T36_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_68) (colonanonymous___scriptconfig_u122)); T36_.ClE_0 = NIM_NIL;
	T37_ = (NI)0;
	T37_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_67, T36_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T38_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T38_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_71) (colonanonymous___scriptconfig_u124)); T38_.ClE_0 = NIM_NIL;
	T39_ = (NI)0;
	T39_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_70, T38_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T40_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T40_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_74) (colonanonymous___scriptconfig_u126)); T40_.ClE_0 = NIM_NIL;
	T41_ = (NI)0;
	T41_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_73, T40_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T42_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T42_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_77) (colonanonymous___scriptconfig_u128)); T42_.ClE_0 = NIM_NIL;
	T43_ = (NI)0;
	T43_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_76, T42_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T44_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T44_.ClP_0 = colonanonymous___scriptconfig_u130; T44_.ClE_0 = colonenv__1;
	T45_ = (NI)0;
	T45_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_79, T44_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T46_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T46_.ClP_0 = colonanonymous___scriptconfig_u132; T46_.ClE_0 = colonenv__1;
	T47_ = (NI)0;
	T47_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_81, T46_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T48_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T48_.ClP_0 = colonanonymous___scriptconfig_u134; T48_.ClE_0 = colonenv__1;
	T49_ = (NI)0;
	T49_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_83, T48_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T50_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T50_.ClP_0 = colonanonymous___scriptconfig_u136; T50_.ClE_0 = colonenv__1;
	T51_ = (NI)0;
	T51_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_85, T50_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T52_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T52_.ClP_0 = colonanonymous___scriptconfig_u138; T52_.ClE_0 = colonenv__1;
	T53_ = (NI)0;
	T53_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_87, T52_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T54_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T54_.ClP_0 = colonanonymous___scriptconfig_u140; T54_.ClE_0 = colonenv__1;
	T55_ = (NI)0;
	T55_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_89, T54_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T56_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T56_.ClP_0 = colonanonymous___scriptconfig_u142; T56_.ClE_0 = colonenv__1;
	T57_ = (NI)0;
	T57_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_92, T56_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T58_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T58_.ClP_0 = colonanonymous___scriptconfig_u144; T58_.ClE_0 = colonenv__1;
	T59_ = (NI)0;
	T59_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_94, T58_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T60_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T60_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_97) (colonanonymous___scriptconfig_u146)); T60_.ClE_0 = NIM_NIL;
	T61_ = (NI)0;
	T61_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_96, T60_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T62_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T62_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_100) (colonanonymous___scriptconfig_u148)); T62_.ClE_0 = NIM_NIL;
	T63_ = (NI)0;
	T63_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_99, T62_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T64_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T64_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_103) (colonanonymous___scriptconfig_u150)); T64_.ClE_0 = NIM_NIL;
	T65_ = (NI)0;
	T65_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_102, T64_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T66_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T66_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_106) (colonanonymous___scriptconfig_u152)); T66_.ClE_0 = NIM_NIL;
	T67_ = (NI)0;
	T67_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_105, T66_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T68_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T68_.ClP_0 = colonanonymous___scriptconfig_u154; T68_.ClE_0 = colonenv__1;
	T69_ = (NI)0;
	T69_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_108, T68_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T70_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T70_.ClP_0 = colonanonymous___scriptconfig_u161; T70_.ClE_0 = colonenv__1;
	T71_ = (NI)0;
	T71_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_110, T70_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T72_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T72_.ClP_0 = colonanonymous___scriptconfig_u163; T72_.ClE_0 = colonenv__1;
	T73_ = (NI)0;
	T73_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_112, T72_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T74_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T74_.ClP_0 = colonanonymous___scriptconfig_u165; T74_.ClE_0 = colonenv__1;
	T75_ = (NI)0;
	T75_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_114, T74_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T76_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T76_.ClP_0 = colonanonymous___scriptconfig_u167; T76_.ClE_0 = colonenv__1;
	T77_ = (NI)0;
	T77_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_116, T76_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T78_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T78_.ClP_0 = colonanonymous___scriptconfig_u169; T78_.ClE_0 = colonenv__1;
	T79_ = (NI)0;
	T79_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_118, T78_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T80_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T80_.ClP_0 = ((TM__FA6jNt3IW9afkuZFmR0bnUQ_126) (colonanonymous___scriptconfig_u173)); T80_.ClE_0 = NIM_NIL;
	T81_ = (NI)0;
	T81_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_125, T80_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T82_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T82_.ClP_0 = colonanonymous___scriptconfig_u175; T82_.ClE_0 = colonenv__1;
	T83_ = (NI)0;
	T83_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_128, T82_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T84_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T84_.ClP_0 = colonanonymous___scriptconfig_u177; T84_.ClE_0 = colonenv__1;
	T85_ = (NI)0;
	T85_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_130, T84_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T86_), sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	T86_.ClP_0 = colonanonymous___scriptconfig_u183; T86_.ClE_0 = colonenv__1;
	T87_ = (NI)0;
	T87_ = registerCallback__vmdef_u2258(result, TM__FA6jNt3IW9afkuZFmR0bnUQ_134, T86_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___pureZos_u200((&colontmpD_));
	eqdestroy___scriptconfig_u329(colonenv__1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, runNimScript__scriptconfig_u189)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, NimStringV2 scriptName_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, NIM_BOOL freshDefines_p3, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p4, tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg* stream_p5) {
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_1;
	NimStringV2 colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* vm_1;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* colontmpD__2;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA oldSymbolFiles_1;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A oldGlobalOptions_1;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg oldSelectedGC_1;
	NIM_BOOL T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	graph_1 = NIM_NIL;
	m_1 = NIM_NIL;
	vm_1 = NIM_NIL;
	oldSymbolFiles_1 = (*conf_p4).symbolFiles;
	(*conf_p4).symbolFiles = ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0);
	graph_1 = newModuleGraph__modulegraphs_u13525(cache_p0, conf_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	connectPipelineCallbacks__pipelines_u1647(graph_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!freshDefines_p3) goto LA4_;
		initDefines__condsyms_u17((*conf_p4).symbols);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_3, TM__FA6jNt3IW9afkuZFmR0bnUQ_5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_7, TM__FA6jNt3IW9afkuZFmR0bnUQ_8);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___system_u2697((*conf_p4).libpath);
	add__commands_u1640((&(*conf_p4).searchPaths), colontmpD_);
	oldGlobalOptions_1 = (*conf_p4).globalOptions;
	oldSelectedGC_1 = (*conf_p4).selectedGC;
	unregisterArcOrc__commands_u1313(conf_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*conf_p4).globalOptions &= ~(((NU64)1) << (((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)47))) & 63));
	(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)0);
	m_1 = makeModule__modules_u44(graph_1, scriptName_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*m_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14))) & 63);
	vm_1 = setupVM__scriptconfig_u40(m_1, cache_p0, scriptName_p1, graph_1, idgen_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = eqdup___vmdef_u2213(vm_1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___ast_u4955(&(*graph_1).vm, (*((RootObj**) (&(colontmpD__2)))));
	setPipeLinePass__pipelines_u36(graph_1, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)4));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	compilePipelineSystemModule__pipelines_u1687(graph_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = (NIM_BOOL)0;
	T6_ = processPipelineModule__pipelines_u418(graph_1, m_1, (*vm_1).Sup.idgen, stream_p5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(T6_);
	{
		if (!((*conf_p4).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)0))) goto LA9_;
		(*conf_p4).selectedGC = oldSelectedGC_1;
	}
LA9_: ;
	{
		if (!((oldGlobalOptions_1 &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)47)))&63U)))!=0)) goto LA13_;
		(*conf_p4).globalOptions = ((*conf_p4).globalOptions | IL64(246290604621824));
		defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_138, TM__FA6jNt3IW9afkuZFmR0bnUQ_139);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	{
		if (!((*conf_p4).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*conf_p4).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5) || (*conf_p4).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6))) goto LA17_;
		(*conf_p4).globalOptions = ((*conf_p4).globalOptions | IL64(105553116266496));
		defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_140, TM__FA6jNt3IW9afkuZFmR0bnUQ_141);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_143, TM__FA6jNt3IW9afkuZFmR0bnUQ_144);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_146, TM__FA6jNt3IW9afkuZFmR0bnUQ_147);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		switch ((*conf_p4).selectedGC) {
		case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4):
		{
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_149, TM__FA6jNt3IW9afkuZFmR0bnUQ_150);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5):
		{
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_152, TM__FA6jNt3IW9afkuZFmR0bnUQ_153);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6):
		{
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_155, TM__FA6jNt3IW9afkuZFmR0bnUQ_156);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
			raiseAssert__stdZassertions_u15(TM__FA6jNt3IW9afkuZFmR0bnUQ_158);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		}
	}
LA17_: ;
	resetSystemArtifacts__modules_u13(graph_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	undefSymbol__condsyms_u8((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_159);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	undefSymbol__condsyms_u8((*conf_p4).symbols, TM__FA6jNt3IW9afkuZFmR0bnUQ_160);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*conf_p4).symbolFiles = oldSymbolFiles_1;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___vmdef_u2206(vm_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___modulegraphs_u14753(graph_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
