/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_OptParser__pqMTtVZW7HhFSYkGtStiLg tyObject_OptParser__pqMTtVZW7HhFSYkGtStiLg;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct Exception Exception;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA;
typedef struct tyTuple__8TaWyfF78pGKQc2T027bVA tyTuple__8TaWyfF78pGKQc2T027bVA;
typedef struct tyTuple__odFiRrDKhZPQ2taWAayfYw tyTuple__odFiRrDKhZPQ2taWAayfYw;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
typedef NU8 tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw;
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU16 tySet_tyEnum_ParserRules__uEyHTc9b9aq9acVuwJNR0YL9cw;
typedef NU8 tyEnum_CmdLineKind__HBxufsKJDla5VnYoM9ck1bg;
struct tyObject_OptParser__pqMTtVZW7HhFSYkGtStiLg {
	RootObj Sup;
	NI pos;
	NIM_BOOL inShortState;
	tySet_tyChar__nmiMWKVIe46vacnhAFrQvw shortNoVal;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ longNoVal;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cmds;
	NI idx;
	tySet_tyChar__nmiMWKVIe46vacnhAFrQvw separators;
	tySet_tyEnum_ParserRules__uEyHTc9b9aq9acVuwJNR0YL9cw rules;
	tyEnum_CmdLineKind__HBxufsKJDla5VnYoM9ck1bg kind;
	NimStringV2 key;
	NimStringV2 val;
};
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
typedef NU8 tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA[16];
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef NU8 tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw;
typedef NU8 tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA {
	NI a;
	NI b;
};
typedef tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw tyArray__jQ6Zibb0SzsKfL1Qwwi9bag[4];
typedef NU8 tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw;
typedef NU8 tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg;
struct tyTuple__8TaWyfF78pGKQc2T027bVA {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NimStringV2 Field5;
	NimStringV2 Field6;
	NimStringV2 Field7;
	NimStringV2 Field8;
	NimStringV2 Field9;
	NimStringV2 Field10;
	NimStringV2 Field11;
	tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg Field12;
};
typedef tyTuple__8TaWyfF78pGKQc2T027bVA tyArray__RQFn3NKTp5P7VzZ9bksPIyA[34];
typedef NU8 tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ;
struct tyTuple__odFiRrDKhZPQ2taWAayfYw {
	NimStringV2 Field0;
	NI Field1;
	tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ Field2;
	NI Field3;
	NI Field4;
};
typedef tyTuple__odFiRrDKhZPQ2taWAayfYw tyArray__BJ38CrWfGxMtyd3CSynibg[29];
typedef NU8 tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringV2 s_p0, NimStringV2 suffix_p1);
N_LIB_PRIVATE N_NIMCALL(void, setCmd__commands_u1211)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosunixToNativePath)(NimStringV2 path_p0, NimStringV2 drive_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, npocmdLineRest)(tyObject_OptParser__pqMTtVZW7HhFSYkGtStiLg* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, setCommandEarly__commands_u1214)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 command_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ, parseCommand__commands_u1189)(NimStringV2 command_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuNormalize)(NimStringV2 s_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringV2 s_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringV2 s_p0, NIM_CHAR sub_p1, NI start_p2, NI last_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8659)(NimStringV2 s_p0, NI first_p1, NI last_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8672)(NimStringV2 s_p0, NI first_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_u1361)(NimStringV2 switch_p0, NimStringV2 arg_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p4);
N_LIB_PRIVATE N_NIMCALL(void, expectArg__commands_u278)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, addPrefix__commands_u184)(NimStringV2 switch_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuToLowerAsciiStr)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1833)(NimStringV2 s_p0, NimStringV2 sub_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, removeTrailingDirSep__options_u3681)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, addPath__nimblecmd_u13)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, processCfgPath__commands_u1115)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuUnescape)(NimStringV2 s_p0, NimStringV2 prefix_p1, NimStringV2 suffix_p2);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringV2 path_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringV2 path_p0);
static N_INLINE(NIM_BOOL, contains__stdZprivateZospaths2_u383)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1);
static N_INLINE(NI, find__stdZprivateZospaths2_u388)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1);
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosjoinPath)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, pathSubs__options_u3759)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 p_p1, NimStringV2 config_p2);
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3659)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZos_u236)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, processPath__commands_u1104)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, NIM_BOOL notRelativeToProj_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getEnv__stdZenvvars_u16)(NimStringV2 key_p0, NimStringV2 default_p1);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_u139)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, slash___pathutils_u166)(NimStringV2 base_p0, NimStringV2 f_p1);
N_LIB_PRIVATE N_NIMCALL(void, nimblePath__nimblecmd_u2257)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(void, expectNoArg__commands_u284)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(void, disableNimblePath__options_u3684)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, clearNimblePath__options_u3698)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___options_u3652)(NimStringV2 x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u1391)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuReplaceChar)(NimStringV2 s_p0, NIM_CHAR sub_p1, NIM_CHAR by_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, pathRelativeToConfig__commands_u1349)(NimStringV2 arg_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toAbsoluteDir__pathutils_u117)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitchG__commands_u260)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A op_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw, parseEnum__commands_u1465)(NimStringV2 s_p0, tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw default_p1);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_u4)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1, NimStringV2 value_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1837)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p1);
N_LIB_PRIVATE N_NIMCALL(void, splitSwitch__commands_u196)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2* cmd_p2, NimStringV2* arg_p3, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p4, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p5);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, invalidCmdLineOption__commands_u191)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1, NimStringV2 switch_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, specialDefine__commands_u1217)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_u8)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(void, processCompile__commands_u503)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findFile__options_u4081)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL suppressStdlib_p2);
static N_INLINE(NIM_BOOL, isEmpty__options_u4086)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToCompile__extccomp_u1350)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(void, addExternalFileToLink__extccomp_u977)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
static N_INLINE(void, warningDeprecated__msgs_u1572)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2);
N_LIB_PRIVATE N_NIMCALL(void, processMemoryManagementOption__commands_u1323)(NimStringV2 switch_p0, NimStringV2 arg_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p4);
N_LIB_PRIVATE N_NIMCALL(void, unregisterArcOrc__commands_u1313)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, registerArcOrc__commands_u1290)(tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processOnOffSwitchOrList__commands_u243)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ op_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(void, listWarnings__msgs_u1646)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__commands_u290)(NimStringV2 arg_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw state_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, NimStringV2 orig_p4, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p5);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA, findStr__commands_u346)(NimStringV2 s_p2, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA default_p3);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA, findStr__commands_u377)(NimStringV2 s_p2, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA default_p3);
static N_INLINE(NIM_BOOL, contains__stdZenumutils_u51)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1);
static N_INLINE(NI, find__stdZenumutils_u56)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1);
static N_INLINE(void, X5BX5Deq___commands_u457)(NU8* t_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw key_p1, NIM_BOOL val_p2);
N_LIB_PRIVATE N_NIMCALL(void, listHints__msgs_u1668)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitch__commands_u225)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ op_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_u629)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVSCompatible__extccomp_u696)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, addCompileOptionCmd__extccomp_u915)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 option_p1);
N_LIB_PRIVATE N_NIMCALL(void, addLinkOptionCmd__extccomp_u912)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 option_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__commands_u1640)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findModule__options_u4101)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 modulename_p1, NimStringV2 currentModule_p2);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw, nameToOS__platform_u846)(NimStringV2 name_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuJoinSep)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 sep_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, listOSnames__platform_u870)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5504)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setTarget__platform_u750)(tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA* t_p0, tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw o_p1, tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw c_p2);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw, nameToCPU__platform_u894)(NimStringV2 name_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, listCPUnames__platform_u918)(void);
N_LIB_PRIVATE N_NIMCALL(NI, parseSaturatedNatural__pureZparseutils_u986)(NimStringV2 s_p0, NI* b_p1, NI start_p2);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringV2 s_p0);
static N_INLINE(NIM_BOOL, contains__pureZtimes_u3356)(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA s_p0, NI value_p1);
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(void, writeVersionInfo__commands_u172)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_u737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1, tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw flags_p2);
N_LIB_PRIVATE N_NIMCALL(void, msgQuit__msgs_u479)(NI8 x_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeAdvancedUsage__commands_u158)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1);
N_LIB_PRIVATE N_NIMCALL(void, writeFullhelp__commands_u165)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1);
N_LIB_PRIVATE N_NIMCALL(void, helpOnError__commands_u150)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getCommandLineDesc__commands_u147)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, setUseIc__ast_u834)(NIM_BOOL useIc_p0);
N_LIB_PRIVATE N_NIMCALL(void, putEnv__stdZenvvars_u24)(NimStringV2 key_p0, NimStringV2 val_p1);
N_LIB_PRIVATE N_NIMCALL(void, setCC__extccomp_u781)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 ccname_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(void, track__commands_u1150)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 arg_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, nsuSplitChar)(NimStringV2 s_p0, NIM_CHAR sep_p1, NI maxsplit_p2);
N_LIB_PRIVATE N_NIMCALL(void, setTrackingInfo__commands_u1131)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 dirty_p1, NimStringV2 file_p2, NimStringV2 line_p3, NimStringV2 column_p4, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p5);
N_LIB_PRIVATE N_NIMCALL(NI, parseInt__pureZparseutils_u981)(NimStringV2 s_p0, NI* number_p1, NI start_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeAbsolute__commands_u1128)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, normalizePath__pureZpathnorm_u150)(NimStringV2 path_p0, NIM_CHAR dirSep_p1);
static N_INLINE(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, newLineInfo__msgs_u436)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NI line_p2, NI col_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, newLineInfo__msgs_u419)(NI32 fileInfoIdx_p0, NI line_p1, NI col_p2);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u404)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(void, setDirtyFile__msgs_u632)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, NimStringV2 filename_p2);
N_LIB_PRIVATE N_NIMCALL(void, trackDirty__commands_u1142)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 arg_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(void, trackIde__commands_u1158)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng cmd_p1, NimStringV2 arg_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, dynlibOverride__commands_u1167)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(void, inclDynlibOverride__options_u4263)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 lib_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ, parseEnum__commands_u900)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA, parseEnum__commands_u1849)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, showNonExportedFields__options_u4274)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, docRawOutput__options_u4280)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_u2159)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* c_p0, NimStringV2 define_p1);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__stdZassertions_u79)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1, NimStringV2 val_p2);
N_LIB_PRIVATE N_NIMCALL(void, handleStdinInput__commands_u1179)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimcacheDir__options_u3737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, setConfigVar__options_u3608)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, NimStringV2 val_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDynlibOverride__options_u4266)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 lib_p1);
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_2 = { 5 | NIM_STRLIT_FLAG, ".nims" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_3 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_2};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_4 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_5 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_6 = { 1 | NIM_STRLIT_FLAG, "c" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_7 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_6};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_8 = { 2 | NIM_STRLIT_FLAG, "cc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_9 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_8};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_10 = { 7 | NIM_STRLIT_FLAG, "compile" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_11 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_10};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_12 = { 10 | NIM_STRLIT_FLAG, "compiletoc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_13 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_12};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_14 = { 3 | NIM_STRLIT_FLAG, "cpp" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_15 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_14};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_16 = { 12 | NIM_STRLIT_FLAG, "compiletocpp" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_17 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_16};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_18 = { 4 | NIM_STRLIT_FLAG, "objc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_19 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_18};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_20 = { 11 | NIM_STRLIT_FLAG, "compiletooc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_21 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_20};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_22 = { 2 | NIM_STRLIT_FLAG, "js" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_23 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_22};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_24 = { 11 | NIM_STRLIT_FLAG, "compiletojs" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_25 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_24};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_26 = { 1 | NIM_STRLIT_FLAG, "r" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_27 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_26};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_28 = { 1 | NIM_STRLIT_FLAG, "m" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_29 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_28};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_30 = { 3 | NIM_STRLIT_FLAG, "run" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_31 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_30};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_32 = { 5 | NIM_STRLIT_FLAG, "check" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_33 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_32};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_34 = { 1 | NIM_STRLIT_FLAG, "e" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_35 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_36 = { 4 | NIM_STRLIT_FLAG, "doc0" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_37 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_36};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_38 = { 4 | NIM_STRLIT_FLAG, "doc2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_39 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_38};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_40 = { 3 | NIM_STRLIT_FLAG, "doc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_41 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_40};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_42 = { 7 | NIM_STRLIT_FLAG, "doc2tex" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_43 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_42};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_44 = { 8 | NIM_STRLIT_FLAG, "rst2html" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_45 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_44};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_46 = { 6 | NIM_STRLIT_FLAG, "md2tex" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_47 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_46};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_48 = { 7 | NIM_STRLIT_FLAG, "md2html" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_49 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_48};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_50 = { 7 | NIM_STRLIT_FLAG, "rst2tex" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_51 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_50};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_52 = { 8 | NIM_STRLIT_FLAG, "jsondoc0" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_53 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_52};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_54 = { 8 | NIM_STRLIT_FLAG, "jsondoc2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_55 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_54};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_56 = { 7 | NIM_STRLIT_FLAG, "jsondoc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_57 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_56};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_58 = { 5 | NIM_STRLIT_FLAG, "ctags" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_59 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_58};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_60 = { 10 | NIM_STRLIT_FLAG, "buildindex" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_61 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_60};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_62 = { 9 | NIM_STRLIT_FLAG, "gendepend" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_63 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_62};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_64 = { 4 | NIM_STRLIT_FLAG, "dump" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_65 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_64};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_66 = { 5 | NIM_STRLIT_FLAG, "parse" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_67 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_66};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_68 = { 3 | NIM_STRLIT_FLAG, "rod" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_69 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_68};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_70 = { 6 | NIM_STRLIT_FLAG, "secret" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_71 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_70};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_72 = { 3 | NIM_STRLIT_FLAG, "nop" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_73 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_72};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_74 = { 4 | NIM_STRLIT_FLAG, "help" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_75 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_74};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_76 = { 10 | NIM_STRLIT_FLAG, "jsonscript" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_77 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_76};
static NIM_CONST tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw TM__brsa2DgNdQAKzy1F0pSZlA_78 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x40, 0x00, 0x00, 0x00, 0x00}
;
static NIM_CONST tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw TM__brsa2DgNdQAKzy1F0pSZlA_79 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x02, 0xc0, 0x00, 0x02, 0x04}
;
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_80 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_2};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_81 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_82 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_83 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_84 = { 4 | NIM_STRLIT_FLAG, "eval" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_85 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_84};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_86 = { 4 | NIM_STRLIT_FLAG, "path" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_87 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_86};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_88 = { 1 | NIM_STRLIT_FLAG, "p" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_89 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_88};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_90 = { 10 | NIM_STRLIT_FLAG, "nimblepath" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_91 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_90};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_92 = { 12 | NIM_STRLIT_FLAG, "nonimblepath" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_93 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_92};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_94 = { 15 | NIM_STRLIT_FLAG, "clearnimblepath" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_95 = {15, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_94};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_96 = { 11 | NIM_STRLIT_FLAG, "excludepath" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_97 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_96};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_98 = { 8 | NIM_STRLIT_FLAG, "nimcache" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_99 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_98};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_100 = { 3 | NIM_STRLIT_FLAG, "out" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_101 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_100};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_102 = { 1 | NIM_STRLIT_FLAG, "o" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_103 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_102};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_104 = { 6 | NIM_STRLIT_FLAG, "outdir" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_105 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_104};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_106 = { 11 | NIM_STRLIT_FLAG, "usenimcache" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_107 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_106};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_108 = { 12 | NIM_STRLIT_FLAG, "docseesrcurl" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_109 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_108};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_110 = { 7 | NIM_STRLIT_FLAG, "docroot" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_111 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_110};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_112 = { 7 | NIM_STRLIT_FLAG, "backend" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_113 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_112};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_114 = { 1 | NIM_STRLIT_FLAG, "b" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_115 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_114};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_116 = { 6 | NIM_STRLIT_FLAG, "doccmd" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_117 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_116};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_118 = { 6 | NIM_STRLIT_FLAG, "define" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_119 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_118};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_120 = { 1 | NIM_STRLIT_FLAG, "d" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_121 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_120};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_122 = { 5 | NIM_STRLIT_FLAG, "undef" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_123 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_122};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_124 = { 1 | NIM_STRLIT_FLAG, "u" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_125 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_124};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_126 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_10};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_127 = { 4 | NIM_STRLIT_FLAG, "link" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_128 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_127};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_129 = { 9 | NIM_STRLIT_FLAG, "debuginfo" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_130 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_129};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_131 = { 8 | NIM_STRLIT_FLAG, "embedsrc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_132 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_131};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_133 = { 11 | NIM_STRLIT_FLAG, "compileonly" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_134 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_133};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_135 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_6};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_136 = { 9 | NIM_STRLIT_FLAG, "nolinking" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_137 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_136};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_138 = { 6 | NIM_STRLIT_FLAG, "nomain" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_139 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_138};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_140 = { 10 | NIM_STRLIT_FLAG, "forcebuild" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_141 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_140};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_142 = { 1 | NIM_STRLIT_FLAG, "f" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_143 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_142};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_144 = { 7 | NIM_STRLIT_FLAG, "project" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_145 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_144};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_146 = { 2 | NIM_STRLIT_FLAG, "gc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_147 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_146};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_148 = { 2 | NIM_STRLIT_FLAG, "mm" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_149 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_148};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_150 = { 8 | NIM_STRLIT_FLAG, "warnings" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_151 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_150};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_152 = { 1 | NIM_STRLIT_FLAG, "w" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_153 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_152};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_154 = { 7 | NIM_STRLIT_FLAG, "warning" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_155 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_154};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_156 = { 4 | NIM_STRLIT_FLAG, "hint" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_157 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_156};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_158 = { 14 | NIM_STRLIT_FLAG, "warningaserror" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_159 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_158};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_160 = { 11 | NIM_STRLIT_FLAG, "hintaserror" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_161 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_160};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_162 = { 5 | NIM_STRLIT_FLAG, "hints" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_163 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_162};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_164 = { 14 | NIM_STRLIT_FLAG, "threadanalysis" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_165 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_164};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_166 = { 10 | NIM_STRLIT_FLAG, "stacktrace" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_167 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_166};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_168 = { 14 | NIM_STRLIT_FLAG, "stacktracemsgs" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_169 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_168};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_170 = { 19 | NIM_STRLIT_FLAG, "excessivestacktrace" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_171 = {19, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_170};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_172 = { 9 | NIM_STRLIT_FLAG, "linetrace" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_173 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_172};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_174 = { 8 | NIM_STRLIT_FLAG, "debugger" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_175 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_174};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_176 = { 6 | NIM_STRLIT_FLAG, "mangle" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_177 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_176};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_178 = { 1 | NIM_STRLIT_FLAG, "g" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_179 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_178};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_180 = { 8 | NIM_STRLIT_FLAG, "profiler" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_181 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_180};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_182 = { 10 | NIM_STRLIT_FLAG, "memtracker" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_183 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_182};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_184 = { 16 | NIM_STRLIT_FLAG, "hotcodereloading" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_185 = {16, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_184};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_186 = { 6 | NIM_STRLIT_FLAG, "checks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_187 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_186};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_188 = { 1 | NIM_STRLIT_FLAG, "x" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_189 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_188};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_190 = { 11 | NIM_STRLIT_FLAG, "floatchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_191 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_190};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_192 = { 9 | NIM_STRLIT_FLAG, "infchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_193 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_192};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_194 = { 9 | NIM_STRLIT_FLAG, "nanchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_195 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_194};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_196 = { 9 | NIM_STRLIT_FLAG, "objchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_197 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_196};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_198 = { 11 | NIM_STRLIT_FLAG, "fieldchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_199 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_198};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_200 = { 11 | NIM_STRLIT_FLAG, "rangechecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_201 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_200};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_202 = { 11 | NIM_STRLIT_FLAG, "boundchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_203 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_202};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_204 = { 9 | NIM_STRLIT_FLAG, "refchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_205 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_204};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_206 = { 14 | NIM_STRLIT_FLAG, "overflowchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_207 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_206};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_208 = { 17 | NIM_STRLIT_FLAG, "staticboundchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_209 = {17, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_208};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_210 = { 11 | NIM_STRLIT_FLAG, "stylechecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_211 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_210};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_212 = { 7 | NIM_STRLIT_FLAG, "linedir" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_213 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_212};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_214 = { 10 | NIM_STRLIT_FLAG, "assertions" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_215 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_214};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_216 = { 1 | NIM_STRLIT_FLAG, "a" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_217 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_216};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_218 = { 7 | NIM_STRLIT_FLAG, "threads" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_219 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_218};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_220 = { 12 | NIM_STRLIT_FLAG, "tlsemulation" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_221 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_220};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_222 = { 14 | NIM_STRLIT_FLAG, "implicitstatic" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_223 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_222};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_224 = { 8 | NIM_STRLIT_FLAG, "patterns" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_225 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_224};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_226 = { 8 | NIM_STRLIT_FLAG, "trmacros" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_227 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_226};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_228 = { 3 | NIM_STRLIT_FLAG, "opt" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_229 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_228};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_230 = { 3 | NIM_STRLIT_FLAG, "app" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_231 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_230};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_232 = { 5 | NIM_STRLIT_FLAG, "passc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_233 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_232};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_234 = { 1 | NIM_STRLIT_FLAG, "t" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_235 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_234};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_236 = { 5 | NIM_STRLIT_FLAG, "passl" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_237 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_236};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_238 = { 1 | NIM_STRLIT_FLAG, "l" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_239 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_238};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_240 = { 9 | NIM_STRLIT_FLAG, "cincludes" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_241 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_240};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_242 = { 7 | NIM_STRLIT_FLAG, "clibdir" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_243 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_242};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_244 = { 4 | NIM_STRLIT_FLAG, "clib" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_245 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_244};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_246 = { 6 | NIM_STRLIT_FLAG, "header" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_247 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_246};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_248 = { 14 | NIM_STRLIT_FLAG, "nimbasepattern" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_249 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_248};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_250 = { 5 | NIM_STRLIT_FLAG, "index" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_251 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_250};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_252 = { 11 | NIM_STRLIT_FLAG, "noimportdoc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_253 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_252};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_254 = { 6 | NIM_STRLIT_FLAG, "import" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_255 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_254};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_256 = { 7 | NIM_STRLIT_FLAG, "include" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_257 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_256};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_258 = { 7 | NIM_STRLIT_FLAG, "listcmd" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_259 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_258};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_260 = { 3 | NIM_STRLIT_FLAG, "asm" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_261 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_260};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_262 = { 10 | NIM_STRLIT_FLAG, "genmapping" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_263 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_262};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_264 = { 2 | NIM_STRLIT_FLAG, "os" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_265 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_264};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_266 = { 3 | NIM_STRLIT_FLAG, "cpu" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_267 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_266};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_268 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_30};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_269 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_26};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_270 = { 19 | NIM_STRLIT_FLAG, "maxloopiterationsvm" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_271 = {19, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_270};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_272 = { 14 | NIM_STRLIT_FLAG, "maxcalldepthvm" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_273 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_272};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_274 = { 8 | NIM_STRLIT_FLAG, "errormax" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_275 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_274};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_276 = { 9 | NIM_STRLIT_FLAG, "stdinfile" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_277 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_276};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_278 = { 9 | NIM_STRLIT_FLAG, "verbosity" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_279 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_278};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_280 = { 13 | NIM_STRLIT_FLAG, "parallelbuild" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_281 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_280};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_282 = { 7 | NIM_STRLIT_FLAG, "version" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_283 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_282};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_284 = { 1 | NIM_STRLIT_FLAG, "v" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_285 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_284};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_286 = { 8 | NIM_STRLIT_FLAG, "advanced" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_287 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_286};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_288 = { 8 | NIM_STRLIT_FLAG, "fullhelp" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_289 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_288};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_290 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_74};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_291 = { 1 | NIM_STRLIT_FLAG, "h" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_292 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_291};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_293 = { 11 | NIM_STRLIT_FLAG, "symbolfiles" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_294 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_293};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_295 = { 11 | NIM_STRLIT_FLAG, "incremental" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_296 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_295};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_297 = { 2 | NIM_STRLIT_FLAG, "ic" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_298 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_297};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_299 = { 7 | NIM_STRLIT_FLAG, "skipcfg" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_300 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_299};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_301 = { 11 | NIM_STRLIT_FLAG, "skipprojcfg" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_302 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_301};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_303 = { 11 | NIM_STRLIT_FLAG, "skipusercfg" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_304 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_303};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_305 = { 13 | NIM_STRLIT_FLAG, "skipparentcfg" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_306 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_305};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_307 = { 9 | NIM_STRLIT_FLAG, "genscript" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_308 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_307};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_309 = { 7 | NIM_STRLIT_FLAG, "gendeps" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_310 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_309};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_311 = { 8 | NIM_STRLIT_FLAG, "gencdeps" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_312 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_311};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_313 = { 6 | NIM_STRLIT_FLAG, "colors" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_314 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_313};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_315 = { 3 | NIM_STRLIT_FLAG, "lib" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_316 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_315};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_317 = { 6 | NIM_STRLIT_FLAG, "putenv" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_318 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_317};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_319 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_8};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_320 = { 5 | NIM_STRLIT_FLAG, "track" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_321 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_320};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_322 = { 10 | NIM_STRLIT_FLAG, "trackdirty" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_323 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_322};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_324 = { 7 | NIM_STRLIT_FLAG, "suggest" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_325 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_324};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_326 = { 3 | NIM_STRLIT_FLAG, "def" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_327 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_326};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_328 = { 7 | NIM_STRLIT_FLAG, "context" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_329 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_328};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_330 = { 6 | NIM_STRLIT_FLAG, "usages" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_331 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_330};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_332 = { 9 | NIM_STRLIT_FLAG, "defusages" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_333 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_332};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_334 = { 6 | NIM_STRLIT_FLAG, "stdout" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_335 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_334};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_336 = { 9 | NIM_STRLIT_FLAG, "filenames" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_337 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_336};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_338 = { 10 | NIM_STRLIT_FLAG, "processing" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_339 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_338};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_340 = { 7 | NIM_STRLIT_FLAG, "unitsep" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_341 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_340};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_342 = { 13 | NIM_STRLIT_FLAG, "listfullpaths" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_343 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_342};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_344 = { 12 | NIM_STRLIT_FLAG, "spellsuggest" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_345 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_344};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_346 = { 12 | NIM_STRLIT_FLAG, "declaredlocs" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_347 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_346};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_348 = { 14 | NIM_STRLIT_FLAG, "dynliboverride" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_349 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_348};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_350 = { 17 | NIM_STRLIT_FLAG, "dynliboverrideall" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_351 = {17, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_350};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_352 = { 12 | NIM_STRLIT_FLAG, "experimental" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_353 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_352};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_354 = { 6 | NIM_STRLIT_FLAG, "legacy" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_355 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_354};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_356 = { 15 | NIM_STRLIT_FLAG, "nocppexceptions" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_357 = {15, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_356};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_358 = { 14 | NIM_STRLIT_FLAG, "shownonexports" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_359 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_358};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_360 = { 3 | NIM_STRLIT_FLAG, "raw" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_361 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_360};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_362 = { 10 | NIM_STRLIT_FLAG, "exceptions" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_363 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_362};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_364 = { 9 | NIM_STRLIT_FLAG, "cppdefine" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_365 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_364};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_366 = { 10 | NIM_STRLIT_FLAG, "newruntime" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_367 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_366};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_368 = { 6 | NIM_STRLIT_FLAG, "seqsv2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_369 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_368};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_370 = { 10 | NIM_STRLIT_FLAG, "stylecheck" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_371 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_370};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_372 = { 17 | NIM_STRLIT_FLAG, "showallmismatches" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_373 = {17, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_372};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_374 = { 21 | NIM_STRLIT_FLAG, "cppcompiletonamespace" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_375 = {21, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_374};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_376 = { 11 | NIM_STRLIT_FLAG, "docinternal" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_377 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_376};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_378 = { 12 | NIM_STRLIT_FLAG, "multimethods" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_379 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_378};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_380 = { 11 | NIM_STRLIT_FLAG, "expandmacro" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_381 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_380};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_382 = { 9 | NIM_STRLIT_FLAG, "expandarc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_383 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_382};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_384 = { 11 | NIM_STRLIT_FLAG, "benchmarkvm" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_385 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_384};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_386 = { 9 | NIM_STRLIT_FLAG, "profilevm" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_387 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_386};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_388 = { 13 | NIM_STRLIT_FLAG, "sinkinference" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_389 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_388};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_390 = { 15 | NIM_STRLIT_FLAG, "cursorinference" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_391 = {15, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_390};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_392 = { 6 | NIM_STRLIT_FLAG, "panics" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_393 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_392};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_394 = { 10 | NIM_STRLIT_FLAG, "jsbigint64" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_395 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_394};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_396 = { 9 | NIM_STRLIT_FLAG, "sourcemap" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_397 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_396};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_398 = { 8 | NIM_STRLIT_FLAG, "deepcopy" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_399 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_398};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_400 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_401 = { 7 | NIM_STRLIT_FLAG, "nilseqs" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_402 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_401};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_403 = { 9 | NIM_STRLIT_FLAG, "nilchecks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_404 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_403};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_405 = { 6 | NIM_STRLIT_FLAG, "symbol" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_406 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_405};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_407 = { 9 | NIM_STRLIT_FLAG, "taintmode" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_408 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_407};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_409 = { 2 | NIM_STRLIT_FLAG, "cs" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_410 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_409};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_411 = { 12 | NIM_STRLIT_FLAG, "deadcodeelim" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_412 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_411};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_413 = { 13 | NIM_STRLIT_FLAG, "nimmainprefix" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_414 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_413};
static const struct {
  NI cap; NIM_CHAR data[47+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_415 = { 47 | NIM_STRLIT_FLAG, "argument for command line option expected: \'$1\'" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_416 = {47, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_415};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_417 = { 1 | NIM_STRLIT_FLAG, "-" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_418 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_417};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_419 = { 2 | NIM_STRLIT_FLAG, "--" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_420 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_419};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_422 = { 63 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/commands.nim" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_423 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_34};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_424 = { 11 | NIM_STRLIT_FLAG, "$nimblepath" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_425 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_424};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_426 = { 10 | NIM_STRLIT_FLAG, "$nimbledir" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_427 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_426};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_428 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_90};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_429 = { 9 | NIM_STRLIT_FLAG, "nimbledir" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_430 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_429};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_431 = { 1 | NIM_STRLIT_FLAG, "\"" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_432 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_431};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_433 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_431};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_434 = { 14 | NIM_STRLIT_FLAG, "invalid path: " };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_435 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_434};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_437 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_434};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_439 = { 10 | NIM_STRLIT_FLAG, "NIMBLE_DIR" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_440 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_439};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_441 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_442 = { 5 | NIM_STRLIT_FLAG, "pkgs2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_443 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_442};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_444 = { 4 | NIM_STRLIT_FLAG, "pkgs" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_445 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_444};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_446 = { 46 | NIM_STRLIT_FLAG, "invalid argument for command line option: \'$1\'" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_447 = {46, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_446};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_449 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_450 = { 2 | NIM_STRLIT_FLAG, "on" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_451 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_452 = { 3 | NIM_STRLIT_FLAG, "off" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_453 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_454 = { 38 | NIM_STRLIT_FLAG, "\'on\' or \'off\' expected, but \'$1\' found" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_455 = {38, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_454};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_457 = { 8 | NIM_STRLIT_FLAG, "@default" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_458 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_457};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_459 = { 21 | NIM_STRLIT_FLAG, "invalid backend: \'$1\'" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_460 = {21, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_459};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_462 = { 6 | NIM_STRLIT_FLAG, "nodejs" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_463 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_462};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_464 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_465 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__brsa2DgNdQAKzy1F0pSZlA_466 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x24,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_467 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_468 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_469 = { 1 | NIM_STRLIT_FLAG, " " };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_470 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_469};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_471 = { 33 | NIM_STRLIT_FLAG, "invalid command line option: \'$1\'" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_472 = {33, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_471};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_473 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_417};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_475 = {33, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_471};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_477 = { 9 | NIM_STRLIT_FLAG, "nimQuirky" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_478 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_477};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_479 = { 7 | NIM_STRLIT_FLAG, "release" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_480 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_479};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_481 = { 6 | NIM_STRLIT_FLAG, "danger" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_482 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_481};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_483 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_481};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_484 = { 5 | NIM_STRLIT_FLAG, "quick" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_485 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_484};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_486 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[59+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_488 = { 59 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/msgs.nim" };
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_489 = { 50 | NIM_STRLIT_FLAG, "`gc:option` is deprecated; use `mm:option` instead" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_490 = {50, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_489};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_491 = { 5 | NIM_STRLIT_FLAG, "boehm" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_492 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_491};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_493 = { 4 | NIM_STRLIT_FLAG, "refc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_494 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_493};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_495 = { 12 | NIM_STRLIT_FLAG, "markandsweep" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_496 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_495};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_497 = { 11 | NIM_STRLIT_FLAG, "destructors" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_498 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_497};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_499 = { 3 | NIM_STRLIT_FLAG, "arc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_500 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_499};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_501 = { 3 | NIM_STRLIT_FLAG, "orc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_502 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_501};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_503 = { 9 | NIM_STRLIT_FLAG, "atomicarc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_504 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_503};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_505 = { 5 | NIM_STRLIT_FLAG, "hooks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_506 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_505};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_507 = { 2 | NIM_STRLIT_FLAG, "go" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_508 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_507};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_509 = { 4 | NIM_STRLIT_FLAG, "none" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_510 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_509};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_511 = { 5 | NIM_STRLIT_FLAG, "stack" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_512 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_511};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_513 = { 7 | NIM_STRLIT_FLAG, "regions" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_514 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_513};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_515 = { 13 | NIM_STRLIT_FLAG, "gcdestructors" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_516 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_515};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_517 = { 5 | NIM_STRLIT_FLAG, "gcarc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_518 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_517};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_519 = { 5 | NIM_STRLIT_FLAG, "gcorc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_520 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_519};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_521 = { 11 | NIM_STRLIT_FLAG, "gcatomicarc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_522 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_521};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_523 = { 9 | NIM_STRLIT_FLAG, "nimSeqsV2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_524 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_523};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_525 = { 5 | NIM_STRLIT_FLAG, "nimV2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_526 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_525};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_527 = { 7 | NIM_STRLIT_FLAG, "boehmgc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_528 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_527};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_529 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_530 = { 6 | NIM_STRLIT_FLAG, "gcrefc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_531 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_530};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_532 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_533 = { 14 | NIM_STRLIT_FLAG, "gcmarkandsweep" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_534 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_533};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_535 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_536 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_517};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_537 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_538 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_515};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_539 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_540 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_523};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_541 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_542 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_525};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_543 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_544 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_519};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_545 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_546 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_521};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_547 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_548 = { 7 | NIM_STRLIT_FLAG, "gchooks" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_549 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_548};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_550 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_551 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_523};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_552 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_553 = { 4 | NIM_STRLIT_FLAG, "gogc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_554 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_553};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_555 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_556 = { 4 | NIM_STRLIT_FLAG, "nogc" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_557 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_556};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_558 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_559 = { 9 | NIM_STRLIT_FLAG, "gcregions" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_560 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_559};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_561 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[111+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_562 = { 111 | NIM_STRLIT_FLAG, "\'arc\', \'orc\', \'atomicArc\', \'markAndSweep\', \'boehm\', \'go\', \'none\', \'regions\', or \'refc\' expected, but \'$1\' found" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_563 = {111, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_562};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_565 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_566 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_567 = { 4 | NIM_STRLIT_FLAG, "list" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_568 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_567};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_569 = { 46 | NIM_STRLIT_FLAG, "\'on\', \'off\' or \'list\' expected, but \'$1\' found" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_570 = {46, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_569};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_572 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_573 = { 3 | NIM_STRLIT_FLAG, "all" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_574 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_573};
static NIM_CONST tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA TM__brsa2DgNdQAKzy1F0pSZlA_575 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0xfe, 0xff, 0xff, 0xff, 0x0f}
;
static NIM_CONST tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA TM__brsa2DgNdQAKzy1F0pSZlA_576 = {
0x00, 0x00, 0xf0, 0xff, 0xff, 0xff, 0xff, 0xff,
0xff, 0xff, 0xff, 0x01, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_577 = { 14 | NIM_STRLIT_FLAG, "unknown $#: $#" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_578 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_577};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_579 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_156};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_581 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_577};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_582 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_156};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_584 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_577};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_585 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_154};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_586 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_577};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_587 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_154};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_588 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_590 = {38, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_454};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_592 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_593 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_573};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_594 = { 27 | NIM_STRLIT_FLAG, "only \'all:off\' is supported" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_595 = {27, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_594};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_597 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_598 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_599 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_600 = {38, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_454};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_602 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_603 = { 6 | NIM_STRLIT_FLAG, "native" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_604 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_603};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_605 = { 3 | NIM_STRLIT_FLAG, "gdb" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_606 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_605};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_607 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_608 = { 37 | NIM_STRLIT_FLAG, "expected native|gdb|on|off but found " };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_609 = {37, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_608};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_611 = { 3 | NIM_STRLIT_FLAG, "nim" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_612 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_611};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_613 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_14};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_614 = { 27 | NIM_STRLIT_FLAG, "expected nim|cpp but found " };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_615 = {27, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_614};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_617 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_180};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_618 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_619 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_180};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_620 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_182};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_621 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_622 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_182};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_623 = {16, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_184};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_624 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_625 = { 9 | NIM_STRLIT_FLAG, "useNimRtl" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_626 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_625};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_627 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_628 = { 3 | NIM_STRLIT_FLAG, "/MD" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_629 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_628};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_630 = {16, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_184};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_631 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_625};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_632 = { 24 | NIM_STRLIT_FLAG, "refchecks is deprecated!" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_633 = {24, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_632};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_634 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_224};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_635 = { 35 | NIM_STRLIT_FLAG, "\'$#\' is a deprecated alias for \'$#\'" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_636 = {35, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_635};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_637 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_226};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_638 = { 5 | NIM_STRLIT_FLAG, "speed" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_639 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_638};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_640 = { 4 | NIM_STRLIT_FLAG, "size" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_641 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_640};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_642 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_509};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_643 = { 50 | NIM_STRLIT_FLAG, "\'none\', \'speed\' or \'size\' expected, but \'$1\' found" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_644 = {50, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_643};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_646 = { 3 | NIM_STRLIT_FLAG, "gui" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_647 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_646};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_648 = { 7 | NIM_STRLIT_FLAG, "console" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_649 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_648};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_650 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_315};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_651 = { 9 | NIM_STRLIT_FLAG, "staticlib" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_652 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_651};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_653 = { 10 | NIM_STRLIT_FLAG, "executable" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_654 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_653};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_655 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_656 = { 6 | NIM_STRLIT_FLAG, "guiapp" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_657 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_656};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_658 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_659 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_653};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_660 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_661 = { 10 | NIM_STRLIT_FLAG, "consoleapp" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_662 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_661};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_663 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_664 = { 7 | NIM_STRLIT_FLAG, "library" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_665 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_664};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_666 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_667 = { 3 | NIM_STRLIT_FLAG, "dll" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_668 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_667};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_669 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_670 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_664};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_671 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_672 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_651};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_673 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_674 = { 63 | NIM_STRLIT_FLAG, "\'gui\', \'console\', \'lib\' or \'staticlib\' expected, but \'$1\' found" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_675 = {63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_674};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_677 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_678 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_679 = { 4 | NIM_STRLIT_FLAG, "only" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_680 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_679};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_681 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_682 = {38, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_454};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_684 = { 25 | NIM_STRLIT_FLAG, "Cannot resolve filename: " };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_685 = {25, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_684};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_687 = {25, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_684};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_689 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_690 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_689};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_691 = { 43 | NIM_STRLIT_FLAG, "unknown OS: \'$1\'. Available options are: $2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_692 = {43, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_691};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_694 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_689};
static const struct {
  NI cap; NIM_CHAR data[44+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_695 = { 44 | NIM_STRLIT_FLAG, "unknown CPU: \'$1\'. Available options are: $2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_696 = {44, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_695};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_698 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_462};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_699 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[64+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_700 = { 64 | NIM_STRLIT_FLAG, "maxLoopIterationsVM must be a positive integer greater than zero" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_701 = {64, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_700};
static const struct {
  NI cap; NIM_CHAR data[59+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_703 = { 59 | NIM_STRLIT_FLAG, "maxCallDepthVM must be a positive integer greater than zero" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_704 = {59, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_703};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_706 = { 29 | NIM_STRLIT_FLAG, "invalid verbosity level: \'$1\'" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_707 = {29, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_706};
static const struct {
  NI cap; NIM_CHAR data[89+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_709 = { 89 | NIM_STRLIT_FLAG, "Nim Compiler Version $1 [$2: $3]\012Compiled at $4\012Copyright (c) 2006-2026 by Andreas Rumpf\012" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_710 = {89, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_709};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_711 = { 6 | NIM_STRLIT_FLAG, "2.2.10" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_712 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_711};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_713 = { 10 | NIM_STRLIT_FLAG, "2026-04-24" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_714 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_713};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_715 = { 50 | NIM_STRLIT_FLAG, "git hash: bfeb3146d1638b39f69007a4ae5a23e23ae4e5ef" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_716 = {50, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_715};
static const struct {
  NI cap; NIM_CHAR data[42+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_717 = { 42 | NIM_STRLIT_FLAG, "active boot switches: -d:release -d:danger" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_718 = {42, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_717};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_719 = {89, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_709};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_720 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_711};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_721 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_713};
static const struct {
  NI cap; NIM_CHAR data[12146+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_722 = { 12146 | NIM_STRLIT_FLAG, "Advanced commands:\012    compileToC, cc          compile project with C code generator\012    compileToCpp, cpp       compile project to C++ code\012    compileToOC, objc       compile project to Objective C code\012    js                      compile project to Javascript\012    e                       run a Nimscript file\012    md2html                 convert a Markdown file to HTML\012                            use `--docCmd:skip` to skip compiling snippets\012    rst2html                convert a reStructuredText file to HTML\012                            use `--docCmd:skip` to skip compiling snippets\012    md2tex                  convert a Markdown file to LaTeX\012    rst2tex                 convert a reStructuredText file to LaTeX\012    doc2tex                 extract the documentation to a LaTeX file\012    jsondoc                 extract the documentation to a json file\012    ctags                   create a tags file\012    buildIndex              build an index for the whole documentation\012    genDepend               generate a DOT file containing the\012                            module dependency graph\012    dump                    dump all defined conditionals and search paths\012                            see also: --dump.format:json (useful with: `| jq`)\012    check                   checks the project for syntax and semantics\012                            (can be combined with --defusages)\012\012Runtime checks (see -x):\012  --objChecks:on|off        turn obj conversion checks on|off\012  --fieldChecks:on|off      turn case variant field checks on|off\012  --rangeChecks:on|off      turn range checks on|off\012  --boundChecks:on|off      turn bound checks on|off\012  --overflowChecks:on|off   turn int over-/underflow checks on|off\012  --floatChecks:on|off      turn all floating point (NaN/Inf) checks on|off\012  --nanChecks:on|off        turn NaN checks on|off\012  --infChecks:on|off        turn Inf checks on|off\012\012Advanced options:\012  --defusages:FILE,LINE,COL\012                            find the definition and all usages of a symbol\012  -o:FILE, --out:FILE       set the output filename\012  --outdir:DIR              set the path where the output file will be written\012  --usenimcache             will use `outdir=$nimcache`, whichever it resolves\012                            to after all options have been processed\012  --stdout:on|off           output to stdout\012  --colors:on|off           turn compiler messages coloring on|off\012  --filenames:abs|canonical|legacyRelProj\012                            customize how filenames are rendered in compiler messages,\012                            defaults to `abs` (absolute)\012  --processing:dots|filenames|off\012                            show files as they\'re being processed by nim compiler\012  --unitsep:on|off          use the ASCII unit separator (31) between error\012                            messages, useful for IDE-like tooling\012  --declaredLocs:on|off     show declaration locations in messages\012  --spellSuggest:num        show at most `num >= 0` spelling suggestions on typos.\012                            if `num` is not specified (or `auto`), return\012                            an implementation defined set of suggestions.\012  --hints:on|off|list       `on|off` enables or disables hints.\012                            `list` reports which hints are selected.\012  --hint:X:on|off           turn specific hint X on|off. `hint:X` means `hint:X:on`,\012                            as with similar flags. `all` is the set of all hints\012                            (only `all:off` is supported).\012  --hintAsError:X:on|off    turn specific hint X into an error on|off\012  -w:on|off|list, --warnings:on|off|list\012                            `on|off` enables or disables warnings.\012                            `list` reports which warnings are selected.\012  --warning:X:on|off        turn specific warning X on|off. `warning:X` means `warning:X:on`,\012                            as with similar flags. `all` is the set of all warning\012                            (only `all:off` is supported).\012  --warningAsError:X:on|off\012                            turn specific warning X into an error on|off\012  --styleCheck:off|hint|error\012                            produce hints or errors for Nim identifiers that\012                            do not adhere to Nim\'s official style guide\012                            https://nim-lang.org/docs/nep1.html\012  --styleCheck:usages       only enforce consistent spellings of identifiers,\012                            do not enforce the style on declarations\012  --showAllMismatches:on|off\012                            show all mismatching candidates in overloading\012                            resolution\012  --lib:PATH                set the system library path\012  --import:PATH             add an automatically imported module\012                            see also `patchFile` in nimscript which offers more flexibility.\012  --include:PATH            add an automatically included module\012  --nimcache:PATH           set the path used for generated files\012                            see also https://nim-lang.org/docs/nimc.html#compiler-usage-generated-c-code-directory\012  -c, --compileOnly:on|off  compile Nim files only; do not assemble or link\012  --noLinking:on|off        compile Nim and generated files but do not link\012  --noMain:on|off           do not generate a main procedure\012  --genScript:on|off        generate a compile script (in the \'nimcache\'\012                            subdirectory named \'compile_$project$scriptext\'),\012                            and a \'.deps\' file containing the dependencies;\012                            implies --compileOnly\012  --os:SYMBOL               set the target operating system (cross-compilation)\012  --cpu:SYMBOL              set the target processor (cross-compilation)\012  --debuginfo:on|off        enables debug information\012  --mangle:nim|cpp          selects `nim` or `cpp` style name mangling, defaults to `cpp`\012  -t, --passC:OPTION        pass an option to the C compiler\012  -l, --passL:OPTION        pass an option to the linker\012  --cc:SYMBOL               specify the C compiler\012  --cincludes:DIR           modify the C compiler header search path\012  --clibdir:DIR             modify the linker library search path\012  --clib:LIBNAME            link an additional C library\012                            (you should omit platform-specific extensions)\012  --project                 document the whole project (doc)\012  --docRoot:path            `nim doc --docRoot:/foo --project --outdir:docs /foo/sub/main.nim`\012                            generates: docs/sub/main.html\012                            if path == @pkg, will use nimble file enclosing dir\012                            if path == @path, will use first matching dir in `--path`\012                            if path == @default (the default and most useful), will use\012                            best match among @pkg,@path.\012                            if these are nonexistent, will use project path\012  -b, --backend:c|cpp|js|objc\012                            sets backend to use with commands like `nim doc` or `nim r`\012  --docCmd:cmd              if `cmd == skip`, skips runnableExamples\012                            else, runs runnableExamples with given options, e.g.:\012                            `--docCmd:\"-d:foo --threads:on\"`\012  --docSeeSrcUrl:url        activate \'see source\' for doc command\012                            (see doc.item.seesrc in config/nimdoc.cfg)\012  --docInternal             also generate documentation for non-exported symbols\012  --raw                     turn off markup rendering for JSON docs\012  --lineDir:on|off          generation of #line directive on|off\012  --embedsrc:on|off         embeds the original source code as comments\012                            in the generated output\012  --tlsEmulation:on|off     turn thread local storage emulation on|off\012  --implicitStatic:on|off   turn implicit compile time evaluation on|off\012  --trmacros:on|off         turn term rewriting macros on|off\012  --multimethods:on|off     turn multi-methods on|off\012  --hotCodeReloading:on|off\012                            turn support for hot code reloading on|off\012  --excessiveStackTrace:on|off\012                            stack traces use full file paths\012  --stackTraceMsgs:on|off   enable user defined stack frame msgs via `setFrameMsg`\012  --skipCfg:on|off          do not read the nim installation\'s configuration file\012  --skipUserCfg:on|off      do not read the user\'s configuration file\012  --skipParentCfg:on|off    do not read the parent dirs\' configuration files\012  --skipProjCfg:on|off      do not read the project\'s configuration file\012  --mm:orc|arc|refc|markAndSweep|boehm|go|none|regions\012                            select which memory management to use; default is \'orc\'\012  --exceptions:setjmp|cpp|goto|quirky\012                            select the exception handling implementation\012  --index:on|off|only       docgen: turn index file generation on|off (`only` means\012                            not generate output files like HTML)\012  --noImportdoc:on|off      turn loading documentation ``.idx`` files on|off\012  --putenv:key=value        set an environment variable\012  --NimblePath:PATH         add a path for Nimble support\012  --noNimblePath            deactivate the Nimble path\012  --clearNimblePath         empty the list of Nimble package search paths\012  --cppCompileToNamespace:namespace\012                            use the provided namespace for the generated C++ code,\012                            if no namespace is provided \"Nim\" will be used\012  --nimMainPrefix:prefix    use `{prefix}NimMain` instead of `NimMain` in the produced\012                            C/C++ code\012  --expandMacro:MACRO       dump every generated AST from MACRO\012  --expandArc:PROCNAME      show how PROCNAME looks like after diverse optimizations\012                            before the final backend phase (mostly ARC/ORC specific)\012  --excludePath:PATH        exclude a path from the list of search paths\012  --dynlibOverride:SYMBOL   marks SYMBOL so that dynlib:SYMBOL\012                            has no effect and can be statically linked instead;\012                            symbol matching is fuzzy so\012                            that --dynlibOverride:lua matches\012                            dynlib: \"liblua.so.3\"\012  --dynlibOverrideAll\012                            disables the effects of the dynlib pragma\012  --listCmd                 list the compilation commands; can be combined with\012                            `--hint:exec:on` and `--hint:link:on`\012  --asm                     produce assembler code\012  --parallelBuild:0|1|...   perform a parallel build\012                            value = number of processors (0 for auto-detect)\012  --incremental:on|off      only recompile the changed modules (experimental!)\012  --verbosity:0|1|2|3       set Nim\'s verbosity level (1 is default)\012  --errorMax:N              stop compilation after N errors; 0 means unlimited\012  --maxLoopIterationsVM:N   set max iterations for all VM loops\012  --maxCallDepthVM:N        set max call depth in the VM\012  --experimental:dotOperators|callOperator|parallel|destructor|notnil|dynamicBindSym|forLoopMacros|caseStmtMacros|codeReordering|compiletimeFFI|vmopsDanger|strictFuncs|views|strictNotNil|overloadableEnums|strictEffects|unicodeOperators|flexibleOptionalParams|strictDefs|strictCaseObjects|inferGenericTypes|openSym|genericsOpenSym|vtables|typeBoundOps\012                            enable experimental language feature\012  --legacy:allowSemcheckedAstModification|checkUnsignedConversions|laxEffects|verboseTypeMismatch|emitGenerics|jsNoLambdaLifting|noPanicOnExcept\012                            enable obsolete/legacy language feature\012  --benchmarkVM:on|off      turn benchmarking of VM code with cpuTime() on|off\012  --profileVM:on|off        turn compile time VM profiler on|off\012  --panics:on|off           turn panics into process terminations (default: off)\012  --deepcopy:on|off         enable \'system.deepCopy\' for ``--mm:arc|orc``\012  --jsbigint64:on|off       toggle the use of BigInt for 64-bit integers for\012                            the JavaScript backend (default: on)\012  --nimBasePattern:nimbase.h\012                            allows to specify a custom pattern for `nimbase.h`\012" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_723 = {12146, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_722};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_724 = {89, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_709};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_725 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_711};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_726 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_713};
static const struct {
  NI cap; NIM_CHAR data[14225+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_727 = { 14225 | NIM_STRLIT_FLAG, "\012    nim command [options] [projectfile] [arguments]\012\012Command:\012    compile, c              compile project with default code generator (C)\012    r                       compile to $nimcache/projname, run with `arguments`\012                            using backend specified by `--backend` (default: c)\012    doc                     generate the documentation for inputfile for\012                            backend specified by `--backend` (default: c)\012\012Arguments:\012  arguments are passed to the program being run (if --run option is selected)\012\012Options:\012  -p, --path:PATH           add path to search paths\012  -d, --define:SYMBOL(:VAL)\012                            define a conditional symbol\012                            (Optionally: Define the value for that symbol,\012                            see: \"compile time define pragmas\")\012  -u, --undef:SYMBOL        undefine a conditional symbol\012  -f, --forceBuild:on|off   force rebuilding of all modules\012  --stackTrace:on|off       turn stack tracing on|off\012  --lineTrace:on|off        turn line tracing on|off\012  --threads:on|off          turn support for multi-threading on|off\012  -x, --checks:on|off       turn all runtime checks on|off\012  -a, --assertions:on|off   turn assertions on|off\012  --opt:none|speed|size     optimize not at all or for speed|size\012                            Note: use -d:release for a release build!\012  --debugger:native         use native debugger (gdb)\012  --app:console|gui|lib|staticlib\012                            generate a console app|GUI app|DLL|static library\012  -r, --run                 run the compiled program with given arguments\012  --eval:cmd                evaluate nim code directly; e.g.: `nim --eval:\"echo 1\"`\012                            defaults to `e` (nimscript) but customizable:\012                            `nim r --eval:\'for a in stdin.lines: echo a\'`\012  --fullhelp                show all command line switches\012  -h, --help                show this help\012  -v, --version             show detailed version information\012\012Note, single letter options that take an argument require a colon. E.g. -p:PATH.\012Advanced commands:\012    compileToC, cc          compile project with C code generator\012    compileToCpp, cpp       compile project to C++ code\012    compileToOC, objc       compile project to Objective C code\012    js                      compile project to Javascript\012    e                       run a Nimscript file\012    md2html                 convert a Markdown file to HTML\012                            use `--docCmd:skip` to skip compiling snippets\012    rst2html                convert a reStructuredText file to HTML\012                            use `--docCmd:skip` to skip compiling snippets\012    md2tex                  convert a Markdown file to LaTeX\012    rst2tex                 convert a reStructuredText file to LaTeX\012    doc2tex                 extract the documentation to a LaTeX file\012    jsondoc                 extract the documentation to a json file\012    ctags                   create a tags file\012    buildIndex              build an index for the whole documentation\012    genDepend               generate a DOT file containing the\012                            module dependency graph\012    dump                    dump all defined conditionals and search paths\012                            see also: --dump.format:json (useful with: `| jq`)\012    check                   checks the project for syntax and semantics\012                            (can be combined with --defusages)\012\012Runtime checks (see -x):\012  --objChecks:on|off        turn obj conversion checks on|off\012  --fieldChecks:on|off      turn case variant field checks on|off\012  --rangeChecks:on|off      turn range checks on|off\012  --boundChecks:on|off      turn bound checks on|off\012  --overflowChecks:on|off   turn int over-/underflow checks on|off\012  --floatChecks:on|off      turn all floating point (NaN/Inf) checks on|off\012  --nanChecks:on|off        turn NaN checks on|off\012  --infChecks:on|off        turn Inf checks on|off\012\012Advanced options:\012  --defusages:FILE,LINE,COL\012                            find the definition and all usages of a symbol\012  -o:FILE, --out:FILE       set the output filename\012  --outdir:DIR              set the path where the output file will be written\012  --usenimcache             will use `outdir=$nimcache`, whichever it resolves\012                            to after all options have been processed\012  --stdout:on|off           output to stdout\012  --colors:on|off           turn compiler messages coloring on|off\012  --filenames:abs|canonical|legacyRelProj\012                            customize how filenames are rendered in compiler messages,\012                            defaults to `abs` (absolute)\012  --processing:dots|filenames|off\012                            show files as they\'re being processed by nim compiler\012  --unitsep:on|off          use the ASCII unit separator (31) between error\012                            messages, useful for IDE-like tooling\012  --declaredLocs:on|off     show declaration locations in messages\012  --spellSuggest:num        show at most `num >= 0` spelling suggestions on typos.\012                            if `num` is not specified (or `auto`), return\012                            an implementation defined set of suggestions.\012  --hints:on|off|list       `on|off` enables or disables hints.\012                            `list` reports which hints are selected.\012  --hint:X:on|off           turn specific hint X on|off. `hint:X` means `hint:X:on`,\012                            as with similar flags. `all` is the set of all hints\012                            (only `all:off` is supported).\012  --hintAsError:X:on|off    turn specific hint X into an error on|off\012  -w:on|off|list, --warnings:on|off|list\012                            `on|off` enables or disables warnings.\012                            `list` reports which warnings are selected.\012  --warning:X:on|off        turn specific warning X on|off. `warning:X` means `warning:X:on`,\012                            as with similar flags. `all` is the set of all warning\012                            (only `all:off` is supported).\012  --warningAsError:X:on|off\012                            turn specific warning X into an error on|off\012  --styleCheck:off|hint|error\012                            produce hints or errors for Nim identifiers that\012                            do not adhere to Nim\'s official style guide\012                            https://nim-lang.org/docs/nep1.html\012  --styleCheck:usages       only enforce consistent spellings of identifiers,\012                            do not enforce the style on declarations\012  --showAllMismatches:on|off\012                            show all mismatching candidates in overloading\012                            resolution\012  --lib:PATH                set the system library path\012  --import:PATH             add an automatically imported module\012                            see also `patchFile` in nimscript which offers more flexibility.\012  --include:PATH            add an automatically included module\012  --nimcache:PATH           set the path used for generated files\012                            see also https://nim-lang.org/docs/nimc.html#compiler-usage-generated-c-code-directory\012  -c, --compileOnly:on|off  compile Nim files only; do not assemble or link\012  --noLinking:on|off        compile Nim and generated files but do not link\012  --noMain:on|off           do not generate a main procedure\012  --genScript:on|off        generate a compile script (in the \'nimcache\'\012                            subdirectory named \'compile_$project$scriptext\'),\012                            and a \'.deps\' file containing the dependencies;\012                            implies --compileOnly\012  --os:SYMBOL               set the target operating system (cross-compilation)\012  --cpu:SYMBOL              set the target processor (cross-compilation)\012  --debuginfo:on|off        enables debug information\012  --mangle:nim|cpp          selects `nim` or `cpp` style name mangling, defaults to `cpp`\012  -t, --passC:OPTION        pass an option to the C compiler\012  -l, --passL:OPTION        pass an option to the linker\012  --cc:SYMBOL               specify the C compiler\012  --cincludes:DIR           modify the C compiler header search path\012  --clibdir:DIR             modify the linker library search path\012  --clib:LIBNAME            link an additional C library\012                            (you should omit platform-specific extensions)\012  --project                 document the whole project (doc)\012  --docRoot:path            `nim doc --docRoot:/foo --project --outdir:docs /foo/sub/main.nim`\012                            generates: docs/sub/main.html\012                            if path == @pkg, will use nimble file enclosing dir\012                            if path == @path, will use first matching dir in `--path`\012                            if path == @default (the default and most useful), will use\012                            best match among @pkg,@path.\012                            if these are nonexistent, will use project path\012  -b, --backend:c|cpp|js|objc\012                            sets backend to use with commands like `nim doc` or `nim r`\012  --docCmd:cmd              if `cmd == skip`, skips runnableExamples\012                            else, runs runnableExamples with given options, e.g.:\012                            `--docCmd:\"-d:foo --threads:on\"`\012  --docSeeSrcUrl:url        activate \'see source\' for doc command\012                            (see doc.item.seesrc in config/nimdoc.cfg)\012  --docInternal             also generate documentation for non-exported symbols\012  --raw                     turn off markup rendering for JSON docs\012  --lineDir:on|off          generation of #line directive on|off\012  --embedsrc:on|off         embeds the original source code as comments\012                            in the generated output\012  --tlsEmulation:on|off     turn thread local storage emulation on|off\012  --implicitStatic:on|off   turn implicit compile time evaluation on|off\012  --trmacros:on|off         turn term rewriting macros on|off\012  --multimethods:on|off     turn multi-methods on|off\012  --hotCodeReloading:on|off\012                            turn support for hot code reloading on|off\012  --excessiveStackTrace:on|off\012                            stack traces use full file paths\012  --stackTraceMsgs:on|off   enable user defined stack frame msgs via `setFrameMsg`\012  --skipCfg:on|off          do not read the nim installation\'s configuration file\012  --skipUserCfg:on|off      do not read the user\'s configuration file\012  --skipParentCfg:on|off    do not read the parent dirs\' configuration files\012  --skipProjCfg:on|off      do not read the project\'s configuration file\012  --mm:orc|arc|refc|markAndSweep|boehm|go|none|regions\012                            select which memory management to use; default is \'orc\'\012  --exceptions:setjmp|cpp|goto|quirky\012                            select the exception handling implementation\012  --index:on|off|only       docgen: turn index file generation on|off (`only` means\012                            not generate output files like HTML)\012  --noImportdoc:on|off      turn loading documentation ``.idx`` files on|off\012  --putenv:key=value        set an environment variable\012  --NimblePath:PATH         add a path for Nimble support\012  --noNimblePath            deactivate the Nimble path\012  --clearNimblePath         empty the list of Nimble package search paths\012  --cppCompileToNamespace:namespace\012                            use the provided namespace for the generated C++ code,\012                            if no namespace is provided \"Nim\" will be used\012  --nimMainPrefix:prefix    use `{prefix}NimMain` instead of `NimMain` in the produced\012                            C/C++ code\012  --expandMacro:MACRO       dump every generated AST from MACRO\012  --expandArc:PROCNAME      show how PROCNAME looks like after diverse optimizations\012                            before the final backend phase (mostly ARC/ORC specific)\012  --excludePath:PATH        exclude a path from the list of search paths\012  --dynlibOverride:SYMBOL   marks SYMBOL so that dynlib:SYMBOL\012                            has no effect and can be statically linked instead;\012                            symbol matching is fuzzy so\012                            that --dynlibOverride:lua matches\012                            dynlib: \"liblua.so.3\"\012  --dynlibOverrideAll\012                            disables the effects of the dynlib pragma\012  --listCmd                 list the compilation commands; can be combined with\012                            `--hint:exec:on` and `--hint:link:on`\012  --asm                     produce assembler code\012  --parallelBuild:0|1|...   perform a parallel build\012                            value = number of processors (0 for auto-detect)\012  --incremental:on|off      only recompile the changed modules (experimental!)\012  --verbosity:0|1|2|3       set Nim\'s verbosity level (1 is default)\012  --errorMax:N              stop compilation after N errors; 0 means unlimited\012  --maxLoopIterationsVM:N   set max iterations for all VM loops\012  --maxCallDepthVM:N        set max call depth in the VM\012  --experimental:dotOperators|callOperator|parallel|destructor|notnil|dynamicBindSym|forLoopMacros|caseStmtMacros|codeReordering|compiletimeFFI|vmopsDanger|strictFuncs|views|strictNotNil|overloadableEnums|strictEffects|unicodeOperators|flexibleOptionalParams|strictDefs|strictCaseObjects|inferGenericTypes|openSym|genericsOpenSym|vtables|typeBoundOps\012                            enable experimental language feature\012  --legacy:allowSemcheckedAstModification|checkUnsignedConversions|laxEffects|verboseTypeMismatch|emitGenerics|jsNoLambdaLifting|noPanicOnExcept\012                            enable obsolete/legacy language feature\012  --benchmarkVM:on|off      turn benchmarking of VM code with cpuTime() on|off\012  --profileVM:on|off        turn compile time VM profiler on|off\012  --panics:on|off           turn panics into process terminations (default: off)\012  --deepcopy:on|off         enable \'system.deepCopy\' for ``--mm:arc|orc``\012  --jsbigint64:on|off       toggle the use of BigInt for 64-bit integers for\012                            the JavaScript backend (default: on)\012  --nimBasePattern:nimbase.h\012                            allows to specify a custom pattern for `nimbase.h`\012" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_728 = {14225, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_727};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_729 = {89, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_709};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_730 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_711};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_731 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_713};
static const struct {
  NI cap; NIM_CHAR data[2079+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_732 = { 2079 | NIM_STRLIT_FLAG, "\012    nim command [options] [projectfile] [arguments]\012\012Command:\012    compile, c              compile project with default code generator (C)\012    r                       compile to $nimcache/projname, run with `arguments`\012                            using backend specified by `--backend` (default: c)\012    doc                     generate the documentation for inputfile for\012                            backend specified by `--backend` (default: c)\012\012Arguments:\012  arguments are passed to the program being run (if --run option is selected)\012\012Options:\012  -p, --path:PATH           add path to search paths\012  -d, --define:SYMBOL(:VAL)\012                            define a conditional symbol\012                            (Optionally: Define the value for that symbol,\012                            see: \"compile time define pragmas\")\012  -u, --undef:SYMBOL        undefine a conditional symbol\012  -f, --forceBuild:on|off   force rebuilding of all modules\012  --stackTrace:on|off       turn stack tracing on|off\012  --lineTrace:on|off        turn line tracing on|off\012  --threads:on|off          turn support for multi-threading on|off\012  -x, --checks:on|off       turn all runtime checks on|off\012  -a, --assertions:on|off   turn assertions on|off\012  --opt:none|speed|size     optimize not at all or for speed|size\012                            Note: use -d:release for a release build!\012  --debugger:native         use native debugger (gdb)\012  --app:console|gui|lib|staticlib\012                            generate a console app|GUI app|DLL|static library\012  -r, --run                 run the compiled program with given arguments\012  --eval:cmd                evaluate nim code directly; e.g.: `nim --eval:\"echo 1\"`\012                            defaults to `e` (nimscript) but customizable:\012                            `nim r --eval:\'for a in stdin.lines: echo a\'`\012  --fullhelp                show all command line switches\012  -h, --help                show this help\012  -v, --version             show detailed version information\012\012Note, single letter options that take an argument require a colon. E.g. -p:PATH.\012" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_733 = {2079, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_732};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_734 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_293};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_735 = {35, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_635};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_736 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_295};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_737 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_738 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_739 = { 9 | NIM_STRLIT_FLAG, "writeonly" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_740 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_739};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_741 = { 8 | NIM_STRLIT_FLAG, "readonly" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_742 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_741};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_743 = { 2 | NIM_STRLIT_FLAG, "v2" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_744 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_743};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_745 = { 6 | NIM_STRLIT_FLAG, "stress" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_746 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_745};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_747 = { 34 | NIM_STRLIT_FLAG, "invalid option for --incremental: " };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_748 = {34, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_747};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_750 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_309};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_751 = {35, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_635};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_752 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_307};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_753 = { 25 | NIM_STRLIT_FLAG, "FILE,LINE,COLUMN expected" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_754 = {25, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_753};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_756 = { 24 | NIM_STRLIT_FLAG, "$1 is not a valid number" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_757 = {24, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_756};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_759 = {24, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_756};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_761 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[47+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_762 = { 47 | NIM_STRLIT_FLAG, "DIRTY_BUFFER,ORIGINAL_FILE,LINE,COLUMN expected" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_763 = {47, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_762};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_765 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const struct {
  NI cap; NIM_CHAR data[49+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_766 = { 49 | NIM_STRLIT_FLAG, "[DIRTY_BUFFER,]ORIGINAL_FILE,LINE,COLUMN expected" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_767 = {49, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_766};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_769 = { 3 | NIM_STRLIT_FLAG, "abs" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_770 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_769};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_771 = { 9 | NIM_STRLIT_FLAG, "canonical" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_772 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_771};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_773 = { 13 | NIM_STRLIT_FLAG, "legacyrelproj" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_774 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_773};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_775 = { 46 | NIM_STRLIT_FLAG, "expected: abs|canonical|legacyRelProj, got: $1" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_776 = {46, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_775};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_778 = { 4 | NIM_STRLIT_FLAG, "dots" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_779 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_778};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_780 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_336};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_781 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_782 = { 37 | NIM_STRLIT_FLAG, "expected: dots|filenames|off, got: $1" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_783 = {37, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_782};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_785 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_786 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_787 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_788 = {38, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_454};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_790 = { 1 | NIM_STRLIT_FLAG, "\037" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_791 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_790};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_792 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_793 = {0, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_4};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_794 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_795 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_796 = {38, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_454};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_797 = { 4 | NIM_STRLIT_FLAG, "auto" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_798 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_797};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_799 = { 28 | NIM_STRLIT_FLAG, "unknown experimental feature" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_800 = {28, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_799};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_802 = { 24 | NIM_STRLIT_FLAG, "unknown obsolete feature" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_803 = {24, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_802};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_805 = { 15 | NIM_STRLIT_FLAG, "noCppExceptions" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_806 = {15, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_805};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_807 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_808 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_14};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_809 = { 6 | NIM_STRLIT_FLAG, "setjmp" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_810 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_809};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_811 = { 6 | NIM_STRLIT_FLAG, "quirky" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_812 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_811};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_813 = { 4 | NIM_STRLIT_FLAG, "goto" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_814 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_813};
static const struct {
  NI cap; NIM_CHAR data[60+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_815 = { 60 | NIM_STRLIT_FLAG, "\'goto\', \'setjmp\', \'cpp\' or \'quirky\' expected, but \'$1\' found" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_816 = {60, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_815};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_818 = { 46 | NIM_STRLIT_FLAG, "newruntime is deprecated, use arc/orc instead!" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_819 = {46, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_818};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_820 = { 37 | NIM_STRLIT_FLAG, "commands.nim(1118, 15) `conf != nil` " };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_821 = {37, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_820};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_822 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_525};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_823 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_824 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_548};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_825 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_826 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_523};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_827 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_828 = { 15 | NIM_STRLIT_FLAG, "nimOwnedEnabled" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_829 = {15, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_828};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_830 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_831 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_523};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_832 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_833 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_834 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_156};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_835 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_154};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_836 = { 5 | NIM_STRLIT_FLAG, "error" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_837 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_836};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_838 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_330};
static const struct {
  NI cap; NIM_CHAR data[70+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_839 = { 70 | NIM_STRLIT_FLAG, "\'off\', \'hint\', \'warning\', \'error\' or \'usages\' expected, but \'$1\' found" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_840 = {70, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_839};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_842 = { 3 | NIM_STRLIT_FLAG, "Nim" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_843 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_842};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_844 = { 21 | NIM_STRLIT_FLAG, "cppCompileToNamespace" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_845 = {21, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_844};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_846 = { 1 | NIM_STRLIT_FLAG, "T" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_847 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_846};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_848 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_846};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_849 = { 9 | NIM_STRLIT_FLAG, "nimPanics" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_850 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_849};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_851 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_852 = { 30 | NIM_STRLIT_FLAG, "\'$#\' is deprecated, now a noop" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_853 = {30, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_852};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_854 = { 7 | NIM_STRLIT_FLAG, "cmdfile" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_855 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_854};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_856 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_129};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_857 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_133};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_858 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_6};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_859 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_136};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_860 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_138};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_861 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_140};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_862 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_142};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_863 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_150};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_864 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_152};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_865 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_162};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_866 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_164};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_867 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_166};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_868 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_168};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_869 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_172};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_870 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_174};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_871 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_180};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_872 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_182};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_873 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_186};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_874 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_188};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_875 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_190};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_876 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_192};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_877 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_194};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_878 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_196};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_879 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_198};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_880 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_200};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_881 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_202};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_882 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_204};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_883 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_206};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_884 = {17, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_208};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_885 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_210};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_886 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_212};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_887 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_214};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_888 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_216};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_889 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_30};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_890 = {1, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_26};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_891 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_293};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_892 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_307};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_893 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_311};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_894 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_218};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_895 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_220};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_896 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_222};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_897 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_224};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_898 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_226};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_899 = {19, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_170};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_900 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_401};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_901 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_403};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_902 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_407};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_903 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_392};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_904 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_394};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_905 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_176};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_906 = {24, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_632};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_907 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_224};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_908 = {35, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_635};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_909 = {8, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_226};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_910 = {30, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_852};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_911 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_146};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_912 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_148};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_913 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_228};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_914 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_278};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_915 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_230};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_916 = {14, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_348};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_917 = {10, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_362};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_918 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_352};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_919 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_491};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_920 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_493};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_921 = {12, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_495};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_922 = {11, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_497};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_923 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_499};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_924 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_501};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_925 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_505};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_926 = {2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_507};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_927 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_509};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_928 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_511};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_929 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_513};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_930 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_503};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_931 = {111, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_562};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_933 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_638};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_934 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_640};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_935 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_509};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_936 = {50, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_643};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_938 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_646};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_939 = {7, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_648};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_940 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_315};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_941 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_651};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_942 = {63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_674};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_944 = {3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_14};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_945 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_809};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_946 = {6, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_811};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_947 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_813};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_948 = {60, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_815};
static const struct {
  NI cap; NIM_CHAR data[432+1];
} TM__brsa2DgNdQAKzy1F0pSZlA_950 = { 432 | NIM_STRLIT_FLAG, "\'dotOperators\', \'callOperator\', \'parallel\', \'destructor\', \'notnil\', \'dynamicBindSym\', \'forLoopMacros\', \'caseStmtMacros\', \'codeReordering\', \'compiletimeFFI\', \'vmopsDanger\', \'strictFuncs\', \'views\', \'strictNotNil\', \'overloadableEnums\', \'strictEffects\', \'unicodeOperators\', \'flexibleOptionalParams\', \'strictDefs\', \'strictCaseObjects\', \'inferGenericTypes\', \'openSym\', \'genericsOpenSym\', \'vtables\', \'typeBoundOps\' expected, but \'$1\' found" };
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_951 = {432, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_950};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_953 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_519};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_954 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_955 = {13, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_515};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_956 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_957 = {9, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_523};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_958 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_959 = {5, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_525};
static const NimStringV2 TM__brsa2DgNdQAKzy1F0pSZlA_960 = {4, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_464};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_421 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)179),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_436 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)397),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_438 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)383),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_448 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)183),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_456 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)175),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_461 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)693),
((NI)46)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_474 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)124),
((NI)30)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_476 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)125),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_487 = {{59, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_488},
((NI)629),
((NI)9)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_564 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)621),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_571 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)168),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_580 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)213),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_583 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)215),
((NI)18)}
;
static NIM_CONST tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ TM__brsa2DgNdQAKzy1F0pSZlA_589 = {{2, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_450},
{3, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_452}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_591 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)226),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_596 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)230),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_601 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)159),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_610 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)763),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_616 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)771),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_645 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)838),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_676 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)861),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_683 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)888),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_686 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)896),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_688 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)904),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_693 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)918),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_697 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)926),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_702 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)938),
((NI)29)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_705 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)944),
((NI)29)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_708 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)963),
((NI)16)}
;
extern NIM_CONST tyArray__jQ6Zibb0SzsKfL1Qwwi9bag NotesVerbosity__lineinfos_u228;
extern NIM_CONST tyArray__RQFn3NKTp5P7VzZ9bksPIyA OS__platform_u534;
extern NIM_CONST tyArray__BJ38CrWfGxMtyd3CSynibg CPU__platform_u740;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_749 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)998),
((NI)22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_755 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)436),
((NI)27)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_758 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)415),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_760 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)417),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_764 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)430),
((NI)27)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_768 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)448),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_777 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)1054),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_784 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)1064),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_789 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)151),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_801 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)1087),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_804 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)1092),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_817 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)1109),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_841 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)1139),
((NI)20)}
;
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA gCmdLineInfo__msgs_u442;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_932 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)276),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_937 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)284),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_943 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)296),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_949 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)307),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__brsa2DgNdQAKzy1F0pSZlA_952 = {{63, (NimStrPayload*)&TM__brsa2DgNdQAKzy1F0pSZlA_422},
((NI)313),
((NI)16)}
;
extern NIM_BOOL nimInErrorMode__system_u4141;
extern Exception* currException__system_u3626;
N_LIB_PRIVATE N_NIMCALL(void, setCmd__commands_u1211)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd_p1) {
	(*conf_p0).cmd = cmd_p1;
	switch (cmd_p1) {
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)2):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)6):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)7):
	{
		(*conf_p0).backend = ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1);
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)3):
	{
		(*conf_p0).backend = ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2);
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)4):
	{
		(*conf_p0).backend = ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)4);
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)5):
	{
		(*conf_p0).backend = ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3);
	}
	break;
	default:
	{
	}
	break;
	}
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4141);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ, parseCommand__commands_u1189)(NimStringV2 command_p0) {
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ result;
	NimStringV2 colontmpD_;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_ = (tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)0;
	colontmpD_ = nsuNormalize(command_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch (hashString(colontmpD_) & 63) {
	case 0: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_21)) goto LA4_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_43)) goto LA13_;
break;
	case 1: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_37)) goto LA11_;
break;
	case 4: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_67)) goto LA24_;
break;
	case 10: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_9)) goto LA2_;
break;
	case 13: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_41)) goto LA12_;
break;
	case 15: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_69)) goto LA25_;
break;
	case 16: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_35)) goto LA10_;
break;
	case 18: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_11)) goto LA2_;
break;
	case 19: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_51)) goto LA17_;
break;
	case 20: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_57)) goto LA19_;
break;
	case 25: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_7)) goto LA2_;
break;
	case 27: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_23)) goto LA5_;
break;
	case 29: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_63)) goto LA22_;
break;
	case 31: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_19)) goto LA4_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_39)) goto LA12_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_45)) goto LA14_;
break;
	case 32: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_17)) goto LA3_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_55)) goto LA19_;
break;
	case 33: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_61)) goto LA21_;
break;
	case 34: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_27)) goto LA6_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_65)) goto LA23_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_73)) goto LA27_;
break;
	case 41: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_31)) goto LA8_;
break;
	case 42: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_33)) goto LA9_;
break;
	case 44: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_13)) goto LA2_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_75)) goto LA27_;
break;
	case 50: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_25)) goto LA5_;
break;
	case 52: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_71)) goto LA26_;
break;
	case 53: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_29)) goto LA7_;
break;
	case 57: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_47)) goto LA15_;
break;
	case 59: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_15)) goto LA3_;
break;
	case 60: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_49)) goto LA16_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_59)) goto LA20_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_77)) goto LA28_;
break;
	case 63: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_53)) goto LA18_;
break;
	}
	goto LA29_;
	LA2_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)2);
	}
	goto LA30_;
	LA3_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)3);
	}
	goto LA30_;
	LA4_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)4);
	}
	goto LA30_;
	LA5_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)5);
	}
	goto LA30_;
	LA6_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)6);
	}
	goto LA30_;
	LA7_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)9);
	}
	goto LA30_;
	LA8_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)7);
	}
	goto LA30_;
	LA9_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8);
	}
	goto LA30_;
	LA10_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)13);
	}
	goto LA30_;
	LA11_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)14);
	}
	goto LA30_;
	LA12_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)15);
	}
	goto LA30_;
	LA13_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16);
	}
	goto LA30_;
	LA14_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)17);
	}
	goto LA30_;
	LA15_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)20);
	}
	goto LA30_;
	LA16_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)19);
	}
	goto LA30_;
	LA17_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)18);
	}
	goto LA30_;
	LA18_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)21);
	}
	goto LA30_;
	LA19_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)22);
	}
	goto LA30_;
	LA20_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)23);
	}
	goto LA30_;
	LA21_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)24);
	}
	goto LA30_;
	LA22_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)25);
	}
	goto LA30_;
	LA23_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)26);
	}
	goto LA30_;
	LA24_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)10);
	}
	goto LA30_;
	LA25_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)11);
	}
	goto LA30_;
	LA26_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)27);
	}
	goto LA30_;
	LA27_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)28);
	}
	goto LA30_;
	LA28_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)29);
	}
	goto LA30_;
	LA29_: ;
	{
		result = ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)1);
	}
LA30_: ;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
N_LIB_PRIVATE N_NIMCALL(void, setCommandEarly__commands_u1214)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 command_p1) {
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___system_u2694((&(*conf_p0).command), command_p1);
	T1_ = (tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)0;
	T1_ = parseCommand__commands_u1189(command_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setCmd__commands_u1211(conf_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*conf_p0).cmd) {
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)17):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)18):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)19):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)20):
	{
		nimCopyMem((void*)(*conf_p0).foreignPackageNotes, (NIM_CONST void*)TM__brsa2DgNdQAKzy1F0pSZlA_78, 13);
	}
	break;
	default:
	{
		nimCopyMem((void*)(*conf_p0).foreignPackageNotes, (NIM_CONST void*)TM__brsa2DgNdQAKzy1F0pSZlA_79, 13);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processArgument__commands_u1995)(tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p0, tyObject_OptParser__pqMTtVZW7HhFSYkGtStiLg* p_p1, NI* argsCount_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p3) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*argsCount_p2) == ((NI)0));
		if (!(T3_)) goto LA4_;
		T3_ = (*config_p3).implicitCmd;
LA4_: ;
		if (!T3_) goto LA5_;
		(*argsCount_p2) += ((NI)1);
	}
LA5_: ;
	{
		if (!((*argsCount_p2) == ((NI)0))) goto LA9_;
		{
			NIM_BOOL T13_;
			NimStringV2 T16_;
			NimStringV2 T17_;
			T13_ = (NIM_BOOL)0;
			T13_ = nsuEndsWith((*p_p1).key, TM__brsa2DgNdQAKzy1F0pSZlA_3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T13_) goto LA14_;
			setCmd__commands_u1211(config_p3, ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)13));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*config_p3).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)2))) & 63);
			T16_.len = 0; T16_.p = NIM_NIL;
			T16_ = nosunixToNativePath((*p_p1).key, TM__brsa2DgNdQAKzy1F0pSZlA_5);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T16_); goto BeforeRet_;}
			eqsink___system_u2700((&(*config_p3).projectName), T16_);
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = npocmdLineRest(p_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T17_); goto BeforeRet_;}
			eqsink___system_u2700((&(*config_p3).arguments), T17_);
			result = NIM_TRUE;
		}
		goto LA11_;
LA14_: ;
		{
			if (!!((pass_p0 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1)))) goto LA19_;
			setCommandEarly__commands_u1214(config_p3, (*p_p1).key);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = NIM_FALSE;
		}
		goto LA11_;
LA19_: ;
		{
			result = NIM_FALSE;
		}
LA11_: ;
	}
	goto LA7_;
LA9_: ;
	{
		{
			NimStringV2 colontmpD_;
			if (!(pass_p0 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0))) goto LA25_;
			colontmpD_ = eqdup___system_u2697((*p_p1).key);
			add__stdZenumutils_u71((&(*config_p3).commandArgs), colontmpD_);
		}
LA25_: ;
		{
			NimStringV2 T41_;
			if (!((*argsCount_p2) == ((NI)1))) goto LA29_;
			{
				NIM_BOOL T33_;
				T33_ = (NIM_BOOL)0;
				T33_ = nsuEndsWith((*p_p1).key, TM__brsa2DgNdQAKzy1F0pSZlA_80);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T33_) goto LA34_;
				(*config_p3).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)2))) & 63);
			}
LA34_: ;
			{
				NimStringV2 T40_;
				if (!((*config_p3).projectName.len == ((NI)0))) goto LA38_;
				T40_.len = 0; T40_.p = NIM_NIL;
				T40_ = nosunixToNativePath((*p_p1).key, TM__brsa2DgNdQAKzy1F0pSZlA_81);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T40_); goto BeforeRet_;}
				eqsink___system_u2700((&(*config_p3).projectName), T40_);
			}
LA38_: ;
			T41_.len = 0; T41_.p = NIM_NIL;
			T41_ = npocmdLineRest(p_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T41_); goto BeforeRet_;}
			eqsink___system_u2700((&(*config_p3).arguments), T41_);
			result = NIM_TRUE;
		}
		goto LA27_;
LA29_: ;
		{
			result = NIM_FALSE;
		}
LA27_: ;
	}
LA7_: ;
	(*argsCount_p2) += ((NI)1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1) {
	(*(*dest_p0).p).data[(*dest_p0).len] = c_p1;
	(*dest_p0).len += ((NI)1);
	(*(*dest_p0).p).data[(*dest_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, addPrefix__commands_u184)(NimStringV2 switch_p0) {
	NimStringV2 result;
	{
		NimStringV2 T5_;
		if (!(switch_p0.len <= ((NI)1))) goto LA3_;
		T5_.len = 0; T5_.p = NIM_NIL;
		T5_ = rawNewString(switch_p0.len + 1);
appendString((&T5_), TM__brsa2DgNdQAKzy1F0pSZlA_418);
appendString((&T5_), switch_p0);
		result = T5_;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 T7_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = rawNewString(switch_p0.len + 2);
appendString((&T7_), TM__brsa2DgNdQAKzy1F0pSZlA_420);
appendString((&T7_), switch_p0);
		result = T7_;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, expectArg__commands_u278)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		if (!(arg_p2.len == 0)) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD_ = addPrefix__commands_u184(switch_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD__2 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_416, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		liMessage__msgs_u1227(conf_p0, info_p4, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_421), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NI, find__stdZprivateZospaths2_u388)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NIM_CHAR i_1;
		NI i_2;
		i_1 = (NIM_CHAR)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < a_p0Len_0)) goto LA3;
				i_1 = a_p0[i_2];
				{
					if (!((NU8)(i_1) == (NU8)(item_p1))) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZprivateZospaths2_u383)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1) {
	NIM_BOOL result;
	NI T1_;
{	T1_ = (NI)0;
	T1_ = find__stdZprivateZospaths2_u388(a_p0, a_p0Len_0, item_p1);
	result = (((NI)0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosjoinPath(head_p0, tail_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (targetDepth_p1 <= (*source_p0).depth);
	if (!(T1_)) goto LA2_;
	T1_ = ((*source_p0).display[targetDepth_p1] == token_p2);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = currException__system_u3626;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	eqcopy___system_u3659(&currException__system_u3626, (*currException__system_u3626).up, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, processCfgPath__commands_u1115)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	NimStringV2 result;
	NimStringV2 path_2;
	NimStringV2 basedir_1;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 p_1;
	NimStringV2 T2_;
	NimStringV2 T10_;
	NimStringV2 T19_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	path_2.len = 0; path_2.p = NIM_NIL;
	basedir_1.len = 0; basedir_1.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	p_1.len = 0; p_1.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((NI)0) < path_p1.len);
		if (!(T5_)) goto LA6_;
		T5_ = ((NU8)(path_p1.p->data[((NI)0)]) == (NU8)(34));
LA6_: ;
		if (!T5_) goto LA7_;
		path_2 = nsuUnescape(path_p1, TM__brsa2DgNdQAKzy1F0pSZlA_432, TM__brsa2DgNdQAKzy1F0pSZlA_433);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA7_: ;
	{
		eqcopy___system_u2694((&path_2), path_p1);
	}
LA3_: ;
	colontmpD__2 = toFullPath__msgs_u624(conf_p0, info_p2.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nossplitFile(colontmpD__2, (&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	basedir_1 = colontmpD_.Field0;
	eqwasMoved___system_u2688((&colontmpD_.Field0));
	T10_.len = 0; T10_.p = NIM_NIL;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nosisAbsolute(path_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (T13_) goto LA14_;
		T13_ = contains__stdZprivateZospaths2_u383(((path_2).p) ? (path_2.p->data) : NIM_NIL, path_2.len, 36);
LA14_: ;
		if (!T13_) goto LA15_;
		p_1 = path_2;
		eqwasMoved___system_u2688((&path_2));
	}
	goto LA11_;
LA15_: ;
	{
		p_1 = slash___stdZprivateZospaths2_u91(basedir_1, path_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	T19_.len = 0; T19_.p = NIM_NIL;
	T19_ = pathSubs__options_u3759(conf_p0, p_1, basedir_1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T19_); goto LA18_;}
	result = T19_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA18_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
			NimStringV2 colontmpD__3;
			NimStringV2 T24_;
			NimStringV2 blitTmp_1;
			*nimErr_ = NIM_FALSE;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T24_.len = 0; T24_.p = NIM_NIL;
			T24_ = rawNewString(p_1.len + 14);
appendString((&T24_), TM__brsa2DgNdQAKzy1F0pSZlA_435);
appendString((&T24_), p_1);
			colontmpD__3 = T24_;
			liMessage__msgs_u1227(conf_p0, info_p2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_436), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			blitTmp_1 = p_1;
			eqwasMoved___system_u2688((&p_1));
			result = blitTmp_1;
			{
				LA23_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			popCurrentException();
			LA21_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(p_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___pureZos_u236((&colontmpD_));
		eqdestroy___system_u2691(basedir_1);
		eqdestroy___system_u2691(path_2);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, processPath__commands_u1104)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, NIM_BOOL notRelativeToProj_p3) {
	NimStringV2 result;
	NimStringV2 p_1;
	NimStringV2 T2_;
	NimStringV2 colontmpD__2;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__3;
	NimStringV2 T18_;
	NimStringV2 T19_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	p_1.len = 0; p_1.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = nosisAbsolute(path_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (T5_) goto LA6_;
		T5_ = contains__stdZprivateZospaths2_u383(((path_p1).p) ? (path_p1.p->data) : NIM_NIL, path_p1.len, 36);
LA6_: ;
		if (!T5_) goto LA7_;
		eqcopy___system_u2694((&p_1), path_p1);
	}
	goto LA3_;
LA7_: ;
	{
		NimStringV2 colontmpD_;
		if (!notRelativeToProj_p3) goto LA10_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = nosgetCurrentDir();
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		p_1 = slash___stdZprivateZospaths2_u91(colontmpD_, path_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA10_: ;
	{
		p_1 = slash___stdZprivateZospaths2_u91((*conf_p0).projectPath, path_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__3), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	T18_.len = 0; T18_.p = NIM_NIL;
	T18_ = toFullPath__msgs_u624(conf_p0, info_p2.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T18_); goto LA17_;}
	colontmpD__2 = T18_;
	nossplitFile(colontmpD__2, (&colontmpD__3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
	T19_.len = 0; T19_.p = NIM_NIL;
	T19_ = pathSubs__options_u3759(conf_p0, p_1, colontmpD__3.Field0);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T19_); goto LA17_;}
	result = T19_;
	{
		LA17_:;
	}
	{
		eqdestroy___pureZos_u236((&colontmpD__3));
		eqdestroy___system_u2691(colontmpD__2);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA16_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
			NimStringV2 colontmpD__4;
			NimStringV2 T26_;
			NimStringV2 blitTmp_1;
			*nimErr_ = NIM_FALSE;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T26_.len = 0; T26_.p = NIM_NIL;
			T26_ = rawNewString(p_1.len + 14);
appendString((&T26_), TM__brsa2DgNdQAKzy1F0pSZlA_437);
appendString((&T26_), p_1);
			colontmpD__4 = T26_;
			liMessage__msgs_u1227(conf_p0, info_p2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__4, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_438), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			blitTmp_1 = p_1;
			eqwasMoved___system_u2688((&p_1));
			result = blitTmp_1;
			{
				LA25_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			popCurrentException();
			LA23_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(p_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_u139)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, expectNoArg__commands_u284)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		if (!!((arg_p2.len == 0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD_ = addPrefix__commands_u184(switch_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD__2 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_447, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		liMessage__msgs_u1227(conf_p0, info_p4, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_448), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, pathRelativeToConfig__commands_u1349)(NimStringV2 arg_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (pass_p1 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = nosisAbsolute(arg_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !(T5_);
LA4_: ;
		if (!T3_) goto LA6_;
		result = slash___stdZprivateZospaths2_u91((*conf_p2).currentConfigDir, arg_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		eqcopy___system_u2694((&result), arg_p0);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitchG__commands_u260)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A op_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nsuNormalize(arg_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_449)) goto LA2_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_451)) goto LA2_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_453)) goto LA3_;
	goto LA4_;
	LA2_: ;
	{
		(*conf_p0).globalOptions = ((*conf_p0).globalOptions | op_p1);
	}
	goto LA5_;
	LA3_: ;
	{
		(*conf_p0).globalOptions = ((*conf_p0).globalOptions & ~ op_p1);
	}
	goto LA5_;
	LA4_: ;
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_455, arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		liMessage__msgs_u1227(conf_p0, info_p4, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_456), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, invalidCmdLineOption__commands_u191)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1, NimStringV2 switch_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		if (!eqStrings(switch_p2, TM__brsa2DgNdQAKzy1F0pSZlA_470)) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_472, TM__brsa2DgNdQAKzy1F0pSZlA_473);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		liMessage__msgs_u1227(conf_p0, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_474), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__2 = addPrefix__commands_u184(switch_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		colontmpD__3 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_475, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		liMessage__msgs_u1227(conf_p0, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_476), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, splitSwitch__commands_u196)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2* cmd_p2, NimStringV2* arg_p3, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p4, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p5) {
	NI i_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqsink___system_u2700((&(*cmd_p2)), TM__brsa2DgNdQAKzy1F0pSZlA_467);
	i_1 = ((NI)0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (i_1 < switch_p1.len);
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(switch_p1.p->data[i_1]) == (NU8)(45));
LA4_: ;
		if (!T3_) goto LA5_;
		i_1 += ((NI)1);
	}
LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = (i_1 < switch_p1.len);
		if (!(T9_)) goto LA10_;
		T9_ = ((NU8)(switch_p1.p->data[i_1]) == (NU8)(45));
LA10_: ;
		if (!T9_) goto LA11_;
		i_1 += ((NI)1);
	}
LA11_: ;
	{
		while (1) {
			if (!(i_1 < switch_p1.len)) goto LA14;
			switch (((NU8)(switch_p1.p->data[i_1]))) {
			case 97 ... 122:
			case 65 ... 90:
			case 48 ... 57:
			case 95:
			case 46:
			{
				nimAddCharV1((&(*cmd_p2)), switch_p1.p->data[i_1]);
			}
			break;
			default:
			{
				goto LA13;
			}
			break;
			}
			i_1 += ((NI)1);
		} LA14: ;
	} LA13: ;
	{
		if (!(switch_p1.len <= i_1)) goto LA19_;
		eqsink___system_u2700((&(*arg_p3)), TM__brsa2DgNdQAKzy1F0pSZlA_468);
	}
	goto LA17_;
LA19_: ;
	{
		NimStringV2 T24_;
		if (!(((NU8)(switch_p1.p->data[i_1])) == ((NU8)(58)) || ((NU8)(switch_p1.p->data[i_1])) == ((NU8)(61)))) goto LA22_;
		T24_.len = 0; T24_.p = NIM_NIL;
		T24_ = substr__system_u8672(switch_p1, (NI)(i_1 + ((NI)1)));
		eqsink___system_u2700((&(*arg_p3)), T24_);
	}
	goto LA17_;
LA22_: ;
	{
		NimStringV2 T28_;
		if (!((NU8)(switch_p1.p->data[i_1]) == (NU8)(91))) goto LA26_;
		T28_.len = 0; T28_.p = NIM_NIL;
		T28_ = substr__system_u8672(switch_p1, i_1);
		eqsink___system_u2700((&(*arg_p3)), T28_);
	}
	goto LA17_;
LA26_: ;
	{
		invalidCmdLineOption__commands_u191(conf_p0, pass_p4, switch_p1, info_p5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA17_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specialDefine__commands_u1217)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = nsuCmpIgnoreStyle(key_p1, TM__brsa2DgNdQAKzy1F0pSZlA_478);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T3_ == ((NI)0))) goto LA4_;
		(*conf_p0).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)4);
	}
	goto LA1_;
LA4_: ;
	{
		NIM_BOOL T7_;
		NI T8_;
		NI T10_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NI)0;
		T8_ = nsuCmpIgnoreStyle(key_p1, TM__brsa2DgNdQAKzy1F0pSZlA_480);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T7_ = (T8_ == ((NI)0));
		if (T7_) goto LA9_;
		T10_ = (NI)0;
		T10_ = nsuCmpIgnoreStyle(key_p1, TM__brsa2DgNdQAKzy1F0pSZlA_482);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T7_ = (T10_ == ((NI)0));
LA9_: ;
		if (!T7_) goto LA11_;
		{
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA15_;
			(*conf_p0).options = ((*conf_p0).options & ~ 724992);
			(*conf_p0).globalOptions = ((*conf_p0).globalOptions & ~ IL64(68719476800));
			(*conf_p0).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15))) & 31);
		}
LA15_: ;
	}
	goto LA1_;
LA11_: ;
LA1_: ;
	{
		NIM_BOOL T19_;
		NI T20_;
		NI T22_;
		T19_ = (NIM_BOOL)0;
		T20_ = (NI)0;
		T20_ = nsuCmpIgnoreStyle(key_p1, TM__brsa2DgNdQAKzy1F0pSZlA_483);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T19_ = (T20_ == ((NI)0));
		if (T19_) goto LA21_;
		T22_ = (NI)0;
		T22_ = nsuCmpIgnoreStyle(key_p1, TM__brsa2DgNdQAKzy1F0pSZlA_485);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T19_ = (T22_ == ((NI)0));
LA21_: ;
		if (!T19_) goto LA23_;
		{
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA27_;
			(*conf_p0).options = ((*conf_p0).options & ~ 661566);
			(*conf_p0).globalOptions = ((*conf_p0).globalOptions & ~ 64);
		}
LA27_: ;
	}
LA23_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__options_u4086)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, processCompile__commands_u503)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1) {
	NimStringV2 found_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	found_1.len = 0; found_1.p = NIM_NIL;
	found_1 = findFile__options_u4081(conf_p0, filename_p1, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD_;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmpty__options_u4086(found_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		colontmpD_ = eqdup___system_u2697(filename_p1);
		eqsink___system_u2700((&found_1), colontmpD_);
	}
LA5_: ;
	addExternalFileToCompile__extccomp_u1350(conf_p0, found_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(found_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, warningDeprecated__msgs_u1572)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	liMessage__msgs_u1227(conf_p0, info_p1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)24), msg_p2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_487), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, unregisterArcOrc__commands_u1313)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	undefSymbol__condsyms_u8((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_516);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	undefSymbol__condsyms_u8((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_518);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	undefSymbol__condsyms_u8((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_520);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	undefSymbol__condsyms_u8((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_522);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	undefSymbol__condsyms_u8((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_524);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	undefSymbol__condsyms_u8((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_526);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*conf_p0).globalOptions &= ~(((NU64)1) << (((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45))) & 63));
	(*conf_p0).globalOptions &= ~(((NU64)1) << (((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46))) & 63));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, registerArcOrc__commands_u1290)(tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	defineSymbol__condsyms_u4((*conf_p1).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_538, TM__brsa2DgNdQAKzy1F0pSZlA_539);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*conf_p1).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45))) & 63);
	(*conf_p1).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46))) & 63);
	{
		if (!(pass_p0 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p0 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA3_;
		defineSymbol__condsyms_u4((*conf_p1).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_540, TM__brsa2DgNdQAKzy1F0pSZlA_541);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		defineSymbol__condsyms_u4((*conf_p1).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_542, TM__brsa2DgNdQAKzy1F0pSZlA_543);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*conf_p1).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)0));
		if (!(T7_)) goto LA8_;
		T7_ = !(((*conf_p1).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2)));
LA8_: ;
		if (!T7_) goto LA9_;
		(*conf_p1).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3);
	}
LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processMemoryManagementOption__commands_u1323)(NimStringV2 switch_p0, NimStringV2 arg_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*conf_p4).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 colontmpD_;
		if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		switch (hashString(colontmpD_) & 15) {
		case 0: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_504)) goto LA15_;
break;
		case 1: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_492)) goto LA10_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_498)) goto LA13_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_510)) goto LA18_;
break;
		case 3: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_512)) goto LA19_;
break;
		case 4: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_514)) goto LA19_;
break;
		case 6: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_506)) goto LA16_;
break;
		case 7: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_508)) goto LA17_;
break;
		case 9: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_502)) goto LA14_;
break;
		case 13: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_500)) goto LA13_;
break;
		case 14: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_494)) goto LA11_;
break;
		case 15: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_496)) goto LA12_;
break;
		}
		goto LA20_;
		LA10_: ;
		{
			unregisterArcOrc__commands_u1313(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)2);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_528, TM__brsa2DgNdQAKzy1F0pSZlA_529);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)28))) & 63);
		}
		goto LA21_;
		LA11_: ;
		{
			unregisterArcOrc__commands_u1313(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_531, TM__brsa2DgNdQAKzy1F0pSZlA_532);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)9);
		}
		goto LA21_;
		LA12_: ;
		{
			unregisterArcOrc__commands_u1313(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)7);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_534, TM__brsa2DgNdQAKzy1F0pSZlA_535);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA21_;
		LA13_: ;
		{
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_536, TM__brsa2DgNdQAKzy1F0pSZlA_537);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			registerArcOrc__commands_u1290(pass_p2, conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA21_;
		LA14_: ;
		{
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_544, TM__brsa2DgNdQAKzy1F0pSZlA_545);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			registerArcOrc__commands_u1290(pass_p2, conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA21_;
		LA15_: ;
		{
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_546, TM__brsa2DgNdQAKzy1F0pSZlA_547);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			registerArcOrc__commands_u1290(pass_p2, conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA21_;
		LA16_: ;
		{
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)8);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_549, TM__brsa2DgNdQAKzy1F0pSZlA_550);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45))) & 63);
			processOnOffSwitchG__commands_u260(conf_p4, IL64(35184372088832), arg_p1, pass_p2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			{
				if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA31_;
				defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_551, TM__brsa2DgNdQAKzy1F0pSZlA_552);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
LA31_: ;
		}
		goto LA21_;
		LA17_: ;
		{
			unregisterArcOrc__commands_u1313(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_554, TM__brsa2DgNdQAKzy1F0pSZlA_555);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA21_;
		LA18_: ;
		{
			unregisterArcOrc__commands_u1313(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)1);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_557, TM__brsa2DgNdQAKzy1F0pSZlA_558);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA21_;
		LA19_: ;
		{
			unregisterArcOrc__commands_u1313(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)3);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_560, TM__brsa2DgNdQAKzy1F0pSZlA_561);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA21_;
		LA20_: ;
		{
			NimStringV2 colontmpD__2;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_563, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_564), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			{
				LA37_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA21_: ;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processOnOffSwitchOrList__commands_u243)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ op_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
	NIM_BOOL result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = NIM_FALSE;
	colontmpD_ = nsuNormalize(arg_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_565)) goto LA2_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_566)) goto LA3_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_568)) goto LA4_;
	goto LA5_;
	LA2_: ;
	{
		(*conf_p0).options = ((*conf_p0).options | op_p1);
	}
	goto LA6_;
	LA3_: ;
	{
		(*conf_p0).options = ((*conf_p0).options & ~ op_p1);
	}
	goto LA6_;
	LA4_: ;
	{
		result = NIM_TRUE;
	}
	goto LA6_;
	LA5_: ;
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_570, arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		liMessage__msgs_u1227(conf_p0, info_p4, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_571), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		{
			LA11_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, find__stdZenumutils_u56)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NimStringV2* i_1;
		NI i_2;
		i_1 = (NimStringV2*)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < a_p0Len_0)) goto LA3;
				i_1 = (&a_p0[i_2]);
				{
					if (!eqStrings((*i_1), item_p1)) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZenumutils_u51)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 item_p1) {
	NIM_BOOL result;
	NI T1_;
{	T1_ = (NI)0;
	T1_ = find__stdZenumutils_u56(a_p0, a_p0Len_0, item_p1);
	result = (((NI)0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, X5BX5Deq___commands_u457)(NU8* t_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw key_p1, NIM_BOOL val_p2) {
	{
		if (!val_p2) goto LA3_;
		t_p0[(NU)((key_p1 - 20))>>3] |=(1U<<((key_p1 - 20)&7U));
	}
	goto LA1_;
LA3_: ;
	{
		t_p0[(NU)((key_p1 - 20))>>3] &= ~(1U<<((key_p1 - 20)&7U));
	}
LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processSpecificNote__commands_u290)(NimStringV2 arg_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw state_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, NimStringV2 orig_p4, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p5) {
	NimStringV2 id_1;
	NimStringV2 colontmpD_;
	NimStringV2 val_1;
	NimStringV2 colontmpD__2;
	NI i_1;
	tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA notes_1;
	NIM_BOOL isBracket_1;
	NIM_BOOL isSomeHint_1;
	NIM_BOOL isSomeWarning_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	id_1.len = 0; id_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	val_1.len = 0; val_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	id_1 = TM__brsa2DgNdQAKzy1F0pSZlA_572;
	i_1 = ((NI)0);
	nimZeroMem((void*)notes_1, sizeof(tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA));
	nimZeroMem(notes_1, sizeof(tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA));
	isBracket_1 = NIM_FALSE;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (i_1 < arg_p0.len);
		if (!(T4_)) goto LA5_;
		T4_ = ((NU8)(arg_p0.p->data[i_1]) == (NU8)(91));
LA5_: ;
		if (!T4_) goto LA6_;
		isBracket_1 = NIM_TRUE;
		i_1 += ((NI)1);
	}
LA6_: ;
	{
		while (1) {
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = (i_1 < arg_p0.len);
			if (!(T10_)) goto LA11_;
			T10_ = !((((NU8)(arg_p0.p->data[i_1])) == ((NU8)(58)) || ((NU8)(arg_p0.p->data[i_1])) == ((NU8)(61)) || ((NU8)(arg_p0.p->data[i_1])) == ((NU8)(93))));
LA11_: ;
			if (!T10_) goto LA9;
			nimAddCharV1((&id_1), arg_p0.p->data[i_1]);
			i_1 += ((NI)1);
		} LA9: ;
	}
	{
		if (!isBracket_1) goto LA14_;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = (i_1 < arg_p0.len);
			if (!(T18_)) goto LA19_;
			T18_ = ((NU8)(arg_p0.p->data[i_1]) == (NU8)(93));
LA19_: ;
			if (!T18_) goto LA20_;
			i_1 += ((NI)1);
		}
		goto LA16_;
LA20_: ;
		{
			invalidCmdLineOption__commands_u191(conf_p5, pass_p2, orig_p4, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA16_: ;
	}
LA14_: ;
	{
		if (!(i_1 == arg_p0.len)) goto LA25_;
	}
	goto LA23_;
LA25_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = (i_1 < arg_p0.len);
		if (!(T28_)) goto LA29_;
		T28_ = (((NU8)(arg_p0.p->data[i_1])) == ((NU8)(58)) || ((NU8)(arg_p0.p->data[i_1])) == ((NU8)(61)));
LA29_: ;
		if (!T28_) goto LA30_;
		i_1 += ((NI)1);
	}
	goto LA23_;
LA30_: ;
	{
		invalidCmdLineOption__commands_u191(conf_p5, pass_p2, orig_p4, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA23_: ;
	isSomeHint_1 = (state_p1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)125) || state_p1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)127));
	isSomeWarning_1 = (state_p1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)124) || state_p1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)126));
	colontmpD_ = nsuNormalize(id_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_574)) goto LA33_;
	goto LA34_;
	LA33_: ;
	{
		tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA T37_;
		{
			if (!isSomeHint_1) goto LA40_;
			nimCopyMem((void*)notes_1, (NIM_CONST void*)TM__brsa2DgNdQAKzy1F0pSZlA_575, 16);
		}
		goto LA38_;
LA40_: ;
		{
			nimCopyMem((void*)notes_1, (NIM_CONST void*)TM__brsa2DgNdQAKzy1F0pSZlA_576, 16);
		}
LA38_: ;
	}
	goto LA35_;
	LA34_: ;
	{
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA xX60gensym37__1;
			if (!isSomeHint_1) goto LA46_;
			xX60gensym37__1 = findStr__commands_u346(id_1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				if (!!((xX60gensym37__1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0)))) goto LA50_;
				nimZeroMem(notes_1, sizeof(tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA));
				notes_1[(NU)(((xX60gensym37__1)))>>3] |=(1U<<((NU)(((xX60gensym37__1)))&7U));
			}
			goto LA48_;
LA50_: ;
			{
				{
					NIM_BOOL T55_;
					NimStringV2 colontmpD__3;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T60_;
					T55_ = (NIM_BOOL)0;
					T55_ = isSomeHint_1;
					if (T55_) goto LA56_;
					T55_ = isSomeWarning_1;
LA56_: ;
					if (!T55_) goto LA57_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					T60_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_579;
					T60_[1] = id_1;
					colontmpD__3 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_578, T60_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					liMessage__msgs_u1227(conf_p5, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)83), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_580), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					{
						LA59_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA53_;
LA57_: ;
				{
					NimStringV2 colontmpD__4;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T65_;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					T65_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_582;
					T65_[1] = id_1;
					colontmpD__4 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_581, T65_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
					liMessage__msgs_u1227(conf_p5, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__4, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_583), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
					{
						LA64_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__4);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA53_: ;
			}
LA48_: ;
		}
		goto LA44_;
LA46_: ;
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA xX60gensym44__1;
			xX60gensym44__1 = findStr__commands_u377(id_1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				if (!!((xX60gensym44__1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0)))) goto LA71_;
				nimZeroMem(notes_1, sizeof(tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA));
				notes_1[(NU)(((xX60gensym44__1)))>>3] |=(1U<<((NU)(((xX60gensym44__1)))&7U));
			}
			goto LA69_;
LA71_: ;
			{
				{
					NIM_BOOL T76_;
					NimStringV2 colontmpD__5;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T81_;
					T76_ = (NIM_BOOL)0;
					T76_ = isSomeHint_1;
					if (T76_) goto LA77_;
					T76_ = isSomeWarning_1;
LA77_: ;
					if (!T76_) goto LA78_;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					T81_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_585;
					T81_[1] = id_1;
					colontmpD__5 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_584, T81_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
					liMessage__msgs_u1227(conf_p5, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)83), colontmpD__5, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_580), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
					{
						LA80_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__5);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA74_;
LA78_: ;
				{
					NimStringV2 colontmpD__6;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T86_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					T86_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_587;
					T86_[1] = id_1;
					colontmpD__6 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_586, T86_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
					liMessage__msgs_u1227(conf_p5, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__6, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_583), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
					{
						LA85_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__6);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA74_: ;
			}
LA69_: ;
		}
LA44_: ;
	}
LA35_: ;
	colontmpD__2 = substr__system_u8672(arg_p0, i_1);
	val_1 = nsuNormalize(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(val_1.len == 0)) goto LA91_;
		eqsink___system_u2700((&val_1), TM__brsa2DgNdQAKzy1F0pSZlA_588);
	}
LA91_: ;
	{
		NIM_BOOL T95_;
		NimStringV2 colontmpD__7;
		T95_ = (NIM_BOOL)0;
		T95_ = contains__stdZenumutils_u51(TM__brsa2DgNdQAKzy1F0pSZlA_589, 2, val_1);
		if (!!(T95_)) goto LA96_;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__7 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_590, arg_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		liMessage__msgs_u1227(conf_p5, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__7, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_591), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		{
			LA98_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA93_;
LA96_: ;
	{
		NimStringV2 colontmpD__8;
		NIM_BOOL isOn_1;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		isOn_1 = eqStrings(val_1, TM__brsa2DgNdQAKzy1F0pSZlA_592);
		{
			NIM_BOOL T105_;
			T105_ = (NIM_BOOL)0;
			T105_ = isOn_1;
			if (!(T105_)) goto LA106_;
			colontmpD__8 = nsuNormalize(id_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
			T105_ = eqStrings(colontmpD__8, TM__brsa2DgNdQAKzy1F0pSZlA_593);
LA106_: ;
			if (!T105_) goto LA107_;
			liMessage__msgs_u1227(conf_p5, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__brsa2DgNdQAKzy1F0pSZlA_595, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_596), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
		}
LA107_: ;
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA n_1;
			NI i_2;
			n_1 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 <= ((NI)123))) goto LA111;
					{
						if (!((notes_1[(NU)((((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_2))))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_2))))&7U)))!=0)) goto LA114_;
						n_1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_2));
						{
							NIM_BOOL T118_;
							T118_ = (NIM_BOOL)0;
							T118_ = !((((*conf_p5).cmdlineNotes[(NU)(((n_1) - 20))>>3] &(1U<<((NU)(((n_1) - 20))&7U)))!=0));
							if (T118_) goto LA119_;
							T118_ = (pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0));
LA119_: ;
							if (!T118_) goto LA120_;
							{
								if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0))) goto LA124_;
								(*conf_p5).cmdlineNotes[(NU)(((n_1) - 20))>>3] |=(1U<<(((n_1) - 20)&7U));
							}
LA124_: ;
							(*conf_p5).modifiedyNotes[(NU)(((n_1) - 20))>>3] |=(1U<<(((n_1) - 20)&7U));
							{
								if (!(state_p1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)126) || state_p1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)127))) goto LA128_;
								X5BX5Deq___commands_u457((*conf_p5).warningAsErrors, (n_1), isOn_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
							}
							goto LA126_;
LA128_: ;
							{
								X5BX5Deq___commands_u457((*conf_p5).notes, (n_1), isOn_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
								X5BX5Deq___commands_u457((*conf_p5).mainPackageNotes, (n_1), isOn_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
							}
LA126_: ;
							{
								if (!!(isOn_1)) goto LA133_;
								(*conf_p5).foreignPackageNotes[(NU)(((n_1) - 20))>>3] &= ~(1U<<(((n_1) - 20)&7U));
							}
LA133_: ;
						}
LA120_: ;
					}
LA114_: ;
					i_2 += ((NI)1);
				} LA111: ;
			}
		}
		{
			LA102_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA93_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(val_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(id_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processOnOffSwitch__commands_u225)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ op_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nsuNormalize(arg_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_597)) goto LA2_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_598)) goto LA2_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_599)) goto LA3_;
	goto LA4_;
	LA2_: ;
	{
		(*conf_p0).options = ((*conf_p0).options | op_p1);
	}
	goto LA5_;
	LA3_: ;
	{
		(*conf_p0).options = ((*conf_p0).options & ~ op_p1);
	}
	goto LA5_;
	LA4_: ;
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_600, arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		liMessage__msgs_u1227(conf_p0, info_p4, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_601), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, contains__pureZtimes_u3356)(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA s_p0, NI value_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (s_p0.a <= value_p1);
	if (!(T1_)) goto LA2_;
	T1_ = (value_p1 <= s_p0.b);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1) {
	tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeVersionInfo__commands_u172)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T6_;
		if (!(pass_p1 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T6_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_712;
		T6_[1] = OS__platform_u534[((*conf_p0).target.hostOS)- 1].Field0;
		T6_[2] = CPU__platform_u740[((*conf_p0).target.hostCPU)- 1].Field0;
		T6_[3] = TM__brsa2DgNdQAKzy1F0pSZlA_714;
		colontmpD_ = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_710, T6_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		msgWriteln__msgs_u737(conf_p0, colontmpD_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		msgWriteln__msgs_u737(conf_p0, TM__brsa2DgNdQAKzy1F0pSZlA_716, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		msgWriteln__msgs_u737(conf_p0, TM__brsa2DgNdQAKzy1F0pSZlA_718, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		msgQuit__msgs_u479(((NI8)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeAdvancedUsage__commands_u158)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T6_;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T7_;
		if (!(pass_p1 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_.len = 0; T6_.p = NIM_NIL;
		T7_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_720;
		T7_[1] = OS__platform_u534[((*conf_p0).target.hostOS)- 1].Field0;
		T7_[2] = CPU__platform_u740[((*conf_p0).target.hostCPU)- 1].Field0;
		T7_[3] = TM__brsa2DgNdQAKzy1F0pSZlA_721;
		colontmpD_ = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_719, T7_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_ = rawNewString(colontmpD_.len + 12146);
appendString((&T6_), colontmpD_);
appendString((&T6_), TM__brsa2DgNdQAKzy1F0pSZlA_723);
		colontmpD__2 = T6_;
		msgWriteln__msgs_u737(conf_p0, colontmpD__2, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		msgQuit__msgs_u479(((NI8)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeFullhelp__commands_u165)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T6_;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T7_;
		if (!(pass_p1 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_.len = 0; T6_.p = NIM_NIL;
		T7_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_725;
		T7_[1] = OS__platform_u534[((*conf_p0).target.hostOS)- 1].Field0;
		T7_[2] = CPU__platform_u740[((*conf_p0).target.hostCPU)- 1].Field0;
		T7_[3] = TM__brsa2DgNdQAKzy1F0pSZlA_726;
		colontmpD_ = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_724, T7_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_ = rawNewString(colontmpD_.len + 14225);
appendString((&T6_), colontmpD_);
appendString((&T6_), TM__brsa2DgNdQAKzy1F0pSZlA_728);
		colontmpD__2 = T6_;
		msgWriteln__msgs_u737(conf_p0, colontmpD__2, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		msgQuit__msgs_u479(((NI8)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getCommandLineDesc__commands_u147)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 T2_;
	tyArray__Seu7uK9aaOSN0BK3EAjjSHw T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	T3_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_730;
	T3_[1] = OS__platform_u534[((*conf_p0).target.hostOS)- 1].Field0;
	T3_[2] = CPU__platform_u740[((*conf_p0).target.hostCPU)- 1].Field0;
	T3_[3] = TM__brsa2DgNdQAKzy1F0pSZlA_731;
	colontmpD_ = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_729, T3_, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + 2079);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__brsa2DgNdQAKzy1F0pSZlA_733);
	result = T2_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, helpOnError__commands_u150)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		if (!(pass_p1 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = getCommandLineDesc__commands_u147(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		msgWriteln__msgs_u737(conf_p0, colontmpD_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		msgQuit__msgs_u479(((NI8)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeAbsolute__commands_u1128)(NimStringV2 s_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = nosisAbsolute(s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T4_) goto LA5_;
		result = normalizePath__pureZpathnorm_u150(s_p0, 47);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA5_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD_ = nosgetCurrentDir();
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		colontmpD__2 = slash___stdZprivateZospaths2_u91(colontmpD_, s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		result = normalizePath__pureZpathnorm_u150(colontmpD__2, 47);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, newLineInfo__msgs_u436)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NI line_p2, NI col_p3) {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA result;
	NI32 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
	T1_ = (NI32)0;
	T1_ = fileInfoIdx__msgs_u404(conf_p0, filename_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newLineInfo__msgs_u419(T1_, line_p2, col_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setTrackingInfo__commands_u1131)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 dirty_p1, NimStringV2 file_p2, NimStringV2 line_p3, NimStringV2 column_p4, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p5) {
	NimStringV2 a_1;
	NI ln_1;
	NI col_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	a_1.len = 0; a_1.p = NIM_NIL;
	ln_1 = ((NI)0);
	col_1 = ((NI)0);
	{
		NI T4_;
		NimStringV2 colontmpD_;
		T4_ = (NI)0;
		T4_ = parseInt__pureZparseutils_u981(line_p3, (&ln_1), ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_ <= ((NI)0))) goto LA5_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_757, line_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		liMessage__msgs_u1227(conf_p0, info_p5, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_758), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		NI T12_;
		NimStringV2 colontmpD__2;
		T12_ = (NI)0;
		T12_ = parseInt__pureZparseutils_u981(column_p4, (&col_1), ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T12_ <= ((NI)0))) goto LA13_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_759, column_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		liMessage__msgs_u1227(conf_p0, info_p5, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_760), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			LA15_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	a_1 = makeAbsolute__commands_u1128(file_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T22_;
		if (!(dirty_p1.len == 0)) goto LA20_;
		nimZeroMem((void*)(&T22_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
		T22_ = newLineInfo__msgs_u436(conf_p0, a_1, ln_1, col_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*conf_p0).m.trackPos = T22_;
	}
	goto LA18_;
LA20_: ;
	{
		NI32 dirtyOriginalIdx_1;
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T31_;
		dirtyOriginalIdx_1 = fileInfoIdx__msgs_u404(conf_p0, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 colontmpD__3;
			if (!(((NI32)0) <= dirtyOriginalIdx_1)) goto LA26_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__3 = makeAbsolute__commands_u1128(dirty_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			setDirtyFile__msgs_u632(conf_p0, dirtyOriginalIdx_1, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			{
				LA28_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA26_: ;
		nimZeroMem((void*)(&T31_), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
		T31_ = newLineInfo__msgs_u419(dirtyOriginalIdx_1, ln_1, col_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*conf_p0).m.trackPos = T31_;
	}
LA18_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(a_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, track__commands_u1150)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 arg_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ a_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	a_1.len = 0; a_1.p = NIM_NIL;
	a_1 = nsuSplitChar(arg_p1, 44, ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T4_;
		T4_ = a_1.len;
		if (!!((T4_ == ((NI)3)))) goto LA5_;
		liMessage__msgs_u1227(conf_p0, info_p2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__brsa2DgNdQAKzy1F0pSZlA_754, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_755), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	setTrackingInfo__commands_u1131(conf_p0, TM__brsa2DgNdQAKzy1F0pSZlA_761, a_1.p->data[((NI)0)], a_1.p->data[((NI)1)], a_1.p->data[((NI)2)], info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u5504(a_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackDirty__commands_u1142)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 arg_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ a_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	a_1.len = 0; a_1.p = NIM_NIL;
	a_1 = nsuSplitChar(arg_p1, 44, ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T4_;
		T4_ = a_1.len;
		if (!!((T4_ == ((NI)4)))) goto LA5_;
		liMessage__msgs_u1227(conf_p0, info_p2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__brsa2DgNdQAKzy1F0pSZlA_763, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_764), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	setTrackingInfo__commands_u1131(conf_p0, a_1.p->data[((NI)0)], a_1.p->data[((NI)1)], a_1.p->data[((NI)2)], a_1.p->data[((NI)3)], info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u5504(a_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, trackIde__commands_u1158)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng cmd_p1, NimStringV2 arg_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ a_1;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	a_1.len = 0; a_1.p = NIM_NIL;
	a_1 = nsuSplitChar(arg_p2, 44, ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = a_1.len;
	switch (T2_) {
	case ((NI)4):
	{
		setTrackingInfo__commands_u1131(conf_p0, a_1.p->data[((NI)0)], a_1.p->data[((NI)1)], a_1.p->data[((NI)2)], a_1.p->data[((NI)3)], info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((NI)3):
	{
		setTrackingInfo__commands_u1131(conf_p0, TM__brsa2DgNdQAKzy1F0pSZlA_765, a_1.p->data[((NI)0)], a_1.p->data[((NI)1)], a_1.p->data[((NI)2)], info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		liMessage__msgs_u1227(conf_p0, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__brsa2DgNdQAKzy1F0pSZlA_767, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_768), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	(*conf_p0).ideCmd = cmd_p1;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u5504(a_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, dynlibOverride__commands_u1167)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2 arg_p2, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(pass_p3 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p3 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA3_;
		expectArg__commands_u278(conf_p0, switch_p1, arg_p2, pass_p3, info_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		inclDynlibOverride__options_u4263(conf_p0, arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, handleStdinInput__commands_u1179)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___system_u2697((*conf_p0).stdinFile);
	eqsink___system_u2700((&(*conf_p0).projectName), colontmpD_);
	(*conf_p0).projectIsStdin = NIM_TRUE;
	colontmpD__2 = eqdup___system_u2697((*conf_p0).projectName);
	eqsink___system_u2700((&(*conf_p0).projectFull), colontmpD__2);
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = nosgetCurrentDir();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1_); goto BeforeRet_;}
	eqsink___system_u2700((&(*conf_p0).projectPath), T1_);
	{
		NIM_BOOL T4_;
		NimStringV2 T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmpty__pathutils_u139((*conf_p0).outDir);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T4_) goto LA5_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = getNimcacheDir__options_u3737(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto BeforeRet_;}
		eqsink___system_u2700((&(*conf_p0).outDir), T7_);
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_u1361)(NimStringV2 switch_p0, NimStringV2 arg_p1, tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p4) {
	NimStringV2 key_1;
	NimStringV2 val_1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	key_1.len = 0; key_1.p = NIM_NIL;
	val_1.len = 0; val_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	key_1 = TM__brsa2DgNdQAKzy1F0pSZlA_82;
	val_1 = TM__brsa2DgNdQAKzy1F0pSZlA_83;
	colontmpD_ = nsuNormalize(switch_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch (hashString(colontmpD_) & 255) {
	case 0: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_187)) goto LA46_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_318)) goto LA102_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_400)) goto LA144_;
break;
	case 1: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_149)) goto LA28_;
break;
	case 2: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_383)) goto LA135_;
break;
	case 3: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_173)) goto LA39_;
break;
	case 7: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_357)) goto LA122_;
break;
	case 11: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_123)) goto LA17_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_179)) goto LA42_;
break;
	case 14: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_201)) goto LA52_;
break;
	case 16: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_155)) goto LA30_;
break;
	case 17: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_231)) goto LA65_;
break;
	case 21: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_363)) goto LA125_;
break;
	case 22: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_161)) goto LA33_;
break;
	case 24: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_373)) goto LA130_;
break;
	case 25: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_151)) goto LA29_;
break;
	case 27: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_157)) goto LA31_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_321)) goto LA104_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_355)) goto LA121_;
break;
	case 28: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_233)) goto LA66_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_296)) goto LA93_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_410)) goto LA145_;
break;
	case 29: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_259)) goto LA77_;
break;
	case 32: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_153)) goto LA29_;
break;
	case 34: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_263)) goto LA79_;
break;
	case 36: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_109)) goto LA12_;
break;
	case 37: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_221)) goto LA61_;
break;
	case 41: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_251)) goto LA73_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_289)) goto LA91_;
break;
	case 43: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_223)) goto LA62_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_327)) goto LA107_;
break;
	case 44: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_308)) goto LA98_;
break;
	case 47: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_175)) goto LA40_;
break;
	case 48: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_91)) goto LA4_;
break;
	case 53: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_367)) goto LA127_;
break;
	case 55: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_261)) goto LA78_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_379)) goto LA133_;
break;
	case 56: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_203)) goto LA53_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_393)) goto LA140_;
break;
	case 59: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_365)) goto LA126_;
break;
	case 61: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_132)) goto LA21_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_199)) goto LA51_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_335)) goto LA111_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_395)) goto LA141_;
break;
	case 63: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_361)) goto LA124_;
break;
	case 66: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_217)) goto LA59_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_277)) goto LA86_;
break;
	case 67: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_247)) goto LA71_;
break;
	case 70: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_283)) goto LA89_;
break;
	case 71: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_265)) goto LA80_;
break;
	case 72: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_139)) goto LA24_;
break;
	case 73: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_125)) goto LA17_;
break;
	case 76: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_243)) goto LA69_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_349)) goto LA118_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_397)) goto LA142_;
break;
	case 78: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_225)) goto LA63_;
break;
	case 79: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_298)) goto LA93_;
break;
	case 82: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_126)) goto LA18_;
break;
	case 83: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_302)) goto LA95_;
break;
	case 85: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_275)) goto LA85_;
break;
	case 86: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_271)) goto LA83_;
break;
	case 88: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_345)) goto LA116_;
break;
	case 89: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_135)) goto LA22_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_391)) goto LA139_;
break;
	case 90: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_353)) goto LA120_;
break;
	case 94: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_294)) goto LA93_;
break;
	case 103: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_95)) goto LA6_;
break;
	case 105: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_268)) goto LA82_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_351)) goto LA119_;
break;
	case 108: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_273)) goto LA84_;
break;
	case 109: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_137)) goto LA23_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_241)) goto LA68_;
break;
	case 110: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_287)) goto LA90_;
break;
	case 115: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_245)) goto LA70_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_323)) goto LA105_;
break;
	case 118: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_117)) goto LA15_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_406)) goto LA145_;
break;
	case 125: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_209)) goto LA56_;
break;
	case 127: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_103)) goto LA9_;
break;
	case 129: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_279)) goto LA87_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_389)) goto LA138_;
break;
	case 130: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_195)) goto LA49_;
break;
	case 132: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_119)) goto LA16_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_347)) goto LA117_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_377)) goto LA132_;
break;
	case 133: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_121)) goto LA16_;
break;
	case 134: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_207)) goto LA55_;
break;
	case 136: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_165)) goto LA35_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_227)) goto LA63_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_304)) goto LA96_;
break;
	case 138: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_105)) goto LA10_;
break;
	case 140: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_215)) goto LA59_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_381)) goto LA134_;
break;
	case 144: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_101)) goto LA9_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_185)) goto LA45_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_257)) goto LA76_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_312)) goto LA99_;
break;
	case 145: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_402)) goto LA145_;
break;
	case 147: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_414)) goto LA146_;
break;
	case 148: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_329)) goto LA108_;
break;
	case 150: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_249)) goto LA72_;
break;
	case 154: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_159)) goto LA32_;
break;
	case 155: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_115)) goto LA14_;
break;
	case 159: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_169)) goto LA37_;
break;
	case 163: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_163)) goto LA34_;
break;
	case 168: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_385)) goto LA136_;
break;
	case 173: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_147)) goto LA27_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_387)) goto LA137_;
break;
	case 174: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_219)) goto LA60_;
break;
	case 175: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_369)) goto LA128_;
break;
	case 178: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_253)) goto LA74_;
break;
	case 179: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_167)) goto LA36_;
break;
	case 180: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_111)) goto LA13_;
break;
	case 181: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_87)) goto LA3_;
break;
	case 183: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_325)) goto LA106_;
break;
	case 184: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_97)) goto LA7_;
break;
	case 185: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_331)) goto LA109_;
break;
	case 186: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_141)) goto LA25_;
break;
	case 190: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_130)) goto LA20_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_213)) goto LA58_;
break;
	case 191: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_333)) goto LA110_;
break;
	case 192: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_337)) goto LA112_;
break;
	case 194: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_314)) goto LA100_;
break;
	case 196: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_181)) goto LA43_;
break;
	case 197: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_229)) goto LA64_;
break;
	case 201: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_359)) goto LA123_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_375)) goto LA131_;
break;
	case 202: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_319)) goto LA103_;
break;
	case 207: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_235)) goto LA66_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_310)) goto LA98_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_404)) goto LA145_;
break;
	case 209: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_113)) goto LA14_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_171)) goto LA38_;
break;
	case 210: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_267)) goto LA81_;
break;
	case 211: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_145)) goto LA26_;
break;
	case 212: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_408)) goto LA145_;
break;
	case 213: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_285)) goto LA89_;
break;
	case 218: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_193)) goto LA48_;
break;
	case 219: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_306)) goto LA97_;
break;
	case 225: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_191)) goto LA47_;
break;
	case 226: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_269)) goto LA82_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_399)) goto LA143_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_412)) goto LA145_;
break;
	case 229: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_189)) goto LA46_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_237)) goto LA67_;
break;
	case 230: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_371)) goto LA129_;
break;
	case 233: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_205)) goto LA54_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_300)) goto LA94_;
break;
	case 234: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_292)) goto LA92_;
break;
	case 236: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_255)) goto LA75_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_290)) goto LA92_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_316)) goto LA101_;
break;
	case 238: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_143)) goto LA25_;
break;
	case 239: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_85)) goto LA2_;
break;
	case 240: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_128)) goto LA19_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_343)) goto LA115_;
break;
	case 241: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_177)) goto LA41_;
break;
	case 243: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_99)) goto LA8_;
break;
	case 244: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_107)) goto LA11_;
break;
	case 248: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_239)) goto LA67_;
break;
	case 249: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_89)) goto LA3_;
break;
	case 250: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_197)) goto LA50_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_211)) goto LA57_;
break;
	case 251: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_183)) goto LA44_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_281)) goto LA88_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_339)) goto LA113_;
break;
	case 252: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_134)) goto LA22_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_341)) goto LA114_;
break;
	case 253: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_93)) goto LA5_;
break;
	}
	goto LA147_;
	LA2_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*conf_p4).projectIsCmd = NIM_TRUE;
		eqcopy___system_u2694((&(*conf_p4).cmdInput), arg_p1);
		{
			if (!((*conf_p4).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)0))) goto LA152_;
			eqsink___system_u2700((&(*conf_p4).command), TM__brsa2DgNdQAKzy1F0pSZlA_423);
			setCmd__commands_u1211(conf_p4, ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)13));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			(*conf_p4).implicitCmd = NIM_TRUE;
		}
LA152_: ;
	}
	goto LA148_;
	LA3_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 path_1;
			NimStringV2 pl_1;
			path_1.len = 0; path_1.p = NIM_NIL;
			pl_1.len = 0; pl_1.p = NIM_NIL;
			pl_1 = nsuToLowerAsciiStr(arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA156_;
			{
				NIM_BOOL T159_;
				T159_ = (NIM_BOOL)0;
				T159_ = contains__pureZstrutils_u1833(pl_1, TM__brsa2DgNdQAKzy1F0pSZlA_425);
				if (NIM_UNLIKELY(*nimErr_)) goto LA156_;
				if (T159_) goto LA160_;
				T159_ = contains__pureZstrutils_u1833(pl_1, TM__brsa2DgNdQAKzy1F0pSZlA_427);
				if (NIM_UNLIKELY(*nimErr_)) goto LA156_;
LA160_: ;
				if (!T159_) goto LA161_;
				{
					NI i_1;
					NI colontmp_;
					NI T164_;
					NI res_1;
					i_1 = (NI)0;
					colontmp_ = (NI)0;
					T164_ = (*conf_p4).nimblePaths.len;
					colontmp_ = (NI)(T164_ - ((NI)1));
					res_1 = colontmp_;
					{
						while (1) {
							NimStringV2 nimblePath_1;
							NimStringV2 colontmpD__2;
							NimStringV2 colontmpD__3;
							tyArray__Seu7uK9aaOSN0BK3EAjjSHw T168_;
							NimStringV2 T169_;
							NimStringV2 T170_;
							if (!(((NI)0) <= res_1)) goto LA166;
							nimblePath_1.len = 0; nimblePath_1.p = NIM_NIL;
							colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
							colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
							i_1 = ((NI) (res_1));
							nimblePath_1 = removeTrailingDirSep__options_u3681((*conf_p4).nimblePaths.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA167_;
							T168_[0] = TM__brsa2DgNdQAKzy1F0pSZlA_428;
							T168_[1] = nimblePath_1;
							T168_[2] = TM__brsa2DgNdQAKzy1F0pSZlA_430;
							T168_[3] = nimblePath_1;
							T169_.len = 0; T169_.p = NIM_NIL;
							T169_ = nsuFormatOpenArray(arg_p1, T168_, 4);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T169_); goto LA167_;}
							eqsink___system_u2700((&path_1), T169_);
							T170_.len = 0; T170_.p = NIM_NIL;
							{
								if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA173_;
								colontmpD__2 = processCfgPath__commands_u1115(conf_p4, path_1, info_p3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA175_;
								T170_ = colontmpD__2;
								{
									LA175_:;
								}
								{
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA167_;
							}
							goto LA171_;
LA173_: ;
							{
								colontmpD__3 = processPath__commands_u1104(conf_p4, path_1, info_p3, NIM_FALSE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA179_;
								T170_ = colontmpD__3;
								{
									LA179_:;
								}
								{
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA167_;
							}
LA171_: ;
							addPath__nimblecmd_u13(conf_p4, T170_, info_p3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA167_;
							res_1 -= ((NI)1);
							{
								LA167_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__3);
								eqdestroy___system_u2691(colontmpD__2);
								eqdestroy___system_u2691(nimblePath_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA156_;
						} LA166: ;
					}
				}
			}
			goto LA157_;
LA161_: ;
			{
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				NimStringV2 T186_;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				eqcopy___system_u2694((&path_1), arg_p1);
				T186_.len = 0; T186_.p = NIM_NIL;
				{
					if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA189_;
					colontmpD__4 = processCfgPath__commands_u1115(conf_p4, path_1, info_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA191_;
					T186_ = colontmpD__4;
					{
						LA191_:;
					}
					{
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA185_;
				}
				goto LA187_;
LA189_: ;
				{
					colontmpD__5 = processPath__commands_u1104(conf_p4, path_1, info_p3, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA195_;
					T186_ = colontmpD__5;
					{
						LA195_:;
					}
					{
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA185_;
				}
LA187_: ;
				addPath__nimblecmd_u13(conf_p4, T186_, info_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA185_;
				{
					LA185_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA156_;
			}
LA157_: ;
			{
				LA156_:;
			}
			{
				eqdestroy___system_u2691(pl_1);
				eqdestroy___system_u2691(path_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
	goto LA148_;
	LA4_: ;
	{
		{
			NIM_BOOL T205_;
			NimStringV2 path_2;
			NimStringV2 nimbleDir_1;
			T205_ = (NIM_BOOL)0;
			T205_ = (pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2));
			if (!(T205_)) goto LA206_;
			T205_ = !((((*conf_p4).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)42)))&63U)))!=0));
LA206_: ;
			if (!T205_) goto LA207_;
			path_2.len = 0; path_2.p = NIM_NIL;
			nimbleDir_1.len = 0; nimbleDir_1.p = NIM_NIL;
			expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA209_;
			path_2 = processPath__commands_u1104(conf_p4, arg_p1, info_p3, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA209_;
			nimbleDir_1 = getEnv__stdZenvvars_u16(TM__brsa2DgNdQAKzy1F0pSZlA_440, TM__brsa2DgNdQAKzy1F0pSZlA_441);
			if (NIM_UNLIKELY(*nimErr_)) goto LA209_;
			{
				NIM_BOOL T212_;
				NIM_BOOL T213_;
				NimStringV2 T217_;
				NimStringV2 T218_;
				T212_ = (NIM_BOOL)0;
				T213_ = (NIM_BOOL)0;
				T213_ = isEmpty__pathutils_u139(nimbleDir_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA209_;
				T212_ = !(T213_);
				if (!(T212_)) goto LA214_;
				T212_ = (pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2));
LA214_: ;
				if (!T212_) goto LA215_;
				T217_.len = 0; T217_.p = NIM_NIL;
				T217_ = slash___pathutils_u166(nimbleDir_1, TM__brsa2DgNdQAKzy1F0pSZlA_443);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T217_); goto LA209_;}
				eqsink___system_u2700((&path_2), T217_);
				nimblePath__nimblecmd_u2257(conf_p4, path_2, info_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA209_;
				T218_.len = 0; T218_.p = NIM_NIL;
				T218_ = slash___pathutils_u166(nimbleDir_1, TM__brsa2DgNdQAKzy1F0pSZlA_445);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T218_); goto LA209_;}
				eqsink___system_u2700((&path_2), T218_);
			}
LA215_: ;
			nimblePath__nimblecmd_u2257(conf_p4, path_2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA209_;
			{
				LA209_:;
			}
			{
				eqdestroy___system_u2691(nimbleDir_1);
				eqdestroy___system_u2691(path_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA207_: ;
	}
	goto LA148_;
	LA5_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		disableNimblePath__options_u3684(conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA6_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		clearNimblePath__options_u3698(conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA7_: ;
	{
		NimStringV2 path_3;
		NI posX60gensym119__1;
		NI posX60gensym123__1;
		path_3.len = 0; path_3.p = NIM_NIL;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		path_3 = processPath__commands_u1104(conf_p4, arg_p1, info_p3, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		posX60gensym119__1 = ((NI)0);
		{
			NI iX60gensym119__1;
			NI colontmp__2;
			NI T226_;
			NI i_2;
			iX60gensym119__1 = (NI)0;
			colontmp__2 = (NI)0;
			T226_ = (*conf_p4).searchPaths.len;
			colontmp__2 = T226_;
			i_2 = ((NI)0);
			{
				while (1) {
					NimStringV2 it_1;
					if (!(i_2 < colontmp__2)) goto LA228;
					it_1.len = 0; it_1.p = NIM_NIL;
					iX60gensym119__1 = i_2;
					eqcopy___system_u2694((&it_1), (*conf_p4).searchPaths.p->data[iX60gensym119__1]);
					{
						NIM_BOOL T231_;
						T231_ = (NIM_BOOL)0;
						T231_ = eqeq___options_u3652(it_1, path_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
						if (!!(T231_)) goto LA232_;
						{
							NimStringV2 T238_;
							if (!!((posX60gensym119__1 == iX60gensym119__1))) goto LA236_;
							T238_.len = 0; T238_.p = NIM_NIL;
							T238_ = (*conf_p4).searchPaths.p->data[iX60gensym119__1];
							eqwasMoved___system_u2688((&(*conf_p4).searchPaths.p->data[iX60gensym119__1]));
							eqsink___system_u2700((&(*conf_p4).searchPaths.p->data[posX60gensym119__1]), T238_);
						}
LA236_: ;
						posX60gensym119__1 += ((NI)1);
					}
LA232_: ;
					i_2 += ((NI)1);
					eqdestroy___system_u2691(it_1);
				} LA228: ;
			}
		}
		setLen__options_u1391((&(*conf_p4).searchPaths), (posX60gensym119__1));
		posX60gensym123__1 = ((NI)0);
		{
			NI iX60gensym123__1;
			NI colontmp__3;
			NI T240_;
			NI i_3;
			iX60gensym123__1 = (NI)0;
			colontmp__3 = (NI)0;
			T240_ = (*conf_p4).lazyPaths.len;
			colontmp__3 = T240_;
			i_3 = ((NI)0);
			{
				while (1) {
					NimStringV2 it_2;
					if (!(i_3 < colontmp__3)) goto LA242;
					it_2.len = 0; it_2.p = NIM_NIL;
					iX60gensym123__1 = i_3;
					eqcopy___system_u2694((&it_2), (*conf_p4).lazyPaths.p->data[iX60gensym123__1]);
					{
						NIM_BOOL T245_;
						T245_ = (NIM_BOOL)0;
						T245_ = eqeq___options_u3652(it_2, path_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
						if (!!(T245_)) goto LA246_;
						{
							NimStringV2 T252_;
							if (!!((posX60gensym123__1 == iX60gensym123__1))) goto LA250_;
							T252_.len = 0; T252_.p = NIM_NIL;
							T252_ = (*conf_p4).lazyPaths.p->data[iX60gensym123__1];
							eqwasMoved___system_u2688((&(*conf_p4).lazyPaths.p->data[iX60gensym123__1]));
							eqsink___system_u2700((&(*conf_p4).lazyPaths.p->data[posX60gensym123__1]), T252_);
						}
LA250_: ;
						posX60gensym123__1 += ((NI)1);
					}
LA246_: ;
					i_3 += ((NI)1);
					eqdestroy___system_u2691(it_2);
				} LA242: ;
			}
		}
		setLen__options_u1391((&(*conf_p4).lazyPaths), (posX60gensym123__1));
		{
			LA224_:;
		}
		{
			eqdestroy___system_u2691(path_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA8_: ;
	{
		NimStringV2 arg_2;
		NimStringV2 colontmpD__6;
		NimStringV2 T264_;
		arg_2.len = 0; arg_2.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
		eqcopy___system_u2694((&arg_2), arg_p1);
		{
			NIM_BOOL T259_;
			NimStringV2 T263_;
			T259_ = (NIM_BOOL)0;
			T259_ = ((*conf_p4).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)2));
			if (!(T259_)) goto LA260_;
			T259_ = NIM_TRUE;
LA260_: ;
			if (!T259_) goto LA261_;
			T263_.len = 0; T263_.p = NIM_NIL;
			T263_ = nsuReplaceChar(arg_2, 92, 47);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T263_); goto LA256_;}
			eqsink___system_u2700((&arg_2), T263_);
		}
LA261_: ;
		colontmpD__6 = pathRelativeToConfig__commands_u1349(arg_2, pass_p2, conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
		T264_.len = 0; T264_.p = NIM_NIL;
		T264_ = processPath__commands_u1104(conf_p4, colontmpD__6, info_p3, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T264_); goto LA256_;}
		eqsink___system_u2700((&(*conf_p4).nimcacheDir), T264_);
		{
			LA256_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(arg_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA9_: ;
	{
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg f_1;
		NimStringV2 colontmpD__7;
		NimStringV2 T269_;
		NimStringV2 T270_;
		nimZeroMem((void*)(&f_1), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA268_;
		colontmpD__7 = processPath__commands_u1104(conf_p4, arg_p1, info_p3, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA268_;
		nossplitFile(colontmpD__7, (&f_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA268_;
		T269_.len = 0; T269_.p = NIM_NIL;
		T269_ = rawNewString(f_1.Field1.len + f_1.Field2.len + 0);
appendString((&T269_), f_1.Field1);
appendString((&T269_), f_1.Field2);
		eqsink___system_u2700((&(*conf_p4).outFile), T269_);
		T270_.len = 0; T270_.p = NIM_NIL;
		T270_ = toAbsoluteDir__pathutils_u117(f_1.Field0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T270_); goto LA268_;}
		eqsink___system_u2700((&(*conf_p4).outDir), T270_);
		{
			LA268_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___pureZos_u236((&f_1));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA10_: ;
	{
		NimStringV2 T274_;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T274_.len = 0; T274_.p = NIM_NIL;
		T274_ = processPath__commands_u1104(conf_p4, arg_p1, info_p3, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T274_); goto LA1_;}
		eqsink___system_u2700((&(*conf_p4).outDir), T274_);
	}
	goto LA148_;
	LA11_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 16384, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA12_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqcopy___system_u2694((&(*conf_p4).docSeeSrcUrl), arg_p1);
	}
	goto LA148_;
	LA13_: ;
	{
		NimStringV2 T278_;
		T278_.len = 0; T278_.p = NIM_NIL;
		{
			if (!(arg_p1.len == ((NI)0))) goto LA281_;
			eqsink___system_u2700((&(*conf_p4).docRoot), TM__brsa2DgNdQAKzy1F0pSZlA_458);
		}
		goto LA279_;
LA281_: ;
		{
			eqcopy___system_u2694((&(*conf_p4).docRoot), arg_p1);
		}
LA279_: ;
	}
	goto LA148_;
	LA14_: ;
	{
		NimStringV2 colontmpD__8;
		tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend_1;
		tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw T286_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__8 = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA285_;
		T286_ = (tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)0;
		backend_1 = parseEnum__commands_u1465(colontmpD__8, T286_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA285_;
		{
			tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw T289_;
			NimStringV2 colontmpD__9;
			T289_ = (tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)0;
			if (!(backend_1 == T289_)) goto LA290_;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__9 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_460, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA292_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__9, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_461), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA292_;
			{
				LA292_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__9);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA285_;
		}
LA290_: ;
		{
			if (!(backend_1 == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA297_;
			(*conf_p4).globalOptions = ((*conf_p4).globalOptions & ~ 167772160);
			{
				if (!(((*conf_p4).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)13)))&63U)))!=0)) goto LA301_;
				defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_463, TM__brsa2DgNdQAKzy1F0pSZlA_465);
				if (NIM_UNLIKELY(*nimErr_)) goto LA285_;
			}
LA301_: ;
		}
LA297_: ;
		(*conf_p4).backend = backend_1;
		{
			LA285_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA15_: ;
	{
		eqcopy___system_u2694((&(*conf_p4).docCmd), arg_p1);
	}
	goto LA148_;
	LA16_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T309_;
			T309_ = (NIM_BOOL)0;
			T309_ = contains__pureZstrutils_u1837(arg_p1, TM__brsa2DgNdQAKzy1F0pSZlA_466);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T309_) goto LA310_;
			splitSwitch__commands_u196(conf_p4, arg_p1, (&key_1), (&val_1), pass_p2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			specialDefine__commands_u1217(conf_p4, key_1, pass_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, key_1, val_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA307_;
LA310_: ;
		{
			specialDefine__commands_u1217(conf_p4, arg_p1, pass_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, arg_p1, TM__brsa2DgNdQAKzy1F0pSZlA_486);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA307_: ;
	}
	goto LA148_;
	LA17_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		undefSymbol__condsyms_u8((*conf_p4).symbols, arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA18_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA317_;
			processCompile__commands_u503(conf_p4, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA317_: ;
	}
	goto LA148_;
	LA19_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA322_;
			addExternalFileToLink__extccomp_u977(conf_p4, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA322_: ;
	}
	goto LA148_;
	LA20_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 64, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA21_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(4294967296), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA22_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 16, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA23_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 32, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA24_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 8388608, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA25_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 2, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA26_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(275414777856), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA27_: ;
	{
		warningDeprecated__msgs_u1572(conf_p4, info_p3, TM__brsa2DgNdQAKzy1F0pSZlA_490);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		processMemoryManagementOption__commands_u1323(switch_p0, arg_p1, pass_p2, info_p3, conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA28_: ;
	{
		processMemoryManagementOption__commands_u1323(switch_p0, arg_p1, pass_p2, info_p3, conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA29_: ;
	{
		{
			NIM_BOOL T336_;
			T336_ = (NIM_BOOL)0;
			T336_ = processOnOffSwitchOrList__commands_u243(conf_p4, 8192, arg_p1, pass_p2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T336_) goto LA337_;
			listWarnings__msgs_u1646(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA337_: ;
	}
	goto LA148_;
	LA30_: ;
	{
		processSpecificNote__commands_u290(arg_p1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)124), pass_p2, info_p3, switch_p0, conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA31_: ;
	{
		processSpecificNote__commands_u290(arg_p1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)125), pass_p2, info_p3, switch_p0, conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA32_: ;
	{
		processSpecificNote__commands_u290(arg_p1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)126), pass_p2, info_p3, switch_p0, conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA33_: ;
	{
		processSpecificNote__commands_u290(arg_p1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)127), pass_p2, info_p3, switch_p0, conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA34_: ;
	{
		{
			NIM_BOOL T346_;
			T346_ = (NIM_BOOL)0;
			T346_ = processOnOffSwitchOrList__commands_u243(conf_p4, 16384, arg_p1, pass_p2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T346_) goto LA347_;
			listHints__msgs_u1668(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA347_: ;
	}
	goto LA148_;
	LA35_: ;
	{
		{
			if (!((*conf_p4).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA352_;
		}
		goto LA350_;
LA352_: ;
		{
			processOnOffSwitchG__commands_u260(conf_p4, 134217728, arg_p1, pass_p2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA350_: ;
	}
	goto LA148_;
	LA36_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 131072, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA37_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 262144, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA38_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(68719476736), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA39_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 524288, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA40_: ;
	{
		NimStringV2 colontmpD__10;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__10 = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA360_;
		if (eqStrings(colontmpD__10, TM__brsa2DgNdQAKzy1F0pSZlA_602)) goto LA361_;
		if (eqStrings(colontmpD__10, TM__brsa2DgNdQAKzy1F0pSZlA_604)) goto LA361_;
		if (eqStrings(colontmpD__10, TM__brsa2DgNdQAKzy1F0pSZlA_606)) goto LA361_;
		if (eqStrings(colontmpD__10, TM__brsa2DgNdQAKzy1F0pSZlA_607)) goto LA362_;
		goto LA363_;
		LA361_: ;
		{
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)6))) & 63);
			(*conf_p4).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12))) & 31);
		}
		goto LA364_;
		LA362_: ;
		{
			(*conf_p4).globalOptions &= ~(((NU64)1) << (((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)6))) & 63));
		}
		goto LA364_;
		LA363_: ;
		{
			NimStringV2 colontmpD__11;
			NimStringV2 T369_;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			T369_.len = 0; T369_.p = NIM_NIL;
			T369_ = rawNewString(arg_p1.len + 37);
appendString((&T369_), TM__brsa2DgNdQAKzy1F0pSZlA_609);
appendString((&T369_), arg_p1);
			colontmpD__11 = T369_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__11, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_610), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA368_;
			{
				LA368_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__11);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA360_;
		}
LA364_: ;
		{
			LA360_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__10);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA41_: ;
	{
		NimStringV2 colontmpD__12;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__12 = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA375_;
		if (eqStrings(colontmpD__12, TM__brsa2DgNdQAKzy1F0pSZlA_612)) goto LA376_;
		if (eqStrings(colontmpD__12, TM__brsa2DgNdQAKzy1F0pSZlA_613)) goto LA377_;
		goto LA378_;
		LA376_: ;
		{
			(*conf_p4).globalOptions &= ~(((NU64)1) << (((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)58))) & 63));
		}
		goto LA379_;
		LA377_: ;
		{
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)58))) & 63);
		}
		goto LA379_;
		LA378_: ;
		{
			NimStringV2 colontmpD__13;
			NimStringV2 T384_;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			T384_.len = 0; T384_.p = NIM_NIL;
			T384_ = rawNewString(arg_p1.len + 27);
appendString((&T384_), TM__brsa2DgNdQAKzy1F0pSZlA_615);
appendString((&T384_), arg_p1);
			colontmpD__13 = T384_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__13, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_616), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA383_;
			{
				LA383_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__13);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA375_;
		}
LA379_: ;
		{
			LA375_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA42_: ;
	{
		(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)6))) & 63);
		(*conf_p4).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12))) & 31);
	}
	goto LA148_;
	LA43_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 2097152, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(((*conf_p4).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)21)))&31U)))!=0)) goto LA393_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_617, TM__brsa2DgNdQAKzy1F0pSZlA_618);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA391_;
LA393_: ;
		{
			undefSymbol__condsyms_u8((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_619);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA391_: ;
	}
	goto LA148_;
	LA44_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 16777216, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(((*conf_p4).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)24)))&31U)))!=0)) goto LA399_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_620, TM__brsa2DgNdQAKzy1F0pSZlA_621);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA397_;
LA399_: ;
		{
			undefSymbol__condsyms_u8((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_622);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA397_: ;
	}
	goto LA148_;
	LA45_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(8796093022208), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T405_;
			T405_ = (NIM_BOOL)0;
			T405_ = hcrOn__options_u629(conf_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T405_) goto LA406_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_623, TM__brsa2DgNdQAKzy1F0pSZlA_624);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_626, TM__brsa2DgNdQAKzy1F0pSZlA_627);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				NIM_BOOL T410_;
				T410_ = (NIM_BOOL)0;
				T410_ = isVSCompatible__extccomp_u696(conf_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T410_) goto LA411_;
				addCompileOptionCmd__extccomp_u915(conf_p4, TM__brsa2DgNdQAKzy1F0pSZlA_629);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA411_: ;
		}
		goto LA403_;
LA406_: ;
		{
			undefSymbol__condsyms_u8((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_630);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			undefSymbol__condsyms_u8((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_631);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA403_: ;
	}
	goto LA148_;
	LA46_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 3518, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA47_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 384, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA48_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 256, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA49_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 128, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA50_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 2, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA51_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 4, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA52_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 8, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA53_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 16, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA54_: ;
	{
		warningDeprecated__msgs_u1572(conf_p4, info_p3, TM__brsa2DgNdQAKzy1F0pSZlA_633);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		processOnOffSwitch__commands_u225(conf_p4, 64, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA55_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 32, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA56_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 512, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA57_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 1024, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA58_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 4096, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA59_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 2048, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA60_: ;
	{
		{
			NIM_BOOL T431_;
			T431_ = (NIM_BOOL)0;
			T431_ = ((*conf_p4).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3));
			if (T431_) goto LA432_;
			T431_ = ((*conf_p4).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)13));
LA432_: ;
			if (!T431_) goto LA433_;
		}
		goto LA429_;
LA433_: ;
		{
			processOnOffSwitchG__commands_u260(conf_p4, 33554432, arg_p1, pass_p2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA429_: ;
	}
	goto LA148_;
	LA61_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 268435456, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(((*conf_p4).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)28)))&63U)))!=0)) goto LA439_;
			(*conf_p4).legacyFeatures |= ((NU8)1)<<(((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)4))) & 7);
		}
LA439_: ;
	}
	goto LA148_;
	LA62_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 4194304, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA63_: ;
	{
		NimStringV2 colontmpD__14;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		{
			NimStringV2 colontmpD__15;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T449_;
			colontmpD__14 = nsuNormalize(switch_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA443_;
			if (!eqStrings(colontmpD__14, TM__brsa2DgNdQAKzy1F0pSZlA_634)) goto LA446_;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			T449_[0] = switch_p0;
			T449_[1] = TM__brsa2DgNdQAKzy1F0pSZlA_637;
			colontmpD__15 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_636, T449_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA448_;
			warningDeprecated__msgs_u1572(conf_p4, info_p3, colontmpD__15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA448_;
			{
				LA448_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__15);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA443_;
		}
LA446_: ;
		processOnOffSwitch__commands_u225(conf_p4, 8388608, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA443_;
		{
			LA443_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__14);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA64_: ;
	{
		NimStringV2 colontmpD__16;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA455_;
		colontmpD__16 = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA455_;
		if (eqStrings(colontmpD__16, TM__brsa2DgNdQAKzy1F0pSZlA_639)) goto LA456_;
		if (eqStrings(colontmpD__16, TM__brsa2DgNdQAKzy1F0pSZlA_641)) goto LA457_;
		if (eqStrings(colontmpD__16, TM__brsa2DgNdQAKzy1F0pSZlA_642)) goto LA458_;
		goto LA459_;
		LA456_: ;
		{
			(*conf_p4).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15))) & 31);
			(*conf_p4).options &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)16))) & 31));
		}
		goto LA460_;
		LA457_: ;
		{
			(*conf_p4).options &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15))) & 31));
			(*conf_p4).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)16))) & 31);
		}
		goto LA460_;
		LA458_: ;
		{
			(*conf_p4).options &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15))) & 31));
			(*conf_p4).options &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)16))) & 31));
		}
		goto LA460_;
		LA459_: ;
		{
			NimStringV2 colontmpD__17;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			colontmpD__17 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_644, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA465_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__17, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_645), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA465_;
			{
				LA465_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__17);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA455_;
		}
LA460_: ;
		{
			LA455_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__16);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA65_: ;
	{
		NimStringV2 colontmpD__18;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		colontmpD__18 = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		if (eqStrings(colontmpD__18, TM__brsa2DgNdQAKzy1F0pSZlA_647)) goto LA472_;
		if (eqStrings(colontmpD__18, TM__brsa2DgNdQAKzy1F0pSZlA_649)) goto LA473_;
		if (eqStrings(colontmpD__18, TM__brsa2DgNdQAKzy1F0pSZlA_650)) goto LA474_;
		if (eqStrings(colontmpD__18, TM__brsa2DgNdQAKzy1F0pSZlA_652)) goto LA475_;
		goto LA476_;
		LA472_: ;
		{
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9))) & 63);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_654, TM__brsa2DgNdQAKzy1F0pSZlA_655);
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_657, TM__brsa2DgNdQAKzy1F0pSZlA_658);
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		}
		goto LA477_;
		LA473_: ;
		{
			(*conf_p4).globalOptions &= ~(((NU64)1) << (((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9))) & 63));
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_659, TM__brsa2DgNdQAKzy1F0pSZlA_660);
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_662, TM__brsa2DgNdQAKzy1F0pSZlA_663);
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		}
		goto LA477_;
		LA474_: ;
		{
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)7))) & 63);
			(*conf_p4).globalOptions &= ~(((NU64)1) << (((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9))) & 63));
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_665, TM__brsa2DgNdQAKzy1F0pSZlA_666);
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_668, TM__brsa2DgNdQAKzy1F0pSZlA_669);
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		}
		goto LA477_;
		LA475_: ;
		{
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)8))) & 63);
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)23))) & 63);
			(*conf_p4).globalOptions &= ~(((NU64)1) << (((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9))) & 63));
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_670, TM__brsa2DgNdQAKzy1F0pSZlA_671);
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_672, TM__brsa2DgNdQAKzy1F0pSZlA_673);
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		}
		goto LA477_;
		LA476_: ;
		{
			NimStringV2 colontmpD__19;
			colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
			colontmpD__19 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_675, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA483_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__19, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_676), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA483_;
			{
				LA483_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__19);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		}
LA477_: ;
		{
			LA471_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__18);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA66_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA491_;
			addCompileOptionCmd__extccomp_u915(conf_p4, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA491_: ;
	}
	goto LA148_;
	LA67_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA496_;
			addLinkOptionCmd__extccomp_u912(conf_p4, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA496_: ;
	}
	goto LA148_;
	LA68_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 T503_;
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA501_;
			T503_.len = 0; T503_.p = NIM_NIL;
			T503_ = processPath__commands_u1104(conf_p4, arg_p1, info_p3, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T503_); goto LA1_;}
			add__commands_u1640((&(*conf_p4).cIncludes), T503_);
		}
LA501_: ;
	}
	goto LA148_;
	LA69_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 T509_;
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA507_;
			T509_.len = 0; T509_.p = NIM_NIL;
			T509_ = processPath__commands_u1104(conf_p4, arg_p1, info_p3, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T509_); goto LA1_;}
			add__commands_u1640((&(*conf_p4).cLibs), T509_);
		}
LA507_: ;
	}
	goto LA148_;
	LA70_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 colontmpD__20;
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA513_;
			colontmpD__20 = eqdup___system_u2697(arg_p1);
			add__stdZenumutils_u71((&(*conf_p4).cLinkedLibs), colontmpD__20);
		}
LA513_: ;
	}
	goto LA148_;
	LA71_: ;
	{
		{
			if (!!((conf_p4 == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL)))) goto LA518_;
			eqcopy___system_u2694((&(*conf_p4).headerFile), arg_p1);
		}
LA518_: ;
		(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)29))) & 63);
	}
	goto LA148_;
	LA72_: ;
	{
		{
			if (!!((conf_p4 == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL)))) goto LA523_;
			eqcopy___system_u2694((&(*conf_p4).nimbasePattern), arg_p1);
		}
LA523_: ;
	}
	goto LA148_;
	LA73_: ;
	{
		NimStringV2 colontmpD__21;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__21 = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA526_;
		if (eqStrings(colontmpD__21, TM__brsa2DgNdQAKzy1F0pSZlA_677)) goto LA527_;
		if (eqStrings(colontmpD__21, TM__brsa2DgNdQAKzy1F0pSZlA_678)) goto LA527_;
		if (eqStrings(colontmpD__21, TM__brsa2DgNdQAKzy1F0pSZlA_680)) goto LA528_;
		if (eqStrings(colontmpD__21, TM__brsa2DgNdQAKzy1F0pSZlA_681)) goto LA529_;
		goto LA530_;
		LA527_: ;
		{
			(*conf_p4).globalOptions = ((*conf_p4).globalOptions | 536870912);
		}
		goto LA531_;
		LA528_: ;
		{
			(*conf_p4).globalOptions = ((*conf_p4).globalOptions | 1610612736);
		}
		goto LA531_;
		LA529_: ;
		{
			(*conf_p4).globalOptions = ((*conf_p4).globalOptions & ~ 1610612736);
		}
		goto LA531_;
		LA530_: ;
		{
			NimStringV2 colontmpD__22;
			colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
			colontmpD__22 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_682, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA536_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__22, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_683), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA536_;
			{
				LA536_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__22);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA526_;
		}
LA531_: ;
		{
			LA526_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__21);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA74_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(2147483648), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA75_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 m_1;
			NimStringV2 colontmpD__23;
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA545_;
			m_1.len = 0; m_1.p = NIM_NIL;
			colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
			colontmpD__23 = toFullPath__msgs_u624(conf_p4, info_p3.fileIndex);
			if (NIM_UNLIKELY(*nimErr_)) goto LA547_;
			m_1 = findModule__options_u4101(conf_p4, arg_p1, colontmpD__23);
			if (NIM_UNLIKELY(*nimErr_)) goto LA547_;
			{
				NimStringV2 colontmpD__24;
				NimStringV2 T553_;
				if (!(m_1.len == ((NI)0))) goto LA550_;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				T553_.len = 0; T553_.p = NIM_NIL;
				T553_ = rawNewString(arg_p1.len + 25);
appendString((&T553_), TM__brsa2DgNdQAKzy1F0pSZlA_685);
appendString((&T553_), arg_p1);
				colontmpD__24 = T553_;
				liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__24, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_686), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA552_;
				{
					LA552_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__24);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA547_;
			}
			goto LA548_;
LA550_: ;
			{
				NimStringV2 blitTmp_1;
				blitTmp_1 = m_1;
				eqwasMoved___system_u2688((&m_1));
				add__stdZenumutils_u71((&(*conf_p4).implicitImports), blitTmp_1);
			}
LA548_: ;
			{
				LA547_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__23);
				eqdestroy___system_u2691(m_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA545_: ;
	}
	goto LA148_;
	LA76_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 m_2;
			NimStringV2 colontmpD__25;
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA562_;
			m_2.len = 0; m_2.p = NIM_NIL;
			colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
			colontmpD__25 = toFullPath__msgs_u624(conf_p4, info_p3.fileIndex);
			if (NIM_UNLIKELY(*nimErr_)) goto LA564_;
			m_2 = findModule__options_u4101(conf_p4, arg_p1, colontmpD__25);
			if (NIM_UNLIKELY(*nimErr_)) goto LA564_;
			{
				NimStringV2 colontmpD__26;
				NimStringV2 T570_;
				if (!(m_2.len == ((NI)0))) goto LA567_;
				colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
				T570_.len = 0; T570_.p = NIM_NIL;
				T570_ = rawNewString(arg_p1.len + 25);
appendString((&T570_), TM__brsa2DgNdQAKzy1F0pSZlA_687);
appendString((&T570_), arg_p1);
				colontmpD__26 = T570_;
				liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__26, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_688), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA569_;
				{
					LA569_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__26);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA564_;
			}
			goto LA565_;
LA567_: ;
			{
				NimStringV2 blitTmp_2;
				blitTmp_2 = m_2;
				eqwasMoved___system_u2688((&m_2));
				add__stdZenumutils_u71((&(*conf_p4).implicitIncludes), blitTmp_2);
			}
LA565_: ;
			{
				LA564_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__25);
				eqdestroy___system_u2691(m_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA562_: ;
	}
	goto LA148_;
	LA77_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 8, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA78_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(1125899906842624), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA79_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 4096, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA80_: ;
	{
		tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw theOS_1;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		theOS_1 = nameToOS__platform_u846(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 osList_1;
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmpD__27;
			NimStringV2 colontmpD__28;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T585_;
			if (!(theOS_1 == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)0))) goto LA582_;
			osList_1.len = 0; osList_1.p = NIM_NIL;
			colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
			colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
			colontmpD__27 = listOSnames__platform_u870();
			if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
			osList_1 = nsuJoinSep(((colontmpD__27).p) ? (colontmpD__27.p->data) : NIM_NIL, colontmpD__27.len, TM__brsa2DgNdQAKzy1F0pSZlA_690);
			if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
			T585_[0] = arg_p1;
			T585_[1] = osList_1;
			colontmpD__28 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_692, T585_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__28, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_693), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA584_;
			{
				LA584_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__28);
				eqdestroy___system_u5504(colontmpD__27);
				eqdestroy___system_u2691(osList_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA580_;
LA582_: ;
		{
			setTarget__platform_u750((&(*conf_p4).target), theOS_1, (*conf_p4).target.targetCPU);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA580_: ;
	}
	goto LA148_;
	LA81_: ;
	{
		tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw cpu_1;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cpu_1 = nameToCPU__platform_u894(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 cpuList_1;
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmpD__29;
			NimStringV2 colontmpD__30;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T595_;
			if (!(cpu_1 == ((tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw)0))) goto LA592_;
			cpuList_1.len = 0; cpuList_1.p = NIM_NIL;
			colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			colontmpD__29 = listCPUnames__platform_u918();
			if (NIM_UNLIKELY(*nimErr_)) goto LA594_;
			cpuList_1 = nsuJoinSep(((colontmpD__29).p) ? (colontmpD__29.p->data) : NIM_NIL, colontmpD__29.len, TM__brsa2DgNdQAKzy1F0pSZlA_694);
			if (NIM_UNLIKELY(*nimErr_)) goto LA594_;
			T595_[0] = arg_p1;
			T595_[1] = cpuList_1;
			colontmpD__30 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_696, T595_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA594_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__30, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_697), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA594_;
			{
				LA594_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__30);
				eqdestroy___system_u5504(colontmpD__29);
				eqdestroy___system_u2691(cpuList_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA590_;
LA592_: ;
		{
			setTarget__platform_u750((&(*conf_p4).target), (*conf_p4).target.targetOS, cpu_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA590_: ;
	}
	goto LA148_;
	LA82_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 8192, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!((*conf_p4).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA602_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_698, TM__brsa2DgNdQAKzy1F0pSZlA_699);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA602_: ;
	}
	goto LA148_;
	LA83_: ;
	{
		NI value_1;
		NI T605_;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		value_1 = ((NI)10000000);
		T605_ = (NI)0;
		T605_ = parseSaturatedNatural__pureZparseutils_u986(arg_p1, (&value_1), ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(void)(T605_);
		{
			if (!(value_1 <= ((NI)0))) goto LA608_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__brsa2DgNdQAKzy1F0pSZlA_701, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_702), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA608_: ;
		(*conf_p4).maxLoopIterationsVM = value_1;
	}
	goto LA148_;
	LA84_: ;
	{
		NI value_2;
		NI T611_;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		value_2 = ((NI)2000);
		T611_ = (NI)0;
		T611_ = parseSaturatedNatural__pureZparseutils_u986(arg_p1, (&value_2), ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(void)(T611_);
		{
			if (!(value_2 <= ((NI)0))) goto LA614_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__brsa2DgNdQAKzy1F0pSZlA_704, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_705), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA614_: ;
		(*conf_p4).maxCallDepthVM = value_2;
	}
	goto LA148_;
	LA85_: ;
	{
		NI value_3;
		NI T617_;
		NI T618_;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		value_3 = ((NI)0);
		T617_ = (NI)0;
		T617_ = parseSaturatedNatural__pureZparseutils_u986(arg_p1, (&value_3), ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(void)(T617_);
		T618_ = (NI)0;
		{
			if (!(value_3 == ((NI)0))) goto LA621_;
			(*conf_p4).errorMax = ((NI)IL64(9223372036854775807));
		}
		goto LA619_;
LA621_: ;
		{
			(*conf_p4).errorMax = value_3;
		}
LA619_: ;
	}
	goto LA148_;
	LA86_: ;
	{
		NimStringV2 T625_;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T625_.len = 0; T625_.p = NIM_NIL;
		{
			NIM_BOOL T628_;
			NimStringV2 colontmpD__31;
			T628_ = (NIM_BOOL)0;
			T628_ = nosisAbsolute(arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T628_) goto LA629_;
			colontmpD__31 = eqdup___system_u2697(arg_p1);
			eqsink___system_u2700((&(*conf_p4).stdinFile), colontmpD__31);
		}
		goto LA626_;
LA629_: ;
		{
			NimStringV2 colontmpD__32;
			NimStringV2 T633_;
			colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
			colontmpD__32 = nosgetCurrentDir();
			if (NIM_UNLIKELY(*nimErr_)) goto LA632_;
			T633_.len = 0; T633_.p = NIM_NIL;
			T633_ = slash___stdZprivateZospaths2_u91(colontmpD__32, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T633_); goto LA632_;}
			eqsink___system_u2700((&(*conf_p4).stdinFile), T633_);
			{
				LA632_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__32);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA626_: ;
	}
	goto LA148_;
	LA87_: ;
	{
		NI verbosity_1;
		tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw verb_1;
		NI T646_;
		NI T647_;
		NI T648_;
		tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw T649_;
		tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw T650_;
		NI T651_;
		NI T652_;
		tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw T653_;
		tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw T654_;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		verbosity_1 = nsuParseInt(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA T639_;
			NIM_BOOL T640_;
			NimStringV2 colontmpD__33;
			T639_ = dotdot___stdZstrbasics_u49(((NI)0), ((NI)3));
			T640_ = (NIM_BOOL)0;
			T640_ = contains__pureZtimes_u3356(T639_, verbosity_1);
			if (!!(T640_)) goto LA641_;
			colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
			colontmpD__33 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_707, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA643_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__33, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_708), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA643_;
			{
				LA643_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__33);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA641_: ;
		(*conf_p4).verbosity = verbosity_1;
		nimZeroMem((void*)verb_1, sizeof(tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw));
		nimCopyMem((void*)verb_1, (NIM_CONST void*)NotesVerbosity__lineinfos_u228[((*conf_p4).verbosity)- 0], 13);
		T646_ = (NI)0;
		T647_ = (NI)0;
		T648_ = (NI)0;
		for (T648_ = 0; T648_ < 13; T648_++) 
  T649_[T648_] = (*conf_p4).modifiedyNotes[T648_] & (*conf_p4).notes[T648_];
		for (T647_ = 0; T647_ < 13; T647_++) 
  T650_[T647_] = T649_[T647_] | verb_1[T647_];
		T651_ = (NI)0;
		T652_ = (NI)0;
		for (T652_ = 0; T652_ < 13; T652_++) 
  T653_[T652_] = (*conf_p4).modifiedyNotes[T652_] & verb_1[T652_];
		for (T651_ = 0; T651_ < 13; T651_++) 
  T654_[T651_] = T653_[T651_] & ~ (*conf_p4).notes[T651_];
		for (T646_ = 0; T646_ < 13; T646_++) 
  (*conf_p4).notes[T646_] = T650_[T646_] & ~ T654_[T646_];
		nimCopyMem((void*)(*conf_p4).mainPackageNotes, (NIM_CONST void*)(*conf_p4).notes, 13);
	}
	goto LA148_;
	LA88_: ;
	{
		NI value_4;
		NI T656_;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		value_4 = ((NI)0);
		T656_ = (NI)0;
		T656_ = parseSaturatedNatural__pureZparseutils_u986(arg_p1, (&value_4), ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(void)(T656_);
		(*conf_p4).numberOfProcessors = value_4;
	}
	goto LA148_;
	LA89_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		writeVersionInfo__commands_u172(conf_p4, pass_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA90_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		writeAdvancedUsage__commands_u158(conf_p4, pass_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA91_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		writeFullhelp__commands_u165(conf_p4, pass_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA92_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		helpOnError__commands_u150(conf_p4, pass_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA93_: ;
	{
		NimStringV2 colontmpD__34;
		colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
		{
			NimStringV2 colontmpD__35;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T668_;
			colontmpD__34 = nsuNormalize(switch_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA662_;
			if (!eqStrings(colontmpD__34, TM__brsa2DgNdQAKzy1F0pSZlA_734)) goto LA665_;
			colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
			T668_[0] = switch_p0;
			T668_[1] = TM__brsa2DgNdQAKzy1F0pSZlA_736;
			colontmpD__35 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_735, T668_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA667_;
			warningDeprecated__msgs_u1572(conf_p4, info_p3, colontmpD__35);
			if (NIM_UNLIKELY(*nimErr_)) goto LA667_;
			{
				LA667_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__35);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA662_;
		}
LA665_: ;
		{
			NimStringV2 colontmpD__36;
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA673_;
			colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
			colontmpD__36 = nsuNormalize(arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA675_;
			if (eqStrings(colontmpD__36, TM__brsa2DgNdQAKzy1F0pSZlA_737)) goto LA676_;
			if (eqStrings(colontmpD__36, TM__brsa2DgNdQAKzy1F0pSZlA_738)) goto LA677_;
			if (eqStrings(colontmpD__36, TM__brsa2DgNdQAKzy1F0pSZlA_740)) goto LA678_;
			if (eqStrings(colontmpD__36, TM__brsa2DgNdQAKzy1F0pSZlA_742)) goto LA679_;
			if (eqStrings(colontmpD__36, TM__brsa2DgNdQAKzy1F0pSZlA_744)) goto LA680_;
			if (eqStrings(colontmpD__36, TM__brsa2DgNdQAKzy1F0pSZlA_746)) goto LA681_;
			goto LA682_;
			LA676_: ;
			{
				(*conf_p4).symbolFiles = ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3);
			}
			goto LA683_;
			LA677_: ;
			{
				(*conf_p4).symbolFiles = ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0);
			}
			goto LA683_;
			LA678_: ;
			{
				(*conf_p4).symbolFiles = ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)1);
			}
			goto LA683_;
			LA679_: ;
			{
				(*conf_p4).symbolFiles = ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)2);
			}
			goto LA683_;
			LA680_: ;
			{
				(*conf_p4).symbolFiles = ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3);
			}
			goto LA683_;
			LA681_: ;
			{
				(*conf_p4).symbolFiles = ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)4);
			}
			goto LA683_;
			LA682_: ;
			{
				NimStringV2 colontmpD__37;
				NimStringV2 T692_;
				colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
				T692_.len = 0; T692_.p = NIM_NIL;
				T692_ = rawNewString(arg_p1.len + 34);
appendString((&T692_), TM__brsa2DgNdQAKzy1F0pSZlA_748);
appendString((&T692_), arg_p1);
				colontmpD__37 = T692_;
				liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__37, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_749), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA691_;
				{
					LA691_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__37);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA675_;
			}
LA683_: ;
			{
				LA675_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__36);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA662_;
		}
LA673_: ;
		setUseIc__ast_u834(!(((*conf_p4).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA662_;
		{
			LA662_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__34);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA94_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 524288, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA95_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 1048576, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA96_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 2097152, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA97_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 4194304, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA98_: ;
	{
		NimStringV2 colontmpD__38;
		colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
		{
			NimStringV2 colontmpD__39;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T710_;
			colontmpD__38 = nsuNormalize(switch_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA704_;
			if (!eqStrings(colontmpD__38, TM__brsa2DgNdQAKzy1F0pSZlA_750)) goto LA707_;
			colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
			T710_[0] = switch_p0;
			T710_[1] = TM__brsa2DgNdQAKzy1F0pSZlA_752;
			colontmpD__39 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_751, T710_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA709_;
			warningDeprecated__msgs_u1572(conf_p4, info_p3, colontmpD__39);
			if (NIM_UNLIKELY(*nimErr_)) goto LA709_;
			{
				LA709_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__39);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA704_;
		}
LA707_: ;
		processOnOffSwitchG__commands_u260(conf_p4, 1024, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA704_;
		processOnOffSwitchG__commands_u260(conf_p4, 16, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA704_;
		{
			LA704_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__38);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA99_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 2048, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA100_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 16777216, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA101_: ;
	{
		NimStringV2 T718_;
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T718_.len = 0; T718_.p = NIM_NIL;
		T718_ = processPath__commands_u1104(conf_p4, arg_p1, info_p3, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T718_); goto LA1_;}
		eqsink___system_u2700((&(*conf_p4).libpath), T718_);
	}
	goto LA148_;
	LA102_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		splitSwitch__commands_u196(conf_p4, arg_p1, (&key_1), (&val_1), pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		putEnv__stdZenvvars_u24(key_1, val_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA103_: ;
	{
		{
			if (!!(((*conf_p4).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3)))) goto LA723_;
			expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			setCC__extccomp_u781(conf_p4, arg_p1, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA723_: ;
	}
	goto LA148_;
	LA104_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		track__commands_u1150(conf_p4, arg_p1, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA105_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		trackDirty__commands_u1142(conf_p4, arg_p1, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA106_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*conf_p4).ideCmd = ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)1);
	}
	goto LA148_;
	LA107_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		trackIde__commands_u1158(conf_p4, ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)3), arg_p1, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA108_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*conf_p4).ideCmd = ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)2);
	}
	goto LA148_;
	LA109_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		trackIde__commands_u1158(conf_p4, ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)4), arg_p1, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA110_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		trackIde__commands_u1158(conf_p4, ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)5), arg_p1, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA111_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, 67108864, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA112_: ;
	{
		NimStringV2 colontmpD__40;
		colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
		colontmpD__40 = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA734_;
		if (eqStrings(colontmpD__40, TM__brsa2DgNdQAKzy1F0pSZlA_770)) goto LA735_;
		if (eqStrings(colontmpD__40, TM__brsa2DgNdQAKzy1F0pSZlA_772)) goto LA736_;
		if (eqStrings(colontmpD__40, TM__brsa2DgNdQAKzy1F0pSZlA_774)) goto LA737_;
		goto LA738_;
		LA735_: ;
		{
			(*conf_p4).filenameOption = ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)0);
		}
		goto LA739_;
		LA736_: ;
		{
			(*conf_p4).filenameOption = ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)2);
		}
		goto LA739_;
		LA737_: ;
		{
			(*conf_p4).filenameOption = ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)3);
		}
		goto LA739_;
		LA738_: ;
		{
			NimStringV2 colontmpD__41;
			colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
			colontmpD__41 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_776, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA744_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__41, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_777), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA744_;
			{
				LA744_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__41);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA734_;
		}
LA739_: ;
		{
			LA734_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__40);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA113_: ;
	{
		NimStringV2 colontmpD__42;
		colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
		(*conf_p4).notes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20))>>3] |=(1U<<((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20)&7U));
		(*conf_p4).mainPackageNotes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20))>>3] |=(1U<<((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20)&7U));
		colontmpD__42 = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA750_;
		if (eqStrings(colontmpD__42, TM__brsa2DgNdQAKzy1F0pSZlA_779)) goto LA751_;
		if (eqStrings(colontmpD__42, TM__brsa2DgNdQAKzy1F0pSZlA_780)) goto LA752_;
		if (eqStrings(colontmpD__42, TM__brsa2DgNdQAKzy1F0pSZlA_781)) goto LA753_;
		goto LA754_;
		LA751_: ;
		{
			(*conf_p4).hintProcessingDots = NIM_TRUE;
		}
		goto LA755_;
		LA752_: ;
		{
			(*conf_p4).hintProcessingDots = NIM_FALSE;
		}
		goto LA755_;
		LA753_: ;
		{
			(*conf_p4).notes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20))>>3] &= ~(1U<<((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20)&7U));
			(*conf_p4).mainPackageNotes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20))>>3] &= ~(1U<<((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20)&7U));
		}
		goto LA755_;
		LA754_: ;
		{
			NimStringV2 colontmpD__43;
			colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
			colontmpD__43 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_783, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA760_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__43, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_784), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA760_;
			{
				LA760_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__43);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA750_;
		}
LA755_: ;
		{
			LA750_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__42);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA114_: ;
	{
		NimStringV2 colontmpD__44;
		NIM_BOOL colontmpD__45;
		NIM_BOOL colontmpD__46;
		NIM_BOOL colontmpD__47;
		NimStringV2 T767_;
		colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
		colontmpD__45 = (NIM_BOOL)0;
		colontmpD__46 = (NIM_BOOL)0;
		colontmpD__47 = (NIM_BOOL)0;
		T767_.len = 0; T767_.p = NIM_NIL;
		{
			NIM_BOOL T770_;
			T770_ = (NIM_BOOL)0;
			colontmpD__44 = nsuNormalize(arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA766_;
			if (eqStrings(colontmpD__44, TM__brsa2DgNdQAKzy1F0pSZlA_785)) goto LA771_;
			if (eqStrings(colontmpD__44, TM__brsa2DgNdQAKzy1F0pSZlA_786)) goto LA771_;
			if (eqStrings(colontmpD__44, TM__brsa2DgNdQAKzy1F0pSZlA_787)) goto LA772_;
			goto LA773_;
			LA771_: ;
			{
				colontmpD__45 = NIM_TRUE;
				T770_ = colontmpD__45;
			}
			goto LA774_;
			LA772_: ;
			{
				colontmpD__46 = NIM_FALSE;
				T770_ = colontmpD__46;
			}
			goto LA774_;
			LA773_: ;
			{
				NimStringV2 colontmpD__48;
				colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
				colontmpD__48 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_788, arg_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA778_;
				liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__48, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_789), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA778_;
				colontmpD__47 = NIM_FALSE;
				T770_ = colontmpD__47;
				{
					LA778_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__48);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA766_;
			}
LA774_: ;
			if (!T770_) goto LA781_;
			eqsink___system_u2700((&(*conf_p4).unitSep), TM__brsa2DgNdQAKzy1F0pSZlA_791);
		}
		goto LA768_;
LA781_: ;
		{
			eqsink___system_u2700((&(*conf_p4).unitSep), TM__brsa2DgNdQAKzy1F0pSZlA_792);
		}
LA768_: ;
		{
			LA766_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__44);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA115_: ;
	{
		NimStringV2 colontmpD__49;
		NIM_BOOL colontmpD__50;
		NIM_BOOL colontmpD__51;
		NIM_BOOL colontmpD__52;
		tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ T788_;
		colontmpD__49.len = 0; colontmpD__49.p = NIM_NIL;
		colontmpD__50 = (NIM_BOOL)0;
		colontmpD__51 = (NIM_BOOL)0;
		colontmpD__52 = (NIM_BOOL)0;
		T788_ = (tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)0;
		{
			NIM_BOOL T791_;
			T791_ = (NIM_BOOL)0;
			colontmpD__49 = nsuNormalize(arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA787_;
			if (eqStrings(colontmpD__49, TM__brsa2DgNdQAKzy1F0pSZlA_793)) goto LA792_;
			if (eqStrings(colontmpD__49, TM__brsa2DgNdQAKzy1F0pSZlA_794)) goto LA792_;
			if (eqStrings(colontmpD__49, TM__brsa2DgNdQAKzy1F0pSZlA_795)) goto LA793_;
			goto LA794_;
			LA792_: ;
			{
				colontmpD__50 = NIM_TRUE;
				T791_ = colontmpD__50;
			}
			goto LA795_;
			LA793_: ;
			{
				colontmpD__51 = NIM_FALSE;
				T791_ = colontmpD__51;
			}
			goto LA795_;
			LA794_: ;
			{
				NimStringV2 colontmpD__53;
				colontmpD__53.len = 0; colontmpD__53.p = NIM_NIL;
				colontmpD__53 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_796, arg_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA799_;
				liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__53, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_789), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA799_;
				colontmpD__52 = NIM_FALSE;
				T791_ = colontmpD__52;
				{
					LA799_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__53);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA787_;
			}
LA795_: ;
			if (!T791_) goto LA802_;
			(*conf_p4).filenameOption = ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)0);
		}
		goto LA789_;
LA802_: ;
		{
			(*conf_p4).filenameOption = ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)2);
		}
LA789_: ;
		{
			LA787_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__49);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA116_: ;
	{
		{
			if (!(arg_p1.len == ((NI)0))) goto LA810_;
			(*conf_p4).spellSuggestMax = ((NI)-1);
		}
		goto LA808_;
LA810_: ;
		{
			if (!eqStrings(arg_p1, TM__brsa2DgNdQAKzy1F0pSZlA_798)) goto LA813_;
			(*conf_p4).spellSuggestMax = ((NI)-1);
		}
		goto LA808_;
LA813_: ;
		{
			NI T816_;
			T816_ = (NI)0;
			T816_ = nsuParseInt(arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			(*conf_p4).spellSuggestMax = T816_;
		}
LA808_: ;
	}
	goto LA148_;
	LA117_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(2199023255552), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA118_: ;
	{
		dynlibOverride__commands_u1167(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA119_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(17592186044416), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA120_: ;
	{
		{
			if (!(arg_p1.len == ((NI)0))) goto LA823_;
			(*conf_p4).features = ((*conf_p4).features | 7);
		}
		goto LA821_;
LA823_: ;
		{
			tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ T827_;
			T827_ = (tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)0;
			T827_ = parseEnum__commands_u900(arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA826_;
			(*conf_p4).features |= ((NU32)1)<<(((T827_)) & 31);
			if (NIM_UNLIKELY(*nimErr_)) {
				LA826_:;
				if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
					*nimErr_ = NIM_FALSE;
					liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__brsa2DgNdQAKzy1F0pSZlA_800, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_801), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA829_;
					popCurrentException();
					LA829_:;
				}
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA821_: ;
	}
	goto LA148_;
	LA121_: ;
	{
		tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA T833_;
		T833_ = (tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)0;
		T833_ = parseEnum__commands_u1849(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA832_;
		(*conf_p4).legacyFeatures |= ((NU8)1)<<(((T833_)) & 7);
		if (NIM_UNLIKELY(*nimErr_)) {
			LA832_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
				*nimErr_ = NIM_FALSE;
				liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__brsa2DgNdQAKzy1F0pSZlA_803, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_804), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA835_;
				popCurrentException();
				LA835_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA122_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*conf_p4).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)0);
		defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_806, TM__brsa2DgNdQAKzy1F0pSZlA_807);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA123_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		showNonExportedFields__options_u4274(conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA124_: ;
	{
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		docRawOutput__options_u4280(conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA125_: ;
	{
		NimStringV2 colontmpD__54;
		NimStringV2 T842_;
		colontmpD__54.len = 0; colontmpD__54.p = NIM_NIL;
		T842_.len = 0; T842_.p = NIM_NIL;
		T842_ = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T842_); goto LA841_;}
		colontmpD__54 = T842_;
		if (eqStrings(colontmpD__54, TM__brsa2DgNdQAKzy1F0pSZlA_808)) goto LA843_;
		if (eqStrings(colontmpD__54, TM__brsa2DgNdQAKzy1F0pSZlA_810)) goto LA844_;
		if (eqStrings(colontmpD__54, TM__brsa2DgNdQAKzy1F0pSZlA_812)) goto LA845_;
		if (eqStrings(colontmpD__54, TM__brsa2DgNdQAKzy1F0pSZlA_814)) goto LA846_;
		goto LA847_;
		LA843_: ;
		{
			(*conf_p4).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)2);
		}
		goto LA848_;
		LA844_: ;
		{
			(*conf_p4).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)1);
		}
		goto LA848_;
		LA845_: ;
		{
			(*conf_p4).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)4);
		}
		goto LA848_;
		LA846_: ;
		{
			(*conf_p4).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3);
		}
		goto LA848_;
		LA847_: ;
		{
			NimStringV2 colontmpD__55;
			NimStringV2 T855_;
			colontmpD__55.len = 0; colontmpD__55.p = NIM_NIL;
			T855_.len = 0; T855_.p = NIM_NIL;
			T855_ = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_816, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T855_); goto LA854_;}
			colontmpD__55 = T855_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__55, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_817), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA854_;
			{
				LA854_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__55);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA841_;
		}
LA848_: ;
		{
			LA841_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__54);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA126_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!!((conf_p4 == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL)))) goto LA863_;
			cppDefine__options_u2159(conf_p4, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA863_: ;
	}
	goto LA148_;
	LA127_: ;
	{
		warningDeprecated__msgs_u1572(conf_p4, info_p3, TM__brsa2DgNdQAKzy1F0pSZlA_819);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		expectNoArg__commands_u284(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA868_;
			{
				if (!!(!((conf_p4 == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL))))) goto LA872_;
				failedAssertImpl__stdZassertions_u79(TM__brsa2DgNdQAKzy1F0pSZlA_821);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA872_: ;
			(*conf_p4).features |= ((NU32)1)<<(((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)3))) & 31);
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46))) & 63);
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)47))) & 63);
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45))) & 63);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_822, TM__brsa2DgNdQAKzy1F0pSZlA_823);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			(*conf_p4).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)8);
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_824, TM__brsa2DgNdQAKzy1F0pSZlA_825);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_826, TM__brsa2DgNdQAKzy1F0pSZlA_827);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_829, TM__brsa2DgNdQAKzy1F0pSZlA_830);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA868_: ;
	}
	goto LA148_;
	LA128_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(35184372088832), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)1) || pass_p2 == ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)2))) goto LA877_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_831, TM__brsa2DgNdQAKzy1F0pSZlA_832);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA877_: ;
	}
	goto LA148_;
	LA129_: ;
	{
		NimStringV2 colontmpD__56;
		NimStringV2 T881_;
		colontmpD__56.len = 0; colontmpD__56.p = NIM_NIL;
		T881_.len = 0; T881_.p = NIM_NIL;
		T881_ = nsuNormalize(arg_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T881_); goto LA880_;}
		colontmpD__56 = T881_;
		if (eqStrings(colontmpD__56, TM__brsa2DgNdQAKzy1F0pSZlA_833)) goto LA882_;
		if (eqStrings(colontmpD__56, TM__brsa2DgNdQAKzy1F0pSZlA_834)) goto LA883_;
		if (eqStrings(colontmpD__56, TM__brsa2DgNdQAKzy1F0pSZlA_835)) goto LA884_;
		if (eqStrings(colontmpD__56, TM__brsa2DgNdQAKzy1F0pSZlA_837)) goto LA885_;
		if (eqStrings(colontmpD__56, TM__brsa2DgNdQAKzy1F0pSZlA_838)) goto LA886_;
		goto LA887_;
		LA882_: ;
		{
			(*conf_p4).globalOptions = ((*conf_p4).globalOptions & ~ 229376);
		}
		goto LA888_;
		LA883_: ;
		{
			(*conf_p4).globalOptions = (((*conf_p4).globalOptions | 32768) & ~ 196608);
		}
		goto LA888_;
		LA884_: ;
		{
			(*conf_p4).globalOptions = (((*conf_p4).globalOptions | 131072) & ~ 98304);
		}
		goto LA888_;
		LA885_: ;
		{
			(*conf_p4).globalOptions = (((*conf_p4).globalOptions | 65536) & ~ 163840);
		}
		goto LA888_;
		LA886_: ;
		{
			(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)18))) & 63);
		}
		goto LA888_;
		LA887_: ;
		{
			NimStringV2 colontmpD__57;
			NimStringV2 T896_;
			colontmpD__57.len = 0; colontmpD__57.p = NIM_NIL;
			T896_.len = 0; T896_.p = NIM_NIL;
			T896_ = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_840, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T896_); goto LA895_;}
			colontmpD__57 = T896_;
			liMessage__msgs_u1227(conf_p4, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__57, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_841), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA895_;
			{
				LA895_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__57);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA880_;
		}
LA888_: ;
		{
			LA880_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__56);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA130_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(137438953472), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA131_: ;
	{
		{
			if (!(((NI)0) < arg_p1.len)) goto LA905_;
			eqcopy___system_u2694((&(*conf_p4).cppCustomNamespace), arg_p1);
		}
		goto LA903_;
LA905_: ;
		{
			eqsink___system_u2700((&(*conf_p4).cppCustomNamespace), TM__brsa2DgNdQAKzy1F0pSZlA_843);
		}
LA903_: ;
		defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_845, (*conf_p4).cppCustomNamespace);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA132_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(549755813888), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA133_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(281474976710656), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA134_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		nstPut((*conf_p4).macrosToExpand, arg_p1, TM__brsa2DgNdQAKzy1F0pSZlA_847);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA135_: ;
	{
		expectArg__commands_u278(conf_p4, switch_p0, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		nstPut((*conf_p4).arcToExpand, arg_p1, TM__brsa2DgNdQAKzy1F0pSZlA_848);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA136_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(562949953421312), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA137_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(9007199254740992), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA138_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 33554432, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA139_: ;
	{
		processOnOffSwitch__commands_u225(conf_p4, 67108864, arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA140_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(2251799813685248), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(((*conf_p4).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)51)))&63U)))!=0)) goto LA919_;
			defineSymbol__condsyms_u4((*conf_p4).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_850, TM__brsa2DgNdQAKzy1F0pSZlA_851);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA919_: ;
	}
	goto LA148_;
	LA141_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(72057594037927936), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA142_: ;
	{
		(*conf_p4).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)52))) & 63);
		(*conf_p4).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12))) & 31);
	}
	goto LA148_;
	LA143_: ;
	{
		processOnOffSwitchG__commands_u260(conf_p4, IL64(18014398509481984), arg_p1, pass_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA144_: ;
	{
		handleStdinInput__commands_u1179(conf_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA145_: ;
	{
		NimStringV2 colontmpD__58;
		NimStringV2 T927_;
		colontmpD__58.len = 0; colontmpD__58.p = NIM_NIL;
		T927_.len = 0; T927_.p = NIM_NIL;
		T927_ = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_853, switch_p0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T927_); goto LA926_;}
		colontmpD__58 = T927_;
		warningDeprecated__msgs_u1572(conf_p4, info_p3, colontmpD__58);
		if (NIM_UNLIKELY(*nimErr_)) goto LA926_;
		{
			LA926_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__58);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA148_;
	LA146_: ;
	{
		eqcopy___system_u2694((&(*conf_p4).nimMainPrefix), arg_p1);
	}
	goto LA148_;
	LA147_: ;
	{
		{
			NI T934_;
			T934_ = (NI)0;
			T934_ = nsuFindChar(switch_p0, 46, ((NI)0), ((NI)-1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)0) <= T934_)) goto LA935_;
			setConfigVar__options_u3608(conf_p4, switch_p0, arg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA932_;
LA935_: ;
		{
			invalidCmdLineOption__commands_u191(conf_p4, pass_p2, switch_p0, info_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA932_: ;
	}
LA148_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(val_1);
		eqdestroy___system_u2691(key_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, processSwitch__commands_u1988)(tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw pass_p0, tyObject_OptParser__pqMTtVZW7HhFSYkGtStiLg* p_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p2) {
	NI bracketLe_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	bracketLe_1 = nsuFindChar((*p_p1).key, 91, ((NI)0), ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 key_1;
		NimStringV2 val_1;
		NimStringV2 colontmpD_;
		NimStringV2 T6_;
		if (!(((NI)0) <= bracketLe_1)) goto LA3_;
		key_1.len = 0; key_1.p = NIM_NIL;
		val_1.len = 0; val_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		key_1 = substr__system_u8659((*p_p1).key, ((NI)0), (NI)(bracketLe_1 - ((NI)1)));
		T6_.len = 0; T6_.p = NIM_NIL;
		colontmpD_ = substr__system_u8672((*p_p1).key, bracketLe_1);
		T6_ = rawNewString(colontmpD_.len + (*p_p1).val.len + 1);
appendString((&T6_), colontmpD_);
appendChar((&T6_), 58);
appendString((&T6_), (*p_p1).val);
		val_1 = T6_;
		processSwitch__commands_u1361(key_1, val_1, pass_p0, gCmdLineInfo__msgs_u442, config_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(val_1);
			eqdestroy___system_u2691(key_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		processSwitch__commands_u1361((*p_p1).key, (*p_p1).val, pass_p0, gCmdLineInfo__msgs_u442, config_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeCommandLineUsage__commands_u182)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getCommandLineDesc__commands_u147(conf_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	msgWriteln__msgs_u737(conf_p0, colontmpD_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, handleCmdInput__commands_u1184)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqsink___system_u2700((&(*conf_p0).projectName), TM__brsa2DgNdQAKzy1F0pSZlA_855);
	colontmpD_ = eqdup___system_u2697((*conf_p0).projectName);
	eqsink___system_u2700((&(*conf_p0).projectFull), colontmpD_);
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = nosgetCurrentDir();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1_); goto BeforeRet_;}
	eqsink___system_u2700((&(*conf_p0).projectPath), T1_);
	{
		NIM_BOOL T4_;
		NimStringV2 T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmpty__pathutils_u139((*conf_p0).outDir);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T4_) goto LA5_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = getNimcacheDir__options_u3737(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto BeforeRet_;}
		eqsink___system_u2700((&(*conf_p0).outDir), T7_);
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOption__commands_u930)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	NIM_BOOL result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nsuNormalize(switch_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch (hashString(colontmpD_) & 63) {
	case 0: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_873)) goto LA16_;
break;
	case 2: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_877)) goto LA19_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_888)) goto LA29_;
break;
	case 3: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_869)) goto LA12_;
break;
	case 4: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_871)) goto LA14_;
break;
	case 6: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_883)) goto LA25_;
break;
	case 8: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_860)) goto LA5_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_866)) goto LA9_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_898)) goto LA37_;
break;
	case 12: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_887)) goto LA29_;
break;
	case 14: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_880)) goto LA22_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_897)) goto LA37_;
break;
	case 15: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_901)) goto LA39_;
break;
	case 16: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_893)) goto LA33_;
break;
	case 17: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_899)) goto LA38_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_900)) goto LA39_;
break;
	case 20: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_902)) goto LA39_;
break;
	case 25: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_858)) goto LA3_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_863)) goto LA7_;
break;
	case 26: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_876)) goto LA18_;
break;
	case 30: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_891)) goto LA31_;
break;
	case 31: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_868)) goto LA11_;
break;
	case 32: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_864)) goto LA7_;
break;
	case 33: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_875)) goto LA17_;
break;
	case 34: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_890)) goto LA30_;
break;
	case 35: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_865)) goto LA8_;
break;
	case 37: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_874)) goto LA16_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_895)) goto LA35_;
break;
	case 41: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_882)) goto LA24_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_889)) goto LA30_;
break;
	case 43: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_896)) goto LA36_;
break;
	case 44: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_892)) goto LA32_;
break;
	case 45: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_859)) goto LA4_;
break;
	case 46: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_862)) goto LA6_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_894)) goto LA34_;
break;
	case 47: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_870)) goto LA13_;
break;
	case 49: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_905)) goto LA42_;
break;
	case 51: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_867)) goto LA10_;
break;
	case 56: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_881)) goto LA23_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_903)) goto LA40_;
break;
	case 58: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_861)) goto LA6_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_878)) goto LA20_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_885)) goto LA27_;
break;
	case 59: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_872)) goto LA15_;
break;
	case 60: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_857)) goto LA3_;
break;
	case 61: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_879)) goto LA21_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_884)) goto LA26_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_904)) goto LA41_;
break;
	case 62: 
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_856)) goto LA2_;
if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_886)) goto LA28_;
break;
	}
	goto LA43_;
	LA2_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)6)))&63U)))!=0);
	}
	goto LA44_;
	LA3_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)4)))&63U)))!=0);
	}
	goto LA44_;
	LA4_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)5)))&63U)))!=0);
	}
	goto LA44_;
	LA5_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)23)))&63U)))!=0);
	}
	goto LA44_;
	LA6_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)1)))&63U)))!=0);
	}
	goto LA44_;
	LA7_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)13)))&31U)))!=0);
	}
	goto LA44_;
	LA8_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)14)))&31U)))!=0);
	}
	goto LA44_;
	LA9_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)27)))&63U)))!=0);
	}
	goto LA44_;
	LA10_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0);
	}
	goto LA44_;
	LA11_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)18)))&31U)))!=0);
	}
	goto LA44_;
	LA12_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)19)))&31U)))!=0);
	}
	goto LA44_;
	LA13_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)6)))&63U)))!=0);
	}
	goto LA44_;
	LA14_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)21)))&31U)))!=0);
	}
	goto LA44_;
	LA15_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)24)))&31U)))!=0);
	}
	goto LA44_;
	LA16_: ;
	{
		result = (((*conf_p0).options & 3518) == 3518);
	}
	goto LA44_;
	LA17_: ;
	{
		result = (((*conf_p0).options & 384) == 384);
	}
	goto LA44_;
	LA18_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)8)))&31U)))!=0);
	}
	goto LA44_;
	LA19_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)7)))&31U)))!=0);
	}
	goto LA44_;
	LA20_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)1)))&31U)))!=0);
	}
	goto LA44_;
	LA21_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)2)))&31U)))!=0);
	}
	goto LA44_;
	LA22_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)3)))&31U)))!=0);
	}
	goto LA44_;
	LA23_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0);
	}
	goto LA44_;
	LA24_: ;
	{
		warningDeprecated__msgs_u1572(conf_p0, info_p2, TM__brsa2DgNdQAKzy1F0pSZlA_906);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)6)))&31U)))!=0);
	}
	goto LA44_;
	LA25_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0);
	}
	goto LA44_;
	LA26_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)9)))&31U)))!=0);
	}
	goto LA44_;
	LA27_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)10)))&31U)))!=0);
	}
	goto LA44_;
	LA28_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0);
	}
	goto LA44_;
	LA29_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)11)))&31U)))!=0);
	}
	goto LA44_;
	LA30_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)13)))&63U)))!=0);
	}
	goto LA44_;
	LA31_: ;
	{
		result = !(((*conf_p0).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)));
	}
	goto LA44_;
	LA32_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)10)))&63U)))!=0);
	}
	goto LA44_;
	LA33_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)11)))&63U)))!=0);
	}
	goto LA44_;
	LA34_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)25)))&63U)))!=0);
	}
	goto LA44_;
	LA35_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)28)))&63U)))!=0);
	}
	goto LA44_;
	LA36_: ;
	{
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)22)))&31U)))!=0);
	}
	goto LA44_;
	LA37_: ;
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		{
			NimStringV2 colontmpD__3;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T87_;
			colontmpD__2 = nsuNormalize(switch_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			if (!eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_907)) goto LA84_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T87_[0] = switch_p1;
			T87_[1] = TM__brsa2DgNdQAKzy1F0pSZlA_909;
			colontmpD__3 = nsuFormatOpenArray(TM__brsa2DgNdQAKzy1F0pSZlA_908, T87_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			warningDeprecated__msgs_u1572(conf_p0, info_p2, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			{
				LA86_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		}
LA84_: ;
		result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)23)))&31U)))!=0);
		{
			LA81_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA44_;
	LA38_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)36)))&63U)))!=0);
	}
	goto LA44_;
	LA39_: ;
	{
		NimStringV2 colontmpD__4;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__4 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_910, switch_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
		warningDeprecated__msgs_u1572(conf_p0, info_p2, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
		result = NIM_FALSE;
		{
			LA94_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA44_;
	LA40_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)51)))&63U)))!=0);
	}
	goto LA44_;
	LA41_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)56)))&63U)))!=0);
	}
	goto LA44_;
	LA42_: ;
	{
		result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)58)))&63U)))!=0);
	}
	goto LA44_;
	LA43_: ;
	{
		result = NIM_FALSE;
		invalidCmdLineOption__commands_u191(conf_p0, ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0), switch_p1, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA44_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOptionArg__commands_u783)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2 arg_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	NIM_BOOL result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nsuNormalize(switch_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_911)) goto LA2_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_912)) goto LA2_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_913)) goto LA3_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_914)) goto LA4_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_915)) goto LA5_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_916)) goto LA6_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_917)) goto LA7_;
	if (eqStrings(colontmpD_, TM__brsa2DgNdQAKzy1F0pSZlA_918)) goto LA8_;
	goto LA9_;
	LA2_: ;
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = nsuNormalize(arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		switch (hashString(colontmpD__2) & 15) {
		case 0: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_930)) goto LA22_;
break;
		case 1: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_919)) goto LA13_;
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_922)) goto LA16_;
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_927)) goto LA20_;
break;
		case 3: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_928)) goto LA21_;
break;
		case 4: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_929)) goto LA21_;
break;
		case 6: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_925)) goto LA18_;
break;
		case 7: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_926)) goto LA19_;
break;
		case 9: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_924)) goto LA17_;
break;
		case 13: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_923)) goto LA16_;
break;
		case 14: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_920)) goto LA14_;
break;
		case 15: 
if (eqStrings(colontmpD__2, TM__brsa2DgNdQAKzy1F0pSZlA_921)) goto LA15_;
break;
		}
		goto LA23_;
		LA13_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)2));
		}
		goto LA24_;
		LA14_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)9));
		}
		goto LA24_;
		LA15_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)7));
		}
		goto LA24_;
		LA16_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4));
		}
		goto LA24_;
		LA17_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5));
		}
		goto LA24_;
		LA18_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)8));
		}
		goto LA24_;
		LA19_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10));
		}
		goto LA24_;
		LA20_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)1));
		}
		goto LA24_;
		LA21_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)3));
		}
		goto LA24_;
		LA22_: ;
		{
			result = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6));
		}
		goto LA24_;
		LA23_: ;
		{
			NimStringV2 colontmpD__3;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			result = NIM_FALSE;
			colontmpD__3 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_931, arg_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			liMessage__msgs_u1227(conf_p0, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_932), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			{
				LA36_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		}
LA24_: ;
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
	LA3_: ;
	{
		NimStringV2 colontmpD__4;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__4 = nsuNormalize(arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
		if (eqStrings(colontmpD__4, TM__brsa2DgNdQAKzy1F0pSZlA_933)) goto LA43_;
		if (eqStrings(colontmpD__4, TM__brsa2DgNdQAKzy1F0pSZlA_934)) goto LA44_;
		if (eqStrings(colontmpD__4, TM__brsa2DgNdQAKzy1F0pSZlA_935)) goto LA45_;
		goto LA46_;
		LA43_: ;
		{
			result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15)))&31U)))!=0);
		}
		goto LA47_;
		LA44_: ;
		{
			result = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)16)))&31U)))!=0);
		}
		goto LA47_;
		LA45_: ;
		{
			tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T51_;
			T51_ = 0;
			result = (((*conf_p0).options & 98304) == T51_);
		}
		goto LA47_;
		LA46_: ;
		{
			NimStringV2 colontmpD__5;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			result = NIM_FALSE;
			colontmpD__5 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_936, arg_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			liMessage__msgs_u1227(conf_p0, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__5, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_937), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			{
				LA53_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
		}
LA47_: ;
		{
			LA42_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
	LA4_: ;
	{
		NimStringV2 colontmpD__6;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__6 = dollar___systemZdollars_u9((*conf_p0).verbosity);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		result = eqStrings(colontmpD__6, arg_p2);
		eqdestroy___system_u2691(colontmpD__6);
	}
	goto LA10_;
	LA5_: ;
	{
		NimStringV2 colontmpD__7;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__7 = nsuNormalize(arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		if (eqStrings(colontmpD__7, TM__brsa2DgNdQAKzy1F0pSZlA_938)) goto LA61_;
		if (eqStrings(colontmpD__7, TM__brsa2DgNdQAKzy1F0pSZlA_939)) goto LA62_;
		if (eqStrings(colontmpD__7, TM__brsa2DgNdQAKzy1F0pSZlA_940)) goto LA63_;
		if (eqStrings(colontmpD__7, TM__brsa2DgNdQAKzy1F0pSZlA_941)) goto LA64_;
		goto LA65_;
		LA61_: ;
		{
			result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9)))&63U)))!=0);
		}
		goto LA66_;
		LA62_: ;
		{
			result = !((((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9)))&63U)))!=0));
		}
		goto LA66_;
		LA63_: ;
		{
			NIM_BOOL T70_;
			T70_ = (NIM_BOOL)0;
			T70_ = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)7)))&63U)))!=0);
			if (!(T70_)) goto LA71_;
			T70_ = !((((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9)))&63U)))!=0));
LA71_: ;
			result = T70_;
		}
		goto LA66_;
		LA64_: ;
		{
			NIM_BOOL T73_;
			T73_ = (NIM_BOOL)0;
			T73_ = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)8)))&63U)))!=0);
			if (!(T73_)) goto LA74_;
			T73_ = !((((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9)))&63U)))!=0));
LA74_: ;
			result = T73_;
		}
		goto LA66_;
		LA65_: ;
		{
			NimStringV2 colontmpD__8;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			result = NIM_FALSE;
			colontmpD__8 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_942, arg_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			liMessage__msgs_u1227(conf_p0, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__8, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_943), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			{
				LA76_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__8);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		}
LA66_: ;
		{
			LA60_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
	LA6_: ;
	{
		result = isDynlibOverride__options_u4266(conf_p0, arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
	LA7_: ;
	{
		NimStringV2 colontmpD__9;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__9 = nsuNormalize(arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		if (eqStrings(colontmpD__9, TM__brsa2DgNdQAKzy1F0pSZlA_944)) goto LA84_;
		if (eqStrings(colontmpD__9, TM__brsa2DgNdQAKzy1F0pSZlA_945)) goto LA85_;
		if (eqStrings(colontmpD__9, TM__brsa2DgNdQAKzy1F0pSZlA_946)) goto LA86_;
		if (eqStrings(colontmpD__9, TM__brsa2DgNdQAKzy1F0pSZlA_947)) goto LA87_;
		goto LA88_;
		LA84_: ;
		{
			result = ((*conf_p0).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)2));
		}
		goto LA89_;
		LA85_: ;
		{
			result = ((*conf_p0).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)1));
		}
		goto LA89_;
		LA86_: ;
		{
			result = ((*conf_p0).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)4));
		}
		goto LA89_;
		LA87_: ;
		{
			result = ((*conf_p0).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3));
		}
		goto LA89_;
		LA88_: ;
		{
			NimStringV2 colontmpD__10;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			result = NIM_FALSE;
			colontmpD__10 = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_948, arg_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			liMessage__msgs_u1227(conf_p0, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__10, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_949), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			{
				LA95_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		}
LA89_: ;
		{
			LA83_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
	LA8_: ;
	{
		tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ T102_;
		T102_ = (tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)0;
		T102_ = parseEnum__commands_u900(arg_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
		result = (((*conf_p0).features &((NU32)1<<((NU)((T102_))&31U)))!=0);
		if (NIM_UNLIKELY(*nimErr_)) {
			LA101_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
				NimStringV2 colontmpD__11;
				NimStringV2 T107_;
				*nimErr_ = NIM_FALSE;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				result = NIM_FALSE;
				T107_.len = 0; T107_.p = NIM_NIL;
				T107_ = nsuFormatSingleElem(TM__brsa2DgNdQAKzy1F0pSZlA_951, arg_p2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T107_); goto LA106_;}
				colontmpD__11 = T107_;
				liMessage__msgs_u1227(conf_p0, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__11, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__brsa2DgNdQAKzy1F0pSZlA_952), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
				{
					LA106_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__11);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
				popCurrentException();
				LA104_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
	LA9_: ;
	{
		result = NIM_FALSE;
		invalidCmdLineOption__commands_u191(conf_p0, ((tyEnum_TCmdLinePass__luEYfGx27esHXDqgmAF8Vw)0), switch_p1, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initOrcDefines__commands_u1272)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*conf_p0).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5);
	defineSymbol__condsyms_u4((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_953, TM__brsa2DgNdQAKzy1F0pSZlA_954);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_955, TM__brsa2DgNdQAKzy1F0pSZlA_956);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*conf_p0).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45))) & 63);
	(*conf_p0).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46))) & 63);
	defineSymbol__condsyms_u4((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_957, TM__brsa2DgNdQAKzy1F0pSZlA_958);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	defineSymbol__condsyms_u4((*conf_p0).symbols, TM__brsa2DgNdQAKzy1F0pSZlA_959, TM__brsa2DgNdQAKzy1F0pSZlA_960);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*conf_p0).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)0));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*conf_p0).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2)));
LA4_: ;
		if (!T3_) goto LA5_;
		(*conf_p0).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3);
	}
LA5_: ;
	}BeforeRet_: ;
}
