/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA;
typedef struct tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg;
typedef struct tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w;
typedef struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg;
typedef struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyTuple__N4J9cV4JZGem3ljqqj5rT0Q;
typedef struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg;
typedef struct tyTuple__DTRsWi2kgTewbhN2TT5mbA tyTuple__DTRsWi2kgTewbhN2TT5mbA;
typedef struct tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ;
typedef struct tySequence__LqZapiAqCFeXPQZdoIAUew tySequence__LqZapiAqCFeXPQZdoIAUew;
typedef struct tySequence__LqZapiAqCFeXPQZdoIAUew_Content tySequence__LqZapiAqCFeXPQZdoIAUew_Content;
typedef struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ tyObject_Table__tro5f9chxPVpES1mQpDwZtQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content;
typedef struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ;
typedef struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content;
typedef struct tyObject_ModSection__wPQrS9bWBp9awUjfwyT8lJcA tyObject_ModSection__wPQrS9bWBp9awUjfwyT8lJcA;
typedef struct tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg;
typedef struct tySequence__uAwiTxV3boseSy9a9cSsXHEA tySequence__uAwiTxV3boseSy9a9cSsXHEA;
typedef struct tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content;
typedef struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg;
typedef struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content;
typedef struct tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw;
typedef struct tySequence__9at3Cmn7xIajy679cMZSmybg tySequence__9at3Cmn7xIajy679cMZSmybg;
typedef struct tySequence__9at3Cmn7xIajy679cMZSmybg_Content tySequence__9at3Cmn7xIajy679cMZSmybg_Content;
typedef struct tySequence__eb7tUf9a8CR5sBO6O3AH67A tySequence__eb7tUf9a8CR5sBO6O3AH67A;
typedef struct tySequence__eb7tUf9a8CR5sBO6O3AH67A_Content tySequence__eb7tUf9a8CR5sBO6O3AH67A_Content;
typedef struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg;
typedef struct tySequence__lCWXucMn9bU7PUqVDK7772w tySequence__lCWXucMn9bU7PUqVDK7772w;
typedef struct tySequence__lCWXucMn9bU7PUqVDK7772w_Content tySequence__lCWXucMn9bU7PUqVDK7772w_Content;
typedef struct tyObject_Table__fncSH0hxktvgfMu5tiOgpw tyObject_Table__fncSH0hxktvgfMu5tiOgpw;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tySequence__qagWYy9b8OIJNg9bWhIaAjyw tySequence__qagWYy9b8OIJNg9bWhIaAjyw;
typedef struct tySequence__qagWYy9b8OIJNg9bWhIaAjyw_Content tySequence__qagWYy9b8OIJNg9bWhIaAjyw_Content;
typedef struct tySequence__vz9c2digtAnM8l0FZWLUAGg tySequence__vz9c2digtAnM8l0FZWLUAGg;
typedef struct tySequence__vz9c2digtAnM8l0FZWLUAGg_Content tySequence__vz9c2digtAnM8l0FZWLUAGg_Content;
typedef struct tyObject_Table__bzy14J3py7GGCrkIhTsFXw tyObject_Table__bzy14J3py7GGCrkIhTsFXw;
typedef struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw tySequence__O9a9cp2XDKWshwC0UDgFP6Pw;
typedef struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content;
typedef struct tySequence__jK2T9bFw5BWKL8ZZ854oXZg tySequence__jK2T9bFw5BWKL8ZZ854oXZg;
typedef struct tySequence__jK2T9bFw5BWKL8ZZ854oXZg_Content tySequence__jK2T9bFw5BWKL8ZZ854oXZg_Content;
typedef struct tySequence__vdmFdgox3dhDOMkkFi9ayfg tySequence__vdmFdgox3dhDOMkkFi9ayfg;
typedef struct tySequence__vdmFdgox3dhDOMkkFi9ayfg_Content tySequence__vdmFdgox3dhDOMkkFi9ayfg_Content;
typedef struct tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA;
typedef struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg;
typedef struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content;
typedef struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA tySequence__m9axZwxFfhSNLcoofvKZJYA;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content tySequence__m9axZwxFfhSNLcoofvKZJYA_Content;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw tySequence__fXWXs2NlFKREhy9cn6vokJw;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content tySequence__fXWXs2NlFKREhy9cn6vokJw_Content;
typedef struct tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw;
typedef struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA;
typedef struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA;
typedef struct tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg;
typedef struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA tySequence__b9cVyuSHmrW80P0ZGgU2KHA;
typedef struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content;
typedef struct tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg;
typedef struct tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct Exception Exception;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw;
typedef struct tySequence__T69aiRC686UsUPVrEM9awLDA tySequence__T69aiRC686UsUPVrEM9awLDA;
typedef struct tySequence__T69aiRC686UsUPVrEM9awLDA_Content tySequence__T69aiRC686UsUPVrEM9awLDA_Content;
typedef struct tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q tySequence__4eQHGndY6XBYpFOH09apV8Q;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content tySequence__4eQHGndY6XBYpFOH09apV8Q_Content;
typedef struct tyObject_Table__I1hAea2wVUrLyIxtQj9cheA tyObject_Table__I1hAea2wVUrLyIxtQj9cheA;
typedef struct tySequence__SFipDZIkFtPcrLs0AGBBjQ tySequence__SFipDZIkFtPcrLs0AGBBjQ;
typedef struct tySequence__SFipDZIkFtPcrLs0AGBBjQ_Content tySequence__SFipDZIkFtPcrLs0AGBBjQ_Content;
typedef struct tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyTuple__M7ImznM2hk9a9beBDTxcwGeg;
typedef struct tyTuple__30Ti2rm9aDSr5neUSZP6EVQ tyTuple__30Ti2rm9aDSr5neUSZP6EVQ;
typedef struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ;
typedef struct tyTuple__kNIN44R9cL9cYoYzXmSW4y7w tyTuple__kNIN44R9cL9cYoYzXmSW4y7w;
typedef struct tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q;
typedef struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg;
typedef struct tyTuple__RrY3dT8dfTceE0s6Bv9bxJw tyTuple__RrY3dT8dfTceE0s6Bv9bxJw;
typedef struct tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw;
typedef struct tyTuple__i2GOAy1W4iVZ1R13oxrTvA tyTuple__i2GOAy1W4iVZ1R13oxrTvA;
typedef struct tySequence__36jA1xDCIBAS29cySYLQ7kQ tySequence__36jA1xDCIBAS29cySYLQ7kQ;
typedef struct tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content;
typedef struct tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw;
typedef struct tySequence__mg32q50AXD9cQ6jovpBmgWA tySequence__mg32q50AXD9cQ6jovpBmgWA;
typedef struct tySequence__mg32q50AXD9cQ6jovpBmgWA_Content tySequence__mg32q50AXD9cQ6jovpBmgWA_Content;
typedef struct tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ;
typedef struct tyTuple__bvjw5f4vMpB9bESWLU7nvyA tyTuple__bvjw5f4vMpB9bESWLU7nvyA;
typedef struct tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ;
typedef struct tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A;
typedef struct tyTuple__Na59bk2YQTCLBWTLyeMrWdA tyTuple__Na59bk2YQTCLBWTLyeMrWdA;
typedef struct tySequence__ib5UTyrs9aC6K60sNqKElQA tySequence__ib5UTyrs9aC6K60sNqKElQA;
typedef struct tySequence__ib5UTyrs9aC6K60sNqKElQA_Content tySequence__ib5UTyrs9aC6K60sNqKElQA_Content;
typedef struct tyTuple__4Ywt2LYBMs9aMJ09cL7digow tyTuple__4Ywt2LYBMs9aMJ09cL7digow;
typedef struct tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng;
typedef struct tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ;
typedef struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
typedef struct tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ;
typedef struct tyTuple__8ZxhPt1NwfElsJs8zUSV9bg tyTuple__8ZxhPt1NwfElsJs8zUSV9bg;
typedef struct tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g;
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
struct tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg {
	tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ filenameToIdx;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ idxToFilename;
};
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA {
	RootObj Sup;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf0;
	NimStringV2 destFile1;
	NimStringV2 filename2;
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d3;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg {
	NI len;
	NI cap;
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q* d;
};
struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg {
	NI len;
	NI cap;
	tyTuple__DTRsWi2kgTewbhN2TT5mbA* d;
};
struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w {
	tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg traceStack;
	tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg toFree;
	NI freed;
	NI touched;
	NI edges;
	NI rcSum;
	NIM_BOOL keepThreshold;
};
struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q {
	void** Field0;
	TNimTypeV2* Field1;
};
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q {
	RootObj Sup;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf0;
	NimStringV2 file21;
};
typedef struct {
N_NIMCALL_PTR(NimStringV2, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__LCMSFwcIs5O0HdDmqpX05g;
typedef N_CLOSURE_PTR(NimStringV2, TM__5fUAZGW8WPeit3fZaQyNXA_10) (void);
typedef N_CLOSURE_PTR(NimStringV2, TM__5fUAZGW8WPeit3fZaQyNXA_11) (void);
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
struct tySequence__LqZapiAqCFeXPQZdoIAUew {
  NI len; tySequence__LqZapiAqCFeXPQZdoIAUew_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NimStringV2, ClP_0) (NimStringV2 filename_p0, void* ClE_0);
void* ClE_0;
} tyProc__oFHfEKFsiYTMAy9a42cSiKw;
typedef NU8 tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 filename_p0, NI line_p1, NI col_p2, tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g msgKind_p3, NimStringV2 arg_p4, void* ClE_0);
void* ClE_0;
} tyProc__lsy8uLKFmavBA17NQuqO5g;
typedef NimStringV2 tyArray__9cz2sUUdI81pQB2Ck7Scwnw[6];
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  NI len; tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content* p;
};
struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og data;
	NI counter;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4, void* ClE_0);
void* ClE_0;
} tyProc__9bd86QnQPXw1dUoLzfDMOKg;
typedef NU8 tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA;
struct tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ {
	RootObj Sup;
	tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* config;
	NI splitAfter;
	NI listingCounter;
	tySequence__LqZapiAqCFeXPQZdoIAUew tocPart;
	NIM_BOOL hasToc;
	NimStringV2 theIndex;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile;
	tyProc__lsy8uLKFmavBA17NQuqO5g msgHandler;
	NimStringV2 outDir;
	NimStringV2 destFile;
	tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg filenames;
	NimStringV2 filename;
	tyArray__9cz2sUUdI81pQB2Ck7Scwnw meta;
	NimStringV2 currentSection;
	tyObject_Table__tro5f9chxPVpES1mQpDwZtQ seenIndexTerms;
	NI id;
	tyProc__9bd86QnQPXw1dUoLzfDMOKg onTestSnippet;
	tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode;
	NI curQuotationDepth;
};
struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ {
  NI len; tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content* p;
};
struct tySequence__uAwiTxV3boseSy9a9cSsXHEA {
  NI len; tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content* p;
};
struct tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg {
	tySequence__uAwiTxV3boseSy9a9cSsXHEA data;
	NI counter;
};
struct tyObject_ModSection__wPQrS9bWBp9awUjfwyT8lJcA {
	tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg secItems;
	NimStringV2 finalMarkup;
};
typedef tyObject_ModSection__wPQrS9bWBp9awUjfwyT8lJcA tyArray__Yw19aj9beaCnpn27UUVel7ew[25];
struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg {
  NI len; tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content* p;
};
typedef tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg tyArray__0acqklojSPw9cxAZIw9cNlcw[25];
struct tySequence__9at3Cmn7xIajy679cMZSmybg {
  NI len; tySequence__9at3Cmn7xIajy679cMZSmybg_Content* p;
};
struct tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw {
	tySequence__9at3Cmn7xIajy679cMZSmybg data;
	NI counter;
};
typedef tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw tyArray__4HsCYUlJOw2SgmvXzHSaXA[25];
typedef NimStringV2 tyArray__O8wQyq1jirG7etVwjBjR1Q[25];
struct tySequence__eb7tUf9a8CR5sBO6O3AH67A {
  NI len; tySequence__eb7tUf9a8CR5sBO6O3AH67A_Content* p;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__lCWXucMn9bU7PUqVDK7772w {
  NI len; tySequence__lCWXucMn9bU7PUqVDK7772w_Content* p;
};
struct tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg {
	tySequence__lCWXucMn9bU7PUqVDK7772w data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__fncSH0hxktvgfMu5tiOgpw {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ {
	tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ Sup;
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ modDescPre;
	NimStringV2 modDescFinal;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	NimStringV2 modDeprecationMsg;
	tyArray__Yw19aj9beaCnpn27UUVel7ew section;
	tyArray__0acqklojSPw9cxAZIw9cNlcw tocSimple;
	tyArray__4HsCYUlJOw2SgmvXzHSaXA tocTable;
	tyArray__O8wQyq1jirG7etVwjBjR1Q toc2;
	tyArray__O8wQyq1jirG7etVwjBjR1Q toc;
	NimStringV2 indexValFilename;
	NimStringV2 analytics;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* seenSymbols;
	tySequence__eb7tUf9a8CR5sBO6O3AH67A jEntriesPre;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* jEntriesFinal;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg types;
	tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* sharedState;
	NIM_BOOL standaloneDoc;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	NI exampleCounter;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA emitted;
	NimStringV2 thisDir;
	tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg exampleGroups;
	NIM_BOOL wroteSupportFiles;
	tyObject_Table__fncSH0hxktvgfMu5tiOgpw nimToRstFid;
};
struct tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ {
	NimStringV2 rdoccmd;
	NimStringV2 docCmd;
	NimStringV2 code;
	NI index;
};
typedef NU tyArray__KznKlIbW0OmA9ckg0NfmHVQ[8];
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
typedef tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* tyArray__s9a2jZbmN9cnqFaNnzUrYEjg[8192];
struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA {
	tyArray__s9a2jZbmN9cnqFaNnzUrYEjg buckets;
	NI wordCounter;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idAnon;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idDelegator;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* emptyIdent;
};
typedef NU8 tySet_tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg;
struct tySequence__qagWYy9b8OIJNg9bWhIaAjyw {
  NI len; tySequence__qagWYy9b8OIJNg9bWhIaAjyw_Content* p;
};
typedef NU8 tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w;
struct tySequence__vz9c2digtAnM8l0FZWLUAGg {
  NI len; tySequence__vz9c2digtAnM8l0FZWLUAGg_Content* p;
};
struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw {
  NI len; tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content* p;
};
struct tyObject_Table__bzy14J3py7GGCrkIhTsFXw {
	tySequence__O9a9cp2XDKWshwC0UDgFP6Pw data;
	NI counter;
};
struct tySequence__jK2T9bFw5BWKL8ZZ854oXZg {
  NI len; tySequence__jK2T9bFw5BWKL8ZZ854oXZg_Content* p;
};
struct tySequence__vdmFdgox3dhDOMkkFi9ayfg {
  NI len; tySequence__vdmFdgox3dhDOMkkFi9ayfg_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 targetRelPath_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* Result, void* ClE_0);
void* ClE_0;
} tyProc__lYMtBEH0vEMRzoDaCw5CJg;
struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg {
  NI len; tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content* p;
};
struct tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA {
	tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg data;
	NI counter;
};
struct tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA {
	tySet_tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg options;
	tySequence__qagWYy9b8OIJNg9bWhIaAjyw hLevels;
	NI hTitleCnt;
	NI hCurLevel;
	NimStringV2 currRole;
	tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w currRoleKind;
	tySequence__vz9c2digtAnM8l0FZWLUAGg subs;
	tySequence__vz9c2digtAnM8l0FZWLUAGg refs;
	tyObject_Table__bzy14J3py7GGCrkIhTsFXw anchors;
	tySequence__jK2T9bFw5BWKL8ZZ854oXZg lineFootnoteNum;
	tySequence__jK2T9bFw5BWKL8ZZ854oXZg lineFootnoteNumRef;
	NI currFootnoteNumRef;
	tySequence__jK2T9bFw5BWKL8ZZ854oXZg lineFootnoteSym;
	tySequence__jK2T9bFw5BWKL8ZZ854oXZg lineFootnoteSymRef;
	NI currFootnoteSymRef;
	tySequence__vdmFdgox3dhDOMkkFi9ayfg footnotes;
	tyProc__lsy8uLKFmavBA17NQuqO5g msgHandler;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile;
	tyProc__lYMtBEH0vEMRzoDaCw5CJg findRefFile;
	tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg filenames;
	NI32 currFileIdx;
	tySequence__LqZapiAqCFeXPQZdoIAUew tocPart;
	NIM_BOOL hasToc;
	tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA idxImports;
	NIM_BOOL nimFileImported;
};
typedef NU8 tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA;
struct tySequence__m9axZwxFfhSNLcoofvKZJYA {
  NI len; tySequence__m9axZwxFfhSNLcoofvKZJYA_Content* p;
};
struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ {
	tySequence__m9axZwxFfhSNLcoofvKZJYA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__fXWXs2NlFKREhy9cn6vokJw {
  NI len; tySequence__fXWXs2NlFKREhy9cn6vokJw_Content* p;
};
struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g {
	NIM_BOOL isUnquoted;
	tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA kind;
union{
	struct {
	NimStringV2 str;
} _kind_1;
	struct {
	NI64 num;
} _kind_2;
	struct {
	NF fnum;
} _kind_3;
	struct {
	NIM_BOOL bval;
} _kind_4;
	struct {
	tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ fields;
} _kind_6;
	struct {
	tySequence__fXWXs2NlFKREhy9cn6vokJw elems;
} _kind_7;
};
};
struct tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* json;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* rst;
	NimStringV2 rstField;
};
struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA {
	tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w kind;
union{
	struct {
	NimStringV2 text;
} _kind_1;
	struct {
	NimStringV2 labelFmt;
} _kind_2;
	struct {
	NimStringV2 lineIndent;
} _kind_3;
	struct {
	NimStringV2 adType;
} _kind_4;
	struct {
	NI level;
} _kind_5;
	struct {
	NI order;
} _kind_6;
	struct {
	NI quotationDepth;
} _kind_7;
	struct {
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
} _kind_8;
	struct {
	NimStringV2 tooltip;
} _kind_9;
	struct {
	NI colCount;
} _kind_10;
	struct {
	NIM_BOOL endsHeader;
} _kind_11;
	struct {
	NI span;
} _kind_12;
};
	NimStringV2 anchor;
	tySequence__LqZapiAqCFeXPQZdoIAUew sons;
};
struct tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg {
	NimStringV2 content;
	NimStringV2 sortName;
};
struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA {
  NI len; tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content* p;
};
struct tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg {
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ descRst;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ substitutions;
	NimStringV2 sortName;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
	NimStringV2 anchor;
	NimStringV2 name;
	NimStringV2 detailedName;
};
struct tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ {
	NIM_BOOL isRst;
union{
	struct {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* rst;
} _isRst_1;
	struct {
	NimStringV2 str;
} _isRst_2;
};
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU8 tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg;
typedef NU8 tyEnum_MsgClass__n9ca9cM20fZgCJnzACrVYWGA;
typedef NU8 tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA;
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
	NimStringV2 Field0;
	NI Field1;
};
struct tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ {
	RootObj Sup;
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d0;
	NimStringV2 outp1;
};
struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig {
	NI a;
	NI b;
};
typedef NimStringV2 tyArray__ftd030ZQb0rgyFYIoQaqFA[10];
typedef N_CLOSURE_PTR(NimStringV2, TM__5fUAZGW8WPeit3fZaQyNXA_93) (NimStringV2 cmd_p0);
typedef NU8 tySet_tyEnum_ProcessOption__f8zQPCJAq3Y51oMx2CR9cxw;
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
typedef NU8 tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA;
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
typedef NU8 tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q;
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__al2p7ldDMvbBVYNFCuu4Rw[2];
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__T69aiRC686UsUPVrEM9awLDA {
  NI len; tySequence__T69aiRC686UsUPVrEM9awLDA_Content* p;
};
typedef NU16 tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
typedef NU8 tySet_tyEnum_Section__kFwo9cQo4Vx5PNnUQphuHtw;
struct tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw {
	NI indent;
	NI lineLen;
	NI col;
	NI pos;
	NI idx;
	tySequence__T69aiRC686UsUPVrEM9awLDA tokens;
	NimStringV2 buf;
	NI pendingNL;
	NI pendingWhitespace;
	tySequence__9ahcSjIErJohSBBFLwuF56Q comStack;
	tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg flags;
	tySet_tyEnum_Section__kFwo9cQo4Vx5PNnUQphuHtw inside;
	NIM_BOOL checkAnon;
	NI inPragma;
	NI32 fid;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA mangler;
};
struct tySequence__4eQHGndY6XBYpFOH09apV8Q {
  NI len; tySequence__4eQHGndY6XBYpFOH09apV8Q_Content* p;
};
struct tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw {
	NimStringV2 symKind;
	NimStringV2 symTypeKind;
	NimStringV2 name;
	NimStringV2 generics;
	NIM_BOOL isGroup;
	NIM_BOOL parametersProvided;
	tySequence__4eQHGndY6XBYpFOH09apV8Q parameters;
	NimStringV2 outType;
};
typedef NU8 tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA;
typedef NU8 tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw;
typedef NU8 tySet_tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw[21];
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__Nwi28HyTG9cEj6FfWArgLbQ[1];
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ[3];
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__TAsXwXSUBvAawE1kIQ5ziQ[1];
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
typedef NU8 tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ;
typedef NimStringV2 tyArray__A2YC0h9cZydgH7zGAndH9bLg[6];
typedef NimStringV2 tyArray__hSrJSIaqyFxuH67Wd7apZQ[8];
struct tySequence__SFipDZIkFtPcrLs0AGBBjQ {
  NI len; tySequence__SFipDZIkFtPcrLs0AGBBjQ_Content* p;
};
struct tyObject_Table__I1hAea2wVUrLyIxtQj9cheA {
	tySequence__SFipDZIkFtPcrLs0AGBBjQ data;
	NI counter;
};
struct tyTuple__M7ImznM2hk9a9beBDTxcwGeg {
	NimStringV2 Field0;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field1;
};
typedef tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyArray__GPOoWfHUB3hkY9cTO9a64aBQ[4];
typedef tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyArray__RoVffB9aih5q3xLhl7ODfeQ[3];
typedef tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyArray__QVwsJe5kly9bx1OOTWRPirA[2];
typedef tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyArray__OVeR5N7j5qJxmEceQoHGOw[1];
typedef NU8 tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA;
struct tyTuple__30Ti2rm9aDSr5neUSZP6EVQ {
	NI Field0;
	NimStringV2 Field1;
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA Field2;
};
struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ {
	NI len;
	void* p;
};
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (NimStringV2 x_p0, NimStringV2 y_p1, void* ClE_0);
void* ClE_0;
} tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA;
typedef NU8 tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA;
typedef N_CLOSURE_PTR(NI, TM__5fUAZGW8WPeit3fZaQyNXA_461) (NimStringV2 x_p0, NimStringV2 y_p1, void* ClE_0);
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* x_p0, tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* y_p1, void* ClE_0);
void* ClE_0;
} tyProc__LEXkfikBreOpENJW4Qw2Tg;
typedef N_CLOSURE_PTR(NI, TM__5fUAZGW8WPeit3fZaQyNXA_462) (tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* x_p0, tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* y_p1, void* ClE_0);
struct tyTuple__kNIN44R9cL9cYoYzXmSW4y7w {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* Field3;
};
typedef NimStringV2 tyArray__CVH4DKy6jsFwcdfgh9ceJxQ[16];
struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg {
	Exception Sup;
};
struct tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q {
	tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg Sup;
};
typedef NimStringV2 tyArray__wgmwCG2MY84OFtPmYaVG9bA[14];
struct tyTuple__RrY3dT8dfTceE0s6Bv9bxJw {
	NI Field0;
	NimStringV2 Field1;
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg Field2;
};
typedef N_CLOSURE_PTR(NI, TM__5fUAZGW8WPeit3fZaQyNXA_566) (NimStringV2 x_p0, NimStringV2 y_p1, void* ClE_0);
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* x_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* y_p1, void* ClE_0);
void* ClE_0;
} tyProc__uvNcvuBCVAehqicKbFevrQ;
typedef N_CLOSURE_PTR(NI, TM__5fUAZGW8WPeit3fZaQyNXA_567) (tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* x_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* y_p1, void* ClE_0);
typedef N_CLOSURE_PTR(NI, TM__5fUAZGW8WPeit3fZaQyNXA_578) (tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* x_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* y_p1, void* ClE_0);
typedef NimStringV2 tyArray__E9cjy83smb5N4sXLGk0xt3w[22];
typedef NimStringV2 tyArray__pWlgt9ctxOw6ipY8HFli9aAQ[28];
typedef NU8 tySet_tyEnum_CopyFlag__1j5oUmplkZXgil3SrVhR7g;
typedef NU8 tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg;
typedef NimStringV2 tyArray__TTqeMuXKmfkD8gA7Zp8opA[26];
struct tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw {
	RootObj Sup;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf0;
};
struct tySequence__36jA1xDCIBAS29cySYLQ7kQ {
  NI len; tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content* p;
};
struct tySequence__mg32q50AXD9cQ6jovpBmgWA {
  NI len; tySequence__mg32q50AXD9cQ6jovpBmgWA_Content* p;
};
struct tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw {
	tySequence__mg32q50AXD9cQ6jovpBmgWA data;
	NI counter;
};
struct tyTuple__i2GOAy1W4iVZ1R13oxrTvA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ Field0;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ Field1;
	tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw Field2;
};
struct tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ {
	tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ kind;
	NimStringV2 keyword;
	NimStringV2 link;
	NimStringV2 linkTitle;
	NimStringV2 linkDesc;
	NI line;
	NimStringV2 module;
	NimStringV2 aux;
};
struct tyTuple__bvjw5f4vMpB9bESWLU7nvyA {
	NI Field0;
	tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ Field1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ Field2;
};
struct tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg {
	RootObj Sup;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf0;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__LqZapiAqCFeXPQZdoIAUew_Content { NI cap; tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* data[SEQ_DECL_SIZE]; };
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
	NI Field0;
	NimStringV2 Field1;
	NI Field2;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content { NI cap; tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE]; };
struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content { NI cap; tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ data[SEQ_DECL_SIZE]; };
struct tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content { NI cap; tyTuple__30Ti2rm9aDSr5neUSZP6EVQ data[SEQ_DECL_SIZE]; };
struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content { NI cap; tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg data[SEQ_DECL_SIZE]; };
struct tySequence__9at3Cmn7xIajy679cMZSmybg_Content { NI cap; tyTuple__RrY3dT8dfTceE0s6Bv9bxJw data[SEQ_DECL_SIZE]; };
struct tySequence__eb7tUf9a8CR5sBO6O3AH67A_Content { NI cap; tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tySequence__lCWXucMn9bU7PUqVDK7772w_Content { NI cap; tyTuple__kNIN44R9cL9cYoYzXmSW4y7w data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ {
	NIM_CHAR symbol;
	NIM_BOOL hasOverline;
	NI line;
	NIM_BOOL hasPeers;
};
struct tySequence__qagWYy9b8OIJNg9bWhIaAjyw_Content { NI cap; tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_SubstitutionKind__juwrhPkgYiHpJAKqmfpbPw;
struct tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A {
	tyEnum_SubstitutionKind__juwrhPkgYiHpJAKqmfpbPw kind;
	NimStringV2 key;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* value;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
};
struct tySequence__vz9c2digtAnM8l0FZWLUAGg_Content { NI cap; tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A data[SEQ_DECL_SIZE]; };
struct tySequence__ib5UTyrs9aC6K60sNqKElQA {
  NI len; tySequence__ib5UTyrs9aC6K60sNqKElQA_Content* p;
};
struct tyTuple__Na59bk2YQTCLBWTLyeMrWdA {
	NI Field0;
	NimStringV2 Field1;
	tySequence__ib5UTyrs9aC6K60sNqKElQA Field2;
};
struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content { NI cap; tyTuple__Na59bk2YQTCLBWTLyeMrWdA data[SEQ_DECL_SIZE]; };
struct tySequence__jK2T9bFw5BWKL8ZZ854oXZg_Content { NI cap; tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_FootnoteType__AwBNmZfS9azDCP9cRgTUCl6g;
struct tyTuple__4Ywt2LYBMs9aMJ09cL7digow {
	tyEnum_FootnoteType__AwBNmZfS9azDCP9cRgTUCl6g Field0;
	NI Field1;
	NI Field2;
	NI Field3;
	NimStringV2 Field4;
};
struct tySequence__vdmFdgox3dhDOMkkFi9ayfg_Content { NI cap; tyTuple__4Ywt2LYBMs9aMJ09cL7digow data[SEQ_DECL_SIZE]; };
struct tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ {
	NIM_BOOL used;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA fromInfo;
	NimStringV2 idxPath;
	NimStringV2 linkRelPath;
	NimStringV2 title;
};
struct tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng {
	NI Field0;
	NimStringV2 Field1;
	tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ Field2;
};
struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content { NI cap; tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng data[SEQ_DECL_SIZE]; };
struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field3;
};
struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content { NI cap; tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ data[SEQ_DECL_SIZE]; };
struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content { NI cap; tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* data[SEQ_DECL_SIZE]; };
struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content { NI cap; tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ {
	tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA kind;
	NI32 length;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tySequence__T69aiRC686UsUPVrEM9awLDA_Content { NI cap; tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ data[SEQ_DECL_SIZE]; };
struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content { NI cap; tyTuple__UV3llMMYFckfui8YMBuUZA data[SEQ_DECL_SIZE]; };
struct tyTuple__8ZxhPt1NwfElsJs8zUSV9bg {
	NI Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
struct tySequence__SFipDZIkFtPcrLs0AGBBjQ_Content { NI cap; tyTuple__8ZxhPt1NwfElsJs8zUSV9bg data[SEQ_DECL_SIZE]; };
struct tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content { NI cap; tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ data[SEQ_DECL_SIZE]; };
struct tySequence__mg32q50AXD9cQ6jovpBmgWA_Content { NI cap; tyTuple__bvjw5f4vMpB9bESWLU7nvyA data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_AnchorRule__EbWqr3fy26ujwRNegmj44Q;
typedef NU8 tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ;
struct tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA {
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
	NI priority;
	tyEnum_AnchorRule__EbWqr3fy26ujwRNegmj44Q kind;
union{
	struct {
	tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ anchorType;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* target;
} _kind_1;
	struct {
	tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ anchorTypeExt;
	NimStringV2 refnameExt;
} _kind_2;
	struct {
	NI32 module;
	NimStringV2 tooltip;
	tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw langSym;
	NimStringV2 refname;
	NIM_BOOL external;
} _kind_3;
};
};
struct tySequence__ib5UTyrs9aC6K60sNqKElQA_Content { NI cap; tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA data[SEQ_DECL_SIZE]; };
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u13934)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13852)(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___docgen_u13864)(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* dest_p0, void* env_p1);
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1);
static N_INLINE(void, add__system_u3018)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3026)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u2138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg** dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOutFile2__docgen_u1907)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NimStringV2 ext_p2, NIM_BOOL guessTarget_p3);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringV2 dir_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, slash___pathutils_u135)(NimStringV2 base_p0, NimStringV2 f_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, noschangeFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
static N_INLINE(NIM_BOOL, isEmpty__options_u3633)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, absOutFile__options_u3622)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOutFile__options_u3612)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NimStringV2 ext_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, presentationPath__docgen_u1793)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 file_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14049)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13977)(tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u3939)(NimStringV2 x_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getRelativePathFromConfigPath__options_u3934)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL isTitle_p2);
N_LIB_PRIVATE N_CLOSURE(NimStringV2, nimbleDir__docgen_u1802)(void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosparentDir)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimbleFile__options_u3711)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_u139)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, relativeTo__pathutils_u196)(NimStringV2 fullPath_p0, NimStringV2 baseFilename_p1, NIM_CHAR sep_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringV2 dir_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosexpandFilename)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, nossplitPath)(NimStringV2 path_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZprivateZospaths2_u306)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuReplaceStr)(NimStringV2 s_p0, NimStringV2 sub_p1, NimStringV2 by_p2);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__stdZassertions_u79)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14010)(tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3466)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14052)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2078)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u519)(tySequence__kxu4GK0onha2t9bo86mdVAg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3085)(tySequence__lCWXucMn9bU7PUqVDK7772w dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u100)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u66)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u274)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u2567)(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u70)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2896)(tySequence__eb7tUf9a8CR5sBO6O3AH67A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstast_u173)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2732)(tySequence__9at3Cmn7xIajy679cMZSmybg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2579)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2263)(tySequence__uAwiTxV3boseSy9a9cSsXHEA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5506)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2125)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u577)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u1172)(tySequence__7lEisrXlQEzwtUKW5pzRCw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstast_u152)(tySequence__LqZapiAqCFeXPQZdoIAUew dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___docgen_u2090)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* dest_p0, void* env_p1);
static N_INLINE(void, nimTraceRef)(void* q_p0, TNimTypeV2* desc_p1, void* env_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u3469)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ** dest_p0, tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* src_p1, NIM_BOOL cyclic_p2);
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___idents_u341)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA** dest_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrst_u3752)(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA** dest_p0, tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA*, newRstSharedState__packagesZdocutilsZrst_u2425)(tySet_tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg options_p0, NimStringV2 filename_p1, tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile_p2, tyProc__lYMtBEH0vEMRzoDaCw5CJg findRefFile_p3, tyProc__lsy8uLKFmavBA17NQuqO5g msgHandler_p4, NIM_BOOL hasToc_p5);
N_LIB_PRIVATE N_CLOSURE(NimStringV2, docgenFindFile__docgen_u1972)(NimStringV2 sX60gensym51__p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findFile__options_u4081)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL suppressStdlib_p2);
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosjoinPath)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_CLOSURE(void, docgenFindRefFile__docgen_u1975)(NimStringV2 targetRelPathX60gensym51__p0, tyTuple__UV3llMMYFckfui8YMBuUZA* Result, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringV2 path_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuReplaceChar)(NimStringV2 s_p0, NIM_CHAR sub_p1, NIM_CHAR by_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosrelativePath)(NimStringV2 path_p0, NimStringV2 base_p1, NIM_CHAR sep_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZos_u200)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_CLOSURE(void, compilerMsgHandler__docgen_u1956)(NimStringV2 filenameX60gensym51__p0, NI lineX60gensym51__p1, NI colX60gensym51__p2, tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g msgKindX60gensym51__p3, NimStringV2 argX60gensym51__p4, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_MsgClass__n9ca9cM20fZgCJnzACrVYWGA, whichMsgClass__packagesZdocutilsZrst_u608)(tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g k_p0);
static N_INLINE(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, newLineInfo__msgs_u436)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NI line_p2, NI col_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, newLineInfo__msgs_u419)(NI32 fileInfoIdx_p0, NI line_p1, NI col_p2);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u404)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__lineinfos_u299)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3741)(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, initRstGenerator__packagesZdocutilsZrstgen_u86)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* g_p0, tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p1, tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* config_p2, NimStringV2 filename_p3, tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile_p4, tyProc__lsy8uLKFmavBA17NQuqO5g msgHandler_p5, tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg* filenames_p6, NIM_BOOL hasToc_p7);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLatexCmd__docgen_u1921)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsthasKey)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOrDefault__pureZstrtabs_u390)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1, NimStringV2 default_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZstrtabs_u536)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg** dest_p0, tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg*, nstnewStringTable)(tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA mode_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZstrtabs_u525)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZjson_u333)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** dest_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, newJArray__pureZjson_u506)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u324)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6347)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* dest_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg, initStrTable__ast_u6321)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6338)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u3501)(tyProc__9bd86QnQPXw1dUoLzfDMOKg* dest_p0, tyProc__9bd86QnQPXw1dUoLzfDMOKg src_p1);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_u1993)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* gen_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14086)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13788)(tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u2034)(tyTuple__XOVT24GHXwqiEj5GCsEGCA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pathutils_u73)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13815)(tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, slash___pathutils_u166)(NimStringV2 base_p0, NimStringV2 f_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimcacheDir__options_u3737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_u39)(NimStringV2 x_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, writeFile__stdZsyncio_u532)(NimStringV2 filename_p0, NimStringV2 content_p1);
N_LIB_PRIVATE N_CLOSURE(NimStringV2, interpSnippetCmd__docgen_u2009)(NimStringV2 cmd_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringV2 s_p0, NimStringV2 prefix_p1);
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1314)(NimStringV2 s_p0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
static N_INLINE(tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig, dotdot___stdZenumutils_u106)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nospquoteShell)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetAppFilename)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u144)(tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw e_p0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__XOVT24GHXwqiEj5GCsEGCA, execCmdEx__pureZosproc_u1990)(NimStringV2 command_p0, tySet_tyEnum_ProcessOption__f8zQPCJAq3Y51oMx2CR9cxw options_p1, tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* env_p2, NimStringV2 workingDir_p3, NimStringV2 input_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA*, eqdup___docgen_u13898)(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZcollectionsZintsets_u236)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* src_p1);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_u37)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u17753)(tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13891)(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, findPragma__trees_u294)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw which_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genDeprecationMsg__docgen_u6432)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getConfigVar__options_u3603)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, NimStringV2 default_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, escape__pureZxmltree_u1069)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, setDoctype__docgen_u9685)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuToLowerAsciiStr)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___nodekinds_u168)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw e_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u129)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* rst_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u132)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* x_p0, tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, eqdup___packagesZdocutilsZrstast_u291)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, genComment__docgen_u3537)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, comment__ast_u836)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, newRstLeaf__packagesZdocutilsZrstast_u454)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NI32, addRstFileIndex__docgen_u1723)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, addRstFileIndex__docgen_u200)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NI32 fileIndex_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, getOrDefault__docgen_u271)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw t_p0, NI32 key_p1, NI32 def_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, addFilename__packagesZdocutilsZrst_u863)(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* s_p0, NimStringV2 file1_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___docgen_u708)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw* t_p0, NI32 key_p1, NI32 val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, parseRst__docgen_u1900)(NimStringV2 text_p0, NI line_p1, NI column_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3, tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* sharedState_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, rstParsePass1__packagesZdocutilsZrst_u15585)(NimStringV2 fragment_p0, NI line_p1, NI column_p2, tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* sharedState_p3);
static N_INLINE(NI, toLinenumber__msgs_u695)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0);
static N_INLINE(NI, toColumn__msgs_u698)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstast_u285)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* dest_p0);
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, newRstNode__packagesZdocutilsZrstast_u121)(tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w kind_p0, tySequence__LqZapiAqCFeXPQZdoIAUew sons_p1, NimStringV2 anchor_p2);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3661)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(void, documentRaises__docgen_u9832)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, documentEffect__docgen_u9781)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw effectType_p3, NI idx_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, effectSpec__trees_u307)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw effectType_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4095)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NI children_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeToString__types_u54)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q prefer_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8664)(NimStringV2 s_p0, NI first_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIdentNode__ast_u5164)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTreeI__ast_u4180)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p2, NI children_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___wordrecg_u307)(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw e_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, documentWriteEffect__docgen_u9810)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flag_p2, NimStringV2 pragmaName_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, documentNewEffect__docgen_u9772)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genItem__docgen_u6544)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nameNode_p2, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p3, tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA docFlags_p4, NIM_BOOL nonExports_p5);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVisible__docgen_u6310)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astyaml_u223)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2284)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZdochelpers_u159)(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___renderer_u402)(tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getName__docgen_u6374)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderDefinitionName__renderer_u125)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, NIM_BOOL noQuotes_p1);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, esc__packagesZdocutilsZrstgen_u264)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2 s_p1, NI splitAfter_p2, tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPlainDocstring__docgen_u3590)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, getAllRunnableExamples__docgen_u6291)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getRoutineBody__docgen_u6271)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw, getAllRunnableExamplesImpl__docgen_u6220)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p2, tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw state_p3, NIM_BOOL topLevel_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, genRecComment__docgen_u3574)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrstast_u294)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA** dest_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, genRecCommentAux__docgen_u3549)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, commenteq___ast_u1334)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isRunnableExamples__trees_u411)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareExample__docgen_u4111)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL topLevel_p2, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u707)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toMsgFilename__msgs_u688)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, extractRunnableExamplesSource__renderverbatim_u95)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI indent_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, exampleOutputDir__docgen_u3687)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosextractFilename)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTree__ast_u4170)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p1, NI children_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5422)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NimStringV2 strVal_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderModule__renderer_u2169)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NimStringV2 outfile_p1, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p2, NI32 fid_p3, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p4);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1833)(NimStringV2 s_p0, NimStringV2 sub_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___docgen_u4140)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* x_p0);
N_LIB_PRIVATE N_NIMCALL(void, toInstantiationInfo__docgen_u4107)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyTuple__kN8up2W6YKc5YA9avn5mV5w* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___msgs_u1579)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, quoted__docgen_u4100)(NimStringV2 a_p0);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZprivateZoscommon_u120)(NimStringV2* s_p0, NimStringV2 x_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__docgen_u4238)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___docgen_u4623)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1, tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* val_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3106)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* dest_p0);
static N_INLINE(NI, len__docgen_u3743)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ**, X5BX5D___docgen_u5918)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonicalImport__options_u4253)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 file_p1);
N_LIB_PRIVATE N_NIMCALL(void, nsuAddf)(NimStringV2* s_p0, NimStringV2 formatstr_p1, NimStringV2* a_p2, NI a_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u193)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0, NimStringV2 str_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderNimCode__packagesZdocutilsZrstgen_u3815)(NimStringV2* result_p0, NimStringV2 code_p1, tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p2);
N_LIB_PRIVATE N_NIMCALL(void, initTokRender__renderer_u2186)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p1, tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw* Result);
N_LIB_PRIVATE N_NIMCALL(void, getNextTok__renderer_u2190)(tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw* r_p0, tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA* kind_p1, NimStringV2* literal_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getDeclPragma__ast_u3932)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuStrip)(NimStringV2 s_p0, NIM_BOOL leading_p1, NIM_BOOL trailing_p2, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeKind__docgen_u6464)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHumanStr__ast_u7574)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderPlainSymbolName__typesrenderer_u9)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, complexName__docgen_u6413)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 baseName_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderParamTypes__typesrenderer_u146)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NimStringV2 sep_p1, NIM_BOOL toNormalize_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, encodeUrl__pureZuri_u84)(NimStringV2 s_p0, NIM_BOOL usePlus_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, newUniquePlainSymbol__docgen_u6404)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NimStringV2 original_p1);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1, NimStringV2 val_p2);
N_LIB_PRIVATE N_NIMCALL(void, toLangSymbol__docgen_u6467)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 baseName_p2, tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimIdentNormalize__pureZstrutils_u124)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, renderParamTypes__typesrenderer_u111)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* found_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL toNormalize_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, renderParamNames__typesrenderer_u67)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NIM_BOOL toNormalize_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZdochelpers_u247)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderOutType__typesrenderer_u159)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NIM_BOOL toNormalize_p1);
N_LIB_PRIVATE N_NIMCALL(void, addAnchorNim__packagesZdocutilsZrst_u5936)(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA** s_p0, NIM_BOOL external_p1, NimStringV2 refn_p2, NimStringV2 tooltip_p3, tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* langSym_p4, NI priority_p5, tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info_p6, NI32 module_p7);
N_LIB_PRIVATE N_NIMCALL(NI, symbolPriority__docgen_u6461)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p0);
N_LIB_PRIVATE N_NIMCALL(void, nodeToHighlightedHtml__docgen_u3616)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p3, NimStringV2 procLink_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getTokSym__renderer_u2208)(tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw* r_p0);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToProjectPackage__packages_u81)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, externalDep__docgen_u3602)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genSeeSrc__docgen_u6450)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NimStringV2 path_p1, NI line_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u7984)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* x_p0, tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__b9cVyuSHmrW80P0ZGgU2KHA*, mgetOrPut__docgen_u6713)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0, NimStringV2 key_p1, tySequence__b9cVyuSHmrW80P0ZGgU2KHA val_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2305)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ, eqdup___docgen_u2131)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ src_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2147)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* s_p0, NI newlen_p1);
static N_INLINE(void, nimIncRef)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, eqdup___system_u5512)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__b9cVyuSHmrW80P0ZGgU2KHA, newSeq__docgen_u6649)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2122)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, attachToType__docgen_u1860)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* p_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, whichType__docgen_u1842)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, strTableContains__astalgo_u2567)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg t_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setIndexTerm__packagesZdocutilsZrstgen_u353)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ k_p1, NimStringV2 htmlFile_p2, NimStringV2 id_p3, NimStringV2 term_p4, NimStringV2 linkTitle_p5, NimStringV2 linkDesc_p6, NI line_p7);
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, docstringSummary__docgen_u6423)(NimStringV2 rstText_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringV2 s_p0, NIM_CHAR sub_p1, NI start_p2, NI last_p3);
N_LIB_PRIVATE N_NIMCALL(void, setLengthStrV2)(NimStringV2* s_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindCharSet)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p1, NI start_p2, NI last_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u8039)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* x_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg*, mgetOrPut__docgen_u8144)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* t_p0, NimStringV2 key_p1, tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg val_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2600)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg, newSeq__docgen_u8080)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_u2666)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* t_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, generateDoc__docgen_u9898)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* orig_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p3, tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA docFlags_p4);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkForFalse__docgen_u9720)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void, traceDeps__docgen_u9727)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, prettyLink__packagesZdocutilsZrstgen_u81)(NimStringV2 file_p0);
N_LIB_PRIVATE N_NIMCALL(void, exportSym__docgen_u9748)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, originatingModule__ast_u7142)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u9972)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* x_p0, tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* y_p1, NI y_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u11752)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* j_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___pureZjson_u2433)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u11759)(tySequence__eb7tUf9a8CR5sBO6O3AH67A* x_p0, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdup___docgen_u2970)(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* src_p0, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___docgen_u11810)(tyObject_Table__I1hAea2wVUrLyIxtQj9cheA table_p0);
N_LIB_PRIVATE N_NIMCALL(void, genJsonItem__docgen_u9423)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nameNode_p2, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p3, NIM_BOOL nonExports_p4, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNameEsc__docgen_u6382)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___pureZjson_u2187)(tyTuple__M7ImznM2hk9a9beBDTxcwGeg* keyVals_p0, NI keyVals_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___pureZjson_u2158)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u309)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q e_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___pureZjson_u2168)(NI n_p0);
static N_INLINE(void, X5BX5Deq___pureZjson_u2308)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* obj_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pureZjson_u739)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, eqdup___pureZjson_u330)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstast_u282)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, newJObject__pureZjson_u443)(void);
static N_INLINE(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, X5BX5D___pureZjson_u3478)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NimStringV2 name_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZjson_u327)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** dest_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g**, X5BX5D___pureZjson_u3048)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___renderer_u2166)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__pureZjson_u662)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* father_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* child_p1);
static N_INLINE(NI, len__ast_u5502)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2964)(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, generateJson__docgen_u11779)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p2, NIM_BOOL includeComments_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrst_u17756)(tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg* dest_p0, tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrstast_u288)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA** dest_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, preparePass2__packagesZdocutilsZrst_u16267)(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA** s_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* mainNode_p1, NIM_BOOL importdoc_p2);
N_LIB_PRIVATE N_NIMCALL(void, traverseForIndex__packagesZdocutilsZrstgen_u4022)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, setIndexTitle__docgen_u10022)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NIM_BOOL useMetaTitle_p1);
N_LIB_PRIVATE N_NIMCALL(NI, len__docgen_u10125)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg t_p0);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2287)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* dest_p0, tySequence__b9cVyuSHmrW80P0ZGgU2KHA src_p1);
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2128)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u5509)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, overloadGroupName__docgen_u10018)(NimStringV2 s_p0, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u5503)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, sorted__docgen_u10907)(NimStringV2* a_p0, NI a_p0Len_0, tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA cmp_p1, tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA order_p2);
N_LIB_PRIVATE N_NIMCALL(NI, cmpDecimalsIgnoreCase__docgen_u1727)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuIsDigitChar)(NIM_CHAR c_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__b9cVyuSHmrW80P0ZGgU2KHA*, X5BX5D___docgen_u11008)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, sort__docgen_u11077)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* a_p0, NI a_p0Len_0, tyProc__LEXkfikBreOpENJW4Qw2Tg cmp_p1, tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA order_p2);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__docgen_u10448)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* x_p0, tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderItemPre__docgen_u10420)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ fragments_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, resolveSubs__packagesZdocutilsZrst_u17344)(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* s_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderRstToOut__packagesZdocutilsZrstgen_u324)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, amp___docgen_u11262)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ x_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ y_p1);
N_LIB_PRIVATE N_NIMCALL(void, clear__docgen_u11354)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2967)(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* dest_p0, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, completePass2__packagesZdocutilsZrst_u17450)(tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, indexFile__docgen_u13371)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0);
N_LIB_PRIVATE N_NIMCALL(void, runAllExamples__docgen_u3690)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u4006)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ** dest_p0, tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* src_p1);
static N_INLINE(NimStringV2, findNodeJs__nodejs_u2)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findExe__pureZos_u76)(NimStringV2 exe_p0, NIM_BOOL followSymlinks_p1, NimStringV2* extensions_p2, NI extensions_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringV2* args_p0, NI args_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4);
N_LIB_PRIVATE N_NIMCALL(NI, nosexecShellCmd)(NimStringV2 command_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, prettyString__docgen_u4068)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, quit__system_u7994)(NimStringV2 errormsg_p0, NI errorcode_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, msgKindToString__msgs_u867)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA kind_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u4003)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genOutFile__docgen_u13298)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NIM_BOOL groupedToc_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntries__packagesZdocutilsZrstgen_u3698)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NI* j_p1, NI lvl_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(void, genSection__docgen_u12338)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p1, NIM_BOOL groupedToc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, len__docgen_u12624)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2582)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* dest_p0, tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg*, X5BX5D___docgen_u12867)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, sort__docgen_u12936)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* a_p0, NI a_p0Len_0, tyProc__uvNcvuBCVAehqicKbFevrQ cmp_p1, tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA order_p2);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__docgen_u12350)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* x_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg, sorted__docgen_u13140)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* a_p0, NI a_p0Len_0, tyProc__uvNcvuBCVAehqicKbFevrQ cmp_p1, tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA order_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getDateStr__options_u643)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getClockStr__options_u651)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, relLink__docgen_u13289)(NimStringV2 outDir_p0, NimStringV2 destFile_p1, NimStringV2 linkto_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___docgen_u13294)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(void, write__stdZsyncio_u254)(FILE* f_p0, NimStringV2 s_p1);
N_LIB_PRIVATE N_NIMCALL(void, updateOutfile__docgen_u13384)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NimStringV2 outfile_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u4029)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPrefixDir__options_u3645)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, noscopyFile)(NimStringV2 source_p0, NimStringV2 dest_p1, tySet_tyEnum_CopyFlag__1j5oUmplkZXgil3SrVhR7g options_p2, NI bufferSize_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, interp__nimpaths_u27)(NimStringV2 path_p0, NimStringV2 nimr_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getDocHacksJs__nimpaths_u94)(NimStringV2 nimr_p0, NimStringV2 nim_p1, NIM_BOOL forceRebuild_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, noslastPathPart)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeIndexFile__packagesZdocutilsZrstgen_u211)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* g_p0, NimStringV2 outfile_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPackageName__options_u3730)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1);
static N_INLINE(void, writeLine__msgs_u470)(FILE* f_p0, NimStringV2* x_p1, NI x_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___pureZjson_u4831)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__stdZsyncio_u412)(FILE** f_p0, NimStringV2 filename_p1, tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg mode_p2, NI bufSize_p3);
N_LIB_PRIVATE N_NIMCALL(void, close__stdZsyncio_u268)(FILE* f_p0);
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__docgen_u13475)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, parseFile__syntaxes_u235)(NI32 fileIdx_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ*, newDocumentor__docgen_u1928)(NimStringV2 filename_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2, NimStringV2 outExt_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p4, NIM_BOOL standaloneDoc_p5, NIM_BOOL preferMarkdown_p6, NIM_BOOL hasToc_p7);
N_LIB_PRIVATE N_NIMCALL(void, finishGenerateDoc__docgen_u10030)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ** d_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeOutput__docgen_u13398)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NIM_BOOL useWarning_p1, NIM_BOOL groupedToc_p2);
N_LIB_PRIVATE N_NIMCALL(void, generateIndex__docgen_u13377)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mergeIndexes__packagesZdocutilsZrstgen_u3543)(NimStringV2 dir_p0);
N_LIB_PRIVATE N_NIMCALL(void, commandRstAux__docgen_u13490)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, NimStringV2 filename_p2, NimStringV2 outExt_p3, NIM_BOOL preferMarkdown_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosaddFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, readFile__stdZsyncio_u527)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u2134)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ src_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14772)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14705)(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14736)(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* dest_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_u13573)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw*, eqdup___docgen_u14743)(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, pretty__pureZjson_u4827)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NI indent_p1);
N_LIB_PRIVATE N_NIMCALL(void, readIndexDir__packagesZdocutilsZrstgen_u2311)(NimStringV2 dir_p0, tyTuple__i2GOAy1W4iVZ1R13oxrTvA* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstidx_u278)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstgen_u2153)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, len__packagesZdocutilsZrstgen_u1417)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrstgen_u1602)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* x_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdup___packagesZdocutilsZrstidx_u203)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* src_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___docgen_u13709)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* elements_p0, NI elements_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___jsgen_u8347)(NimStringV2* elements_p0, NI elements_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstidx_u281)(tySequence__36jA1xDCIBAS29cySYLQ7kQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u2156)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u3613)(tyTuple__i2GOAy1W4iVZ1R13oxrTvA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14860)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14793)(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14824)(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* dest_p0);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_u13596)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg*, eqdup___docgen_u14831)(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, generateTags__docgen_u12308)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* r_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTagsItem__docgen_u12302)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nameNode_p2, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p3);
N_LIB_PRIVATE TNimTypeV2 NTIv2__F7WTziupp71j3xJKFj9ccRA_;
N_LIB_PRIVATE TNimTypeV2 NTIv2__ets57owy36keA5i1GuWy6Q_;
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_4 = { 8 | NIM_STRLIT_FLAG, "@default" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_5 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_4};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_6 = { 4 | NIM_STRLIT_FLAG, "@pkg" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_7 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_6};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_8 = { 5 | NIM_STRLIT_FLAG, "@path" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_9 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_8};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_12 = { 11 | NIM_STRLIT_FLAG, "\'$1\' failed" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_13 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_12};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_15 = { 23 | NIM_STRLIT_FLAG, "conf.docRoot.isAbsolute" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_16 = { 16 | NIM_STRLIT_FLAG, "; conf.docRoot: " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_17 = {16, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_16};
static const struct {
  NI cap; NIM_CHAR data[61+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_19 = { 61 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/docgen.nim" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_20 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_12};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_22 = { 22 | NIM_STRLIT_FLAG, "conf.docRoot.dirExists" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_23 = {16, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_16};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_25 = { 2 | NIM_STRLIT_FLAG, ".." };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_26 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_25};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_27 = { 3 | NIM_STRLIT_FLAG, "_._" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_28 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_27};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_29 = { 40 | NIM_STRLIT_FLAG, "docgen.nim(213, 3) `not result.isEmpty` " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_30 = {40, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_29};
static const struct {
  NI cap; NIM_CHAR data[51+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_31 = { 51 | NIM_STRLIT_FLAG, "docgen.nim(214, 3) `not isAbsolute(result.string)` " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_32 = {51, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_31};
N_LIB_PRIVATE TNimTypeV2 NTIv2__GoTm9bL1y89aFdwPpcNTadzQ_;
extern TNimTypeV2 NTIv2__6YauuaWEZeOKzNYK3p1vqA_;
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_34 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_35 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_36 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_38 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_40 = { 19 | NIM_STRLIT_FLAG, "doc.googleAnalytics" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_41 = {19, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_40};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_42 = { 22 | NIM_STRLIT_FLAG, "doc.plausibleAnalytics" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_43 = {22, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_42};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_44 = { 48 | NIM_STRLIT_FLAG, "Either use googleAnalytics or plausibleAnalytics" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_45 = {48, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_44};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_46 = {19, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_40};
static const struct {
  NI cap; NIM_CHAR data[402+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_47 = { 402 | NIM_STRLIT_FLAG, "<script>\012  (function(i,s,o,g,r,a,m){i[\'GoogleAnalyticsObject\']=r;i[r]=i[r]||function(){\012  (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),\012  m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)\012  })(window,document,\'script\',\'//www.google-analytics.com/analytics.js\',\'ga\');\012\012  ga(\'create\', \'$1\', \'auto\');\012  ga(\'send\', \'pageview\');\012\012</script>\012    " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_48 = {402, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_47};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_49 = { 19 | NIM_STRLIT_FLAG, "doc.googleAnalytics" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_50 = {19, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_49};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_51 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_52 = {22, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_42};
static const struct {
  NI cap; NIM_CHAR data[92+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_53 = { 92 | NIM_STRLIT_FLAG, "    <script defer data-domain=\"$1\" src=\"https://plausible.io/js/plausible.js\"></script>\012    " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_54 = {92, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_53};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_55 = { 22 | NIM_STRLIT_FLAG, "doc.plausibleAnalytics" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_56 = {22, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_55};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_57 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_58 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
N_LIB_PRIVATE TNimTypeV2 NTIv2__nWAzUKcV7eAMzCwZy3hiPQ_;
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_60 = { 4 | NIM_STRLIT_FLAG, "skip" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_61 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_60};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_62 = { 8 | NIM_STRLIT_FLAG, "snippets" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_63 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_62};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_64 = { 9 | NIM_STRLIT_FLAG, "_snippet_" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_65 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_64};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_66 = { 4 | NIM_STRLIT_FLAG, ".nim" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_67 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_66};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_68 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_69 = { 12 | NIM_STRLIT_FLAG, "import \"$1\"\012" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_70 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_69};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_71 = { 1 | NIM_STRLIT_FLAG, "\\" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_72 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_71};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_73 = { 1 | NIM_STRLIT_FLAG, "/" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_74 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_73};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_75 = { 4 | NIM_STRLIT_FLAG, "nim " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_76 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_75};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_77 = { 5 | NIM_STRLIT_FLAG, "$nim " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_78 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_77};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_79 = { 2 | NIM_STRLIT_FLAG, "$1" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_80 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_81 = { 8 | NIM_STRLIT_FLAG, "$options" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_82 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_81};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_83 = { 3 | NIM_STRLIT_FLAG, "nim" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_84 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_83};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_85 = { 7 | NIM_STRLIT_FLAG, "libpath" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_86 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_85};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_87 = { 6 | NIM_STRLIT_FLAG, "docCmd" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_88 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_87};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_89 = { 7 | NIM_STRLIT_FLAG, "backend" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_90 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_89};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_91 = { 7 | NIM_STRLIT_FLAG, "options" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_92 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_91};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_95 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_96 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[60+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_97 = { 60 | NIM_STRLIT_FLAG, "snippet failed: cmd: \'$1\' status: $2 expected: $3 output: $4" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_98 = {60, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_97};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_100 = { 18 | NIM_STRLIT_FLAG, "doc.deprecationmsg" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_101 = {18, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_100};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_102 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_104 = { 5 | NIM_STRLIT_FLAG, "label" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_105 = { 10 | NIM_STRLIT_FLAG, "Deprecated" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_106 = { 7 | NIM_STRLIT_FLAG, "message" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_107 = {18, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_100};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_108 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_109 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_104};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_110 = { 11 | NIM_STRLIT_FLAG, "Deprecated:" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_111 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_110};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_112 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_106};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_113 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_114 = { 11 | NIM_STRLIT_FLAG, "unreachable" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_115 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_114};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_116 = { 39 | NIM_STRLIT_FLAG, "doctype pragma takes exactly 1 argument" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_117 = {39, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_116};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_119 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[44+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_120 = { 44 | NIM_STRLIT_FLAG, "unknown argument type $1 provided to doctype" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_121 = {44, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_120};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_123 = { 8 | NIM_STRLIT_FLAG, "markdown" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_124 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_123};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_125 = { 11 | NIM_STRLIT_FLAG, "rstmarkdown" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_126 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_125};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_127 = { 3 | NIM_STRLIT_FLAG, "rst" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_128 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_127};
static const struct {
  NI cap; NIM_CHAR data[75+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_129 = { 75 | NIM_STRLIT_FLAG, "unknown doctype value \"$1\", should be from \"RST\", \"Markdown\", \"RstMarkdown\"" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_130 = {75, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_129};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_132 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_133 = { 4 | NIM_STRLIT_FLAG, "ref " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_134 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_133};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_135 = { 6 | NIM_STRLIT_FLAG, "writes" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_136 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_135};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_137 = { 3 | NIM_STRLIT_FLAG, "new" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_138 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_137};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_139 = { 7 | NIM_STRLIT_FLAG, "escapes" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_140 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_139};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_141 = { 1 | NIM_STRLIT_FLAG, "`" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_142 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_141};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_143 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_144 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_145 = { 2 | NIM_STRLIT_FLAG, "##" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_146 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_145};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_147 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_148 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_149 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_150 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_151 = { 37 | NIM_STRLIT_FLAG, "docgen.nim(789, 5) `result.len == 2` " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_152 = {37, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_151};
static NIM_CONST tySet_tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw TM__5fUAZGW8WPeit3fZaQyNXA_153 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04,
0x00, 0x06, 0x00, 0x00, 0xc0, 0x00, 0x08, 0x40,
0x20, 0x61, 0x20, 0x00, 0x00}
;
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_154 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_155 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_156 = { 24 | NIM_STRLIT_FLAG, "runnableExamples invalid" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_157 = {24, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_156};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_159 = { 24 | NIM_STRLIT_FLAG, "string litteral expected" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_160 = {24, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_159};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_162 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_163 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_164 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_163};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_165 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_166 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_165};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_167 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_168 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_167};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_169 = { 43 | NIM_STRLIT_FLAG, "autogenerated by docgen\012loc: $1\012rdoccmd: $2" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_170 = {43, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_169};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_171 = { 16 | NIM_STRLIT_FLAG, "runnableExamples" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_172 = {16, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_171};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_173 = { 18 | NIM_STRLIT_FLAG, "$#_examples_$#.nim" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_174 = {18, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_173};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_175 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_176 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_175};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_177 = { 14 | NIM_STRLIT_FLAG, "std/assertions" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_178 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_177};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_179 = { 14 | NIM_STRLIT_FLAG, "codeReordering" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_180 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_179};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_181 = { 17 | NIM_STRLIT_FLAG, "{.line: $#.}:\012$#\012" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_182 = {17, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_181};
static const struct {
  NI cap; NIM_CHAR data[44+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_183 = { 44 | NIM_STRLIT_FLAG, "#[\012$#\012]#\012import std/assertions\012import $#\012$#\012" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_184 = {44, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_183};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_185 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_186 = { 10 | NIM_STRLIT_FLAG, "import $1\012" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_187 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_186};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_188 = { 12 | NIM_STRLIT_FLAG, "import $#\012$#" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_189 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_188};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_190 = { 8 | NIM_STRLIT_FLAG, "Example:" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_191 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_190};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_192 = { 6 | NIM_STRLIT_FLAG, " cmd: " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_193 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_192};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_194 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_195 = { 50 | NIM_STRLIT_FLAG, "\012<p><strong class=\"examples_text\">$1</strong></p>\012" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_196 = {50, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_195};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_197 = { 14 | NIM_STRLIT_FLAG, "\012\012\\textbf{$1}\012" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_198 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_197};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_199 = { 17 | NIM_STRLIT_FLAG, "doc.listing_start" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_200 = {17, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_199};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_201 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_202 = { 7 | NIM_STRLIT_FLAG, "langNim" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_203 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_202};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_204 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_205 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_206 = { 15 | NIM_STRLIT_FLAG, "doc.listing_end" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_207 = {15, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_206};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_208 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[67+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_209 = { 67 | NIM_STRLIT_FLAG, "runnableExamples must appear before the first non-comment statement" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_210 = {67, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_209};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__5fUAZGW8WPeit3fZaQyNXA_212 = {
0x00, 0x3e, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_213 = { 4 | NIM_STRLIT_FLAG, "enum" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_214 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_213};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_215 = { 6 | NIM_STRLIT_FLAG, "object" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_216 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_215};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_217 = { 5 | NIM_STRLIT_FLAG, "tuple" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_218 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_217};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_219 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_220 = { 1 | NIM_STRLIT_FLAG, " " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_221 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_220};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_222 = { 2 | NIM_STRLIT_FLAG, ".m" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_223 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_222};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_224 = { 2 | NIM_STRLIT_FLAG, ".e" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_225 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_224};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_226 = { 2 | NIM_STRLIT_FLAG, ".i" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_227 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_226};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_228 = { 2 | NIM_STRLIT_FLAG, ".t" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_229 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_228};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_230 = { 2 | NIM_STRLIT_FLAG, ".c" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_231 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_230};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_232 = { 1 | NIM_STRLIT_FLAG, "," };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_233 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_232};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_234 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_232};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_235 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_236 = { 1 | NIM_STRLIT_FLAG, "_" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_237 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_236};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_238 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[55+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_239 = { 55 | NIM_STRLIT_FLAG, "docgen.nim(1016, 5) `paramTypes.len <= paramNames.len` " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_240 = {55, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_239};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_241 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_242 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_243 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_244 = { 31 | NIM_STRLIT_FLAG, "<span class=\"Comment\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_245 = {31, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_244};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_246 = { 16 | NIM_STRLIT_FLAG, "\\spanComment{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_247 = {16, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_246};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_248 = { 31 | NIM_STRLIT_FLAG, "<span class=\"Keyword\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_249 = {31, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_248};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_250 = { 16 | NIM_STRLIT_FLAG, "\\spanKeyword{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_251 = {16, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_250};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_252 = { 32 | NIM_STRLIT_FLAG, "<span class=\"Operator\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_253 = {32, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_252};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_254 = { 17 | NIM_STRLIT_FLAG, "\\spanOperator{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_255 = {17, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_254};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_256 = { 33 | NIM_STRLIT_FLAG, "<span class=\"StringLit\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_257 = {33, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_256};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_258 = { 18 | NIM_STRLIT_FLAG, "\\spanStringLit{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_259 = {18, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_258};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_260 = { 31 | NIM_STRLIT_FLAG, "<span class=\"CharLit\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_261 = {31, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_260};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_262 = { 16 | NIM_STRLIT_FLAG, "\\spanCharLit{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_263 = {16, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_262};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_264 = { 33 | NIM_STRLIT_FLAG, "<span class=\"DecNumber\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_265 = {33, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_264};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_266 = { 18 | NIM_STRLIT_FLAG, "\\spanDecNumber{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_267 = {18, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_266};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_268 = { 35 | NIM_STRLIT_FLAG, "<span class=\"FloatNumber\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_269 = {35, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_268};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_270 = { 20 | NIM_STRLIT_FLAG, "\\spanFloatNumber{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_271 = {20, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_270};
static const struct {
  NI cap; NIM_CHAR data[52+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_272 = { 52 | NIM_STRLIT_FLAG, "<a href=\"#$2\"><span class=\"Identifier\">$1</span></a>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_273 = {52, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_272};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_274 = { 19 | NIM_STRLIT_FLAG, "\\spanIdentifier{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_275 = {19, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_274};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_276 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_277 = { 4 | NIM_STRLIT_FLAG, "html" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_278 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_279 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_280 = { 1 | NIM_STRLIT_FLAG, "#" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_281 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_280};
static const struct {
  NI cap; NIM_CHAR data[51+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_282 = { 51 | NIM_STRLIT_FLAG, "<a href=\"$1\"><span class=\"Identifier\">$2</span></a>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_283 = {51, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_282};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_284 = { 34 | NIM_STRLIT_FLAG, "<span class=\"Identifier\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_285 = {34, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_284};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_286 = {19, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_274};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_287 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_288 = { 14 | NIM_STRLIT_FLAG, "\\spanOther{$1}" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_289 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_288};
static const struct {
  NI cap; NIM_CHAR data[82+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_290 = { 82 | NIM_STRLIT_FLAG, "<span>\012<span class=\"Other pragmadots\">...</span>\012</span>\012<span class=\"pragmawrap\">" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_291 = {82, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_290};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_292 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_293 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_292};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_294 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_295 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_288};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_296 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_297 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_288};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_298 = { 7 | NIM_STRLIT_FLAG, "</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_299 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_298};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_300 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_288};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_301 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_302 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_288};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_303 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_304 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_288};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_305 = { 29 | NIM_STRLIT_FLAG, "<span class=\"Other\">$1</span>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_306 = {29, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_305};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_307 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_288};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_308 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_309 = { 15 | NIM_STRLIT_FLAG, "doc.item.seesrc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_310 = {15, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_309};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_311 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_312 = { 7 | NIM_STRLIT_FLAG, "git.url" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_313 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_312};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_314 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_315 = { 5 | NIM_STRLIT_FLAG, "devel" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_316 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_315};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_317 = { 13 | NIM_STRLIT_FLAG, "version-$1-$2" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_318 = {13, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_317};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_319 = { 10 | NIM_STRLIT_FLAG, "git.commit" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_320 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_319};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_321 = { 9 | NIM_STRLIT_FLAG, "git.devel" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_322 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_321};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_323 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_315};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_324 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_325 = { 4 | NIM_STRLIT_FLAG, "path" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_326 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_325};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_327 = { 4 | NIM_STRLIT_FLAG, "line" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_328 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_327};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_329 = { 3 | NIM_STRLIT_FLAG, "url" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_330 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_329};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_331 = { 6 | NIM_STRLIT_FLAG, "commit" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_332 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_331};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_333 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_315};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_334 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_335 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_325};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_336 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_327};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_337 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_329};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_338 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_331};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_339 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_315};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_340 = { 10 | NIM_STRLIT_FLAG, "uniqueName" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_341 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_340};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_342 = { 6 | NIM_STRLIT_FLAG, "header" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_343 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_342};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_344 = { 6 | NIM_STRLIT_FLAG, "itemID" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_345 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_344};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_346 = { 12 | NIM_STRLIT_FLAG, "header_plain" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_347 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_346};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_348 = { 7 | NIM_STRLIT_FLAG, "itemSym" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_349 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_348};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_350 = { 10 | NIM_STRLIT_FLAG, "itemSymEnc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_351 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_350};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_352 = { 14 | NIM_STRLIT_FLAG, "itemSymOrIDEnc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_353 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_352};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_354 = { 6 | NIM_STRLIT_FLAG, "seeSrc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_355 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_354};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_356 = { 14 | NIM_STRLIT_FLAG, "deprecationMsg" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_357 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_356};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_358 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_359 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_360 = { 3 | NIM_STRLIT_FLAG, "\342\200\246" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_361 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_360};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__5fUAZGW8WPeit3fZaQyNXA_362 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x50, 0x00, 0x04,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_363 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_360};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_364 = { 12 | NIM_STRLIT_FLAG, "doc.item.toc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_365 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_364};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_366 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_367 = { 4 | NIM_STRLIT_FLAG, "name" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_368 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_367};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_369 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_346};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_370 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_352};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_371 = { 17 | NIM_STRLIT_FLAG, "doc.item.tocTable" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_372 = {17, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_371};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_373 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_374 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_367};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_375 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_346};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_376 = { 11 | NIM_STRLIT_FLAG, "itemSymOrID" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_377 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_376};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_378 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_232};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_379 = { 6 | NIM_STRLIT_FLAG, ",<wbr>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_380 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_379};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_381 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_352};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_382 = { 5 | NIM_STRLIT_FLAG, "false" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_383 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_382};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_384 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_165};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_385 = { 46 | NIM_STRLIT_FLAG, "<a class=\"reference external\" href=\"$2\">$1</a>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_386 = {46, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_385};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_387 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_388 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_389 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_390 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_165};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_391 = {46, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_385};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_392 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_393 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_394 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_395 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_165};
static const struct {
  NI cap; NIM_CHAR data[54+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_396 = { 54 | NIM_STRLIT_FLAG, "<a href=\"$2#$3\"><span class=\"Identifier\">$1</span></a>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_397 = {54, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_396};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_398 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_399 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_79};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_400 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_401 = { 7 | NIM_STRLIT_FLAG, "comment" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_402 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_401};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_403 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_367};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_404 = { 4 | NIM_STRLIT_FLAG, "type" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_405 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_404};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_406 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_327};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_407 = { 3 | NIM_STRLIT_FLAG, "col" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_408 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_407};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_409 = { 11 | NIM_STRLIT_FLAG, "description" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_410 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_409};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_411 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_409};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_412 = { 4 | NIM_STRLIT_FLAG, "code" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_413 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_412};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_414 = { 9 | NIM_STRLIT_FLAG, "signature" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_415 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_416 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_417 = { 6 | NIM_STRLIT_FLAG, "return" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_418 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_417};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_419 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_420 = { 9 | NIM_STRLIT_FLAG, "arguments" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_421 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_420};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_422 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_423 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_420};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_424 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_367};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_425 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_404};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_426 = { 7 | NIM_STRLIT_FLAG, "default" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_427 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_426};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_428 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_429 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_420};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_430 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_367};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_431 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_404};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_432 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_433 = { 7 | NIM_STRLIT_FLAG, "pragmas" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_434 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_433};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_435 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_436 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_433};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_437 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_438 = { 13 | NIM_STRLIT_FLAG, "genericParams" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_439 = {13, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_438};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_440 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_367};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_441 = { 5 | NIM_STRLIT_FLAG, "types" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_442 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_441};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_443 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_441};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_444 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_414};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_445 = {13, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_438};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_446 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_447 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_448 = { 7 | NIM_STRLIT_FLAG, "module " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_449 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_448};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_450 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_451 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_452 = { 1 | NIM_STRLIT_FLAG, "-" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_453 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_452};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_454 = { 5 | NIM_STRLIT_FLAG, "s-all" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_455 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_454};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_456 = { 17 | NIM_STRLIT_FLAG, "$1 ($2 overloads)" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_457 = {17, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_456};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_458 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_220};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_459 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_460 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_463 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_464 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_465 = { 8 | NIM_STRLIT_FLAG, "doc.item" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_466 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_465};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_467 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_468 = { 4 | NIM_STRLIT_FLAG, "desc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_469 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_468};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_470 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_367};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_471 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_376};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_472 = { 9 | NIM_STRLIT_FLAG, "doc.item2" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_473 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_472};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_474 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_475 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_346};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_476 = { 17 | NIM_STRLIT_FLAG, "overloadGroupName" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_477 = {17, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_476};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_478 = { 7 | NIM_STRLIT_FLAG, "content" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_479 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_478};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_480 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_481 = { 4 | NIM_STRLIT_FLAG, ".idx" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_482 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_481};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_483 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_60};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_484 = { 23 | NIM_STRLIT_FLAG, "$1_group$2_examples.nim" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_485 = {23, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_484};
static const struct {
  NI cap; NIM_CHAR data[55+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_486 = { 55 | NIM_STRLIT_FLAG, "# autogenerated by docgen\012# source: $1\012# rdoccmd: $2\012$3" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_487 = {55, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_486};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_488 = { 12 | NIM_STRLIT_FLAG, "--path:$path" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_489 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_488};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_490 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_325};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_491 = { 18 | NIM_STRLIT_FLAG, "$args --path:$path" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_492 = {18, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_491};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_493 = { 4 | NIM_STRLIT_FLAG, "args" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_494 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_493};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_495 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_325};
static const struct {
  NI cap; NIM_CHAR data[112+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_496 = { 112 | NIM_STRLIT_FLAG, "$nim $backend -r --lib:$libpath --warning:UnusedImport:off $pathArgs --nimcache:$nimcache $rdoccmd $docCmd $file" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_497 = {112, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_496};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_498 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_83};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_499 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_89};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_500 = { 8 | NIM_STRLIT_FLAG, "pathArgs" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_501 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_500};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_502 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_85};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_503 = { 8 | NIM_STRLIT_FLAG, "nimcache" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_504 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_503};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_505 = { 4 | NIM_STRLIT_FLAG, "file" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_506 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_505};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_507 = { 7 | NIM_STRLIT_FLAG, "rdoccmd" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_508 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_507};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_509 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_87};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_510 = { 6 | NIM_STRLIT_FLAG, "nodejs" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_511 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_510};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_512 = { 4 | NIM_STRLIT_FLAG, "node" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_513 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_512};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_515 = { 63 | NIM_STRLIT_FLAG, "Please install NodeJS first, see https://nodejs.org/en/download" };
extern TNimTypeV2 NTIv2__vBePDvr8fj01uTfaJy9aD3Q_;
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_516 = { 24 | NIM_STRLIT_FLAG, "NodeJS not found in PATH" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_517 = {24, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_516};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_518 = { 8 | NIM_STRLIT_FLAG, "nimDebug" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_519 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_518};
static const struct {
  NI cap; NIM_CHAR data[67+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_520 = { 67 | NIM_STRLIT_FLAG, "[runnableExamples] failed: generated file: \'$1\' group: \'$2\' cmd: $3" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_521 = {67, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_520};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_522 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_523 = { 9 | NIM_STRLIT_FLAG, "rdoccmd: " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_524 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_523};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_525 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_292};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_526 = { 8 | NIM_STRLIT_FLAG, "docCmd: " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_527 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_526};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_528 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_292};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_529 = { 6 | NIM_STRLIT_FLAG, "code: " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_530 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_529};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_531 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_292};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_532 = { 7 | NIM_STRLIT_FLAG, "index: " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_533 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_532};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_534 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_292};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_535 = {67, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_520};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_536 = { 18 | NIM_STRLIT_FLAG, "runnableExamples: " };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_537 = {18, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_536};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_539 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_540 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_541 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_542 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_543 = { 7 | NIM_STRLIT_FLAG, "Imports" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_544 = { 5 | NIM_STRLIT_FLAG, "Types" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_545 = { 4 | NIM_STRLIT_FLAG, "Vars" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_546 = { 4 | NIM_STRLIT_FLAG, "Lets" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_547 = { 6 | NIM_STRLIT_FLAG, "Consts" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_548 = { 5 | NIM_STRLIT_FLAG, "Procs" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_549 = { 5 | NIM_STRLIT_FLAG, "Funcs" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_550 = { 7 | NIM_STRLIT_FLAG, "Methods" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_551 = { 9 | NIM_STRLIT_FLAG, "Iterators" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_552 = { 10 | NIM_STRLIT_FLAG, "Converters" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_553 = { 6 | NIM_STRLIT_FLAG, "Macros" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_554 = { 9 | NIM_STRLIT_FLAG, "Templates" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_555 = { 7 | NIM_STRLIT_FLAG, "Exports" };
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_556 = { 11 | NIM_STRLIT_FLAG, "doc.section" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_557 = {11, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_556};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_558 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_559 = { 9 | NIM_STRLIT_FLAG, "sectionid" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_560 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_559};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_561 = { 12 | NIM_STRLIT_FLAG, "sectionTitle" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_562 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_561};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_563 = { 14 | NIM_STRLIT_FLAG, "sectionTitleID" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_564 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_563};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_565 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_478};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_568 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_569 = { 16 | NIM_STRLIT_FLAG, "doc.section.toc2" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_570 = {16, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_569};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_571 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_572 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_559};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_573 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_561};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_574 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_563};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_575 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_478};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_576 = { 9 | NIM_STRLIT_FLAG, "plainName" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_577 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_576};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_579 = { 9 | NIM_STRLIT_FLAG, "sectionID" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_580 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_579};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_581 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_563};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_582 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_561};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_583 = { 15 | NIM_STRLIT_FLAG, "doc.section.toc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_584 = {15, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_583};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_585 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_586 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_478};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_587 = { 20 | NIM_STRLIT_FLAG, "doc.section.toc_item" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_588 = {20, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_587};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_589 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_590 = { 7 | NIM_STRLIT_FLAG, "doc.toc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_591 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_590};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_592 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_593 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_478};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_594 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_595 = { 28 | NIM_STRLIT_FLAG, "<h2 class=\"subtitle\">$1</h2>" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_596 = {28, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_595};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_597 = { 25 | NIM_STRLIT_FLAG, "\\\\\\vspace{0.5em}\\large $1" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_598 = {25, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_597};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_599 = { 25 | NIM_STRLIT_FLAG, "doc.body_toc_groupsection" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_600 = {25, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_599};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_601 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_602 = { 18 | NIM_STRLIT_FLAG, "doc.body_toc_group" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_603 = {18, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_602};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_604 = { 12 | NIM_STRLIT_FLAG, "doc.body_toc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_605 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_604};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_606 = { 15 | NIM_STRLIT_FLAG, "doc.body_no_toc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_607 = {15, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_606};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_608 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_609 = { 5 | NIM_STRLIT_FLAG, "title" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_610 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_609};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_611 = { 8 | NIM_STRLIT_FLAG, "subtitle" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_612 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_611};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_613 = { 15 | NIM_STRLIT_FLAG, "tableofcontents" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_614 = {15, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_613};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_615 = { 10 | NIM_STRLIT_FLAG, "moduledesc" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_616 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_615};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_617 = { 4 | NIM_STRLIT_FLAG, "date" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_618 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_617};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_619 = { 4 | NIM_STRLIT_FLAG, "time" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_620 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_619};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_621 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_478};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_622 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_356};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_623 = { 12 | NIM_STRLIT_FLAG, "theindexhref" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_624 = {12, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_623};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_625 = { 13 | NIM_STRLIT_FLAG, "theindex.html" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_626 = {13, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_625};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_627 = { 21 | NIM_STRLIT_FLAG, "body_toc_groupsection" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_628 = {21, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_627};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_629 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_354};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_630 = { 8 | NIM_STRLIT_FLAG, "doc.file" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_631 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_630};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_632 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_633 = { 9 | NIM_STRLIT_FLAG, "nimdoccss" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_634 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_633};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_635 = { 14 | NIM_STRLIT_FLAG, "nimdoc.out.css" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_636 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_635};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_637 = { 9 | NIM_STRLIT_FLAG, "dochackjs" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_638 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_637};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_639 = { 10 | NIM_STRLIT_FLAG, "dochack.js" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_640 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_639};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_641 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_609};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_642 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_611};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_643 = {15, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_613};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_644 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_615};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_645 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_617};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_646 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_619};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_647 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_478};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_648 = { 6 | NIM_STRLIT_FLAG, "author" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_649 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_648};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_650 = { 7 | NIM_STRLIT_FLAG, "version" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_651 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_650};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_652 = { 9 | NIM_STRLIT_FLAG, "analytics" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_653 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_652};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_654 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_356};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_655 = { 10 | NIM_STRLIT_FLAG, "nimVersion" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_656 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_655};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_657 = { 1 | NIM_STRLIT_FLAG, "." };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_658 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_657};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_659 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_657};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_661 = { 20 | NIM_STRLIT_FLAG, "$nimr/doc/nimdoc.css" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_662 = {20, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_661};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_663 = { 14 | NIM_STRLIT_FLAG, "nimdoc.out.css" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_664 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_663};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_665 = { 20 | NIM_STRLIT_FLAG, "$nimr/doc/nimdoc.cls" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_666 = {20, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_665};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_667 = { 10 | NIM_STRLIT_FLAG, "nimdoc.cls" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_668 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_667};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_669 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_670 = { 4 | NIM_STRLIT_FLAG, "orig" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_671 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_670};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_672 = { 6 | NIM_STRLIT_FLAG, "nimble" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_673 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_672};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_674 = { 17 | NIM_STRLIT_FLAG, "moduleDescription" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_675 = {17, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_674};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_676 = { 7 | NIM_STRLIT_FLAG, "entries" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_677 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_676};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_678 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_292};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_679 = { 21 | NIM_STRLIT_FLAG, "unable to open file \"" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_680 = {21, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_679};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_681 = { 13 | NIM_STRLIT_FLAG, "\" for writing" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_682 = {13, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_681};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_684 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_685 = {13, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_625};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_686 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_687 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_688 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_630};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_689 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_690 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_633};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_691 = {14, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_635};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_692 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_637};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_693 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_639};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_694 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_609};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_695 = { 5 | NIM_STRLIT_FLAG, "Index" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_696 = {5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_695};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_697 = {8, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_611};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_698 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_699 = {15, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_613};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_700 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_701 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_615};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_702 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_703 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_617};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_704 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_619};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_705 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_478};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_706 = {6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_648};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_707 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_708 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_650};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_709 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_710 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_652};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_711 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_712 = {10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_655};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_713 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_657};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_714 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_657};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_716 = { 3 | NIM_STRLIT_FLAG, "txt" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_717 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_716};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_718 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_719 = { 3 | NIM_STRLIT_FLAG, "tex" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_720 = {3, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_719};
N_LIB_PRIVATE TNimTypeV2 NTIv2__3Hx3nKTJ3nyE0W9cWCRi9aYw_;
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_722 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const struct {
  NI cap; NIM_CHAR data[55+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_723 = { 55 | NIM_STRLIT_FLAG, "the \':test:\' attribute is not supported by this backend" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_724 = {55, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_723};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_726 = { 4 | NIM_STRLIT_FLAG, "json" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_727 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_726};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_729 = { 9 | NIM_STRLIT_FLAG, "documents" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_730 = {9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_729};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_731 = { 7 | NIM_STRLIT_FLAG, "modules" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_732 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_731};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_733 = { 7 | NIM_STRLIT_FLAG, "symbols" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_734 = {7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_733};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_735 = {13, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_625};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_736 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_737 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_726};
N_LIB_PRIVATE TNimTypeV2 NTIv2__v5euAZjSQsVMJHq0GZMMZg_;
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_740 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_277};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_741 = {55, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_723};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_743 = {0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_744 = {2, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_145};
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_745 = {1, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_292};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__5fUAZGW8WPeit3fZaQyNXA_746 = { 4 | NIM_STRLIT_FLAG, "tags" };
static const NimStringV2 TM__5fUAZGW8WPeit3fZaQyNXA_747 = {4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_746};
static NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA TM__5fUAZGW8WPeit3fZaQyNXA_14 = {{23, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_15}}
;
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_18 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)204),
((NI)8)}
;
static NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA TM__5fUAZGW8WPeit3fZaQyNXA_21 = {{22, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_22}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_24 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)205),
((NI)8)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_37 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)331),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_39 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)277),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_94 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)415),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_99 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)418),
((NI)18)}
;
static NIM_CONST tyArray__Seu7uK9aaOSN0BK3EAjjSHw TM__5fUAZGW8WPeit3fZaQyNXA_103 = {{5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_104},
{10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_105},
{7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_106},
{0, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_34}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_118 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1227),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_122 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1238),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_131 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1253),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_158 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)626),
((NI)40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_161 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)630),
((NI)44)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_211 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)756),
((NI)18)}
;
extern NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA ExeExts__pureZos_u75;
static NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA TM__5fUAZGW8WPeit3fZaQyNXA_514 = {{63, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_515}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_538 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)612),
((NI)16)}
;
N_LIB_PRIVATE NIM_CONST tyArray__wgmwCG2MY84OFtPmYaVG9bA sectionNames__docgen_u12342 = {{7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_543},
{5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_544},
{4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_545},
{4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_546},
{6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_547},
{4, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_545},
{5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_548},
{5, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_549},
{7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_550},
{9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_551},
{10, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_552},
{6, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_553},
{9, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_554},
{7, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_555}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_660 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1803),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_683 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1837),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_715 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1956),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_725 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1891),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_728 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1909),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_738 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1970),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_742 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1917),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__5fUAZGW8WPeit3fZaQyNXA_748 = {{61, (NimStrPayload*)&TM__5fUAZGW8WPeit3fZaQyNXA_19},
((NI)1933),
((NI)16)}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static NIM_CONST NU32 TM__5fUAZGW8WPeit3fZaQyNXA_2[2] = {3701606400, 3046362624};
N_LIB_PRIVATE TNimTypeV2 NTIv2__F7WTziupp71j3xJKFj9ccRA_ = {.destructor = (void*)rttiDestroy__docgen_u13934, .size = sizeof(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA), .align = (NI16) NIM_ALIGNOF(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA), .depth = 1, .display = TM__5fUAZGW8WPeit3fZaQyNXA_2, .traceImpl = (void*)eqtrace___docgen_u13864, .flags = 0};
static NIM_CONST NU32 TM__5fUAZGW8WPeit3fZaQyNXA_3[2] = {3701606400, 3678006784};
N_LIB_PRIVATE TNimTypeV2 NTIv2__ets57owy36keA5i1GuWy6Q_ = {.destructor = (void*)rttiDestroy__docgen_u14049, .size = sizeof(tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q), .align = (NI16) NIM_ALIGNOF(tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q), .depth = 1, .display = TM__5fUAZGW8WPeit3fZaQyNXA_3, .traceImpl = (void*)NIM_NIL, .flags = 0};
static NIM_CONST NU32 TM__5fUAZGW8WPeit3fZaQyNXA_33[3] = {3701606400, 217529344, 2229729280};
N_LIB_PRIVATE TNimTypeV2 NTIv2__GoTm9bL1y89aFdwPpcNTadzQ_ = {.destructor = (void*)rttiDestroy__docgen_u14052, .size = sizeof(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ), .align = (NI16) NIM_ALIGNOF(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ), .depth = 2, .display = TM__5fUAZGW8WPeit3fZaQyNXA_33, .traceImpl = (void*)eqtrace___docgen_u2090, .flags = 0};
static NIM_CONST NU32 TM__5fUAZGW8WPeit3fZaQyNXA_59[2] = {3701606400, 1613975552};
N_LIB_PRIVATE TNimTypeV2 NTIv2__nWAzUKcV7eAMzCwZy3hiPQ_ = {.destructor = (void*)rttiDestroy__docgen_u14086, .size = sizeof(tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ), .align = (NI16) NIM_ALIGNOF(tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ), .depth = 1, .display = TM__5fUAZGW8WPeit3fZaQyNXA_59, .traceImpl = (void*)NIM_NIL, .flags = 0};
extern Exception* currException__system_u3628;
static NIM_CONST NU32 TM__5fUAZGW8WPeit3fZaQyNXA_721[2] = {3701606400, 2088213504};
N_LIB_PRIVATE TNimTypeV2 NTIv2__3Hx3nKTJ3nyE0W9cWCRi9aYw_ = {.destructor = (void*)rttiDestroy__docgen_u14772, .size = sizeof(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw), .align = (NI16) NIM_ALIGNOF(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw), .depth = 1, .display = TM__5fUAZGW8WPeit3fZaQyNXA_721, .traceImpl = (void*)NIM_NIL, .flags = 0};
static NIM_CONST NU32 TM__5fUAZGW8WPeit3fZaQyNXA_739[2] = {3701606400, 2544763136};
N_LIB_PRIVATE TNimTypeV2 NTIv2__v5euAZjSQsVMJHq0GZMMZg_ = {.destructor = (void*)rttiDestroy__docgen_u14860, .size = sizeof(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg), .align = (NI16) NIM_ALIGNOF(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg), .depth = 1, .display = TM__5fUAZGW8WPeit3fZaQyNXA_739, .traceImpl = (void*)NIM_NIL, .flags = 0};
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13852)(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn((*dest_p0).d3);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose((*dest_p0).d3);
	}
LA4_: ;
	eqdestroy___system_u2691((*dest_p0).filename2);
	eqdestroy___system_u2691((*dest_p0).destFile1);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).conf0);
		if (!T8_) goto LA9_;
		eqdestroy___options_u1751((&(*(*dest_p0).conf0)));
		nimRawDispose((*dest_p0).conf0, ((NI)8));
	}
LA9_: ;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u13934)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___docgen_u13852((&(*((tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, add__system_u3018)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2) {
	void** colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3026(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p1));
		add__system_u3018((&(*j_1).traceStack), p_1, (*((TNimTypeV2**) ((*p_1)))));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___docgen_u13864)(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).d3, env_p1);
}
static N_INLINE(NIM_BOOL, isEmpty__options_u3633)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOutFile2__docgen_u1907)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NimStringV2 ext_p2, NIM_BOOL guessTarget_p3) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		NimStringV2 d_1;
		NimStringV2 colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)38)))&63U)))!=0);
		if (T3_) goto LA4_;
		T3_ = guessTarget_p3;
LA4_: ;
		if (!T3_) goto LA5_;
		d_1.len = 0; d_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		d_1 = (*conf_p0).outDir;
		noscreateDir(d_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD_ = noschangeFileExt(filename_p1, ext_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		result = slash___pathutils_u135(d_1, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = isEmpty__options_u3633((*conf_p0).outFile);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T11_)) goto LA12_;
		result = absOutFile__options_u3622(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA12_: ;
	{
		result = getOutFile__options_u3612(conf_p0, filename_p1, ext_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13977)(tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).file21);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).conf0);
		if (!T3_) goto LA4_;
		eqdestroy___options_u1751((&(*(*dest_p0).conf0)));
		nimRawDispose((*dest_p0).conf0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14049)(void* dest_p0) {
	eqdestroy___docgen_u13977((&(*((tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q*) (dest_p0)))));
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(NimStringV2, nimbleDir__docgen_u1802)(void* ClE_0) {
	NimStringV2 result;
	tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q* colonenvP__1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colonenvP__1 = (tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getNimbleFile__options_u3711((*colonenvP__1).conf0, (*colonenvP__1).file21);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = nosparentDir(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_u139)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14010)(tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__ets57owy36keA5i1GuWy6Q_))));
		if (!T3_) goto LA4_;
		eqdestroy___docgen_u13977((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, presentationPath__docgen_u1793)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 file_p1) {
	NimStringV2 result;
	tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q* colonenv__1;
	tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q* T2_;
	NimStringV2 T3_;
	NimStringV2 T95_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colonenv__1 = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q*) nimNewObj(sizeof(tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q), NIM_ALIGNOF(tyObject_Env_docgendotnim_presentationPath___ets57owy36keA5i1GuWy6Q));
	(*T2_).Sup.m_type = (&NTIv2__ets57owy36keA5i1GuWy6Q_);
	colonenv__1 = T2_;
	eqcopy___options_u2138(&(*colonenv__1).conf0, conf_p0);
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = dollar___options_u3939(file_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA1_;}
	eqsink___system_u2700((&(*colonenv__1).file21), T3_);
	if (eqStrings((*(*colonenv__1).conf0).docRoot, TM__5fUAZGW8WPeit3fZaQyNXA_5)) goto LA4_;
	if (eqStrings((*(*colonenv__1).conf0).docRoot, TM__5fUAZGW8WPeit3fZaQyNXA_7)) goto LA5_;
	if (eqStrings((*(*colonenv__1).conf0).docRoot, TM__5fUAZGW8WPeit3fZaQyNXA_9)) goto LA6_;
	goto LA7_;
	LA4_: ;
	{
		NimStringV2 dir_1;
		tyProc__LCMSFwcIs5O0HdDmqpX05g T11_;
		dir_1.len = 0; dir_1.p = NIM_NIL;
		result = getRelativePathFromConfigPath__options_u3934((*colonenv__1).conf0, file_p1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		nimZeroMem((void*)(&T11_), sizeof(tyProc__LCMSFwcIs5O0HdDmqpX05g));
		T11_.ClP_0 = nimbleDir__docgen_u1802; T11_.ClE_0 = colonenv__1;
		dir_1 = T11_.ClE_0? T11_.ClP_0(T11_.ClE_0):((TM__5fUAZGW8WPeit3fZaQyNXA_10)(T11_.ClP_0))();
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			NIM_BOOL T14_;
			NimStringV2 result2_1;
			T14_ = (NIM_BOOL)0;
			T14_ = isEmpty__pathutils_u139(dir_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			if (!!(T14_)) goto LA15_;
			result2_1.len = 0; result2_1.p = NIM_NIL;
			result2_1 = relativeTo__pathutils_u196(file_p1, dir_1, 47);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			{
				NIM_BOOL T20_;
				NIM_BOOL T21_;
				NIM_BOOL T23_;
				T20_ = (NIM_BOOL)0;
				T21_ = (NIM_BOOL)0;
				T21_ = isEmpty__options_u3633(result2_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
				T20_ = !(T21_);
				if (!(T20_)) goto LA22_;
				T23_ = (NIM_BOOL)0;
				T23_ = isEmpty__options_u3633(result);
				if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
				if (T23_) goto LA24_;
				T23_ = (result2_1.len < result.len);
LA24_: ;
				T20_ = T23_;
LA22_: ;
				if (!T20_) goto LA25_;
				eqsink___system_u2700((&result), result2_1);
				eqwasMoved___system_u2688((&result2_1));
			}
LA25_: ;
			{
				LA17_:;
			}
			{
				eqdestroy___system_u2691(result2_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA15_: ;
		{
			NIM_BOOL T31_;
			NimStringV2 T34_;
			T31_ = (NIM_BOOL)0;
			T31_ = isEmpty__options_u3633(result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			if (!T31_) goto LA32_;
			T34_.len = 0; T34_.p = NIM_NIL;
			T34_ = relativeTo__pathutils_u196(file_p1, (*(*colonenv__1).conf0).projectPath, 47);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T34_); goto LA10_;}
			eqsink___system_u2700((&result), T34_);
		}
LA32_: ;
		{
			LA10_:;
		}
		{
			eqdestroy___system_u2691(dir_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
	LA5_: ;
	{
		NimStringV2 dir_2;
		tyProc__LCMSFwcIs5O0HdDmqpX05g T39_;
		dir_2.len = 0; dir_2.p = NIM_NIL;
		nimZeroMem((void*)(&T39_), sizeof(tyProc__LCMSFwcIs5O0HdDmqpX05g));
		T39_.ClP_0 = nimbleDir__docgen_u1802; T39_.ClE_0 = colonenv__1;
		dir_2 = T39_.ClE_0? T39_.ClP_0(T39_.ClE_0):((TM__5fUAZGW8WPeit3fZaQyNXA_11)(T39_.ClP_0))();
		if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		{
			NIM_BOOL T42_;
			T42_ = (NIM_BOOL)0;
			T42_ = isEmpty__pathutils_u139(dir_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			if (!T42_) goto LA43_;
			result = relativeTo__pathutils_u196(file_p1, (*(*colonenv__1).conf0).projectPath, 47);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		}
		goto LA40_;
LA43_: ;
		{
			result = relativeTo__pathutils_u196(file_p1, dir_2, 47);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		}
LA40_: ;
		{
			LA38_:;
		}
		{
			eqdestroy___system_u2691(dir_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
	LA6_: ;
	{
		result = getRelativePathFromConfigPath__options_u3934((*colonenv__1).conf0, file_p1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T51_;
			NimStringV2 T54_;
			T51_ = (NIM_BOOL)0;
			T51_ = isEmpty__options_u3633(result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T51_) goto LA52_;
			T54_.len = 0; T54_.p = NIM_NIL;
			T54_ = relativeTo__pathutils_u196(file_p1, (*(*colonenv__1).conf0).projectPath, 47);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T54_); goto LA1_;}
			eqsink___system_u2700((&result), T54_);
		}
LA52_: ;
	}
	goto LA8_;
	LA7_: ;
	{
		{
			NimStringV2 colontmpD_;
			if (!(((NI)0) < (*(*colonenv__1).conf0).docRoot.len)) goto LA58_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			{
				NIM_BOOL T63_;
				NimStringV2 arg2X60gensym24__1;
				T63_ = (NIM_BOOL)0;
				T63_ = nosisAbsolute((*(*colonenv__1).conf0).docRoot);
				if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
				if (!!(T63_)) goto LA64_;
				arg2X60gensym24__1.len = 0; arg2X60gensym24__1.p = NIM_NIL;
				arg2X60gensym24__1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_13, TM__5fUAZGW8WPeit3fZaQyNXA_14, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				{
					NimStringV2 colontmpD__2;
					NimStringV2 T71_;
					if (!(((NI)0) < (*(*colonenv__1).conf0).docRoot.len)) goto LA69_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					T71_.len = 0; T71_.p = NIM_NIL;
					T71_ = rawNewString((*(*colonenv__1).conf0).docRoot.len + 16);
appendString((&T71_), TM__5fUAZGW8WPeit3fZaQyNXA_17);
appendString((&T71_), (*(*colonenv__1).conf0).docRoot);
					colontmpD__2 = T71_;
					prepareAdd((&arg2X60gensym24__1), colontmpD__2.len + 0);
appendString((&arg2X60gensym24__1), colontmpD__2);
					eqdestroy___system_u2691(colontmpD__2);
				}
LA69_: ;
				liMessage__msgs_u1227((*colonenv__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), arg2X60gensym24__1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__5fUAZGW8WPeit3fZaQyNXA_18), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				{
					LA66_:;
				}
				{
					eqdestroy___system_u2691(arg2X60gensym24__1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
			}
LA64_: ;
			{
				NIM_BOOL T76_;
				NimStringV2 arg2X60gensym27__1;
				T76_ = (NIM_BOOL)0;
				T76_ = nosdirExists((*(*colonenv__1).conf0).docRoot);
				if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
				if (!!(T76_)) goto LA77_;
				arg2X60gensym27__1.len = 0; arg2X60gensym27__1.p = NIM_NIL;
				arg2X60gensym27__1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_20, TM__5fUAZGW8WPeit3fZaQyNXA_21, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
				{
					NimStringV2 colontmpD__3;
					NimStringV2 T84_;
					if (!(((NI)0) < (*(*colonenv__1).conf0).docRoot.len)) goto LA82_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					T84_.len = 0; T84_.p = NIM_NIL;
					T84_ = rawNewString((*(*colonenv__1).conf0).docRoot.len + 16);
appendString((&T84_), TM__5fUAZGW8WPeit3fZaQyNXA_23);
appendString((&T84_), (*(*colonenv__1).conf0).docRoot);
					colontmpD__3 = T84_;
					prepareAdd((&arg2X60gensym27__1), colontmpD__3.len + 0);
appendString((&arg2X60gensym27__1), colontmpD__3);
					eqdestroy___system_u2691(colontmpD__3);
				}
LA82_: ;
				liMessage__msgs_u1227((*colonenv__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), arg2X60gensym27__1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__5fUAZGW8WPeit3fZaQyNXA_24), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
				{
					LA79_:;
				}
				{
					eqdestroy___system_u2691(arg2X60gensym27__1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
			}
LA77_: ;
			colontmpD_ = nosexpandFilename((*(*colonenv__1).conf0).docRoot);
			if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
			result = relativeTo__pathutils_u196(file_p1, colontmpD_, 47);
			if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
			{
				LA60_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA56_;
LA58_: ;
		{
			result = relativeTo__pathutils_u196(file_p1, (*(*colonenv__1).conf0).projectPath, 47);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA56_: ;
	}
LA8_: ;
	{
		NIM_BOOL T92_;
		NimStringV2 colontmpD__4;
		tyTuple__UV3llMMYFckfui8YMBuUZA colontmpD__5;
		T92_ = (NIM_BOOL)0;
		T92_ = nosisAbsolute(result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T92_) goto LA93_;
		nimZeroMem((void*)(&colontmpD__5), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		nossplitPath(file_p1, (&colontmpD__5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__4 = eqdup___system_u2697(colontmpD__5.Field1);
		eqsink___system_u2700((&result), colontmpD__4);
		eqdestroy___stdZprivateZospaths2_u306((&colontmpD__5));
	}
LA93_: ;
	T95_.len = 0; T95_.p = NIM_NIL;
	T95_ = nsuReplaceStr(result, TM__5fUAZGW8WPeit3fZaQyNXA_26, TM__5fUAZGW8WPeit3fZaQyNXA_28);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T95_); goto LA1_;}
	eqsink___system_u2700((&result), T95_);
	{
		NIM_BOOL T98_;
		T98_ = (NIM_BOOL)0;
		T98_ = isEmpty__options_u3633(result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(!(T98_))) goto LA99_;
		failedAssertImpl__stdZassertions_u79(TM__5fUAZGW8WPeit3fZaQyNXA_30);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA99_: ;
	{
		NIM_BOOL T103_;
		T103_ = (NIM_BOOL)0;
		T103_ = nosisAbsolute(result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(!(T103_))) goto LA104_;
		failedAssertImpl__stdZassertions_u79(TM__5fUAZGW8WPeit3fZaQyNXA_32);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA104_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___docgen_u14010(colonenv__1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3466)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3106)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).code);
	eqdestroy___system_u2691((*dest_p0).docCmd);
	eqdestroy___system_u2691((*dest_p0).rdoccmd);
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2896)(tySequence__eb7tUf9a8CR5sBO6O3AH67A dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].rstField);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].rst);
				if (!T6_) goto LA7_;
				eqdestroy___packagesZdocutilsZrstast_u173((&(*dest_p0.p->data[colontmp_].rst)));
				nimRawDispose(dest_p0.p->data[colontmp_].rst, ((NI)8));
			}
LA7_: ;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].json);
				if (!T11_) goto LA12_;
				eqdestroy___pureZjson_u70((&(*dest_p0.p->data[colontmp_].json)));
				nimRawDispose(dest_p0.p->data[colontmp_].json, ((NI)8));
			}
LA12_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2579)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].sortName);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].content);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2125)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			switch (dest_p0.p->data[colontmp_].isRst) {
			case NIM_TRUE:
			{
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_]._isRst_1.rst);
					if (!T7_) goto LA8_;
					eqdestroy___packagesZdocutilsZrstast_u173((&(*dest_p0.p->data[colontmp_]._isRst_1.rst)));
					nimRawDispose(dest_p0.p->data[colontmp_]._isRst_1.rst, ((NI)8));
				}
LA8_: ;
			}
			break;
			case NIM_FALSE:
			{
				eqdestroy___system_u2691(dest_p0.p->data[colontmp_]._isRst_2.str);
			}
			break;
			default:
			{
			}
			break;
			}
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2284)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].detailedName);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].name);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].anchor);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].sortName);
			eqdestroy___system_u5506(dest_p0.p->data[colontmp_].substitutions);
			eqdestroy___docgen_u2125(dest_p0.p->data[colontmp_].descRst);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2078)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* dest_p0) {
	NI colontmp_;
	NI colontmp__2;
	NI colontmp__3;
	NI colontmp__4;
	NI colontmp__5;
	NI colontmp__6;
	eqdestroy___docgen_u519((*dest_p0).nimToRstFid.data);
	eqdestroy___docgen_u3085((*dest_p0).exampleGroups.data);
	eqdestroy___system_u2691((*dest_p0).thisDir);
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).emitted.data);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).emitted.head);
		if (!T3_) goto LA4_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).emitted.head)));
		nimRawDispose((*dest_p0).emitted.head, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLast((*dest_p0).cache);
		if (!T8_) goto LA9_;
		eqdestroy___idents_u274((&(*(*dest_p0).cache)));
		nimRawDispose((*dest_p0).cache, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).conf);
		if (!T13_) goto LA14_;
		eqdestroy___options_u1751((&(*(*dest_p0).conf)));
		nimRawDispose((*dest_p0).conf, ((NI)8));
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastCyclicStatic((*dest_p0).sharedState, ((TNimTypeV2*) ((&NTIv2__6YauuaWEZeOKzNYK3p1vqA_))));
		if (!T18_) goto LA19_;
		eqdestroy___packagesZdocutilsZrst_u2567((&(*(*dest_p0).sharedState)));
		nimRawDispose((*dest_p0).sharedState, ((NI)8));
	}
LA19_: ;
	eqdestroy___ast_u4848((*dest_p0).types.data);
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).jEntriesFinal);
		if (!T23_) goto LA24_;
		eqdestroy___pureZjson_u70((&(*(*dest_p0).jEntriesFinal)));
		nimRawDispose((*dest_p0).jEntriesFinal, ((NI)8));
	}
LA24_: ;
	eqdestroy___docgen_u2896((*dest_p0).jEntriesPre);
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLastCyclicDyn((*dest_p0).seenSymbols);
		if (!T28_) goto LA29_;
		nimDestroyAndDispose((*dest_p0).seenSymbols);
	}
LA29_: ;
	eqdestroy___system_u2691((*dest_p0).analytics);
	eqdestroy___system_u2691((*dest_p0).indexValFilename);
	colontmp_ = ((NI)0);
	{
		while (1) {
			if (!(colontmp_ < ((NI)25))) goto LA32;
			eqdestroy___system_u2691((*dest_p0).toc[(colontmp_)- 0]);
			colontmp_ += ((NI)1);
		} LA32: ;
	}
	colontmp__2 = ((NI)0);
	{
		while (1) {
			if (!(colontmp__2 < ((NI)25))) goto LA34;
			eqdestroy___system_u2691((*dest_p0).toc2[(colontmp__2)- 0]);
			colontmp__2 += ((NI)1);
		} LA34: ;
	}
	colontmp__3 = ((NI)0);
	{
		while (1) {
			if (!(colontmp__3 < ((NI)25))) goto LA36;
			eqdestroy___docgen_u2732((*dest_p0).tocTable[(colontmp__3)- 0].data);
			colontmp__3 += ((NI)1);
		} LA36: ;
	}
	colontmp__4 = ((NI)0);
	{
		while (1) {
			if (!(colontmp__4 < ((NI)25))) goto LA38;
			eqdestroy___docgen_u2579((*dest_p0).tocSimple[(colontmp__4)- 0]);
			colontmp__4 += ((NI)1);
		} LA38: ;
	}
	colontmp__5 = ((NI)0);
	{
		while (1) {
			if (!(colontmp__5 < ((NI)25))) goto LA40;
			eqdestroy___system_u2691((*dest_p0).section[(colontmp__5)- 0].finalMarkup);
			eqdestroy___docgen_u2263((*dest_p0).section[(colontmp__5)- 0].secItems.data);
			colontmp__5 += ((NI)1);
		} LA40: ;
	}
	eqdestroy___system_u2691((*dest_p0).modDeprecationMsg);
	{
		NIM_BOOL T43_;
		T43_ = (NIM_BOOL)0;
		T43_ = nimDecRefIsLastDyn((*dest_p0).module);
		if (!T43_) goto LA44_;
		eqdestroy___ast_u3469((&(*(*dest_p0).module)));
		nimRawDispose((*dest_p0).module, ((NI)8));
	}
LA44_: ;
	eqdestroy___system_u2691((*dest_p0).modDescFinal);
	eqdestroy___docgen_u2125((*dest_p0).modDescPre);
	{
		NIM_BOOL T48_;
		T48_ = (NIM_BOOL)0;
		T48_ = nimDecRefIsLastCyclicDyn((*dest_p0).Sup.onTestSnippet.ClE_0);
		if (!T48_) goto LA49_;
		nimDestroyAndDispose((*dest_p0).Sup.onTestSnippet.ClE_0);
	}
LA49_: ;
	eqdestroy___vmdef_u577((*dest_p0).Sup.seenIndexTerms.data);
	eqdestroy___system_u2691((*dest_p0).Sup.currentSection);
	colontmp__6 = ((NI)0);
	{
		while (1) {
			if (!(colontmp__6 < ((NI)6))) goto LA52;
			eqdestroy___system_u2691((*dest_p0).Sup.meta[(colontmp__6)- 0]);
			colontmp__6 += ((NI)1);
		} LA52: ;
	}
	eqdestroy___system_u2691((*dest_p0).Sup.filename);
	eqdestroy___system_u5506((*dest_p0).Sup.filenames.idxToFilename);
	eqdestroy___packagesZdocutilsZrst_u1172((*dest_p0).Sup.filenames.filenameToIdx.data);
	eqdestroy___system_u2691((*dest_p0).Sup.destFile);
	eqdestroy___system_u2691((*dest_p0).Sup.outDir);
	{
		NIM_BOOL T55_;
		T55_ = (NIM_BOOL)0;
		T55_ = nimDecRefIsLastCyclicDyn((*dest_p0).Sup.msgHandler.ClE_0);
		if (!T55_) goto LA56_;
		nimDestroyAndDispose((*dest_p0).Sup.msgHandler.ClE_0);
	}
LA56_: ;
	{
		NIM_BOOL T60_;
		T60_ = (NIM_BOOL)0;
		T60_ = nimDecRefIsLastCyclicDyn((*dest_p0).Sup.findFile.ClE_0);
		if (!T60_) goto LA61_;
		nimDestroyAndDispose((*dest_p0).Sup.findFile.ClE_0);
	}
LA61_: ;
	eqdestroy___system_u2691((*dest_p0).Sup.theIndex);
	eqdestroy___packagesZdocutilsZrstast_u152((*dest_p0).Sup.tocPart);
	{
		NIM_BOOL T65_;
		T65_ = (NIM_BOOL)0;
		T65_ = nimDecRefIsLastCyclicDyn((*dest_p0).Sup.config);
		if (!T65_) goto LA66_;
		nimDestroyAndDispose((*dest_p0).Sup.config);
	}
LA66_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14052)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___docgen_u2078((&(*((tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimTraceRef)(void* q_p0, TNimTypeV2* desc_p1, void* env_p2) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p2));
		add__system_u3018((&(*j_1).traceStack), p_1, desc_p1);
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___docgen_u2090)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).Sup.config, env_p1);
	nimTraceRefDyn((&(*dest_p0).Sup.findFile.ClE_0), env_p1);
	nimTraceRefDyn((&(*dest_p0).Sup.msgHandler.ClE_0), env_p1);
	nimTraceRefDyn((&(*dest_p0).Sup.onTestSnippet.ClE_0), env_p1);
	nimTraceRefDyn(&(*dest_p0).seenSymbols, env_p1);
	nimTraceRef(&(*dest_p0).sharedState, ((TNimTypeV2*) ((&NTIv2__6YauuaWEZeOKzNYK3p1vqA_))), env_p1);
}
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1) {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* h_1;
	NI T1_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	h_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_));
	(*h_1).rc = pluspercent___system_u785((*h_1).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u3469)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ** dest_p0, tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* src_p1, NIM_BOOL cyclic_p2) {
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* colontmp_;
	colontmp_ = (*dest_p0);
	{
		if (!src_p1) goto LA3_;
		nimIncRefCyclic(src_p1, cyclic_p2);
	}
LA3_: ;
	(*dest_p0) = src_p1;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T7_) goto LA8_;
		nimDestroyAndDispose(colontmp_);
	}
LA8_: ;
}
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosjoinPath(head_p0, tail_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(NimStringV2, docgenFindFile__docgen_u1972)(NimStringV2 sX60gensym51__p0, void* ClE_0) {
	NimStringV2 result;
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colonenvP__1 = (tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA*) ClE_0;
	result = findFile__options_u4081((*colonenvP__1).conf0, sX60gensym51__p0, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T6_;
		if (!(result.len == ((NI)0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = nosgetCurrentDir();
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_.len = 0; T6_.p = NIM_NIL;
		T6_ = slash___stdZprivateZospaths2_u91(colontmpD_, sX60gensym51__p0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T6_); goto LA5_;}
		eqsink___system_u2700((&result), T6_);
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = nosfileExists(result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			if (!!(T9_)) goto LA10_;
			eqsink___system_u2700((&result), TM__5fUAZGW8WPeit3fZaQyNXA_35);
		}
LA10_: ;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, docgenFindRefFile__docgen_u1975)(NimStringV2 targetRelPathX60gensym51__p0, tyTuple__UV3llMMYFckfui8YMBuUZA* Result, void* ClE_0) {
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* colonenvP__1;
	NimStringV2 fromDirX60gensym51__1;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD_;
	NimStringV2 basedirX60gensym51__1;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__2;
	NimStringV2 outDirPathX60gensym51__1;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmp_;
	NimStringV2 colontmp__2;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 blitTmp_1;
	NimStringV2 blitTmp_2;
	NimStringV2 T13_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	colonenvP__1 = (tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA*) ClE_0;
	fromDirX60gensym51__1.len = 0; fromDirX60gensym51__1.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	basedirX60gensym51__1.len = 0; basedirX60gensym51__1.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	outDirPathX60gensym51__1.len = 0; outDirPathX60gensym51__1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmp_.len = 0; colontmp_.p = NIM_NIL;
	colontmp__2.len = 0; colontmp__2.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__4), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	nossplitFile((*colonenvP__1).destFile1, (&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fromDirX60gensym51__1 = colontmpD_.Field0;
	eqwasMoved___system_u2688((&colontmpD_.Field0));
	nossplitFile((*colonenvP__1).filename2, (&colontmpD__2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	basedirX60gensym51__1 = colontmpD__2.Field0;
	eqwasMoved___system_u2688((&colontmpD__2.Field0));
	colontmpD__3 = slash___stdZprivateZospaths2_u91(basedirX60gensym51__1, targetRelPathX60gensym51__p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	outDirPathX60gensym51__1 = presentationPath__docgen_u1793((*colonenvP__1).conf0, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmp_ = slash___pathutils_u135((*(*colonenvP__1).conf0).outDir, outDirPathX60gensym51__1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmp__2 = TM__5fUAZGW8WPeit3fZaQyNXA_36;
	blitTmp_1 = colontmp_;
	eqwasMoved___system_u2688((&colontmp_));
	(*Result).Field0 = blitTmp_1;
	blitTmp_2 = colontmp__2;
	eqwasMoved___system_u2688((&colontmp__2));
	(*Result).Field1 = blitTmp_2;
	{
		NIM_BOOL T4_;
		NimStringV2 destPathX60gensym51__1;
		T4_ = (NIM_BOOL)0;
		T4_ = nosfileExists((*Result).Field0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		destPathX60gensym51__1.len = 0; destPathX60gensym51__1.p = NIM_NIL;
		destPathX60gensym51__1 = slash___stdZprivateZospaths2_u91(fromDirX60gensym51__1, targetRelPathX60gensym51__p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = !(eqStrings(destPathX60gensym51__1, (*Result).Field0));
			if (!(T9_)) goto LA10_;
			T9_ = nosfileExists(destPathX60gensym51__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA10_: ;
			if (!T9_) goto LA11_;
			eqsink___system_u2700((&(*Result).Field0), destPathX60gensym51__1);
			eqwasMoved___system_u2688((&destPathX60gensym51__1));
		}
LA11_: ;
		eqdestroy___system_u2691(destPathX60gensym51__1);
	}
LA5_: ;
	nossplitFile((*Result).Field0, (&colontmpD__4));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = nosrelativePath(colontmpD__4.Field0, fromDirX60gensym51__1, 47);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_.len = 0; T13_.p = NIM_NIL;
	T13_ = nsuReplaceChar(colontmpD__5, 92, 47);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T13_); goto LA1_;}
	eqsink___system_u2700((&(*Result).Field1), T13_);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___pureZos_u200((&colontmpD__4));
		eqdestroy___system_u2691(colontmp__2);
		eqdestroy___system_u2691(colontmp_);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(outDirPathX60gensym51__1);
		eqdestroy___pureZos_u200((&colontmpD__2));
		eqdestroy___system_u2691(basedirX60gensym51__1);
		eqdestroy___pureZos_u200((&colontmpD_));
		eqdestroy___system_u2691(fromDirX60gensym51__1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, newLineInfo__msgs_u436)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NI line_p2, NI col_p3) {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA result;
	NI32 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
	T1_ = (NI32)0;
	T1_ = fileInfoIdx__msgs_u404(conf_p0, filename_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newLineInfo__msgs_u419(T1_, line_p2, col_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, compilerMsgHandler__docgen_u1956)(NimStringV2 filenameX60gensym51__p0, NI lineX60gensym51__p1, NI colX60gensym51__p2, tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g msgKindX60gensym51__p3, NimStringV2 argX60gensym51__p4, void* ClE_0) {
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* colonenvP__1;
	tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA kX60gensym51__1;
	NIM_BOOL errorsAsWarningsX60gensym51__1;
	NIM_BOOL T21_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA*) ClE_0;
	kX60gensym51__1 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
	switch (msgKindX60gensym51__p3) {
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)0):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)1):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)5);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)2):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)6);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)3):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)7);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)4):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)8);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)5):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)9);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)6):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)10);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)7):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)11);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)8):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)12);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)9):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)13);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)10):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)14);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)19):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)15);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)11):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)29);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)12):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)30);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)13):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)31);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)14):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)32);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)15):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)33);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)16):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)34);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)18):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)35);
	}
	break;
	case ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)17):
	{
		kX60gensym51__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)36);
	}
	break;
	default: __builtin_unreachable();
	}
	T21_ = (NIM_BOOL)0;
	T21_ = (((*(*(*colonenvP__1).d3).sharedState).options &((NU8)1<<((NU)((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)3)))&7U)))!=0);
	if (!(T21_)) goto LA22_;
	T21_ = !((*(*colonenvP__1).d3).standaloneDoc);
LA22_: ;
	errorsAsWarningsX60gensym51__1 = T21_;
	{
		NIM_BOOL T25_;
		tyEnum_MsgClass__n9ca9cM20fZgCJnzACrVYWGA T26_;
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T30_;
		T25_ = (NIM_BOOL)0;
		T26_ = (tyEnum_MsgClass__n9ca9cM20fZgCJnzACrVYWGA)0;
		T26_ = whichMsgClass__packagesZdocutilsZrst_u608(msgKindX60gensym51__p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T25_ = (T26_ == ((tyEnum_MsgClass__n9ca9cM20fZgCJnzACrVYWGA)2));
		if (!(T25_)) goto LA27_;
		T25_ = errorsAsWarningsX60gensym51__1;
LA27_: ;
		if (!T25_) goto LA28_;
		T30_ = newLineInfo__msgs_u436((*colonenvP__1).conf0, filenameX60gensym51__p0, lineX60gensym51__p1, colX60gensym51__p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		liMessage__msgs_u1227((*colonenvP__1).conf0, T30_, kX60gensym51__1, argX60gensym51__p4, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__5fUAZGW8WPeit3fZaQyNXA_37), NIM_FALSE, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		raiseRecoverableError__lineinfos_u299(TM__5fUAZGW8WPeit3fZaQyNXA_38);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA23_;
LA28_: ;
	{
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T32_;
		T32_ = newLineInfo__msgs_u436((*colonenvP__1).conf0, filenameX60gensym51__p0, lineX60gensym51__p1, colX60gensym51__p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		liMessage__msgs_u1227((*colonenvP__1).conf0, T32_, kX60gensym51__1, argX60gensym51__p4, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__5fUAZGW8WPeit3fZaQyNXA_39), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA23_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLatexCmd__docgen_u1921)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NIM_BOOL result;
	result = ((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)18) || (*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)20) || (*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13788)(tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).outp1);
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14086)(void* dest_p0) {
	eqdestroy___docgen_u13788((&(*((tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ*) (dest_p0)))));
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13815)(tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__nWAzUKcV7eAMzCwZy3hiPQ_))));
		if (!T3_) goto LA4_;
		eqdestroy___docgen_u13788((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1314)(NimStringV2 s_p0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1) {
	NimStringV2 result;
	NI a_1;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)((NI)(s_p0.len - x_p1.b) - a_1) + ((NI)1));
	result = mnewString((L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				nimPrepareStrMutationV2((&result));
				result.p->data[i_1] = s_p0.p->data[(NI)(i_1 + a_1)];
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig, dotdot___stdZenumutils_u106)(NI a_p0, NI b_p1) {
	tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(NimStringV2, interpSnippetCmd__docgen_u2009)(NimStringV2 cmd_p0, void* ClE_0) {
	NimStringV2 result;
	tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ* colonenvP__1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	tyArray__ftd030ZQb0rgyFYIoQaqFA T10_;
	NimStringV2 T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colonenvP__1 = (tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD__7;
		NimStringV2 T7_;
		tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = nsuStartsWith(cmd_p0, TM__5fUAZGW8WPeit3fZaQyNXA_76);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T7_.len = 0; T7_.p = NIM_NIL;
		T8_ = dotdot___stdZenumutils_u106(((NI)4), ((NI)1));
		colontmpD__7 = X5BX5D___pureZstrutils_u1314(cmd_p0, T8_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = rawNewString(colontmpD__7.len + 5);
appendString((&T7_), TM__5fUAZGW8WPeit3fZaQyNXA_78);
appendString((&T7_), colontmpD__7);
		result = T7_;
		eqdestroy___system_u2691(colontmpD__7);
	}
	goto LA2_;
LA5_: ;
	{
		eqcopy___system_u2694((&result), cmd_p0);
	}
LA2_: ;
	colontmpD_ = nsuReplaceStr(result, TM__5fUAZGW8WPeit3fZaQyNXA_80, TM__5fUAZGW8WPeit3fZaQyNXA_82);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_84;
	colontmpD__2 = nosgetAppFilename();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = nospquoteShell(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[1] = colontmpD__3;
	T10_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_86;
	colontmpD__4 = nospquoteShell((*(*(*colonenvP__1).d0).conf).libpath);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[3] = colontmpD__4;
	T10_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_88;
	T10_[5] = (*(*(*colonenvP__1).d0).conf).docCmd;
	T10_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_90;
	colontmpD__5 = dollar___options_u144((*(*(*colonenvP__1).d0).conf).backend);
	T10_[7] = colontmpD__5;
	T10_[8] = TM__5fUAZGW8WPeit3fZaQyNXA_92;
	colontmpD__6 = nospquoteShell((*colonenvP__1).outp1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[9] = colontmpD__6;
	T11_.len = 0; T11_.p = NIM_NIL;
	T11_ = nsuFormatOpenArray(colontmpD_, T10_, 10);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA1_;}
	eqsink___system_u2700((&result), T11_);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_u1993)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* gen_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4, void* ClE_0) {
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* colonenvP__1;
	tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ* colonenv__1;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD_;
	NimStringV2 importStmt_1;
	NimStringV2 colontmpD__2;
	NimStringV2 cmd_2;
	tyTuple__XOVT24GHXwqiEj5GCsEGCA tmpTuple_1;
	NimStringV2 output_1;
	tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ* T2_;
	NimStringV2 T25_;
	NimStringV2 T35_;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T36_;
	NI gotten_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA*) ClE_0;
	colonenv__1 = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	importStmt_1.len = 0; importStmt_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	cmd_2.len = 0; cmd_2.p = NIM_NIL;
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__XOVT24GHXwqiEj5GCsEGCA));
	output_1.len = 0; output_1.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ*) nimNewObj(sizeof(tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ), NIM_ALIGNOF(tyObject_Env_docgendotnim_colonanonymous___nWAzUKcV7eAMzCwZy3hiPQ));
	(*T2_).Sup.m_type = (&NTIv2__nWAzUKcV7eAMzCwZy3hiPQ_);
	colonenv__1 = T2_;
	{
		if (!eqStrings((*(*colonenvP__1).conf0).docCmd, TM__5fUAZGW8WPeit3fZaQyNXA_61)) goto LA5_;
		eqdestroy___system_u2691(output_1);
		eqdestroy___pureZosproc_u2034(tmpTuple_1);
		eqdestroy___system_u2691(cmd_2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(importStmt_1);
		eqdestroy___pathutils_u73((&colontmpD_));
		eqdestroy___docgen_u13815(colonenv__1);
		goto BeforeRet_;
	}
LA5_: ;
	(*gen_p0).id += ((NI)1);
	(*colonenv__1).d0 = (*((tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ**) (&(gen_p0))));
	{
		NimStringV2 nameOnly_1;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 T12_;
		NimStringV2 T13_;
		if (!(filename_p1.len == ((NI)0))) goto LA9_;
		nameOnly_1.len = 0; nameOnly_1.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__3), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		nossplitFile((*(*colonenv__1).d0).Sup.filename, (&colontmpD__3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		nameOnly_1 = colontmpD__3.Field1;
		eqwasMoved___system_u2688((&colontmpD__3.Field1));
		colontmpD__4 = getNimcacheDir__options_u3737((*colonenvP__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		colontmpD__5 = slash___pathutils_u166(colontmpD__4, TM__5fUAZGW8WPeit3fZaQyNXA_63);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		colontmpD__6 = slash___pathutils_u166(colontmpD__5, nameOnly_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		T12_.len = 0; T12_.p = NIM_NIL;
		colontmpD__7 = dollar___systemZdollars_u9((*(*colonenv__1).d0).Sup.id);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		T12_ = rawNewString(nameOnly_1.len + colontmpD__7.len + 13);
appendString((&T12_), nameOnly_1);
appendString((&T12_), TM__5fUAZGW8WPeit3fZaQyNXA_65);
appendString((&T12_), colontmpD__7);
appendString((&T12_), TM__5fUAZGW8WPeit3fZaQyNXA_67);
		colontmpD__8 = T12_;
		T13_.len = 0; T13_.p = NIM_NIL;
		T13_ = slash___pathutils_u135(colontmpD__6, colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T13_); goto LA11_;}
		eqsink___system_u2700((&(*colonenv__1).outp1), T13_);
		{
			LA11_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___pureZos_u200((&colontmpD__3));
			eqdestroy___system_u2691(nameOnly_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA7_;
LA9_: ;
	{
		NIM_BOOL T17_;
		NimStringV2 colontmpD__9;
		T17_ = (NIM_BOOL)0;
		T17_ = nosisAbsolute(filename_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T17_) goto LA18_;
		colontmpD__9 = eqdup___system_u2697(filename_p1);
		eqsink___system_u2700((&(*colonenv__1).outp1), colontmpD__9);
	}
	goto LA7_;
LA18_: ;
	{
		NimStringV2 nameOnly_2;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__10;
		NimStringV2 T22_;
		nameOnly_2.len = 0; nameOnly_2.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__10), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile((*(*colonenv__1).d0).Sup.filename, (&colontmpD__10));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		nameOnly_2 = colontmpD__10.Field1;
		eqwasMoved___system_u2688((&colontmpD__10.Field1));
		T22_.len = 0; T22_.p = NIM_NIL;
		T22_ = slash___pathutils_u135(nameOnly_2, filename_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T22_); goto LA21_;}
		eqsink___system_u2700((&(*colonenv__1).outp1), T22_);
		{
			LA21_:;
		}
		{
			eqdestroy___pureZos_u200((&colontmpD__10));
			eqdestroy___system_u2691(nameOnly_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	splitFile__pathutils_u39((*colonenv__1).outp1, (&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	noscreateDir(colontmpD_.Field0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T25_.len = 0; T25_.p = NIM_NIL;
	{
		if (!(*(*colonenv__1).d0).standaloneDoc) goto LA28_;
		importStmt_1 = TM__5fUAZGW8WPeit3fZaQyNXA_68;
	}
	goto LA26_;
LA28_: ;
	{
		NimStringV2 colontmpD__11;
		tyArray__YgExxhfgKcesA5EOUj1MOA T32_;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__11 = nsuReplaceStr((*(*colonenv__1).d0).Sup.filename, TM__5fUAZGW8WPeit3fZaQyNXA_72, TM__5fUAZGW8WPeit3fZaQyNXA_74);
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		T32_[0] = colontmpD__11;
		importStmt_1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_70, T32_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		{
			LA31_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA26_: ;
	T35_.len = 0; T35_.p = NIM_NIL;
	T35_ = rawNewString(importStmt_1.len + content_p4.len + 0);
appendString((&T35_), importStmt_1);
appendString((&T35_), content_p4);
	colontmpD__2 = T35_;
	writeFile__stdZsyncio_u532((*colonenv__1).outp1, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nimZeroMem((void*)(&T36_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T36_.ClP_0 = interpSnippetCmd__docgen_u2009; T36_.ClE_0 = colonenv__1;
	cmd_2 = T36_.ClE_0? T36_.ClP_0(cmd_p2, T36_.ClE_0):((TM__5fUAZGW8WPeit3fZaQyNXA_93)(T36_.ClP_0))(cmd_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	liMessage__msgs_u1227((*colonenvP__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)109), cmd_2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__5fUAZGW8WPeit3fZaQyNXA_94), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tmpTuple_1 = execCmdEx__pureZosproc_u1990(cmd_2, 10, ((tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg*) NIM_NIL), TM__5fUAZGW8WPeit3fZaQyNXA_95, TM__5fUAZGW8WPeit3fZaQyNXA_96);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	output_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u2688((&tmpTuple_1.Field0));
	gotten_1 = tmpTuple_1.Field1;
	{
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T42_;
		if (!!((gotten_1 == status_p3))) goto LA39_;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		T42_[0] = cmd_2;
		colontmpD__12 = dollar___systemZdollars_u9(gotten_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		T42_[1] = colontmpD__12;
		colontmpD__13 = dollar___systemZdollars_u9(status_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		T42_[2] = colontmpD__13;
		T42_[3] = output_1;
		colontmpD__14 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_98, T42_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		liMessage__msgs_u1227((*colonenvP__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__14, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__5fUAZGW8WPeit3fZaQyNXA_99), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		{
			LA41_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA39_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(output_1);
		eqdestroy___pureZosproc_u2034(tmpTuple_1);
		eqdestroy___system_u2691(cmd_2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(importStmt_1);
		eqdestroy___pathutils_u73((&colontmpD_));
		eqdestroy___docgen_u13815(colonenv__1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA*, eqdup___docgen_u13898)(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* src_p0, NIM_BOOL cyclic_p1) {
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* result;
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initPackedSet__pureZcollectionsZintsets_u37(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u13891)(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__F7WTziupp71j3xJKFj9ccRA_))));
		if (!T3_) goto LA4_;
		eqdestroy___docgen_u13852((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ*, newDocumentor__docgen_u1928)(NimStringV2 filename_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2, NimStringV2 outExt_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p4, NIM_BOOL standaloneDoc_p5, NIM_BOOL preferMarkdown_p6, NIM_BOOL hasToc_p7) {
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* result;
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* colonenv__1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g colontmpD__3;
	tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g colontmpD__4;
	tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg colontmpD__5;
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* colontmpD__6;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__7;
	tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA* T2_;
	NimStringV2 T3_;
	tySet_tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg options_1;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T12_;
	tyProc__lYMtBEH0vEMRzoDaCw5CJg T13_;
	tyProc__lsy8uLKFmavBA17NQuqO5g T14_;
	tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* T15_;
	tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g T16_;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw T23_;
	tyProc__lsy8uLKFmavBA17NQuqO5g T24_;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* T51_;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* T52_;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg T53_;
	tyProc__9bd86QnQPXw1dUoLzfDMOKg T54_;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA T55_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colonenv__1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__3 = (tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0;
	colontmpD__4 = (tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0;
	nimZeroMem((void*)(&colontmpD__5), sizeof(tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg));
	nimZeroMem((void*)(&colontmpD__7), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA*) nimNewObj(sizeof(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA), NIM_ALIGNOF(tyObject_Env_docgendotnim_newDocumentor___F7WTziupp71j3xJKFj9ccRA));
	(*T2_).Sup.m_type = (&NTIv2__F7WTziupp71j3xJKFj9ccRA_);
	colonenv__1 = T2_;
	eqcopy___system_u2694((&(*colonenv__1).filename2), filename_p0);
	eqcopy___options_u2138(&(*colonenv__1).conf0, conf_p2);
	colontmpD_ = presentationPath__docgen_u1793((*colonenv__1).conf0, (*colonenv__1).filename2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = getOutFile2__docgen_u1907((*colonenv__1).conf0, colontmpD_, outExt_p3, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA1_;}
	eqsink___system_u2700((&(*colonenv__1).destFile1), T3_);
	eqdestroy___docgen_u3466(result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = (tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ*) nimNewObj(sizeof(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ), NIM_ALIGNOF(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ));
	(*result).Sup.Sup.m_type = (&NTIv2__GoTm9bL1y89aFdwPpcNTadzQ_);
	eqcopy___docgen_u3469(&(*colonenv__1).d3, result, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u4577(&(*result).module, module_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___options_u2138(&(*result).conf, (*colonenv__1).conf0);
	eqcopy___idents_u341(&(*result).cache, cache_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = eqdup___system_u2697((*(*colonenv__1).conf0).outDir);
	eqsink___system_u2700((&(*result).Sup.outDir), colontmpD__2);
	(*result).standaloneDoc = standaloneDoc_p5;
	options_1 = 38;
	{
		if (!preferMarkdown_p6) goto LA6_;
		options_1 |= ((NU8)1)<<(((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)3))) & 7);
	}
LA6_: ;
	{
		if (!!(standaloneDoc_p5)) goto LA10_;
		options_1 |= ((NU8)1)<<(((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)4))) & 7);
	}
LA10_: ;
	(*result).Sup.hasToc = hasToc_p7;
	nimZeroMem((void*)(&T12_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T12_.ClP_0 = docgenFindFile__docgen_u1972; T12_.ClE_0 = colonenv__1;
	nimZeroMem((void*)(&T13_), sizeof(tyProc__lYMtBEH0vEMRzoDaCw5CJg));
	T13_.ClP_0 = docgenFindRefFile__docgen_u1975; T13_.ClE_0 = colonenv__1;
	nimZeroMem((void*)(&T14_), sizeof(tyProc__lsy8uLKFmavBA17NQuqO5g));
	T14_.ClP_0 = compilerMsgHandler__docgen_u1956; T14_.ClE_0 = colonenv__1;
	T15_ = NIM_NIL;
	T15_ = newRstSharedState__packagesZdocutilsZrst_u2425(options_1, (*colonenv__1).filename2, T12_, T13_, T14_, hasToc_p7);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrst_u3741(T15_); goto LA1_;}
	eqsink___packagesZdocutilsZrst_u3752(&(*result).sharedState, T15_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T16_ = (tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0;
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = isLatexCmd__docgen_u1921((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T19_) goto LA20_;
		colontmpD__3 = ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1);
		T16_ = colontmpD__3;
	}
	goto LA17_;
LA20_: ;
	{
		colontmpD__4 = ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0);
		T16_ = colontmpD__4;
	}
LA17_: ;
	nimZeroMem((void*)(&T23_), sizeof(tyProc__oFHfEKFsiYTMAy9a42cSiKw));
	T23_.ClP_0 = docgenFindFile__docgen_u1972; T23_.ClE_0 = colonenv__1;
	nimZeroMem((void*)(&T24_), sizeof(tyProc__lsy8uLKFmavBA17NQuqO5g));
	T24_.ClP_0 = compilerMsgHandler__docgen_u1956; T24_.ClE_0 = colonenv__1;
	nimZeroMem((void*)(&colontmpD__5), sizeof(tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg));
	initRstGenerator__packagesZdocutilsZrstgen_u86(&result->Sup, T16_, (*(*colonenv__1).conf0).configVars, (*colonenv__1).filename2, T23_, T24_, (&colontmpD__5), NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T27_;
		T27_ = (NIM_BOOL)0;
		T27_ = nsthasKey((*(*colonenv__1).conf0).configVars, TM__5fUAZGW8WPeit3fZaQyNXA_41);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T27_)) goto LA28_;
		T27_ = nsthasKey((*(*colonenv__1).conf0).configVars, TM__5fUAZGW8WPeit3fZaQyNXA_43);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA28_: ;
		if (!T27_) goto LA29_;
		raiseAssert__stdZassertions_u15(TM__5fUAZGW8WPeit3fZaQyNXA_45);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA29_: ;
	{
		NIM_BOOL T33_;
		NimStringV2 colontmpD__8;
		tyArray__YgExxhfgKcesA5EOUj1MOA T37_;
		NimStringV2 T38_;
		T33_ = (NIM_BOOL)0;
		T33_ = nsthasKey((*(*colonenv__1).conf0).configVars, TM__5fUAZGW8WPeit3fZaQyNXA_46);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T33_) goto LA34_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__8 = getOrDefault__pureZstrtabs_u390((*(*colonenv__1).conf0).configVars, TM__5fUAZGW8WPeit3fZaQyNXA_50, TM__5fUAZGW8WPeit3fZaQyNXA_51);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		T37_[0] = colontmpD__8;
		T38_.len = 0; T38_.p = NIM_NIL;
		T38_ = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_48, T37_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T38_); goto LA36_;}
		eqsink___system_u2700((&(*result).analytics), T38_);
		{
			LA36_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA31_;
LA34_: ;
	{
		NIM_BOOL T42_;
		NimStringV2 colontmpD__9;
		tyArray__YgExxhfgKcesA5EOUj1MOA T46_;
		NimStringV2 T47_;
		T42_ = (NIM_BOOL)0;
		T42_ = nsthasKey((*(*colonenv__1).conf0).configVars, TM__5fUAZGW8WPeit3fZaQyNXA_52);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T42_) goto LA43_;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__9 = getOrDefault__pureZstrtabs_u390((*(*colonenv__1).conf0).configVars, TM__5fUAZGW8WPeit3fZaQyNXA_56, TM__5fUAZGW8WPeit3fZaQyNXA_57);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T46_[0] = colontmpD__9;
		T47_.len = 0; T47_.p = NIM_NIL;
		T47_ = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_54, T46_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T47_); goto LA45_;}
		eqsink___system_u2700((&(*result).analytics), T47_);
		{
			LA45_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA31_;
LA43_: ;
	{
		eqsink___system_u2700((&(*result).analytics), TM__5fUAZGW8WPeit3fZaQyNXA_58);
	}
LA31_: ;
	T51_ = NIM_NIL;
	T51_ = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)1));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___pureZstrtabs_u525(T51_); goto LA1_;}
	eqsink___pureZstrtabs_u536(&(*result).seenSymbols, T51_);
	(*result).Sup.id = ((NI)100);
	T52_ = NIM_NIL;
	T52_ = newJArray__pureZjson_u506();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___pureZjson_u324(T52_); goto LA1_;}
	eqsink___pureZjson_u333(&(*result).jEntriesFinal, T52_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T53_ = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6338(T53_); goto LA1_;}
	eqsink___ast_u6347((&(*result).types), T53_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = eqdup___docgen_u13898(colonenv__1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nimZeroMem((void*)(&T54_), sizeof(tyProc__9bd86QnQPXw1dUoLzfDMOKg));
	T54_.ClP_0 = colonanonymous___docgen_u1993; T54_.ClE_0 = colontmpD__6;
	eqsink___docgen_u3501((&(*result).Sup.onTestSnippet), T54_);
	nimZeroMem((void*)(&T55_), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&T55_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___pureZcollectionsZintsets_u236((&(*result).emitted), (&T55_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&(*result).Sup.destFile), (*colonenv__1).destFile1);
	splitFile__pathutils_u39((*result).Sup.destFile, (&colontmpD__7));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___system_u2700((&(*result).thisDir), colontmpD__7.Field0);
	eqwasMoved___system_u2688((&colontmpD__7.Field0));
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pathutils_u73((&colontmpD__7));
		eqdestroy___packagesZdocutilsZrst_u17753((&colontmpD__5));
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___docgen_u13891(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u3477)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ** dest_p0, tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* src_p1) {
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* colontmp_;
	colontmp_ = (*dest_p0);
	(*dest_p0) = src_p1;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u3463)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ** dest_p0) {
	(*dest_p0) = 0;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genDeprecationMsg__docgen_u6432)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 result;
	NI T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!(n_p1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	T5_ = (NI)0;
	T5_ = safeLen__ast_u3197(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch (T5_) {
	case ((NI)0):
	{
		NimStringV2 colontmpD_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_101, TM__5fUAZGW8WPeit3fZaQyNXA_102);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		result = nsuFormatOpenArray(colontmpD_, TM__5fUAZGW8WPeit3fZaQyNXA_103, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((NI)2):
	{
		{
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T16_;
			if (!((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA13_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__2 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_107, TM__5fUAZGW8WPeit3fZaQyNXA_108);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T16_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_109;
			T16_[1] = TM__5fUAZGW8WPeit3fZaQyNXA_111;
			T16_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_112;
			colontmpD__3 = escape__pureZxmltree_u1069((*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T16_[3] = colontmpD__3;
			result = nsuFormatOpenArray(colontmpD__2, T16_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			{
				LA15_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA11_;
LA13_: ;
		{
			result = TM__5fUAZGW8WPeit3fZaQyNXA_113;
		}
LA11_: ;
	}
	break;
	default:
	{
		raiseAssert__stdZassertions_u15(TM__5fUAZGW8WPeit3fZaQyNXA_115);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setDoctype__docgen_u9685)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 dt_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	dt_1.len = 0; dt_1.p = NIM_NIL;
	{
		if (!(n_p1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		eqdestroy___system_u2691(dt_1);
		goto BeforeRet_;
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (NI)0;
		T8_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((T8_ == ((NI)2)))) goto LA9_;
		liMessage__msgs_u1227((*d_p0).conf, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19), TM__5fUAZGW8WPeit3fZaQyNXA_117, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__5fUAZGW8WPeit3fZaQyNXA_118), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(dt_1);
		goto BeforeRet_;
	}
LA9_: ;
	dt_1 = TM__5fUAZGW8WPeit3fZaQyNXA_119;
	switch ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20):
	{
		NimStringV2 T12_;
		T12_.len = 0; T12_.p = NIM_NIL;
		T12_ = nsuToLowerAsciiStr((*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T12_); goto LA1_;}
		eqsink___system_u2700((&dt_1), T12_);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		NimStringV2 T14_;
		T14_.len = 0; T14_.p = NIM_NIL;
		T14_ = nsuToLowerAsciiStr((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident).s);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T14_); goto LA1_;}
		eqsink___system_u2700((&dt_1), T14_);
	}
	break;
	default:
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T17_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD_ = dollar___nodekinds_u168((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind);
		T17_[0] = colontmpD_;
		colontmpD__2 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_121, T17_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		liMessage__msgs_u1227((*d_p0).conf, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__5fUAZGW8WPeit3fZaQyNXA_122), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(dt_1);
		goto BeforeRet_;
		{
			LA16_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	if (eqStrings(dt_1, TM__5fUAZGW8WPeit3fZaQyNXA_124)) goto LA20_;
	if (eqStrings(dt_1, TM__5fUAZGW8WPeit3fZaQyNXA_126)) goto LA21_;
	if (eqStrings(dt_1, TM__5fUAZGW8WPeit3fZaQyNXA_128)) goto LA22_;
	goto LA23_;
	LA20_: ;
	{
		(*(*d_p0).sharedState).options |= ((NU8)1)<<(((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)2))) & 7);
		(*(*d_p0).sharedState).options |= ((NU8)1)<<(((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)3))) & 7);
	}
	goto LA24_;
	LA21_: ;
	{
		(*(*d_p0).sharedState).options |= ((NU8)1)<<(((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)2))) & 7);
		(*(*d_p0).sharedState).options &= ~(((NU8)1) << (((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)3))) & 7));
	}
	goto LA24_;
	LA22_: ;
	{
		(*(*d_p0).sharedState).options &= ~(((NU8)1) << (((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)2))) & 7));
		(*(*d_p0).sharedState).options &= ~(((NU8)1) << (((((tyEnum_RstParseOption__mQDjQMWj1He9c82GsKA9b59bg)3))) & 7));
	}
	goto LA24_;
	LA23_: ;
	{
		NimStringV2 colontmpD__3;
		tyArray__YgExxhfgKcesA5EOUj1MOA T30_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T30_[0] = dt_1;
		colontmpD__3 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_130, T30_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		liMessage__msgs_u1227((*d_p0).conf, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__5fUAZGW8WPeit3fZaQyNXA_131), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		{
			LA29_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA24_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(dt_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u129)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* rst_p1) {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD_;
	tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
	T1_.isRst = NIM_TRUE;
	colontmpD_ = eqdup___packagesZdocutilsZrstast_u291(rst_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_._isRst_1.rst = colontmpD_;
	add__docgen_u132((&(*dest_p0)), T1_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI32, addRstFileIndex__docgen_u200)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NI32 fileIndex_p1) {
	NI32 result;
	NI32 invalid_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI32)0;
	invalid_1 = ((NI32)-1);
	result = getOrDefault__docgen_u271((*d_p0).nimToRstFid, fileIndex_p1, invalid_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 fname_1;
		if (!(result == invalid_1)) goto LA3_;
		fname_1.len = 0; fname_1.p = NIM_NIL;
		fname_1 = toFullPath__msgs_u624((*d_p0).conf, fileIndex_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = addFilename__packagesZdocutilsZrst_u863((*d_p0).sharedState, fname_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		X5BX5Deq___docgen_u708((&(*d_p0).nimToRstFid), fileIndex_p1, result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(fname_1);
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, addRstFileIndex__docgen_u1723)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	NI32 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI32)0;
	result = addRstFileIndex__docgen_u200(d_p0, info_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, parseRst__docgen_u1900)(NimStringV2 text_p0, NI line_p1, NI column_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3, tyObject_RstSharedState__6YauuaWEZeOKzNYK3p1vqA* sharedState_p4) {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = rstParsePass1__packagesZdocutilsZrst_u15585(text_p0, line_p1, column_p2, sharedState_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, toLinenumber__msgs_u695)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0) {
	NI result;
	result = ((NI) (info_p0.line));
	return result;
}
static N_INLINE(NI, toColumn__msgs_u698)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0) {
	NI result;
	result = ((NI) (info_p0.col));
	return result;
}
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (targetDepth_p1 <= (*source_p0).depth);
	if (!(T1_)) goto LA2_;
	T1_ = ((*source_p0).display[targetDepth_p1] == token_p2);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = currException__system_u3628;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	eqcopy___system_u3661(&currException__system_u3628, (*currException__system_u3628).up, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, genComment__docgen_u3537)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* result;
	NimStringV2 colontmpD_;
NIM_BOOL oldNimErrFin25_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		NI32 T13_;
		NimStringV2 colontmpD__3;
		NimStringV2 T16_;
		NI T17_;
		NI T18_;
		tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* T19_;
		colontmpD_ = comment__ast_u836(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)0) < colontmpD_.len)) goto LA4_;
		{
			NimStringV2 colontmpD__2;
			if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)57)))&63U)))!=0)) goto LA8_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = comment__ast_u836(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			result = newRstLeaf__packagesZdocutilsZrstast_u454(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			goto BeforeRet_;
			{
				LA10_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA8_: ;
		T13_ = (NI32)0;
		T13_ = addRstFileIndex__docgen_u1723(d_p0, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*(*d_p0).sharedState).currFileIdx = T13_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T16_.len = 0; T16_.p = NIM_NIL;
		T16_ = comment__ast_u836(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T16_); goto LA15_;}
		colontmpD__3 = T16_;
		T17_ = (NI)0;
		T17_ = toLinenumber__msgs_u695((*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T18_ = (NI)0;
		T18_ = toColumn__msgs_u698((*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T19_ = NIM_NIL;
		T19_ = parseRst__docgen_u1900(colontmpD__3, T17_, (NI)(T18_ + ((NI)3)), (*d_p0).conf, (*d_p0).sharedState);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrstast_u285(T19_); goto LA15_;}
		result = T19_;
		{
			LA15_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		if (NIM_UNLIKELY(*nimErr_)) {
			LA14_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 4, 4171512832)) {
				NimStringV2 colontmpD__4;
				tySequence__LqZapiAqCFeXPQZdoIAUew colontmpD__5;
				NimStringV2 T26_;
				tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* T27_;
				tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* T28_;
				*nimErr_ = NIM_FALSE;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__5.len = 1; colontmpD__5.p = (tySequence__LqZapiAqCFeXPQZdoIAUew_Content*) newSeqPayload(1, sizeof(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*), NIM_ALIGNOF(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*));
				T26_.len = 0; T26_.p = NIM_NIL;
				T26_ = comment__ast_u836(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T26_); goto LA25_;}
				colontmpD__4 = T26_;
				T27_ = NIM_NIL;
				T27_ = newRstLeaf__packagesZdocutilsZrstast_u454(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrstast_u285(T27_); goto LA25_;}
				colontmpD__5.p->data[0] = T27_;
				T28_ = NIM_NIL;
				T28_ = newRstNode__packagesZdocutilsZrstast_u121(((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)26), colontmpD__5, TM__5fUAZGW8WPeit3fZaQyNXA_132);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrstast_u285(T28_); goto LA25_;}
				result = T28_;
				{
					LA25_:;
				}
				{
					oldNimErrFin25_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___packagesZdocutilsZrstast_u152(colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					eqdestroy___system_u2691(colontmpD__4);
					*nimErr_ = oldNimErrFin25_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				popCurrentException();
				LA23_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		result = ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, documentEffect__docgen_u9781)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw effectType_p3, NI idx_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* spec_1;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	spec_1 = NIM_NIL;
	spec_1 = effectSpec__trees_u307(x_p2, effectType_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* actual_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* real_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* effects_1;
		NimStringV2 colontmpD_;
		tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD__2;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
		NI realLen_1;
		tyArray__al2p7ldDMvbBVYNFCuu4Rw T29_;
		if (!(spec_1 == 0)) goto LA4_;
		s_1 = NIM_NIL;
		actual_1 = NIM_NIL;
		real_1 = NIM_NIL;
		effects_1 = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		colontmpD__3 = NIM_NIL;
		s_1 = (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym;
		eqcopy___ast_u3255(&actual_1, (*(*(*s_1).typ).n)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			NI T9_;
			T9_ = (NI)0;
			T9_ = len__ast_u3190(actual_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			if (!!((T9_ == ((NI)6)))) goto LA10_;
			eqdestroy___ast_u3252(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___idents_u155(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u3252(effects_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(real_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(actual_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(spec_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA10_: ;
		eqcopy___ast_u3255(&real_1, (*actual_1)._kind_6.sons.p->data[idx_p4]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			if (!(real_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA14_;
			eqdestroy___ast_u3252(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___idents_u155(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u3252(effects_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(real_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(actual_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(spec_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA14_: ;
		realLen_1 = len__ast_u3190(real_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		effects_1 = newNodeI__ast_u4095(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41), (*n_p1).info, realLen_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = ((NI)0);
			{
				while (1) {
					NimStringV2 t_1;
					tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD__4;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T26_;
					if (!(i_2 < realLen_1)) goto LA18;
					t_1.len = 0; t_1.p = NIM_NIL;
					colontmpD__4 = NIM_NIL;
					i_1 = i_2;
					t_1 = typeToString__types_u54((*(*real_1)._kind_6.sons.p->data[i_1]).typField, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					{
						NIM_BOOL T22_;
						NimStringV2 T25_;
						T22_ = (NIM_BOOL)0;
						T22_ = nsuStartsWith(t_1, TM__5fUAZGW8WPeit3fZaQyNXA_134);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						if (!T22_) goto LA23_;
						T25_.len = 0; T25_.p = NIM_NIL;
						T25_ = substr__system_u8664(t_1, ((NI)4));
						eqsink___system_u2700((&t_1), T25_);
					}
LA23_: ;
					colontmpD__4 = getIdent__idents_u206(cache_p0, t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					T26_ = NIM_NIL;
					T26_ = newIdentNode__ast_u5164(colontmpD__4, (*n_p1).info);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T26_); goto LA19_;}
					eqsink___ast_u3261(&(*effects_1)._kind_6.sons.p->data[i_1], T26_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					eqcopy___ast_u3381(&(*(*effects_1)._kind_6.sons.p->data[i_1]).typField, (*(*real_1)._kind_6.sons.p->data[i_1]).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					i_2 += ((NI)1);
					{
						LA19_:;
					}
					{
						oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___idents_u155(colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						eqdestroy___system_u2691(t_1);
						*nimErr_ = oldNimErrFin19_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				} LA18: ;
			}
		}
		nimZeroMem((void*)T29_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
		colontmpD_ = dollar___wordrecg_u307(effectType_p3);
		colontmpD__2 = getIdent__idents_u206(cache_p0, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__3 = newIdentNode__ast_u5164(colontmpD__2, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T29_[0] = colontmpD__3;
		T29_[1] = effects_1;
		result = newTreeI__ast_u4180(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34), (*n_p1).info, T29_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___idents_u155(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u3252(effects_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(real_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(actual_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(spec_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, documentWriteEffect__docgen_u9810)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flag_p2, NimStringV2 pragmaName_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* params_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* effects_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	s_1 = NIM_NIL;
	params_1 = NIM_NIL;
	effects_1 = NIM_NIL;
	s_1 = (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym;
	eqcopy___ast_u3255(&params_1, (*(*s_1).typ).n);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	effects_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41), (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(params_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i_1 = i_2;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = ((*(*params_1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
					if (!(T6_)) goto LA7_;
					T6_ = (((*(*(*params_1)._kind_6.sons.p->data[i_1])._kind_4.sym).flags &((NU64)1<<((NU)((flag_p2))&63U)))!=0);
LA7_: ;
					if (!T6_) goto LA8_;
					add__ast_u3215(effects_1, (*params_1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA8_: ;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	{
		NI T12_;
		tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
		tyArray__al2p7ldDMvbBVYNFCuu4Rw T15_;
		T12_ = (NI)0;
		T12_ = len__ast_u3190(effects_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(((NI)0) < T12_)) goto LA13_;
		colontmpD_ = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		nimZeroMem((void*)T15_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
		colontmpD_ = getIdent__idents_u206(cache_p0, pragmaName_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__2 = newIdentNode__ast_u5164(colontmpD_, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T15_[0] = colontmpD__2;
		T15_[1] = effects_1;
		result = newTreeI__ast_u4180(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34), (*n_p1).info, T15_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA10_;
LA13_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA10_: ;
	eqdestroy___ast_u3252(effects_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(params_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, documentNewEffect__docgen_u9772)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	s_1 = NIM_NIL;
	s_1 = (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym;
	{
		tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
		if (!(((*(*s_1).typ).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)3)))&63U)))!=0)) goto LA3_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = getIdent__idents_u206(cache_p0, TM__5fUAZGW8WPeit3fZaQyNXA_138);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = newIdentNode__ast_u5164(colontmpD_, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, documentRaises__docgen_u9832)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragmas_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p1_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p2_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p3_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p4_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p5_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p6_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	pragmas_1 = NIM_NIL;
	p1_1 = NIM_NIL;
	p2_1 = NIM_NIL;
	p3_1 = NIM_NIL;
	p4_1 = NIM_NIL;
	p5_1 = NIM_NIL;
	p6_1 = NIM_NIL;
	{
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA4_;
		eqdestroy___ast_u3252(p6_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p5_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p4_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p3_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p1_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(pragmas_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	eqcopy___ast_u3255(&pragmas_1, (*n_p1)._kind_6.sons.p->data[((NI)4)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	p1_1 = documentEffect__docgen_u9781(cache_p0, n_p1, pragmas_1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)175), ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	p2_1 = documentEffect__docgen_u9781(cache_p0, n_p1, pragmas_1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)180), ((NI)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	p3_1 = documentWriteEffect__docgen_u9810(cache_p0, n_p1, ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)31), TM__5fUAZGW8WPeit3fZaQyNXA_136);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	p4_1 = documentNewEffect__docgen_u9772(cache_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	p5_1 = documentWriteEffect__docgen_u9810(cache_p0, n_p1, ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)19), TM__5fUAZGW8WPeit3fZaQyNXA_140);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	p6_1 = documentEffect__docgen_u9781(cache_p0, n_p1, pragmas_1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)181), ((NI)5));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T8_;
		NIM_BOOL T9_;
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		T8_ = (NIM_BOOL)0;
		T9_ = (NIM_BOOL)0;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T12_ = !((p1_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
		if (T12_) goto LA13_;
		T12_ = !((p2_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA13_: ;
		T11_ = T12_;
		if (T11_) goto LA14_;
		T11_ = !((p3_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA14_: ;
		T10_ = T11_;
		if (T10_) goto LA15_;
		T10_ = !((p4_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA15_: ;
		T9_ = T10_;
		if (T9_) goto LA16_;
		T9_ = !((p5_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA16_: ;
		T8_ = T9_;
		if (T8_) goto LA17_;
		T8_ = !((p6_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA17_: ;
		if (!T8_) goto LA18_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T24_;
			if (!((*pragmas_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1))) goto LA22_;
			T24_ = NIM_NIL;
			T24_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90), (*n_p1).info);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T24_); goto LA1_;}
			eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)4)], T24_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA22_: ;
		{
			if (!!((p1_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA27_;
			add__ast_u3215((*n_p1)._kind_6.sons.p->data[((NI)4)], p1_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA27_: ;
		{
			if (!!((p2_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA31_;
			add__ast_u3215((*n_p1)._kind_6.sons.p->data[((NI)4)], p2_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA31_: ;
		{
			if (!!((p3_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA35_;
			add__ast_u3215((*n_p1)._kind_6.sons.p->data[((NI)4)], p3_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA35_: ;
		{
			if (!!((p4_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA39_;
			add__ast_u3215((*n_p1)._kind_6.sons.p->data[((NI)4)], p4_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA39_: ;
		{
			if (!!((p5_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA43_;
			add__ast_u3215((*n_p1)._kind_6.sons.p->data[((NI)4)], p5_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA43_: ;
		{
			if (!!((p6_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA47_;
			add__ast_u3215((*n_p1)._kind_6.sons.p->data[((NI)4)], p6_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA47_: ;
	}
LA18_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(p6_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p5_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p4_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p3_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(p1_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(pragmas_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isVisible__docgen_u6310)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31))) goto LA3_;
		{
			NIM_BOOL T7_;
			NI T8_;
			tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* v_1;
			NIM_BOOL T12_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NI)0;
			T8_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T7_ = (T8_ == ((NI)2));
			if (!(T7_)) goto LA9_;
			T7_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA9_: ;
			if (!T7_) goto LA10_;
			v_1 = NIM_NIL;
			v_1 = (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_5.ident;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*v_1).id == ((NI)72));
			if (T12_) goto LA13_;
			T12_ = ((*v_1).id == ((NI)73));
LA13_: ;
			result = T12_;
		}
LA10_: ;
	}
	goto LA1_;
LA3_: ;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA15_;
		{
			tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T21_;
			if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)39)))&63U)))!=0)) goto LA19_;
			T21_ = 0;
			result = ((20 & (*(*n_p1)._kind_4.sym).flags) == T21_);
		}
		goto LA17_;
LA19_: ;
		{
			result = ((22 & (*(*n_p1)._kind_4.sym).flags) == 2);
		}
LA17_: ;
		{
			NIM_BOOL T25_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym187__1;
			T25_ = (NIM_BOOL)0;
			T25_ = result;
			if (!(T25_)) goto LA26_;
			xX60gensym187__1 = (*(*n_p1)._kind_4.sym).itemId;
			T25_ = containsOrIncl__astyaml_u223((&(*d_p0).emitted), (NI)((NI)((NU64)(((NI) (xX60gensym187__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym187__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA26_: ;
			if (!T25_) goto LA27_;
			result = NIM_FALSE;
		}
LA27_: ;
	}
	goto LA1_;
LA15_: ;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)43))) goto LA30_;
		result = isVisible__docgen_u6310(d_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA30_: ;
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getName__docgen_u6374)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	switch ((*n_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31):
	{
		result = getName__docgen_u6374((*n_p0)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)43):
	{
		result = getName__docgen_u6374((*n_p0)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		result = renderDefinitionName__renderer_u125((*n_p0)._kind_4.sym, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		eqcopy___system_u2694((&result), (*(*n_p0)._kind_5.ident).s);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53):
	{
		result = TM__5fUAZGW8WPeit3fZaQyNXA_142;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					NimStringV2 colontmpD_;
					if (!(i_2 < colontmp_)) goto LA8;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					i_1 = i_2;
					colontmpD_ = getName__docgen_u6374((*n_p0)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
					i_2 += ((NI)1);
					eqdestroy___system_u2691(colontmpD_);
				} LA8: ;
			}
		}
		nimAddCharV1((&result), 96);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
	{
		result = getName__docgen_u6374((*n_p0)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		result = TM__5fUAZGW8WPeit3fZaQyNXA_143;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPlainDocstring__docgen_u3590)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		if (!(n_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		result = TM__5fUAZGW8WPeit3fZaQyNXA_144;
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T7_;
		colontmpD_ = comment__ast_u836(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = (NIM_BOOL)0;
		T7_ = nsuStartsWith(colontmpD_, TM__5fUAZGW8WPeit3fZaQyNXA_146);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T7_) goto LA8_;
		result = comment__ast_u836(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA8_: ;
	{
		result = TM__5fUAZGW8WPeit3fZaQyNXA_147;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)0);
			{
				while (1) {
					NimStringV2 T14_;
					if (!(i_2 < colontmp_)) goto LA13;
					i_1 = i_2;
					T14_.len = 0; T14_.p = NIM_NIL;
					T14_ = getPlainDocstring__docgen_u3590((*n_p0)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T14_); goto LA1_;}
					eqsink___system_u2700((&result), T14_);
					{
						if (!(((NI)0) < result.len)) goto LA17_;
						eqdestroy___system_u2691(colontmpD_);
						goto BeforeRet_;
					}
LA17_: ;
					i_2 += ((NI)1);
				} LA13: ;
			}
		}
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getRoutineBody__docgen_u6271)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3255(&result, (*n_p0)._kind_6.sons.p->data[((NI)6)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI T8_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*result).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*result)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T8_ = (NI)0;
		T8_ = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (((NI)7) < T8_);
LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA9_;
		T3_ = ((*(*n_p0)._kind_6.sons.p->data[((NI)7)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA9_: ;
		if (!T3_) goto LA10_;
		{
			NI T14_;
			T14_ = (NI)0;
			T14_ = len__ast_u3190(result);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!((T14_ == ((NI)2)))) goto LA15_;
			failedAssertImpl__stdZassertions_u79(TM__5fUAZGW8WPeit3fZaQyNXA_152);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA15_: ;
		eqcopy___ast_u3255(&result, (*result)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA10_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, genRecCommentAux__docgen_u3549)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!(n_p1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		result = ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL);
		goto BeforeRet_;
	}
LA3_: ;
	result = genComment__docgen_u3537(d_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(result == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL))) goto LA7_;
		{
			if (!((TM__5fUAZGW8WPeit3fZaQyNXA_153[(NU)(((*n_p1).kind))>>3] &(1U<<((NU)(((*n_p1).kind))&7U)))!=0)) goto LA11_;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 = ((NI)0);
				{
					while (1) {
						tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* T16_;
						if (!(i_2 < colontmp_)) goto LA15;
						i_1 = i_2;
						T16_ = NIM_NIL;
						T16_ = genRecCommentAux__docgen_u3549(d_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrstast_u285(T16_); goto BeforeRet_;}
						eqsink___packagesZdocutilsZrstast_u294(&result, T16_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						{
							if (!!((result == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL)))) goto LA19_;
							goto BeforeRet_;
						}
LA19_: ;
						i_2 += ((NI)1);
					} LA15: ;
				}
			}
		}
LA11_: ;
	}
	goto LA5_;
LA7_: ;
	{
		commenteq___ast_u1334(n_p1, TM__5fUAZGW8WPeit3fZaQyNXA_154);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, genRecComment__docgen_u3574)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!(n_p1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		result = ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL);
		goto BeforeRet_;
	}
LA3_: ;
	result = genComment__docgen_u3537(d_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(result == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL))) goto LA7_;
		{
			tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* T13_;
			if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81))) goto LA11_;
			T13_ = NIM_NIL;
			T13_ = genRecCommentAux__docgen_u3549(d_p0, (*n_p1)._kind_6.sons.p->data[((NI)6)]);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrstast_u285(T13_); goto BeforeRet_;}
			eqsink___packagesZdocutilsZrstast_u294(&result, T13_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA9_;
LA11_: ;
		{
			tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* T15_;
			T15_ = NIM_NIL;
			T15_ = genRecCommentAux__docgen_u3549(d_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrstast_u285(T15_); goto BeforeRet_;}
			eqsink___packagesZdocutilsZrstast_u294(&result, T15_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA9_: ;
	}
LA7_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	T1_ = X5BX5D___ast_u5211((((*n_p0)._kind_6.sons).p) ? ((*n_p0)._kind_6.sons.p->data) : NIM_NIL, (*n_p0)._kind_6.sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u707)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = TM__5fUAZGW8WPeit3fZaQyNXA_162;
	colontmpD_ = toMsgFilename__msgs_u688(conf_p0, info_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
	{
		if (!(((NI)0) < ((NI) (info_p1.line)))) goto LA4_;
		prepareAdd((&result), 1);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_164);
		addInt__stdZprivateZdigitsutils_u204((&result), ((NI) (info_p1.line)));
		{
			if (!(((NI)0) < (NI)(((NI) (info_p1.col)) + ((NI)1)))) goto LA8_;
			prepareAdd((&result), 2);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_166);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)(((NI) (info_p1.col)) + ((NI)1)));
		}
LA8_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_168);
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, exampleOutputDir__docgen_u3687)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getNimcacheDir__options_u3737((*d_p0).conf);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = slash___pathutils_u166(colontmpD_, TM__5fUAZGW8WPeit3fZaQyNXA_172);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toInstantiationInfo__docgen_u4107)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyTuple__kN8up2W6YKc5YA9avn5mV5w* Result) {
	NimStringV2 colontmp_;
	NI colontmp__2;
	NI colontmp__3;
	NimStringV2 blitTmp_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__kN8up2W6YKc5YA9avn5mV5w));
	colontmp_.len = 0; colontmp_.p = NIM_NIL;
	colontmp_ = toMsgFilename__msgs_u688(conf_p0, info_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmp__2 = ((NI) (info_p1.line));
	colontmp__3 = (NI)(((NI) (info_p1.col)) + ((NI)1));
	blitTmp_1 = colontmp_;
	eqwasMoved___system_u2688((&colontmp_));
	(*Result).Field0 = blitTmp_1;
	(*Result).Field1 = colontmp__2;
	(*Result).Field2 = colontmp__3;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmp_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, quoted__docgen_u4100)(NimStringV2 a_p0) {
	NimStringV2 result;
	result = TM__5fUAZGW8WPeit3fZaQyNXA_185;
	addQuoted__stdZprivateZoscommon_u120((&result), a_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u4012)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ** dest_p0, tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* src_p1) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___docgen_u3106((&(*(*dest_p0))));
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u4000)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ** dest_p0) {
	(*dest_p0) = 0;
}
static N_INLINE(NI, len__docgen_u3743)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0) {
	NI result;
	result = (*t_p0).counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, prepareExample__docgen_u4111)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL topLevel_p2, tyTuple__UV3llMMYFckfui8YMBuUZA* Result) {
	NimStringV2 rdoccmd_1;
	NimStringV2 loc_1;
	NimStringV2 code_1;
	NimStringV2 comment_1;
	NimStringV2 outputDir_1;
	NimStringV2 outp_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 codeShown_1;
	NimStringV2 colontmp_;
	NimStringV2 colontmp__2;
	NIM_BOOL useRenderModule_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T26_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T27_;
NIM_BOOL oldNimErrFin32_;
	tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ** T68_;
	NimStringV2 blitTmp_3;
	NimStringV2 blitTmp_4;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	rdoccmd_1.len = 0; rdoccmd_1.p = NIM_NIL;
	loc_1.len = 0; loc_1.p = NIM_NIL;
	code_1.len = 0; code_1.p = NIM_NIL;
	comment_1.len = 0; comment_1.p = NIM_NIL;
	outputDir_1.len = 0; outputDir_1.p = NIM_NIL;
	outp_1.len = 0; outp_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	codeShown_1.len = 0; codeShown_1.p = NIM_NIL;
	colontmp_.len = 0; colontmp_.p = NIM_NIL;
	colontmp__2.len = 0; colontmp__2.p = NIM_NIL;
	rdoccmd_1 = TM__5fUAZGW8WPeit3fZaQyNXA_155;
	{
		NIM_BOOL T4_;
		NI T5_;
		NI T7_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = (T5_ < ((NI)2));
		if (T4_) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = (((NI)3) < T7_);
LA6_: ;
		if (!T4_) goto LA8_;
		liMessage__msgs_u1227((*d_p0).conf, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__5fUAZGW8WPeit3fZaQyNXA_157, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__5fUAZGW8WPeit3fZaQyNXA_158), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		NI T12_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n1_1;
		T12_ = (NI)0;
		T12_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T12_ == ((NI)3))) goto LA13_;
		n1_1 = NIM_NIL;
		n1_1 = (*n_p1)._kind_6.sons.p->data[((NI)1)];
		{
			if (!!(((*n1_1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*n1_1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22)))) goto LA17_;
			liMessage__msgs_u1227((*d_p0).conf, (*n1_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__5fUAZGW8WPeit3fZaQyNXA_160, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__5fUAZGW8WPeit3fZaQyNXA_161), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA17_: ;
		eqcopy___system_u2694((&rdoccmd_1), (*n1_1)._kind_3.strVal);
	}
LA13_: ;
	useRenderModule_1 = NIM_FALSE;
	loc_1 = toFileLineCol__msgs_u707((*d_p0).conf, (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	code_1 = extractRunnableExamplesSource__renderverbatim_u95((*d_p0).conf, n_p1, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmp__3;
		NimStringV2 colontmp__4;
		NimStringV2 blitTmp_1;
		NimStringV2 blitTmp_2;
		if (!(((NI)0) < (*(*d_p0).conf).errorCounter)) goto LA21_;
		colontmp__3.len = 0; colontmp__3.p = NIM_NIL;
		colontmp__4.len = 0; colontmp__4.p = NIM_NIL;
		colontmp__3 = rdoccmd_1;
		eqwasMoved___system_u2688((&rdoccmd_1));
		colontmp__4 = code_1;
		eqwasMoved___system_u2688((&code_1));
		blitTmp_1 = colontmp__3;
		eqwasMoved___system_u2688((&colontmp__3));
		(*Result).Field0 = blitTmp_1;
		blitTmp_2 = colontmp__4;
		eqwasMoved___system_u2688((&colontmp__4));
		(*Result).Field1 = blitTmp_2;
		eqdestroy___system_u2691(colontmp__4);
		eqdestroy___system_u2691(colontmp__3);
		eqdestroy___system_u2691(colontmp__2);
		eqdestroy___system_u2691(colontmp_);
		eqdestroy___system_u2691(codeShown_1);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(outp_1);
		eqdestroy___system_u2691(outputDir_1);
		eqdestroy___system_u2691(comment_1);
		eqdestroy___system_u2691(code_1);
		eqdestroy___system_u2691(loc_1);
		eqdestroy___system_u2691(rdoccmd_1);
		goto BeforeRet_;
		{
			LA23_:;
		}
		{
			eqdestroy___system_u2691(colontmp__4);
			eqdestroy___system_u2691(colontmp__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA21_: ;
	T26_[0] = loc_1;
	T26_[1] = rdoccmd_1;
	comment_1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_170, T26_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	outputDir_1 = exampleOutputDir__docgen_u3687(d_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	noscreateDir(outputDir_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*d_p0).exampleCounter += ((NI)1);
	colontmpD_ = nosextractFilename((*d_p0).Sup.filename);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = noschangeFileExt(colontmpD_, TM__5fUAZGW8WPeit3fZaQyNXA_176);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T27_[0] = colontmpD__2;
	colontmpD__3 = dollar___systemZdollars_u9((*d_p0).exampleCounter);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T27_[1] = colontmpD__3;
	colontmpD__4 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_174, T27_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	outp_1 = slash___pathutils_u135(outputDir_1, colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* docComment_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* runnableExamples_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__7;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__9;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__10;
		tyArray__Nwi28HyTG9cEj6FfWArgLbQ T33_;
		tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ T34_;
		tyArray__TAsXwXSUBvAawE1kIQ5ziQ T35_;
		tyArray__TAsXwXSUBvAawE1kIQ5ziQ T36_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T41_;
		if (!useRenderModule_1) goto LA30_;
		docComment_1 = NIM_NIL;
		runnableExamples_1 = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		colontmpD__8 = NIM_NIL;
		colontmpD__9 = NIM_NIL;
		colontmpD__10 = NIM_NIL;
		nimZeroMem((void*)T33_, sizeof(tyArray__Nwi28HyTG9cEj6FfWArgLbQ));
		docComment_1 = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125), T33_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		commenteq___ast_u1334(docComment_1, comment_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		nimZeroMem((void*)T34_, sizeof(tyArray__JEzAlj49cAK8qpM6I2Q9bfcQ));
		T34_[0] = docComment_1;
		nimZeroMem((void*)T35_, sizeof(tyArray__TAsXwXSUBvAawE1kIQ5ziQ));
		colontmpD__7 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), TM__5fUAZGW8WPeit3fZaQyNXA_178);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		T35_[0] = colontmpD__7;
		colontmpD__8 = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116), T35_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		T34_[1] = colontmpD__8;
		nimZeroMem((void*)T36_, sizeof(tyArray__TAsXwXSUBvAawE1kIQ5ziQ));
		colontmpD__9 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), (*d_p0).Sup.filename);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		T36_[0] = colontmpD__9;
		colontmpD__10 = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116), T36_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		T34_[2] = colontmpD__10;
		runnableExamples_1 = newTree__ast_u4170(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), T34_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		(*runnableExamples_1).info = (*n_p1).info;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmp__5;
			a_1 = NIM_NIL;
			colontmp__5 = NIM_NIL;
			colontmp__5 = lastSon__ast_u5208(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			{
				NI i_1;
				NI colontmp__6;
				NI i_2;
				i_1 = (NI)0;
				colontmp__6 = (NI)0;
				colontmp__6 = safeLen__ast_u3197(colontmp__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp__6)) goto LA40;
						i_1 = i_2;
						eqcopy___ast_u3255(&a_1, (*colontmp__5)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
						add__ast_u3215(runnableExamples_1, a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
						i_2 += ((NI)1);
					} LA40: ;
				}
			}
			eqdestroy___ast_u3252(colontmp__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			eqdestroy___ast_u3252(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
		T41_ = 0;
		renderModule__renderer_u2169(runnableExamples_1, outp_1, T41_, ((NI32)-1), (*d_p0).conf);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		{
			LA32_:;
		}
		{
			oldNimErrFin32_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(runnableExamples_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(docComment_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin32_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA28_;
LA30_: ;
	{
		NimStringV2 code2_1;
		NimStringV2 colontmpD__11;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T58_;
		NimStringV2 T59_;
		code2_1.len = 0; code2_1.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		eqcopy___system_u2694((&code2_1), code_1);
		{
			NIM_BOOL T48_;
			NIM_BOOL T50_;
			NimStringV2 codeIndent_1;
			tyTuple__kN8up2W6YKc5YA9avn5mV5w colontmpD__12;
			NimStringV2 colontmpD__13;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T54_;
			NimStringV2 T55_;
			T48_ = (NIM_BOOL)0;
			T48_ = (((NI)0) < code_1.len);
			if (!(T48_)) goto LA49_;
			T50_ = (NIM_BOOL)0;
			T50_ = contains__pureZstrutils_u1833(code_1, TM__5fUAZGW8WPeit3fZaQyNXA_180);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			T48_ = !(T50_);
LA49_: ;
			if (!T48_) goto LA51_;
			codeIndent_1.len = 0; codeIndent_1.p = NIM_NIL;
			nimZeroMem((void*)(&colontmpD__12), sizeof(tyTuple__kN8up2W6YKc5YA9avn5mV5w));
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			codeIndent_1 = extractRunnableExamplesSource__renderverbatim_u95((*d_p0).conf, n_p1, ((NI)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			toInstantiationInfo__docgen_u4107((*d_p0).conf, (*n_p1).info, (&colontmpD__12));
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			colontmpD__13 = dollar___docgen_u4140((&colontmpD__12));
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			T54_[0] = colontmpD__13;
			T54_[1] = codeIndent_1;
			T55_.len = 0; T55_.p = NIM_NIL;
			T55_ = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_182, T54_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T55_); goto LA53_;}
			eqsink___system_u2700((&code2_1), T55_);
			{
				LA53_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___msgs_u1579((&colontmpD__12));
				eqdestroy___system_u2691(codeIndent_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		}
LA51_: ;
		T58_[0] = comment_1;
		colontmpD__11 = quoted__docgen_u4100((*d_p0).Sup.filename);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T58_[1] = colontmpD__11;
		T58_[2] = code2_1;
		T59_.len = 0; T59_.p = NIM_NIL;
		T59_ = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_184, T58_, 3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T59_); goto LA45_;}
		eqsink___system_u2700((&code2_1), T59_);
		writeFile__stdZsyncio_u532(outp_1, code2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		{
			LA45_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(code2_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA28_: ;
	{
		NIM_BOOL T64_;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* T67_;
		T64_ = (NIM_BOOL)0;
		T64_ = contains__docgen_u4238((&(*d_p0).exampleGroups), rdoccmd_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T64_)) goto LA65_;
		T67_ = NIM_NIL;
		T67_ = (tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ*) nimNewObj(sizeof(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ), NIM_ALIGNOF(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ));
		colontmpD__14 = eqdup___system_u2697(rdoccmd_1);
		(*T67_).rdoccmd = colontmpD__14;
		colontmpD__15 = eqdup___system_u2697((*(*d_p0).conf).docCmd);
		(*T67_).docCmd = colontmpD__15;
		(*T67_).index = len__docgen_u3743((&(*d_p0).exampleGroups));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		X5BX5Deq___docgen_u4623((&(*d_p0).exampleGroups), rdoccmd_1, T67_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA65_: ;
	T68_ = (tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ**)0;
	T68_ = X5BX5D___docgen_u5918((&(*d_p0).exampleGroups), rdoccmd_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = quoted__docgen_u4100(outp_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = nsuFormatSingleElem(TM__5fUAZGW8WPeit3fZaQyNXA_187, colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*T68_)).code), colontmpD__6.len + 0);
appendString((&(*(*T68_)).code), colontmpD__6);
	{
		NimStringV2 title_1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T74_;
		if (!topLevel_p2) goto LA71_;
		title_1.len = 0; title_1.p = NIM_NIL;
		title_1 = canonicalImport__options_u4253((*d_p0).conf, (*d_p0).Sup.filename);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T74_[0] = title_1;
		T74_[1] = code_1;
		codeShown_1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_189, T74_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		{
			LA73_:;
		}
		{
			eqdestroy___system_u2691(title_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA69_;
LA71_: ;
	{
		codeShown_1 = code_1;
		eqwasMoved___system_u2688((&code_1));
	}
LA69_: ;
	colontmp_ = rdoccmd_1;
	eqwasMoved___system_u2688((&rdoccmd_1));
	colontmp__2 = codeShown_1;
	eqwasMoved___system_u2688((&codeShown_1));
	blitTmp_3 = colontmp_;
	eqwasMoved___system_u2688((&colontmp_));
	(*Result).Field0 = blitTmp_3;
	blitTmp_4 = colontmp__2;
	eqwasMoved___system_u2688((&colontmp__2));
	(*Result).Field1 = blitTmp_4;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmp__2);
		eqdestroy___system_u2691(colontmp_);
		eqdestroy___system_u2691(codeShown_1);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(outp_1);
		eqdestroy___system_u2691(outputDir_1);
		eqdestroy___system_u2691(comment_1);
		eqdestroy___system_u2691(code_1);
		eqdestroy___system_u2691(loc_1);
		eqdestroy___system_u2691(rdoccmd_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u193)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0, NimStringV2 str_p1) {
	NimStringV2 colontmpD_;
	tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ T1_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
	T1_.isRst = NIM_FALSE;
	colontmpD_ = eqdup___system_u2697(str_p1);
	T1_._isRst_2.str = colontmpD_;
	add__docgen_u132((&(*dest_p0)), T1_);
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw, getAllRunnableExamplesImpl__docgen_u6220)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p2, tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw state_p3, NIM_BOOL topLevel_p4) {
	tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw result;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)0;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	{
		{
			tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD_;
			if (!(state_p3 == ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)0) || state_p3 == ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)2))) goto LA4_;
			colontmpD_ = NIM_NIL;
			colontmpD_ = genRecComment__docgen_u3574(d_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			add__docgen_u129(dest_p2, colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			result = ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)1);
			eqdestroy___packagesZdocutilsZrstast_u285(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
			{
				LA6_:;
			}
			{
				oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___packagesZdocutilsZrstast_u285(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin6_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
		colontmpD__2 = NIM_NIL;
		{
			NIM_BOOL T13_;
			NIM_BOOL T14_;
			NI T16_;
			T13_ = (NIM_BOOL)0;
			T14_ = (NIM_BOOL)0;
			T14_ = isRunnableExamples__trees_u411((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			if (!(T14_)) goto LA15_;
			T16_ = (NI)0;
			T16_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			T14_ = (((NI)2) <= T16_);
LA15_: ;
			T13_ = T14_;
			if (!(T13_)) goto LA17_;
			colontmpD__2 = lastSon__ast_u5208(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			T13_ = ((*colontmpD__2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115));
LA17_: ;
			if (!T13_) goto LA18_;
			{
				tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_1;
				NimStringV2 rdoccmd_1;
				NimStringV2 code_1;
				NimStringV2 msg_1;
				NimStringV2 s_1;
				NimStringV2 id_1;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				NimStringV2 dest2_1;
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T38_;
				if (!(state_p3 == ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)0) || state_p3 == ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)1) || state_p3 == ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)2))) goto LA22_;
				nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				rdoccmd_1.len = 0; rdoccmd_1.p = NIM_NIL;
				code_1.len = 0; code_1.p = NIM_NIL;
				msg_1.len = 0; msg_1.p = NIM_NIL;
				s_1.len = 0; s_1.p = NIM_NIL;
				id_1.len = 0; id_1.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				dest2_1.len = 0; dest2_1.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				prepareExample__docgen_u4111(d_p0, n_p1, topLevel_p4, (&tmpTuple_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				rdoccmd_1 = tmpTuple_1.Field0;
				eqwasMoved___system_u2688((&tmpTuple_1.Field0));
				code_1 = tmpTuple_1.Field1;
				eqwasMoved___system_u2688((&tmpTuple_1.Field1));
				msg_1 = TM__5fUAZGW8WPeit3fZaQyNXA_191;
				{
					NimStringV2 colontmpD__7;
					NimStringV2 T29_;
					if (!(((NI)0) < rdoccmd_1.len)) goto LA27_;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					T29_.len = 0; T29_.p = NIM_NIL;
					T29_ = rawNewString(rdoccmd_1.len + 6);
appendString((&T29_), TM__5fUAZGW8WPeit3fZaQyNXA_193);
appendString((&T29_), rdoccmd_1);
					colontmpD__7 = T29_;
					prepareAdd((&msg_1), colontmpD__7.len + 0);
appendString((&msg_1), colontmpD__7);
					eqdestroy___system_u2691(colontmpD__7);
				}
LA27_: ;
				s_1 = TM__5fUAZGW8WPeit3fZaQyNXA_194;
				{
					NIM_BOOL T32_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T35_;
					T32_ = (NIM_BOOL)0;
					T32_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					if (!!(T32_)) goto LA33_;
					T35_[0] = msg_1;
					nsuAddf((&s_1), TM__5fUAZGW8WPeit3fZaQyNXA_196, T35_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				}
				goto LA30_;
LA33_: ;
				{
					tyArray__YgExxhfgKcesA5EOUj1MOA T37_;
					T37_[0] = msg_1;
					nsuAddf((&s_1), TM__5fUAZGW8WPeit3fZaQyNXA_198, T37_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				}
LA30_: ;
				add__docgen_u193(dest_p2, s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				(*d_p0).Sup.listingCounter += ((NI)1);
				id_1 = dollar___systemZdollars_u9((*d_p0).Sup.listingCounter);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				colontmpD__3 = getOrDefault__pureZstrtabs_u390((*d_p0).Sup.config, TM__5fUAZGW8WPeit3fZaQyNXA_200, TM__5fUAZGW8WPeit3fZaQyNXA_201);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				T38_[0] = id_1;
				T38_[1] = TM__5fUAZGW8WPeit3fZaQyNXA_203;
				T38_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_204;
				colontmpD__4 = nsuFormatOpenArray(colontmpD__3, T38_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				add__docgen_u193(dest_p2, colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				dest2_1 = TM__5fUAZGW8WPeit3fZaQyNXA_205;
				renderNimCode__packagesZdocutilsZrstgen_u3815((&dest2_1), code_1, (*d_p0).Sup.target);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				add__docgen_u193(dest_p2, dest2_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				colontmpD__5 = getOrDefault__pureZstrtabs_u390((*d_p0).Sup.config, TM__5fUAZGW8WPeit3fZaQyNXA_207, TM__5fUAZGW8WPeit3fZaQyNXA_208);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				colontmpD__6 = nsuFormatSingleElem(colontmpD__5, id_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				add__docgen_u193(dest_p2, colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				result = ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)2);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(dest2_1);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(id_1);
				eqdestroy___system_u2691(s_1);
				eqdestroy___system_u2691(msg_1);
				eqdestroy___system_u2691(code_1);
				eqdestroy___system_u2691(rdoccmd_1);
				eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_1));
				eqdestroy___ast_u3252(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
				{
					LA24_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(dest2_1);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(id_1);
					eqdestroy___system_u2691(s_1);
					eqdestroy___system_u2691(msg_1);
					eqdestroy___system_u2691(code_1);
					eqdestroy___system_u2691(rdoccmd_1);
					eqdestroy___stdZprivateZospaths2_u306((&tmpTuple_1));
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			}
			goto LA20_;
LA22_: ;
			{
				liMessage__msgs_u1227((*d_p0).conf, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19), TM__5fUAZGW8WPeit3fZaQyNXA_210, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__5fUAZGW8WPeit3fZaQyNXA_211), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			}
LA20_: ;
		}
LA18_: ;
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
	}
	break;
	}
	result = ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)3);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getAllRunnableExamples__docgen_u6291)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD_;
	tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw state_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_2 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	eqcopy___ast_u3255(&n_2, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	state_1 = ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)0);
	colontmpD_ = genComment__docgen_u3537(d_p0, n_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__docgen_u129(dest_p2, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*n_2).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T3_;
		T3_ = NIM_NIL;
		T3_ = getRoutineBody__docgen_u6271(n_2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T3_); goto LA1_;}
		eqsink___ast_u3261(&n_2, T3_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		switch ((*n_2).kind) {
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
		{
			state_1 = getAllRunnableExamplesImpl__docgen_u6220(d_p0, n_2, dest_p2, state_1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(n_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i_1 = i_2;
						state_1 = getAllRunnableExamplesImpl__docgen_u6220(d_p0, (*n_2)._kind_6.sons.p->data[i_1], dest_p2, state_1, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						{
							if (!(state_1 == ((tyEnum_RunnableState__M9bYVpn4S5QwWYjuMsVfy9cw)3))) goto LA11_;
						}
LA11_: ;
						i_2 += ((NI)1);
					} LA8: ;
				}
			}
		}
		break;
		}
	}
	break;
	default:
	{
		state_1 = getAllRunnableExamplesImpl__docgen_u6220(d_p0, n_2, dest_p2, state_1, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___packagesZdocutilsZrstast_u285(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeKind__docgen_u6464)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
	T1_.len = 0; T1_.p = NIM_NIL;
	switch ((*(*n_p0)._kind_6.sons.p->data[((NI)2)]).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)150):
	{
		result = TM__5fUAZGW8WPeit3fZaQyNXA_214;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)133):
	{
		result = TM__5fUAZGW8WPeit3fZaQyNXA_216;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)134):
	{
		result = TM__5fUAZGW8WPeit3fZaQyNXA_218;
	}
	break;
	default:
	{
		result = TM__5fUAZGW8WPeit3fZaQyNXA_219;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, complexName__docgen_u6413)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 baseName_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), baseName_p2);
	switch (k_p0) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13):
	{
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17):
	{
		prepareAdd((&result), 2);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_223);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14):
	{
		prepareAdd((&result), 2);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_225);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15):
	{
		prepareAdd((&result), 2);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_227);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	{
		prepareAdd((&result), 2);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_229);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16):
	{
		prepareAdd((&result), 2);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_231);
	}
	break;
	default:
	{
	}
	break;
	}
	{
		NIM_BOOL T10_;
		NI T11_;
		NimStringV2 params_1;
		T10_ = (NIM_BOOL)0;
		T11_ = (NI)0;
		T11_ = safeLen__ast_u3197(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T10_ = (((NI)3) < T11_);
		if (!(T10_)) goto LA12_;
		T10_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)3)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76));
LA12_: ;
		if (!T10_) goto LA13_;
		params_1.len = 0; params_1.p = NIM_NIL;
		params_1 = renderParamTypes__typesrenderer_u146((*n_p1)._kind_6.sons.p->data[((NI)3)], TM__5fUAZGW8WPeit3fZaQyNXA_233, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			if (!(((NI)0) < params_1.len)) goto LA18_;
			prepareAdd((&result), 1);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_234);
			prepareAdd((&result), params_1.len + 0);
appendString((&result), params_1);
		}
LA18_: ;
		{
			LA15_:;
		}
		{
			eqdestroy___system_u2691(params_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA13_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, newUniquePlainSymbol__docgen_u6404)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NimStringV2 original_p1) {
	NimStringV2 result;
	NI count_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsthasKey((*d_p0).seenSymbols, original_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		eqcopy___system_u2694((&result), original_p1);
		nstPut((*d_p0).seenSymbols, original_p1, TM__5fUAZGW8WPeit3fZaQyNXA_235);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	count_1 = ((NI)2);
	{
		while (1) {
			NimStringV2 colontmpD_;
			NimStringV2 T9_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			T9_.len = 0; T9_.p = NIM_NIL;
			colontmpD_ = dollar___systemZdollars_u9(count_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			T9_ = rawNewString(original_p1.len + colontmpD_.len + 1);
appendString((&T9_), original_p1);
appendString((&T9_), TM__5fUAZGW8WPeit3fZaQyNXA_237);
appendString((&T9_), colontmpD_);
			eqsink___system_u2700((&result), T9_);
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = nsthasKey((*d_p0).seenSymbols, result);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				if (!!(T12_)) goto LA13_;
				nstPut((*d_p0).seenSymbols, result, TM__5fUAZGW8WPeit3fZaQyNXA_238);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				eqdestroy___system_u2691(colontmpD_);
				goto LA6;
			}
LA13_: ;
			count_1 += ((NI)1);
			{
				LA8_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	} LA6: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toLangSymbol__docgen_u6467)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 baseName_p2, tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw* Result) {
	NimStringV2 T1_;
	NimStringV2 T2_;
NIM_BOOL oldNimErrFin46_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw));
	nimZeroMem((void*)Result, sizeof(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw));
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = nimIdentNormalize__pureZstrutils_u124(baseName_p2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1_); goto BeforeRet_;}
	(*Result).name = T1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = toHumanStr__ast_u7574(k_p0);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T2_); goto BeforeRet_;}
	(*Result).symKind = T2_;
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ paramTypes_1;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ paramNames_1;
		NimStringV2 T26_;
		if (!(k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA5_;
		paramTypes_1.len = 0; paramTypes_1.p = NIM_NIL;
		paramNames_1.len = 0; paramNames_1.p = NIM_NIL;
		paramTypes_1.len = 0; paramTypes_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		renderParamTypes__typesrenderer_u111((&paramTypes_1), (*n_p1)._kind_6.sons.p->data[((NI)3)], NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		paramNames_1 = renderParamNames__typesrenderer_u67((*n_p1)._kind_6.sons.p->data[((NI)3)], NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			NI T10_;
			NI T11_;
			T10_ = paramTypes_1.len;
			T11_ = paramNames_1.len;
			if (!!((T10_ <= T11_))) goto LA12_;
			failedAssertImpl__stdZassertions_u79(TM__5fUAZGW8WPeit3fZaQyNXA_240);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA12_: ;
		{
			NI i_1;
			NI colontmp_;
			NI T15_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T15_ = paramNames_1.len;
			colontmp_ = T15_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA17;
					i_1 = i_2;
					{
						NI T20_;
						NimStringV2 colontmpD_;
						NimStringV2 colontmpD__2;
						tyTuple__UV3llMMYFckfui8YMBuUZA T23_;
						T20_ = paramTypes_1.len;
						if (!(i_1 < T20_)) goto LA21_;
						colontmpD_ = eqdup___system_u2697(paramNames_1.p->data[i_1]);
						T23_.Field0 = colontmpD_;
						colontmpD__2 = eqdup___system_u2697(paramTypes_1.p->data[i_1]);
						T23_.Field1 = colontmpD__2;
						add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), (&T23_));
					}
					goto LA18_;
LA21_: ;
					{
						NimStringV2 colontmpD__3;
						tyTuple__UV3llMMYFckfui8YMBuUZA T25_;
						colontmpD__3 = eqdup___system_u2697(paramNames_1.p->data[i_1]);
						T25_.Field0 = colontmpD__3;
						T25_.Field1 = TM__5fUAZGW8WPeit3fZaQyNXA_241;
						add__packagesZdocutilsZdochelpers_u247((&(*Result).parameters), (&T25_));
					}
LA18_: ;
					i_2 += ((NI)1);
				} LA17: ;
			}
		}
		(*Result).parametersProvided = NIM_TRUE;
		T26_.len = 0; T26_.p = NIM_NIL;
		T26_ = renderOutType__typesrenderer_u159((*n_p1)._kind_6.sons.p->data[((NI)3)], NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T26_); goto LA7_;}
		eqsink___system_u2700((&(*Result).outType), T26_);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u5506(paramNames_1);
			eqdestroy___system_u5506(paramTypes_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* genNode_1;
		if (!(k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) || k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15))) goto LA31_;
		genNode_1 = NIM_NIL;
		genNode_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		{
			if (!(k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7))) goto LA35_;
			genNode_1 = (*n_p1)._kind_6.sons.p->data[((NI)1)];
		}
		goto LA33_;
LA35_: ;
		{
			{
				if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)5)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA40_;
				genNode_1 = (*(*n_p1)._kind_6.sons.p->data[((NI)5)])._kind_6.sons.p->data[((NI)1)];
			}
LA40_: ;
		}
LA33_: ;
		{
			NimStringV2 literal_1;
			tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw r_1;
			tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA kind_1;
			if (!!((genNode_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA44_;
			literal_1.len = 0; literal_1.p = NIM_NIL;
			nimZeroMem((void*)(&r_1), sizeof(tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw));
			literal_1 = TM__5fUAZGW8WPeit3fZaQyNXA_242;
			initTokRender__renderer_u2186(genNode_1, 6230, (&r_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
			kind_1 = ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)1);
			{
				while (1) {
					getNextTok__renderer_u2190((&r_1), (&kind_1), (&literal_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
					{
						if (!(kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)1))) goto LA51_;
						goto LA47;
					}
LA51_: ;
					{
						NimStringV2 colontmpD__4;
						if (!!((kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)113)))) goto LA55_;
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						colontmpD__4 = nimIdentNormalize__pureZstrutils_u124(literal_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
						prepareAdd((&(*Result).generics), colontmpD__4.len + 0);
appendString((&(*Result).generics), colontmpD__4);
						eqdestroy___system_u2691(colontmpD__4);
					}
LA55_: ;
				}
			} LA47: ;
			{
				LA46_:;
			}
			{
				oldNimErrFin46_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___renderer_u402((&r_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___system_u2691(literal_1);
				*nimErr_ = oldNimErrFin46_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA44_: ;
	}
LA31_: ;
	{
		NimStringV2 T63_;
		if (!(k_p0 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7))) goto LA61_;
		T63_.len = 0; T63_.p = NIM_NIL;
		T63_ = getTypeKind__docgen_u6464(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T63_); goto BeforeRet_;}
		eqsink___system_u2700((&(*Result).symTypeKind), T63_);
	}
LA61_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, symbolPriority__docgen_u6461)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p0) {
	NI result;
	NI T1_;
	T1_ = (NI)0;
	switch (k_p0) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17):
	{
		result = ((NI)-3);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	{
		result = ((NI)-2);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15):
	{
		result = ((NI)-1);
	}
	break;
	default:
	{
		result = ((NI)0);
	}
	break;
	}
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, externalDep__docgen_u3602)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		NimStringV2 full_1;
		NimStringV2 tmp_1;
		NimStringV2 colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)38)))&63U)))!=0);
		if (T3_) goto LA4_;
		T3_ = (((NI)0) < (*(*d_p0).conf).docRoot.len);
LA4_: ;
		if (!T3_) goto LA5_;
		full_1.len = 0; full_1.p = NIM_NIL;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		full_1 = toFullPath__msgs_u624((*d_p0).conf, ((NI32) ((*module_p1).position)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD_ = presentationPath__docgen_u1793((*d_p0).conf, full_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		tmp_1 = getOutFile2__docgen_u1907((*d_p0).conf, colontmpD_, TM__5fUAZGW8WPeit3fZaQyNXA_278, !((((*module_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		result = relativeTo__pathutils_u196(tmp_1, (*d_p0).thisDir, 47);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(tmp_1);
			eqdestroy___system_u2691(full_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = toFullPath__msgs_u624((*d_p0).conf, ((NI32) ((*module_p1).position)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = nosextractFilename(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nodeToHighlightedHtml__docgen_u3616)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p3, NimStringV2 procLink_p4) {
	tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw r_1;
	NimStringV2 literal_1;
	tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA kind_1;
	NI tokenPos_1;
	NI procTokenPos_1;
NIM_BOOL oldNimErrFin151_;
NIM_BOOL oldNimErrFin143_;
NIM_BOOL oldNimErrFin109_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&r_1), sizeof(tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw));
	literal_1.len = 0; literal_1.p = NIM_NIL;
	initTokRender__renderer_u2186(n_p1, renderFlags_p3, (&r_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	literal_1 = TM__5fUAZGW8WPeit3fZaQyNXA_243;
	kind_1 = ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)1);
	tokenPos_1 = ((NI)0);
	procTokenPos_1 = ((NI)0);
	{
		while (1) {
			getNextTok__renderer_u2190((&r_1), (&kind_1), (&literal_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			tokenPos_1 += ((NI)1);
			switch (kind_1) {
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)1):
			{
				goto LA2;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)111):
			{
				{
					NIM_BOOL T8_;
					NimStringV2 colontmpD_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T12_;
					T8_ = (NIM_BOOL)0;
					T8_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T8_)) goto LA9_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD_ = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					T12_[0] = colontmpD_;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_245, T12_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					{
						LA11_:;
					}
					{
						eqdestroy___system_u2691(colontmpD_);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA6_;
LA9_: ;
				{
					NimStringV2 colontmpD__2;
					tyArray__YgExxhfgKcesA5EOUj1MOA T17_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__2 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					T17_[0] = colontmpD__2;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_247, T17_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					{
						LA16_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA6_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)3) ... ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)68):
			{
				{
					if (!(kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)51) || kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)41) || kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)38) || kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)40) || kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)59) || kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)30) || kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)15))) goto LA23_;
					procTokenPos_1 = tokenPos_1;
				}
LA23_: ;
				{
					NIM_BOOL T27_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T30_;
					T27_ = (NIM_BOOL)0;
					T27_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T27_)) goto LA28_;
					T30_[0] = literal_1;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_249, T30_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA25_;
LA28_: ;
				{
					tyArray__YgExxhfgKcesA5EOUj1MOA T32_;
					T32_[0] = literal_1;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_251, T32_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA25_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)110):
			{
				{
					NIM_BOOL T36_;
					NimStringV2 colontmpD__3;
					tyArray__YgExxhfgKcesA5EOUj1MOA T40_;
					T36_ = (NIM_BOOL)0;
					T36_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T36_)) goto LA37_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__3 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
					T40_[0] = colontmpD__3;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_253, T40_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
					{
						LA39_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA34_;
LA37_: ;
				{
					NimStringV2 colontmpD__4;
					tyArray__YgExxhfgKcesA5EOUj1MOA T45_;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					colontmpD__4 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
					T45_[0] = colontmpD__4;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_255, T45_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
					{
						LA44_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__4);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA34_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)83) ... ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)85):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)89):
			{
				{
					NIM_BOOL T51_;
					NimStringV2 colontmpD__5;
					tyArray__YgExxhfgKcesA5EOUj1MOA T55_;
					T51_ = (NIM_BOOL)0;
					T51_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T51_)) goto LA52_;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					colontmpD__5 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					T55_[0] = colontmpD__5;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_257, T55_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					{
						LA54_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__5);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA49_;
LA52_: ;
				{
					NimStringV2 colontmpD__6;
					tyArray__YgExxhfgKcesA5EOUj1MOA T60_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__6 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T60_[0] = colontmpD__6;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_259, T60_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					{
						LA59_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__6);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA49_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)88):
			{
				{
					NIM_BOOL T66_;
					NimStringV2 colontmpD__7;
					tyArray__YgExxhfgKcesA5EOUj1MOA T70_;
					T66_ = (NIM_BOOL)0;
					T66_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T66_)) goto LA67_;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					colontmpD__7 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
					T70_[0] = colontmpD__7;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_261, T70_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
					{
						LA69_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__7);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA64_;
LA67_: ;
				{
					NimStringV2 colontmpD__8;
					tyArray__YgExxhfgKcesA5EOUj1MOA T75_;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					colontmpD__8 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
					T75_[0] = colontmpD__8;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_263, T75_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
					{
						LA74_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__8);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA64_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)69) ... ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)78):
			{
				{
					NIM_BOOL T81_;
					NimStringV2 colontmpD__9;
					tyArray__YgExxhfgKcesA5EOUj1MOA T85_;
					T81_ = (NIM_BOOL)0;
					T81_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T81_)) goto LA82_;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					colontmpD__9 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					T85_[0] = colontmpD__9;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_265, T85_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					{
						LA84_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__9);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA79_;
LA82_: ;
				{
					NimStringV2 colontmpD__10;
					tyArray__YgExxhfgKcesA5EOUj1MOA T90_;
					colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
					colontmpD__10 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					T90_[0] = colontmpD__10;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_267, T90_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					{
						LA89_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__10);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA79_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)79) ... ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)82):
			{
				{
					NIM_BOOL T96_;
					NimStringV2 colontmpD__11;
					tyArray__YgExxhfgKcesA5EOUj1MOA T100_;
					T96_ = (NIM_BOOL)0;
					T96_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T96_)) goto LA97_;
					colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
					colontmpD__11 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
					T100_[0] = colontmpD__11;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_269, T100_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
					{
						LA99_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__11);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA94_;
LA97_: ;
				{
					NimStringV2 colontmpD__12;
					tyArray__YgExxhfgKcesA5EOUj1MOA T105_;
					colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
					colontmpD__12 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
					T105_[0] = colontmpD__12;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_271, T105_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
					{
						LA104_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__12);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA94_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)2):
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__13;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__14;
				s_1 = NIM_NIL;
				colontmpD__13 = NIM_NIL;
				colontmpD__14 = NIM_NIL;
				s_1 = getTokSym__renderer_u2208((&r_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				{
					NIM_BOOL T112_;
					T112_ = (NIM_BOOL)0;
					T112_ = (procTokenPos_1 == (NI)(tokenPos_1 - ((NI)2)));
					if (!(T112_)) goto LA113_;
					T112_ = !((procLink_p4.len == 0));
LA113_: ;
					if (!T112_) goto LA114_;
					{
						NIM_BOOL T118_;
						NimStringV2 colontmpD__15;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T122_;
						T118_ = (NIM_BOOL)0;
						T118_ = isLatexCmd__docgen_u1921((*d_p0).conf);
						if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
						if (!!(T118_)) goto LA119_;
						colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
						colontmpD__15 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA121_;
						T122_[0] = colontmpD__15;
						T122_[1] = procLink_p4;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_273, T122_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA121_;
						{
							LA121_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__15);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
					}
					goto LA116_;
LA119_: ;
					{
						NimStringV2 colontmpD__16;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T127_;
						colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
						colontmpD__16 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA126_;
						T127_[0] = colontmpD__16;
						T127_[1] = procLink_p4;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_275, T127_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA126_;
						{
							LA126_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__16);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
					}
LA116_: ;
				}
				goto LA110_;
LA114_: ;
				{
					NIM_BOOL T131_;
					NIM_BOOL T132_;
					NIM_BOOL T133_;
					NIM_BOOL T134_;
					NIM_BOOL T135_;
					NimStringV2 href_1;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__17;
					NimStringV2 colontmpD__18;
					NimStringV2 colontmpD__19;
					NimStringV2 colontmpD__20;
					NimStringV2 T144_;
					NimStringV2 T145_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T154_;
					T131_ = (NIM_BOOL)0;
					T132_ = (NIM_BOOL)0;
					T133_ = (NIM_BOOL)0;
					T134_ = (NIM_BOOL)0;
					T135_ = (NIM_BOOL)0;
					T135_ = !((s_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
					if (!(T135_)) goto LA136_;
					T135_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10));
LA136_: ;
					T134_ = T135_;
					if (!(T134_)) goto LA137_;
					T134_ = (((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1)))&63U)))!=0);
LA137_: ;
					T133_ = T134_;
					if (!(T133_)) goto LA138_;
					colontmpD__13 = owner__ast_u6254(s_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
					T133_ = !((colontmpD__13 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA138_: ;
					T132_ = T133_;
					if (!(T132_)) goto LA139_;
					colontmpD__14 = owner__ast_u6254(s_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
					T132_ = belongsToProjectPackage__packages_u81((*d_p0).conf, colontmpD__14);
					if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
LA139_: ;
					T131_ = T132_;
					if (!(T131_)) goto LA140_;
					T131_ = ((*d_p0).Sup.target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0));
LA140_: ;
					if (!T131_) goto LA141_;
					href_1.len = 0; href_1.p = NIM_NIL;
					colontmpD__17 = NIM_NIL;
					colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
					colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
					colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
					T144_.len = 0; T144_.p = NIM_NIL;
					T145_.len = 0; T145_.p = NIM_NIL;
					{
						colontmpD__17 = owner__ast_u6254(s_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
						if (!((*d_p0).module == colontmpD__17)) goto LA148_;
						colontmpD__18 = TM__5fUAZGW8WPeit3fZaQyNXA_276;
						T145_ = colontmpD__18;
					}
					goto LA146_;
LA148_: ;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__21;
						NimStringV2 colontmpD__22;
						colontmpD__21 = NIM_NIL;
						colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
						colontmpD__21 = owner__ast_u6254(s_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA151_;
						colontmpD__22 = externalDep__docgen_u3602(d_p0, colontmpD__21);
						if (NIM_UNLIKELY(*nimErr_)) goto LA151_;
						colontmpD__19 = noschangeFileExt(colontmpD__22, TM__5fUAZGW8WPeit3fZaQyNXA_279);
						if (NIM_UNLIKELY(*nimErr_)) goto LA151_;
						T145_ = colontmpD__19;
						{
							LA151_:;
						}
						{
							oldNimErrFin151_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__22);
							eqdestroy___ast_u4574(colontmpD__21);
							if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
							*nimErr_ = oldNimErrFin151_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
					}
LA146_: ;
					T144_ = rawNewString(T145_.len + literal_1.len + 1);
appendString((&T144_), T145_);
appendString((&T144_), TM__5fUAZGW8WPeit3fZaQyNXA_281);
appendString((&T144_), literal_1);
					href_1 = T144_;
					T154_[0] = href_1;
					colontmpD__20 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
					T154_[1] = colontmpD__20;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_283, T154_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
					{
						LA143_:;
					}
					{
						oldNimErrFin143_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__20);
						eqdestroy___system_u2691(colontmpD__19);
						eqdestroy___system_u2691(colontmpD__18);
						eqdestroy___ast_u4574(colontmpD__17);
						if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
						eqdestroy___system_u2691(href_1);
						*nimErr_ = oldNimErrFin143_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				}
				goto LA110_;
LA141_: ;
				{
					{
						NIM_BOOL T160_;
						NimStringV2 colontmpD__23;
						tyArray__YgExxhfgKcesA5EOUj1MOA T164_;
						T160_ = (NIM_BOOL)0;
						T160_ = isLatexCmd__docgen_u1921((*d_p0).conf);
						if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
						if (!!(T160_)) goto LA161_;
						colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
						colontmpD__23 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
						T164_[0] = colontmpD__23;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_285, T164_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
						{
							LA163_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__23);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
					}
					goto LA158_;
LA161_: ;
					{
						NimStringV2 colontmpD__24;
						tyArray__YgExxhfgKcesA5EOUj1MOA T169_;
						colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
						colontmpD__24 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
						T169_[0] = colontmpD__24;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_286, T169_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
						{
							LA168_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__24);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
					}
LA158_: ;
				}
LA110_: ;
				{
					LA109_:;
				}
				{
					oldNimErrFin109_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(colontmpD__14);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u4574(colontmpD__13);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u4574(s_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin109_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)113):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)0):
			{
				prepareAdd((&(*result_p2)), literal_1.len + 0);
appendString((&(*result_p2)), literal_1);
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)117):
			{
				{
					if (!((renderFlags_p3 &((NU16)1<<((NU)((((tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg)8)))&15U)))!=0)) goto LA178_;
					{
						NIM_BOOL T182_;
						NimStringV2 colontmpD__25;
						tyArray__YgExxhfgKcesA5EOUj1MOA T186_;
						T182_ = (NIM_BOOL)0;
						T182_ = isLatexCmd__docgen_u1921((*d_p0).conf);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!!(T182_)) goto LA183_;
						colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
						colontmpD__25 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA185_;
						T186_[0] = colontmpD__25;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_287, T186_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA185_;
						{
							LA185_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__25);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA180_;
LA183_: ;
					{
						NimStringV2 colontmpD__26;
						tyArray__YgExxhfgKcesA5EOUj1MOA T191_;
						colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
						colontmpD__26 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
						T191_[0] = colontmpD__26;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_289, T191_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA190_;
						{
							LA190_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__26);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA180_: ;
				}
				goto LA176_;
LA178_: ;
				{
					{
						NIM_BOOL T197_;
						NimStringV2 colontmpD__27;
						NimStringV2 colontmpD__28;
						tyArray__YgExxhfgKcesA5EOUj1MOA T201_;
						T197_ = (NIM_BOOL)0;
						T197_ = isLatexCmd__docgen_u1921((*d_p0).conf);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!!(T197_)) goto LA198_;
						colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
						colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
						colontmpD__27 = nsuReplaceStr(TM__5fUAZGW8WPeit3fZaQyNXA_291, TM__5fUAZGW8WPeit3fZaQyNXA_293, TM__5fUAZGW8WPeit3fZaQyNXA_294);
						if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
						colontmpD__28 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
						T201_[0] = colontmpD__28;
						nsuAddf(result_p2, colontmpD__27, T201_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
						{
							LA200_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__28);
							eqdestroy___system_u2691(colontmpD__27);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA195_;
LA198_: ;
					{
						NimStringV2 colontmpD__29;
						tyArray__YgExxhfgKcesA5EOUj1MOA T206_;
						colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
						colontmpD__29 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA205_;
						T206_[0] = colontmpD__29;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_295, T206_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA205_;
						{
							LA205_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__29);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA195_: ;
				}
LA176_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)118):
			{
				{
					if (!((renderFlags_p3 &((NU16)1<<((NU)((((tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg)8)))&15U)))!=0)) goto LA212_;
					{
						NIM_BOOL T216_;
						NimStringV2 colontmpD__30;
						tyArray__YgExxhfgKcesA5EOUj1MOA T220_;
						T216_ = (NIM_BOOL)0;
						T216_ = isLatexCmd__docgen_u1921((*d_p0).conf);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!!(T216_)) goto LA217_;
						colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
						colontmpD__30 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
						T220_[0] = colontmpD__30;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_296, T220_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA219_;
						{
							LA219_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__30);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA214_;
LA217_: ;
					{
						NimStringV2 colontmpD__31;
						tyArray__YgExxhfgKcesA5EOUj1MOA T225_;
						colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
						colontmpD__31 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
						T225_[0] = colontmpD__31;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_297, T225_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
						{
							LA224_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__31);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA214_: ;
				}
				goto LA210_;
LA212_: ;
				{
					{
						NIM_BOOL T231_;
						NimStringV2 colontmpD__32;
						tyArray__YgExxhfgKcesA5EOUj1MOA T235_;
						T231_ = (NIM_BOOL)0;
						T231_ = isLatexCmd__docgen_u1921((*d_p0).conf);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!!(T231_)) goto LA232_;
						colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
						colontmpD__32 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
						T235_[0] = colontmpD__32;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_299, T235_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
						{
							LA234_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__32);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA229_;
LA232_: ;
					{
						NimStringV2 colontmpD__33;
						tyArray__YgExxhfgKcesA5EOUj1MOA T240_;
						colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
						colontmpD__33 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
						T240_[0] = colontmpD__33;
						nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_300, T240_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
						{
							LA239_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__33);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA229_: ;
				}
LA210_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)98):
			{
				{
					NIM_BOOL T246_;
					NimStringV2 colontmpD__34;
					tyArray__YgExxhfgKcesA5EOUj1MOA T250_;
					T246_ = (NIM_BOOL)0;
					T246_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T246_)) goto LA247_;
					colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
					colontmpD__34 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA249_;
					T250_[0] = colontmpD__34;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_301, T250_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA249_;
					{
						LA249_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__34);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA244_;
LA247_: ;
				{
					NimStringV2 colontmpD__35;
					tyArray__YgExxhfgKcesA5EOUj1MOA T255_;
					colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
					colontmpD__35 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
					T255_[0] = colontmpD__35;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_302, T255_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
					{
						LA254_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__35);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA244_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)99):
			{
				{
					NIM_BOOL T261_;
					NimStringV2 colontmpD__36;
					tyArray__YgExxhfgKcesA5EOUj1MOA T265_;
					T261_ = (NIM_BOOL)0;
					T261_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T261_)) goto LA262_;
					colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
					colontmpD__36 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA264_;
					T265_[0] = colontmpD__36;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_303, T265_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA264_;
					{
						LA264_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__36);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA259_;
LA262_: ;
				{
					NimStringV2 colontmpD__37;
					tyArray__YgExxhfgKcesA5EOUj1MOA T270_;
					colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
					colontmpD__37 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
					T270_[0] = colontmpD__37;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_304, T270_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA269_;
					{
						LA269_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__37);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA259_: ;
			}
			break;
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)90):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)91):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)92):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)93):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)94):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)95):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)96):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)97):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)100):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)101):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)102):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)103):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)104):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)106):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)107):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)108):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)112):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)105):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)86):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)87):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)114):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)115):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)116):
			case ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)109):
			{
				{
					NIM_BOOL T276_;
					NimStringV2 colontmpD__38;
					tyArray__YgExxhfgKcesA5EOUj1MOA T280_;
					T276_ = (NIM_BOOL)0;
					T276_ = isLatexCmd__docgen_u1921((*d_p0).conf);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!!(T276_)) goto LA277_;
					colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
					colontmpD__38 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA279_;
					T280_[0] = colontmpD__38;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_306, T280_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA279_;
					{
						LA279_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__38);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA274_;
LA277_: ;
				{
					NimStringV2 colontmpD__39;
					tyArray__YgExxhfgKcesA5EOUj1MOA T285_;
					colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
					colontmpD__39 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, literal_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA284_;
					T285_[0] = colontmpD__39;
					nsuAddf(result_p2, TM__5fUAZGW8WPeit3fZaQyNXA_307, T285_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA284_;
					{
						LA284_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__39);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA274_: ;
			}
			break;
			default: __builtin_unreachable();
			}
		}
	} LA2: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(literal_1);
		eqdestroy___renderer_u402((&r_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genSeeSrc__docgen_u6450)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NimStringV2 path_p1, NI line_p2) {
	NimStringV2 result;
	NimStringV2 docItemSeeSrc_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	docItemSeeSrc_1.len = 0; docItemSeeSrc_1.p = NIM_NIL;
	result = TM__5fUAZGW8WPeit3fZaQyNXA_308;
	docItemSeeSrc_1 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_310, TM__5fUAZGW8WPeit3fZaQyNXA_311);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 path_2;
		NimStringV2 colontmpD_;
		NimStringV2 gitUrl_1;
		if (!(((NI)0) < docItemSeeSrc_1.len)) goto LA4_;
		path_2.len = 0; path_2.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		gitUrl_1.len = 0; gitUrl_1.p = NIM_NIL;
		colontmpD_ = nosgetCurrentDir();
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		path_2 = relativeTo__pathutils_u196(path_p1, colontmpD_, 47);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		gitUrl_1 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_313, TM__5fUAZGW8WPeit3fZaQyNXA_314);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			NimStringV2 defaultBranch_1;
			NimStringV2 commit_1;
			NimStringV2 develBranch_1;
			NimStringV2 T12_;
			if (!(((NI)0) < gitUrl_1.len)) goto LA9_;
			defaultBranch_1.len = 0; defaultBranch_1.p = NIM_NIL;
			commit_1.len = 0; commit_1.p = NIM_NIL;
			develBranch_1.len = 0; develBranch_1.p = NIM_NIL;
			T12_.len = 0; T12_.p = NIM_NIL;
			{
				if (!NIM_FALSE) goto LA15_;
				defaultBranch_1 = TM__5fUAZGW8WPeit3fZaQyNXA_316;
			}
			goto LA13_;
LA15_: ;
			{
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T19_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__2 = dollar___systemZdollars_u9(((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				T19_[0] = colontmpD__2;
				colontmpD__3 = dollar___systemZdollars_u9(((NI)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				T19_[1] = colontmpD__3;
				defaultBranch_1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_318, T19_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				{
					LA18_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			}
LA13_: ;
			commit_1 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_320, defaultBranch_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			develBranch_1 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_322, TM__5fUAZGW8WPeit3fZaQyNXA_323);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			{
				NIM_BOOL T24_;
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				tyArray__YgExxhfgKcesA5EOUj1MOA T28_;
				tyArray__ftd030ZQb0rgyFYIoQaqFA T29_;
				T24_ = (NIM_BOOL)0;
				T24_ = isLatexCmd__docgen_u1921((*d_p0).conf);
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				if (!!(T24_)) goto LA25_;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				T29_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_326;
				T29_[1] = path_2;
				T29_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_328;
				colontmpD__4 = dollar___systemZdollars_u9(line_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				T29_[3] = colontmpD__4;
				T29_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_330;
				T29_[5] = gitUrl_1;
				T29_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_332;
				T29_[7] = commit_1;
				T29_[8] = TM__5fUAZGW8WPeit3fZaQyNXA_333;
				T29_[9] = develBranch_1;
				colontmpD__5 = nsuFormatOpenArray(docItemSeeSrc_1, T29_, 10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				T28_[0] = colontmpD__5;
				nsuAddf((&result), TM__5fUAZGW8WPeit3fZaQyNXA_324, T28_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				{
					LA27_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			}
			goto LA22_;
LA25_: ;
			{
				NimStringV2 colontmpD__6;
				NimStringV2 colontmpD__7;
				tyArray__YgExxhfgKcesA5EOUj1MOA T34_;
				tyArray__ftd030ZQb0rgyFYIoQaqFA T35_;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				T35_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_335;
				T35_[1] = path_2;
				T35_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_336;
				colontmpD__6 = dollar___systemZdollars_u9(line_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T35_[3] = colontmpD__6;
				T35_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_337;
				T35_[5] = gitUrl_1;
				T35_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_338;
				T35_[7] = commit_1;
				T35_[8] = TM__5fUAZGW8WPeit3fZaQyNXA_339;
				T35_[9] = develBranch_1;
				colontmpD__7 = nsuFormatOpenArray(docItemSeeSrc_1, T35_, 10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T34_[0] = colontmpD__7;
				nsuAddf((&result), TM__5fUAZGW8WPeit3fZaQyNXA_334, T34_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				{
					LA33_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__7);
					eqdestroy___system_u2691(colontmpD__6);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			}
LA22_: ;
			{
				LA11_:;
			}
			{
				eqdestroy___system_u2691(develBranch_1);
				eqdestroy___system_u2691(commit_1);
				eqdestroy___system_u2691(defaultBranch_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA9_: ;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(gitUrl_1);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(path_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(docItemSeeSrc_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u2293)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* dest_p0, tySequence__b9cVyuSHmrW80P0ZGgU2KHA src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___docgen_u2284((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2281)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2350)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).detailedName);
	eqdestroy___system_u2691((*dest_p0).name);
	eqdestroy___system_u2691((*dest_p0).anchor);
	eqdestroy___system_u2691((*dest_p0).sortName);
	eqdestroy___system_u5506((*dest_p0).substitutions);
	eqdestroy___docgen_u2125((*dest_p0).descRst);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2347)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* dest_p0) {
	(*dest_p0).descRst.len = 0; (*dest_p0).descRst.p = NIM_NIL;
	(*dest_p0).substitutions.len = 0; (*dest_p0).substitutions.p = NIM_NIL;
	(*dest_p0).sortName.len = 0; (*dest_p0).sortName.p = NIM_NIL;
	(*dest_p0).info.line = 0;
	(*dest_p0).info.col = 0;
	(*dest_p0).info.fileIndex = 0;
	(*dest_p0).anchor.len = 0; (*dest_p0).anchor.p = NIM_NIL;
	(*dest_p0).name.len = 0; (*dest_p0).name.p = NIM_NIL;
	(*dest_p0).detailedName.len = 0; (*dest_p0).detailedName.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u160)(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ dest_p0) {
	switch (dest_p0.isRst) {
	case NIM_TRUE:
	{
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = nimDecRefIsLastDyn(dest_p0._isRst_1.rst);
			if (!T4_) goto LA5_;
			eqdestroy___packagesZdocutilsZrstast_u173((&(*dest_p0._isRst_1.rst)));
			nimRawDispose(dest_p0._isRst_1.rst, ((NI)8));
		}
LA5_: ;
	}
	break;
	case NIM_FALSE:
	{
		eqdestroy___system_u2691(dest_p0._isRst_2.str);
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u157)(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* dest_p0) {
	(*dest_p0).isRst = 0;
	switch ((*dest_p0).isRst) {
	case NIM_TRUE:
	{
		(*dest_p0)._isRst_1.rst = 0;
	}
	break;
	case NIM_FALSE:
	{
		(*dest_p0)._isRst_2.str.len = 0; (*dest_p0)._isRst_2.str.p = NIM_NIL;
	}
	break;
	default:
	{
	}
	break;
	}
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ, eqdup___docgen_u2131)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ src_p0) {
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__docgen_u2147((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_].isRst = src_p0.p->data[colontmp_].isRst;
			switch (result.p->data[colontmp_].isRst) {
			case NIM_TRUE:
			{
				result.p->data[colontmp_]._isRst_1.rst = src_p0.p->data[colontmp_]._isRst_1.rst;
				{
					if (!src_p0.p->data[colontmp_]._isRst_1.rst) goto LA8_;
					nimIncRef(src_p0.p->data[colontmp_]._isRst_1.rst);
				}
LA8_: ;
			}
			break;
			case NIM_FALSE:
			{
				result.p->data[colontmp_]._isRst_2.str = eqdup___system_u2697(src_p0.p->data[colontmp_]._isRst_2.str);
			}
			break;
			default:
			{
			}
			break;
			}
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__b9cVyuSHmrW80P0ZGgU2KHA, eqdup___docgen_u2290)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA src_p0) {
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA result;
	NI T1_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__docgen_u2305((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ T5_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			T5_.len = 0; T5_.p = NIM_NIL;
			T5_ = eqdup___docgen_u2131(src_p0.p->data[colontmp_].descRst);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___docgen_u2125(T5_); goto BeforeRet_;}
			result.p->data[colontmp_].descRst = T5_;
			result.p->data[colontmp_].substitutions = eqdup___system_u5512(src_p0.p->data[colontmp_].substitutions);
			result.p->data[colontmp_].sortName = eqdup___system_u2697(src_p0.p->data[colontmp_].sortName);
			result.p->data[colontmp_].info.line = src_p0.p->data[colontmp_].info.line;
			result.p->data[colontmp_].info.col = src_p0.p->data[colontmp_].info.col;
			result.p->data[colontmp_].info.fileIndex = src_p0.p->data[colontmp_].info.fileIndex;
			result.p->data[colontmp_].anchor = eqdup___system_u2697(src_p0.p->data[colontmp_].anchor);
			result.p->data[colontmp_].name = eqdup___system_u2697(src_p0.p->data[colontmp_].name);
			result.p->data[colontmp_].detailedName = eqdup___system_u2697(src_p0.p->data[colontmp_].detailedName);
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2122)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, whichType__docgen_u1842)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = strTableContains__astalgo_u2567((*d_p0).types, (*n_p1)._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T7_) goto LA8_;
			eqcopy___ast_u4577(&result, (*n_p1)._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA5_;
LA8_: ;
		{
			result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		}
LA5_: ;
	}
	goto LA1_;
LA3_: ;
	{
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* x_1;
					if (!(i_2 < colontmp_)) goto LA14;
					x_1 = NIM_NIL;
					i_1 = i_2;
					x_1 = whichType__docgen_u1842(d_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					{
						if (!!((x_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA18_;
						result = x_1;
						eqwasMoved___ast_u4571(&x_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						eqdestroy___ast_u4574(x_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA18_: ;
					i_2 += ((NI)1);
					{
						LA15_:;
					}
					{
						oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(x_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin15_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA14: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, attachToType__docgen_u1860)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* p_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* params_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	params_1 = NIM_NIL;
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	eqcopy___ast_u3255(&params_1, (*(*p_p1).ast)._kind_6.sons.p->data[((NI)3)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T4_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T7_;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(params_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)1) < T4_)) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = whichType__docgen_u1842(d_p0, (*params_1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T7_); goto LA1_;}
		eqsink___ast_u4583(&result, T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA10_;
			eqdestroy___ast_u3252(params_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA10_: ;
	}
LA5_: ;
	{
		NI T14_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T17_;
		T14_ = (NI)0;
		T14_ = len__ast_u3190(params_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)0) < T14_)) goto LA15_;
		T17_ = NIM_NIL;
		T17_ = whichType__docgen_u1842(d_p0, (*params_1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T17_); goto LA1_;}
		eqsink___ast_u4583(&result, T17_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA20_;
			eqdestroy___ast_u3252(params_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA20_: ;
	}
LA15_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(params_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)2);
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T25_;
				if (!(i_2 < colontmp_)) goto LA24;
				i_1 = i_2;
				T25_ = NIM_NIL;
				T25_ = whichType__docgen_u1842(d_p0, (*params_1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T25_); goto LA1_;}
				eqsink___ast_u4583(&result, T25_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA28_;
					eqdestroy___ast_u3252(params_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA28_: ;
				i_2 += ((NI)1);
			} LA24: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(params_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1) {
	(*(*dest_p0).p).data[(*dest_p0).len] = c_p1;
	(*dest_p0).len += ((NI)1);
	(*(*dest_p0).p).data[(*dest_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, docstringSummary__docgen_u6423)(NimStringV2 rstText_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NI pos_1;
	NI last_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = substr__system_u8664(rstText_p0, ((NI)2));
	result = nsuStrip(colontmpD_, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_212);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	pos_1 = nsuFindChar(result, 10, ((NI)0), ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((NI)0) < pos_1)) goto LA4_;
		setLengthStrV2((&result), ((NI)(pos_1 - ((NI)1))));
		prepareAdd((&result), 3);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_361);
	}
LA4_: ;
	{
		if (!(pos_1 < ((NI)100))) goto LA8_;
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
	}
LA8_: ;
	pos_1 = nsuFindCharSet(result, TM__5fUAZGW8WPeit3fZaQyNXA_362, ((NI)0), ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	last_1 = (NI)(result.len - ((NI)1));
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = (((NI)0) < pos_1);
		if (!(T12_)) goto LA13_;
		T12_ = (pos_1 < last_1);
LA13_: ;
		if (!T12_) goto LA14_;
		setLengthStrV2((&result), ((NI)(pos_1 - ((NI)1))));
		prepareAdd((&result), 3);
appendString((&result), TM__5fUAZGW8WPeit3fZaQyNXA_363);
	}
LA14_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u2588)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* dest_p0, tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___docgen_u2579((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2576)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2645)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).sortName);
	eqdestroy___system_u2691((*dest_p0).content);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2642)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* dest_p0) {
	(*dest_p0).content.len = 0; (*dest_p0).content.p = NIM_NIL;
	(*dest_p0).sortName.len = 0; (*dest_p0).sortName.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg, eqdup___docgen_u2585)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg src_p0) {
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__docgen_u2600((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_].content = eqdup___system_u2697(src_p0.p->data[colontmp_].content);
			result.p->data[colontmp_].sortName = eqdup___system_u2697(src_p0.p->data[colontmp_].sortName);
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genItem__docgen_u6544)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nameNode_p2, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p3, tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA docFlags_p4, NIM_BOOL nonExports_p5) {
	NimStringV2 name_1;
	NimStringV2 nameEsc_1;
	NimStringV2 plainDocstring_1;
	NimStringV2 result_1;
	NimStringV2 literal_1;
	NimStringV2 plainName_1;
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ comm_1;
	tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw r_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragmaNode_1;
	NimStringV2 plainNameEsc_1;
	NimStringV2 colontmpD_;
	NimStringV2 typeDescr_1;
	NimStringV2 colontmpD__2;
	NimStringV2 detailedName_1;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 uniqueName_1;
	NimStringV2 sortName_1;
	NimStringV2 cleanPlainSymbol_1;
	NimStringV2 complexSymbol_1;
	NimStringV2 plainSymbolEnc_1;
	NimStringV2 symbolOrId_1;
	NimStringV2 symbolOrIdEnc_1;
	NimStringV2 deprecationMsg_1;
	tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw rstLangSymbol_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* symNameNode_1;
	NimStringV2 seeSrc_1;
	NimStringV2 colontmpD__5;
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	NimStringV2 colontmpD__9;
	NimStringV2 colontmpD__10;
	NimStringV2 colontmpD__11;
	NimStringV2 colontmpD__12;
	NimStringV2 colontmpD__13;
	NimStringV2 external_1;
	NimStringV2 colontmpD__14;
	NimStringV2 attype_1;
	NimStringV2 colontmpD__15;
	NimStringV2 colontmpD__16;
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg colontmpD__17;
	NimStringV2 colontmpD__18;
	NimStringV2 colontmpD__19;
	NimStringV2 colontmpD__20;
	NimStringV2 colontmpD__21;
	tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA kind_1;
NIM_BOOL oldNimErrFin14_;
	NimStringV2 T28_;
	NimStringV2 T36_;
	NimStringV2 T37_;
	NimStringV2 T43_;
	NimStringV2 T49_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T55_;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA lineinfo_1;
	NI T61_;
	NI32 T62_;
	tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_1;
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA* T67_;
	tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg T68_;
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ blitTmp_1;
	NimStringV2 blitTmp_2;
	NimStringV2 blitTmp_3;
	NimStringV2 T69_;
	NimStringV2 blitTmp_4;
	NimStringV2 blitTmp_5;
	NimStringV2 blitTmp_6;
NIM_BOOL oldNimErrFin90_;
NIM_BOOL oldNimErrFin88_;
	tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg T107_;
	tyArray__A2YC0h9cZydgH7zGAndH9bLg T108_;
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* T109_;
	tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg T110_;
	NimStringV2 blitTmp_7;
	tyArray__hSrJSIaqyFxuH67Wd7apZQ T111_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	name_1.len = 0; name_1.p = NIM_NIL;
	nameEsc_1.len = 0; nameEsc_1.p = NIM_NIL;
	plainDocstring_1.len = 0; plainDocstring_1.p = NIM_NIL;
	result_1.len = 0; result_1.p = NIM_NIL;
	literal_1.len = 0; literal_1.p = NIM_NIL;
	plainName_1.len = 0; plainName_1.p = NIM_NIL;
	comm_1.len = 0; comm_1.p = NIM_NIL;
	nimZeroMem((void*)(&r_1), sizeof(tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw));
	pragmaNode_1 = NIM_NIL;
	plainNameEsc_1.len = 0; plainNameEsc_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	typeDescr_1.len = 0; typeDescr_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	detailedName_1.len = 0; detailedName_1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	uniqueName_1.len = 0; uniqueName_1.p = NIM_NIL;
	sortName_1.len = 0; sortName_1.p = NIM_NIL;
	cleanPlainSymbol_1.len = 0; cleanPlainSymbol_1.p = NIM_NIL;
	complexSymbol_1.len = 0; complexSymbol_1.p = NIM_NIL;
	plainSymbolEnc_1.len = 0; plainSymbolEnc_1.p = NIM_NIL;
	symbolOrId_1.len = 0; symbolOrId_1.p = NIM_NIL;
	symbolOrIdEnc_1.len = 0; symbolOrIdEnc_1.p = NIM_NIL;
	deprecationMsg_1.len = 0; deprecationMsg_1.p = NIM_NIL;
	nimZeroMem((void*)(&rstLangSymbol_1), sizeof(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw));
	symNameNode_1 = NIM_NIL;
	seeSrc_1.len = 0; seeSrc_1.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	external_1.len = 0; external_1.p = NIM_NIL;
	colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
	attype_1.len = 0; attype_1.p = NIM_NIL;
	colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
	colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
	colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
	colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
	colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
	colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		NIM_BOOL T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = !((docFlags_p4 == ((tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA)1)));
		if (!(T4_)) goto LA5_;
		T6_ = (NIM_BOOL)0;
		T6_ = isVisible__docgen_u6310(d_p0, nameNode_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !(T6_);
LA5_: ;
		if (!T4_) goto LA7_;
		eqdestroy___system_u2691(colontmpD__21);
		eqdestroy___system_u2691(colontmpD__20);
		eqdestroy___system_u2691(colontmpD__19);
		eqdestroy___system_u2691(colontmpD__18);
		eqdestroy___docgen_u2579(colontmpD__17);
		eqdestroy___system_u2691(colontmpD__16);
		eqdestroy___system_u2691(attype_1);
		eqdestroy___system_u2691(colontmpD__14);
		eqdestroy___system_u2691(external_1);
		eqdestroy___docgen_u2284(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(seeSrc_1);
		eqdestroy___ast_u3252(symNameNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___packagesZdocutilsZdochelpers_u159((&rstLangSymbol_1));
		eqdestroy___system_u2691(deprecationMsg_1);
		eqdestroy___system_u2691(symbolOrIdEnc_1);
		eqdestroy___system_u2691(symbolOrId_1);
		eqdestroy___system_u2691(plainSymbolEnc_1);
		eqdestroy___system_u2691(complexSymbol_1);
		eqdestroy___system_u2691(cleanPlainSymbol_1);
		eqdestroy___system_u2691(sortName_1);
		eqdestroy___system_u2691(uniqueName_1);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(detailedName_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(typeDescr_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(plainNameEsc_1);
		eqdestroy___ast_u3252(pragmaNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___renderer_u402((&r_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___docgen_u2125(comm_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(plainName_1);
		eqdestroy___system_u2691(literal_1);
		eqdestroy___system_u2691(result_1);
		eqdestroy___system_u2691(plainDocstring_1);
		eqdestroy___system_u2691(nameEsc_1);
		eqdestroy___system_u2691(name_1);
		goto BeforeRet_;
	}
LA7_: ;
	name_1 = getName__docgen_u6374(nameNode_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nameEsc_1 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, name_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	plainDocstring_1 = getPlainDocstring__docgen_u3590(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result_1 = TM__5fUAZGW8WPeit3fZaQyNXA_148;
	literal_1 = TM__5fUAZGW8WPeit3fZaQyNXA_149;
	plainName_1 = TM__5fUAZGW8WPeit3fZaQyNXA_150;
	kind_1 = ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)1);
	comm_1.len = 0; comm_1.p = NIM_NIL;
	{
		if (!((*n_p1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79) && (*n_p1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159))) goto LA11_;
		getAllRunnableExamples__docgen_u6291(d_p0, n_p1, (&comm_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA9_;
LA11_: ;
	{
		tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD__22;
		colontmpD__22 = NIM_NIL;
		colontmpD__22 = genRecComment__docgen_u3574(d_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		add__docgen_u129((&comm_1), colontmpD__22);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			LA14_:;
		}
		{
			oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___packagesZdocutilsZrstast_u285(colontmpD__22);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin14_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	initTokRender__renderer_u2186(n_p1, 6238, (&r_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			getNextTok__renderer_u2190((&r_1), (&kind_1), (&literal_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				if (!(kind_1 == ((tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA)1))) goto LA21_;
				goto LA17;
			}
LA21_: ;
			prepareAdd((&plainName_1), literal_1.len + 0);
appendString((&plainName_1), literal_1);
		}
	} LA17: ;
	pragmaNode_1 = getDeclPragma__ast_u3932(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T27_;
		if (!!((pragmaNode_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA25_;
		T27_ = NIM_NIL;
		T27_ = findPragma__trees_u294(pragmaNode_1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)139));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T27_); goto LA1_;}
		eqsink___ast_u3261(&pragmaNode_1, T27_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA25_: ;
	(*d_p0).Sup.id += ((NI)1);
	colontmpD_ = nsuStrip(plainName_1, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_212);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	plainNameEsc_1 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, colontmpD_, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T28_.len = 0; T28_.p = NIM_NIL;
	{
		NIM_BOOL T31_;
		T31_ = (NIM_BOOL)0;
		T31_ = (k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7));
		if (!(T31_)) goto LA32_;
		colontmpD__2 = getTypeKind__docgen_u6464(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T31_ = !((colontmpD__2.len == 0));
LA32_: ;
		if (!T31_) goto LA33_;
		typeDescr_1 = getTypeKind__docgen_u6464(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA29_;
LA33_: ;
	{
		typeDescr_1 = toHumanStr__ast_u7574(k_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA29_: ;
	T36_.len = 0; T36_.p = NIM_NIL;
	T37_.len = 0; T37_.p = NIM_NIL;
	{
		if (!(k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA40_;
		eqcopy___system_u2694((&colontmpD__3), plainName_1);
		T37_ = colontmpD__3;
	}
	goto LA38_;
LA40_: ;
	{
		eqcopy___system_u2694((&colontmpD__4), name_1);
		T37_ = colontmpD__4;
	}
LA38_: ;
	T36_ = rawNewString(typeDescr_1.len + T37_.len + 1);
appendString((&T36_), typeDescr_1);
appendString((&T36_), TM__5fUAZGW8WPeit3fZaQyNXA_221);
appendString((&T36_), T37_);
	detailedName_1 = T36_;
	T43_.len = 0; T43_.p = NIM_NIL;
	{
		if (!(k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA46_;
		eqcopy___system_u2694((&uniqueName_1), plainNameEsc_1);
	}
	goto LA44_;
LA46_: ;
	{
		uniqueName_1 = nameEsc_1;
		eqwasMoved___system_u2688((&nameEsc_1));
	}
LA44_: ;
	T49_.len = 0; T49_.p = NIM_NIL;
	{
		if (!(k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA52_;
		sortName_1 = nsuStrip(plainName_1, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_212);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA50_;
LA52_: ;
	{
		eqcopy___system_u2694((&sortName_1), name_1);
	}
LA50_: ;
	cleanPlainSymbol_1 = renderPlainSymbolName__typesrenderer_u9(nameNode_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	complexSymbol_1 = complexName__docgen_u6413(k_p3, n_p1, cleanPlainSymbol_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	plainSymbolEnc_1 = encodeUrl__pureZuri_u84(cleanPlainSymbol_1, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	symbolOrId_1 = newUniquePlainSymbol__docgen_u6404(d_p0, complexSymbol_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	symbolOrIdEnc_1 = encodeUrl__pureZuri_u84(symbolOrId_1, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	deprecationMsg_1 = genDeprecationMsg__docgen_u6432(d_p0, pragmaNode_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	toLangSymbol__docgen_u6467(k_p3, n_p1, cleanPlainSymbol_1, (&rstLangSymbol_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T55_ = NIM_NIL;
	{
		if (!((*nameNode_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31))) goto LA58_;
		eqcopy___ast_u3255(&symNameNode_1, (*nameNode_p2)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA56_;
LA58_: ;
	{
		eqcopy___ast_u3255(&symNameNode_1, nameNode_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA56_: ;
	lineinfo_1.line = (*nameNode_p2).info.line;
	lineinfo_1.col = (*nameNode_p2).info.col;
	lineinfo_1.fileIndex = addRstFileIndex__docgen_u1723(d_p0, (*nameNode_p2).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T61_ = (NI)0;
	T61_ = symbolPriority__docgen_u6461(k_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T62_ = (NI32)0;
	T62_ = addRstFileIndex__docgen_u200(d_p0, ((NI32) ((*(*d_p0).module).position)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addAnchorNim__packagesZdocutilsZrst_u5936(&(*d_p0).sharedState, NIM_FALSE, symbolOrId_1, detailedName_1, (&rstLangSymbol_1), T61_, lineinfo_1, T62_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	renderFlags_1 = 6286;
	{
		if (!nonExports_p5) goto LA65_;
		renderFlags_1 |= ((NU16)1)<<(((((tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg)10))) & 15);
	}
LA65_: ;
	nodeToHighlightedHtml__docgen_u3616(d_p0, n_p1, (&result_1), renderFlags_1, symbolOrIdEnc_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = toFullPath__msgs_u624((*d_p0).conf, (*n_p1).info.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	seeSrc_1 = genSeeSrc__docgen_u6450(d_p0, colontmpD__5, ((NI) ((*n_p1).info.line)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = newSeq__docgen_u6649(((NI)0));
	T67_ = (tySequence__b9cVyuSHmrW80P0ZGgU2KHA*)0;
	T67_ = mgetOrPut__docgen_u6713((&(*d_p0).section[(k_p3)- 0].secItems), cleanPlainSymbol_1, colontmpD__6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	blitTmp_1 = comm_1;
	eqwasMoved___docgen_u2122((&comm_1));
	T68_.descRst = blitTmp_1;
	colontmpD__7 = eqdup___system_u2697(sortName_1);
	T68_.sortName = colontmpD__7;
	T68_.info = lineinfo_1;
	colontmpD__8 = eqdup___system_u2697(symbolOrId_1);
	T68_.anchor = colontmpD__8;
	colontmpD__9 = eqdup___system_u2697(detailedName_1);
	T68_.detailedName = colontmpD__9;
	colontmpD__10 = eqdup___system_u2697(name_1);
	T68_.name = colontmpD__10;
	T68_.substitutions.len = 18; T68_.substitutions.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(18, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	T68_.substitutions.p->data[0] = TM__5fUAZGW8WPeit3fZaQyNXA_341;
	blitTmp_2 = uniqueName_1;
	eqwasMoved___system_u2688((&uniqueName_1));
	T68_.substitutions.p->data[1] = blitTmp_2;
	T68_.substitutions.p->data[2] = TM__5fUAZGW8WPeit3fZaQyNXA_343;
	blitTmp_3 = result_1;
	eqwasMoved___system_u2688((&result_1));
	T68_.substitutions.p->data[3] = blitTmp_3;
	T68_.substitutions.p->data[4] = TM__5fUAZGW8WPeit3fZaQyNXA_345;
	T69_.len = 0; T69_.p = NIM_NIL;
	T69_ = dollar___systemZdollars_u9((*d_p0).Sup.id);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T69_); goto LA1_;}
	T68_.substitutions.p->data[5] = T69_;
	T68_.substitutions.p->data[6] = TM__5fUAZGW8WPeit3fZaQyNXA_347;
	colontmpD__11 = eqdup___system_u2697(plainNameEsc_1);
	T68_.substitutions.p->data[7] = colontmpD__11;
	T68_.substitutions.p->data[8] = TM__5fUAZGW8WPeit3fZaQyNXA_349;
	colontmpD__12 = eqdup___system_u2697(cleanPlainSymbol_1);
	T68_.substitutions.p->data[9] = colontmpD__12;
	T68_.substitutions.p->data[10] = TM__5fUAZGW8WPeit3fZaQyNXA_351;
	blitTmp_4 = plainSymbolEnc_1;
	eqwasMoved___system_u2688((&plainSymbolEnc_1));
	T68_.substitutions.p->data[11] = blitTmp_4;
	T68_.substitutions.p->data[12] = TM__5fUAZGW8WPeit3fZaQyNXA_353;
	colontmpD__13 = eqdup___system_u2697(symbolOrIdEnc_1);
	T68_.substitutions.p->data[13] = colontmpD__13;
	T68_.substitutions.p->data[14] = TM__5fUAZGW8WPeit3fZaQyNXA_355;
	blitTmp_5 = seeSrc_1;
	eqwasMoved___system_u2688((&seeSrc_1));
	T68_.substitutions.p->data[15] = blitTmp_5;
	T68_.substitutions.p->data[16] = TM__5fUAZGW8WPeit3fZaQyNXA_357;
	blitTmp_6 = deprecationMsg_1;
	eqwasMoved___system_u2688((&deprecationMsg_1));
	T68_.substitutions.p->data[17] = blitTmp_6;
	add__docgen_u7984((&(*T67_)), (&T68_));
	colontmpD__14 = relativeTo__pathutils_u196((*d_p0).Sup.destFile, (*(*d_p0).conf).outDir, 47);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	external_1 = noschangeFileExt(colontmpD__14, TM__5fUAZGW8WPeit3fZaQyNXA_358);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	attype_1 = TM__5fUAZGW8WPeit3fZaQyNXA_359;
	{
		NIM_BOOL T72_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* att_1;
		T72_ = (NIM_BOOL)0;
		T72_ = (k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
		if (!(T72_)) goto LA73_;
		T72_ = ((*symNameNode_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA73_: ;
		if (!T72_) goto LA74_;
		att_1 = NIM_NIL;
		att_1 = attachToType__docgen_u1860(d_p0, (*nameNode_p2)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 T80_;
			if (!!((att_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA78_;
			T80_.len = 0; T80_.p = NIM_NIL;
			T80_ = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, (*(*att_1).name).s, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T80_); goto LA1_;}
			eqsink___system_u2700((&attype_1), T80_);
		}
LA78_: ;
		eqdestroy___ast_u4574(att_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA70_;
LA74_: ;
	{
		NIM_BOOL T82_;
		NIM_BOOL T83_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* etyp_1;
		T82_ = (NIM_BOOL)0;
		T83_ = (NIM_BOOL)0;
		T83_ = (k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7));
		if (!(T83_)) goto LA84_;
		T83_ = ((*symNameNode_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA84_: ;
		T82_ = T83_;
		if (!(T82_)) goto LA85_;
		T82_ = ((*(*(*symNameNode_1)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14) || (*(*(*symNameNode_1)._kind_4.sym).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1));
LA85_: ;
		if (!T82_) goto LA86_;
		etyp_1 = NIM_NIL;
		eqcopy___ast_u3381(&etyp_1, (*(*symNameNode_1)._kind_4.sym).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_1;
			e_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197((*etyp_1).n);
				if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA93;
						i_1 = i_2;
						eqcopy___ast_u3255(&e_1, (*(*etyp_1).n)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
						{
							NimStringV2 plain_1;
							NimStringV2 symbolOrId_2;
							NimStringV2 colontmpD__23;
							NimStringV2 colontmpD__24;
							NimStringV2 colontmpD__25;
							NimStringV2 colontmpD__26;
							NimStringV2 T100_;
							plain_1.len = 0; plain_1.p = NIM_NIL;
							symbolOrId_2.len = 0; symbolOrId_2.p = NIM_NIL;
							colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
							colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
							colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
							colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
							{
								if (!!(((*(*e_1)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20)))) goto LA98_;
								eqdestroy___system_u2691(colontmpD__26);
								eqdestroy___system_u2691(colontmpD__25);
								eqdestroy___system_u2691(colontmpD__24);
								eqdestroy___system_u2691(colontmpD__23);
								eqdestroy___system_u2691(symbolOrId_2);
								eqdestroy___system_u2691(plain_1);
								goto LA94;
							}
LA98_: ;
							plain_1 = renderPlainSymbolName__typesrenderer_u9(e_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
							symbolOrId_2 = newUniquePlainSymbol__docgen_u6404(d_p0, plain_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
							T100_.len = 0; T100_.p = NIM_NIL;
							T100_ = rawNewString((*(*(*symNameNode_1)._kind_4.sym).name).s.len + plain_1.len + 1);
appendString((&T100_), (*(*(*symNameNode_1)._kind_4.sym).name).s);
appendChar((&T100_), 46);
appendString((&T100_), plain_1);
							colontmpD__23 = T100_;
							colontmpD__24 = getPlainDocstring__docgen_u3590(e_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
							colontmpD__25 = docstringSummary__docgen_u6423(colontmpD__24);
							if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
							colontmpD__26 = escape__pureZxmltree_u1069(colontmpD__25);
							if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
							setIndexTerm__packagesZdocutilsZrstgen_u353(&d_p0->Sup, ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)4), external_1, symbolOrId_2, plain_1, colontmpD__23, colontmpD__26, ((NI) ((*n_p1).info.line)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
							{
								LA95_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__26);
								eqdestroy___system_u2691(colontmpD__25);
								eqdestroy___system_u2691(colontmpD__24);
								eqdestroy___system_u2691(colontmpD__23);
								eqdestroy___system_u2691(symbolOrId_2);
								eqdestroy___system_u2691(plain_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
						} LA94: ;
						i_2 += ((NI)1);
					} LA93: ;
				}
			}
			{
				LA90_:;
			}
			{
				oldNimErrFin90_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(e_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
				*nimErr_ = oldNimErrFin90_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		}
		{
			LA88_:;
		}
		{
			oldNimErrFin88_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(etyp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin88_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA70_;
LA86_: ;
LA70_: ;
	colontmpD__15 = eqdup___system_u2697(sortName_1);
	T107_.sortName = colontmpD__15;
	colontmpD__16 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_365, TM__5fUAZGW8WPeit3fZaQyNXA_366);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T108_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_368;
	T108_[1] = name_1;
	T108_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_369;
	T108_[3] = plainNameEsc_1;
	T108_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_370;
	T108_[5] = symbolOrIdEnc_1;
	T107_.content = nsuFormatOpenArray(colontmpD__16, T108_, 6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__docgen_u8039((&(*d_p0).tocSimple[(k_p3)- 0]), (&T107_));
	colontmpD__17 = newSeq__docgen_u8080(((NI)0));
	T109_ = (tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg*)0;
	T109_ = mgetOrPut__docgen_u8144((&(*d_p0).tocTable[(k_p3)- 0]), cleanPlainSymbol_1, colontmpD__17);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	blitTmp_7 = sortName_1;
	eqwasMoved___system_u2688((&sortName_1));
	T110_.sortName = blitTmp_7;
	colontmpD__18 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_372, TM__5fUAZGW8WPeit3fZaQyNXA_373);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T111_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_374;
	T111_[1] = name_1;
	T111_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_375;
	T111_[3] = plainNameEsc_1;
	T111_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_377;
	colontmpD__19 = nsuReplaceStr(symbolOrId_1, TM__5fUAZGW8WPeit3fZaQyNXA_378, TM__5fUAZGW8WPeit3fZaQyNXA_380);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T111_[5] = colontmpD__19;
	T111_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_381;
	T111_[7] = symbolOrIdEnc_1;
	T110_.content = nsuFormatOpenArray(colontmpD__18, T111_, 8);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__docgen_u8039((&(*T109_)), (&T110_));
	colontmpD__20 = docstringSummary__docgen_u6423(plainDocstring_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__21 = escape__pureZxmltree_u1069(colontmpD__20);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setIndexTerm__packagesZdocutilsZrstgen_u353(&d_p0->Sup, ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)4), external_1, symbolOrId_1, name_1, detailedName_1, colontmpD__21, ((NI) ((*n_p1).info.line)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T114_;
		T114_ = (NIM_BOOL)0;
		T114_ = (k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7));
		if (!(T114_)) goto LA115_;
		T114_ = ((*symNameNode_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA115_: ;
		if (!T114_) goto LA116_;
		strTableAdd__astalgo_u2666((&(*d_p0).types), (*symNameNode_1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA116_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__21);
		eqdestroy___system_u2691(colontmpD__20);
		eqdestroy___system_u2691(colontmpD__19);
		eqdestroy___system_u2691(colontmpD__18);
		eqdestroy___docgen_u2579(colontmpD__17);
		eqdestroy___system_u2691(colontmpD__16);
		eqdestroy___system_u2691(attype_1);
		eqdestroy___system_u2691(colontmpD__14);
		eqdestroy___system_u2691(external_1);
		eqdestroy___docgen_u2284(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(seeSrc_1);
		eqdestroy___ast_u3252(symNameNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___packagesZdocutilsZdochelpers_u159((&rstLangSymbol_1));
		eqdestroy___system_u2691(deprecationMsg_1);
		eqdestroy___system_u2691(symbolOrIdEnc_1);
		eqdestroy___system_u2691(symbolOrId_1);
		eqdestroy___system_u2691(plainSymbolEnc_1);
		eqdestroy___system_u2691(complexSymbol_1);
		eqdestroy___system_u2691(cleanPlainSymbol_1);
		eqdestroy___system_u2691(sortName_1);
		eqdestroy___system_u2691(uniqueName_1);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(detailedName_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(typeDescr_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(plainNameEsc_1);
		eqdestroy___ast_u3252(pragmaNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___renderer_u402((&r_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___docgen_u2125(comm_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(plainName_1);
		eqdestroy___system_u2691(literal_1);
		eqdestroy___system_u2691(result_1);
		eqdestroy___system_u2691(plainDocstring_1);
		eqdestroy___system_u2691(nameEsc_1);
		eqdestroy___system_u2691(name_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkForFalse__docgen_u9720)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
	if (!(T1_)) goto LA2_;
	T3_ = (NI)0;
	T3_ = nsuCmpIgnoreStyle((*(*n_p0)._kind_5.ident).s, TM__5fUAZGW8WPeit3fZaQyNXA_383);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (T3_ == ((NI)0));
LA2_: ;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, traceDeps__docgen_u9727)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1) {
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* sep_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dir_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*it_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_u3190(it_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (T6_ == ((NI)3));
LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = ((*(*it_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41));
LA7_: ;
		if (!T3_) goto LA8_;
		sep_1 = NIM_NIL;
		dir_1 = NIM_NIL;
		a_1 = NIM_NIL;
		eqcopy___ast_u3255(&sep_1, (*it_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		eqcopy___ast_u3255(&dir_1, (*it_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		a_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29), (*it_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		add__ast_u3215(a_1, sep_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		add__ast_u3215(a_1, dir_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		add__ast_u3215(a_1, sep_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** colontmp_;
			x_1 = NIM_NIL;
			colontmp_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
			colontmp_ = &(*it_p1)._kind_6.sons.p->data[((NI)2)];
			{
				NI i_1;
				NI colontmp__2;
				NI i_2;
				i_1 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_u3197((*colontmp_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp__2)) goto LA15;
						i_1 = i_2;
						eqcopy___ast_u3255(&x_1, (*(*colontmp_))._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						eqsink___ast_u3261(&(*a_1)._kind_6.sons.p->data[((NI)2)], x_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						eqwasMoved___ast_u3249(&x_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						traceDeps__docgen_u9727(d_p0, a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						i_2 += ((NI)1);
					} LA15: ;
				}
			}
			{
				LA12_:;
			}
			{
				oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(x_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				*nimErr_ = oldNimErrFin12_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(dir_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(sep_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA8_: ;
	{
		NIM_BOOL T21_;
		NimStringV2 external_1;
		T21_ = (NIM_BOOL)0;
		T21_ = ((*it_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T21_)) goto LA22_;
		T21_ = belongsToProjectPackage__packages_u81((*d_p0).conf, (*it_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA22_: ;
		if (!T21_) goto LA23_;
		external_1.len = 0; external_1.p = NIM_NIL;
		external_1 = externalDep__docgen_u3602(d_p0, (*it_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		{
			if (!!(((*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6))- 0].finalMarkup.len == 0))) goto LA28_;
			prepareAdd((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6))- 0].finalMarkup), 2);
appendString((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_384);
		}
LA28_: ;
		{
			NIM_BOOL T32_;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T36_;
			T32_ = (NIM_BOOL)0;
			T32_ = isLatexCmd__docgen_u1921((*d_p0).conf);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			if (!!(T32_)) goto LA33_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD_ = prettyLink__packagesZdocutilsZrstgen_u81(external_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			colontmpD__2 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, colontmpD_, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			T36_[0] = colontmpD__2;
			colontmpD__3 = noschangeFileExt(external_1, TM__5fUAZGW8WPeit3fZaQyNXA_387);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			T36_[1] = colontmpD__3;
			nsuAddf((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_386, T36_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			{
				LA35_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		}
		goto LA30_;
LA33_: ;
		{
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T41_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__4 = prettyLink__packagesZdocutilsZrstgen_u81(external_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			colontmpD__5 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, colontmpD__4, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			T41_[0] = colontmpD__5;
			colontmpD__6 = noschangeFileExt(external_1, TM__5fUAZGW8WPeit3fZaQyNXA_389);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			T41_[1] = colontmpD__6;
			nsuAddf((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_388, T41_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			{
				LA40_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		}
LA30_: ;
		{
			LA25_:;
		}
		{
			eqdestroy___system_u2691(external_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA23_: ;
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, exportSym__docgen_u9748)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL oldNimErrFin34_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	{
		NIM_BOOL T4_;
		NimStringV2 external_1;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
		if (!(T4_)) goto LA5_;
		T4_ = belongsToProjectPackage__packages_u81((*d_p0).conf, s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
		external_1.len = 0; external_1.p = NIM_NIL;
		external_1 = externalDep__docgen_u3602(d_p0, s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			if (!!(((*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup.len == 0))) goto LA11_;
			prepareAdd((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup), 2);
appendString((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_390);
		}
LA11_: ;
		{
			NIM_BOOL T15_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T19_;
			T15_ = (NIM_BOOL)0;
			T15_ = isLatexCmd__docgen_u1921((*d_p0).conf);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			if (!!(T15_)) goto LA16_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__2 = prettyLink__packagesZdocutilsZrstgen_u81(external_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			colontmpD__3 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, colontmpD__2, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			T19_[0] = colontmpD__3;
			colontmpD__4 = noschangeFileExt(external_1, TM__5fUAZGW8WPeit3fZaQyNXA_392);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			T19_[1] = colontmpD__4;
			nsuAddf((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_391, T19_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			{
				LA18_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
		goto LA13_;
LA16_: ;
		{
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T24_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__5 = prettyLink__packagesZdocutilsZrstgen_u81(external_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			colontmpD__6 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, colontmpD__5, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T24_[0] = colontmpD__6;
			colontmpD__7 = noschangeFileExt(external_1, TM__5fUAZGW8WPeit3fZaQyNXA_394);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T24_[1] = colontmpD__7;
			nsuAddf((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_393, T24_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			{
				LA23_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA13_: ;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(external_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		NIM_BOOL T30_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_1;
		T30_ = (NIM_BOOL)0;
		T30_ = !(((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6)));
		if (!(T30_)) goto LA31_;
		colontmpD_ = owner__ast_u6254(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T30_ = !((colontmpD_ == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA31_: ;
		if (!T30_) goto LA32_;
		module_1 = NIM_NIL;
		module_1 = originatingModule__ast_u7142(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		{
			NIM_BOOL T37_;
			NimStringV2 complexSymbol_1;
			NimStringV2 symbolOrId_1;
			NimStringV2 external_2;
			T37_ = (NIM_BOOL)0;
			T37_ = belongsToProjectPackage__packages_u81((*d_p0).conf, module_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			if (!T37_) goto LA38_;
			complexSymbol_1.len = 0; complexSymbol_1.p = NIM_NIL;
			symbolOrId_1.len = 0; symbolOrId_1.p = NIM_NIL;
			external_2.len = 0; external_2.p = NIM_NIL;
			complexSymbol_1 = complexName__docgen_u6413((*s_p1).kind, (*s_p1).ast, (*(*s_p1).name).s);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			symbolOrId_1 = newUniquePlainSymbol__docgen_u6404(d_p0, complexSymbol_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			external_2 = externalDep__docgen_u3602(d_p0, module_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			{
				if (!!(((*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup.len == 0))) goto LA43_;
				prepareAdd((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup), 2);
appendString((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_395);
			}
LA43_: ;
			{
				NIM_BOOL T47_;
				NimStringV2 colontmpD__8;
				NimStringV2 colontmpD__9;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T51_;
				T47_ = (NIM_BOOL)0;
				T47_ = isLatexCmd__docgen_u1921((*d_p0).conf);
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
				if (!!(T47_)) goto LA48_;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__8 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, (*(*s_p1).name).s, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				T51_[0] = colontmpD__8;
				colontmpD__9 = noschangeFileExt(external_2, TM__5fUAZGW8WPeit3fZaQyNXA_398);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				T51_[1] = colontmpD__9;
				T51_[2] = symbolOrId_1;
				nsuAddf((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_397, T51_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				{
					LA50_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			}
			goto LA45_;
LA48_: ;
			{
				NimStringV2 colontmpD__10;
				NimStringV2 colontmpD__11;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T56_;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__10 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, (*(*s_p1).name).s, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				T56_[0] = colontmpD__10;
				colontmpD__11 = noschangeFileExt(external_2, TM__5fUAZGW8WPeit3fZaQyNXA_400);
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				T56_[1] = colontmpD__11;
				T56_[2] = symbolOrId_1;
				nsuAddf((&(*d_p0).section[(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))- 0].finalMarkup), TM__5fUAZGW8WPeit3fZaQyNXA_399, T56_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				{
					LA55_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(colontmpD__10);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			}
LA45_: ;
			{
				LA40_:;
			}
			{
				eqdestroy___system_u2691(external_2);
				eqdestroy___system_u2691(symbolOrId_1);
				eqdestroy___system_u2691(complexSymbol_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		}
LA38_: ;
		{
			LA34_:;
		}
		{
			oldNimErrFin34_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(module_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin34_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA32_: ;
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u163)(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* dest_p0, tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ src_p1) {
	tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&colontmp_), sizeof(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
	colontmp_ = (*dest_p0);
	nimZeroMem((void*)(&(*dest_p0)), sizeof(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
	(*dest_p0).isRst = src_p1.isRst;
	switch ((*dest_p0).isRst) {
	case NIM_TRUE:
	{
		(*dest_p0)._isRst_1.rst = 0;
		{
			if (!src_p1._isRst_1.rst) goto LA4_;
			nimIncRef(src_p1._isRst_1.rst);
		}
LA4_: ;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = nimDecRefIsLastDyn((*dest_p0)._isRst_1.rst);
			if (!T8_) goto LA9_;
			eqdestroy___packagesZdocutilsZrstast_u173((&(*(*dest_p0)._isRst_1.rst)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose((*dest_p0)._isRst_1.rst, ((NI)8));
		}
LA9_: ;
		(*dest_p0)._isRst_1.rst = src_p1._isRst_1.rst;
	}
	break;
	case NIM_FALSE:
	{
		(*dest_p0)._isRst_2.str.len = 0; (*dest_p0)._isRst_2.str.p = NIM_NIL;
		eqcopy___system_u2694((&(*dest_p0)._isRst_2.str), src_p1._isRst_2.str);
	}
	break;
	default:
	{
	}
	break;
	}
	switch (colontmp_.isRst) {
	case NIM_TRUE:
	{
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = nimDecRefIsLastDyn(colontmp_._isRst_1.rst);
			if (!T16_) goto LA17_;
			eqdestroy___packagesZdocutilsZrstast_u173((&(*colontmp_._isRst_1.rst)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose(colontmp_._isRst_1.rst, ((NI)8));
		}
LA17_: ;
	}
	break;
	case NIM_FALSE:
	{
		eqdestroy___system_u2691(colontmp_._isRst_2.str);
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateDoc__docgen_u9898)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* orig_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p3, tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA docFlags_p4) {
	NIM_BOOL showNonExports_1;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin33_;
NIM_BOOL oldNimErrFin38_;
NIM_BOOL oldNimErrFin54_;
NIM_BOOL oldNimErrFin46_;
NIM_BOOL oldNimErrFin75_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	showNonExports_1 = (((*config_p3).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)55)))&63U)))!=0);
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragmaNode_1;
		NimStringV2 colontmpD_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* doctypeNode_1;
		pragmaNode_1 = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		doctypeNode_1 = NIM_NIL;
		pragmaNode_1 = findPragma__trees_u294(n_p1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)139));
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		colontmpD_ = genDeprecationMsg__docgen_u6432(d_p0, pragmaNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		prepareAdd((&(*d_p0).modDeprecationMsg), colontmpD_.len + 0);
appendString((&(*d_p0).modDeprecationMsg), colontmpD_);
		doctypeNode_1 = findPragma__trees_u294(n_p1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)210));
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		setDoctype__docgen_u9685(d_p0, doctypeNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(doctypeNode_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u3252(pragmaNode_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	{
		tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD__2;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = genComment__docgen_u3537(d_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		add__docgen_u129((&(*d_p0).modDescPre), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___packagesZdocutilsZrstast_u285(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genItem__docgen_u6544(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12), docFlags_p4, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	{
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genItem__docgen_u6544(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14), docFlags_p4, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	{
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genItem__docgen_u6544(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15), docFlags_p4, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	{
		genItem__docgen_u6544(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17), docFlags_p4, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	{
		genItem__docgen_u6544(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18), docFlags_p4, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	{
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genItem__docgen_u6544(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16), docFlags_p4, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA18;
					i_1 = i_2;
					{
						if (!!(((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125)))) goto LA21_;
						genItem__docgen_u6544(d_p0, (*n_p1)._kind_6.sons.p->data[i_1], (*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) + (NI)((*n_p1).kind - ((NI)98))), docFlags_p4, showNonExports_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA21_: ;
					i_2 += ((NI)1);
				} LA18: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_4 = ((NI)0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA26;
					i_3 = i_4;
					generateDoc__docgen_u9898(d_p0, (*n_p1)._kind_6.sons.p->data[i_3], orig_p2, config_p3, ((tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_4 += ((NI)1);
				} LA26: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)93):
	{
		{
			NIM_BOOL T30_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
			T30_ = (NIM_BOOL)0;
			T30_ = checkForFalse__docgen_u9720((*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T30_)) goto LA31_;
			colontmpD__3 = NIM_NIL;
			colontmpD__3 = lastSon__ast_u5208((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			generateDoc__docgen_u9898(d_p0, colontmpD__3, orig_p2, config_p3, ((tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			{
				LA33_:;
			}
			{
				oldNimErrFin33_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin33_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA31_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
			it_1 = NIM_NIL;
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
				i_6 = ((NI)0);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA41;
						i_5 = i_6;
						eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_5]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
						traceDeps__docgen_u9727(d_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
						i_6 += ((NI)1);
					} LA41: ;
				}
			}
			{
				LA38_:;
			}
			{
				oldNimErrFin38_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin38_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)118):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_2;
			it_2 = NIM_NIL;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
				i_8 = ((NI)0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA49;
						i_7 = i_8;
						eqcopy___ast_u3255(&it_2, (*n_p1)._kind_6.sons.p->data[i_7]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
						{
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__4;
							if (!((*it_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA52_;
							colontmpD__4 = NIM_NIL;
							{
								NIM_BOOL T57_;
								T57_ = (NIM_BOOL)0;
								T57_ = !(((*d_p0).module == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
								if (!(T57_)) goto LA58_;
								colontmpD__4 = owner__ast_u6254((*it_2)._kind_4.sym);
								if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
								T57_ = ((*d_p0).module == colontmpD__4);
LA58_: ;
								if (!T57_) goto LA59_;
								{
									if (!!((((*(*it_2)._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1)))&63U)))!=0))) goto LA63_;
									generateDoc__docgen_u9898(d_p0, (*(*it_2)._kind_4.sym).ast, orig_p2, config_p3, ((tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA)1));
									if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
								}
LA63_: ;
							}
							goto LA55_;
LA59_: ;
							{
								if (!!(((*(*it_2)._kind_4.sym).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA66_;
								exportSym__docgen_u9748(d_p0, (*it_2)._kind_4.sym);
								if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
							}
							goto LA55_;
LA66_: ;
LA55_: ;
							{
								LA54_:;
							}
							{
								oldNimErrFin54_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u4574(colontmpD__4);
								if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
								*nimErr_ = oldNimErrFin54_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
						}
LA52_: ;
						i_8 += ((NI)1);
					} LA49: ;
				}
			}
			{
				LA46_:;
			}
			{
				oldNimErrFin46_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(it_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin46_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)119):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)120):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)117):
	{
		traceDeps__docgen_u9727(d_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ comm_1;
		comm_1.len = 0; comm_1.p = NIM_NIL;
		comm_1.len = 0; comm_1.p = NIM_NIL;
		getAllRunnableExamples__docgen_u6291(d_p0, n_p1, (&comm_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
		{
			NI T78_;
			T78_ = comm_1.len;
			if (!!((T78_ == ((NI)0)))) goto LA79_;
			add__docgen_u9972((&(*d_p0).modDescPre), ((comm_1).p) ? (comm_1.p->data) : NIM_NIL, comm_1.len);
		}
LA79_: ;
		{
			LA75_:;
		}
		{
			oldNimErrFin75_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___docgen_u2125(comm_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin75_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdup___docgen_u2970)(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* src_p0, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* Result) {
	nimZeroMem((void*)Result, sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
	(*Result).json = (*src_p0).json;
	{
		if (!(*src_p0).json) goto LA3_;
		nimIncRef((*src_p0).json);
	}
LA3_: ;
	(*Result).rst = (*src_p0).rst;
	{
		if (!(*src_p0).rst) goto LA7_;
		nimIncRef((*src_p0).rst);
	}
LA7_: ;
	(*Result).rstField = eqdup___system_u2697((*src_p0).rstField);
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u11752)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* j_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw colontmpD_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___pureZjson_u2433((*j_p1).json, ((tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !(T4_);
		if (T3_) goto LA5_;
		T3_ = !(((*j_p1).rst == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL)));
LA5_: ;
		if (!T3_) goto LA6_;
		eqdup___docgen_u2970(j_p1, (&colontmpD_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__docgen_u11759((&(*d_p0).jEntriesPre), (&colontmpD_));
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNameEsc__docgen_u6382)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = getName__docgen_u6374(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, colontmpD_, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, X5BX5Deq___pureZjson_u2308)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* obj_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___pureZjson_u330(val_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	X5BX5Deq___pureZjson_u739((&(*obj_p0)._kind_6.fields), key_p1, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, X5BX5D___pureZjson_u3478)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0, NimStringV2 name_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* result;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g**)0;
	T1_ = X5BX5D___pureZjson_u3048((&(*node_p0)._kind_6.fields), name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___pureZjson_u327(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_u5502)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0).sons.len;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genJsonItem__docgen_u9423)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nameNode_p2, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p3, NIM_BOOL nonExports_p4, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* Result) {
	NimStringV2 name_1;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* comm_1;
	tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw r_1;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
	NimStringV2 colontmpD__2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__3;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__4;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__5;
	tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_1;
	tyArray__GPOoWfHUB3hkY9cTO9a64aBQ T11_;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* T12_;
NIM_BOOL oldNimErrFin35_;
NIM_BOOL oldNimErrFin43_;
NIM_BOOL oldNimErrFin60_;
NIM_BOOL oldNimErrFin66_;
NIM_BOOL oldNimErrFin82_;
NIM_BOOL oldNimErrFin78_;
NIM_BOOL oldNimErrFin76_;
NIM_BOOL oldNimErrFin106_;
NIM_BOOL oldNimErrFin99_;
NIM_BOOL oldNimErrFin95_;
NIM_BOOL oldNimErrFin93_;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
	name_1.len = 0; name_1.p = NIM_NIL;
	comm_1 = NIM_NIL;
	nimZeroMem((void*)(&r_1), sizeof(tyObject_TSrcGen__q5rcmyeq1oDODhspKYHvMw));
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	colontmpD__5 = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isVisible__docgen_u6310(d_p0, nameNode_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		eqdestroy___pureZjson_u324(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___pureZjson_u324(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___renderer_u402((&r_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___packagesZdocutilsZrstast_u285(comm_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(name_1);
		goto BeforeRet_;
	}
LA5_: ;
	name_1 = getNameEsc__docgen_u6382(d_p0, nameNode_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	comm_1 = genRecComment__docgen_u3574(d_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	renderFlags_1 = 6158;
	{
		if (!nonExports_p4) goto LA9_;
		renderFlags_1 |= ((NU16)1)<<(((((tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg)10))) & 15);
	}
LA9_: ;
	initTokRender__renderer_u2186(n_p1, renderFlags_1, (&r_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nimZeroMem((void*)Result, sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
	nimZeroMem((void*)T11_, sizeof(tyArray__GPOoWfHUB3hkY9cTO9a64aBQ));
	T11_[0].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_403;
	colontmpD_ = percent___pureZjson_u2158(name_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_[0].Field1 = colontmpD_;
	T11_[1].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_405;
	colontmpD__2 = dollar___ast_u309(k_p3);
	colontmpD__3 = percent___pureZjson_u2158(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_[1].Field1 = colontmpD__3;
	T11_[2].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_406;
	colontmpD__4 = percent___pureZjson_u2168(((NI) ((*n_p1).info.line)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_[2].Field1 = colontmpD__4;
	T11_[3].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_408;
	colontmpD__5 = percent___pureZjson_u2168(((NI) ((*n_p1).info.col)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_[3].Field1 = colontmpD__5;
	T12_ = NIM_NIL;
	T12_ = percent___pureZjson_u2187(T11_, 4);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___pureZjson_u324(T12_); goto LA1_;}
	(*Result).json = T12_;
	{
		if (!!((comm_1 == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL)))) goto LA15_;
		{
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__6;
			if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)57)))&63U)))!=0)) goto LA19_;
			colontmpD__6 = NIM_NIL;
			colontmpD__6 = percent___pureZjson_u2158((*comm_1)._kind_1.text);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			X5BX5Deq___pureZjson_u2308((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_410, colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___pureZjson_u324(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA17_;
LA19_: ;
		{
			eqsink___packagesZdocutilsZrstast_u294(&(*Result).rst, comm_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqwasMoved___packagesZdocutilsZrstast_u282(&comm_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqsink___system_u2700((&(*Result).rstField), TM__5fUAZGW8WPeit3fZaQyNXA_411);
		}
LA17_: ;
	}
LA15_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__7;
		if (!(((NI)0) < r_1.buf.len)) goto LA24_;
		colontmpD__7 = NIM_NIL;
		colontmpD__7 = percent___pureZjson_u2158(r_1.buf);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		X5BX5Deq___pureZjson_u2308((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_413, colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___pureZjson_u324(colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA24_: ;
	{
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__8;
		if (!(k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || k_p3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA28_;
		colontmpD__8 = NIM_NIL;
		colontmpD__8 = newJObject__pureZjson_u443();
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		X5BX5Deq___pureZjson_u2308((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_415, colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		{
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__9;
			NimStringV2 colontmpD__10;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__11;
			if (!!(((*(*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA33_;
			colontmpD__9 = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11 = NIM_NIL;
			colontmpD__9 = X5BX5D___pureZjson_u3478((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_416);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			colontmpD__10 = dollar___renderer_u2166((*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			colontmpD__11 = percent___pureZjson_u2158(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			X5BX5Deq___pureZjson_u2308(colontmpD__9, TM__5fUAZGW8WPeit3fZaQyNXA_418, colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			{
				LA35_:;
			}
			{
				oldNimErrFin35_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___pureZjson_u324(colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				*nimErr_ = oldNimErrFin35_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
LA33_: ;
		{
			NI T40_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__12;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__13;
			T40_ = (NI)0;
			T40_ = len__ast_u3190((*n_p1)._kind_6.sons.p->data[((NI)3)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			if (!(((NI)1) < T40_)) goto LA41_;
			colontmpD__12 = NIM_NIL;
			colontmpD__13 = NIM_NIL;
			colontmpD__12 = X5BX5D___pureZjson_u3478((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_419);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			colontmpD__13 = newJArray__pureZjson_u506();
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			X5BX5Deq___pureZjson_u2308(colontmpD__12, TM__5fUAZGW8WPeit3fZaQyNXA_421, colontmpD__13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			{
				LA43_:;
			}
			{
				oldNimErrFin43_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				eqdestroy___pureZjson_u324(colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				*nimErr_ = oldNimErrFin43_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
LA41_: ;
		{
			NI paramIdx_1;
			NI colontmp_;
			NI i_1;
			paramIdx_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190((*n_p1)._kind_6.sons.p->data[((NI)3)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			i_1 = ((NI)1);
			{
				while (1) {
					if (!(i_1 < colontmp_)) goto LA48;
					paramIdx_1 = i_1;
					{
						NI identIdx_1;
						NI colontmp__2;
						NI T50_;
						NI i_2;
						identIdx_1 = (NI)0;
						colontmp__2 = (NI)0;
						T50_ = (NI)0;
						T50_ = len__ast_u3190((*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[paramIdx_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
						colontmp__2 = (NI)(T50_ - ((NI)2));
						i_2 = ((NI)0);
						{
							while (1) {
								NimStringV2 paramName_1;
								NimStringV2 paramType_1;
								NI T54_;
								if (!(i_2 < colontmp__2)) goto LA52;
								paramName_1.len = 0; paramName_1.p = NIM_NIL;
								paramType_1.len = 0; paramType_1.p = NIM_NIL;
								identIdx_1 = i_2;
								paramName_1 = dollar___renderer_u2166((*(*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[paramIdx_1])._kind_6.sons.p->data[identIdx_1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								T54_ = (NI)0;
								T54_ = len__ast_u3190((*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[paramIdx_1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								paramType_1 = dollar___renderer_u2166((*(*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[paramIdx_1])._kind_6.sons.p->data[(NI)(T54_ - ((NI)2))]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								{
									NI T57_;
									NimStringV2 paramDefault_1;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__14;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__15;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__16;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__17;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__18;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__19;
									NI T61_;
									tyArray__RoVffB9aih5q3xLhl7ODfeQ T62_;
									T57_ = (NI)0;
									T57_ = len__ast_u3190((*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[paramIdx_1]);
									if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
									if (!!(((*(*(*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[paramIdx_1])._kind_6.sons.p->data[(NI)(T57_ - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA58_;
									paramDefault_1.len = 0; paramDefault_1.p = NIM_NIL;
									colontmpD__14 = NIM_NIL;
									colontmpD__15 = NIM_NIL;
									colontmpD__16 = NIM_NIL;
									colontmpD__17 = NIM_NIL;
									colontmpD__18 = NIM_NIL;
									colontmpD__19 = NIM_NIL;
									T61_ = (NI)0;
									T61_ = len__ast_u3190((*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[paramIdx_1]);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									paramDefault_1 = dollar___renderer_u2166((*(*(*n_p1)._kind_6.sons.p->data[((NI)3)])._kind_6.sons.p->data[paramIdx_1])._kind_6.sons.p->data[(NI)(T61_ - ((NI)1))]);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									colontmpD__14 = X5BX5D___pureZjson_u3478((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_422);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									colontmpD__15 = X5BX5D___pureZjson_u3478(colontmpD__14, TM__5fUAZGW8WPeit3fZaQyNXA_423);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									nimZeroMem((void*)T62_, sizeof(tyArray__RoVffB9aih5q3xLhl7ODfeQ));
									T62_[0].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_424;
									colontmpD__16 = percent___pureZjson_u2158(paramName_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									T62_[0].Field1 = colontmpD__16;
									T62_[1].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_425;
									colontmpD__17 = percent___pureZjson_u2158(paramType_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									T62_[1].Field1 = colontmpD__17;
									T62_[2].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_427;
									colontmpD__18 = percent___pureZjson_u2158(paramDefault_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									T62_[2].Field1 = colontmpD__18;
									colontmpD__19 = percent___pureZjson_u2187(T62_, 3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									add__pureZjson_u662(colontmpD__15, colontmpD__19);
									if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
									{
										LA60_:;
									}
									{
										oldNimErrFin60_ = *nimErr_; *nimErr_ = NIM_FALSE;
										eqdestroy___pureZjson_u324(colontmpD__19);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__18);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__17);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__16);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__15);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__14);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___system_u2691(paramDefault_1);
										*nimErr_ = oldNimErrFin60_;
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								}
								goto LA55_;
LA58_: ;
								{
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__20;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__21;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__22;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__23;
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__24;
									tyArray__QVwsJe5kly9bx1OOTWRPirA T67_;
									colontmpD__20 = NIM_NIL;
									colontmpD__21 = NIM_NIL;
									colontmpD__22 = NIM_NIL;
									colontmpD__23 = NIM_NIL;
									colontmpD__24 = NIM_NIL;
									colontmpD__20 = X5BX5D___pureZjson_u3478((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_428);
									if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
									colontmpD__21 = X5BX5D___pureZjson_u3478(colontmpD__20, TM__5fUAZGW8WPeit3fZaQyNXA_429);
									if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
									nimZeroMem((void*)T67_, sizeof(tyArray__QVwsJe5kly9bx1OOTWRPirA));
									T67_[0].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_430;
									colontmpD__22 = percent___pureZjson_u2158(paramName_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
									T67_[0].Field1 = colontmpD__22;
									T67_[1].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_431;
									colontmpD__23 = percent___pureZjson_u2158(paramType_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
									T67_[1].Field1 = colontmpD__23;
									colontmpD__24 = percent___pureZjson_u2187(T67_, 2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
									add__pureZjson_u662(colontmpD__21, colontmpD__24);
									if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
									{
										LA66_:;
									}
									{
										oldNimErrFin66_ = *nimErr_; *nimErr_ = NIM_FALSE;
										eqdestroy___pureZjson_u324(colontmpD__24);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__23);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__22);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__21);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										eqdestroy___pureZjson_u324(colontmpD__20);
										if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
										*nimErr_ = oldNimErrFin66_;
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								}
LA55_: ;
								i_2 += ((NI)1);
								{
									LA53_:;
								}
								{
									eqdestroy___system_u2691(paramType_1);
									eqdestroy___system_u2691(paramName_1);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
							} LA52: ;
						}
					}
					i_1 += ((NI)1);
				} LA48: ;
			}
		}
		{
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__25;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__26;
			if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)4)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA74_;
			colontmpD__25 = NIM_NIL;
			colontmpD__26 = NIM_NIL;
			colontmpD__25 = X5BX5D___pureZjson_u3478((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_432);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			colontmpD__26 = newJArray__pureZjson_u506();
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			X5BX5Deq___pureZjson_u2308(colontmpD__25, TM__5fUAZGW8WPeit3fZaQyNXA_434, colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragma_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** colontmp__3;
				pragma_1 = NIM_NIL;
				colontmp__3 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
				colontmp__3 = &(*n_p1)._kind_6.sons.p->data[((NI)4)];
				{
					NI i_3;
					NI colontmp__4;
					NI i_4;
					i_3 = (NI)0;
					colontmp__4 = (NI)0;
					colontmp__4 = safeLen__ast_u3197((*colontmp__3));
					if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
					i_4 = ((NI)0);
					{
						while (1) {
							tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__27;
							tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__28;
							NimStringV2 colontmpD__29;
							tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__30;
							if (!(i_4 < colontmp__4)) goto LA81;
							colontmpD__27 = NIM_NIL;
							colontmpD__28 = NIM_NIL;
							colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
							colontmpD__30 = NIM_NIL;
							i_3 = i_4;
							eqcopy___ast_u3255(&pragma_1, (*(*colontmp__3))._kind_6.sons.p->data[i_3]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
							colontmpD__27 = X5BX5D___pureZjson_u3478((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_435);
							if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
							colontmpD__28 = X5BX5D___pureZjson_u3478(colontmpD__27, TM__5fUAZGW8WPeit3fZaQyNXA_436);
							if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
							colontmpD__29 = dollar___renderer_u2166(pragma_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
							colontmpD__30 = percent___pureZjson_u2158(colontmpD__29);
							if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
							add__pureZjson_u662(colontmpD__28, colontmpD__30);
							if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
							i_4 += ((NI)1);
							{
								LA82_:;
							}
							{
								oldNimErrFin82_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___pureZjson_u324(colontmpD__30);
								if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
								eqdestroy___system_u2691(colontmpD__29);
								eqdestroy___pureZjson_u324(colontmpD__28);
								if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
								eqdestroy___pureZjson_u324(colontmpD__27);
								if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
								*nimErr_ = oldNimErrFin82_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
						} LA81: ;
					}
				}
				{
					LA78_:;
				}
				{
					oldNimErrFin78_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(pragma_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
					*nimErr_ = oldNimErrFin78_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			}
			{
				LA76_:;
			}
			{
				oldNimErrFin76_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__26);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				eqdestroy___pureZjson_u324(colontmpD__25);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				*nimErr_ = oldNimErrFin76_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
LA74_: ;
		{
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__31;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__32;
			if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA91_;
			colontmpD__31 = NIM_NIL;
			colontmpD__32 = NIM_NIL;
			colontmpD__31 = X5BX5D___pureZjson_u3478((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_437);
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
			colontmpD__32 = newJArray__pureZjson_u506();
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
			X5BX5Deq___pureZjson_u2308(colontmpD__31, TM__5fUAZGW8WPeit3fZaQyNXA_439, colontmpD__32);
			if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* genericParam_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** colontmp__5;
				genericParam_1 = NIM_NIL;
				colontmp__5 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
				colontmp__5 = &(*n_p1)._kind_6.sons.p->data[((NI)2)];
				{
					NI i_5;
					NI colontmp__6;
					NI i_6;
					i_5 = (NI)0;
					colontmp__6 = (NI)0;
					colontmp__6 = safeLen__ast_u3197((*colontmp__5));
					if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
					i_6 = ((NI)0);
					{
						while (1) {
							tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* param_1;
							NimStringV2 colontmpD__33;
							tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__34;
							tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__35;
							tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__36;
							tyArray__OVeR5N7j5qJxmEceQoHGOw T100_;
							if (!(i_6 < colontmp__6)) goto LA98;
							param_1 = NIM_NIL;
							colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
							colontmpD__34 = NIM_NIL;
							colontmpD__35 = NIM_NIL;
							colontmpD__36 = NIM_NIL;
							i_5 = i_6;
							eqcopy___ast_u3255(&genericParam_1, (*(*colontmp__5))._kind_6.sons.p->data[i_5]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
							nimZeroMem((void*)T100_, sizeof(tyArray__OVeR5N7j5qJxmEceQoHGOw));
							T100_[0].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_440;
							colontmpD__33 = dollar___renderer_u2166(genericParam_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
							colontmpD__34 = percent___pureZjson_u2158(colontmpD__33);
							if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
							T100_[0].Field1 = colontmpD__34;
							param_1 = percent___pureZjson_u2187(T100_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
							{
								NI T103_;
								tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__37;
								tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__38;
								NimStringV2 colontmpD__39;
								tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__40;
								T103_ = (NI)0;
								T103_ = len__ast_u5502((*(*genericParam_1)._kind_4.sym).typ);
								if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
								if (!(((NI)0) < T103_)) goto LA104_;
								colontmpD__37 = NIM_NIL;
								colontmpD__38 = NIM_NIL;
								colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
								colontmpD__40 = NIM_NIL;
								colontmpD__37 = newJArray__pureZjson_u506();
								if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
								X5BX5Deq___pureZjson_u2308(param_1, TM__5fUAZGW8WPeit3fZaQyNXA_442, colontmpD__37);
								if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
								colontmpD__38 = elementType__ast_u5331((*(*genericParam_1)._kind_4.sym).typ);
								if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
								colontmpD__39 = typeToString__types_u54(colontmpD__38, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
								if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
								colontmpD__40 = percent___pureZjson_u2158(colontmpD__39);
								if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
								X5BX5Deq___pureZjson_u2308(param_1, TM__5fUAZGW8WPeit3fZaQyNXA_443, colontmpD__40);
								if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
								{
									LA106_:;
								}
								{
									oldNimErrFin106_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___pureZjson_u324(colontmpD__40);
									if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
									eqdestroy___system_u2691(colontmpD__39);
									eqdestroy___ast_u3378(colontmpD__38);
									if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
									eqdestroy___pureZjson_u324(colontmpD__37);
									if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
									*nimErr_ = oldNimErrFin106_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
							}
LA104_: ;
							colontmpD__35 = X5BX5D___pureZjson_u3478((*Result).json, TM__5fUAZGW8WPeit3fZaQyNXA_444);
							if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
							colontmpD__36 = X5BX5D___pureZjson_u3478(colontmpD__35, TM__5fUAZGW8WPeit3fZaQyNXA_445);
							if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
							add__pureZjson_u662(colontmpD__36, param_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
							i_6 += ((NI)1);
							{
								LA99_:;
							}
							{
								oldNimErrFin99_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___pureZjson_u324(colontmpD__36);
								if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
								eqdestroy___pureZjson_u324(colontmpD__35);
								if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
								eqdestroy___pureZjson_u324(colontmpD__34);
								if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
								eqdestroy___system_u2691(colontmpD__33);
								eqdestroy___pureZjson_u324(param_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
								*nimErr_ = oldNimErrFin99_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
						} LA98: ;
					}
				}
				{
					LA95_:;
				}
				{
					oldNimErrFin95_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(genericParam_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
					*nimErr_ = oldNimErrFin95_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
			}
			{
				LA93_:;
			}
			{
				oldNimErrFin93_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__32);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				eqdestroy___pureZjson_u324(colontmpD__31);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				*nimErr_ = oldNimErrFin93_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
LA91_: ;
		{
			LA30_:;
		}
		{
			oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZjson_u324(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin30_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA28_: ;
	{
		if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)29)))&63U)))!=0)) goto LA119_;
		genItem__docgen_u6544(d_p0, n_p1, nameNode_p2, k_p3, ((tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA)1), NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA119_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pureZjson_u324(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___pureZjson_u324(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___renderer_u402((&r_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___packagesZdocutilsZrstast_u285(comm_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(name_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2964)(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).rstField);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).rst);
		if (!T3_) goto LA4_;
		eqdestroy___packagesZdocutilsZrstast_u173((&(*(*dest_p0).rst)));
		nimRawDispose((*dest_p0).rst, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).json);
		if (!T8_) goto LA9_;
		eqdestroy___pureZjson_u70((&(*(*dest_p0).json)));
		nimRawDispose((*dest_p0).json, ((NI)8));
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateJson__docgen_u11779)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p2, NIM_BOOL includeComments_p3) {
NIM_BOOL oldNimErrFin2_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin20_;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin28_;
NIM_BOOL oldNimErrFin32_;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin40_;
NIM_BOOL oldNimErrFin51_;
NIM_BOOL oldNimErrFin64_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* doctypeNode_1;
		doctypeNode_1 = NIM_NIL;
		doctypeNode_1 = findPragma__trees_u294(n_p1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)210));
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		setDoctype__docgen_u9685(d_p0, doctypeNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(doctypeNode_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	{
		{
			tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD_;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__2;
			tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw T11_;
			tyObject_Table__I1hAea2wVUrLyIxtQj9cheA T12_;
			if (!includeComments_p3) goto LA8_;
			colontmpD_ = NIM_NIL;
			colontmpD__2 = NIM_NIL;
			nimZeroMem((void*)(&T11_), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
			colontmpD_ = genComment__docgen_u3537(d_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			T11_.rst = colontmpD_;
			T11_.rstField = TM__5fUAZGW8WPeit3fZaQyNXA_402;
			nimZeroMem((void*)(&T12_), sizeof(tyObject_Table__I1hAea2wVUrLyIxtQj9cheA));
			colontmpD__2 = percent___docgen_u11810(T12_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			T11_.json = colontmpD__2;
			add__docgen_u11752(d_p0, (&T11_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			{
				LA10_:;
			}
			{
				oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___pureZjson_u324(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___packagesZdocutilsZrstast_u285(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin10_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA6_;
LA8_: ;
		{
			tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD__3;
			colontmpD__3 = NIM_NIL;
			colontmpD__3 = genComment__docgen_u3537(d_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			add__docgen_u129((&(*d_p0).modDescPre), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			{
				LA16_:;
			}
			{
				oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___packagesZdocutilsZrstast_u285(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin16_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA6_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
		tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw colontmpD__4;
		nimZeroMem((void*)(&colontmpD__4), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		genJsonItem__docgen_u9423(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12), NIM_FALSE, (&colontmpD__4));
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		add__docgen_u11752(d_p0, (&colontmpD__4));
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		{
			LA20_:;
		}
		{
			oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___docgen_u2964((&colontmpD__4));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin20_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	{
		tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw colontmpD__5;
		nimZeroMem((void*)(&colontmpD__5), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		genJsonItem__docgen_u9423(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14), NIM_FALSE, (&colontmpD__5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		add__docgen_u11752(d_p0, (&colontmpD__5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		{
			LA24_:;
		}
		{
			oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___docgen_u2964((&colontmpD__5));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin24_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	{
		tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw colontmpD__6;
		nimZeroMem((void*)(&colontmpD__6), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		genJsonItem__docgen_u9423(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15), NIM_FALSE, (&colontmpD__6));
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		add__docgen_u11752(d_p0, (&colontmpD__6));
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		{
			LA28_:;
		}
		{
			oldNimErrFin28_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___docgen_u2964((&colontmpD__6));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin28_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	{
		tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw colontmpD__7;
		nimZeroMem((void*)(&colontmpD__7), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
		genJsonItem__docgen_u9423(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17), NIM_FALSE, (&colontmpD__7));
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		add__docgen_u11752(d_p0, (&colontmpD__7));
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		{
			LA32_:;
		}
		{
			oldNimErrFin32_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___docgen_u2964((&colontmpD__7));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin32_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	{
		tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw colontmpD__8;
		nimZeroMem((void*)(&colontmpD__8), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
		genJsonItem__docgen_u9423(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18), NIM_FALSE, (&colontmpD__8));
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		add__docgen_u11752(d_p0, (&colontmpD__8));
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		{
			LA36_:;
		}
		{
			oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___docgen_u2964((&colontmpD__8));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin36_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	{
		tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw colontmpD__9;
		nimZeroMem((void*)(&colontmpD__9), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		genJsonItem__docgen_u9423(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16), NIM_FALSE, (&colontmpD__9));
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		add__docgen_u11752(d_p0, (&colontmpD__9));
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		{
			LA40_:;
		}
		{
			oldNimErrFin40_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___docgen_u2964((&colontmpD__9));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin40_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA46;
					i_1 = i_2;
					{
						tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw colontmpD__10;
						if (!!(((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125)))) goto LA49_;
						nimZeroMem((void*)(&colontmpD__10), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
						genJsonItem__docgen_u9423(d_p0, (*n_p1)._kind_6.sons.p->data[i_1], (*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) + (NI)((*n_p1).kind - ((NI)98))), (((*config_p2).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)55)))&63U)))!=0), (&colontmpD__10));
						if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
						add__docgen_u11752(d_p0, (&colontmpD__10));
						if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
						{
							LA51_:;
						}
						{
							oldNimErrFin51_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___docgen_u2964((&colontmpD__10));
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							*nimErr_ = oldNimErrFin51_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA49_: ;
					i_2 += ((NI)1);
				} LA46: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_4 = ((NI)0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA57;
					i_3 = i_4;
					generateJson__docgen_u11779(d_p0, (*n_p1)._kind_6.sons.p->data[i_3], config_p2, includeComments_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_4 += ((NI)1);
				} LA57: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)93):
	{
		{
			NIM_BOOL T61_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__11;
			T61_ = (NIM_BOOL)0;
			T61_ = checkForFalse__docgen_u9720((*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T61_)) goto LA62_;
			colontmpD__11 = NIM_NIL;
			colontmpD__11 = lastSon__ast_u5208((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
			generateJson__docgen_u11779(d_p0, colontmpD__11, config_p2, includeComments_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
			{
				LA64_:;
			}
			{
				oldNimErrFin64_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin64_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA62_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setIndexTitle__docgen_u10022)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NIM_BOOL useMetaTitle_p1) {
	tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ colontmpD_;
	tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ colontmpD__2;
	NimStringV2 external_1;
	NimStringV2 colontmpD__3;
	NimStringV2 term_1;
	NimStringV2 linkTitle_1;
	tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ titleKind_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = (tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)0;
	colontmpD__2 = (tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)0;
	external_1.len = 0; external_1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	term_1.len = 0; term_1.p = NIM_NIL;
	linkTitle_1.len = 0; linkTitle_1.p = NIM_NIL;
	{
		if (!(*d_p0).standaloneDoc) goto LA4_;
		colontmpD_ = ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)0);
		titleKind_1 = colontmpD_;
	}
	goto LA2_;
LA4_: ;
	{
		colontmpD__2 = ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)1);
		titleKind_1 = colontmpD__2;
	}
LA2_: ;
	colontmpD__3 = relativeTo__pathutils_u196((*d_p0).Sup.destFile, (*(*d_p0).conf).outDir, 47);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	external_1 = noschangeFileExt(colontmpD__3, TM__5fUAZGW8WPeit3fZaQyNXA_446);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = useMetaTitle_p1;
		if (!(T9_)) goto LA10_;
		T9_ = !(((*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)2))- 0].len == ((NI)0)));
LA10_: ;
		if (!T9_) goto LA11_;
		eqcopy___system_u2694((&term_1), (*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)1))- 0]);
		eqcopy___system_u2694((&linkTitle_1), (*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)1))- 0]);
	}
	goto LA7_;
LA11_: ;
	{
		NimStringV2 filename_1;
		NimStringV2 T15_;
		NimStringV2 T21_;
		filename_1.len = 0; filename_1.p = NIM_NIL;
		filename_1 = nosextractFilename((*d_p0).Sup.filename);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T15_.len = 0; T15_.p = NIM_NIL;
		{
			if (!(*d_p0).standaloneDoc) goto LA18_;
			term_1 = filename_1;
			eqwasMoved___system_u2688((&filename_1));
		}
		goto LA16_;
LA18_: ;
		{
			term_1 = noschangeFileExt(filename_1, TM__5fUAZGW8WPeit3fZaQyNXA_447);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		}
LA16_: ;
		T21_.len = 0; T21_.p = NIM_NIL;
		{
			if (!(*d_p0).standaloneDoc) goto LA24_;
			eqcopy___system_u2694((&linkTitle_1), term_1);
		}
		goto LA22_;
LA24_: ;
		{
			linkTitle_1 = canonicalImport__options_u4253((*d_p0).conf, (*d_p0).Sup.filename);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		}
LA22_: ;
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(filename_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	{
		NimStringV2 T33_;
		if (!!((*d_p0).standaloneDoc)) goto LA31_;
		T33_.len = 0; T33_.p = NIM_NIL;
		T33_ = rawNewString(linkTitle_1.len + 7);
appendString((&T33_), TM__5fUAZGW8WPeit3fZaQyNXA_449);
appendString((&T33_), linkTitle_1);
		eqsink___system_u2700((&linkTitle_1), T33_);
	}
LA31_: ;
	setIndexTerm__packagesZdocutilsZrstgen_u353(&d_p0->Sup, titleKind_1, external_1, TM__5fUAZGW8WPeit3fZaQyNXA_450, term_1, linkTitle_1, TM__5fUAZGW8WPeit3fZaQyNXA_451, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(linkTitle_1);
		eqdestroy___system_u2691(term_1);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(external_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0) {
	NIM_BOOL result;
	result = !((hcode_p0 == ((NI)0)));
	return result;
}
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1) {
	NIM_BOOL result;
	result = ((*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (x_p0))).p == (*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (y_p1))).p);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2128)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__docgen_u2147((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ colontmp__2;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			nimZeroMem((void*)(&colontmp__2), sizeof(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
			colontmp__2 = (*dest_p0).p->data[colontmp_];
			nimZeroMem((void*)(&(*dest_p0).p->data[colontmp_]), sizeof(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
			(*dest_p0).p->data[colontmp_].isRst = src_p1.p->data[colontmp_].isRst;
			switch ((*dest_p0).p->data[colontmp_].isRst) {
			case NIM_TRUE:
			{
				(*dest_p0).p->data[colontmp_]._isRst_1.rst = 0;
				{
					if (!src_p1.p->data[colontmp_]._isRst_1.rst) goto LA13_;
					nimIncRef(src_p1.p->data[colontmp_]._isRst_1.rst);
				}
LA13_: ;
				{
					NIM_BOOL T17_;
					T17_ = (NIM_BOOL)0;
					T17_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_]._isRst_1.rst);
					if (!T17_) goto LA18_;
					eqdestroy___packagesZdocutilsZrstast_u173((&(*(*dest_p0).p->data[colontmp_]._isRst_1.rst)));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					nimRawDispose((*dest_p0).p->data[colontmp_]._isRst_1.rst, ((NI)8));
				}
LA18_: ;
				(*dest_p0).p->data[colontmp_]._isRst_1.rst = src_p1.p->data[colontmp_]._isRst_1.rst;
			}
			break;
			case NIM_FALSE:
			{
				(*dest_p0).p->data[colontmp_]._isRst_2.str.len = 0; (*dest_p0).p->data[colontmp_]._isRst_2.str.p = NIM_NIL;
				eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_]._isRst_2.str), src_p1.p->data[colontmp_]._isRst_2.str);
			}
			break;
			default:
			{
			}
			break;
			}
			switch (colontmp__2.isRst) {
			case NIM_TRUE:
			{
				{
					NIM_BOOL T25_;
					T25_ = (NIM_BOOL)0;
					T25_ = nimDecRefIsLastDyn(colontmp__2._isRst_1.rst);
					if (!T25_) goto LA26_;
					eqdestroy___packagesZdocutilsZrstast_u173((&(*colontmp__2._isRst_1.rst)));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					nimRawDispose(colontmp__2._isRst_1.rst, ((NI)8));
				}
LA26_: ;
			}
			break;
			case NIM_FALSE:
			{
				eqdestroy___system_u2691(colontmp__2._isRst_2.str);
			}
			break;
			default:
			{
			}
			break;
			}
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2287)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* dest_p0, tySequence__b9cVyuSHmrW80P0ZGgU2KHA src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__docgen_u2305((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			eqcopy___docgen_u2128((&(*dest_p0).p->data[colontmp_].descRst), src_p1.p->data[colontmp_].descRst);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqcopy___system_u5509((&(*dest_p0).p->data[colontmp_].substitutions), src_p1.p->data[colontmp_].substitutions);
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].sortName), src_p1.p->data[colontmp_].sortName);
			(*dest_p0).p->data[colontmp_].info.line = src_p1.p->data[colontmp_].info.line;
			(*dest_p0).p->data[colontmp_].info.col = src_p1.p->data[colontmp_].info.col;
			(*dest_p0).p->data[colontmp_].info.fileIndex = src_p1.p->data[colontmp_].info.fileIndex;
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].anchor), src_p1.p->data[colontmp_].anchor);
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].name), src_p1.p->data[colontmp_].name);
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].detailedName), src_p1.p->data[colontmp_].detailedName);
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, overloadGroupName__docgen_u10018)(NimStringV2 s_p0, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	colontmpD_ = toHumanStr__ast_u7574(k_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = rawNewString(s_p0.len + colontmpD_.len + 6);
appendString((&T1_), s_p0);
appendString((&T1_), TM__5fUAZGW8WPeit3fZaQyNXA_453);
appendString((&T1_), colontmpD_);
appendString((&T1_), TM__5fUAZGW8WPeit3fZaQyNXA_455);
	result = T1_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmpDecimalsIgnoreCase__docgen_u1727)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NI result;
	NI aLen_1;
	NI bLen_1;
	NI iA_1;
	NI iB_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	aLen_1 = a_p0.len;
	bLen_1 = b_p1.len;
	iA_1 = ((NI)0);
	iB_1 = ((NI)0);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = (iA_1 < aLen_1);
			if (!(T3_)) goto LA4_;
			T3_ = (iB_1 < bLen_1);
LA4_: ;
			if (!T3_) goto LA2;
			{
				NIM_BOOL T7_;
				NI limitA_1;
				NI limitB_1;
				NI pos_1;
				T7_ = (NIM_BOOL)0;
				T7_ = nsuIsDigitChar(a_p0.p->data[iA_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!(T7_)) goto LA8_;
				T7_ = nsuIsDigitChar(b_p1.p->data[iB_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA8_: ;
				if (!T7_) goto LA9_;
				limitA_1 = iA_1;
				limitB_1 = iB_1;
				{
					while (1) {
						NIM_BOOL T13_;
						T13_ = (NIM_BOOL)0;
						T13_ = (limitA_1 < aLen_1);
						if (!(T13_)) goto LA14_;
						T13_ = nsuIsDigitChar(a_p0.p->data[limitA_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA14_: ;
						if (!T13_) goto LA12;
						limitA_1 += ((NI)1);
					} LA12: ;
				}
				{
					while (1) {
						NIM_BOOL T17_;
						T17_ = (NIM_BOOL)0;
						T17_ = (limitB_1 < bLen_1);
						if (!(T17_)) goto LA18_;
						T17_ = nsuIsDigitChar(b_p1.p->data[limitB_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
						if (!T17_) goto LA16;
						limitB_1 += ((NI)1);
					} LA16: ;
				}
				pos_1 = (((NI)(limitA_1 - iA_1) >= (NI)(limitB_1 - iB_1)) ? (NI)(limitA_1 - iA_1) : (NI)(limitB_1 - iB_1));
				{
					while (1) {
						if (!(((NI)0) < pos_1)) goto LA20;
						{
							if (!((NI)(limitA_1 - pos_1) < iA_1)) goto LA23_;
							result = (NI)(((NI)48) - ((NU8)(b_p1.p->data[(NI)(limitB_1 - pos_1)])));
						}
						goto LA21_;
LA23_: ;
						{
							if (!((NI)(limitB_1 - pos_1) < iB_1)) goto LA26_;
							result = (NI)(((NU8)(a_p0.p->data[(NI)(limitA_1 - pos_1)])) - ((NI)48));
						}
						goto LA21_;
LA26_: ;
						{
							result = (NI)(((NU8)(a_p0.p->data[(NI)(limitA_1 - pos_1)])) - ((NU8)(b_p1.p->data[(NI)(limitB_1 - pos_1)])));
						}
LA21_: ;
						{
							if (!!((result == ((NI)0)))) goto LA31_;
							goto BeforeRet_;
						}
LA31_: ;
						pos_1 -= ((NI)1);
					} LA20: ;
				}
				result = (NI)((NI)(limitA_1 - iA_1) - (NI)(limitB_1 - iB_1));
				{
					if (!!((result == ((NI)0)))) goto LA35_;
					goto BeforeRet_;
				}
LA35_: ;
				iA_1 = limitA_1;
				iB_1 = limitB_1;
			}
			goto LA5_;
LA9_: ;
			{
				NIM_CHAR T38_;
				NIM_CHAR T39_;
				T38_ = (NIM_CHAR)0;
				T38_ = nsuToLowerAsciiChar(a_p0.p->data[iA_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T39_ = (NIM_CHAR)0;
				T39_ = nsuToLowerAsciiChar(b_p1.p->data[iB_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				result = (NI)(((NU8)(T38_)) - ((NU8)(T39_)));
				{
					if (!!((result == ((NI)0)))) goto LA42_;
					goto BeforeRet_;
				}
LA42_: ;
				iA_1 += ((NI)1);
				iB_1 += ((NI)1);
			}
LA5_: ;
		} LA2: ;
	}
	result = (NI)((NI)(aLen_1 - iA_1) - (NI)(bLen_1 - iB_1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u2359)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* dest_p0, tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).descRst.p != (*src_p1).descRst.p) {	eqdestroy___docgen_u2125((*dest_p0).descRst);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).descRst.len = (*src_p1).descRst.len; (*dest_p0).descRst.p = (*src_p1).descRst.p;
	if ((*dest_p0).substitutions.p != (*src_p1).substitutions.p) {	eqdestroy___system_u5506((*dest_p0).substitutions);
	}
(*dest_p0).substitutions.len = (*src_p1).substitutions.len; (*dest_p0).substitutions.p = (*src_p1).substitutions.p;
	if ((*dest_p0).sortName.p != (*src_p1).sortName.p) {	eqdestroy___system_u2691((*dest_p0).sortName);
	}
(*dest_p0).sortName.len = (*src_p1).sortName.len; (*dest_p0).sortName.p = (*src_p1).sortName.p;
	(*dest_p0).info.line = (*src_p1).info.line;
	(*dest_p0).info.col = (*src_p1).info.col;
	(*dest_p0).info.fileIndex = (*src_p1).info.fileIndex;
	if ((*dest_p0).anchor.p != (*src_p1).anchor.p) {	eqdestroy___system_u2691((*dest_p0).anchor);
	}
(*dest_p0).anchor.len = (*src_p1).anchor.len; (*dest_p0).anchor.p = (*src_p1).anchor.p;
	if ((*dest_p0).name.p != (*src_p1).name.p) {	eqdestroy___system_u2691((*dest_p0).name);
	}
(*dest_p0).name.len = (*src_p1).name.len; (*dest_p0).name.p = (*src_p1).name.p;
	if ((*dest_p0).detailedName.p != (*src_p1).detailedName.p) {	eqdestroy___system_u2691((*dest_p0).detailedName);
	}
(*dest_p0).detailedName.len = (*src_p1).detailedName.len; (*dest_p0).detailedName.p = (*src_p1).detailedName.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__docgen_u10448)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* x_p0, tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* y_p1) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = cmpDecimalsIgnoreCase__docgen_u1727((*x_p0).sortName, (*y_p1).sortName);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderItemPre__docgen_u10420)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ fragments_p1, NimStringV2* result_p2) {
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* f_1;
		NI i_1;
		NI L_1;
		NI T2_;
		f_1 = (tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ*)0;
		i_1 = ((NI)0);
		T2_ = fragments_p1.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				f_1 = (&fragments_p1.p->data[i_1]);
				switch ((*f_1).isRst) {
				case NIM_TRUE:
				{
					tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* resolved_1;
					resolved_1 = NIM_NIL;
					resolved_1 = resolveSubs__packagesZdocutilsZrst_u17344((*d_p0).sharedState, (*f_1)._isRst_1.rst);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					renderRstToOut__packagesZdocutilsZrstgen_u324(&d_p0->Sup, resolved_1, result_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					{
						LA6_:;
					}
					{
						oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___packagesZdocutilsZrstast_u285(resolved_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin6_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
				break;
				case NIM_FALSE:
				{
					prepareAdd((&(*result_p2)), (*f_1)._isRst_2.str.len + 0);
appendString((&(*result_p2)), (*f_1)._isRst_2.str);
				}
				break;
				default:
				{
				}
				break;
				}
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2967)(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* dest_p0, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(*src_p1).json) goto LA3_;
		nimIncRef((*src_p1).json);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0).json);
		if (!T7_) goto LA8_;
		eqdestroy___pureZjson_u70((&(*(*dest_p0).json)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).json, ((NI)8));
	}
LA8_: ;
	(*dest_p0).json = (*src_p1).json;
	{
		if (!(*src_p1).rst) goto LA12_;
		nimIncRef((*src_p1).rst);
	}
LA12_: ;
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = nimDecRefIsLastDyn((*dest_p0).rst);
		if (!T16_) goto LA17_;
		eqdestroy___packagesZdocutilsZrstast_u173((&(*(*dest_p0).rst)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).rst, ((NI)8));
	}
LA17_: ;
	(*dest_p0).rst = (*src_p1).rst;
	eqcopy___system_u2694((&(*dest_p0).rstField), (*src_p1).rstField);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, finishGenerateDoc__docgen_u10030)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ** d_p0) {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* firstRst_1;
	NIM_BOOL T10_;
	NIM_BOOL importdoc_1;
	NIM_BOOL T12_;
NIM_BOOL oldNimErrFin31_;
NIM_BOOL oldNimErrFin64_;
NIM_BOOL oldNimErrFin120_;
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* T146_;
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ T147_;
NIM_BOOL oldNimErrFin157_;
NIM_BOOL oldNimErrFin149_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	firstRst_1 = NIM_NIL;
	eqcopy___packagesZdocutilsZrst_u17756((&(*(*d_p0)).Sup.filenames), (&(*(*(*d_p0)).sharedState).filenames));
	firstRst_1 = ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL);
	{
		tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* fragment_1;
		NI i_1;
		NI L_1;
		NI T3_;
		fragment_1 = (tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ*)0;
		i_1 = ((NI)0);
		T3_ = (*(*d_p0)).modDescPre.len;
		L_1 = T3_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA5;
				fragment_1 = (&(*(*d_p0)).modDescPre.p->data[i_1]);
				{
					if (!(*fragment_1).isRst) goto LA8_;
					eqcopy___packagesZdocutilsZrstast_u288(&firstRst_1, (*fragment_1)._isRst_1.rst);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					goto LA2;
				}
LA8_: ;
				i_1 += ((NI)1);
			} LA5: ;
		}
	} LA2: ;
	T10_ = (NIM_BOOL)0;
	T10_ = (*(*d_p0)).Sup.hasToc;
	if (T10_) goto LA11_;
	T10_ = (*(*(*d_p0)).sharedState).hasToc;
LA11_: ;
	(*(*d_p0)).Sup.hasToc = T10_;
	T12_ = (NIM_BOOL)0;
	T12_ = !((((*(*(*d_p0)).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)30)))&63U)))!=0));
	if (!(T12_)) goto LA13_;
	T12_ = !((((*(*(*d_p0)).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)31)))&63U)))!=0));
LA13_: ;
	importdoc_1 = T12_;
	preparePass2__packagesZdocutilsZrst_u16267(&(*(*d_p0)).sharedState, firstRst_1, importdoc_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*(*(*d_p0)).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)30)))&63U)))!=0)) goto LA16_;
		{
			tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* fragment_2;
			NI i_2;
			NI L_2;
			NI T19_;
			fragment_2 = (tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ*)0;
			i_2 = ((NI)0);
			T19_ = (*(*d_p0)).modDescPre.len;
			L_2 = T19_;
			{
				while (1) {
					if (!(i_2 < L_2)) goto LA21;
					fragment_2 = (&(*(*d_p0)).modDescPre.p->data[i_2]);
					{
						if (!(*fragment_2).isRst) goto LA24_;
						traverseForIndex__packagesZdocutilsZrstgen_u4022(&(*d_p0)->Sup, (*fragment_2)._isRst_1.rst);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA24_: ;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
		setIndexTitle__docgen_u10022((*d_p0), (*(*d_p0)).standaloneDoc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_1;
			k_1 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			{
				tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q v_1;
				NI res_1;
				v_1 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
				res_1 = ((NI)0);
				{
					while (1) {
						if (!(res_1 <= ((NI)24))) goto LA29;
						v_1 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q) (res_1));
						k_1 = v_1;
						{
							NimStringV2 __1;
							tySequence__b9cVyuSHmrW80P0ZGgU2KHA overloadChoices_1;
							tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* colontmp_;
							NI L_3;
							__1.len = 0; __1.p = NIM_NIL;
							overloadChoices_1.len = 0; overloadChoices_1.p = NIM_NIL;
							__1.len = 0; __1.p = NIM_NIL;
							overloadChoices_1.len = 0; overloadChoices_1.p = NIM_NIL;
							colontmp_ = (tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg*)0;
							colontmp_ = (&(*(*d_p0)).section[(k_1)- 0].secItems);
							L_3 = len__docgen_u10125((*colontmp_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
							{
								NI h_1;
								NI colontmp__2;
								NI T33_;
								NI res_2;
								h_1 = (NI)0;
								colontmp__2 = (NI)0;
								T33_ = ((*colontmp_).data.len-1);
								colontmp__2 = T33_;
								res_2 = ((NI)0);
								{
									while (1) {
										if (!(res_2 <= colontmp__2)) goto LA35;
										h_1 = ((NI) (res_2));
										{
											NIM_BOOL T38_;
											T38_ = (NIM_BOOL)0;
											T38_ = isFilled__pureZcollectionsZtables_u32((*colontmp_).data.p->data[h_1].Field0);
											if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
											if (!T38_) goto LA39_;
											eqcopy___system_u2694((&__1), (*colontmp_).data.p->data[h_1].Field1);
											eqcopy___docgen_u2287((&overloadChoices_1), (*colontmp_).data.p->data[h_1].Field2);
											if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
											{
												tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* item_1;
												NI i_3;
												NI L_4;
												NI T42_;
												item_1 = (tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg*)0;
												i_3 = ((NI)0);
												T42_ = overloadChoices_1.len;
												L_4 = T42_;
												{
													while (1) {
														if (!(i_3 < L_4)) goto LA44;
														item_1 = (&overloadChoices_1.p->data[i_3]);
														{
															tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* fragment_3;
															NI i_4;
															NI L_5;
															NI T46_;
															fragment_3 = (tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ*)0;
															i_4 = ((NI)0);
															T46_ = (*item_1).descRst.len;
															L_5 = T46_;
															{
																while (1) {
																	if (!(i_4 < L_5)) goto LA48;
																	fragment_3 = (&(*item_1).descRst.p->data[i_4]);
																	{
																		if (!(*fragment_3).isRst) goto LA51_;
																		traverseForIndex__packagesZdocutilsZrstgen_u4022(&(*d_p0)->Sup, (*fragment_3)._isRst_1.rst);
																		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
																	}
LA51_: ;
																	i_4 += ((NI)1);
																} LA48: ;
															}
														}
														i_3 += ((NI)1);
													} LA44: ;
												}
											}
										}
LA39_: ;
										res_2 += ((NI)1);
									} LA35: ;
								}
							}
							{
								LA31_:;
							}
							{
								oldNimErrFin31_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___docgen_u2284(overloadChoices_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___system_u2691(__1);
								*nimErr_ = oldNimErrFin31_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						}
						res_1 += ((NI)1);
					} LA29: ;
				}
			}
		}
	}
LA16_: ;
	{
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_2;
		k_2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q v_2;
			NI res_3;
			v_2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			res_3 = ((NI)0);
			{
				while (1) {
					if (!(res_3 <= ((NI)24))) goto LA58;
					v_2 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q) (res_3));
					k_2 = v_2;
					{
						if (!(k_2 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_2 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_2 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || k_2 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || k_2 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || k_2 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || k_2 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA61_;
						{
							NimStringV2 plainName_1;
							tySequence__b9cVyuSHmrW80P0ZGgU2KHA overloadChoices_2;
							tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* colontmp__3;
							NI L_6;
							plainName_1.len = 0; plainName_1.p = NIM_NIL;
							overloadChoices_2.len = 0; overloadChoices_2.p = NIM_NIL;
							plainName_1.len = 0; plainName_1.p = NIM_NIL;
							overloadChoices_2.len = 0; overloadChoices_2.p = NIM_NIL;
							colontmp__3 = (tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg*)0;
							colontmp__3 = (&(*(*d_p0)).section[(k_2)- 0].secItems);
							L_6 = len__docgen_u10125((*colontmp__3));
							if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
							{
								NI h_2;
								NI colontmp__4;
								NI T66_;
								NI res_4;
								h_2 = (NI)0;
								colontmp__4 = (NI)0;
								T66_ = ((*colontmp__3).data.len-1);
								colontmp__4 = T66_;
								res_4 = ((NI)0);
								{
									while (1) {
										if (!(res_4 <= colontmp__4)) goto LA68;
										h_2 = ((NI) (res_4));
										{
											NIM_BOOL T71_;
											T71_ = (NIM_BOOL)0;
											T71_ = isFilled__pureZcollectionsZtables_u32((*colontmp__3).data.p->data[h_2].Field0);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											if (!T71_) goto LA72_;
											eqcopy___system_u2694((&plainName_1), (*colontmp__3).data.p->data[h_2].Field1);
											eqcopy___docgen_u2287((&overloadChoices_2), (*colontmp__3).data.p->data[h_2].Field2);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											{
												{
													NI T77_;
													NimStringV2 refn_1;
													NimStringV2 tooltip_1;
													NimStringV2 colontmpD_;
													NimStringV2 colontmpD__2;
													NimStringV2 colontmpD__3;
													NimStringV2 name_1;
													NimStringV2 external_1;
													NimStringV2 colontmpD__4;
													NimStringV2 colontmpD__5;
													NimStringV2 colontmpD__6;
													tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T81_;
													NimStringV2 T82_;
													NI T83_;
													tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw T88_;
													NI T89_;
													NI32 T90_;
													T77_ = overloadChoices_2.len;
													if (!(((NI)1) < T77_)) goto LA78_;
													refn_1.len = 0; refn_1.p = NIM_NIL;
													tooltip_1.len = 0; tooltip_1.p = NIM_NIL;
													colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
													colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
													colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
													name_1.len = 0; name_1.p = NIM_NIL;
													external_1.len = 0; external_1.p = NIM_NIL;
													colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
													colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
													colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
													refn_1 = overloadGroupName__docgen_u10018(plainName_1, k_2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													T82_.len = 0; T82_.p = NIM_NIL;
													colontmpD_ = toHumanStr__ast_u7574(k_2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													T82_ = rawNewString(colontmpD_.len + plainName_1.len + 1);
appendString((&T82_), colontmpD_);
appendString((&T82_), TM__5fUAZGW8WPeit3fZaQyNXA_458);
appendString((&T82_), plainName_1);
													colontmpD__2 = T82_;
													T81_[0] = colontmpD__2;
													T83_ = overloadChoices_2.len;
													colontmpD__3 = dollar___systemZdollars_u9(T83_);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													T81_[1] = colontmpD__3;
													tooltip_1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_457, T81_, 2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													name_1 = nimIdentBackticksNormalize__packagesZdocutilsZdochelpers_u103(plainName_1);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													colontmpD__4 = relativeTo__pathutils_u196((*(*d_p0)).Sup.destFile, (*(*(*d_p0)).conf).outDir, 47);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													external_1 = noschangeFileExt(colontmpD__4, TM__5fUAZGW8WPeit3fZaQyNXA_459);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													colontmpD__5 = toHumanStr__ast_u7574(k_2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													setIndexTerm__packagesZdocutilsZrstgen_u353(&(*d_p0)->Sup, ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)5), external_1, refn_1, name_1, colontmpD__5, TM__5fUAZGW8WPeit3fZaQyNXA_460, ((NI) (overloadChoices_2.p->data[((NI)0)].info.line)));
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													{
														if (!(((*(*(*d_p0)).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)30)))&63U)))!=0)) goto LA86_;
														eqdestroy___system_u2691(colontmpD__6);
														eqdestroy___system_u2691(colontmpD__5);
														eqdestroy___system_u2691(colontmpD__4);
														eqdestroy___system_u2691(external_1);
														eqdestroy___system_u2691(name_1);
														eqdestroy___system_u2691(colontmpD__3);
														eqdestroy___system_u2691(colontmpD__2);
														eqdestroy___system_u2691(colontmpD_);
														eqdestroy___system_u2691(tooltip_1);
														eqdestroy___system_u2691(refn_1);
														goto LA74;
													}
LA86_: ;
													nimZeroMem((void*)(&T88_), sizeof(tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw));
													colontmpD__6 = toHumanStr__ast_u7574(k_2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													T88_.symKind = colontmpD__6;
													T88_.name = name_1;
													T88_.isGroup = NIM_TRUE;
													T89_ = (NI)0;
													T89_ = symbolPriority__docgen_u6461(k_2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													T90_ = (NI32)0;
													T90_ = addRstFileIndex__docgen_u200((*d_p0), ((NI32) ((*(*(*d_p0)).module).position)));
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													addAnchorNim__packagesZdocutilsZrst_u5936(&(*(*d_p0)).sharedState, NIM_FALSE, refn_1, tooltip_1, (&T88_), T89_, overloadChoices_2.p->data[((NI)0)].info, T90_);
													if (NIM_UNLIKELY(*nimErr_)) goto LA80_;
													{
														LA80_:;
													}
													{
														eqdestroy___system_u2691(colontmpD__6);
														eqdestroy___system_u2691(colontmpD__5);
														eqdestroy___system_u2691(colontmpD__4);
														eqdestroy___system_u2691(external_1);
														eqdestroy___system_u2691(name_1);
														eqdestroy___system_u2691(colontmpD__3);
														eqdestroy___system_u2691(colontmpD__2);
														eqdestroy___system_u2691(colontmpD_);
														eqdestroy___system_u2691(tooltip_1);
														eqdestroy___system_u2691(refn_1);
													}
													if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
												}
LA78_: ;
											} LA74: ;
										}
LA72_: ;
										res_4 += ((NI)1);
									} LA68: ;
								}
							}
							{
								LA64_:;
							}
							{
								oldNimErrFin64_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___docgen_u2284(overloadChoices_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___system_u2691(plainName_1);
								*nimErr_ = oldNimErrFin64_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						}
					}
LA61_: ;
					res_3 += ((NI)1);
				} LA58: ;
			}
		}
	}
	{
		if (!(((*(*(*d_p0)).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)30)))&63U)))!=0)) goto LA97_;
		eqdestroy___packagesZdocutilsZrstast_u285(firstRst_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA97_: ;
	{
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_3;
		k_3 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q v_3;
			NI res_5;
			v_3 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			res_5 = ((NI)0);
			{
				while (1) {
					tySequence__sM4lkSb7zS6F7OVMvW9cffQ overloadableNames_1;
					tySequence__sM4lkSb7zS6F7OVMvW9cffQ resultX60gensym420__1;
					if (!(res_5 <= ((NI)24))) goto LA102;
					overloadableNames_1.len = 0; overloadableNames_1.p = NIM_NIL;
					resultX60gensym420__1.len = 0; resultX60gensym420__1.p = NIM_NIL;
					v_3 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q) (res_5));
					k_3 = v_3;
					resultX60gensym420__1.len = 0; resultX60gensym420__1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
					{
						NimStringV2* xX60gensym420__1;
						tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* colontmp__5;
						NI L_7;
						xX60gensym420__1 = (NimStringV2*)0;
						colontmp__5 = (tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg*)0;
						colontmp__5 = (&(*(*d_p0)).section[(k_3)- 0].secItems);
						L_7 = len__docgen_u10125((*colontmp__5));
						if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
						{
							NI h_3;
							NI colontmp__6;
							NI T106_;
							NI res_6;
							h_3 = (NI)0;
							colontmp__6 = (NI)0;
							T106_ = ((*colontmp__5).data.len-1);
							colontmp__6 = T106_;
							res_6 = ((NI)0);
							{
								while (1) {
									if (!(res_6 <= colontmp__6)) goto LA108;
									h_3 = ((NI) (res_6));
									{
										NIM_BOOL T111_;
										NimStringV2 colontmpD__7;
										T111_ = (NIM_BOOL)0;
										T111_ = isFilled__pureZcollectionsZtables_u32((*colontmp__5).data.p->data[h_3].Field0);
										if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
										if (!T111_) goto LA112_;
										xX60gensym420__1 = (&(*colontmp__5).data.p->data[h_3].Field1);
										colontmpD__7 = eqdup___system_u2697((*xX60gensym420__1));
										add__stdZenumutils_u71((&resultX60gensym420__1), colontmpD__7);
									}
LA112_: ;
									res_6 += ((NI)1);
								} LA108: ;
							}
						}
					}
					overloadableNames_1 = resultX60gensym420__1;
					eqwasMoved___system_u5503((&resultX60gensym420__1));
					{
						tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmp__7;
						NimStringV2* plainName_2;
						tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA T116_;
						NI i_5;
						NI L_8;
						NI T117_;
						colontmp__7.len = 0; colontmp__7.p = NIM_NIL;
						plainName_2 = (NimStringV2*)0;
						colontmp__7.len = 0; colontmp__7.p = NIM_NIL;
						nimZeroMem((void*)(&T116_), sizeof(tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA));
						T116_.ClP_0 = ((TM__5fUAZGW8WPeit3fZaQyNXA_461) (cmpDecimalsIgnoreCase__docgen_u1727)); T116_.ClE_0 = NIM_NIL;
						colontmp__7 = sorted__docgen_u10907(((overloadableNames_1).p) ? (overloadableNames_1.p->data) : NIM_NIL, overloadableNames_1.len, T116_, ((tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA)1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
						i_5 = ((NI)0);
						T117_ = colontmp__7.len;
						L_8 = T117_;
						{
							while (1) {
								tySequence__b9cVyuSHmrW80P0ZGgU2KHA overloadChoices_3;
								NimStringV2 nameContent_1;
								tySequence__b9cVyuSHmrW80P0ZGgU2KHA* T121_;
								tyProc__LEXkfikBreOpENJW4Qw2Tg T122_;
								if (!(i_5 < L_8)) goto LA119;
								overloadChoices_3.len = 0; overloadChoices_3.p = NIM_NIL;
								nameContent_1.len = 0; nameContent_1.p = NIM_NIL;
								plainName_2 = (&colontmp__7.p->data[i_5]);
								T121_ = (tySequence__b9cVyuSHmrW80P0ZGgU2KHA*)0;
								T121_ = X5BX5D___docgen_u11008((&(*(*d_p0)).section[(k_3)- 0].secItems), (*plainName_2));
								if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
								eqcopy___docgen_u2287((&overloadChoices_3), (*T121_));
								if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
								nimZeroMem((void*)(&T122_), sizeof(tyProc__LEXkfikBreOpENJW4Qw2Tg));
								T122_.ClP_0 = ((TM__5fUAZGW8WPeit3fZaQyNXA_462) (cmp__docgen_u10448)); T122_.ClE_0 = NIM_NIL;
								sort__docgen_u11077(((overloadChoices_3).p) ? (overloadChoices_3.p->data) : NIM_NIL, overloadChoices_3.len, T122_, ((tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA)1));
								if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
								nameContent_1 = TM__5fUAZGW8WPeit3fZaQyNXA_463;
								{
									tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* item_2;
									NI i_6;
									NI L_9;
									NI T124_;
									item_2 = (tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg*)0;
									i_6 = ((NI)0);
									T124_ = overloadChoices_3.len;
									L_9 = T124_;
									{
										while (1) {
											NimStringV2 itemDesc_1;
											NimStringV2 colontmpD__8;
											tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmpD__9;
											NimStringV2 colontmpD__10;
											NimStringV2 colontmpD__11;
											tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmpD__12;
											NimStringV2 colontmpD__13;
											tySequence__sM4lkSb7zS6F7OVMvW9cffQ T128_;
											NimStringV2 blitTmp_1;
											if (!(i_6 < L_9)) goto LA126;
											itemDesc_1.len = 0; itemDesc_1.p = NIM_NIL;
											colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
											colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
											colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
											item_2 = (&overloadChoices_3.p->data[i_6]);
											itemDesc_1 = TM__5fUAZGW8WPeit3fZaQyNXA_464;
											renderItemPre__docgen_u10420((*d_p0), (*item_2).descRst, (&itemDesc_1));
											if (NIM_UNLIKELY(*nimErr_)) goto LA127_;
											colontmpD__8 = getConfigVar__options_u3603((*(*d_p0)).conf, TM__5fUAZGW8WPeit3fZaQyNXA_466, TM__5fUAZGW8WPeit3fZaQyNXA_467);
											if (NIM_UNLIKELY(*nimErr_)) goto LA127_;
											colontmpD__9 = eqdup___system_u5512((*item_2).substitutions);
											T128_.len = 0; T128_.p = NIM_NIL;
											T128_.len = 6; T128_.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(6, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
											T128_.p->data[0] = TM__5fUAZGW8WPeit3fZaQyNXA_469;
											blitTmp_1 = itemDesc_1;
											eqwasMoved___system_u2688((&itemDesc_1));
											T128_.p->data[1] = blitTmp_1;
											T128_.p->data[2] = TM__5fUAZGW8WPeit3fZaQyNXA_470;
											colontmpD__10 = eqdup___system_u2697((*item_2).name);
											T128_.p->data[3] = colontmpD__10;
											T128_.p->data[4] = TM__5fUAZGW8WPeit3fZaQyNXA_471;
											colontmpD__11 = eqdup___system_u2697((*item_2).anchor);
											T128_.p->data[5] = colontmpD__11;
											colontmpD__12 = amp___docgen_u11262(colontmpD__9, T128_);
											colontmpD__13 = nsuFormatOpenArray(colontmpD__8, ((colontmpD__12).p) ? (colontmpD__12.p->data) : NIM_NIL, colontmpD__12.len);
											if (NIM_UNLIKELY(*nimErr_)) goto LA127_;
											prepareAdd((&nameContent_1), colontmpD__13.len + 0);
appendString((&nameContent_1), colontmpD__13);
											i_6 += ((NI)1);
											{
												LA127_:;
											}
											{
												eqdestroy___system_u2691(colontmpD__13);
												eqdestroy___system_u5506(colontmpD__12);
												eqdestroy___system_u2691(colontmpD__8);
												eqdestroy___system_u2691(itemDesc_1);
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
										} LA126: ;
									}
								}
								{
									NimStringV2 plainNameEsc1_1;
									NimStringV2 colontmpD__14;
									NimStringV2 plainNameEsc2_1;
									NimStringV2 colontmpD__15;
									NimStringV2 colontmpD__16;
									tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmpD__17;
									NimStringV2 colontmpD__18;
									NimStringV2 blitTmp_2;
									NimStringV2 T136_;
									NimStringV2 blitTmp_3;
									if (!(k_3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || k_3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || k_3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || k_3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || k_3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || k_3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || k_3 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA133_;
									plainNameEsc1_1.len = 0; plainNameEsc1_1.p = NIM_NIL;
									colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
									plainNameEsc2_1.len = 0; plainNameEsc2_1.p = NIM_NIL;
									colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
									colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
									colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
									colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
									colontmpD__14 = nsuStrip((*plainName_2), NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_212);
									if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
									plainNameEsc1_1 = esc__packagesZdocutilsZrstgen_u264((*(*d_p0)).Sup.target, colontmpD__14, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
									if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
									colontmpD__15 = nsuStrip((*plainName_2), NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_212);
									if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
									plainNameEsc2_1 = esc__packagesZdocutilsZrstgen_u264((*(*d_p0)).Sup.target, colontmpD__15, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)2));
									if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
									colontmpD__16 = getConfigVar__options_u3603((*(*d_p0)).conf, TM__5fUAZGW8WPeit3fZaQyNXA_473, TM__5fUAZGW8WPeit3fZaQyNXA_474);
									if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
									colontmpD__17.len = 6; colontmpD__17.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(6, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
									colontmpD__17.p->data[0] = TM__5fUAZGW8WPeit3fZaQyNXA_475;
									blitTmp_2 = plainNameEsc1_1;
									eqwasMoved___system_u2688((&plainNameEsc1_1));
									colontmpD__17.p->data[1] = blitTmp_2;
									colontmpD__17.p->data[2] = TM__5fUAZGW8WPeit3fZaQyNXA_477;
									T136_.len = 0; T136_.p = NIM_NIL;
									T136_ = overloadGroupName__docgen_u10018(plainNameEsc2_1, k_3);
									if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T136_); goto LA135_;}
									colontmpD__17.p->data[3] = T136_;
									colontmpD__17.p->data[4] = TM__5fUAZGW8WPeit3fZaQyNXA_479;
									blitTmp_3 = nameContent_1;
									eqwasMoved___system_u2688((&nameContent_1));
									colontmpD__17.p->data[5] = blitTmp_3;
									colontmpD__18 = nsuFormatOpenArray(colontmpD__16, ((colontmpD__17).p) ? (colontmpD__17.p->data) : NIM_NIL, colontmpD__17.len);
									if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
									prepareAdd((&(*(*d_p0)).section[(k_3)- 0].finalMarkup), colontmpD__18.len + 0);
appendString((&(*(*d_p0)).section[(k_3)- 0].finalMarkup), colontmpD__18);
									{
										LA135_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__18);
										eqdestroy___system_u5506(colontmpD__17);
										eqdestroy___system_u2691(colontmpD__16);
										eqdestroy___system_u2691(colontmpD__15);
										eqdestroy___system_u2691(plainNameEsc2_1);
										eqdestroy___system_u2691(colontmpD__14);
										eqdestroy___system_u2691(plainNameEsc1_1);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
								}
								goto LA131_;
LA133_: ;
								{
									prepareAdd((&(*(*d_p0)).section[(k_3)- 0].finalMarkup), nameContent_1.len + 0);
appendString((&(*(*d_p0)).section[(k_3)- 0].finalMarkup), nameContent_1);
								}
LA131_: ;
								i_5 += ((NI)1);
								{
									LA120_:;
								}
								{
									oldNimErrFin120_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___system_u2691(nameContent_1);
									eqdestroy___docgen_u2284(overloadChoices_3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
									*nimErr_ = oldNimErrFin120_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
							} LA119: ;
						}
						{
							LA115_:;
						}
						{
							eqdestroy___system_u5506(colontmp__7);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
					}
					clear__docgen_u11354((&(*(*d_p0)).section[(k_3)- 0].secItems));
					if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
					res_5 += ((NI)1);
					{
						LA103_:;
					}
					{
						eqdestroy___system_u5506(resultX60gensym420__1);
						eqdestroy___system_u5506(overloadableNames_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA102: ;
			}
		}
	}
	T146_ = NIM_NIL;
	T146_ = (*d_p0);
	T147_.len = 0; T147_.p = NIM_NIL;
	T147_ = (*(*d_p0)).modDescPre;
	renderItemPre__docgen_u10420(T146_, T147_, (&(*(*d_p0)).modDescFinal));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setLen__docgen_u2147((&(*(*d_p0)).modDescPre), ((NI)0));
	{
		tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw entry_1;
		NI i_7;
		NI i_8;
		NI L_10;
		NI T150_;
		nimZeroMem((void*)(&entry_1), sizeof(tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw));
		i_7 = (NI)0;
		i_8 = ((NI)0);
		T150_ = (*(*d_p0)).jEntriesPre.len;
		L_10 = T150_;
		{
			while (1) {
				if (!(i_8 < L_10)) goto LA152;
				i_7 = i_8;
				eqcopy___docgen_u2967((&entry_1), (&(*(*d_p0)).jEntriesPre.p->data[i_8]));
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
				{
					tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* resolved_1;
					NimStringV2 str_1;
					tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__19;
					if (!!((entry_1.rst == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL)))) goto LA155_;
					resolved_1 = NIM_NIL;
					str_1.len = 0; str_1.p = NIM_NIL;
					colontmpD__19 = NIM_NIL;
					resolved_1 = resolveSubs__packagesZdocutilsZrst_u17344((*(*d_p0)).sharedState, entry_1.rst);
					if (NIM_UNLIKELY(*nimErr_)) goto LA157_;
					str_1 = TM__5fUAZGW8WPeit3fZaQyNXA_480;
					renderRstToOut__packagesZdocutilsZrstgen_u324(&(*d_p0)->Sup, resolved_1, (&str_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA157_;
					colontmpD__19 = percent___pureZjson_u2158(str_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA157_;
					X5BX5Deq___pureZjson_u2308(entry_1.json, entry_1.rstField, colontmpD__19);
					if (NIM_UNLIKELY(*nimErr_)) goto LA157_;
					eqsink___packagesZdocutilsZrstast_u294(&(*(*d_p0)).jEntriesPre.p->data[i_7].rst, ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL));
					if (NIM_UNLIKELY(*nimErr_)) goto LA157_;
					{
						LA157_:;
					}
					{
						oldNimErrFin157_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___pureZjson_u324(colontmpD__19);
						if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
						eqdestroy___system_u2691(str_1);
						eqdestroy___packagesZdocutilsZrstast_u285(resolved_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
						*nimErr_ = oldNimErrFin157_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
				}
LA155_: ;
				add__pureZjson_u662((*(*d_p0)).jEntriesFinal, entry_1.json);
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
				i_8 += ((NI)1);
			} LA152: ;
		}
		{
			LA149_:;
		}
		{
			oldNimErrFin149_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___docgen_u2964((&entry_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin149_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	setIndexTitle__docgen_u10022((*d_p0), (*(*d_p0)).standaloneDoc);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	completePass2__packagesZdocutilsZrst_u17450((*(*d_p0)).sharedState);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___packagesZdocutilsZrstast_u285(firstRst_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, indexFile__docgen_u13371)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0) {
	NimStringV2 result;
	NimStringV2 dir_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tmpTuple_1;
	NimStringV2 finalDir_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	dir_1.len = 0; dir_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	finalDir_1.len = 0; finalDir_1.p = NIM_NIL;
	dir_1 = (*(*d_p0).conf).outDir;
	colontmpD_ = presentationPath__docgen_u1793((*d_p0).conf, (*d_p0).Sup.filename);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = noschangeFileExt(colontmpD_, TM__5fUAZGW8WPeit3fZaQyNXA_482);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = slash___pathutils_u135(dir_1, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nossplitFile(result, (&tmpTuple_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	finalDir_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u2688((&tmpTuple_1.Field0));
	noscreateDir(finalDir_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(finalDir_1);
		eqdestroy___pureZos_u200((&tmpTuple_1));
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u4006)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ** dest_p0, tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* src_p1) {
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLast((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___docgen_u3106((&(*(*dest_p0))));
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
}
static N_INLINE(NimStringV2, findNodeJs__nodejs_u2)(void) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = findExe__pureZos_u76(TM__5fUAZGW8WPeit3fZaQyNXA_511, NIM_TRUE, ExeExts__pureZos_u75, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 T5_;
		if (!(result.len == ((NI)0))) goto LA3_;
		T5_.len = 0; T5_.p = NIM_NIL;
		T5_ = findExe__pureZos_u76(TM__5fUAZGW8WPeit3fZaQyNXA_513, NIM_TRUE, ExeExts__pureZos_u75, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T5_); goto BeforeRet_;}
		eqsink___system_u2700((&result), T5_);
	}
LA3_: ;
	{
		tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q* T10_;
		if (!(result.len == ((NI)0))) goto LA8_;
		echoBinSafe(TM__5fUAZGW8WPeit3fZaQyNXA_514, 1);
		T10_ = NIM_NIL;
		T10_ = (tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q*) nimNewObj(sizeof(tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q), NIM_ALIGNOF(tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q));
		(*T10_).Sup.Sup.Sup.m_type = (&NTIv2__vBePDvr8fj01uTfaJy9aD3Q_);
		(*T10_).Sup.Sup.name = "IOError";
		(*T10_).Sup.Sup.message = TM__5fUAZGW8WPeit3fZaQyNXA_517;
		(*T10_).Sup.Sup.parent = ((Exception*) NIM_NIL);
		raiseExceptionEx((Exception*)T10_, "IOError", "findNodeJs", "nodejs.nim", 10);
goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, prettyString__docgen_u4068)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* a_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = TM__5fUAZGW8WPeit3fZaQyNXA_522;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T5_;
		if (!NIM_TRUE) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T5_.len = 0; T5_.p = NIM_NIL;
		T5_ = rawNewString((*a_p0).rdoccmd.len + 10);
appendString((&T5_), TM__5fUAZGW8WPeit3fZaQyNXA_524);
appendString((&T5_), (*a_p0).rdoccmd);
appendString((&T5_), TM__5fUAZGW8WPeit3fZaQyNXA_525);
		colontmpD_ = T5_;
		prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
LA3_: ;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 T10_;
		if (!NIM_TRUE) goto LA8_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = rawNewString((*a_p0).docCmd.len + 9);
appendString((&T10_), TM__5fUAZGW8WPeit3fZaQyNXA_527);
appendString((&T10_), (*a_p0).docCmd);
appendString((&T10_), TM__5fUAZGW8WPeit3fZaQyNXA_528);
		colontmpD__2 = T10_;
		prepareAdd((&result), colontmpD__2.len + 0);
appendString((&result), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
	}
LA8_: ;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 T15_;
		if (!NIM_TRUE) goto LA13_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = rawNewString((*a_p0).code.len + 7);
appendString((&T15_), TM__5fUAZGW8WPeit3fZaQyNXA_530);
appendString((&T15_), (*a_p0).code);
appendString((&T15_), TM__5fUAZGW8WPeit3fZaQyNXA_531);
		colontmpD__3 = T15_;
		prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
	}
LA13_: ;
	{
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 T20_;
		if (!NIM_TRUE) goto LA18_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T20_.len = 0; T20_.p = NIM_NIL;
		colontmpD__4 = dollar___systemZdollars_u9((*a_p0).index);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T20_ = rawNewString(colontmpD__4.len + 8);
appendString((&T20_), TM__5fUAZGW8WPeit3fZaQyNXA_533);
appendString((&T20_), colontmpD__4);
appendString((&T20_), TM__5fUAZGW8WPeit3fZaQyNXA_534);
		colontmpD__5 = T20_;
		prepareAdd((&result), colontmpD__5.len + 0);
appendString((&result), colontmpD__5);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
	}
LA18_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u4003)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___docgen_u3106((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, runAllExamples__docgen_u3690)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0) {
	NimStringV2 outputDir_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	outputDir_1.len = 0; outputDir_1.p = NIM_NIL;
	outputDir_1 = exampleOutputDir__docgen_u3687(d_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 __1;
		tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* group_1;
		NI L_1;
		__1.len = 0; __1.p = NIM_NIL;
		group_1 = NIM_NIL;
		L_1 = len__docgen_u3743((&(*d_p0).exampleGroups));
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		{
			NI h_1;
			if (!(((NI)0) < (*d_p0).exampleGroups.counter)) goto LA6_;
			h_1 = (*d_p0).exampleGroups.first;
			{
				while (1) {
					NI nxt_1;
					if (!(((NI)0) <= h_1)) goto LA9;
					nxt_1 = (*d_p0).exampleGroups.data.p->data[h_1].Field1;
					{
						NIM_BOOL T12_;
						T12_ = (NIM_BOOL)0;
						T12_ = isFilled__pureZcollectionsZtables_u32((*d_p0).exampleGroups.data.p->data[h_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						if (!T12_) goto LA13_;
						eqcopy___system_u2694((&__1), (*d_p0).exampleGroups.data.p->data[h_1].Field2);
						eqcopy___docgen_u4006(&group_1, (*d_p0).exampleGroups.data.p->data[h_1].Field3);
						{
							NimStringV2 outp_1;
							tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD_;
							NimStringV2 colontmpD__2;
							NimStringV2 colontmpD__3;
							NimStringV2 pathArgs_1;
							NimStringV2 colontmpD__4;
							NimStringV2 cmd_1;
							NimStringV2 colontmpD__5;
							NimStringV2 colontmpD__6;
							NimStringV2 colontmpD__7;
							NimStringV2 colontmpD__8;
							NimStringV2 colontmpD__9;
							NimStringV2 colontmpD__10;
							NimStringV2 colontmpD__11;
							tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T21_;
							tyArray__dyW7vpmfeTYw8kX3EXuaJA T22_;
							NimStringV2 T23_;
							tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T24_;
							tyArray__CVH4DKy6jsFwcdfgh9ceJxQ T34_;
							outp_1.len = 0; outp_1.p = NIM_NIL;
							nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
							colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
							colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
							pathArgs_1.len = 0; pathArgs_1.p = NIM_NIL;
							colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
							cmd_1.len = 0; cmd_1.p = NIM_NIL;
							colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
							colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
							colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
							colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
							colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
							colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
							colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
							{
								if (!eqStrings((*group_1).docCmd, TM__5fUAZGW8WPeit3fZaQyNXA_483)) goto LA19_;
								eqdestroy___system_u2691(colontmpD__11);
								eqdestroy___system_u2691(colontmpD__10);
								eqdestroy___system_u2691(colontmpD__9);
								eqdestroy___system_u2691(colontmpD__8);
								eqdestroy___system_u2691(colontmpD__7);
								eqdestroy___system_u2691(colontmpD__6);
								eqdestroy___system_u2691(colontmpD__5);
								eqdestroy___system_u2691(cmd_1);
								eqdestroy___system_u2691(colontmpD__4);
								eqdestroy___system_u2691(pathArgs_1);
								eqdestroy___system_u2691(colontmpD__3);
								eqdestroy___system_u2691(colontmpD__2);
								eqdestroy___pureZos_u200((&colontmpD_));
								eqdestroy___system_u2691(outp_1);
								goto LA15;
							}
LA19_: ;
							nossplitFile((*d_p0).Sup.filename, (&colontmpD_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T21_[0] = colontmpD_.Field1;
							colontmpD__2 = dollar___systemZdollars_u9((*group_1).index);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T21_[1] = colontmpD__2;
							colontmpD__3 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_485, T21_, 2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							outp_1 = slash___pathutils_u135(outputDir_1, colontmpD__3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T22_[0] = (*d_p0).Sup.filename;
							T22_[1] = (*group_1).rdoccmd;
							T22_[2] = (*group_1).code;
							T23_.len = 0; T23_.p = NIM_NIL;
							T23_ = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_487, T22_, 3);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T23_); goto LA16_;}
							eqsink___system_u2700((&(*group_1).code), T23_);
							writeFile__stdZsyncio_u532(outp_1, (*group_1).code);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T24_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_490;
							colontmpD__4 = nospquoteShell((*(*d_p0).conf).projectPath);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T24_[1] = colontmpD__4;
							pathArgs_1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_489, T24_, 2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							{
								NimStringV2* p_1;
								NI i_1;
								NI L_2;
								NI T26_;
								p_1 = (NimStringV2*)0;
								i_1 = ((NI)0);
								T26_ = (*(*d_p0).conf).searchPaths.len;
								L_2 = T26_;
								{
									while (1) {
										NimStringV2 colontmpD__12;
										tyArray__Seu7uK9aaOSN0BK3EAjjSHw T30_;
										NimStringV2 T31_;
										if (!(i_1 < L_2)) goto LA28;
										colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
										p_1 = (&(*(*d_p0).conf).searchPaths.p->data[i_1]);
										T30_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_494;
										T30_[1] = pathArgs_1;
										T30_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_495;
										colontmpD__12 = nospquoteShell((*p_1));
										if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
										T30_[3] = colontmpD__12;
										T31_.len = 0; T31_.p = NIM_NIL;
										T31_ = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_492, T30_, 4);
										if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T31_); goto LA29_;}
										eqsink___system_u2700((&pathArgs_1), T31_);
										i_1 += ((NI)1);
										{
											LA29_:;
										}
										{
											eqdestroy___system_u2691(colontmpD__12);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
									} LA28: ;
								}
							}
							T34_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_498;
							colontmpD__5 = nosgetAppFilename();
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							colontmpD__6 = nospquoteShell(colontmpD__5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T34_[1] = colontmpD__6;
							T34_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_499;
							colontmpD__7 = dollar___options_u144((*(*d_p0).conf).backend);
							T34_[3] = colontmpD__7;
							T34_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_501;
							T34_[5] = pathArgs_1;
							T34_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_502;
							colontmpD__8 = nospquoteShell((*(*d_p0).conf).libpath);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T34_[7] = colontmpD__8;
							T34_[8] = TM__5fUAZGW8WPeit3fZaQyNXA_504;
							colontmpD__9 = nospquoteShell(outputDir_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T34_[9] = colontmpD__9;
							T34_[10] = TM__5fUAZGW8WPeit3fZaQyNXA_506;
							colontmpD__10 = nospquoteShell(outp_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T34_[11] = colontmpD__10;
							T34_[12] = TM__5fUAZGW8WPeit3fZaQyNXA_508;
							T34_[13] = (*group_1).rdoccmd;
							T34_[14] = TM__5fUAZGW8WPeit3fZaQyNXA_509;
							T34_[15] = (*group_1).docCmd;
							cmd_1 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_497, T34_, 16);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							{
								NIM_BOOL T37_;
								T37_ = (NIM_BOOL)0;
								T37_ = ((*(*d_p0).conf).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3));
								if (!(T37_)) goto LA38_;
								colontmpD__11 = findNodeJs__nodejs_u2();
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								T37_ = (colontmpD__11.len == 0);
LA38_: ;
								if (!T37_) goto LA39_;
							}
							goto LA35_;
LA39_: ;
							{
								NI T42_;
								T42_ = (NI)0;
								T42_ = nosexecShellCmd(cmd_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								if (!!((T42_ == ((NI)0)))) goto LA43_;
								{
									NIM_BOOL T47_;
									NimStringV2 colontmpD__13;
									NimStringV2 colontmpD__14;
									tyArray__dyW7vpmfeTYw8kX3EXuaJA T51_;
									T47_ = (NIM_BOOL)0;
									T47_ = isDefined__options_u959((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_519);
									if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
									if (!T47_) goto LA48_;
									colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
									colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
									T51_[0] = outp_1;
									colontmpD__13 = prettyString__docgen_u4068((&(*group_1)));
									if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
									T51_[1] = colontmpD__13;
									T51_[2] = cmd_1;
									colontmpD__14 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_521, T51_, 3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
									raiseAssert__stdZassertions_u15(colontmpD__14);
									if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
									{
										LA50_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__14);
										eqdestroy___system_u2691(colontmpD__13);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								}
								goto LA45_;
LA48_: ;
								{
									NimStringV2 colontmpD__15;
									NimStringV2 colontmpD__16;
									tyArray__dyW7vpmfeTYw8kX3EXuaJA T56_;
									colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
									colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
									T56_[0] = outp_1;
									colontmpD__15 = prettyString__docgen_u4068((&(*group_1)));
									if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
									T56_[1] = colontmpD__15;
									T56_[2] = cmd_1;
									colontmpD__16 = nsuFormatOpenArray(TM__5fUAZGW8WPeit3fZaQyNXA_535, T56_, 3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
									quit__system_u7994(colontmpD__16, ((NI)1));
									{
										LA55_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__16);
										eqdestroy___system_u2691(colontmpD__15);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								}
LA45_: ;
							}
							goto LA35_;
LA43_: ;
							{
								NimStringV2 argX60gensym124__1;
								NimStringV2 colontmpD__17;
								NimStringV2 colontmpD__18;
								tyArray__YgExxhfgKcesA5EOUj1MOA T61_;
								NimStringV2 T62_;
								argX60gensym124__1.len = 0; argX60gensym124__1.p = NIM_NIL;
								colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
								colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
								colontmpD__17 = msgKindToString__msgs_u867(((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)89));
								if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
								T62_.len = 0; T62_.p = NIM_NIL;
								T62_ = rawNewString(outp_1.len + 18);
appendString((&T62_), TM__5fUAZGW8WPeit3fZaQyNXA_537);
appendString((&T62_), outp_1);
								colontmpD__18 = T62_;
								T61_[0] = colontmpD__18;
								argX60gensym124__1 = nsuFormatOpenArray(colontmpD__17, T61_, 1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
								liMessage__msgs_u1227((*d_p0).conf, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)89), argX60gensym124__1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__5fUAZGW8WPeit3fZaQyNXA_538), NIM_TRUE, NIM_FALSE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
								{
									LA60_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__18);
									eqdestroy___system_u2691(colontmpD__17);
									eqdestroy___system_u2691(argX60gensym124__1);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							}
LA35_: ;
							{
								LA16_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__11);
								eqdestroy___system_u2691(colontmpD__10);
								eqdestroy___system_u2691(colontmpD__9);
								eqdestroy___system_u2691(colontmpD__8);
								eqdestroy___system_u2691(colontmpD__7);
								eqdestroy___system_u2691(colontmpD__6);
								eqdestroy___system_u2691(colontmpD__5);
								eqdestroy___system_u2691(cmd_1);
								eqdestroy___system_u2691(colontmpD__4);
								eqdestroy___system_u2691(pathArgs_1);
								eqdestroy___system_u2691(colontmpD__3);
								eqdestroy___system_u2691(colontmpD__2);
								eqdestroy___pureZos_u200((&colontmpD_));
								eqdestroy___system_u2691(outp_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						} LA15: ;
					}
LA13_: ;
					h_1 = nxt_1;
				} LA9: ;
			}
		}
LA6_: ;
		{
			LA3_:;
		}
		{
			eqdestroy___docgen_u4003(group_1);
			eqdestroy___system_u2691(__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(outputDir_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2582)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* dest_p0, tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg src_p1) {
	NI T6_;
	NI colontmp_;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__docgen_u2600((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].content), src_p1.p->data[colontmp_].content);
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].sortName), src_p1.p->data[colontmp_].sortName);
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u2654)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* dest_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* src_p1) {
	if ((*dest_p0).content.p != (*src_p1).content.p) {	eqdestroy___system_u2691((*dest_p0).content);
	}
(*dest_p0).content.len = (*src_p1).content.len; (*dest_p0).content.p = (*src_p1).content.p;
	if ((*dest_p0).sortName.p != (*src_p1).sortName.p) {	eqdestroy___system_u2691((*dest_p0).sortName);
	}
(*dest_p0).sortName.len = (*src_p1).sortName.len; (*dest_p0).sortName.p = (*src_p1).sortName.p;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__docgen_u12350)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* x_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* y_p1) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = cmpDecimalsIgnoreCase__docgen_u1727((*x_p0).sortName, (*y_p1).sortName);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u2648)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* dest_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* src_p1) {
	eqcopy___system_u2694((&(*dest_p0).content), (*src_p1).content);
	eqcopy___system_u2694((&(*dest_p0).sortName), (*src_p1).sortName);
}
N_LIB_PRIVATE N_NIMCALL(void, genSection__docgen_u12338)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p1, NIM_BOOL groupedToc_p2) {
	NimStringV2 title_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ sectionValues_1;
	tyArray__hSrJSIaqyFxuH67Wd7apZQ T6_;
	NimStringV2 T7_;
	NimStringV2 T49_;
	NimStringV2 T50_;
	NimStringV2 blitTmp_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	title_1.len = 0; title_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	sectionValues_1.len = 0; sectionValues_1.p = NIM_NIL;
	{
		if (!((*d_p0).section[(kind_p1)- 0].finalMarkup.len == 0)) goto LA4_;
		eqdestroy___system_u5506(sectionValues_1);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(title_1);
		goto BeforeRet_;
	}
LA4_: ;
	eqcopy___system_u2694((&title_1), sectionNames__docgen_u12342[(kind_p1)- 6]);
	colontmpD_ = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_557, TM__5fUAZGW8WPeit3fZaQyNXA_558);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_560;
	colontmpD__2 = dollar___systemZdollars_u9(kind_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_[1] = colontmpD__2;
	T6_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_562;
	T6_[3] = title_1;
	T6_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_564;
	colontmpD__3 = dollar___systemZdollars_u9((NI)(kind_p1 + ((NI)50)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_[5] = colontmpD__3;
	T6_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_565;
	T6_[7] = (*d_p0).section[(kind_p1)- 0].finalMarkup;
	T7_.len = 0; T7_.p = NIM_NIL;
	T7_ = nsuFormatOpenArray(colontmpD_, T6_, 8);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA1_;}
	eqsink___system_u2700((&(*d_p0).section[(kind_p1)- 0].finalMarkup), T7_);
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ overloadableNames_1;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ resultX60gensym468__1;
		if (!groupedToc_p2) goto LA10_;
		overloadableNames_1.len = 0; overloadableNames_1.p = NIM_NIL;
		resultX60gensym468__1.len = 0; resultX60gensym468__1.p = NIM_NIL;
		resultX60gensym468__1.len = 0; resultX60gensym468__1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		{
			NimStringV2* xX60gensym468__1;
			tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* colontmp_;
			NI L_1;
			xX60gensym468__1 = (NimStringV2*)0;
			colontmp_ = (tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw*)0;
			colontmp_ = (&(*d_p0).tocTable[(kind_p1)- 0]);
			L_1 = len__docgen_u12624((*colontmp_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			{
				NI h_1;
				NI colontmp__2;
				NI T15_;
				NI res_1;
				h_1 = (NI)0;
				colontmp__2 = (NI)0;
				T15_ = ((*colontmp_).data.len-1);
				colontmp__2 = T15_;
				res_1 = ((NI)0);
				{
					while (1) {
						if (!(res_1 <= colontmp__2)) goto LA17;
						h_1 = ((NI) (res_1));
						{
							NIM_BOOL T20_;
							NimStringV2 colontmpD__4;
							T20_ = (NIM_BOOL)0;
							T20_ = isFilled__pureZcollectionsZtables_u32((*colontmp_).data.p->data[h_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
							if (!T20_) goto LA21_;
							xX60gensym468__1 = (&(*colontmp_).data.p->data[h_1].Field1);
							colontmpD__4 = eqdup___system_u2697((*xX60gensym468__1));
							add__stdZenumutils_u71((&resultX60gensym468__1), colontmpD__4);
						}
LA21_: ;
						res_1 += ((NI)1);
					} LA17: ;
				}
			}
		}
		overloadableNames_1 = resultX60gensym468__1;
		eqwasMoved___system_u5503((&resultX60gensym468__1));
		{
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmp__3;
			NimStringV2* plainName_1;
			tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA T25_;
			NI i_1;
			NI L_2;
			NI T26_;
			colontmp__3.len = 0; colontmp__3.p = NIM_NIL;
			plainName_1 = (NimStringV2*)0;
			nimZeroMem((void*)(&T25_), sizeof(tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA));
			T25_.ClP_0 = ((TM__5fUAZGW8WPeit3fZaQyNXA_566) (cmpDecimalsIgnoreCase__docgen_u1727)); T25_.ClE_0 = NIM_NIL;
			colontmp__3 = sorted__docgen_u10907(((overloadableNames_1).p) ? (overloadableNames_1.p->data) : NIM_NIL, overloadableNames_1.len, T25_, ((tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			i_1 = ((NI)0);
			T26_ = colontmp__3.len;
			L_2 = T26_;
			{
				while (1) {
					tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg overloadChoices_1;
					NimStringV2 content_1;
					NimStringV2 colontmpD__5;
					NimStringV2 colontmpD__6;
					NimStringV2 colontmpD__7;
					NimStringV2 colontmpD__8;
					tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* T30_;
					tyProc__uvNcvuBCVAehqicKbFevrQ T31_;
					tyArray__ftd030ZQb0rgyFYIoQaqFA T36_;
					if (!(i_1 < L_2)) goto LA28;
					overloadChoices_1.len = 0; overloadChoices_1.p = NIM_NIL;
					content_1.len = 0; content_1.p = NIM_NIL;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					plainName_1 = (&colontmp__3.p->data[i_1]);
					T30_ = (tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg*)0;
					T30_ = X5BX5D___docgen_u12867((&(*d_p0).tocTable[(kind_p1)- 0]), (*plainName_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					eqcopy___docgen_u2582((&overloadChoices_1), (*T30_));
					nimZeroMem((void*)(&T31_), sizeof(tyProc__uvNcvuBCVAehqicKbFevrQ));
					T31_.ClP_0 = ((TM__5fUAZGW8WPeit3fZaQyNXA_567) (cmp__docgen_u12350)); T31_.ClE_0 = NIM_NIL;
					sort__docgen_u12936(((overloadChoices_1).p) ? (overloadChoices_1.p->data) : NIM_NIL, overloadChoices_1.len, T31_, ((tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					content_1 = TM__5fUAZGW8WPeit3fZaQyNXA_568;
					{
						tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* item_1;
						NI i_2;
						NI L_3;
						NI T33_;
						item_1 = (tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg*)0;
						i_2 = ((NI)0);
						T33_ = overloadChoices_1.len;
						L_3 = T33_;
						{
							while (1) {
								if (!(i_2 < L_3)) goto LA35;
								item_1 = (&overloadChoices_1.p->data[i_2]);
								prepareAdd((&content_1), (*item_1).content.len + 0);
appendString((&content_1), (*item_1).content);
								i_2 += ((NI)1);
							} LA35: ;
						}
					}
					colontmpD__5 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_570, TM__5fUAZGW8WPeit3fZaQyNXA_571);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					T36_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_572;
					colontmpD__6 = dollar___systemZdollars_u9(kind_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					T36_[1] = colontmpD__6;
					T36_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_573;
					T36_[3] = title_1;
					T36_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_574;
					colontmpD__7 = dollar___systemZdollars_u9((NI)(kind_p1 + ((NI)50)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					T36_[5] = colontmpD__7;
					T36_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_575;
					T36_[7] = content_1;
					T36_[8] = TM__5fUAZGW8WPeit3fZaQyNXA_577;
					T36_[9] = (*plainName_1);
					colontmpD__8 = nsuFormatOpenArray(colontmpD__5, T36_, 10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					prepareAdd((&(*d_p0).toc2[(kind_p1)- 0]), colontmpD__8.len + 0);
appendString((&(*d_p0).toc2[(kind_p1)- 0]), colontmpD__8);
					i_1 += ((NI)1);
					{
						LA29_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___system_u2691(content_1);
						eqdestroy___docgen_u2579(overloadChoices_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				} LA28: ;
			}
			{
				LA24_:;
			}
			{
				eqdestroy___system_u5506(colontmp__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		}
		{
			LA12_:;
		}
		{
			eqdestroy___system_u5506(resultX60gensym468__1);
			eqdestroy___system_u5506(overloadableNames_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA10_: ;
	{
		{
			tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg colontmp__4;
			tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* item_2;
			tyProc__uvNcvuBCVAehqicKbFevrQ T45_;
			NI i_3;
			NI L_4;
			NI T46_;
			colontmp__4.len = 0; colontmp__4.p = NIM_NIL;
			item_2 = (tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg*)0;
			nimZeroMem((void*)(&T45_), sizeof(tyProc__uvNcvuBCVAehqicKbFevrQ));
			T45_.ClP_0 = ((TM__5fUAZGW8WPeit3fZaQyNXA_578) (cmp__docgen_u12350)); T45_.ClE_0 = NIM_NIL;
			colontmp__4 = sorted__docgen_u13140((((*d_p0).tocSimple[(kind_p1)- 0]).p) ? ((*d_p0).tocSimple[(kind_p1)- 0].p->data) : NIM_NIL, (*d_p0).tocSimple[(kind_p1)- 0].len, T45_, ((tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_3 = ((NI)0);
			T46_ = colontmp__4.len;
			L_4 = T46_;
			{
				while (1) {
					if (!(i_3 < L_4)) goto LA48;
					item_2 = (&colontmp__4.p->data[i_3]);
					prepareAdd((&(*d_p0).toc2[(kind_p1)- 0]), (*item_2).content.len + 0);
appendString((&(*d_p0).toc2[(kind_p1)- 0]), (*item_2).content);
					i_3 += ((NI)1);
				} LA48: ;
			}
			eqdestroy___docgen_u2579(colontmp__4);
		}
	}
LA8_: ;
	sectionValues_1.len = 6; sectionValues_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(6, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	sectionValues_1.p->data[0] = TM__5fUAZGW8WPeit3fZaQyNXA_580;
	T49_.len = 0; T49_.p = NIM_NIL;
	T49_ = dollar___systemZdollars_u9(kind_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T49_); goto LA1_;}
	sectionValues_1.p->data[1] = T49_;
	sectionValues_1.p->data[2] = TM__5fUAZGW8WPeit3fZaQyNXA_581;
	T50_.len = 0; T50_.p = NIM_NIL;
	T50_ = dollar___systemZdollars_u9((NI)(kind_p1 + ((NI)50)));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T50_); goto LA1_;}
	sectionValues_1.p->data[3] = T50_;
	sectionValues_1.p->data[4] = TM__5fUAZGW8WPeit3fZaQyNXA_582;
	blitTmp_1 = title_1;
	eqwasMoved___system_u2688((&title_1));
	sectionValues_1.p->data[5] = blitTmp_1;
	{
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ colontmpD__11;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ blitTmp_2;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ T56_;
		NimStringV2 T57_;
		if (!!(((*d_p0).toc2[(kind_p1)- 0].len == 0))) goto LA53_;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__9 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_584, TM__5fUAZGW8WPeit3fZaQyNXA_585);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		blitTmp_2 = sectionValues_1;
		eqwasMoved___system_u5503((&sectionValues_1));
		T56_.len = 0; T56_.p = NIM_NIL;
		T56_.len = 2; T56_.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(2, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		T56_.p->data[0] = TM__5fUAZGW8WPeit3fZaQyNXA_586;
		colontmpD__10 = eqdup___system_u2697((*d_p0).toc2[(kind_p1)- 0]);
		T56_.p->data[1] = colontmpD__10;
		colontmpD__11 = amp___docgen_u11262(blitTmp_2, T56_);
		T57_.len = 0; T57_.p = NIM_NIL;
		T57_ = nsuFormatOpenArray(colontmpD__9, ((colontmpD__11).p) ? (colontmpD__11.p->data) : NIM_NIL, colontmpD__11.len);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T57_); goto LA55_;}
		eqsink___system_u2700((&(*d_p0).toc[(kind_p1)- 0]), T57_);
		{
			LA55_:;
		}
		{
			eqdestroy___system_u5506(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA51_;
LA53_: ;
	{
		NimStringV2 colontmpD__12;
		NimStringV2 T62_;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__12 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_588, TM__5fUAZGW8WPeit3fZaQyNXA_589);
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		T62_.len = 0; T62_.p = NIM_NIL;
		T62_ = nsuFormatOpenArray(colontmpD__12, ((sectionValues_1).p) ? (sectionValues_1.p->data) : NIM_NIL, sectionValues_1.len);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T62_); goto LA61_;}
		eqsink___system_u2700((&(*d_p0).toc[(kind_p1)- 0]), T62_);
		{
			LA61_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA51_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u5506(sectionValues_1);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(title_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, relLink__docgen_u13289)(NimStringV2 outDir_p0, NimStringV2 destFile_p1, NimStringV2 linkto_p2) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__2;
	NimStringV2 colontmpD__3;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD_ = slash___pathutils_u135(outDir_p0, linkto_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	splitFile__pathutils_u39(destFile_p1, (&colontmpD__2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = relativeTo__pathutils_u196(colontmpD_, colontmpD__2.Field0, 47);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = dollar___docgen_u13294(colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___pathutils_u73((&colontmpD__2));
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genOutFile__docgen_u13298)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NIM_BOOL groupedToc_p1) {
	NimStringV2 result;
	NimStringV2 code_1;
	NimStringV2 content_1;
	NimStringV2 title_1;
	NimStringV2 toc_1;
	NimStringV2 subtitle_1;
	NimStringV2 groupsection_1;
	NimStringV2 bodyname_1;
	NimStringV2 seeSrc_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NI j_1;
	NimStringV2 T29_;
	NimStringV2 T48_;
	tyArray__E9cjy83smb5N4sXLGk0xt3w T62_;
	NimStringV2 T63_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	code_1.len = 0; code_1.p = NIM_NIL;
	content_1.len = 0; content_1.p = NIM_NIL;
	title_1.len = 0; title_1.p = NIM_NIL;
	toc_1.len = 0; toc_1.p = NIM_NIL;
	subtitle_1.len = 0; subtitle_1.p = NIM_NIL;
	groupsection_1.len = 0; groupsection_1.p = NIM_NIL;
	bodyname_1.len = 0; bodyname_1.p = NIM_NIL;
	seeSrc_1.len = 0; seeSrc_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	code_1 = TM__5fUAZGW8WPeit3fZaQyNXA_539;
	content_1 = TM__5fUAZGW8WPeit3fZaQyNXA_540;
	title_1 = TM__5fUAZGW8WPeit3fZaQyNXA_541;
	j_1 = ((NI)0);
	toc_1 = TM__5fUAZGW8WPeit3fZaQyNXA_542;
	renderTocEntries__packagesZdocutilsZrstgen_u3698(&d_p0->Sup, (&j_1), ((NI)1), (&toc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q i_1;
		i_1 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q v_1;
			NI res_1;
			v_1 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			res_1 = ((NI)0);
			{
				while (1) {
					NIM_BOOL shouldSort_1;
					NIM_BOOL T6_;
					if (!(res_1 <= ((NI)24))) goto LA5;
					v_1 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q) (res_1));
					i_1 = v_1;
					T6_ = (NIM_BOOL)0;
					T6_ = (i_1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || i_1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || i_1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || i_1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || i_1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || i_1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || i_1 == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
					if (!(T6_)) goto LA7_;
					T6_ = groupedToc_p1;
LA7_: ;
					shouldSort_1 = T6_;
					genSection__docgen_u12338(d_p0, i_1, shouldSort_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&toc_1), (*d_p0).toc[(i_1)- 0].len + 0);
appendString((&toc_1), (*d_p0).toc[(i_1)- 0]);
					res_1 += ((NI)1);
				} LA5: ;
			}
		}
	}
	{
		NIM_BOOL T10_;
		NimStringV2 colontmpD__5;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T15_;
		NimStringV2 T16_;
		T10_ = (NIM_BOOL)0;
		T10_ = !((toc_1.len == 0));
		if (T10_) goto LA11_;
		T10_ = ((*d_p0).Sup.target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1));
LA11_: ;
		if (!T10_) goto LA12_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__5 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_591, TM__5fUAZGW8WPeit3fZaQyNXA_592);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T15_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_593;
		T15_[1] = toc_1;
		T16_.len = 0; T16_.p = NIM_NIL;
		T16_ = nsuFormatOpenArray(colontmpD__5, T15_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T16_); goto LA14_;}
		eqsink___system_u2700((&toc_1), T16_);
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA12_: ;
	{
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q i_2;
		i_2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q v_2;
			NI res_2;
			v_2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			res_2 = ((NI)0);
			{
				while (1) {
					if (!(res_2 <= ((NI)24))) goto LA22;
					v_2 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q) (res_2));
					i_2 = v_2;
					prepareAdd((&code_1), (*d_p0).section[(i_2)- 0].finalMarkup.len + 0);
appendString((&code_1), (*d_p0).section[(i_2)- 0].finalMarkup);
					res_2 += ((NI)1);
				} LA22: ;
			}
		}
	}
	{
		if (!!(((*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)2))- 0].len == ((NI)0)))) goto LA25_;
		eqcopy___system_u2694((&title_1), (*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)2))- 0]);
	}
	goto LA23_;
LA25_: ;
	{
		NimStringV2 T28_;
		T28_.len = 0; T28_.p = NIM_NIL;
		T28_ = canonicalImport__options_u4253((*d_p0).conf, (*d_p0).Sup.filename);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T28_); goto LA1_;}
		eqsink___system_u2700((&title_1), T28_);
	}
LA23_: ;
	T29_.len = 0; T29_.p = NIM_NIL;
	T29_ = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, title_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T29_); goto LA1_;}
	eqsink___system_u2700((&title_1), T29_);
	subtitle_1 = TM__5fUAZGW8WPeit3fZaQyNXA_594;
	{
		if (!!(((*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)3))- 0].len == 0))) goto LA32_;
		{
			NIM_BOOL T36_;
			NimStringV2 colontmpD__6;
			tyArray__YgExxhfgKcesA5EOUj1MOA T40_;
			T36_ = (NIM_BOOL)0;
			T36_ = isLatexCmd__docgen_u1921((*d_p0).conf);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T36_)) goto LA37_;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__6 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, (*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)3))- 0], ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			T40_[0] = colontmpD__6;
			nsuAddf((&subtitle_1), TM__5fUAZGW8WPeit3fZaQyNXA_596, T40_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			{
				LA39_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__6);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA34_;
LA37_: ;
		{
			NimStringV2 colontmpD__7;
			tyArray__YgExxhfgKcesA5EOUj1MOA T45_;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__7 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, (*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)3))- 0], ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T45_[0] = colontmpD__7;
			nsuAddf((&subtitle_1), TM__5fUAZGW8WPeit3fZaQyNXA_598, T45_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			{
				LA44_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA34_: ;
	}
LA32_: ;
	groupsection_1 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_600, TM__5fUAZGW8WPeit3fZaQyNXA_601);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T48_.len = 0; T48_.p = NIM_NIL;
	{
		NIM_BOOL T51_;
		NIM_BOOL T52_;
		NIM_BOOL T55_;
		T51_ = (NIM_BOOL)0;
		T52_ = (NIM_BOOL)0;
		T52_ = (*d_p0).Sup.hasToc;
		if (!(T52_)) goto LA53_;
		T52_ = !((*d_p0).standaloneDoc);
LA53_: ;
		T51_ = T52_;
		if (!(T51_)) goto LA54_;
		T55_ = (NIM_BOOL)0;
		T55_ = isLatexCmd__docgen_u1921((*d_p0).conf);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T51_ = !(T55_);
LA54_: ;
		if (!T51_) goto LA56_;
		setLengthStrV2((&groupsection_1), ((NI)0));
		bodyname_1 = TM__5fUAZGW8WPeit3fZaQyNXA_603;
	}
	goto LA49_;
LA56_: ;
	{
		if (!(*d_p0).Sup.hasToc) goto LA59_;
		bodyname_1 = TM__5fUAZGW8WPeit3fZaQyNXA_605;
	}
	goto LA49_;
LA59_: ;
	{
		bodyname_1 = TM__5fUAZGW8WPeit3fZaQyNXA_607;
	}
LA49_: ;
	seeSrc_1 = genSeeSrc__docgen_u6450(d_p0, (*d_p0).Sup.filename, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getConfigVar__options_u3603((*d_p0).conf, bodyname_1, TM__5fUAZGW8WPeit3fZaQyNXA_608);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T62_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_610;
	T62_[1] = title_1;
	T62_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_612;
	T62_[3] = subtitle_1;
	T62_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_614;
	T62_[5] = toc_1;
	T62_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_616;
	T62_[7] = (*d_p0).modDescFinal;
	T62_[8] = TM__5fUAZGW8WPeit3fZaQyNXA_618;
	colontmpD__2 = getDateStr__options_u643();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T62_[9] = colontmpD__2;
	T62_[10] = TM__5fUAZGW8WPeit3fZaQyNXA_620;
	colontmpD__3 = getClockStr__options_u651();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T62_[11] = colontmpD__3;
	T62_[12] = TM__5fUAZGW8WPeit3fZaQyNXA_621;
	T62_[13] = code_1;
	T62_[14] = TM__5fUAZGW8WPeit3fZaQyNXA_622;
	T62_[15] = (*d_p0).modDeprecationMsg;
	T62_[16] = TM__5fUAZGW8WPeit3fZaQyNXA_624;
	colontmpD__4 = relLink__docgen_u13289((*(*d_p0).conf).outDir, (*d_p0).Sup.destFile, TM__5fUAZGW8WPeit3fZaQyNXA_626);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T62_[17] = colontmpD__4;
	T62_[18] = TM__5fUAZGW8WPeit3fZaQyNXA_628;
	T62_[19] = groupsection_1;
	T62_[20] = TM__5fUAZGW8WPeit3fZaQyNXA_629;
	T62_[21] = seeSrc_1;
	T63_.len = 0; T63_.p = NIM_NIL;
	T63_ = nsuFormatOpenArray(colontmpD_, T62_, 22);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T63_); goto LA1_;}
	eqsink___system_u2700((&content_1), T63_);
	{
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		NimStringV2 colontmpD__17;
		tyArray__pWlgt9ctxOw6ipY8HFli9aAQ T69_;
		NimStringV2 T70_;
		NimStringV2 T71_;
		if (!!((((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)4)))&63U)))!=0))) goto LA66_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__8 = getConfigVar__options_u3603((*d_p0).conf, TM__5fUAZGW8WPeit3fZaQyNXA_631, TM__5fUAZGW8WPeit3fZaQyNXA_632);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_634;
		colontmpD__9 = relLink__docgen_u13289((*(*d_p0).conf).outDir, (*d_p0).Sup.destFile, TM__5fUAZGW8WPeit3fZaQyNXA_636);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[1] = colontmpD__9;
		T69_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_638;
		colontmpD__10 = relLink__docgen_u13289((*(*d_p0).conf).outDir, (*d_p0).Sup.destFile, TM__5fUAZGW8WPeit3fZaQyNXA_640);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[3] = colontmpD__10;
		T69_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_641;
		T69_[5] = title_1;
		T69_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_642;
		T69_[7] = subtitle_1;
		T69_[8] = TM__5fUAZGW8WPeit3fZaQyNXA_643;
		T69_[9] = toc_1;
		T69_[10] = TM__5fUAZGW8WPeit3fZaQyNXA_644;
		T69_[11] = (*d_p0).modDescFinal;
		T69_[12] = TM__5fUAZGW8WPeit3fZaQyNXA_645;
		colontmpD__11 = getDateStr__options_u643();
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[13] = colontmpD__11;
		T69_[14] = TM__5fUAZGW8WPeit3fZaQyNXA_646;
		colontmpD__12 = getClockStr__options_u651();
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[15] = colontmpD__12;
		T69_[16] = TM__5fUAZGW8WPeit3fZaQyNXA_647;
		T69_[17] = content_1;
		T69_[18] = TM__5fUAZGW8WPeit3fZaQyNXA_649;
		T69_[19] = (*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)4))- 0];
		T69_[20] = TM__5fUAZGW8WPeit3fZaQyNXA_651;
		colontmpD__13 = esc__packagesZdocutilsZrstgen_u264((*d_p0).Sup.target, (*d_p0).Sup.meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)5))- 0], ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[21] = colontmpD__13;
		T69_[22] = TM__5fUAZGW8WPeit3fZaQyNXA_653;
		T69_[23] = (*d_p0).analytics;
		T69_[24] = TM__5fUAZGW8WPeit3fZaQyNXA_654;
		T69_[25] = (*d_p0).modDeprecationMsg;
		T69_[26] = TM__5fUAZGW8WPeit3fZaQyNXA_656;
		T70_.len = 0; T70_.p = NIM_NIL;
		colontmpD__14 = dollar___systemZdollars_u9(((NI)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		colontmpD__15 = dollar___systemZdollars_u9(((NI)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		colontmpD__16 = dollar___systemZdollars_u9(((NI)10));
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T70_ = rawNewString(colontmpD__14.len + colontmpD__15.len + colontmpD__16.len + 2);
appendString((&T70_), colontmpD__14);
appendString((&T70_), TM__5fUAZGW8WPeit3fZaQyNXA_658);
appendString((&T70_), colontmpD__15);
appendString((&T70_), TM__5fUAZGW8WPeit3fZaQyNXA_659);
appendString((&T70_), colontmpD__16);
		colontmpD__17 = T70_;
		T69_[27] = colontmpD__17;
		T71_.len = 0; T71_.p = NIM_NIL;
		T71_ = nsuFormatOpenArray(colontmpD__8, T69_, 28);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T71_); goto LA68_;}
		eqsink___system_u2700((&code_1), T71_);
		{
			LA68_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA64_;
LA66_: ;
	{
		eqsink___system_u2700((&code_1), content_1);
		eqwasMoved___system_u2688((&content_1));
	}
LA64_: ;
	result = code_1;
	eqwasMoved___system_u2688((&code_1));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(seeSrc_1);
		eqdestroy___system_u2691(groupsection_1);
		eqdestroy___system_u2691(subtitle_1);
		eqdestroy___system_u2691(toc_1);
		eqdestroy___system_u2691(title_1);
		eqdestroy___system_u2691(content_1);
		eqdestroy___system_u2691(code_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, updateOutfile__docgen_u13384)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NimStringV2 outfile_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*d_p0).module == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = (((*(*d_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0);
LA4_: ;
		if (!T3_) goto LA5_;
		{
			NIM_BOOL T9_;
			NimStringV2 T12_;
			T9_ = (NIM_BOOL)0;
			T9_ = isEmpty__options_u3633((*(*d_p0).conf).outFile);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA10_;
			T12_.len = 0; T12_.p = NIM_NIL;
			T12_ = relativeTo__pathutils_u196(outfile_p1, (*(*d_p0).conf).outDir, 47);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T12_); goto BeforeRet_;}
			eqsink___system_u2700((&(*(*d_p0).conf).outFile), T12_);
			{
				NIM_BOOL T15_;
				NimStringV2 colontmpD_;
				tyTuple__UV3llMMYFckfui8YMBuUZA colontmpD__2;
				T15_ = (NIM_BOOL)0;
				T15_ = nosisAbsolute((*(*d_p0).conf).outFile);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T15_) goto LA16_;
				nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
				nossplitPath((*(*d_p0).conf).outFile, (&colontmpD__2));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				colontmpD_ = eqdup___system_u2697(colontmpD__2.Field1);
				eqsink___system_u2700((&(*(*d_p0).conf).outFile), colontmpD_);
				eqdestroy___stdZprivateZospaths2_u306((&colontmpD__2));
			}
LA16_: ;
		}
LA10_: ;
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeOutput__docgen_u13398)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NIM_BOOL useWarning_p1, NIM_BOOL groupedToc_p2) {
	NimStringV2 content_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	content_1.len = 0; content_1.p = NIM_NIL;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T7_;
		if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)30)))&63U)))!=0)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = indexFile__docgen_u13371(d_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = relativeTo__pathutils_u196(colontmpD_, (*(*d_p0).conf).outDir, 47);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA6_;}
		eqsink___system_u2700((&(*(*d_p0).conf).outFile), T7_);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(content_1);
		goto BeforeRet_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	runAllExamples__docgen_u3690(d_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	content_1 = genOutFile__docgen_u13298(d_p0, groupedToc_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA12_;
		write__stdZsyncio_u254(stdout, content_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
LA12_: ;
	{
		NimStringV2 dir_1;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__2;
		dir_1.len = 0; dir_1.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		splitFile__pathutils_u39((*d_p0).Sup.destFile, (&colontmpD__2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		dir_1 = colontmpD__2.Field0;
		eqwasMoved___system_u2688((&colontmpD__2.Field0));
		noscreateDir(dir_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		updateOutfile__docgen_u13384(d_p0, (*d_p0).Sup.destFile);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		writeFile__stdZsyncio_u532((*d_p0).Sup.destFile, content_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		if (NIM_UNLIKELY(*nimErr_)) {
			LA16_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 395251200)) {
				tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD__3;
				tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmpD__4;
				tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA T20_;
				*nimErr_ = NIM_FALSE;
				colontmpD__3 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
				colontmpD__4 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
				T20_ = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
				{
					if (!useWarning_p1) goto LA23_;
					colontmpD__3 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)20);
					T20_ = colontmpD__3;
				}
				goto LA21_;
LA23_: ;
				{
					colontmpD__4 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4);
					T20_ = colontmpD__4;
				}
LA21_: ;
				liMessage__msgs_u1227((*d_p0).conf, unknownLineInfo__lineinfos_u364, T20_, (*d_p0).Sup.destFile, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__5fUAZGW8WPeit3fZaQyNXA_660), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				popCurrentException();
				LA18_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			NimStringV2 nimr_1;
			NimStringV2 colontmpD__5;
			NimStringV2 T31_;
			NimStringV2 T32_;
			if (!!((*d_p0).wroteSupportFiles)) goto LA28_;
			nimr_1.len = 0; nimr_1.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T31_.len = 0; T31_.p = NIM_NIL;
			T31_ = getPrefixDir__options_u3645((*d_p0).conf);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T31_); goto LA30_;}
			colontmpD__5 = T31_;
			T32_.len = 0; T32_.p = NIM_NIL;
			T32_ = dollar___options_u4029(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T32_); goto LA30_;}
			nimr_1 = T32_;
			switch ((*d_p0).Sup.target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				NimStringV2 colontmpD__6;
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2 T35_;
				NimStringV2 T36_;
				NimStringV2 T37_;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				T35_.len = 0; T35_.p = NIM_NIL;
				T35_ = interp__nimpaths_u27(TM__5fUAZGW8WPeit3fZaQyNXA_662, nimr_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T35_); goto LA34_;}
				colontmpD__6 = T35_;
				T36_.len = 0; T36_.p = NIM_NIL;
				T36_ = dollar___options_u4029((*(*d_p0).conf).outDir);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T36_); goto LA34_;}
				colontmpD__7 = T36_;
				T37_.len = 0; T37_.p = NIM_NIL;
				T37_ = slash___stdZprivateZospaths2_u91(colontmpD__7, TM__5fUAZGW8WPeit3fZaQyNXA_664);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T37_); goto LA34_;}
				colontmpD__8 = T37_;
				noscopyFile(colontmpD__6, colontmpD__8, 2, ((NI)16384));
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				{
					LA34_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
					eqdestroy___system_u2691(colontmpD__6);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				NimStringV2 colontmpD__9;
				NimStringV2 colontmpD__10;
				NimStringV2 colontmpD__11;
				NimStringV2 T42_;
				NimStringV2 T43_;
				NimStringV2 T44_;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				T42_.len = 0; T42_.p = NIM_NIL;
				T42_ = interp__nimpaths_u27(TM__5fUAZGW8WPeit3fZaQyNXA_666, nimr_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T42_); goto LA41_;}
				colontmpD__9 = T42_;
				T43_.len = 0; T43_.p = NIM_NIL;
				T43_ = dollar___options_u4029((*(*d_p0).conf).outDir);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T43_); goto LA41_;}
				colontmpD__10 = T43_;
				T44_.len = 0; T44_.p = NIM_NIL;
				T44_ = slash___stdZprivateZospaths2_u91(colontmpD__10, TM__5fUAZGW8WPeit3fZaQyNXA_668);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T44_); goto LA41_;}
				colontmpD__11 = T44_;
				noscopyFile(colontmpD__9, colontmpD__11, 2, ((NI)16384));
				if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
				{
					LA41_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(colontmpD__10);
					eqdestroy___system_u2691(colontmpD__9);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			}
			break;
			default: __builtin_unreachable();
			}
			{
				NimStringV2 docHackJs2_1;
				NimStringV2 colontmpD__12;
				NimStringV2 colontmpD__13;
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				NimStringV2 T52_;
				NimStringV2 T53_;
				NimStringV2 T54_;
				NimStringV2 T55_;
				NimStringV2 T56_;
				if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)29)))&63U)))!=0)) goto LA49_;
				docHackJs2_1.len = 0; docHackJs2_1.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				T52_.len = 0; T52_.p = NIM_NIL;
				T52_ = nosgetAppFilename();
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T52_); goto LA51_;}
				colontmpD__12 = T52_;
				T53_.len = 0; T53_.p = NIM_NIL;
				T53_ = getDocHacksJs__nimpaths_u94(nimr_1, colontmpD__12, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T53_); goto LA51_;}
				docHackJs2_1 = T53_;
				T54_.len = 0; T54_.p = NIM_NIL;
				T54_ = dollar___options_u4029((*(*d_p0).conf).outDir);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T54_); goto LA51_;}
				colontmpD__13 = T54_;
				T55_.len = 0; T55_.p = NIM_NIL;
				T55_ = noslastPathPart(docHackJs2_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T55_); goto LA51_;}
				colontmpD__14 = T55_;
				T56_.len = 0; T56_.p = NIM_NIL;
				T56_ = slash___stdZprivateZospaths2_u91(colontmpD__13, colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T56_); goto LA51_;}
				colontmpD__15 = T56_;
				noscopyFile(docHackJs2_1, colontmpD__15, 2, ((NI)16384));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				{
					LA51_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(colontmpD__13);
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(docHackJs2_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			}
LA49_: ;
			(*d_p0).wroteSupportFiles = NIM_TRUE;
			{
				LA30_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(nimr_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		}
LA28_: ;
		{
			LA15_:;
		}
		{
			eqdestroy___pathutils_u73((&colontmpD__2));
			eqdestroy___system_u2691(dir_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(content_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateIndex__docgen_u13377)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 dest_1;
		if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)29)))&63U)))!=0)) goto LA3_;
		dest_1.len = 0; dest_1.p = NIM_NIL;
		dest_1 = indexFile__docgen_u13371(d_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		writeIndexFile__packagesZdocutilsZrstgen_u211(&d_p0->Sup, dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(dest_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, writeLine__msgs_u470)(FILE* f_p0, NimStringV2* x_p1, NI x_p1Len_0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2* i_1;
		NI i_2;
		i_1 = (NimStringV2*)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < x_p1Len_0)) goto LA3;
				i_1 = (&x_p1[i_2]);
				write__stdZsyncio_u254(f_p0, (*i_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	write__stdZsyncio_u254(f_p0, TM__5fUAZGW8WPeit3fZaQyNXA_678);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeOutputJson__docgen_u13431)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, NIM_BOOL useWarning_p1) {
	NimStringV2 modDesc_1;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* content_1;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
	NimStringV2 colontmpD__2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__3;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__4;
	tyArray__GPOoWfHUB3hkY9cTO9a64aBQ T5_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	modDesc_1.len = 0; modDesc_1.p = NIM_NIL;
	content_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	runAllExamples__docgen_u3690(d_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	modDesc_1 = TM__5fUAZGW8WPeit3fZaQyNXA_669;
	{
		NIM_CHAR desc_1;
		NI i_1;
		NI L_1;
		desc_1 = (NIM_CHAR)0;
		i_1 = ((NI)0);
		L_1 = (*d_p0).modDescFinal.len;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				desc_1 = (*d_p0).modDescFinal.p->data[i_1];
				nimAddCharV1((&modDesc_1), desc_1);
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	nimZeroMem((void*)T5_, sizeof(tyArray__GPOoWfHUB3hkY9cTO9a64aBQ));
	T5_[0].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_671;
	colontmpD_ = percent___pureZjson_u2158((*d_p0).Sup.filename);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_[0].Field1 = colontmpD_;
	T5_[1].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_673;
	colontmpD__2 = getPackageName__options_u3730((*d_p0).conf, (*d_p0).Sup.filename);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = percent___pureZjson_u2158(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_[1].Field1 = colontmpD__3;
	T5_[2].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_675;
	colontmpD__4 = percent___pureZjson_u2158(modDesc_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_[2].Field1 = colontmpD__4;
	T5_[3].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_677;
	T5_[3].Field1 = (*d_p0).jEntriesFinal;
	content_1 = percent___pureZjson_u2187(T5_, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD__5;
		tyArray__YgExxhfgKcesA5EOUj1MOA T11_;
		if (!(((*(*d_p0).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA8_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__5 = dollar___pureZjson_u4831(content_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T11_[0] = colontmpD__5;
		writeLine__msgs_u470(stdout, T11_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			LA10_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA6_;
LA8_: ;
	{
		NimStringV2 dir_1;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__6;
		FILE* f_1;
		dir_1.len = 0; dir_1.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__6), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile((*d_p0).Sup.destFile, (&colontmpD__6));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		dir_1 = colontmpD__6.Field0;
		eqwasMoved___system_u2688((&colontmpD__6.Field0));
		noscreateDir(dir_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		f_1 = 0;
		{
			NIM_BOOL T18_;
			NimStringV2 colontmpD__7;
			T18_ = (NIM_BOOL)0;
			T18_ = open__stdZsyncio_u412(&f_1, (*d_p0).Sup.destFile, ((tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg)1), ((NI)-1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			if (!T18_) goto LA19_;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__7 = dollar___pureZjson_u4831(content_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			write__stdZsyncio_u254(f_1, colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			close__stdZsyncio_u268(f_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			updateOutfile__docgen_u13384(d_p0, (*d_p0).Sup.destFile);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			{
				LA21_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		}
		goto LA16_;
LA19_: ;
		{
			NimStringV2 colontmpD__8;
			tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T26_;
			NimStringV2 T27_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T26_ = newLineInfo__msgs_u436((*d_p0).conf, (*d_p0).Sup.filename, ((NI)-1), ((NI)-1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			T27_.len = 0; T27_.p = NIM_NIL;
			T27_ = rawNewString((*d_p0).Sup.destFile.len + 34);
appendString((&T27_), TM__5fUAZGW8WPeit3fZaQyNXA_680);
appendString((&T27_), (*d_p0).Sup.destFile);
appendString((&T27_), TM__5fUAZGW8WPeit3fZaQyNXA_682);
			colontmpD__8 = T27_;
			liMessage__msgs_u1227((*d_p0).conf, T26_, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85), colontmpD__8, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__5fUAZGW8WPeit3fZaQyNXA_683), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			{
				LA25_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__8);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		}
LA16_: ;
		{
			LA15_:;
		}
		{
			eqdestroy___pureZos_u200((&colontmpD__6));
			eqdestroy___system_u2691(dir_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pureZjson_u324(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___pureZjson_u324(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(content_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(modDesc_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__docgen_u13475)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 T5_;
		if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)38)))&63U)))!=0)) goto LA3_;
		T5_.len = 0; T5_.p = NIM_NIL;
		T5_ = slash___pathutils_u135((*conf_p0).outDir, (*conf_p0).outFile);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T5_); goto BeforeRet_;}
		eqsink___system_u2700((&(*conf_p0).outDir), T5_);
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandDoc__docgen_u13481)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast_1;
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ast_1 = NIM_NIL;
	d_1 = NIM_NIL;
	handleDocOutputOptions__docgen_u13475(conf_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ast_1 = parseFile__syntaxes_u235((*conf_p1).projectMainIdx, cache_p0, conf_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(ast_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		eqdestroy___docgen_u3466(d_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ast_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	d_1 = newDocumentor__docgen_u1928((*conf_p1).projectFull, cache_p0, conf_p1, TM__5fUAZGW8WPeit3fZaQyNXA_684, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), NIM_FALSE, NIM_TRUE, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	generateDoc__docgen_u9898(d_1, ast_1, ast_1, conf_p1, ((tyEnum_DocFlags__qzlkq9cdCcOd9bpeWtpJO59aA)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	finishGenerateDoc__docgen_u10030(&d_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	writeOutput__docgen_u13398(d_1, NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	generateIndex__docgen_u13377(d_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___docgen_u3466(d_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ast_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandBuildIndex__docgen_u13609)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 dir_p1, NimStringV2 outFile_p2) {
	NimStringV2 content_1;
	NimStringV2 outFile_2;
	NimStringV2 filename_1;
	NimStringV2 code_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	NimStringV2 colontmpD__9;
	tyArray__TTqeMuXKmfkD8gA7Zp8opA T12_;
	NimStringV2 T13_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	content_1.len = 0; content_1.p = NIM_NIL;
	outFile_2.len = 0; outFile_2.p = NIM_NIL;
	filename_1.len = 0; filename_1.p = NIM_NIL;
	code_1.len = 0; code_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
	colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
	{
		if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)30)))&63U)))!=0)) goto LA4_;
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(code_1);
		eqdestroy___system_u2691(filename_1);
		eqdestroy___system_u2691(outFile_2);
		eqdestroy___system_u2691(content_1);
		goto BeforeRet_;
	}
LA4_: ;
	content_1 = mergeIndexes__packagesZdocutilsZrstgen_u3543(dir_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&outFile_2), outFile_p2);
	{
		NIM_BOOL T8_;
		NimStringV2 T11_;
		T8_ = (NIM_BOOL)0;
		T8_ = isEmpty__options_u3633(outFile_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T8_) goto LA9_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = noschangeFileExt(TM__5fUAZGW8WPeit3fZaQyNXA_685, TM__5fUAZGW8WPeit3fZaQyNXA_686);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA1_;}
		eqsink___system_u2700((&outFile_2), T11_);
	}
LA9_: ;
	filename_1 = getOutFile__options_u3612(conf_p0, outFile_2, TM__5fUAZGW8WPeit3fZaQyNXA_687);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getConfigVar__options_u3603(conf_p0, TM__5fUAZGW8WPeit3fZaQyNXA_688, TM__5fUAZGW8WPeit3fZaQyNXA_689);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_[0] = TM__5fUAZGW8WPeit3fZaQyNXA_690;
	colontmpD__2 = relLink__docgen_u13289((*conf_p0).outDir, filename_1, TM__5fUAZGW8WPeit3fZaQyNXA_691);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_[1] = colontmpD__2;
	T12_[2] = TM__5fUAZGW8WPeit3fZaQyNXA_692;
	colontmpD__3 = relLink__docgen_u13289((*conf_p0).outDir, filename_1, TM__5fUAZGW8WPeit3fZaQyNXA_693);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_[3] = colontmpD__3;
	T12_[4] = TM__5fUAZGW8WPeit3fZaQyNXA_694;
	T12_[5] = TM__5fUAZGW8WPeit3fZaQyNXA_696;
	T12_[6] = TM__5fUAZGW8WPeit3fZaQyNXA_697;
	T12_[7] = TM__5fUAZGW8WPeit3fZaQyNXA_698;
	T12_[8] = TM__5fUAZGW8WPeit3fZaQyNXA_699;
	T12_[9] = TM__5fUAZGW8WPeit3fZaQyNXA_700;
	T12_[10] = TM__5fUAZGW8WPeit3fZaQyNXA_701;
	T12_[11] = TM__5fUAZGW8WPeit3fZaQyNXA_702;
	T12_[12] = TM__5fUAZGW8WPeit3fZaQyNXA_703;
	colontmpD__4 = getDateStr__options_u643();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_[13] = colontmpD__4;
	T12_[14] = TM__5fUAZGW8WPeit3fZaQyNXA_704;
	colontmpD__5 = getClockStr__options_u651();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_[15] = colontmpD__5;
	T12_[16] = TM__5fUAZGW8WPeit3fZaQyNXA_705;
	T12_[17] = content_1;
	T12_[18] = TM__5fUAZGW8WPeit3fZaQyNXA_706;
	T12_[19] = TM__5fUAZGW8WPeit3fZaQyNXA_707;
	T12_[20] = TM__5fUAZGW8WPeit3fZaQyNXA_708;
	T12_[21] = TM__5fUAZGW8WPeit3fZaQyNXA_709;
	T12_[22] = TM__5fUAZGW8WPeit3fZaQyNXA_710;
	T12_[23] = TM__5fUAZGW8WPeit3fZaQyNXA_711;
	T12_[24] = TM__5fUAZGW8WPeit3fZaQyNXA_712;
	T13_.len = 0; T13_.p = NIM_NIL;
	colontmpD__6 = dollar___systemZdollars_u9(((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__7 = dollar___systemZdollars_u9(((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__8 = dollar___systemZdollars_u9(((NI)10));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_ = rawNewString(colontmpD__6.len + colontmpD__7.len + colontmpD__8.len + 2);
appendString((&T13_), colontmpD__6);
appendString((&T13_), TM__5fUAZGW8WPeit3fZaQyNXA_713);
appendString((&T13_), colontmpD__7);
appendString((&T13_), TM__5fUAZGW8WPeit3fZaQyNXA_714);
appendString((&T13_), colontmpD__8);
	colontmpD__9 = T13_;
	T12_[25] = colontmpD__9;
	code_1 = nsuFormatOpenArray(colontmpD_, T12_, 26);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	writeFile__stdZsyncio_u532(filename_1, code_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA14_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 395251200)) {
			*nimErr_ = NIM_FALSE;
			liMessage__msgs_u1227(conf_p0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), filename_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__5fUAZGW8WPeit3fZaQyNXA_715), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			popCurrentException();
			LA16_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(code_1);
		eqdestroy___system_u2691(filename_1);
		eqdestroy___system_u2691(outFile_2);
		eqdestroy___system_u2691(content_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u2134)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* dest_p0, tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___docgen_u2125((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandRstAux__docgen_u13490)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, NimStringV2 filename_p2, NimStringV2 outExt_p3, NIM_BOOL preferMarkdown_p4) {
	NimStringV2 filen_1;
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_1;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* rst_1;
	NimStringV2 colontmpD_;
	NimStringV2 T4_;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* T5_;
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ T6_;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* blitTmp_1;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	filen_1.len = 0; filen_1.p = NIM_NIL;
	d_1 = NIM_NIL;
	filen_1 = nosaddFileExt(filename_p2, TM__5fUAZGW8WPeit3fZaQyNXA_717);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	d_1 = newDocumentor__docgen_u1928(filen_1, cache_p0, conf_p1, outExt_p3, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), NIM_TRUE, preferMarkdown_p4, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rst_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T4_.len = 0; T4_.p = NIM_NIL;
	T4_ = readFile__stdZsyncio_u527(filen_1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T4_); goto LA3_;}
	colontmpD_ = T4_;
	T5_ = NIM_NIL;
	T5_ = parseRst__docgen_u1900(colontmpD_, ((NI)1), ((NI)0), conf_p1, (*d_1).sharedState);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrstast_u285(T5_); goto LA3_;}
	rst_1 = T5_;
	T6_.len = 0; T6_.p = NIM_NIL;
	T6_.len = 1; T6_.p = (tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content*) newSeqPayload(1, sizeof(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ), NIM_ALIGNOF(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
	T6_.p->data[0].isRst = NIM_TRUE;
	blitTmp_1 = rst_1;
	eqwasMoved___packagesZdocutilsZrstast_u282(&rst_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
	T6_.p->data[0]._isRst_1.rst = blitTmp_1;
	eqsink___docgen_u2134((&(*d_1).modDescPre), T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
	finishGenerateDoc__docgen_u10030(&d_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
	writeOutput__docgen_u13398(d_1, NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
	generateIndex__docgen_u13377(d_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
	{
		LA3_:;
	}
	{
		oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___packagesZdocutilsZrstast_u285(rst_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		*nimErr_ = oldNimErrFin3_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA2_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 4, 4171512832)) {
			*nimErr_ = NIM_FALSE;
			popCurrentException();
			LA10_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___docgen_u3466(d_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(filen_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandRst2Html__docgen_u13556)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, NIM_BOOL preferMarkdown_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	commandRstAux__docgen_u13490(cache_p0, conf_p1, (*conf_p1).projectFull, TM__5fUAZGW8WPeit3fZaQyNXA_718, preferMarkdown_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandRst2TeX__docgen_u13560)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, NIM_BOOL preferMarkdown_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	commandRstAux__docgen_u13490(cache_p0, conf_p1, (*conf_p1).projectFull, TM__5fUAZGW8WPeit3fZaQyNXA_720, preferMarkdown_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14705)(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).conf0);
		if (!T3_) goto LA4_;
		eqdestroy___options_u1751((&(*(*dest_p0).conf0)));
		nimRawDispose((*dest_p0).conf0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14772)(void* dest_p0) {
	eqdestroy___docgen_u14705((&(*((tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw*) (dest_p0)))));
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14736)(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__3Hx3nKTJ3nyE0W9cWCRi9aYw_))));
		if (!T3_) goto LA4_;
		eqdestroy___docgen_u14705((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_u13573)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4, void* ClE_0) {
	tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* colonenvP__1;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw*) ClE_0;
	T1_ = newLineInfo__msgs_u436((*colonenvP__1).conf0, (*d_p0).filename, ((NI)-1), ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	liMessage__msgs_u1227((*colonenvP__1).conf0, T1_, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85), TM__5fUAZGW8WPeit3fZaQyNXA_724, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__5fUAZGW8WPeit3fZaQyNXA_725), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw*, eqdup___docgen_u14743)(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* src_p0, NIM_BOOL cyclic_p1) {
	tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* result;
	tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, commandJson__docgen_u13564)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
	tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* colonenv__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast_1;
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_1;
	tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* colontmpD_;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* json_1;
	NimStringV2 content_1;
	tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw* T2_;
	tyProc__9bd86QnQPXw1dUoLzfDMOKg T7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenv__1 = NIM_NIL;
	ast_1 = NIM_NIL;
	d_1 = NIM_NIL;
	json_1 = NIM_NIL;
	content_1.len = 0; content_1.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw*) nimNewObj(sizeof(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw), NIM_ALIGNOF(tyObject_Env_docgendotnim_commandJson___3Hx3nKTJ3nyE0W9cWCRi9aYw));
	(*T2_).Sup.m_type = (&NTIv2__3Hx3nKTJ3nyE0W9cWCRi9aYw_);
	colonenv__1 = T2_;
	eqcopy___options_u2138(&(*colonenv__1).conf0, conf_p1);
	ast_1 = parseFile__syntaxes_u235((*(*colonenv__1).conf0).projectMainIdx, cache_p0, (*colonenv__1).conf0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(ast_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA5_;
		eqdestroy___system_u2691(content_1);
		eqdestroy___pureZjson_u324(json_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___docgen_u3466(d_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ast_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___docgen_u14736(colonenv__1);
		goto BeforeRet_;
	}
LA5_: ;
	d_1 = newDocumentor__docgen_u1928((*(*colonenv__1).conf0).projectFull, cache_p0, (*colonenv__1).conf0, TM__5fUAZGW8WPeit3fZaQyNXA_722, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), NIM_FALSE, NIM_TRUE, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___docgen_u14743(colonenv__1, NIM_TRUE);
	nimZeroMem((void*)(&T7_), sizeof(tyProc__9bd86QnQPXw1dUoLzfDMOKg));
	T7_.ClP_0 = colonanonymous___docgen_u13573; T7_.ClE_0 = colontmpD_;
	eqsink___docgen_u3501((&(*d_1).Sup.onTestSnippet), T7_);
	generateJson__docgen_u11779(d_1, ast_1, (*colonenv__1).conf0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	finishGenerateDoc__docgen_u10030(&d_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___pureZjson_u327(&json_1, (*d_1).jEntriesFinal);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	content_1 = pretty__pureZjson_u4827(json_1, ((NI)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*(*d_1).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA10_;
		write__stdZsyncio_u254(stdout, content_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA10_: ;
	{
		NimStringV2 filename_1;
		NimStringV2 dir_1;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__2;
		NimStringV2 T14_;
		filename_1.len = 0; filename_1.p = NIM_NIL;
		dir_1.len = 0; dir_1.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		filename_1 = getOutFile__options_u3612((*colonenv__1).conf0, (*(*colonenv__1).conf0).projectName, TM__5fUAZGW8WPeit3fZaQyNXA_727);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_.len = 0; T14_.p = NIM_NIL;
		T14_ = relativeTo__pathutils_u196(filename_1, (*(*colonenv__1).conf0).outDir, 47);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T14_); goto LA13_;}
		eqsink___system_u2700((&(*(*colonenv__1).conf0).outFile), T14_);
		splitFile__pathutils_u39(filename_1, (&colontmpD__2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		dir_1 = colontmpD__2.Field0;
		eqwasMoved___system_u2688((&colontmpD__2.Field0));
		noscreateDir(dir_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		writeFile__stdZsyncio_u532(filename_1, content_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		if (NIM_UNLIKELY(*nimErr_)) {
			LA15_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 395251200)) {
				*nimErr_ = NIM_FALSE;
				liMessage__msgs_u1227((*colonenv__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), filename_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__5fUAZGW8WPeit3fZaQyNXA_728), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
				popCurrentException();
				LA17_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			eqdestroy___pathutils_u73((&colontmpD__2));
			eqdestroy___system_u2691(dir_1);
			eqdestroy___system_u2691(filename_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(content_1);
		eqdestroy___pureZjson_u324(json_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___docgen_u3466(d_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ast_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___docgen_u14736(colonenv__1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandBuildIndexJson__docgen_u13661)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 dir_p1, NimStringV2 outFile_p2) {
	tyTuple__i2GOAy1W4iVZ1R13oxrTvA tmpTuple_1;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ modules_1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ symbols_1;
	tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw docs_1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ documents_1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ resultX60gensym514__1;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* body_1;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__3;
	NimStringV2 outFile_2;
	NimStringV2 filename_1;
	tyArray__RoVffB9aih5q3xLhl7ODfeQ T13_;
	NimStringV2 colontmpD__5;
	NimStringV2 T22_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__i2GOAy1W4iVZ1R13oxrTvA));
	modules_1.len = 0; modules_1.p = NIM_NIL;
	symbols_1.len = 0; symbols_1.p = NIM_NIL;
	nimZeroMem((void*)(&docs_1), sizeof(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw));
	documents_1.len = 0; documents_1.p = NIM_NIL;
	resultX60gensym514__1.len = 0; resultX60gensym514__1.p = NIM_NIL;
	body_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	outFile_2.len = 0; outFile_2.p = NIM_NIL;
	filename_1.len = 0; filename_1.p = NIM_NIL;
	readIndexDir__packagesZdocutilsZrstgen_u2311(dir_p1, (&tmpTuple_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	modules_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u5503((&tmpTuple_1.Field0));
	symbols_1 = tmpTuple_1.Field1;
	eqwasMoved___packagesZdocutilsZrstidx_u278((&tmpTuple_1.Field1));
	docs_1 = tmpTuple_1.Field2;
	eqwasMoved___packagesZdocutilsZrstgen_u2153((&tmpTuple_1.Field2));
	resultX60gensym514__1.len = 0; resultX60gensym514__1.p = (tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content*) newSeqPayload(0, sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ), NIM_ALIGNOF(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
	{
		tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* xX60gensym514__1;
		NI L_1;
		xX60gensym514__1 = (tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ*)0;
		L_1 = len__packagesZdocutilsZrstgen_u1417(docs_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NI h_1;
			NI colontmp_;
			NI T4_;
			NI res_1;
			h_1 = (NI)0;
			colontmp_ = (NI)0;
			T4_ = (docs_1.data.len-1);
			colontmp_ = T4_;
			res_1 = ((NI)0);
			{
				while (1) {
					if (!(res_1 <= colontmp_)) goto LA6;
					h_1 = ((NI) (res_1));
					{
						NIM_BOOL T9_;
						tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ colontmpD__4;
						tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ T12_;
						T9_ = (NIM_BOOL)0;
						T9_ = isFilled__pureZcollectionsZtables_u32(docs_1.data.p->data[h_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!T9_) goto LA10_;
						xX60gensym514__1 = (&docs_1.data.p->data[h_1].Field1);
						nimZeroMem((void*)(&T12_), sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
						eqdup___packagesZdocutilsZrstidx_u203((&(*xX60gensym514__1)), (&T12_));
						colontmpD__4 = T12_;
						add__packagesZdocutilsZrstgen_u1602((&resultX60gensym514__1), (&colontmpD__4));
					}
LA10_: ;
					res_1 += ((NI)1);
				} LA6: ;
			}
		}
	}
	documents_1 = resultX60gensym514__1;
	eqwasMoved___packagesZdocutilsZrstidx_u278((&resultX60gensym514__1));
	nimZeroMem((void*)T13_, sizeof(tyArray__RoVffB9aih5q3xLhl7ODfeQ));
	T13_[0].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_730;
	colontmpD_ = percent___docgen_u13709(((documents_1).p) ? (documents_1.p->data) : NIM_NIL, documents_1.len);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_[0].Field1 = colontmpD_;
	T13_[1].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_732;
	colontmpD__2 = percent___jsgen_u8347(((modules_1).p) ? (modules_1.p->data) : NIM_NIL, modules_1.len);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_[1].Field1 = colontmpD__2;
	T13_[2].Field0 = TM__5fUAZGW8WPeit3fZaQyNXA_734;
	colontmpD__3 = percent___docgen_u13709(((symbols_1).p) ? (symbols_1.p->data) : NIM_NIL, symbols_1.len);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_[2].Field1 = colontmpD__3;
	body_1 = percent___pureZjson_u2187(T13_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&outFile_2), outFile_p2);
	{
		NIM_BOOL T16_;
		NimStringV2 T19_;
		T16_ = (NIM_BOOL)0;
		T16_ = isEmpty__options_u3633(outFile_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T16_) goto LA17_;
		T19_.len = 0; T19_.p = NIM_NIL;
		T19_ = noschangeFileExt(TM__5fUAZGW8WPeit3fZaQyNXA_735, TM__5fUAZGW8WPeit3fZaQyNXA_736);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T19_); goto LA1_;}
		eqsink___system_u2700((&outFile_2), T19_);
	}
LA17_: ;
	filename_1 = getOutFile__options_u3612(conf_p0, outFile_2, TM__5fUAZGW8WPeit3fZaQyNXA_737);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	T22_.len = 0; T22_.p = NIM_NIL;
	T22_ = dollar___pureZjson_u4831(body_1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T22_); goto LA21_;}
	colontmpD__5 = T22_;
	writeFile__stdZsyncio_u532(filename_1, colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
	{
		LA21_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__5);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA20_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 395251200)) {
			*nimErr_ = NIM_FALSE;
			liMessage__msgs_u1227(conf_p0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), filename_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__5fUAZGW8WPeit3fZaQyNXA_738), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			popCurrentException();
			LA26_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(filename_1);
		eqdestroy___system_u2691(outFile_2);
		eqdestroy___pureZjson_u324(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___pureZjson_u324(body_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___packagesZdocutilsZrstidx_u281(resultX60gensym514__1);
		eqdestroy___packagesZdocutilsZrstidx_u281(documents_1);
		eqdestroy___packagesZdocutilsZrstgen_u2156(docs_1);
		eqdestroy___packagesZdocutilsZrstidx_u281(symbols_1);
		eqdestroy___system_u5506(modules_1);
		eqdestroy___packagesZdocutilsZrstgen_u3613((&tmpTuple_1));
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14793)(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).conf0);
		if (!T3_) goto LA4_;
		eqdestroy___options_u1751((&(*(*dest_p0).conf0)));
		nimRawDispose((*dest_p0).conf0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__docgen_u14860)(void* dest_p0) {
	eqdestroy___docgen_u14793((&(*((tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg*) (dest_p0)))));
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u14824)(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__v5euAZjSQsVMJHq0GZMMZg_))));
		if (!T3_) goto LA4_;
		eqdestroy___docgen_u14793((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___docgen_u13596)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4, void* ClE_0) {
	tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* colonenvP__1;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg*) ClE_0;
	T1_ = newLineInfo__msgs_u436((*colonenvP__1).conf0, (*d_p0).filename, ((NI)-1), ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	liMessage__msgs_u1227((*colonenvP__1).conf0, T1_, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85), TM__5fUAZGW8WPeit3fZaQyNXA_741, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__5fUAZGW8WPeit3fZaQyNXA_742), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg*, eqdup___docgen_u14831)(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* src_p0, NIM_BOOL cyclic_p1) {
	tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* result;
	tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTagsItem__docgen_u12302)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nameNode_p2, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q k_p3) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	colontmpD_ = getNameEsc__docgen_u6382(d_p0, nameNode_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = rawNewString(colontmpD_.len + 1);
appendString((&T1_), colontmpD_);
appendString((&T1_), TM__5fUAZGW8WPeit3fZaQyNXA_745);
	result = T1_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, generateTags__docgen_u12308)(tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* r_p2) {
NIM_BOOL oldNimErrFin53_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	{
		NimStringV2 colontmpD_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		{
			NIM_BOOL T5_;
			NimStringV2 stripped_1;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			colontmpD_ = comment__ast_u836(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			T5_ = (NIM_BOOL)0;
			T5_ = nsuStartsWith(colontmpD_, TM__5fUAZGW8WPeit3fZaQyNXA_744);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			if (!T5_) goto LA6_;
			stripped_1.len = 0; stripped_1.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__2 = comment__ast_u836(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			colontmpD__3 = substr__system_u8664(colontmpD__2, ((NI)2));
			stripped_1 = nsuStrip(colontmpD__3, NIM_TRUE, NIM_TRUE, TM__5fUAZGW8WPeit3fZaQyNXA_212);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			prepareAdd((&(*r_p2)), stripped_1.len + 0);
appendString((&(*r_p2)), stripped_1);
			{
				LA8_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(stripped_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
LA6_: ;
		{
			LA2_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	{
		NimStringV2 colontmpD__4;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__4 = genTagsItem__docgen_u12302(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&(*r_p2)), colontmpD__4.len + 0);
appendString((&(*r_p2)), colontmpD__4);
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
		NimStringV2 colontmpD__5;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		colontmpD__5 = genTagsItem__docgen_u12302(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13));
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		prepareAdd((&(*r_p2)), colontmpD__5.len + 0);
appendString((&(*r_p2)), colontmpD__5);
		{
			LA18_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	{
		NimStringV2 colontmpD__6;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		colontmpD__6 = genTagsItem__docgen_u12302(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&(*r_p2)), colontmpD__6.len + 0);
appendString((&(*r_p2)), colontmpD__6);
		{
			LA22_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	{
		NimStringV2 colontmpD__7;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		colontmpD__7 = genTagsItem__docgen_u12302(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15));
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		prepareAdd((&(*r_p2)), colontmpD__7.len + 0);
appendString((&(*r_p2)), colontmpD__7);
		{
			LA26_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	{
		NimStringV2 colontmpD__8;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__8 = genTagsItem__docgen_u12302(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*r_p2)), colontmpD__8.len + 0);
appendString((&(*r_p2)), colontmpD__8);
		eqdestroy___system_u2691(colontmpD__8);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	{
		NimStringV2 colontmpD__9;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__9 = genTagsItem__docgen_u12302(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*r_p2)), colontmpD__9.len + 0);
appendString((&(*r_p2)), colontmpD__9);
		eqdestroy___system_u2691(colontmpD__9);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	{
		NimStringV2 colontmpD__10;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		documentRaises__docgen_u9832((*d_p0).cache, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		colontmpD__10 = genTagsItem__docgen_u12302(d_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		prepareAdd((&(*r_p2)), colontmpD__10.len + 0);
appendString((&(*r_p2)), colontmpD__10);
		{
			LA32_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__10);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA38;
					i_1 = i_2;
					{
						NimStringV2 colontmpD__11;
						if (!!(((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125)))) goto LA41_;
						colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
						colontmpD__11 = genTagsItem__docgen_u12302(d_p0, (*n_p1)._kind_6.sons.p->data[i_1], (*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) + (NI)((*n_p1).kind - ((NI)98))));
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						prepareAdd((&(*r_p2)), colontmpD__11.len + 0);
appendString((&(*r_p2)), colontmpD__11);
						eqdestroy___system_u2691(colontmpD__11);
					}
LA41_: ;
					i_2 += ((NI)1);
				} LA38: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115):
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_4 = ((NI)0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA46;
					i_3 = i_4;
					generateTags__docgen_u12308(d_p0, (*n_p1)._kind_6.sons.p->data[i_3], r_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_4 += ((NI)1);
				} LA46: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)93):
	{
		{
			NIM_BOOL T50_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__12;
			T50_ = (NIM_BOOL)0;
			T50_ = checkForFalse__docgen_u9720((*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T50_)) goto LA51_;
			colontmpD__12 = NIM_NIL;
			colontmpD__12 = lastSon__ast_u5208((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			generateTags__docgen_u12308(d_p0, colontmpD__12, r_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			{
				LA53_:;
			}
			{
				oldNimErrFin53_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin53_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA51_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandTags__docgen_u13587)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
	tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* colonenv__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast_1;
	tyObject_TDocumentor__GoTm9bL1y89aFdwPpcNTadzQ* d_1;
	tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* colontmpD_;
	NimStringV2 content_1;
	tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg* T2_;
	tyProc__9bd86QnQPXw1dUoLzfDMOKg T7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenv__1 = NIM_NIL;
	ast_1 = NIM_NIL;
	d_1 = NIM_NIL;
	content_1.len = 0; content_1.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg*) nimNewObj(sizeof(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg), NIM_ALIGNOF(tyObject_Env_docgendotnim_commandTags___v5euAZjSQsVMJHq0GZMMZg));
	(*T2_).Sup.m_type = (&NTIv2__v5euAZjSQsVMJHq0GZMMZg_);
	colonenv__1 = T2_;
	eqcopy___options_u2138(&(*colonenv__1).conf0, conf_p1);
	ast_1 = parseFile__syntaxes_u235((*(*colonenv__1).conf0).projectMainIdx, cache_p0, (*colonenv__1).conf0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(ast_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA5_;
		eqdestroy___system_u2691(content_1);
		eqdestroy___docgen_u3466(d_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ast_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___docgen_u14824(colonenv__1);
		goto BeforeRet_;
	}
LA5_: ;
	d_1 = newDocumentor__docgen_u1928((*(*colonenv__1).conf0).projectFull, cache_p0, (*colonenv__1).conf0, TM__5fUAZGW8WPeit3fZaQyNXA_740, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), NIM_FALSE, NIM_TRUE, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___docgen_u14831(colonenv__1, NIM_TRUE);
	nimZeroMem((void*)(&T7_), sizeof(tyProc__9bd86QnQPXw1dUoLzfDMOKg));
	T7_.ClP_0 = colonanonymous___docgen_u13596; T7_.ClE_0 = colontmpD_;
	eqsink___docgen_u3501((&(*d_1).Sup.onTestSnippet), T7_);
	content_1 = TM__5fUAZGW8WPeit3fZaQyNXA_743;
	generateTags__docgen_u12308(d_1, ast_1, (&content_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*(*d_1).conf).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA10_;
		write__stdZsyncio_u254(stdout, content_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA10_: ;
	{
		NimStringV2 filename_1;
		NimStringV2 dir_1;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__2;
		NimStringV2 T14_;
		filename_1.len = 0; filename_1.p = NIM_NIL;
		dir_1.len = 0; dir_1.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		filename_1 = getOutFile__options_u3612((*colonenv__1).conf0, (*(*colonenv__1).conf0).projectName, TM__5fUAZGW8WPeit3fZaQyNXA_747);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_.len = 0; T14_.p = NIM_NIL;
		T14_ = relativeTo__pathutils_u196(filename_1, (*(*colonenv__1).conf0).outDir, 47);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T14_); goto LA13_;}
		eqsink___system_u2700((&(*(*colonenv__1).conf0).outFile), T14_);
		splitFile__pathutils_u39(filename_1, (&colontmpD__2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		dir_1 = colontmpD__2.Field0;
		eqwasMoved___system_u2688((&colontmpD__2.Field0));
		noscreateDir(dir_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		writeFile__stdZsyncio_u532(filename_1, content_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		if (NIM_UNLIKELY(*nimErr_)) {
			LA15_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 395251200)) {
				*nimErr_ = NIM_FALSE;
				liMessage__msgs_u1227((*colonenv__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), filename_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__5fUAZGW8WPeit3fZaQyNXA_748), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
				popCurrentException();
				LA17_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			eqdestroy___pathutils_u73((&colontmpD__2));
			eqdestroy___system_u2691(dir_1);
			eqdestroy___system_u2691(filename_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(content_1);
		eqdestroy___docgen_u3466(d_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ast_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___docgen_u14824(colonenv__1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
