/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw tySequence__AE2UIxl7EbPzzBnmYsjIcw;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content;
typedef struct tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ;
typedef struct tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q tySequence__tsHRsYLyvTCPLlGRExqi7Q;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA tySequence__lAikaRQvUF0uwNAz0U4FFA;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content tySequence__lAikaRQvUF0uwNAz0U4FFA_Content;
typedef struct tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A tySequence__4zAALtm0xUbRlYWQ2V8K7A;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA tySequence__9bffTLF0HkxjFCzZL8og4GA;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content tySequence__9bffTLF0HkxjFCzZL8og4GA_Content;
typedef struct tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content;
typedef struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content tySequence__E8pi9b5QNahsURYzXMjh3qw_Content;
typedef struct tyObject_Table__g77QNejuRRKraNk8K2YkoA tyObject_Table__g77QNejuRRKraNk8K2YkoA;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w tySequence__3B6hFqG0Do0FxDvnNucL7w;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content tySequence__3B6hFqG0Do0FxDvnNucL7w_Content;
typedef struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg tyObject_Table__toCaB3NxiVHPRVLgcez0Xg;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyTuple__pod1b7gjdRZb0inVGup1nQ tyTuple__pod1b7gjdRZb0inVGup1nQ;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA;
typedef struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w;
typedef struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg;
typedef struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyTuple__N4J9cV4JZGem3ljqqj5rT0Q;
typedef struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg;
typedef struct tyTuple__DTRsWi2kgTewbhN2TT5mbA tyTuple__DTRsWi2kgTewbhN2TT5mbA;
typedef struct tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ;
typedef struct tyTuple__WX5tJaowKpyuKe6hGR9aIXQ tyTuple__WX5tJaowKpyuKe6hGR9aIXQ;
typedef struct tySequence__SxRJJ9bayPyj0RYzIZTiohA tySequence__SxRJJ9bayPyj0RYzIZTiohA;
typedef struct tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyTuple__09aD69az7aYn14Gt61AHvLIA tyTuple__09aD69az7aYn14Gt61AHvLIA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
typedef struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ;
typedef struct tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag;
typedef struct tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ;
typedef struct tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ tySequence__7OXYQ6bHRkhJpRaiS7kiwQ;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content;
typedef struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ tySequence__KYLoGmc5aaHsSDjEH1FTxQ;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg;
typedef struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw {
  NI len; tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__uJvLVbod8mnHGzJkQj89bWg[38];
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q {
  NI len; tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content* p;
};
struct tySequence__lAikaRQvUF0uwNAz0U4FFA {
  NI len; tySequence__lAikaRQvUF0uwNAz0U4FFA_Content* p;
};
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__Yik7hgYZHhPeLJ5RsXTPqg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p2);
typedef NU32 tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__JIyBW5s9ba7hfYBnWxDVvgg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p3);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__iXlRd9cBAN0CQpA5dkyhRvw) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__7FLV9alRQFu6LOhr9bksExQQ) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, void* ClE_0);
void* ClE_0;
} tyProc__0qHBYUhlP28E2DV7mVNNAg;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__1nD4dBuhjTAOzMZJo9bmgog) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
typedef NU32 tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__209aOewTLBT6nbWmyvOQFiw) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nOrig_p2, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p3, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p4, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p5);
typedef N_NIMCALL_PTR(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, tyProc__D9aXgBooMpgLrPTmha6q31w) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* prev_p2);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, void* ClE_0);
void* ClE_0;
} tyProc__GbPSPD9bjvt0RIJnnVTczJA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fn_p1, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, void* ClE_0);
void* ClE_0;
} tyProc__iDJMP540ifFac3zJ49bj2cA;
typedef struct {
N_NIMCALL_PTR(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, void* ClE_0);
void* ClE_0;
} tyProc__gq9a76bauTeymgreaiTI9cmg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p2, void* ClE_0);
void* ClE_0;
} tyProc__Gji0NjiFFDU49aJiF3QZF8A;
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A {
  NI len; tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content* p;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__UAj9bGJLVN9cwAsTcRZFyWmg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dc_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p4, NI col_p5);
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
struct tySequence__9bffTLF0HkxjFCzZL8og4GA {
  NI len; tySequence__9bffTLF0HkxjFCzZL8og4GA_Content* p;
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  NI len; tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content* p;
};
struct tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ {
	tySequence__Bis5AbpONWcIRrPyPJS8Yw data;
	NI counter;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  NI len; tySequence__E8pi9b5QNahsURYzXMjh3qw_Content* p;
};
struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw {
	tySequence__E8pi9b5QNahsURYzXMjh3qw data;
	NI counter;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w {
  NI len; tySequence__3B6hFqG0Do0FxDvnNucL7w_Content* p;
};
struct tyObject_Table__g77QNejuRRKraNk8K2YkoA {
	tySequence__3B6hFqG0Do0FxDvnNucL7w data;
	NI counter;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  NI len; tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content* p;
};
struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg {
	tySequence__QqvaCqCpEE1QmQZbcZLi5A data;
	NI counter;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__bvRec9bo79ajqrJt3Bkg9c33w) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw k_p2);
struct tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* enforceVoidContext;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* voidType;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* currentScope;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* moduleScope;
	tySequence__AE2UIxl7EbPzzBnmYsjIcw imports;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* topLevelScope;
	tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* p;
	tyArray__uJvLVbod8mnHGzJkQj89bWg intTypeCache;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* nilTypeCache;
	tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg* matchedConcept;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA friendModules;
	NI instCounter;
	NI* templInstCounter;
	NI inGenericContext;
	NI inStaticContext;
	NI inUnrolledContext;
	NI compilesContextId;
	NI compilesContextIdGenerator;
	NI inGenericInst;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA converters;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA patterns;
	tySequence__tsHRsYLyvTCPLlGRExqi7Q optionStack;
	tySequence__lAikaRQvUF0uwNAz0U4FFA libs;
	tyProc__Yik7hgYZHhPeLJ5RsXTPqg semConstExpr;
	tyProc__JIyBW5s9ba7hfYBnWxDVvgg semExpr;
	tyProc__JIyBW5s9ba7hfYBnWxDVvgg semExprWithType;
	tyProc__iXlRd9cBAN0CQpA5dkyhRvw semTryExpr;
	tyProc__Yik7hgYZHhPeLJ5RsXTPqg semTryConstExpr;
	tyProc__7FLV9alRQFu6LOhr9bksExQQ computeRequiresInit;
	tyProc__0qHBYUhlP28E2DV7mVNNAg hasUnresolvedArgs;
	tyProc__iXlRd9cBAN0CQpA5dkyhRvw semOperand;
	tyProc__1nD4dBuhjTAOzMZJo9bmgog semConstBoolExpr;
	tyProc__209aOewTLBT6nbWmyvOQFiw semOverloadedCall;
	tyProc__D9aXgBooMpgLrPTmha6q31w semTypeNode;
	tyProc__GbPSPD9bjvt0RIJnnVTczJA semInferredLambda;
	tyProc__iDJMP540ifFac3zJ49bj2cA semGenerateInstance;
	tyProc__gq9a76bauTeymgreaiTI9cmg instantiateOnlyProcType;
	tyProc__Gji0NjiFFDU49aJiF3QZF8A fitDefaultNode;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA includedFiles;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg pureEnumFields;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg userPragmas;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* evalContext;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA unknownIdents;
	tySequence__4zAALtm0xUbRlYWQ2V8K7A generics;
	NI topStmts;
	NI lastGenericIdx;
	NI inParallelStmt;
	tyProc__UAj9bGJLVN9cwAsTcRZFyWmg instTypeBoundOp;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg signatures;
	NimStringV2 recursiveDep;
	NIM_BOOL suggestionsMade;
	NIM_BOOL isAmbiguous;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	NI inTypeContext;
	NI inConceptDecl;
	tySequence__9bffTLF0HkxjFCzZL8og4GA unusedImports;
	tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ exportIndirections;
	tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw importModuleMap;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastTLineInfo;
	tyObject_Table__g77QNejuRRKraNk8K2YkoA sideEffects;
	NI inUncheckedAssignSection;
	tyObject_Table__toCaB3NxiVHPRVLgcez0Xg importModuleLookup;
	tySequence__9ahcSjIErJohSBBFLwuF56Q skipTypes;
	NI inTypeofContext;
	tyProc__bvRec9bo79ajqrJt3Bkg9c33w semAsgnOpr;
};
struct tyTuple__pod1b7gjdRZb0inVGup1nQ {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	NIM_BOOL Field1;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
struct tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA {
	RootObj Sup;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* realModule0;
	tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c1;
};
struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg {
	NI len;
	NI cap;
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q* d;
};
struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg {
	NI len;
	NI cap;
	tyTuple__DTRsWi2kgTewbhN2TT5mbA* d;
};
struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w {
	tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg traceStack;
	tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg toFree;
	NI freed;
	NI touched;
	NI edges;
	NI rcSum;
	NIM_BOOL keepThreshold;
};
struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q {
	void** Field0;
	TNimTypeV2* Field1;
};
struct tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ {
	RootObj Sup;
	tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c0;
	tyTuple__pod1b7gjdRZb0inVGup1nQ ret1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n2;
};
struct tySequence__SxRJJ9bayPyj0RYzIZTiohA {
  NI len; tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content* p;
};
struct tyTuple__WX5tJaowKpyuKe6hGR9aIXQ {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	tySequence__SxRJJ9bayPyj0RYzIZTiohA Field1;
};
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef NU8 tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw[38];
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, ClP_0) (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n2_p0, void* ClE_0);
void* ClE_0;
} tyProc__Wv5nSBLQP3WX9cri6Nd9cGbg;
typedef N_CLOSURE_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, TM__NsDkQfDe2CjzDqtBRW9bqQg_17) (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n2_p0);
typedef N_CLOSURE_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, TM__NsDkQfDe2CjzDqtBRW9bqQg_18) (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n2_p0);
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef NU8 tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ defaultCC;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* dynlib;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* otherPragmas;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
};
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
struct tyTuple__09aD69az7aYn14Gt61AHvLIA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, void* ClE_0);
void* ClE_0;
} tyProc__9bhdHboBEtDk0F52fk9bOITw;
typedef N_CLOSURE_PTR(void, TM__NsDkQfDe2CjzDqtBRW9bqQg_44) (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
typedef N_CLOSURE_PTR(void, TM__NsDkQfDe2CjzDqtBRW9bqQg_45) (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
typedef N_CLOSURE_PTR(void, TM__NsDkQfDe2CjzDqtBRW9bqQg_46) (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
typedef NU8 tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ;
struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m;
	tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ mode;
union{
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA imported;
} _mode_2;
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA exceptSet;
} _mode_3;
};
};
typedef NU tyArray__KznKlIbW0OmA9ckg0NfmHVQ[8];
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
struct tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag {
	NI h;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
};
struct tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA {
	NI lastModule;
	NU32 lastLit;
	NI32 lastFile;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
struct tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ {
	tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA decoder;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw values;
	NI i;
	NI module;
};
struct tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ {
	NIM_BOOL fromRod;
	NI modIndex;
	tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti;
	tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ rodIt;
	NIM_BOOL importHidden;
};
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
	NI Field0;
	NI Field1;
};
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content { NI cap; tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content { NI cap; tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* data[SEQ_DECL_SIZE]; };
struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content { NI cap; tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* data[SEQ_DECL_SIZE]; };
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ {
  NI len; tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content* p;
};
struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA {
	NI counter;
	tySequence__7OXYQ6bHRkhJpRaiS7kiwQ data;
};
struct tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A {
	tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA topLayer;
	tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* nextLayer;
	NI previousLen;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* genericSym;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content { NI cap; tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw data[SEQ_DECL_SIZE]; };
struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content { NI cap; tyTuple__09aD69az7aYn14Gt61AHvLIA data[SEQ_DECL_SIZE]; };
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
	NI Field0;
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content { NI cap; tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE]; };
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
	NI Field0;
	NI Field1;
	NI Field2;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content { NI cap; tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE]; };
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ {
  NI len; tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content* p;
};
struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw {
	NI Field0;
	NI Field1;
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ Field2;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content { NI cap; tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw data[SEQ_DECL_SIZE]; };
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
	NI Field0;
	NI Field1;
	tySequence__qwqHTkRvwhrRyENtudHQ7g Field2;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content { NI cap; tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content { NI cap; tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw data[SEQ_DECL_SIZE]; };
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val;
};
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content { NI cap; tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg data[SEQ_DECL_SIZE]; };
struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content { NI cap; tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, someSymFromImportTable__lookups_u2381)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, NIM_BOOL* ambiguous_p2);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_u2666)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* t_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3130)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyNode__ast_u6736)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSons__ast_u6108)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, NI length_p1);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, impMod__importer_u3919)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* importStmtResult_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, myImportModule__importer_u3687)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* importStmtResult_p2);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__importer_u4123)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u4044)(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3500)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___importer_u4056)(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* dest_p0, void* env_p1);
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1);
static N_INLINE(void, add__system_u3021)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3029)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semdata_u4218)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw** dest_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(void, transformImportAs__importer_u3534)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyTuple__pod1b7gjdRZb0inVGup1nQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__importer_u4253)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u4171)(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___importer_u4183)(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* dest_p0, void* env_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___importer_u3673)(tyTuple__pod1b7gjdRZb0inVGup1nQ* dest_p0, tyTuple__pod1b7gjdRZb0inVGup1nQ src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, considerQuotedIdent__lookups_u31)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* origin_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_CLOSURE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, processPragma__importer_u3546)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n2_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, splitPragmas__importer_u1409)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyTuple__WX5tJaowKpyuKe6hGR9aIXQ* Result);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___importer_u1457)(tySequence__SxRJJ9bayPyj0RYzIZTiohA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__importer_u1431)(tySequence__SxRJJ9bayPyj0RYzIZTiohA* x_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw y_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw, whichKeyword__idents_u360)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* id_p0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___importer_u1469)(tySequence__SxRJJ9bayPyj0RYzIZTiohA* dest_p0, tySequence__SxRJJ9bayPyj0RYzIZTiohA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u1460)(tySequence__SxRJJ9bayPyj0RYzIZTiohA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___importer_u3572)(tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u1576)(tyTuple__WX5tJaowKpyuKe6hGR9aIXQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___importer_u3667)(tyTuple__pod1b7gjdRZb0inVGup1nQ* dest_p0, tyTuple__pod1b7gjdRZb0inVGup1nQ src_p1);
static N_INLINE(void, nimIncRef)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u4214)(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, checkModuleName__modulepaths_u22)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL doLocalError_p2);
N_LIB_PRIVATE N_NIMCALL(void, addImportFileDep__semdata_u4247)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, NI32 f_p1);
static N_INLINE(NI, find__importer_u3698)(tySequence__48JTohSgTy339bRxHzUD8KA a_p0, NI32 item_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u21077)(tySequence__48JTohSgTy339bRxHzUD8KA* x_p0, NI32 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*, pushOptionEntry__semdata_u2309)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, importModuleAs__importer_u2175)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* realModule_p2, NIM_BOOL importHidden_p3, NIM_BOOL trackUnusedImport_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, createModuleAlias__ast_u6311)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* newIdent_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p4);
N_LIB_PRIVATE N_NIMCALL(void, add__sempass2_u5950)(tySequence__9bffTLF0HkxjFCzZL8og4GA* x_p0, tyTuple__09aD69az7aYn14Gt61AHvLIA y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, eqdup___lineinfos_u2037)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA src_p0);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___sempass2_u2301)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0, NI key_p1, NI val_p2);
N_LIB_PRIVATE N_NIMCALL(void, addUnique__importer_u3514)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g*, mgetOrPut__importer_u2347)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg* t_p0, NI key_p1, tySequence__qwqHTkRvwhrRyENtudHQ7g val_p2);
N_LIB_PRIVATE N_NIMCALL(void, popOptionEntry__semdata_u2337)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u16111)(tySequence__48JTohSgTy339bRxHzUD8KA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getModuleName__modulepaths_u10)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToStdlib__modulegraphs_u17983)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringV2 s_p0, NimStringV2 prefix_p1);
N_LIB_PRIVATE N_CLOSURE(void, suggestMod__importer_u3748)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, void* ClE_0);
static N_INLINE(void, suggestSym__sigmatch_u6643)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** usageSym_p3, NIM_BOOL isDecl_p4, NIM_BOOL isGenericInstance_p5);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5171)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u611)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u3664)(tyTuple__pod1b7gjdRZb0inVGup1nQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u4079)(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* dest_p0);
static N_INLINE(void, addDecl__lookups_u3789)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
static N_INLINE(void, addDeclAt__lookups_u3781)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_u3253)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbols__importer_u2053)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fromMod_p1);
N_LIB_PRIVATE N_NIMCALL(void, addImport__importer_u1640)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u3006)(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* dest_p0, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u2994)(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, incl__importer_u1686)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* other_p1);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_u37)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZcollectionsZintsets_u227)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_u2846)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_u366)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZcollectionsZintsets_u45)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZcollectionsZintsets_u51)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA** dest_p0, tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u48)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u230)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZcollectionsZintsets_u236)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2997)(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__importer_u1828)(tySequence__AE2UIxl7EbPzzBnmYsjIcw* x_p0, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, loadPackedSym__modulegraphs_u10725)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, addConverter__semdata_u4291)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA conv_p1);
N_LIB_PRIVATE N_NIMCALL(void, addPattern__semdata_u4330)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA p_p1);
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumFields__importer_u87)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* etyp_p2);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initIdentIter__lookups_u135)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* ti_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* marked_p1, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_p2, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3435)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextIdentIter__lookups_u350)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* ti_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* marked_p1, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumField__importer_u79)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, afterImport__importer_u3761)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u3008)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u2997)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1);
N_LIB_PRIVATE N_NIMCALL(NI*, X5BX5D___lookups_u3355)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initRodIterAllSyms__icZic_u21632)(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ* it_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p2, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p3, NI32 module_p4, NIM_BOOL importHidden_p5);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, incl__importer_u301)(tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ* s_p0, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextRodIter__icZic_u21968)(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ* it_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3288)(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4851)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0, tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, checkMinSonsLen__semdata_u4675)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NI length_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5168)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbolsExcept__importer_u1852)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fromMod_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* exceptSet_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdup___pureZcollectionsZintsets_u233)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* src_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, readExceptSet__importer_u19)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, importSymbol__importer_u1600)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fromMod_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* importSet_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, someSym__modulegraphs_u3324)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p2);
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__lookups_u5145)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 name_p2, NimStringV2 extra_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initModuleIter__modulegraphs_u3177)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* mi_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p2, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p3);
N_LIB_PRIVATE N_NIMCALL(void, rawImportSymbol__importer_u127)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* origin_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* importSet_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
static N_INLINE(NIM_BOOL, hasPattern__ast_u7174)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
static N_INLINE(NIM_BOOL, isRoutine__ast_u7152)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextModuleIter__modulegraphs_u3222)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* mi_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1);
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_2 = { 2 | NIM_STRLIT_FLAG, "as" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_3 = {2, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_2};
N_LIB_PRIVATE TNimTypeV2 NTIv2__vsIkeqP4DxwpPFMRthoIdA_;
N_LIB_PRIVATE TNimTypeV2 NTIv2__a9cZyk8ZcjiwDkYDzj9a9cDjQ_;
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_6 = {2, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_2};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_7 = { 14 | NIM_STRLIT_FLAG, "invalid pragma" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_8 = {14, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_7};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_10 = { 63 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/importer.nim" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_11 = {14, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_7};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_13 = { 26 | NIM_STRLIT_FLAG, "invalid pragma, expected: " };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_14 = {26, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_13};
static NIM_CONST tySet_tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw TM__NsDkQfDe2CjzDqtBRW9bqQg_15 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x40}
;
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_19 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_20 = {0, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_19};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_21 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_22 = {1, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_21};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_23 = { 9 | NIM_STRLIT_FLAG, " imports " };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_24 = {9, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_23};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_25 = { 34 | NIM_STRLIT_FLAG, "module alias must be an identifier" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_26 = {34, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_25};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_28 = { 32 | NIM_STRLIT_FLAG, "module \'$1\' cannot import itself" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_29 = {32, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_28};
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_31 = {0, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_19};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_32 = { 2 | NIM_STRLIT_FLAG, "; " };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_33 = {2, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_32};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_34 = { 14 | NIM_STRLIT_FLAG, " is deprecated" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_35 = {14, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_37 = { 4 | NIM_STRLIT_FLAG, "std/" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_38 = {4, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_37};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_39 = { 7 | NIM_STRLIT_FLAG, "system/" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_40 = {7, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_39};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_41 = { 9 | NIM_STRLIT_FLAG, "packages/" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_42 = {9, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_41};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_47 = { 15 | NIM_STRLIT_FLAG, "rawImportSymbol" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_48 = {15, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_47};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_50 = { 17 | NIM_STRLIT_FLAG, "unexpected pragma" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_51 = {17, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_50};
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_53 = {0, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_19};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__NsDkQfDe2CjzDqtBRW9bqQg_54 = { 15 | NIM_STRLIT_FLAG, "importSymbol: 3" };
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_55 = {15, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_54};
static const NimStringV2 TM__NsDkQfDe2CjzDqtBRW9bqQg_57 = {15, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_47};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_9 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)124),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_12 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)125),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_16 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)265),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_27 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)240),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_30 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)305),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_36 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)309),
((NI)13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_43 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)313),
((NI)13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_49 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)62),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_52 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)134),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_56 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)150),
((NI)48)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__NsDkQfDe2CjzDqtBRW9bqQg_58 = {{63, (NimStrPayload*)&TM__NsDkQfDe2CjzDqtBRW9bqQg_10},
((NI)97),
((NI)23)}
;
extern NIM_BOOL nimInErrorMode__system_u4146;
static NIM_CONST NU32 TM__NsDkQfDe2CjzDqtBRW9bqQg_4[2] = {3701606400, 3257170432};
N_LIB_PRIVATE TNimTypeV2 NTIv2__vsIkeqP4DxwpPFMRthoIdA_ = {.destructor = (void*)rttiDestroy__importer_u4123, .size = sizeof(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA), .align = (NI16) NIM_ALIGNOF(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA), .depth = 1, .display = TM__NsDkQfDe2CjzDqtBRW9bqQg_4, .traceImpl = (void*)eqtrace___importer_u4056, .flags = 0};
static NIM_CONST NU32 TM__NsDkQfDe2CjzDqtBRW9bqQg_5[2] = {3701606400, 4134703872};
N_LIB_PRIVATE TNimTypeV2 NTIv2__a9cZyk8ZcjiwDkYDzj9a9cDjQ_ = {.destructor = (void*)rttiDestroy__importer_u4253, .size = sizeof(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ), .align = (NI16) NIM_ALIGNOF(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ), .depth = 1, .display = TM__NsDkQfDe2CjzDqtBRW9bqQg_5, .traceImpl = (void*)eqtrace___importer_u4183, .flags = 0};
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4146);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, declarePureEnumField__importer_u71)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	NIM_BOOL amb_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	amb_1 = NIM_FALSE;
	{
		colontmpD_ = someSymFromImportTable__lookups_u2381(c_p0, (*s_p1).name, (&amb_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(colontmpD_ == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA4_;
		strTableAdd__astalgo_u2666((&(*c_p0).pureEnumFields), s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3130(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___importer_u3673)(tyTuple__pod1b7gjdRZb0inVGup1nQ* dest_p0, tyTuple__pod1b7gjdRZb0inVGup1nQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)8));
	}
LA4_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	(*dest_p0).Field1 = src_p1.Field1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u3664)(tyTuple__pod1b7gjdRZb0inVGup1nQ dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3500(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u4044)(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn((*dest_p0).c1);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose((*dest_p0).c1);
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).realModule0);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3469((&(*(*dest_p0).realModule0)));
		nimRawDispose((*dest_p0).realModule0, ((NI)8));
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__importer_u4123)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___importer_u4044((&(*((tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, add__system_u3021)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2) {
	void** colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3029(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p1));
		add__system_u3021((&(*j_1).traceStack), p_1, (*((TNimTypeV2**) ((*p_1)))));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___importer_u4056)(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).c1, env_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u4171)(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).n2);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0).n2)));
		nimRawDispose((*dest_p0).n2, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).ret1.Field0);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3270((&(*(*dest_p0).ret1.Field0)));
		nimRawDispose((*dest_p0).ret1.Field0, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastCyclicDyn((*dest_p0).c0);
		if (!T13_) goto LA14_;
		nimDestroyAndDispose((*dest_p0).c0);
	}
LA14_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__importer_u4253)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___importer_u4171((&(*((tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___importer_u4183)(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).c0, env_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___importer_u1457)(tySequence__SxRJJ9bayPyj0RYzIZTiohA* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u1460)(tySequence__SxRJJ9bayPyj0RYzIZTiohA dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___importer_u1469)(tySequence__SxRJJ9bayPyj0RYzIZTiohA* dest_p0, tySequence__SxRJJ9bayPyj0RYzIZTiohA src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___importer_u1460((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, splitPragmas__importer_u1409)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyTuple__WX5tJaowKpyuKe6hGR9aIXQ* Result) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmp_;
	tySequence__SxRJJ9bayPyj0RYzIZTiohA colontmp__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
	tySequence__SxRJJ9bayPyj0RYzIZTiohA blitTmp_2;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__WX5tJaowKpyuKe6hGR9aIXQ));
	colontmp_ = NIM_NIL;
	colontmp__2.len = 0; colontmp__2.p = NIM_NIL;
	colontmp_ = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	colontmp__2.len = 0; colontmp__2.p = (tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content*) newSeqPayload(0, sizeof(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw), NIM_ALIGNOF(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw));
	blitTmp_1 = colontmp_;
	eqwasMoved___ast_u3249(&colontmp_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*Result).Field0 = blitTmp_1;
	blitTmp_2 = colontmp__2;
	eqwasMoved___importer_u1457((&colontmp__2));
	(*Result).Field1 = blitTmp_2;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)43))) goto LA4_;
		{
			NIM_BOOL T8_;
			NI T9_;
			T8_ = (NIM_BOOL)0;
			T9_ = (NI)0;
			T9_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T8_ = (T9_ == ((NI)2));
			if (!(T8_)) goto LA10_;
			T8_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90));
LA10_: ;
			if (!T8_) goto LA11_;
			eqcopy___ast_u3255(&(*Result).Field0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ni_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** colontmp__3;
				ni_1 = NIM_NIL;
				colontmp__3 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
				colontmp__3 = &(*n_p1)._kind_6.sons.p->data[((NI)1)];
				{
					NI i_1;
					NI colontmp__4;
					NI i_2;
					i_1 = (NI)0;
					colontmp__4 = (NI)0;
					colontmp__4 = safeLen__ast_u3197((*colontmp__3));
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					i_2 = ((NI)0);
					{
						while (1) {
							if (!(i_2 < colontmp__4)) goto LA17;
							i_1 = i_2;
							eqcopy___ast_u3255(&ni_1, (*(*colontmp__3))._kind_6.sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
							{
								tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T22_;
								if (!((*ni_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2))) goto LA20_;
								T22_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
								T22_ = whichKeyword__idents_u360((*ni_1)._kind_5.ident);
								if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
								add__importer_u1431((&(*Result).Field1), T22_);
							}
							goto LA18_;
LA20_: ;
							{
								liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__NsDkQfDe2CjzDqtBRW9bqQg_8, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__NsDkQfDe2CjzDqtBRW9bqQg_9), NIM_FALSE, NIM_FALSE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
							}
LA18_: ;
							i_2 += ((NI)1);
						} LA17: ;
					}
				}
				{
					LA14_:;
				}
				{
					oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(ni_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin14_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
		}
		goto LA6_;
LA11_: ;
		{
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__NsDkQfDe2CjzDqtBRW9bqQg_11, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__NsDkQfDe2CjzDqtBRW9bqQg_12), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA6_: ;
	}
	goto LA2_;
LA4_: ;
	{
		eqcopy___ast_u3255(&(*Result).Field0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NI T30_;
			tyTuple__WX5tJaowKpyuKe6hGR9aIXQ tmpTupleAsgn;
			NI T33_;
			NI T34_;
			T30_ = (NI)0;
			T30_ = safeLen__ast_u3197((*Result).Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)0) < T30_)) goto LA31_;
			nimZeroMem((void*)(&tmpTupleAsgn), sizeof(tyTuple__WX5tJaowKpyuKe6hGR9aIXQ));
			T33_ = (NI)0;
			T33_ = len__ast_u3190((*Result).Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			splitPragmas__importer_u1409(c_p0, (*(*Result).Field0)._kind_6.sons.p->data[(NI)(T33_ - ((NI)1))], (&tmpTupleAsgn));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T34_ = (NI)0;
			T34_ = len__ast_u3190((*Result).Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqsink___ast_u3261(&(*(*Result).Field0)._kind_6.sons.p->data[(NI)(T34_ - ((NI)1))], tmpTupleAsgn.Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqsink___importer_u1469((&(*Result).Field1), tmpTupleAsgn.Field1);
		}
LA31_: ;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___importer_u1460(colontmp__2);
		eqdestroy___ast_u3252(colontmp_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u1576)(tyTuple__WX5tJaowKpyuKe6hGR9aIXQ dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)8));
	}
LA4_: ;
	eqdestroy___importer_u1460(dest_p0.Field1);
}
N_LIB_PRIVATE N_CLOSURE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, processPragma__importer_u3546)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n2_p0, void* ClE_0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* colonenvP__1;
	tyTuple__WX5tJaowKpyuKe6hGR9aIXQ tmpTuple_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result2_1;
	tySequence__SxRJJ9bayPyj0RYzIZTiohA kws_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colonenvP__1 = (tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ*) ClE_0;
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__WX5tJaowKpyuKe6hGR9aIXQ));
	result2_1 = NIM_NIL;
	kws_1.len = 0; kws_1.p = NIM_NIL;
	splitPragmas__importer_u1409((*colonenvP__1).c0, n2_p0, (&tmpTuple_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result2_1 = tmpTuple_1.Field0;
	eqwasMoved___ast_u3249(&tmpTuple_1.Field0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	kws_1 = tmpTuple_1.Field1;
	eqwasMoved___importer_u1457((&tmpTuple_1.Field1));
	result = result2_1;
	eqwasMoved___ast_u3249(&result2_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw* ai_1;
		NI i_1;
		NI L_1;
		NI T3_;
		ai_1 = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw*)0;
		i_1 = ((NI)0);
		T3_ = kws_1.len;
		L_1 = T3_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA5;
				ai_1 = (&kws_1.p->data[i_1]);
				switch ((*ai_1)) {
				case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)302):
				{
					(*colonenvP__1).ret1.Field1 = NIM_TRUE;
				}
				break;
				default:
				{
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					NimStringV2 T9_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					T9_.len = 0; T9_.p = NIM_NIL;
					colontmpD_ = dollar___importer_u3572(TM__NsDkQfDe2CjzDqtBRW9bqQg_15);
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					T9_ = rawNewString(colontmpD_.len + 26);
appendString((&T9_), TM__NsDkQfDe2CjzDqtBRW9bqQg_14);
appendString((&T9_), colontmpD_);
					colontmpD__2 = T9_;
					liMessage__msgs_u1227((*(*(*colonenvP__1).c0).graph).config, (*(*colonenvP__1).n2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__NsDkQfDe2CjzDqtBRW9bqQg_16), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					{
						LA8_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				break;
				}
				i_1 += ((NI)1);
			} LA5: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___importer_u1460(kws_1);
		eqdestroy___ast_u3252(result2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___importer_u1576(tmpTuple_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___importer_u3667)(tyTuple__pod1b7gjdRZb0inVGup1nQ* dest_p0, tyTuple__pod1b7gjdRZb0inVGup1nQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1.Field0) goto LA3_;
		nimIncRef(src_p1.Field0);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3270((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)8));
	}
LA8_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	(*dest_p0).Field1 = src_p1.Field1;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3500(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u4214)(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__a9cZyk8ZcjiwDkYDzj9a9cDjQ_))));
		if (!T3_) goto LA4_;
		eqdestroy___importer_u4171((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, transformImportAs__importer_u3534)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyTuple__pod1b7gjdRZb0inVGup1nQ* Result) {
	tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* colonenv__1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmp_;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
	tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ* T2_;
	NIM_BOOL colontmp__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
	tyTuple__pod1b7gjdRZb0inVGup1nQ T3_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__pod1b7gjdRZb0inVGup1nQ));
	colonenv__1 = NIM_NIL;
	colontmp_ = NIM_NIL;
	colontmpD_ = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ*) nimNewObj(sizeof(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ), NIM_ALIGNOF(tyObject_Env_importerdotnim_transformImportAs___a9cZyk8ZcjiwDkYDzj9a9cDjQ));
	(*T2_).Sup.m_type = (&NTIv2__a9cZyk8ZcjiwDkYDzj9a9cDjQ_);
	colonenv__1 = T2_;
	eqcopy___semdata_u4218(&(*colonenv__1).c0, c_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3255(&(*colonenv__1).n2, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmp_ = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	colontmp__2 = NIM_FALSE;
	blitTmp_1 = colontmp_;
	eqwasMoved___ast_u3249(&colontmp_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*Result).Field0 = blitTmp_1;
	(*Result).Field1 = colontmp__2;
	nimZeroMem((void*)(&T3_), sizeof(tyTuple__pod1b7gjdRZb0inVGup1nQ));
	eqsink___importer_u3673((&(*colonenv__1).ret1), T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T6_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T11_;
		tyProc__Wv5nSBLQP3WX9cri6Nd9cGbg T12_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*(*colonenv__1).n2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29));
		if (!(T6_)) goto LA7_;
		colontmpD_ = considerQuotedIdent__lookups_u31((*colonenv__1).c0, (*(*colonenv__1).n2)._kind_6.sons.p->data[((NI)0)], ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T6_ = eqStrings((*colontmpD_).s, TM__NsDkQfDe2CjzDqtBRW9bqQg_6);
LA7_: ;
		if (!T6_) goto LA8_;
		colontmpD__2 = NIM_NIL;
		T11_ = NIM_NIL;
		T11_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)78), (*(*colonenv__1).n2).info);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T11_); goto LA10_;}
		eqsink___ast_u3261(&(*colonenv__1).ret1.Field0, T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		nimZeroMem((void*)(&T12_), sizeof(tyProc__Wv5nSBLQP3WX9cri6Nd9cGbg));
		T12_.ClP_0 = processPragma__importer_u3546; T12_.ClE_0 = colonenv__1;
		colontmpD__2 = T12_.ClE_0? T12_.ClP_0((*(*colonenv__1).n2)._kind_6.sons.p->data[((NI)1)], T12_.ClE_0):((TM__NsDkQfDe2CjzDqtBRW9bqQg_17)(T12_.ClP_0))((*(*colonenv__1).n2)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		add__ast_u3215((*colonenv__1).ret1.Field0, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		add__ast_u3215((*colonenv__1).ret1.Field0, (*(*colonenv__1).n2)._kind_6.sons.p->data[((NI)2)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA8_: ;
	{
		tyProc__Wv5nSBLQP3WX9cri6Nd9cGbg T16_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T17_;
		nimZeroMem((void*)(&T16_), sizeof(tyProc__Wv5nSBLQP3WX9cri6Nd9cGbg));
		T16_.ClP_0 = processPragma__importer_u3546; T16_.ClE_0 = colonenv__1;
		T17_ = NIM_NIL;
		T17_ = T16_.ClE_0? T16_.ClP_0((*colonenv__1).n2, T16_.ClE_0):((TM__NsDkQfDe2CjzDqtBRW9bqQg_18)(T16_.ClP_0))((*colonenv__1).n2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u3261(&(*colonenv__1).ret1.Field0, T17_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	eqcopy___importer_u3667(Result, (*colonenv__1).ret1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqdestroy___idents_u155(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmp_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___importer_u4214(colonenv__1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___idents_u155(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmp_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___importer_u4214(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, find__importer_u3698)(tySequence__48JTohSgTy339bRxHzUD8KA a_p0, NI32 item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NI32* i_1;
		NI i_2;
		NI L_1;
		NI T2_;
		i_1 = (NI32*)0;
		i_2 = ((NI)0);
		T2_ = a_p0.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA4;
				i_1 = (&a_p0.p->data[i_2]);
				{
					if (!((*i_1) == item_p1)) goto LA7_;
					goto BeforeRet_;
				}
LA7_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, importModuleAs__importer_u2175)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* realModule_p2, NIM_BOOL importHidden_p3, NIM_BOOL trackUnusedImport_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* moduleIdent_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T25_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym110__1;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym112__1;
	tySequence__qwqHTkRvwhrRyENtudHQ7g T37_;
	tySequence__qwqHTkRvwhrRyENtudHQ7g* T38_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym126__1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	moduleIdent_1 = NIM_NIL;
	eqcopy___ast_u4577(&result, realModule_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)78)))) goto LA4_;
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T7_;
		NI T8_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NI)0;
		T8_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = !((T8_ == ((NI)2)));
		if (T7_) goto LA9_;
		T7_ = !(((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2)));
LA9_: ;
		if (!T7_) goto LA10_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__NsDkQfDe2CjzDqtBRW9bqQg_26, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__NsDkQfDe2CjzDqtBRW9bqQg_27), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA10_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T15_;
		if (!!(((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident).id == (*(*realModule_p2).name).id))) goto LA13_;
		T15_ = NIM_NIL;
		T15_ = createModuleAlias__ast_u6311(realModule_p2, (*c_p0).Sup.idgen, (*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_5.ident, (*n_p1).info, (*(*(*c_p0).graph).config).options);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T15_); goto LA1_;}
		eqsink___ast_u4583(&result, T15_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA13_: ;
LA2_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T20_;
		if (!(result == realModule_p2)) goto LA18_;
		T20_ = NIM_NIL;
		T20_ = createModuleAlias__ast_u6311(realModule_p2, (*c_p0).Sup.idgen, (*realModule_p2).name, (*n_p1).info, (*(*(*c_p0).graph).config).options);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T20_); goto LA1_;}
		eqsink___ast_u4583(&result, T20_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA18_: ;
	{
		if (!importHidden_p3) goto LA23_;
		(*result).options |= ((NU32)1)<<(((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)27))) & 31);
	}
LA23_: ;
	T25_ = NIM_NIL;
	{
		NI T30_;
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)78))) goto LA28_;
		T30_ = (NI)0;
		T30_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqcopy___ast_u3255(&moduleIdent_1, (*n_p1)._kind_6.sons.p->data[(NI)(T30_ - ((NI)1))]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA26_;
LA28_: ;
	{
		eqcopy___ast_u3255(&moduleIdent_1, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA26_: ;
	(*result).info = (*moduleIdent_1).info;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__2;
		tyTuple__09aD69az7aYn14Gt61AHvLIA T36_;
		if (!trackUnusedImport_p4) goto LA34_;
		nimZeroMem((void*)(&T36_), sizeof(tyTuple__09aD69az7aYn14Gt61AHvLIA));
		colontmpD_ = eqdup___ast_u4580(result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T36_.Field0 = colontmpD_;
		colontmpD__2 = eqdup___lineinfos_u2037((*result).info);
		T36_.Field1 = colontmpD__2;
		add__sempass2_u5950((&(*c_p0).unusedImports), T36_);
	}
LA34_: ;
	xX60gensym110__1 = (*result).itemId;
	xX60gensym112__1 = (*realModule_p2).itemId;
	X5BX5Deq___sempass2_u2301((&(*c_p0).importModuleMap), (NI)((NI)((NU64)(((NI) (xX60gensym110__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym110__1.item))), (NI)((NI)((NU64)(((NI) (xX60gensym112__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym112__1.item))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T37_.len = 0; T37_.p = NIM_NIL;
	T37_.len = 0; T37_.p = (tySequence__qwqHTkRvwhrRyENtudHQ7g_Content*) newSeqPayload(0, sizeof(NI), NIM_ALIGNOF(NI));
	T38_ = (tySequence__qwqHTkRvwhrRyENtudHQ7g*)0;
	T38_ = mgetOrPut__importer_u2347((&(*c_p0).importModuleLookup), (*(*result).name).id, T37_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	xX60gensym126__1 = (*realModule_p2).itemId;
	addUnique__importer_u3514(T38_, (NI)((NI)((NU64)(((NI) (xX60gensym126__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym126__1.item))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(moduleIdent_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, suggestSym__sigmatch_u6643)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** usageSym_p3, NIM_BOOL isDecl_p4, NIM_BOOL isGenericInstance_p5) {
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_1;
	conf_1 = NIM_NIL;
	conf_1 = (*g_p0).config;
}
N_LIB_PRIVATE N_CLOSURE(void, suggestMod__importer_u3748)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, void* ClE_0) {
	tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA*) ClE_0;
	{
		tyProc__9bhdHboBEtDk0F52fk9bOITw T5_;
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)78))) goto LA3_;
		nimZeroMem((void*)(&T5_), sizeof(tyProc__9bhdHboBEtDk0F52fk9bOITw));
		T5_.ClP_0 = suggestMod__importer_u3748; T5_.ClE_0 = colonenvP__1;
		T5_.ClE_0? T5_.ClP_0((*n_p0)._kind_6.sons.p->data[((NI)0)], (*colonenvP__1).realModule0, T5_.ClE_0):((TM__NsDkQfDe2CjzDqtBRW9bqQg_44)(T5_.ClP_0))((*n_p0)._kind_6.sons.p->data[((NI)0)], (*colonenvP__1).realModule0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyProc__9bhdHboBEtDk0F52fk9bOITw T9_;
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29))) goto LA7_;
		nimZeroMem((void*)(&T9_), sizeof(tyProc__9bhdHboBEtDk0F52fk9bOITw));
		T9_.ClP_0 = suggestMod__importer_u3748; T9_.ClE_0 = colonenvP__1;
		T9_.ClE_0? T9_.ClP_0((*n_p0)._kind_6.sons.p->data[((NI)2)], s_p1, T9_.ClE_0):((TM__NsDkQfDe2CjzDqtBRW9bqQg_45)(T9_.ClP_0))((*n_p0)._kind_6.sons.p->data[((NI)2)], s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA7_: ;
	{
		tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* T11_;
		T11_ = NIM_NIL;
		T11_ = (*(*colonenvP__1).c1).graph;
		suggestSym__sigmatch_u6643(T11_, (*n_p0).info, s_p1, &(*(*(*colonenvP__1).c1).graph).usageSym, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___importer_u4079)(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__vsIkeqP4DxwpPFMRthoIdA_))));
		if (!T3_) goto LA4_;
		eqdestroy___importer_u4044((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, myImportModule__importer_u3687)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* importStmtResult_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* colonenv__1;
	tyTuple__pod1b7gjdRZb0inVGup1nQ transf_1;
	tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA* T2_;
	NI32 f_1;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colonenv__1 = NIM_NIL;
	nimZeroMem((void*)(&transf_1), sizeof(tyTuple__pod1b7gjdRZb0inVGup1nQ));
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA*) nimNewObj(sizeof(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA), NIM_ALIGNOF(tyObject_Env_importerdotnim_myImportModule___vsIkeqP4DxwpPFMRthoIdA));
	(*T2_).Sup.m_type = (&NTIv2__vsIkeqP4DxwpPFMRthoIdA_);
	colonenv__1 = T2_;
	eqcopy___semdata_u4218(&(*colonenv__1).c1, c_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	transformImportAs__importer_u3534((*colonenv__1).c1, (*n_p1), (&transf_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___ast_u3261(&(*n_p1), transf_1.Field0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqwasMoved___ast_u3249(&transf_1.Field0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	f_1 = checkModuleName__modulepaths_u22((*(*(*colonenv__1).c1).graph).config, (*n_p1), NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* colontmpD_;
		NimStringV2 moduleName_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
		NI L_1;
		NI T8_;
		NI recursion_1;
		NIM_BOOL trackUnusedImport_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T21_;
		tyProc__9bhdHboBEtDk0F52fk9bOITw T55_;
		if (!!((f_1 == ((NI32)-1)))) goto LA5_;
		colontmpD_ = NIM_NIL;
		moduleName_1.len = 0; moduleName_1.p = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		addImportFileDep__semdata_u4247((*colonenv__1).c1, f_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_ = (*(*(*colonenv__1).c1).graph).importStack.len;
		L_1 = T8_;
		recursion_1 = find__importer_u3698((*(*(*colonenv__1).c1).graph).importStack, f_1);
		add__icZic_u21077((&(*(*(*colonenv__1).c1).graph).importStack), f_1);
		{
			NimStringV2 err_1;
			if (!(((NI)0) <= recursion_1)) goto LA11_;
			err_1.len = 0; err_1.p = NIM_NIL;
			err_1 = TM__NsDkQfDe2CjzDqtBRW9bqQg_20;
			{
				NI i_1;
				NI i_2;
				i_1 = (NI)0;
				i_2 = recursion_1;
				{
					while (1) {
						NimStringV2 colontmpD__3;
						NimStringV2 colontmpD__4;
						NimStringV2 colontmpD__5;
						NimStringV2 T20_;
						if (!(i_2 < L_1)) goto LA15;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						i_1 = i_2;
						{
							if (!(recursion_1 < i_1)) goto LA18_;
							prepareAdd((&err_1), 1);
appendString((&err_1), TM__NsDkQfDe2CjzDqtBRW9bqQg_22);
						}
LA18_: ;
						T20_.len = 0; T20_.p = NIM_NIL;
						colontmpD__3 = toFullPath__msgs_u624((*(*(*colonenv__1).c1).graph).config, (*(*(*colonenv__1).c1).graph).importStack.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						colontmpD__4 = toFullPath__msgs_u624((*(*(*colonenv__1).c1).graph).config, (*(*(*colonenv__1).c1).graph).importStack.p->data[(NI)(i_1 + ((NI)1))]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						T20_ = rawNewString(colontmpD__3.len + colontmpD__4.len + 9);
appendString((&T20_), colontmpD__3);
appendString((&T20_), TM__NsDkQfDe2CjzDqtBRW9bqQg_24);
appendString((&T20_), colontmpD__4);
						colontmpD__5 = T20_;
						prepareAdd((&err_1), colontmpD__5.len + 0);
appendString((&err_1), colontmpD__5);
						i_2 += ((NI)1);
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
					} LA15: ;
				}
			}
			eqsink___system_u2700((&(*(*colonenv__1).c1).recursiveDep), err_1);
		}
LA11_: ;
		trackUnusedImport_1 = (((*(*(*(*colonenv__1).c1).graph).config).notes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)42) - 20))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)42) - 20))&7U)))!=0);
		colontmpD_ = pushOptionEntry__semdata_u2309((*colonenv__1).c1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		(void)(colontmpD_);
		T21_ = NIM_NIL;
		T21_ = (*(*(*colonenv__1).c1).graph).importModuleCallback((*(*colonenv__1).c1).graph, (*(*colonenv__1).c1).module, f_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T21_); goto LA7_;}
		eqsink___ast_u4583(&(*colonenv__1).realModule0, T21_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		result = importModuleAs__importer_u2175((*colonenv__1).c1, (*n_p1), (*colonenv__1).realModule0, transf_1.Field1, trackUnusedImport_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		popOptionEntry__semdata_u2337((*colonenv__1).c1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		setLen__icZic_u16111((&(*(*(*colonenv__1).c1).graph).importStack), (L_1));
		{
			NimStringV2 colontmpD__6;
			if (!((*colonenv__1).realModule0 == (*(*colonenv__1).c1).module)) goto LA24_;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__6 = nsuFormatSingleElem(TM__NsDkQfDe2CjzDqtBRW9bqQg_29, (*(*(*colonenv__1).realModule0).name).s);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			liMessage__msgs_u1227((*(*(*colonenv__1).c1).graph).config, (*(*n_p1)).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__6, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__NsDkQfDe2CjzDqtBRW9bqQg_30), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			{
				LA26_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__6);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA24_: ;
		{
			NimStringV2 prefix_1;
			NimStringV2 colontmpD__7;
			NimStringV2 T39_;
			if (!(((*(*colonenv__1).realModule0).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)22)))&63U)))!=0)) goto LA31_;
			prefix_1.len = 0; prefix_1.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			prefix_1 = TM__NsDkQfDe2CjzDqtBRW9bqQg_31;
			{
				NimStringV2 T38_;
				if (!!(((*(*colonenv__1).realModule0).constraint == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA36_;
				T38_.len = 0; T38_.p = NIM_NIL;
				T38_ = rawNewString((*(*(*colonenv__1).realModule0).constraint)._kind_3.strVal.len + 2);
appendString((&T38_), (*(*(*colonenv__1).realModule0).constraint)._kind_3.strVal);
appendString((&T38_), TM__NsDkQfDe2CjzDqtBRW9bqQg_33);
				eqsink___system_u2700((&prefix_1), T38_);
			}
LA36_: ;
			T39_.len = 0; T39_.p = NIM_NIL;
			T39_ = rawNewString(prefix_1.len + (*(*(*colonenv__1).realModule0).name).s.len + 14);
appendString((&T39_), prefix_1);
appendString((&T39_), (*(*(*colonenv__1).realModule0).name).s);
appendString((&T39_), TM__NsDkQfDe2CjzDqtBRW9bqQg_35);
			colontmpD__7 = T39_;
			liMessage__msgs_u1227((*(*(*colonenv__1).c1).graph).config, (*(*n_p1)).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)24), colontmpD__7, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__NsDkQfDe2CjzDqtBRW9bqQg_36), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			{
				LA33_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(prefix_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA31_: ;
		moduleName_1 = getModuleName__modulepaths_u10((*(*(*colonenv__1).c1).graph).config, (*n_p1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			NIM_BOOL T44_;
			NIM_BOOL T45_;
			NIM_BOOL T46_;
			NIM_BOOL T48_;
			NIM_BOOL T50_;
			NIM_BOOL T52_;
			T44_ = (NIM_BOOL)0;
			T45_ = (NIM_BOOL)0;
			T46_ = (NIM_BOOL)0;
			T46_ = belongsToStdlib__modulegraphs_u17983((*(*colonenv__1).c1).graph, result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			if (!(T46_)) goto LA47_;
			T48_ = (NIM_BOOL)0;
			T48_ = nsuStartsWith(moduleName_1, TM__NsDkQfDe2CjzDqtBRW9bqQg_38);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			T46_ = !(T48_);
LA47_: ;
			T45_ = T46_;
			if (!(T45_)) goto LA49_;
			T50_ = (NIM_BOOL)0;
			T50_ = nsuStartsWith(moduleName_1, TM__NsDkQfDe2CjzDqtBRW9bqQg_40);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			T45_ = !(T50_);
LA49_: ;
			T44_ = T45_;
			if (!(T44_)) goto LA51_;
			T52_ = (NIM_BOOL)0;
			T52_ = nsuStartsWith(moduleName_1, TM__NsDkQfDe2CjzDqtBRW9bqQg_42);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			T44_ = !(T52_);
LA51_: ;
			if (!T44_) goto LA53_;
			liMessage__msgs_u1227((*(*(*colonenv__1).c1).graph).config, (*(*n_p1)).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)82), (*(*(*colonenv__1).realModule0).name).s, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__NsDkQfDe2CjzDqtBRW9bqQg_43), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA53_: ;
		nimZeroMem((void*)(&T55_), sizeof(tyProc__9bhdHboBEtDk0F52fk9bOITw));
		T55_.ClP_0 = suggestMod__importer_u3748; T55_.ClE_0 = colonenv__1;
		T55_.ClE_0? T55_.ClP_0((*n_p1), result, T55_.ClE_0):((TM__NsDkQfDe2CjzDqtBRW9bqQg_46)(T55_.ClP_0))((*n_p1), result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__2 = newSymNode__ast_u5171(result, (*(*n_p1)).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		add__ast_u3215(importStmtResult_p2, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(moduleName_1);
			eqdestroy___semdata_u611(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	}
LA3_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___importer_u3664(transf_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___importer_u4079(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addDeclAt__lookups_u3781)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addDeclAt__lookups_u3253(c_p0, scope_p1, sym_p2, (*sym_p2).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, addDecl__lookups_u3789)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addDeclAt__lookups_u3781(c_p0, (*c_p0).currentScope, sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initPackedSet__pureZcollectionsZintsets_u37(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addImport__importer_u1640)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_p1) {
	tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw blitTmp_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((*c_p0).imports.len-1);
		colontmp_ = T3_;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA5;
				i_1 = ((NI) (res_1));
				{
					if (!((*c_p0).imports.p->data[i_1].m == (*im_p1).m)) goto LA8_;
					switch ((*c_p0).imports.p->data[i_1].mode) {
					case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
					{
					}
					break;
					case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
					{
						switch ((*im_p1).mode) {
						case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
						case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
						{
							eqsink___semdata_u3006((&(*c_p0).imports.p->data[i_1]), im_p1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqwasMoved___semdata_u2994(im_p1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						}
						break;
						case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
						{
							incl__importer_u1686((&(*c_p0).imports.p->data[i_1]._mode_2.imported), (&(*im_p1)._mode_2.imported));
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						}
						break;
						default: __builtin_unreachable();
						}
					}
					break;
					case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
					{
						switch ((*im_p1).mode) {
						case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
						{
							eqsink___semdata_u3006((&(*c_p0).imports.p->data[i_1]), im_p1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqwasMoved___semdata_u2994(im_p1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						}
						break;
						case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
						{
						}
						break;
						case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
						{
							tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA cut_1;
							nimZeroMem((void*)(&cut_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
							initIntSet__pureZcollectionsZintsets_u598((&cut_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							{
								tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA colontmp__2;
								NI j_1;
								nimZeroMem((void*)(&colontmp__2), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
								j_1 = (NI)0;
								nimZeroMem((void*)(&colontmp__2), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
								colontmp__2 = (*im_p1)._mode_3.exceptSet;
								eqwasMoved___pureZcollectionsZintsets_u227((&(*im_p1)._mode_3.exceptSet));
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								{
									if (!(colontmp__2.elems <= ((NI)34))) goto LA21_;
									{
										NI i_2;
										NI i_3;
										i_2 = (NI)0;
										i_3 = ((NI)0);
										{
											while (1) {
												if (!(i_3 < colontmp__2.elems)) goto LA25;
												i_2 = i_3;
												j_1 = colontmp__2.a[(i_2)- 0];
												{
													NIM_BOOL T28_;
													T28_ = (NIM_BOOL)0;
													T28_ = contains__astalgo_u2846((&(*c_p0).imports.p->data[i_1]._mode_3.exceptSet), j_1);
													if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
													if (!T28_) goto LA29_;
													incl__pureZcollectionsZintsets_u366((&cut_1), j_1);
													if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
												}
LA29_: ;
												i_3 += ((NI)1);
											} LA25: ;
										}
									}
								}
								goto LA19_;
LA21_: ;
								{
									tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* r_1;
									r_1 = NIM_NIL;
									r_1 = colontmp__2.head;
									eqwasMoved___pureZcollectionsZintsets_u45(&colontmp__2.head);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									{
										while (1) {
											NI i_4;
											if (!!((r_1 == ((tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA*) NIM_NIL)))) goto LA33;
											i_4 = ((NI)0);
											{
												while (1) {
													NU w_1;
													NI j_2;
													if (!(i_4 <= ((NI)7))) goto LA35;
													w_1 = (*r_1).bits[(i_4)- 0];
													j_2 = ((NI)0);
													{
														while (1) {
															if (!!((w_1 == ((NU)0)))) goto LA37;
															{
																NI T42_;
																if (!!(((NU)(w_1 & ((NU)1)) == ((NU)0)))) goto LA40_;
																T42_ = (NI)0;
																T42_ = pluspercent___system_u785((NI)((NU64)(i_4) << (NU64)(((NI)6) & (64 - 1))), j_2);
																j_1 = (NI)((NI)((NU64)((*r_1).key) << (NU64)(((NI)9) & (64 - 1))) | T42_);
																{
																	NIM_BOOL T45_;
																	T45_ = (NIM_BOOL)0;
																	T45_ = contains__astalgo_u2846((&(*c_p0).imports.p->data[i_1]._mode_3.exceptSet), j_1);
																	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
																	if (!T45_) goto LA46_;
																	incl__pureZcollectionsZintsets_u366((&cut_1), j_1);
																	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
																}
LA46_: ;
															}
LA40_: ;
															j_2 += ((NI)1);
															w_1 = (NU)((NU64)(w_1) >> (NU64)(((NI)1) & (64 - 1)));
														} LA37: ;
													}
													i_4 += ((NI)1);
												} LA35: ;
											}
											eqcopy___pureZcollectionsZintsets_u51(&r_1, (*r_1).next);
											if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
										} LA33: ;
									}
									eqdestroy___pureZcollectionsZintsets_u48(r_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								}
LA19_: ;
								eqdestroy___pureZcollectionsZintsets_u230((&colontmp__2));
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							}
							eqsink___pureZcollectionsZintsets_u236((&(*c_p0).imports.p->data[i_1]._mode_3.exceptSet), (&cut_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						}
						break;
						default: __builtin_unreachable();
						}
					}
					break;
					default: __builtin_unreachable();
					}
					eqdestroy___semdata_u2997(im_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA8_: ;
				res_1 += ((NI)1);
			} LA5: ;
		}
	}
	nimZeroMem((void*)(&blitTmp_1), sizeof(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw));
	blitTmp_1 = (*im_p1);
	eqwasMoved___semdata_u2994(im_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__importer_u1828((&(*c_p0).imports), (&blitTmp_1));
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___semdata_u2997(im_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumField__importer_u79)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	NIM_BOOL amb_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	amb_1 = NIM_FALSE;
	{
		colontmpD_ = someSymFromImportTable__lookups_u2381(c_p0, (*s_p1).name, (&amb_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(colontmpD_ == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA4_;
		strTableAdd__astalgo_u2666((&(*c_p0).pureEnumFields), s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, importPureEnumFields__importer_u87)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* etyp_p2) {
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI j_1;
		NI colontmp_;
		NI i_1;
		j_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190((*etyp_p2).n);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_1 = ((NI)0);
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* e_1;
				if (!(i_1 < colontmp_)) goto LA3;
				e_1 = NIM_NIL;
				j_1 = i_1;
				eqcopy___ast_u4577(&e_1, (*(*(*etyp_p2).n)._kind_6.sons.p->data[j_1])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				{
					if (!!(((*e_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20)))) goto LA7_;
					internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*s_p1).info, TM__NsDkQfDe2CjzDqtBRW9bqQg_48, (&TM__NsDkQfDe2CjzDqtBRW9bqQg_49));
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
LA7_: ;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* check_1;
					tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA marked_1;
					check_1 = NIM_NIL;
					nimZeroMem((void*)(&marked_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
					check_1 = 0;
					initIntSet__pureZcollectionsZintsets_u598((&marked_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					{
						tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_1;
						NI i_2;
						NI L_1;
						NI T12_;
						im_1 = (tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw*)0;
						i_2 = ((NI)0);
						T12_ = (*c_p0).imports.len;
						L_1 = T12_;
						{
							while (1) {
								if (!(i_2 < L_1)) goto LA14;
								im_1 = (&(*c_p0).imports.p->data[i_2]);
								{
									tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
									tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ ti_1;
									tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_1;
									s_2 = NIM_NIL;
									nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
									candidate_1 = NIM_NIL;
									s_2 = 0;
									nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
									candidate_1 = initIdentIter__lookups_u135((&ti_1), (&marked_1), (&(*im_1)), (*e_1).name, (*c_p0).graph);
									if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
									{
										while (1) {
											tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T23_;
											if (!!((candidate_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA18;
											eqsink___ast_u4583(&s_2, candidate_1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
											eqwasMoved___ast_u4571(&candidate_1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
											eqsink___ast_u4583(&check_1, s_2);
											if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
											eqwasMoved___ast_u4571(&s_2);
											if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
											{
												tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym13__1;
												tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym15__1;
												xX60gensym13__1 = (*check_1).itemId;
												xX60gensym15__1 = (*e_1).itemId;
												if (!((NI)((NI)((NU64)(((NI) (xX60gensym13__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym13__1.item))) == (NI)((NI)((NU64)(((NI) (xX60gensym15__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym15__1.item))))) goto LA21_;
												eqsink___ast_u4583(&e_1, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
												if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
												eqdestroy___ast_u4574(candidate_1);
												if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
												eqdestroy___modulegraphs_u3435((&ti_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
												eqdestroy___ast_u4574(s_2);
												if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
												eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
												eqdestroy___ast_u4574(check_1);
												if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
												goto LA9;
											}
LA21_: ;
											T23_ = NIM_NIL;
											T23_ = nextIdentIter__lookups_u350((&ti_1), (&marked_1), (&(*im_1)), (*c_p0).graph);
											if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T23_); goto LA16_;}
											eqsink___ast_u4583(&candidate_1, T23_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
										} LA18: ;
									}
									{
										LA16_:;
									}
									{
										oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
										eqdestroy___ast_u4574(candidate_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
										eqdestroy___modulegraphs_u3435((&ti_1));
										if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
										eqdestroy___ast_u4574(s_2);
										if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
										*nimErr_ = oldNimErrFin16_;
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
								}
								i_2 += ((NI)1);
							} LA14: ;
						}
					}
					{
						LA10_:;
					}
					{
						oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						eqdestroy___ast_u4574(check_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						*nimErr_ = oldNimErrFin10_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				} LA9: ;
				{
					if (!!((e_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA30_;
					importPureEnumField__importer_u79(c_p0, e_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
LA30_: ;
				i_1 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(e_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbols__importer_u2053)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fromMod_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw));
	colontmpD_ = eqdup___ast_u4580(fromMod_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.m = colontmpD_;
	T1_.mode = ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0);
	addImport__importer_u1640(c_p0, (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* it_1;
		NI i_1;
		NI L_1;
		NI T3_;
		it_1 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
		i_1 = ((NI)0);
		T3_ = (*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].converters.len;
		L_1 = T3_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA5;
				it_1 = (&(*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].converters.p->data[i_1]);
				{
					if (!NIM_TRUE) goto LA8_;
					loadPackedSym__modulegraphs_u10725((*c_p0).graph, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						if (!(((*(*it_1).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1)))&63U)))!=0)) goto LA12_;
						addConverter__semdata_u4291(c_p0, (*it_1));
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA12_: ;
				}
LA8_: ;
				i_1 += ((NI)1);
			} LA5: ;
		}
	}
	{
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* it_2;
		NI i_2;
		NI L_2;
		NI T15_;
		it_2 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
		i_2 = ((NI)0);
		T15_ = (*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].patterns.len;
		L_2 = T15_;
		{
			while (1) {
				if (!(i_2 < L_2)) goto LA17;
				it_2 = (&(*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].patterns.p->data[i_2]);
				{
					if (!NIM_TRUE) goto LA20_;
					loadPackedSym__modulegraphs_u10725((*c_p0).graph, it_2);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						if (!(((*(*it_2).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1)))&63U)))!=0)) goto LA24_;
						addPattern__semdata_u4330(c_p0, (*it_2));
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA24_: ;
				}
LA20_: ;
				i_2 += ((NI)1);
			} LA17: ;
		}
	}
	{
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* it_3;
		NI i_3;
		NI L_3;
		NI T27_;
		it_3 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
		i_3 = ((NI)0);
		T27_ = (*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].pureEnums.len;
		L_3 = T27_;
		{
			while (1) {
				if (!(i_3 < L_3)) goto LA29;
				it_3 = (&(*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].pureEnums.p->data[i_3]);
				{
					if (!NIM_TRUE) goto LA32_;
					loadPackedSym__modulegraphs_u10725((*c_p0).graph, it_3);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					importPureEnumFields__importer_u87(c_p0, (*it_3).sym, (*(*it_3).sym).typ);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA32_: ;
				i_3 += ((NI)1);
			} LA29: ;
		}
	}
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u2997)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*g_p0).packed_0.pm.len;
	T1_ = (module_p1 < T2_);
	if (!(T1_)) goto LA3_;
	T1_ = ((*g_p0).packed_0.pm.p->data[module_p1].status == ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)3));
LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u3008)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = isCachedModule__modulegraphs_u2997(g_p0, (*m_p1).position);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, afterImport__importer_u3761)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
	NI realModuleId_1;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym158__1;
	NI* T6_;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isCachedModule__modulegraphs_u3008((*c_p0).graph, m_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	xX60gensym158__1 = (*m_p1).itemId;
	T6_ = (NI*)0;
	T6_ = X5BX5D___lookups_u3355((&(*c_p0).importModuleMap), (NI)((NI)((NU64)(((NI) (xX60gensym158__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym158__1.item))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	realModuleId_1 = (*T6_);
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
		NIM_BOOL importHidden_1;
		s_1 = NIM_NIL;
		importHidden_1 = (((*m_p1).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)27)))&31U)))!=0);
		{
			NIM_BOOL T11_;
			tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ rodIt_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* r_1;
			tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T15_;
			tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T16_;
			T11_ = (NIM_BOOL)0;
			T11_ = isCachedModule__modulegraphs_u3008((*c_p0).graph, m_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			if (!T11_) goto LA12_;
			nimZeroMem((void*)(&rodIt_1), sizeof(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ));
			r_1 = NIM_NIL;
			nimZeroMem((void*)(&rodIt_1), sizeof(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ));
			T15_ = NIM_NIL;
			T15_ = (*(*c_p0).graph).config;
			T16_ = NIM_NIL;
			T16_ = (*(*c_p0).graph).cache;
			r_1 = initRodIterAllSyms__icZic_u21632((&rodIt_1), T15_, T16_, (&(*(*c_p0).graph).packed_0), ((NI32) ((*m_p1).position)), importHidden_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			{
				while (1) {
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T25_;
					if (!!((r_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA18;
					colontmpD_ = NIM_NIL;
					eqsink___ast_u4583(&s_1, r_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					eqwasMoved___ast_u4571(&r_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					{
						tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym161__1;
						tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T24_;
						tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym163__1;
						tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym165__1;
						colontmpD_ = owner__ast_u6254(s_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						xX60gensym161__1 = (*colontmpD_).itemId;
						if (!!(((NI)((NI)((NU64)(((NI) (xX60gensym161__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym161__1.item))) == realModuleId_1))) goto LA22_;
						xX60gensym163__1 = (*m_p1).itemId;
						T24_.Field0 = (NI)((NI)((NU64)(((NI) (xX60gensym163__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym163__1.item)));
						xX60gensym165__1 = (*s_1).itemId;
						T24_.Field1 = (NI)((NI)((NU64)(((NI) (xX60gensym165__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym165__1.item)));
						incl__importer_u301((&(*c_p0).exportIndirections), T24_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					}
LA22_: ;
					T25_ = NIM_NIL;
					T25_ = nextRodIter__icZic_u21968((&rodIt_1), (&(*(*c_p0).graph).packed_0));
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T25_); goto LA19_;}
					eqsink___ast_u4583(&r_1, T25_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					{
						LA19_:;
					}
					{
						oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						*nimErr_ = oldNimErrFin19_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
				} LA18: ;
			}
			{
				LA14_:;
			}
			{
				oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(r_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				eqdestroy___modulegraphs_u3288((&rodIt_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				*nimErr_ = oldNimErrFin14_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
		goto LA9_;
LA12_: ;
		{
			{
				tySequence__ZCZaCk14bTmSb6LMW9aWPVA colontmp_;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** s_2;
				tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* retX60gensym20__1;
				NI i_1;
				NI L_1;
				NI T36_;
				colontmp_.len = 0; colontmp_.p = NIM_NIL;
				s_2 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
				retX60gensym20__1 = (&(*(*c_p0).graph).ifaces.p->data[(*m_p1).position].interf);
				{
					if (!importHidden_1) goto LA34_;
					retX60gensym20__1 = (&(*(*c_p0).graph).ifaces.p->data[(*m_p1).position].interfHidden);
				}
LA34_: ;
				eqcopy___ast_u4851((&colontmp_), (*retX60gensym20__1).data);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				i_1 = ((NI)0);
				T36_ = colontmp_.len;
				L_1 = T36_;
				{
					while (1) {
						if (!(i_1 < L_1)) goto LA38;
						s_2 = &colontmp_.p->data[i_1];
						{
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
							if (!!(((*s_2) == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA41_;
							colontmpD__2 = NIM_NIL;
							eqcopy___ast_u4577(&s_1, (*s_2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
							{
								tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym161__2;
								tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T47_;
								tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym163__2;
								tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym165__2;
								colontmpD__2 = owner__ast_u6254(s_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
								xX60gensym161__2 = (*colontmpD__2).itemId;
								if (!!(((NI)((NI)((NU64)(((NI) (xX60gensym161__2.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym161__2.item))) == realModuleId_1))) goto LA45_;
								xX60gensym163__2 = (*m_p1).itemId;
								T47_.Field0 = (NI)((NI)((NU64)(((NI) (xX60gensym163__2.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym163__2.item)));
								xX60gensym165__2 = (*s_1).itemId;
								T47_.Field1 = (NI)((NI)((NU64)(((NI) (xX60gensym165__2.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym165__2.item)));
								incl__importer_u301((&(*c_p0).exportIndirections), T47_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
							}
LA45_: ;
							eqdestroy___ast_u4574(colontmpD__2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						}
LA41_: ;
						i_1 += ((NI)1);
					} LA38: ;
				}
				eqdestroy___ast_u4848(colontmp_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			}
		}
LA9_: ;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, impMod__importer_u3919)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* importStmtResult_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	it_2 = NIM_NIL;
	m_1 = NIM_NIL;
	eqcopy___ast_u3255(&it_2, it_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	m_1 = myImportModule__importer_u3687(c_p0, &it_2, importStmtResult_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((m_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA4_;
		addDecl__lookups_u3789(c_p0, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		importAllSymbols__importer_u2053(c_p0, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		afterImport__importer_u3761(c_p0, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(it_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalImport__importer_u3929)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116), (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA3;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				{
					NIM_BOOL T7_;
					NI T9_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* imp_1;
					NI lastPos_1;
					NI T13_;
					NI T14_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30));
					if (!(T7_)) goto LA8_;
					T9_ = (NI)0;
					T9_ = len__ast_u3190(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
					T7_ = ((*(*it_1)._kind_6.sons.p->data[(NI)(T9_ - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41));
LA8_: ;
					if (!T7_) goto LA10_;
					imp_1 = NIM_NIL;
					T13_ = (NI)0;
					T13_ = len__ast_u3190(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					lastPos_1 = (NI)(T13_ - ((NI)1));
					imp_1 = copyNode__ast_u6736(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					T14_ = (NI)0;
					T14_ = len__ast_u3190(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					newSons__ast_u6108(imp_1, T14_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					{
						NI i_3;
						NI i_4;
						i_3 = (NI)0;
						i_4 = ((NI)0);
						{
							while (1) {
								if (!(i_4 < lastPos_1)) goto LA17;
								i_3 = i_4;
								eqcopy___ast_u3255(&(*imp_1)._kind_6.sons.p->data[i_3], (*it_1)._kind_6.sons.p->data[i_3]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
								i_4 += ((NI)1);
							} LA17: ;
						}
					}
					eqcopy___ast_u3255(&(*imp_1)._kind_6.sons.p->data[lastPos_1], (*imp_1)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** colontmp__2;
						x_1 = NIM_NIL;
						x_1 = 0;
						colontmp__2 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
						colontmp__2 = &(*it_1)._kind_6.sons.p->data[lastPos_1];
						{
							NI i_5;
							NI colontmp__3;
							NI i_6;
							i_5 = (NI)0;
							colontmp__3 = (NI)0;
							colontmp__3 = safeLen__ast_u3197((*colontmp__2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							i_6 = ((NI)0);
							{
								while (1) {
									if (!(i_6 < colontmp__3)) goto LA22;
									i_5 = i_6;
									eqcopy___ast_u3255(&x_1, (*(*colontmp__2))._kind_6.sons.p->data[i_5]);
									if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
									{
										NIM_BOOL T25_;
										tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* impAs_1;
										T25_ = (NIM_BOOL)0;
										T25_ = ((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29));
										if (!(T25_)) goto LA26_;
										T25_ = eqStrings((*(*(*x_1)._kind_6.sons.p->data[((NI)0)])._kind_5.ident).s, TM__NsDkQfDe2CjzDqtBRW9bqQg_3);
LA26_: ;
										if (!T25_) goto LA27_;
										impAs_1 = NIM_NIL;
										impAs_1 = copyNode__ast_u6736(x_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
										newSons__ast_u6108(impAs_1, ((NI)3));
										if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
										eqcopy___ast_u3255(&(*impAs_1)._kind_6.sons.p->data[((NI)0)], (*x_1)._kind_6.sons.p->data[((NI)0)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
										eqcopy___ast_u3255(&(*imp_1)._kind_6.sons.p->data[lastPos_1], (*x_1)._kind_6.sons.p->data[((NI)1)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
										eqcopy___ast_u3255(&(*impAs_1)._kind_6.sons.p->data[((NI)1)], imp_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
										eqcopy___ast_u3255(&(*impAs_1)._kind_6.sons.p->data[((NI)2)], (*x_1)._kind_6.sons.p->data[((NI)2)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
										impMod__importer_u3919(c_p0, impAs_1, result);
										if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
										{
											LA29_:;
										}
										{
											oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
											eqdestroy___ast_u3252(impAs_1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
											*nimErr_ = oldNimErrFin29_;
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
									}
									goto LA23_;
LA27_: ;
									{
										eqsink___ast_u3261(&(*imp_1)._kind_6.sons.p->data[lastPos_1], x_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
										eqwasMoved___ast_u3249(&x_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
										impMod__importer_u3919(c_p0, imp_1, result);
										if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
									}
LA23_: ;
									i_6 += ((NI)1);
								} LA22: ;
							}
						}
						{
							LA19_:;
						}
						{
							oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(x_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
							*nimErr_ = oldNimErrFin19_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					}
					{
						LA12_:;
					}
					{
						oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(imp_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						*nimErr_ = oldNimErrFin12_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
				goto LA5_;
LA10_: ;
				{
					impMod__importer_u3919(c_p0, it_1, result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
LA5_: ;
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, importAllSymbolsExcept__importer_u1852)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fromMod_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* exceptSet_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA colontmpD__2;
	tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&T1_), sizeof(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw));
	colontmpD_ = eqdup___ast_u4580(fromMod_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.m = colontmpD_;
	T1_.mode = ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2);
	eqdup___pureZcollectionsZintsets_u233(exceptSet_p2, (&colontmpD__2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_._mode_3.exceptSet = colontmpD__2;
	addImport__importer_u1640(c_p0, (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* it_1;
		NI i_1;
		NI L_1;
		NI T3_;
		it_1 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
		i_1 = ((NI)0);
		T3_ = (*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].converters.len;
		L_1 = T3_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA5;
				it_1 = (&(*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].converters.p->data[i_1]);
				{
					NIM_BOOL T8_;
					T8_ = (NIM_BOOL)0;
					T8_ = contains__astalgo_u2846(exceptSet_p2, (*(*(*it_1).sym).name).id);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!!(T8_)) goto LA9_;
					loadPackedSym__modulegraphs_u10725((*c_p0).graph, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						if (!(((*(*it_1).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1)))&63U)))!=0)) goto LA13_;
						addConverter__semdata_u4291(c_p0, (*it_1));
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA13_: ;
				}
LA9_: ;
				i_1 += ((NI)1);
			} LA5: ;
		}
	}
	{
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* it_2;
		NI i_2;
		NI L_2;
		NI T16_;
		it_2 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
		i_2 = ((NI)0);
		T16_ = (*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].patterns.len;
		L_2 = T16_;
		{
			while (1) {
				if (!(i_2 < L_2)) goto LA18;
				it_2 = (&(*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].patterns.p->data[i_2]);
				{
					NIM_BOOL T21_;
					T21_ = (NIM_BOOL)0;
					T21_ = contains__astalgo_u2846(exceptSet_p2, (*(*(*it_2).sym).name).id);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!!(T21_)) goto LA22_;
					loadPackedSym__modulegraphs_u10725((*c_p0).graph, it_2);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						if (!(((*(*it_2).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1)))&63U)))!=0)) goto LA26_;
						addPattern__semdata_u4330(c_p0, (*it_2));
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA26_: ;
				}
LA22_: ;
				i_2 += ((NI)1);
			} LA18: ;
		}
	}
	{
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* it_3;
		NI i_3;
		NI L_3;
		NI T29_;
		it_3 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
		i_3 = ((NI)0);
		T29_ = (*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].pureEnums.len;
		L_3 = T29_;
		{
			while (1) {
				if (!(i_3 < L_3)) goto LA31;
				it_3 = (&(*(*c_p0).graph).ifaces.p->data[(*fromMod_p1).position].pureEnums.p->data[i_3]);
				{
					NIM_BOOL T34_;
					T34_ = (NIM_BOOL)0;
					T34_ = contains__astalgo_u2846(exceptSet_p2, (*(*(*it_3).sym).name).id);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!!(T34_)) goto LA35_;
					loadPackedSym__modulegraphs_u10725((*c_p0).graph, it_3);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					importPureEnumFields__importer_u87(c_p0, (*it_3).sym, (*(*it_3).sym).typ);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA35_: ;
				i_3 += ((NI)1);
			} LA31: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, readExceptSet__importer_u19)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)1);
		{
			while (1) {
				tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
				if (!(i_2 < colontmp_)) goto LA3;
				ident_1 = NIM_NIL;
				i_1 = i_2;
				ident_1 = considerQuotedIdent__lookups_u31(c_p0, (*n_p1)._kind_6.sons.p->data[i_1], ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				incl__pureZcollectionsZintsets_u366(Result, (*ident_1).id);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___idents_u155(ident_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalImportExcept__importer_u3979)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	m_1 = NIM_NIL;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116), (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	checkMinSonsLen__semdata_u4675(n_p1, ((NI)2), (*(*c_p0).graph).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	m_1 = myImportModule__importer_u3687(c_p0, &(*n_p1)._kind_6.sons.p->data[((NI)0)], result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA colontmpD_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T7_;
		if (!!((m_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA4_;
		nimZeroMem((void*)(&colontmpD_), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
		T7_ = NIM_NIL;
		T7_ = newSymNode__ast_u5168(m_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T7_); goto LA6_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)0)], T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		addDecl__lookups_u3789(c_p0, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		readExceptSet__importer_u19(c_p0, n_p1, (&colontmpD_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		importAllSymbolsExcept__importer_u1852(c_p0, m_1, (&colontmpD_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		afterImport__importer_u3761(c_p0, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZcollectionsZintsets_u230((&colontmpD_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isRoutine__ast_u7152)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	NIM_BOOL result;
	result = ((*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
	return result;
}
static N_INLINE(NIM_BOOL, hasPattern__ast_u7174)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = isRoutine__ast_u7152(s_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	if (!(T1_)) goto LA2_;
	T1_ = !(((*(*(*s_p0).ast)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)));
LA2_: ;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawImportSymbol__importer_u127)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* origin_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* importSet_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym18__1;
NIM_BOOL oldNimErrFin26_;
NIM_BOOL oldNimErrFin20_;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	xX60gensym18__1 = (*s_p1).itemId;
	incl__pureZcollectionsZintsets_u366(importSet_p3, (NI)((NI)((NU64)(((NI) (xX60gensym18__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym18__1.item))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* etyp_1;
		if (!((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7))) goto LA4_;
		etyp_1 = NIM_NIL;
		eqcopy___ast_u3381(&etyp_1, (*s_p1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			if (!((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14))) goto LA9_;
			{
				NI j_1;
				NI colontmp_;
				NI i_1;
				j_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190((*etyp_1).n);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				i_1 = ((NI)0);
				{
					while (1) {
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* e_1;
						if (!(i_1 < colontmp_)) goto LA13;
						e_1 = NIM_NIL;
						j_1 = i_1;
						eqcopy___ast_u4577(&e_1, (*(*(*etyp_1).n)._kind_6.sons.p->data[j_1])._kind_4.sym);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						{
							if (!!(((*e_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20)))) goto LA17_;
							internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*s_p1).info, TM__NsDkQfDe2CjzDqtBRW9bqQg_57, (&TM__NsDkQfDe2CjzDqtBRW9bqQg_58));
							if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						}
LA17_: ;
						{
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* check_1;
							tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA marked_1;
							check_1 = NIM_NIL;
							nimZeroMem((void*)(&marked_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
							check_1 = 0;
							initIntSet__pureZcollectionsZintsets_u598((&marked_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
							{
								tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_1;
								NI i_2;
								NI L_1;
								NI T22_;
								im_1 = (tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw*)0;
								i_2 = ((NI)0);
								T22_ = (*c_p0).imports.len;
								L_1 = T22_;
								{
									while (1) {
										if (!(i_2 < L_1)) goto LA24;
										im_1 = (&(*c_p0).imports.p->data[i_2]);
										{
											tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
											tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ ti_1;
											tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_1;
											s_2 = NIM_NIL;
											nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
											candidate_1 = NIM_NIL;
											s_2 = 0;
											nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
											candidate_1 = initIdentIter__lookups_u135((&ti_1), (&marked_1), (&(*im_1)), (*e_1).name, (*c_p0).graph);
											if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
											{
												while (1) {
													tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T33_;
													if (!!((candidate_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA28;
													eqsink___ast_u4583(&s_2, candidate_1);
													if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
													eqwasMoved___ast_u4571(&candidate_1);
													if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
													eqsink___ast_u4583(&check_1, s_2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
													eqwasMoved___ast_u4571(&s_2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
													{
														tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym26__1;
														tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym28__1;
														xX60gensym26__1 = (*check_1).itemId;
														xX60gensym28__1 = (*e_1).itemId;
														if (!((NI)((NI)((NU64)(((NI) (xX60gensym26__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym26__1.item))) == (NI)((NI)((NU64)(((NI) (xX60gensym28__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym28__1.item))))) goto LA31_;
														eqsink___ast_u4583(&e_1, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
														if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
														eqdestroy___ast_u4574(candidate_1);
														if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
														eqdestroy___modulegraphs_u3435((&ti_1));
														if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
														eqdestroy___ast_u4574(s_2);
														if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
														eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
														if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
														eqdestroy___ast_u4574(check_1);
														if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
														goto LA19;
													}
LA31_: ;
													T33_ = NIM_NIL;
													T33_ = nextIdentIter__lookups_u350((&ti_1), (&marked_1), (&(*im_1)), (*c_p0).graph);
													if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T33_); goto LA26_;}
													eqsink___ast_u4583(&candidate_1, T33_);
													if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
												} LA28: ;
											}
											{
												LA26_:;
											}
											{
												oldNimErrFin26_ = *nimErr_; *nimErr_ = NIM_FALSE;
												eqdestroy___ast_u4574(candidate_1);
												if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
												eqdestroy___modulegraphs_u3435((&ti_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
												eqdestroy___ast_u4574(s_2);
												if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
												*nimErr_ = oldNimErrFin26_;
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
										}
										i_2 += ((NI)1);
									} LA24: ;
								}
							}
							{
								LA20_:;
							}
							{
								oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
								if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
								eqdestroy___ast_u4574(check_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
								*nimErr_ = oldNimErrFin20_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						} LA19: ;
						{
							if (!!((e_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA40_;
							{
								if (!!((((*s_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0))) goto LA44_;
								rawImportSymbol__importer_u127(c_p0, e_1, origin_p2, importSet_p3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
							}
							goto LA42_;
LA44_: ;
							{
								importPureEnumField__importer_u79(c_p0, e_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
							}
LA42_: ;
						}
LA40_: ;
						i_1 += ((NI)1);
						{
							LA14_:;
						}
						{
							oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u4574(e_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
							*nimErr_ = oldNimErrFin14_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					} LA13: ;
				}
			}
		}
LA9_: ;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(etyp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		{
			tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T56_;
			if (!((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16))) goto LA54_;
			nimZeroMem((void*)(&T56_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
			nimZeroMem((void*)(&T56_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
			T56_.sym = s_p1;
			addConverter__semdata_u4291(c_p0, T56_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA54_: ;
		{
			NIM_BOOL T59_;
			tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T62_;
			T59_ = (NIM_BOOL)0;
			T59_ = hasPattern__ast_u7174(s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T59_) goto LA60_;
			nimZeroMem((void*)(&T62_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
			nimZeroMem((void*)(&T62_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
			T62_.sym = s_p1;
			addPattern__semdata_u4330(c_p0, T62_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA60_: ;
	}
LA2_: ;
	{
		tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T67_;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym33__1;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym35__1;
		colontmpD_ = owner__ast_u6254(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((colontmpD_ == origin_p2))) goto LA65_;
		xX60gensym33__1 = (*origin_p2).itemId;
		T67_.Field0 = (NI)((NI)((NU64)(((NI) (xX60gensym33__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym33__1.item)));
		xX60gensym35__1 = (*s_p1).itemId;
		T67_.Field1 = (NI)((NI)((NU64)(((NI) (xX60gensym35__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym35__1.item)));
		incl__importer_u301((&(*c_p0).exportIndirections), T67_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA65_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, importSymbol__importer_u1600)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fromMod_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* importSet_p3) {
	tyTuple__WX5tJaowKpyuKe6hGR9aIXQ tmpTuple_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
	tySequence__SxRJJ9bayPyj0RYzIZTiohA kws_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
NIM_BOOL oldNimErrFin18_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__WX5tJaowKpyuKe6hGR9aIXQ));
	n_2 = NIM_NIL;
	kws_1.len = 0; kws_1.p = NIM_NIL;
	ident_1 = NIM_NIL;
	s_1 = NIM_NIL;
	splitPragmas__importer_u1409(c_p0, n_p1, (&tmpTuple_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	n_2 = tmpTuple_1.Field0;
	eqwasMoved___ast_u3249(&tmpTuple_1.Field0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	kws_1 = tmpTuple_1.Field1;
	eqwasMoved___importer_u1457((&tmpTuple_1.Field1));
	{
		NI T4_;
		T4_ = kws_1.len;
		if (!(((NI)0) < T4_)) goto LA5_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__NsDkQfDe2CjzDqtBRW9bqQg_51, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), (&TM__NsDkQfDe2CjzDqtBRW9bqQg_52), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	ident_1 = considerQuotedIdent__lookups_u31(c_p0, n_2, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	s_1 = someSym__modulegraphs_u3324((*c_p0).graph, fromMod_p2, ident_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(s_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA9_;
		errorUndeclaredIdentifier__lookups_u5145(c_p0, (*n_2).info, (*ident_1).s, TM__NsDkQfDe2CjzDqtBRW9bqQg_53);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA7_;
LA9_: ;
	{
		NIM_BOOL multiImport_1;
		NIM_BOOL T12_;
		tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* T33_;
		T12_ = (NIM_BOOL)0;
		T12_ = !(((*s_1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) && (*s_1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*s_1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) && (*s_1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)23)));
		if (T12_) goto LA13_;
		T12_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
LA13_: ;
		multiImport_1 = T12_;
		{
			tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ it_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* e_1;
			if (!multiImport_1) goto LA16_;
			nimZeroMem((void*)(&it_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
			e_1 = NIM_NIL;
			nimZeroMem((void*)(&it_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
			e_1 = initModuleIter__modulegraphs_u3177((&it_1), (*c_p0).graph, fromMod_p2, (*s_1).name);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			{
				while (1) {
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T29_;
					if (!!((e_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA20;
					{
						if (!!(((*(*e_1).name).id == (*(*s_1).name).id))) goto LA23_;
						internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*n_2).info, TM__NsDkQfDe2CjzDqtBRW9bqQg_55, (&TM__NsDkQfDe2CjzDqtBRW9bqQg_56));
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					}
LA23_: ;
					{
						if (!((*s_1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) && (*s_1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*s_1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) && (*s_1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)23))) goto LA27_;
						rawImportSymbol__importer_u127(c_p0, e_1, fromMod_p2, importSet_p3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					}
LA27_: ;
					T29_ = NIM_NIL;
					T29_ = nextModuleIter__modulegraphs_u3222((&it_1), (*c_p0).graph);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T29_); goto LA18_;}
					eqsink___ast_u4583(&e_1, T29_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				} LA20: ;
			}
			{
				LA18_:;
			}
			{
				oldNimErrFin18_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(e_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___modulegraphs_u3435((&it_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin18_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA14_;
LA16_: ;
		{
			rawImportSymbol__importer_u127(c_p0, s_1, fromMod_p2, importSet_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA14_: ;
		T33_ = NIM_NIL;
		T33_ = (*c_p0).graph;
		suggestSym__sigmatch_u6643(T33_, (*n_2).info, s_1, &(*(*c_p0).graph).usageSym, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(ident_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___importer_u1460(kws_1);
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___importer_u1576(tmpTuple_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalFrom__importer_u3960)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	m_1 = NIM_NIL;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116), (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	checkMinSonsLen__semdata_u4675(n_p1, ((NI)2), (*(*c_p0).graph).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	m_1 = myImportModule__importer_u3687(c_p0, &(*n_p1)._kind_6.sons.p->data[((NI)0)], result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw im_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T7_;
		tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw blitTmp_1;
		if (!!((m_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA4_;
		nimZeroMem((void*)(&im_1), sizeof(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw));
		T7_ = NIM_NIL;
		T7_ = newSymNode__ast_u5168(m_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T7_); goto LA6_;}
		eqsink___ast_u3261(&(*n_p1)._kind_6.sons.p->data[((NI)0)], T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		addDecl__lookups_u3789(c_p0, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD_ = eqdup___ast_u4580(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		im_1.m = colontmpD_;
		im_1.mode = ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1);
		initIntSet__pureZcollectionsZintsets_u598((&im_1._mode_2.imported));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			i_2 = ((NI)1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA10;
					i_1 = i_2;
					{
						if (!!(((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23)))) goto LA13_;
						importSymbol__importer_u1600(c_p0, (*n_p1)._kind_6.sons.p->data[i_1], m_1, (&im_1._mode_2.imported));
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					}
LA13_: ;
					i_2 += ((NI)1);
				} LA10: ;
			}
		}
		nimZeroMem((void*)(&blitTmp_1), sizeof(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw));
		blitTmp_1 = im_1;
		eqwasMoved___semdata_u2994((&im_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		addImport__importer_u1640(c_p0, (&blitTmp_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		afterImport__importer_u3761(c_p0, m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___semdata_u2997((&im_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
