/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#include <glob.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_Table__g39amaj5esSUbnvSF2f9bVgg tyObject_Table__g39amaj5esSUbnvSF2f9bVgg;
typedef struct tySequence__FGxE1Nuen6pVDc58PZudJw tySequence__FGxE1Nuen6pVDc58PZudJw;
typedef struct tySequence__FGxE1Nuen6pVDc58PZudJw_Content tySequence__FGxE1Nuen6pVDc58PZudJw_Content;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyTuple__odFiRrDKhZPQ2taWAayfYw tyTuple__odFiRrDKhZPQ2taWAayfYw;
typedef struct tyTuple__8TaWyfF78pGKQc2T027bVA tyTuple__8TaWyfF78pGKQc2T027bVA;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw;
typedef struct tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw;
typedef struct tyObject_TimezonecolonObjectType___ya1basfKboI1SCTDnQ7Mzg tyObject_TimezonecolonObjectType___ya1basfKboI1SCTDnQ7Mzg;
typedef struct tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA;
typedef struct tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw;
typedef struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyTuple__7xc1P89akJWzo77UAKrb3aA tyTuple__7xc1P89akJWzo77UAKrb3aA;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ {
	tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* data;
};
struct tySequence__FGxE1Nuen6pVDc58PZudJw {
  NI len; tySequence__FGxE1Nuen6pVDc58PZudJw_Content* p;
};
struct tyObject_Table__g39amaj5esSUbnvSF2f9bVgg {
	tySequence__FGxE1Nuen6pVDc58PZudJw data;
	NI counter;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA;
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
typedef tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw tyArray__jQ6Zibb0SzsKfL1Qwwi9bag[4];
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NimStringV2 tyArray__vYAGu69beqgbaFYLoxcYiEw[13];
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
typedef NCSTRING tyUncheckedArray__nvS6J9clHMUMHfoZd8Ad2zg[1];
typedef NU8 tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw;
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ;
struct tyTuple__odFiRrDKhZPQ2taWAayfYw {
	NimStringV2 Field0;
	NI Field1;
	tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ Field2;
	NI Field3;
	NI Field4;
};
typedef tyTuple__odFiRrDKhZPQ2taWAayfYw tyArray__BJ38CrWfGxMtyd3CSynibg[29];
typedef NU8 tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg;
struct tyTuple__8TaWyfF78pGKQc2T027bVA {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NimStringV2 Field5;
	NimStringV2 Field6;
	NimStringV2 Field7;
	NimStringV2 Field8;
	NimStringV2 Field9;
	NimStringV2 Field10;
	NimStringV2 Field11;
	tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg Field12;
};
typedef tyTuple__8TaWyfF78pGKQc2T027bVA tyArray__RQFn3NKTp5P7VzZ9bksPIyA[34];
typedef NU8 tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg;
typedef NimStringV2 tyArray__CVH4DKy6jsFwcdfgh9ceJxQ[16];
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tyEnum_PrefixMatch__ocee5pBJwvwPKYUp2SRA4g;
struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA {
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng section;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ qualifiedPath;
	NimStringV2* name;
	NimStringV2 filePath;
	NI line;
	NI column;
	NimStringV2 doc;
	NimStringV2 forth;
	NI quality;
	NIM_BOOL isGlobal;
	NIM_BOOL contextFits;
	tyEnum_PrefixMatch__ocee5pBJwvwPKYUp2SRA4g prefix;
	NU8 symkind;
	NI scope;
	NI localUsages;
	NI globalUsages;
	NI tokenLen;
	NI version;
	NU16 endLine;
	NI endCol;
	tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw* inlayHintInfo;
};
typedef NU8 tyEnum_SuggestInlayHintKind__jagzSIzxhae5PXBOg9atNeg;
struct tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw {
	tyEnum_SuggestInlayHintKind__jagzSIzxhae5PXBOg9atNeg kind;
	NI line;
	NI column;
	NimStringV2 label;
	NIM_BOOL paddingLeft;
	NIM_BOOL paddingRight;
	NIM_BOOL allowInsert;
	NimStringV2 tooltip;
};
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef NU8 tyEnum_WeekDay__vRTkENUWHrOhVsRbWk62QA;
struct tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw {
	RootObj Sup;
	NI nanosecond;
	NI second;
	NI minute;
	NI hour;
	NI monthdayZero;
	NI monthZero;
	NI year;
	tyEnum_WeekDay__vRTkENUWHrOhVsRbWk62QA weekday;
	NI yearday;
	NIM_BOOL isDst;
	tyObject_TimezonecolonObjectType___ya1basfKboI1SCTDnQ7Mzg* timezone;
	NI utcOffset;
};
struct tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA {
	NI64 seconds;
	NI nanosecond;
};
struct tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw {
	NF time;
	NI count;
};
struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ {
	NI len;
	void* p;
};
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyTuple__7xc1P89akJWzo77UAKrb3aA {
	NI Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
	tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw Field2;
};
struct tySequence__FGxE1Nuen6pVDc58PZudJw_Content { NI cap; tyTuple__7xc1P89akJWzo77UAKrb3aA data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u911)(tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u802)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1553)(tySequence__xOJ2kx2lq9bBfIm3IXnde3Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5506)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1370)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1868)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1204)(tySequence__4eRCaZmrYLLw2k30GPTiMw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u2052)(tySequence__hTEiKNj3evQAjIXUI21elA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u566)(tySequence__7lEisrXlQEzwtUKW5pzRCw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u1841)(tySequence__E0kio2ZnplNTuln9bsnljSA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg*, nstnewStringTable)(tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA mode_p0);
N_LIB_PRIVATE N_NIMCALL(void, initMsgConfig__lineinfos_u392)(tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw, initHashSet__options_u1051)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ*, newProfileData__options_u660)(void);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObjUninit)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg*, newTable__options_u678)(NI initialSize_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, initConfigRefCommon__options_u962)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, setTargetFromSystem__platform_u942)(tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA* t_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isatty__pureZterminal_u637)(FILE* f_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getRelativePathFromConfigPath__options_u3934)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL isTitle_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u3939)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosjoinPath)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, noslastPathPart)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NI, noscmpPaths)(NimStringV2 pathA_p0, NimStringV2 pathB_p1);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringV2 path_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZos_u200)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u4029)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isRelativeTo__stdZprivateZospaths2_u159)(NimStringV2 path_p0, NimStringV2 base_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosrelativePath)(NimStringV2 path_p0, NimStringV2 base_p1, NIM_CHAR sep_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosparentDir)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimbleFile__options_u3711)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsthasKey)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2*, nstTake)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cstrToNimstr)(NCSTRING str_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nstPut)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1, NimStringV2 val_p2);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_u139)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, relativeTo__pathutils_u196)(NimStringV2 fullPath_p0, NimStringV2 baseFilename_p1, NIM_CHAR sep_p2);
static N_INLINE(NIM_BOOL, isEmpty__options_u3633)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuNormalize)(NimStringV2 s_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringV2 s_p0);
static N_INLINE(NIM_CHAR, X5BX5D___system_u8066)(NimStringV2 s_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8651)(NimStringV2 s_p0, NI first_p1, NI last_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, removeTrailingDirSep__options_u3681)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetHomeDir)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, expandTilde__pureZos_u35)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosunixToNativePath)(NimStringV2 path_p0, NimStringV2 drive_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPrefixDir__options_u3645)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, nossplitPath)(NimStringV2 path_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetAppDir)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___options_u3652)(NimStringV2 x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZprivateZospaths2_u306)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimcacheDir__options_u3737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, slash___pathutils_u166)(NimStringV2 base_p0, NimStringV2 f_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOsCacheDir__options_u3735)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getEnv__stdZenvvars_u16)(NimStringV2 key_p0, NimStringV2 default_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimcacheSuffix__options_u3740)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u1391)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawFindFile__options_u3827)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL suppressStdlib_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringV2 s_p0, NimStringV2 prefix_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, slash___pathutils_u135)(NimStringV2 base_p0, NimStringV2 f_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonicalizePath__options_u3669)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosexpandFilename)(NimStringV2 filename_p0);
static N_INLINE(NIM_BOOL, isEmpty__options_u4086)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuToLowerAsciiStr)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawFindFile2__options_u3871)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nstlen)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPackageName__options_u3730)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1);
N_LIB_PRIVATE N_NIMCALL(void, splitFile__pathutils_u39)(NimStringV2 x_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pathutils_u73)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, noscreateDir)(NimStringV2 dir_p0);
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, quit__system_u7994)(NimStringV2 errormsg_p0, NI errorcode_p1);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3661)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, noschangeFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOrDefault__pureZstrtabs_u390)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1, NimStringV2 default_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosaddFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findFile__options_u4081)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL suppressStdlib_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8664)(NimStringV2 s_p0, NI first_p1);
static N_INLINE(NIM_BOOL, startsWith__pureZstrutils_u1394)(NimStringV2 s_p0, NIM_CHAR prefix_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonDynlibName__options_u4258)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindCharSet)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p1, NI start_p2, NI last_p3);
N_LIB_PRIVATE N_NIMCALL(void, incl__options_u2181)(tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw* s_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11820)(tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetCurrentDir)(void);
static N_INLINE(void, nimIncRef)(void* p_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findExe__pureZos_u76)(NimStringV2 exe_p0, NIM_BOOL followSymlinks_p1, NimStringV2* extensions_p2, NI extensions_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11782)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* dest_p0);
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, format__options_u645)(tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw* dt_p0);
N_LIB_PRIVATE N_NIMCALL(void, getSrcTimestamp__options_u641)(tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw* Result);
N_LIB_PRIVATE N_NIMCALL(void, utc__pureZtimes_u2061)(tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA t_p0, tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA, fromUnix__pureZtimes_u1237)(NI64 unix_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA, getTime__pureZtimes_u1291)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZtimes_u1713)(tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, format__options_u653)(tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw* dt_p0);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__stdZassertions_u79)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosdirExists)(NimStringV2 dir_p0);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonicalImportAux__options_u4231)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 file_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nativeToUnixPath__stdZprivateZglobs_u96)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, absOutFile__options_u3622)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u1889)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1);
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_2 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_3 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_4 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_5 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_4};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_6 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_7 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_6};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_8 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_6};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_9 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_6};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_10 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_6};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_11 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_12 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_6};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_13 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_14 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_13};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_15 = { 9 | NIM_STRLIT_FLAG, "stdinfile" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_16 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_15};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_17 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_18 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_19 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_20 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_21 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_22 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_23 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_24 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_25 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static NIM_CONST tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw TM__zQHipMPUXFgsDrLbMR9atnA_26 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x02, 0xc0, 0x00, 0x02, 0x04}
;
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_27 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_28 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_27};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_29 = { 4 | NIM_STRLIT_FLAG, "pure" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_30 = { 4 | NIM_STRLIT_FLAG, "core" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_31 = { 4 | NIM_STRLIT_FLAG, "arch" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_32 = { 16 | NIM_STRLIT_FLAG, "pure/collections" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_33 = { 16 | NIM_STRLIT_FLAG, "pure/concurrency" };
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_34 = { 14 | NIM_STRLIT_FLAG, "pure/unidecode" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_35 = { 6 | NIM_STRLIT_FLAG, "impure" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_36 = { 8 | NIM_STRLIT_FLAG, "wrappers" };
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_37 = { 18 | NIM_STRLIT_FLAG, "wrappers/linenoise" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_38 = { 7 | NIM_STRLIT_FLAG, "windows" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_39 = { 5 | NIM_STRLIT_FLAG, "posix" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_40 = { 2 | NIM_STRLIT_FLAG, "js" };
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_41 = { 15 | NIM_STRLIT_FLAG, "deprecated/pure" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_42 = { 4 | NIM_STRLIT_FLAG, "std/" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_43 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_42};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_44 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_45 = { 8 | NIM_STRLIT_FLAG, "*.nimble" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_46 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_45};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_47 = { 3 | NIM_STRLIT_FLAG, "x86" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_48 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_47};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_49 = { 7 | NIM_STRLIT_FLAG, "itanium" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_50 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_49};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_51 = { 5 | NIM_STRLIT_FLAG, "x8664" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_52 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_51};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_53 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_39};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_54 = { 4 | NIM_STRLIT_FLAG, "unix" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_55 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_54};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_56 = { 5 | NIM_STRLIT_FLAG, "linux" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_57 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_56};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_58 = { 3 | NIM_STRLIT_FLAG, "bsd" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_59 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_58};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_60 = { 7 | NIM_STRLIT_FLAG, "freebsd" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_61 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_60};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_62 = { 18 | NIM_STRLIT_FLAG, "emulatedthreadvars" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_63 = {18, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_62};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_64 = { 5 | NIM_STRLIT_FLAG, "msdos" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_65 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_64};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_66 = { 9 | NIM_STRLIT_FLAG, "mswindows" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_67 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_66};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_68 = { 5 | NIM_STRLIT_FLAG, "win32" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_69 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_68};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_70 = { 9 | NIM_STRLIT_FLAG, "macintosh" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_71 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_70};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_72 = { 3 | NIM_STRLIT_FLAG, "osx" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_73 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_72};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_74 = { 6 | NIM_STRLIT_FLAG, "macosx" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_75 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_74};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_76 = { 5 | NIM_STRLIT_FLAG, "sunos" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_77 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_76};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_78 = { 14 | NIM_STRLIT_FLAG, "nintendoswitch" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_79 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_78};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_80 = { 8 | NIM_STRLIT_FLAG, "freertos" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_81 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_80};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_82 = { 4 | NIM_STRLIT_FLAG, "lwip" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_83 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_82};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_84 = { 6 | NIM_STRLIT_FLAG, "zephyr" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_85 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_84};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_86 = { 5 | NIM_STRLIT_FLAG, "nuttx" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_87 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_86};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_88 = { 12 | NIM_STRLIT_FLAG, "littleendian" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_89 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_88};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_90 = { 9 | NIM_STRLIT_FLAG, "bigendian" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_91 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_90};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_92 = { 4 | NIM_STRLIT_FLAG, "cpu8" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_93 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_92};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_94 = { 5 | NIM_STRLIT_FLAG, "cpu16" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_95 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_94};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_96 = { 5 | NIM_STRLIT_FLAG, "cpu32" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_97 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_96};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_98 = { 5 | NIM_STRLIT_FLAG, "cpu64" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_99 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_98};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_100 = { 12 | NIM_STRLIT_FLAG, "nimrawsetjmp" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_101 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_100};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_102 = { 3 | NIM_STRLIT_FLAG, "nim" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_103 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_102};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_104 = { 4 | NIM_STRLIT_FLAG, "/usr" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_105 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_104};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_106 = { 12 | NIM_STRLIT_FLAG, "/usr/lib/nim" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_107 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_106};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_108 = { 10 | NIM_STRLIT_FLAG, "/usr/local" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_109 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_108};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_110 = { 18 | NIM_STRLIT_FLAG, "/usr/local/lib/nim" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_111 = {18, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_110};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_112 = { 3 | NIM_STRLIT_FLAG, "lib" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_113 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_112};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_114 = { 4 | NIM_STRLIT_FLAG, "home" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_115 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_114};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_116 = { 6 | NIM_STRLIT_FLAG, "config" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_117 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_116};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_118 = { 11 | NIM_STRLIT_FLAG, "projectname" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_119 = {11, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_118};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_120 = { 11 | NIM_STRLIT_FLAG, "projectpath" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_121 = {11, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_120};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_122 = { 10 | NIM_STRLIT_FLAG, "projectdir" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_123 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_122};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_124 = { 8 | NIM_STRLIT_FLAG, "nimcache" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_125 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_124};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_126 = { 8 | NIM_STRLIT_FLAG, "nimcache" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_127 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_126};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_128 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_126};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_129 = { 14 | NIM_STRLIT_FLAG, "XDG_CACHE_HOME" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_130 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_129};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_131 = { 6 | NIM_STRLIT_FLAG, ".cache" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_132 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_131};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_133 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_102};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_134 = { 6 | NIM_STRLIT_FLAG, "_check" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_135 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_134};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_136 = { 7 | NIM_STRLIT_FLAG, "release" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_137 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_136};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_138 = { 6 | NIM_STRLIT_FLAG, "danger" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_139 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_138};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_140 = { 2 | NIM_STRLIT_FLAG, "_r" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_141 = {2, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_140};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_142 = { 2 | NIM_STRLIT_FLAG, "_d" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_143 = {2, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_142};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_144 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_145 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_13};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_146 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_13};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_147 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_13};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_148 = { 7 | NIM_STRLIT_FLAG, "unknown" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_149 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_148};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_150 = { 1 | NIM_STRLIT_FLAG, "_" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_151 = {1, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_150};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_152 = { 8 | NIM_STRLIT_FLAG, "nimDebug" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_153 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_152};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_154 = { 25 | NIM_STRLIT_FLAG, "cannot create directory: " };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_155 = {25, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_154};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_156 = {25, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_154};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_157 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_158 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_157};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_159 = { 1 | NIM_STRLIT_FLAG, "c" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_160 = {1, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_159};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_161 = { 3 | NIM_STRLIT_FLAG, "cpp" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_162 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_161};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_163 = { 2 | NIM_STRLIT_FLAG, "js" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_164 = {2, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_163};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_165 = { 4 | NIM_STRLIT_FLAG, "objc" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_166 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_165};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_167 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_157};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_168 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_102};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_169 = { 4 | NIM_STRLIT_FLAG, "pkg/" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_170 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_169};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_171 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_42};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_172 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_173 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_172};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_174 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_172};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_175 = {1, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_150};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_176 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_112};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__zQHipMPUXFgsDrLbMR9atnA_177 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x43, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_178 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_179 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_178};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_180 = { 12 | NIM_STRLIT_FLAG, "dotOperators" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_181 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_180};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_182 = { 12 | NIM_STRLIT_FLAG, "callOperator" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_183 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_182};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_184 = { 8 | NIM_STRLIT_FLAG, "parallel" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_185 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_184};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_186 = { 10 | NIM_STRLIT_FLAG, "destructor" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_187 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_186};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_188 = { 6 | NIM_STRLIT_FLAG, "notnil" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_189 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_188};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_190 = { 14 | NIM_STRLIT_FLAG, "dynamicBindSym" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_191 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_190};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_192 = { 13 | NIM_STRLIT_FLAG, "forLoopMacros" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_193 = {13, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_192};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_194 = { 14 | NIM_STRLIT_FLAG, "caseStmtMacros" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_195 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_194};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_196 = { 14 | NIM_STRLIT_FLAG, "codeReordering" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_197 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_196};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_198 = { 14 | NIM_STRLIT_FLAG, "compiletimeFFI" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_199 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_198};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_200 = { 11 | NIM_STRLIT_FLAG, "vmopsDanger" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_201 = {11, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_200};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_202 = { 11 | NIM_STRLIT_FLAG, "strictFuncs" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_203 = {11, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_202};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_204 = { 5 | NIM_STRLIT_FLAG, "views" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_205 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_204};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_206 = { 12 | NIM_STRLIT_FLAG, "strictNotNil" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_207 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_206};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_208 = { 17 | NIM_STRLIT_FLAG, "overloadableEnums" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_209 = {17, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_208};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_210 = { 13 | NIM_STRLIT_FLAG, "strictEffects" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_211 = {13, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_210};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_212 = { 16 | NIM_STRLIT_FLAG, "unicodeOperators" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_213 = {16, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_212};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_214 = { 22 | NIM_STRLIT_FLAG, "flexibleOptionalParams" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_215 = {22, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_214};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_216 = { 10 | NIM_STRLIT_FLAG, "strictDefs" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_217 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_216};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_218 = { 17 | NIM_STRLIT_FLAG, "strictCaseObjects" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_219 = {17, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_218};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_220 = { 17 | NIM_STRLIT_FLAG, "inferGenericTypes" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_221 = {17, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_220};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_222 = { 7 | NIM_STRLIT_FLAG, "openSym" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_223 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_222};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_224 = { 15 | NIM_STRLIT_FLAG, "genericsOpenSym" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_225 = {15, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_224};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_226 = { 7 | NIM_STRLIT_FLAG, "vtables" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_227 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_226};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_228 = { 12 | NIM_STRLIT_FLAG, "typeBoundOps" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_229 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_228};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_230 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_157};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_231 = { 3 | NIM_STRLIT_FLAG, "lib" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_232 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_231};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_233 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_102};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_234 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_112};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_235 = { 10 | NIM_STRLIT_FLAG, "system.nim" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_236 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_235};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_237 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_235};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_238 = { 4 | NIM_STRLIT_FLAG, "Type" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_239 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_238};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_240 = { 9 | NIM_STRLIT_FLAG, "Parameter" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_241 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_240};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_242 = { 9 | NIM_STRLIT_FLAG, "Exception" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_243 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_242};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_244 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_157};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_245 = { 3 | NIM_STRLIT_FLAG, "sug" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_246 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_245};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_247 = { 3 | NIM_STRLIT_FLAG, "con" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_248 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_247};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_249 = { 3 | NIM_STRLIT_FLAG, "def" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_250 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_249};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_251 = { 3 | NIM_STRLIT_FLAG, "use" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_252 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_251};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_253 = { 3 | NIM_STRLIT_FLAG, "dus" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_254 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_253};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_255 = { 3 | NIM_STRLIT_FLAG, "chk" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_256 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_255};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_257 = { 7 | NIM_STRLIT_FLAG, "chkFile" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_258 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_257};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_259 = { 3 | NIM_STRLIT_FLAG, "mod" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_260 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_259};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_261 = { 4 | NIM_STRLIT_FLAG, "none" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_262 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_261};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_263 = { 9 | NIM_STRLIT_FLAG, "highlight" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_264 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_263};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_265 = { 7 | NIM_STRLIT_FLAG, "outline" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_266 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_265};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_267 = { 5 | NIM_STRLIT_FLAG, "known" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_268 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_267};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_269 = { 3 | NIM_STRLIT_FLAG, "msg" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_270 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_269};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_271 = { 7 | NIM_STRLIT_FLAG, "project" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_272 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_271};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_273 = { 13 | NIM_STRLIT_FLAG, "globalSymbols" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_274 = {13, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_273};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_275 = { 11 | NIM_STRLIT_FLAG, "declaration" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_276 = {11, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_275};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_277 = { 6 | NIM_STRLIT_FLAG, "expand" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_278 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_277};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_279 = { 9 | NIM_STRLIT_FLAG, "recompile" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_280 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_279};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_281 = { 7 | NIM_STRLIT_FLAG, "changed" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_282 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_281};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_283 = { 4 | NIM_STRLIT_FLAG, "type" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_284 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_283};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_285 = { 10 | NIM_STRLIT_FLAG, "inlayHints" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_286 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_285};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_287 = { 10 | NIM_STRLIT_FLAG, "unselected" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_288 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_287};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_289 = { 4 | NIM_STRLIT_FLAG, "none" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_290 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_289};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_291 = { 5 | NIM_STRLIT_FLAG, "boehm" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_292 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_291};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_293 = { 7 | NIM_STRLIT_FLAG, "regions" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_294 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_293};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_295 = { 3 | NIM_STRLIT_FLAG, "arc" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_296 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_295};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_297 = { 3 | NIM_STRLIT_FLAG, "orc" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_298 = {3, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_297};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_299 = { 9 | NIM_STRLIT_FLAG, "atomicArc" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_300 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_299};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_301 = { 12 | NIM_STRLIT_FLAG, "markAndSweep" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_302 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_301};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_303 = { 5 | NIM_STRLIT_FLAG, "hooks" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_304 = {5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_303};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_305 = { 4 | NIM_STRLIT_FLAG, "refc" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_306 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_305};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_307 = { 2 | NIM_STRLIT_FLAG, "go" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_308 = {2, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_307};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_309 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_157};
extern TNimTypeV2 NTIv2__JiByOtYhsb3evWoWLWfUBw_;
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_310 = { 17 | NIM_STRLIT_FLAG, "SOURCE_DATE_EPOCH" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_311 = {17, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_310};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_312 = { 12 | NIM_STRLIT_FLAG, "not a number" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_313 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_312};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_314 = { 46 | NIM_STRLIT_FLAG, "options.nim(728, 3) `not conf.outDir.isEmpty` " };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_315 = {46, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_314};
static const struct {
  NI cap; NIM_CHAR data[47+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_316 = { 47 | NIM_STRLIT_FLAG, "options.nim(729, 3) `not conf.outFile.isEmpty` " };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_317 = {47, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_316};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_318 = { 4 | NIM_STRLIT_FLAG, ".out" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_319 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_318};
static const struct {
  NI cap; NIM_CHAR data[49+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_320 = { 49 | NIM_STRLIT_FLAG, "options.nim(724, 3) `conf.outDir.string.len > 0` " };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_321 = {49, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_320};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_322 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_2};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_323 = { 7 | NIM_STRLIT_FLAG, "cmdNone" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_324 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_323};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_325 = { 10 | NIM_STRLIT_FLAG, "cmdUnknown" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_326 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_325};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_327 = { 13 | NIM_STRLIT_FLAG, "cmdCompileToC" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_328 = {13, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_327};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_329 = { 15 | NIM_STRLIT_FLAG, "cmdCompileToCpp" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_330 = {15, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_329};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_331 = { 14 | NIM_STRLIT_FLAG, "cmdCompileToOC" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_332 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_331};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_333 = { 14 | NIM_STRLIT_FLAG, "cmdCompileToJS" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_334 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_333};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_335 = { 7 | NIM_STRLIT_FLAG, "cmdCrun" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_336 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_335};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_337 = { 6 | NIM_STRLIT_FLAG, "cmdTcc" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_338 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_337};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_339 = { 8 | NIM_STRLIT_FLAG, "cmdCheck" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_340 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_339};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_341 = { 4 | NIM_STRLIT_FLAG, "cmdM" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_342 = {4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_341};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_343 = { 8 | NIM_STRLIT_FLAG, "cmdParse" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_344 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_343};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_345 = { 6 | NIM_STRLIT_FLAG, "cmdRod" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_346 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_345};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_347 = { 11 | NIM_STRLIT_FLAG, "cmdIdeTools" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_348 = {11, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_347};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_349 = { 12 | NIM_STRLIT_FLAG, "cmdNimscript" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_350 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_349};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_351 = { 7 | NIM_STRLIT_FLAG, "cmdDoc0" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_352 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_351};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_353 = { 6 | NIM_STRLIT_FLAG, "cmdDoc" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_354 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_353};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_355 = { 10 | NIM_STRLIT_FLAG, "cmdDoc2tex" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_356 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_355};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_357 = { 11 | NIM_STRLIT_FLAG, "cmdRst2html" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_358 = {11, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_357};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_359 = { 10 | NIM_STRLIT_FLAG, "cmdRst2tex" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_360 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_359};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_361 = { 10 | NIM_STRLIT_FLAG, "cmdMd2html" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_362 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_361};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_363 = { 9 | NIM_STRLIT_FLAG, "cmdMd2tex" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_364 = {9, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_363};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_365 = { 11 | NIM_STRLIT_FLAG, "cmdJsondoc0" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_366 = {11, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_365};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_367 = { 10 | NIM_STRLIT_FLAG, "cmdJsondoc" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_368 = {10, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_367};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_369 = { 8 | NIM_STRLIT_FLAG, "cmdCtags" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_370 = {8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_369};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_371 = { 13 | NIM_STRLIT_FLAG, "cmdBuildindex" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_372 = {13, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_371};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_373 = { 12 | NIM_STRLIT_FLAG, "cmdGendepend" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_374 = {12, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_373};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_375 = { 7 | NIM_STRLIT_FLAG, "cmdDump" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_376 = {7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_375};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_377 = { 14 | NIM_STRLIT_FLAG, "cmdInteractive" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_378 = {14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_377};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_379 = { 6 | NIM_STRLIT_FLAG, "cmdNop" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_380 = {6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_379};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__zQHipMPUXFgsDrLbMR9atnA_381 = { 13 | NIM_STRLIT_FLAG, "cmdJsonscript" };
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_382 = {13, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_381};
static const NimStringV2 TM__zQHipMPUXFgsDrLbMR9atnA_383 = {0, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_157};
extern NIM_CONST tyArray__jQ6Zibb0SzsKfL1Qwwi9bag NotesVerbosity__lineinfos_u228;
N_LIB_PRIVATE NIM_CONST tyArray__vYAGu69beqgbaFYLoxcYiEw stdlibDirs__options_u3931 = {{4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_29},
{4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_30},
{4, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_31},
{16, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_32},
{16, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_33},
{14, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_34},
{6, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_35},
{8, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_36},
{18, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_37},
{7, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_38},
{5, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_39},
{2, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_40},
{15, (NimStrPayload*)&TM__zQHipMPUXFgsDrLbMR9atnA_41}}
;
extern NIM_CONST tyArray__BJ38CrWfGxMtyd3CSynibg CPU__platform_u740;
extern NIM_CONST tyArray__RQFn3NKTp5P7VzZ9bksPIyA OS__platform_u534;
extern NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA ExeExts__pureZos_u75;
extern NIM_BOOL nimInErrorMode__system_u4143;
extern Exception* currException__system_u3628;
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u911)(tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0.data);
		if (!T3_) goto LA4_;
		eqdestroy___options_u802((*dest_p0.data));
		nimRawDispose(dest_p0.data, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1868)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_]);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NimStringV2));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).currentConfigDir);
	eqdestroy___system_u2691((*dest_p0).expandNodeResult);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0).vmProfileData);
		if (!T3_) goto LA4_;
		eqdestroy___options_u911((*(*dest_p0).vmProfileData));
		nimRawDispose((*dest_p0).vmProfileData, ((NI)8));
	}
LA4_: ;
	eqdestroy___system_u2691((*dest_p0).nimMainPrefix);
	eqdestroy___system_u2691((*dest_p0).cppCustomNamespace);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastCyclicDyn((*dest_p0).structuredErrorHook.ClE_0);
		if (!T8_) goto LA9_;
		nimDestroyAndDispose((*dest_p0).structuredErrorHook.ClE_0);
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastCyclicDyn((*dest_p0).writelnHook.ClE_0);
		if (!T13_) goto LA14_;
		nimDestroyAndDispose((*dest_p0).writelnHook.ClE_0);
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastCyclicDyn((*dest_p0).suggestionResultHook.ClE_0);
		if (!T18_) goto LA19_;
		nimDestroyAndDispose((*dest_p0).suggestionResultHook.ClE_0);
	}
LA19_: ;
	eqdestroy___options_u1553((*dest_p0).toCompile);
	eqdestroy___system_u2691((*dest_p0).cCompilerPath);
	eqdestroy___system_u2691((*dest_p0).compileOptions);
	eqdestroy___system_u2691((*dest_p0).linkOptions);
	eqdestroy___system_u5506((*dest_p0).compileOptionsCmd);
	eqdestroy___system_u2691((*dest_p0).linkOptionsCmd);
	eqdestroy___system_u5506((*dest_p0).externalToLink);
	eqdestroy___system_u5506((*dest_p0).cLinkedLibs);
	eqdestroy___options_u1370((*dest_p0).cLibs);
	eqdestroy___options_u1370((*dest_p0).cIncludes);
	eqdestroy___options_u1868((*dest_p0).configFiles);
	eqdestroy___system_u2691((*dest_p0).docCmd);
	eqdestroy___system_u2691((*dest_p0).docRoot);
	eqdestroy___system_u2691((*dest_p0).docSeeSrcUrl);
	eqdestroy___system_u5506((*dest_p0).implicitIncludes);
	eqdestroy___system_u5506((*dest_p0).implicitImports);
	eqdestroy___system_u5506((*dest_p0).extraCmds);
	eqdestroy___system_u2691((*dest_p0).commandLine);
	eqdestroy___system_u5506((*dest_p0).commandArgs);
	eqdestroy___system_u2691((*dest_p0).command);
	eqdestroy___system_u2691((*dest_p0).stdinFile);
	eqdestroy___system_u2691((*dest_p0).projectFull);
	eqdestroy___system_u2691((*dest_p0).projectPath);
	eqdestroy___system_u2691((*dest_p0).projectName);
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastCyclicDyn((*dest_p0).cfileSpecificOptions);
		if (!T23_) goto LA24_;
		nimDestroyAndDispose((*dest_p0).cfileSpecificOptions);
	}
LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLastCyclicDyn((*dest_p0).moduleOverrides);
		if (!T28_) goto LA29_;
		nimDestroyAndDispose((*dest_p0).moduleOverrides);
	}
LA29_: ;
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = nimDecRefIsLastCyclicDyn((*dest_p0).dllOverrides);
		if (!T33_) goto LA34_;
		nimDestroyAndDispose((*dest_p0).dllOverrides);
	}
LA34_: ;
	eqdestroy___system_u2691((*dest_p0).nimcacheDir);
	eqdestroy___system_u2691((*dest_p0).libpath);
	eqdestroy___system_u2691((*dest_p0).prefixDir);
	eqdestroy___system_u2691((*dest_p0).jsonBuildFile);
	eqdestroy___system_u2691((*dest_p0).outDir);
	eqdestroy___system_u2691((*dest_p0).outFile);
	eqdestroy___options_u1370((*dest_p0).lazyPaths);
	eqdestroy___options_u1370((*dest_p0).searchPaths);
	eqdestroy___options_u1370((*dest_p0).nimblePaths);
	{
		NIM_BOOL T38_;
		T38_ = (NIM_BOOL)0;
		T38_ = nimDecRefIsLastCyclicDyn((*dest_p0).packageCache);
		if (!T38_) goto LA39_;
		nimDestroyAndDispose((*dest_p0).packageCache);
	}
LA39_: ;
	{
		NIM_BOOL T43_;
		T43_ = (NIM_BOOL)0;
		T43_ = nimDecRefIsLastCyclicDyn((*dest_p0).symbols);
		if (!T43_) goto LA44_;
		nimDestroyAndDispose((*dest_p0).symbols);
	}
LA44_: ;
	{
		NIM_BOOL T48_;
		T48_ = (NIM_BOOL)0;
		T48_ = nimDecRefIsLastCyclicDyn((*dest_p0).configVars);
		if (!T48_) goto LA49_;
		nimDestroyAndDispose((*dest_p0).configVars);
	}
LA49_: ;
	eqdestroy___system_u2691((*dest_p0).arguments);
	eqdestroy___system_u2691((*dest_p0).nimbasePattern);
	eqdestroy___system_u2691((*dest_p0).headerFile);
	eqdestroy___options_u1204((*dest_p0).cppDefines.data);
	eqdestroy___system_u2691((*dest_p0).cmdInput);
	eqdestroy___system_u2691((*dest_p0).unitSep);
	eqdestroy___lineinfos_u2052((*dest_p0).m.fileInfos);
	eqdestroy___lineinfos_u566((*dest_p0).m.filenameToIndexTbl.data);
	eqdestroy___lineinfos_u1841((*dest_p0).m.msgContext);
	{
		NIM_BOOL T53_;
		T53_ = (NIM_BOOL)0;
		T53_ = nimDecRefIsLastCyclicDyn((*dest_p0).arcToExpand);
		if (!T53_) goto LA54_;
		nimDestroyAndDispose((*dest_p0).arcToExpand);
	}
LA54_: ;
	{
		NIM_BOOL T58_;
		T58_ = (NIM_BOOL)0;
		T58_ = nimDecRefIsLastCyclicDyn((*dest_p0).macrosToExpand);
		if (!T58_) goto LA59_;
		nimDestroyAndDispose((*dest_p0).macrosToExpand);
	}
LA59_: ;
	eqdestroy___system_u2691((*dest_p0).target.tnl);
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ*, newProfileData__options_u660)(void) {
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* result;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ*) nimNewObjUninit(sizeof(tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ), NIM_ALIGNOF(tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ));
	(*T1_).data = newTable__options_u678(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
N_LIB_PRIVATE N_NIMCALL(void, initConfigRefCommon__options_u962)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	(*conf_p0).selectedGC = ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)0);
	(*conf_p0).verbosity = ((NI)1);
	(*conf_p0).hintProcessingDots = NIM_TRUE;
	(*conf_p0).options = 76180606;
	(*conf_p0).globalOptions = IL64(360288039043334144);
	(*conf_p0).filenameOption = ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)0);
	nimCopyMem((void*)(*conf_p0).foreignPackageNotes, (NIM_CONST void*)TM__zQHipMPUXFgsDrLbMR9atnA_26, 13);
	nimCopyMem((void*)(*conf_p0).notes, (NIM_CONST void*)NotesVerbosity__lineinfos_u228[(((NI)1))- 0], 13);
	nimCopyMem((void*)(*conf_p0).mainPackageNotes, (NIM_CONST void*)NotesVerbosity__lineinfos_u228[(((NI)1))- 0], 13);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*, newConfigRef__options_u1040)(void) {
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* result;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) nimNewObj(sizeof(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg), NIM_ALIGNOF(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg));
	(*T1_).cCompiler = ((tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA)1);
	(*T1_).macrosToExpand = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).arcToExpand = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	initMsgConfig__lineinfos_u392((&(*T1_).m));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).cppDefines = initHashSet__options_u1051(((NI)64));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).headerFile = TM__zQHipMPUXFgsDrLbMR9atnA_3;
	(*T1_).features = 0;
	(*T1_).legacyFeatures = 0;
	(*T1_).configVars = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).symbols = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).packageCache = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).searchPaths.len = 0; (*T1_).searchPaths.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).lazyPaths.len = 0; (*T1_).lazyPaths.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).outFile = TM__zQHipMPUXFgsDrLbMR9atnA_5;
	(*T1_).outDir = TM__zQHipMPUXFgsDrLbMR9atnA_7;
	(*T1_).prefixDir = TM__zQHipMPUXFgsDrLbMR9atnA_8;
	(*T1_).libpath = TM__zQHipMPUXFgsDrLbMR9atnA_9;
	(*T1_).nimcacheDir = TM__zQHipMPUXFgsDrLbMR9atnA_10;
	(*T1_).dllOverrides = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).moduleOverrides = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).cfileSpecificOptions = nstnewStringTable(((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).projectName = TM__zQHipMPUXFgsDrLbMR9atnA_11;
	(*T1_).projectPath = TM__zQHipMPUXFgsDrLbMR9atnA_12;
	(*T1_).projectFull = TM__zQHipMPUXFgsDrLbMR9atnA_14;
	(*T1_).projectIsStdin = NIM_FALSE;
	(*T1_).stdinFile = TM__zQHipMPUXFgsDrLbMR9atnA_16;
	(*T1_).projectMainIdx = ((NI32)0);
	(*T1_).command = TM__zQHipMPUXFgsDrLbMR9atnA_17;
	(*T1_).commandArgs.len = 0; (*T1_).commandArgs.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).commandLine = TM__zQHipMPUXFgsDrLbMR9atnA_18;
	(*T1_).implicitImports.len = 0; (*T1_).implicitImports.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).implicitIncludes.len = 0; (*T1_).implicitIncludes.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).docSeeSrcUrl = TM__zQHipMPUXFgsDrLbMR9atnA_19;
	(*T1_).cIncludes.len = 0; (*T1_).cIncludes.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).cLibs.len = 0; (*T1_).cLibs.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).cLinkedLibs.len = 0; (*T1_).cLinkedLibs.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).backend = ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)0);
	(*T1_).externalToLink.len = 0; (*T1_).externalToLink.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).linkOptionsCmd = TM__zQHipMPUXFgsDrLbMR9atnA_20;
	(*T1_).compileOptionsCmd.len = 0; (*T1_).compileOptionsCmd.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	(*T1_).linkOptions = TM__zQHipMPUXFgsDrLbMR9atnA_21;
	(*T1_).compileOptions = TM__zQHipMPUXFgsDrLbMR9atnA_22;
	(*T1_).cCompilerPath = TM__zQHipMPUXFgsDrLbMR9atnA_23;
	(*T1_).toCompile.len = 0; (*T1_).toCompile.p = (tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content*) newSeqPayload(0, sizeof(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg), NIM_ALIGNOF(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg));
	(*T1_).arguments = TM__zQHipMPUXFgsDrLbMR9atnA_24;
	(*T1_).suggestMaxResults = ((NI)10000);
	(*T1_).maxLoopIterationsVM = ((NI)10000000);
	(*T1_).maxCallDepthVM = ((NI)2000);
	(*T1_).vmProfileData = newProfileData__options_u660();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).spellSuggestMax = ((NI)-1);
	(*T1_).currentConfigDir = TM__zQHipMPUXFgsDrLbMR9atnA_25;
	result = T1_;
	initConfigRefCommon__options_u962(result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setTargetFromSystem__platform_u942((&(*result).target));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isatty__pureZterminal_u637(stderr);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T4_) goto LA5_;
		(*result).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)24))) & 63);
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u2135)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___options_u1751((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosjoinPath(head_p0, tail_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getRelativePathFromConfigPath__options_u3934)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL isTitle_p2) {
	NimStringV2 result;
	NimStringV2 f_2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	f_2.len = 0; f_2.p = NIM_NIL;
	result = TM__zQHipMPUXFgsDrLbMR9atnA_28;
	f_2 = dollar___options_u3939(f_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!isTitle_p2) goto LA4_;
		{
			NimStringV2 dir_1;
			NI i_1;
			dir_1.len = 0; dir_1.p = NIM_NIL;
			i_1 = ((NI)0);
			{
				while (1) {
					NimStringV2 path_1;
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					path_1.len = 0; path_1.p = NIM_NIL;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					eqcopy___system_u2694((&dir_1), stdlibDirs__options_u3931[(i_1)- 0]);
					colontmpD_ = slash___stdZprivateZospaths2_u91((*conf_p0).libpath, dir_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					colontmpD__2 = noslastPathPart(f_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					path_1 = slash___stdZprivateZospaths2_u91(colontmpD_, colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					{
						NI T13_;
						tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__3;
						NimStringV2 T17_;
						T13_ = (NI)0;
						T13_ = noscmpPaths(path_1, f_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						if (!(T13_ == ((NI)0))) goto LA14_;
						nimZeroMem((void*)(&colontmpD__3), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
						T17_.len = 0; T17_.p = NIM_NIL;
						nossplitFile(f_2, (&colontmpD__3));
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						T17_ = rawNewString(colontmpD__3.Field1.len + 4);
appendString((&T17_), TM__zQHipMPUXFgsDrLbMR9atnA_43);
appendString((&T17_), colontmpD__3.Field1);
						result = T17_;
						eqdestroy___pureZos_u200((&colontmpD__3));
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(path_1);
						eqdestroy___system_u2691(dir_1);
						eqdestroy___system_u2691(f_2);
						goto BeforeRet_;
						{
							LA16_:;
						}
						{
							eqdestroy___pureZos_u200((&colontmpD__3));
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					}
LA14_: ;
					{
						if (!(((NI)12) <= i_1)) goto LA22_;
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(path_1);
						goto LA8;
					}
LA22_: ;
					i_1 += ((NI)1);
					{
						LA10_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(path_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				}
			} LA8: ;
			{
				LA7_:;
			}
			{
				eqdestroy___system_u2691(dir_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
LA4_: ;
	{
		NimStringV2* itX60gensym51__1;
		NI i_2;
		NI L_1;
		NI T29_;
		itX60gensym51__1 = (NimStringV2*)0;
		i_2 = ((NI)0);
		T29_ = (*conf_p0).searchPaths.len;
		L_1 = T29_;
		{
			while (1) {
				NimStringV2 itX60gensym51__2;
				if (!(i_2 < L_1)) goto LA31;
				itX60gensym51__2.len = 0; itX60gensym51__2.p = NIM_NIL;
				itX60gensym51__1 = (&(*conf_p0).searchPaths.p->data[i_2]);
				itX60gensym51__2 = dollar___options_u4029((*itX60gensym51__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
				{
					NIM_BOOL T35_;
					T35_ = (NIM_BOOL)0;
					T35_ = isRelativeTo__stdZprivateZospaths2_u159(f_2, itX60gensym51__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					if (!T35_) goto LA36_;
					result = nosrelativePath(f_2, itX60gensym51__2, 47);
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					eqdestroy___system_u2691(itX60gensym51__2);
					eqdestroy___system_u2691(f_2);
					goto BeforeRet_;
				}
LA36_: ;
				i_2 += ((NI)1);
				{
					LA32_:;
				}
				{
					eqdestroy___system_u2691(itX60gensym51__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA31: ;
		}
	}
	{
		NimStringV2* itX60gensym52__1;
		NI i_3;
		NI L_2;
		NI T41_;
		itX60gensym52__1 = (NimStringV2*)0;
		i_3 = ((NI)0);
		T41_ = (*conf_p0).lazyPaths.len;
		L_2 = T41_;
		{
			while (1) {
				NimStringV2 itX60gensym52__2;
				if (!(i_3 < L_2)) goto LA43;
				itX60gensym52__2.len = 0; itX60gensym52__2.p = NIM_NIL;
				itX60gensym52__1 = (&(*conf_p0).lazyPaths.p->data[i_3]);
				itX60gensym52__2 = dollar___options_u4029((*itX60gensym52__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				{
					NIM_BOOL T47_;
					T47_ = (NIM_BOOL)0;
					T47_ = isRelativeTo__stdZprivateZospaths2_u159(f_2, itX60gensym52__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
					if (!T47_) goto LA48_;
					result = nosrelativePath(f_2, itX60gensym52__2, 47);
					if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
					eqdestroy___system_u2691(itX60gensym52__2);
					eqdestroy___system_u2691(f_2);
					goto BeforeRet_;
				}
LA48_: ;
				i_3 += ((NI)1);
				{
					LA44_:;
				}
				{
					eqdestroy___system_u2691(itX60gensym52__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA43: ;
		}
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(f_2);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0) {
	NCSTRING result;
	{
		if (!(s_p0.len == ((NI)0))) goto LA3_;
		result = "";
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NCSTRING) ((*s_p0.p).data));
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimbleFile__options_u3711)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1) {
	NimStringV2 result;
	NI parents_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = TM__zQHipMPUXFgsDrLbMR9atnA_44;
	parents_1 = ((NI)0);
	{
		{
			NimStringV2 d_1;
			NimStringV2 current_1;
			d_1.len = 0; d_1.p = NIM_NIL;
			current_1.len = 0; current_1.p = NIM_NIL;
			eqcopy___system_u2694((&current_1), path_p1);
			{
				while (1) {
					NimStringV2 T6_;
					T6_.len = 0; T6_.p = NIM_NIL;
					T6_ = nosparentDir(current_1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T6_); goto LA3_;}
					eqsink___system_u2700((&current_1), T6_);
					{
						if (!(current_1.len == ((NI)0))) goto LA9_;
						goto LA4;
					}
LA9_: ;
					d_1 = current_1;
					{
						NIM_BOOL T13_;
						NimStringV2* T16_;
						T13_ = (NIM_BOOL)0;
						T13_ = nsthasKey((*conf_p0).packageCache, d_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						if (!T13_) goto LA14_;
						T16_ = (NimStringV2*)0;
						T16_ = nstTake((*conf_p0).packageCache, d_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						eqcopy___system_u2694((&result), (*T16_));
						eqdestroy___system_u2691(current_1);
						goto BeforeRet_;
					}
LA14_: ;
					parents_1 += ((NI)1);
					{
						NimStringV2 file_1;
						NimStringV2 colontmp_;
						glob_t fX60gensym5__1;
						NI resX60gensym5__1;
						int T19_;
						file_1.len = 0; file_1.p = NIM_NIL;
						colontmp_.len = 0; colontmp_.p = NIM_NIL;
						file_1.len = 0; file_1.p = NIM_NIL;
						colontmp_.len = 0; colontmp_.p = NIM_NIL;
						colontmp_ = slash___stdZprivateZospaths2_u91(d_1, TM__zQHipMPUXFgsDrLbMR9atnA_46);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						nimZeroMem((void*)(&fX60gensym5__1), sizeof(glob_t));
						resX60gensym5__1 = (NI)0;
						fX60gensym5__1.gl_offs = ((NI)0);
						fX60gensym5__1.gl_pathc = ((NI)0);
						fX60gensym5__1.gl_pathv = ((NCSTRING*) NIM_NIL);
						T19_ = (int)0;
						T19_ = glob(nimToCStringConv(colontmp_), ((int)0), NIM_NIL, (&fX60gensym5__1));
						resX60gensym5__1 = ((NI) (T19_));
						{
							if (!(resX60gensym5__1 == ((NI)0))) goto LA23_;
							{
								NI iX60gensym5__1;
								NI colontmp__2;
								NI res_1;
								iX60gensym5__1 = (NI)0;
								colontmp__2 = (NI)0;
								colontmp__2 = (NI)(fX60gensym5__1.gl_pathc - ((NI)1));
								res_1 = ((NI)0);
								{
									while (1) {
										NimStringV2 pathX60gensym5__1;
										if (!(res_1 <= colontmp__2)) goto LA27;
										pathX60gensym5__1.len = 0; pathX60gensym5__1.p = NIM_NIL;
										iX60gensym5__1 = ((NI) (res_1));
										pathX60gensym5__1 = cstrToNimstr(fX60gensym5__1.gl_pathv[iX60gensym5__1]);
										{
											NIM_BOOL T31_;
											T31_ = (NIM_BOOL)0;
											T31_ = nosfileExists(pathX60gensym5__1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
											if (!T31_) goto LA32_;
											eqsink___system_u2700((&file_1), pathX60gensym5__1);
											eqwasMoved___system_u2688((&pathX60gensym5__1));
											eqsink___system_u2700((&result), file_1);
											eqwasMoved___system_u2688((&file_1));
											eqdestroy___system_u2691(pathX60gensym5__1);
											globfree((&fX60gensym5__1));
											eqdestroy___system_u2691(colontmp_);
											eqdestroy___system_u2691(file_1);
											eqdestroy___system_u2691(current_1);
											goto LA1;
										}
LA32_: ;
										res_1 += ((NI)1);
										{
											LA28_:;
										}
										{
											eqdestroy___system_u2691(pathX60gensym5__1);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
									} LA27: ;
								}
							}
						}
LA23_: ;
						{
							LA20_:;
						}
						{
							globfree((&fX60gensym5__1));
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						{
							LA18_:;
						}
						{
							eqdestroy___system_u2691(colontmp_);
							eqdestroy___system_u2691(file_1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					}
				}
			} LA4: ;
			{
				LA3_:;
			}
			{
				eqdestroy___system_u2691(current_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	} LA1: ;
	{
		NimStringV2 d_2;
		NimStringV2 current_2;
		d_2.len = 0; d_2.p = NIM_NIL;
		current_2.len = 0; current_2.p = NIM_NIL;
		eqcopy___system_u2694((&current_2), path_p1);
		{
			while (1) {
				NimStringV2 T46_;
				T46_.len = 0; T46_.p = NIM_NIL;
				T46_ = nosparentDir(current_2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T46_); goto LA43_;}
				eqsink___system_u2700((&current_2), T46_);
				{
					if (!(current_2.len == ((NI)0))) goto LA49_;
					goto LA44;
				}
LA49_: ;
				d_2 = current_2;
				nstPut((*conf_p0).packageCache, d_2, result);
				if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
				parents_1 -= ((NI)1);
				{
					if (!(parents_1 <= ((NI)0))) goto LA53_;
					eqdestroy___system_u2691(current_2);
					goto LA42;
				}
LA53_: ;
			}
		} LA44: ;
		{
			LA43_:;
		}
		{
			eqdestroy___system_u2691(current_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	} LA42: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_u139)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__options_u3633)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonicalImportAux__options_u4231)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 file_p1) {
	NimStringV2 result;
	NimStringV2 ret_1;
	NimStringV2 dir_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 blitTmp_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	ret_1.len = 0; ret_1.p = NIM_NIL;
	dir_1.len = 0; dir_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	ret_1 = getRelativePathFromConfigPath__options_u3934(conf_p0, file_p1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = dollar___options_u3939(file_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getNimbleFile__options_u3711(conf_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	dir_1 = nosparentDir(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 relPath_1;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmpty__pathutils_u139(dir_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		relPath_1.len = 0; relPath_1.p = NIM_NIL;
		relPath_1 = relativeTo__pathutils_u196(file_p1, dir_1, 47);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NIM_BOOL T13_;
			T10_ = (NIM_BOOL)0;
			T11_ = (NIM_BOOL)0;
			T11_ = isEmpty__options_u3633(relPath_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			T10_ = !(T11_);
			if (!(T10_)) goto LA12_;
			T13_ = (NIM_BOOL)0;
			T13_ = isEmpty__options_u3633(ret_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			if (T13_) goto LA14_;
			T13_ = (relPath_1.len < ret_1.len);
LA14_: ;
			T10_ = T13_;
LA12_: ;
			if (!T10_) goto LA15_;
			eqsink___system_u2700((&ret_1), relPath_1);
			eqwasMoved___system_u2688((&relPath_1));
		}
LA15_: ;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(relPath_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		NIM_BOOL T21_;
		NimStringV2 T24_;
		T21_ = (NIM_BOOL)0;
		T21_ = isEmpty__options_u3633(ret_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T21_) goto LA22_;
		T24_.len = 0; T24_.p = NIM_NIL;
		T24_ = relativeTo__pathutils_u196(file_p1, (*conf_p0).projectPath, 47);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T24_); goto LA1_;}
		eqsink___system_u2700((&ret_1), T24_);
	}
LA22_: ;
	blitTmp_1 = ret_1;
	eqwasMoved___system_u2688((&ret_1));
	result = blitTmp_1;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(dir_1);
		eqdestroy___system_u2691(ret_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__options_u557)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw note_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	{
		if (!!((((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)14)))&31U)))!=0))) goto LA4_;
		result = NIM_FALSE;
	}
	goto LA2_;
LA4_: ;
	{
		if (!(note_p1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)103) || note_p1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)99))) goto LA7_;
		result = (((*conf_p0).mainPackageNotes[(NU)((note_p1 - 20))>>3] &(1U<<((NU)((note_p1 - 20))&7U)))!=0);
	}
	goto LA2_;
LA7_: ;
	{
		result = (((*conf_p0).notes[(NU)((note_p1 - 20))>>3] &(1U<<((NU)((note_p1 - 20))&7U)))!=0);
	}
LA2_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsthasKey((*conf_p0).symbols, symbol_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA4_: ;
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = nsuCmpIgnoreStyle(symbol_p1, CPU__platform_u740[((*conf_p0).target.targetCPU)- 1].Field0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T7_ == ((NI)0))) goto LA8_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA8_: ;
	{
		NI T11_;
		T11_ = (NI)0;
		T11_ = nsuCmpIgnoreStyle(symbol_p1, OS__platform_u534[((*conf_p0).target.targetOS)- 1].Field0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T11_ == ((NI)0))) goto LA12_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA12_: ;
	{
		NimStringV2 colontmpD_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = nsuNormalize(symbol_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (hashString(colontmpD_) & 31) {
		case 0: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_69)) goto LA24_;
break;
		case 1: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_67)) goto LA24_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_101)) goto LA38_;
break;
		case 2: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_97)) goto LA36_;
break;
		case 3: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_65)) goto LA23_;
break;
		case 6: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_59)) goto LA20_;
break;
		case 7: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_85)) goto LA30_;
break;
		case 13: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_77)) goto LA27_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_81)) goto LA29_;
break;
		case 15: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_48)) goto LA15_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_50)) goto LA16_;
break;
		case 19: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_55)) goto LA18_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_63)) goto LA22_;
break;
		case 20: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_91)) goto LA33_;
break;
		case 21: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_83)) goto LA29_;
break;
		case 22: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_87)) goto LA31_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_93)) goto LA34_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_95)) goto LA35_;
break;
		case 23: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_52)) goto LA17_;
break;
		case 24: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_73)) goto LA26_;
break;
		case 25: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_79)) goto LA28_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_99)) goto LA37_;
break;
		case 26: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_75)) goto LA26_;
break;
		case 27: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_89)) goto LA32_;
break;
		case 30: 
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_53)) goto LA18_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_57)) goto LA19_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_61)) goto LA21_;
if (eqStrings(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_71)) goto LA25_;
break;
		}
		goto LA39_;
		LA15_: ;
		{
			result = ((*conf_p0).target.targetCPU == ((tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw)1));
		}
		goto LA40_;
		LA16_: ;
		{
			result = ((*conf_p0).target.targetCPU == ((tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw)10));
		}
		goto LA40_;
		LA17_: ;
		{
			result = ((*conf_p0).target.targetCPU == ((tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw)11));
		}
		goto LA40_;
		LA18_: ;
		{
			result = ((IL64(16171532272) &((NU64)1<<((NU)(((*conf_p0).target.targetOS))&63U)))!=0);
		}
		goto LA40_;
		LA19_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)4) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)24));
		}
		goto LA40_;
		LA20_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)9) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)10) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)11) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)12) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)13));
		}
		goto LA40_;
		LA21_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)10) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)13));
		}
		goto LA40_;
		LA22_: ;
		{
			result = ((OS__platform_u534[((*conf_p0).target.targetOS)- 1].Field12 &((NU8)1<<((NU)((((tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg)3)))&7U)))!=0);
		}
		goto LA40_;
		LA23_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)1));
		}
		goto LA40_;
		LA24_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)2));
		}
		goto LA40_;
		LA25_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)20) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)21) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)22));
		}
		goto LA40_;
		LA26_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)21) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)22));
		}
		goto LA40_;
		LA27_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)7));
		}
		goto LA40_;
		LA28_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)30));
		}
		goto LA40_;
		LA29_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)31));
		}
		goto LA40_;
		LA30_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)32));
		}
		goto LA40_;
		LA31_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)33));
		}
		goto LA40_;
		LA32_: ;
		{
			result = (CPU__platform_u740[((*conf_p0).target.targetCPU)- 1].Field2 == ((tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ)0));
		}
		goto LA40_;
		LA33_: ;
		{
			result = (CPU__platform_u740[((*conf_p0).target.targetCPU)- 1].Field2 == ((tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ)1));
		}
		goto LA40_;
		LA34_: ;
		{
			result = (CPU__platform_u740[((*conf_p0).target.targetCPU)- 1].Field4 == ((NI)8));
		}
		goto LA40_;
		LA35_: ;
		{
			result = (CPU__platform_u740[((*conf_p0).target.targetCPU)- 1].Field4 == ((NI)16));
		}
		goto LA40_;
		LA36_: ;
		{
			result = (CPU__platform_u740[((*conf_p0).target.targetCPU)- 1].Field4 == ((NI)32));
		}
		goto LA40_;
		LA37_: ;
		{
			result = (CPU__platform_u740[((*conf_p0).target.targetCPU)- 1].Field4 == ((NI)64));
		}
		goto LA40_;
		LA38_: ;
		{
			result = ((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)7) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)9) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)10) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)11) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)12) || (*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)21));
		}
		goto LA40_;
		LA39_: ;
		{
			result = NIM_FALSE;
		}
LA40_: ;
		eqdestroy___system_u2691(colontmpD_);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_CHAR, X5BX5D___system_u8066)(NimStringV2 s_p0, NI i_p1) {
	NIM_CHAR result;
	result = s_p0.p->data[(NI)(s_p0.len - i_p1)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, removeTrailingDirSep__options_u3681)(NimStringV2 path_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_CHAR T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI)0) < path_p0.len);
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_CHAR)0;
		T5_ = X5BX5D___system_u8066(path_p0, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = ((NU8)(T5_) == (NU8)(47));
LA4_: ;
		if (!T3_) goto LA6_;
		result = substr__system_u8651(path_p0, ((NI)0), (NI)(path_p0.len - ((NI)2)));
	}
	goto LA1_;
LA6_: ;
	{
		eqcopy___system_u2694((&result), path_p0);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPrefixDir__options_u3645)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__pathutils_u139((*conf_p0).prefixDir);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		eqcopy___system_u2694((&result), (*conf_p0).prefixDir);
	}
	goto LA1_;
LA4_: ;
	{
		NimStringV2 binParent_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyTuple__UV3llMMYFckfui8YMBuUZA colontmpD__3;
		binParent_1.len = 0; binParent_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__3), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		colontmpD__2 = nosgetAppDir();
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nossplitPath(colontmpD__2, (&colontmpD__3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD_ = eqdup___system_u2697(colontmpD__3.Field0);
		binParent_1 = colontmpD_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = eqeq___options_u3652(binParent_1, TM__zQHipMPUXFgsDrLbMR9atnA_105);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA10_;
			result = TM__zQHipMPUXFgsDrLbMR9atnA_107;
		}
		goto LA7_;
LA10_: ;
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = eqeq___options_u3652(binParent_1, TM__zQHipMPUXFgsDrLbMR9atnA_109);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T13_) goto LA14_;
			result = TM__zQHipMPUXFgsDrLbMR9atnA_111;
		}
		goto LA7_;
LA14_: ;
		{
			result = binParent_1;
			eqwasMoved___system_u2688((&binParent_1));
		}
LA7_: ;
		eqdestroy___stdZprivateZospaths2_u306((&colontmpD__3));
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(binParent_1);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOsCacheDir__options_u3735)(void) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD_ = nosgetHomeDir();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = slash___stdZprivateZospaths2_u91(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_132);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__3 = getEnv__stdZenvvars_u16(TM__zQHipMPUXFgsDrLbMR9atnA_130, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = slash___stdZprivateZospaths2_u91(colontmpD__3, TM__zQHipMPUXFgsDrLbMR9atnA_133);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__3);
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimcacheSuffix__options_u3740)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		if (!((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8))) goto LA4_;
		result = TM__zQHipMPUXFgsDrLbMR9atnA_135;
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = isDefined__options_u959(conf_p0, TM__zQHipMPUXFgsDrLbMR9atnA_137);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (T7_) goto LA8_;
		T7_ = isDefined__options_u959(conf_p0, TM__zQHipMPUXFgsDrLbMR9atnA_139);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA8_: ;
		if (!T7_) goto LA9_;
		result = TM__zQHipMPUXFgsDrLbMR9atnA_141;
	}
	goto LA2_;
LA9_: ;
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_143;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimcacheDir__options_u3737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmpty__pathutils_u139((*conf_p0).nimcacheDir);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T4_)) goto LA5_;
		eqcopy___system_u2694((&result), (*conf_p0).nimcacheDir);
	}
	goto LA2_;
LA5_: ;
	{
		NimStringV2 T10_;
		if (!((*conf_p0).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA8_;
		T10_.len = 0; T10_.p = NIM_NIL;
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = isEmpty__pathutils_u139((*conf_p0).outDir);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T13_) goto LA14_;
			result = slash___pathutils_u166((*conf_p0).projectPath, TM__zQHipMPUXFgsDrLbMR9atnA_127);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA11_;
LA14_: ;
		{
			result = slash___pathutils_u166((*conf_p0).outDir, TM__zQHipMPUXFgsDrLbMR9atnA_128);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA11_: ;
	}
	goto LA2_;
LA8_: ;
	{
		NimStringV2 colontmpD_;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T18_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T18_.len = 0; T18_.p = NIM_NIL;
		colontmpD_ = getOsCacheDir__options_u3735();
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nossplitFile((*conf_p0).projectName, (&colontmpD__2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__3 = slash___stdZprivateZospaths2_u91(colontmpD_, colontmpD__2.Field1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__4 = nimcacheSuffix__options_u3740(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T18_ = rawNewString(colontmpD__3.len + colontmpD__4.len + 0);
appendString((&T18_), colontmpD__3);
appendString((&T18_), colontmpD__4);
		result = T18_;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___pureZos_u200((&colontmpD__2));
		eqdestroy___system_u2691(colontmpD_);
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, pathSubs__options_u3759)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 p_p1, NimStringV2 config_p2) {
	NimStringV2 result;
	NimStringV2 home_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	tyArray__CVH4DKy6jsFwcdfgh9ceJxQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	home_1.len = 0; home_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD_ = nosgetHomeDir();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	home_1 = removeTrailingDirSep__options_u3681(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = TM__zQHipMPUXFgsDrLbMR9atnA_103;
	colontmpD__2 = getPrefixDir__options_u3645(conf_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[1] = colontmpD__2;
	T2_[2] = TM__zQHipMPUXFgsDrLbMR9atnA_113;
	T2_[3] = (*conf_p0).libpath;
	T2_[4] = TM__zQHipMPUXFgsDrLbMR9atnA_115;
	T2_[5] = home_1;
	T2_[6] = TM__zQHipMPUXFgsDrLbMR9atnA_117;
	T2_[7] = config_p2;
	T2_[8] = TM__zQHipMPUXFgsDrLbMR9atnA_119;
	T2_[9] = (*conf_p0).projectName;
	T2_[10] = TM__zQHipMPUXFgsDrLbMR9atnA_121;
	T2_[11] = (*conf_p0).projectPath;
	T2_[12] = TM__zQHipMPUXFgsDrLbMR9atnA_123;
	T2_[13] = (*conf_p0).projectPath;
	T2_[14] = TM__zQHipMPUXFgsDrLbMR9atnA_125;
	colontmpD__3 = getNimcacheDir__options_u3737(conf_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[15] = colontmpD__3;
	colontmpD__4 = nsuFormatOpenArray(p_p1, T2_, 16);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = nosunixToNativePath(colontmpD__4, TM__zQHipMPUXFgsDrLbMR9atnA_144);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = expandTilde__pureZos_u35(colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(home_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, disableNimblePath__options_u3684)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	(*conf_p0).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)42))) & 63);
	setLen__options_u1391((&(*conf_p0).lazyPaths), ((NI)0));
	setLen__options_u1391((&(*conf_p0).nimblePaths), ((NI)0));
}
N_LIB_PRIVATE N_NIMCALL(void, clearNimblePath__options_u3698)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	setLen__options_u1391((&(*conf_p0).lazyPaths), ((NI)0));
	setLen__options_u1391((&(*conf_p0).nimblePaths), ((NI)0));
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonicalizePath__options_u3669)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosexpandFilename(path_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawFindFile__options_u3827)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL suppressStdlib_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NimStringV2* it_1;
		NI i_1;
		NI L_1;
		NI T2_;
		it_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		T2_ = (*conf_p0).searchPaths.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				it_1 = (&(*conf_p0).searchPaths.p->data[i_1]);
				{
					NimStringV2 T12_;
					{
						NIM_BOOL T8_;
						T8_ = (NIM_BOOL)0;
						T8_ = suppressStdlib_p2;
						if (!(T8_)) goto LA9_;
						T8_ = nsuStartsWith((*it_1), (*conf_p0).libpath);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA9_: ;
						if (!T8_) goto LA10_;
						goto LA5;
					}
LA10_: ;
					T12_.len = 0; T12_.p = NIM_NIL;
					T12_ = slash___pathutils_u135((*it_1), f_p1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T12_); goto BeforeRet_;}
					eqsink___system_u2700((&result), T12_);
					{
						NIM_BOOL T15_;
						T15_ = (NIM_BOOL)0;
						T15_ = nosfileExists(result);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T15_) goto LA16_;
						result = canonicalizePath__options_u3669(conf_p0, result);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA16_: ;
				} LA5: ;
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	result = TM__zQHipMPUXFgsDrLbMR9atnA_146;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__options_u4086)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawFindFile2__options_u3871)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NimStringV2 it_1;
		NI i_1;
		NI i_2;
		NI L_1;
		NI T3_;
		it_1.len = 0; it_1.p = NIM_NIL;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		T3_ = (*conf_p0).lazyPaths.len;
		L_1 = T3_;
		{
			while (1) {
				NimStringV2 T6_;
				if (!(i_2 < L_1)) goto LA5;
				i_1 = i_2;
				eqcopy___system_u2694((&it_1), (*conf_p0).lazyPaths.p->data[i_2]);
				T6_.len = 0; T6_.p = NIM_NIL;
				T6_ = slash___pathutils_u135(it_1, f_p1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T6_); goto LA2_;}
				eqsink___system_u2700((&result), T6_);
				{
					NIM_BOOL T9_;
					T9_ = (NIM_BOOL)0;
					T9_ = nosfileExists(result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					if (!T9_) goto LA10_;
					{
						NI j_1;
						NI res_1;
						j_1 = (NI)0;
						res_1 = i_1;
						{
							while (1) {
								NimStringV2 T15_;
								if (!(((NI)1) <= res_1)) goto LA14;
								j_1 = ((NI) (res_1));
								T15_.len = 0; T15_.p = NIM_NIL;
								T15_ = (*conf_p0).lazyPaths.p->data[j_1];
								(*conf_p0).lazyPaths.p->data[j_1] = (*conf_p0).lazyPaths.p->data[(NI)(j_1 - ((NI)1))];
								(*conf_p0).lazyPaths.p->data[(NI)(j_1 - ((NI)1))] = T15_;
								res_1 -= ((NI)1);
							} LA14: ;
						}
					}
					result = canonicalizePath__options_u3669(conf_p0, result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					eqdestroy___system_u2691(it_1);
					goto BeforeRet_;
				}
LA10_: ;
				i_2 += ((NI)1);
			} LA5: ;
		}
		{
			LA2_:;
		}
		{
			eqdestroy___system_u2691(it_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	result = TM__zQHipMPUXFgsDrLbMR9atnA_147;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPackageName__options_u3730)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1) {
	NimStringV2 result;
	NimStringV2 path_2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	path_2.len = 0; path_2.p = NIM_NIL;
	path_2 = getNimbleFile__options_u3711(conf_p0, path_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD_;
		if (!(((NI)0) < path_2.len)) goto LA4_;
		nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		nossplitFile(path_2, (&colontmpD_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		result = colontmpD_.Field1;
		eqwasMoved___system_u2688((&colontmpD_.Field1));
		eqdestroy___pureZos_u200((&colontmpD_));
		eqdestroy___system_u2691(path_2);
		goto BeforeRet_;
		{
			LA6_:;
		}
		{
			eqdestroy___pureZos_u200((&colontmpD_));
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_149;
		eqdestroy___system_u2691(path_2);
		goto BeforeRet_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(path_2);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findFile__options_u4081)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL suppressStdlib_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		NimStringV2 T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = nosisAbsolute(f_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		T6_.len = 0; T6_.p = NIM_NIL;
		{
			NIM_BOOL T9_;
			NimStringV2 colontmpD_;
			T9_ = (NIM_BOOL)0;
			T9_ = nosfileExists(f_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA10_;
			colontmpD_ = eqdup___system_u2697(f_p1);
			result = colontmpD_;
		}
		goto LA7_;
LA10_: ;
		{
			result = TM__zQHipMPUXFgsDrLbMR9atnA_145;
		}
LA7_: ;
	}
	goto LA1_;
LA4_: ;
	{
		result = rawFindFile__options_u3827(conf_p0, f_p1, suppressStdlib_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T16_;
			NimStringV2 colontmpD__2;
			NimStringV2 T20_;
			T16_ = (NIM_BOOL)0;
			T16_ = isEmpty__options_u4086(result);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T16_) goto LA17_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = nsuToLowerAsciiStr(f_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			T20_.len = 0; T20_.p = NIM_NIL;
			T20_ = rawFindFile__options_u3827(conf_p0, colontmpD__2, suppressStdlib_p2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T20_); goto LA19_;}
			eqsink___system_u2700((&result), T20_);
			{
				NIM_BOOL T23_;
				NimStringV2 T26_;
				T23_ = (NIM_BOOL)0;
				T23_ = isEmpty__options_u4086(result);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				if (!T23_) goto LA24_;
				T26_.len = 0; T26_.p = NIM_NIL;
				T26_ = rawFindFile2__options_u3871(conf_p0, f_p1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T26_); goto LA19_;}
				eqsink___system_u2700((&result), T26_);
				{
					NIM_BOOL T29_;
					NimStringV2 colontmpD__3;
					NimStringV2 T33_;
					T29_ = (NIM_BOOL)0;
					T29_ = isEmpty__options_u4086(result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					if (!T29_) goto LA30_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__3 = nsuToLowerAsciiStr(f_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					T33_.len = 0; T33_.p = NIM_NIL;
					T33_ = rawFindFile2__options_u3871(conf_p0, colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T33_); goto LA32_;}
					eqsink___system_u2700((&result), T33_);
					{
						LA32_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				}
LA30_: ;
			}
LA24_: ;
			{
				LA19_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA17_: ;
	}
LA1_: ;
	{
		NIM_BOOL T40_;
		NIM_BOOL T41_;
		NI T43_;
		NimStringV2 key_1;
		NimStringV2 colontmpD__4;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__5;
		NimStringV2 T47_;
		T40_ = (NIM_BOOL)0;
		T41_ = (NIM_BOOL)0;
		T41_ = isEmpty__options_u4086(result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T40_ = !(T41_);
		if (!(T40_)) goto LA42_;
		T43_ = (NI)0;
		T43_ = nstlen((*conf_p0).moduleOverrides);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T40_ = (((NI)0) < T43_);
LA42_: ;
		if (!T40_) goto LA44_;
		key_1.len = 0; key_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__5), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		T47_.len = 0; T47_.p = NIM_NIL;
		colontmpD__4 = getPackageName__options_u3730(conf_p0, result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		splitFile__pathutils_u39(result, (&colontmpD__5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		T47_ = rawNewString(colontmpD__4.len + colontmpD__5.Field1.len + 1);
appendString((&T47_), colontmpD__4);
appendString((&T47_), TM__zQHipMPUXFgsDrLbMR9atnA_151);
appendString((&T47_), colontmpD__5.Field1);
		key_1 = T47_;
		{
			NIM_BOOL T50_;
			NimStringV2 ov_1;
			NimStringV2* T54_;
			T50_ = (NIM_BOOL)0;
			T50_ = nsthasKey((*conf_p0).moduleOverrides, key_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
			if (!T50_) goto LA51_;
			ov_1.len = 0; ov_1.p = NIM_NIL;
			T54_ = (NimStringV2*)0;
			T54_ = nstTake((*conf_p0).moduleOverrides, key_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			eqcopy___system_u2694((&ov_1), (*T54_));
			{
				NimStringV2 blitTmp_1;
				if (!(((NI)0) < ov_1.len)) goto LA57_;
				blitTmp_1 = ov_1;
				eqwasMoved___system_u2688((&ov_1));
				eqsink___system_u2700((&result), blitTmp_1);
			}
LA57_: ;
			{
				LA53_:;
			}
			{
				eqdestroy___system_u2691(ov_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		}
LA51_: ;
		{
			LA46_:;
		}
		{
			eqdestroy___pathutils_u73((&colontmpD__5));
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(key_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA44_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (targetDepth_p1 <= (*source_p0).depth);
	if (!(T1_)) goto LA2_;
	T1_ = ((*source_p0).display[targetDepth_p1] == token_p2);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = currException__system_u3628;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	eqcopy___system_u3661(&currException__system_u3628, (*currException__system_u3628).up, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, completeGeneratedFilePath__options_u3821)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NIM_BOOL createSubDir_p2) {
	NimStringV2 result;
	NimStringV2 subdir_1;
	tyTuple__UV3llMMYFckfui8YMBuUZA colontmpD_;
	NimStringV2 T18_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	subdir_1.len = 0; subdir_1.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	subdir_1 = getNimcacheDir__options_u3737(conf_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!createSubDir_p2) goto LA4_;
		noscreateDir(subdir_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		if (NIM_UNLIKELY(*nimErr_)) {
			LA6_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
				*nimErr_ = NIM_FALSE;
				{
					NIM_BOOL T12_;
					NimStringV2 colontmpD__2;
					NimStringV2 T15_;
					T12_ = (NIM_BOOL)0;
					T12_ = isDefined__options_u959(conf_p0, TM__zQHipMPUXFgsDrLbMR9atnA_153);
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					if (!T12_) goto LA13_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					T15_.len = 0; T15_.p = NIM_NIL;
					T15_ = rawNewString(subdir_1.len + 25);
appendString((&T15_), TM__zQHipMPUXFgsDrLbMR9atnA_155);
appendString((&T15_), subdir_1);
					colontmpD__2 = T15_;
					raiseAssert__stdZassertions_u15(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					eqdestroy___system_u2691(colontmpD__2);
				}
				goto LA10_;
LA13_: ;
				{
					NimStringV2 colontmpD__3;
					NimStringV2 T17_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					T17_.len = 0; T17_.p = NIM_NIL;
					T17_ = rawNewString(subdir_1.len + 25);
appendString((&T17_), TM__zQHipMPUXFgsDrLbMR9atnA_156);
appendString((&T17_), subdir_1);
					colontmpD__3 = T17_;
					quit__system_u7994(colontmpD__3, ((NI)1));
					eqdestroy___system_u2691(colontmpD__3);
				}
LA10_: ;
				popCurrentException();
				LA8_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	nossplitPath(f_p1, (&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T18_.len = 0; T18_.p = NIM_NIL;
	T18_ = slash___pathutils_u135(subdir_1, colontmpD_.Field1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T18_); goto LA1_;}
	result = T18_;
	{
		LA1_:;
	}
	{
		eqdestroy___stdZprivateZospaths2_u306((&colontmpD_));
		eqdestroy___system_u2691(subdir_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toGeneratedFile__options_u3816)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1, NimStringV2 ext_p2) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	tyTuple__UV3llMMYFckfui8YMBuUZA colontmpD__2;
	NimStringV2 colontmpD__3;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD_ = getNimcacheDir__options_u3737(conf_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nossplitPath(path_p1, (&colontmpD__2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = noschangeFileExt(colontmpD__2.Field1, ext_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = slash___pathutils_u135(colontmpD_, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___stdZprivateZospaths2_u306((&colontmpD__2));
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, existsConfigVar__options_u3599)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = nsthasKey((*conf_p0).configVars, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getConfigVar__options_u3603)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, NimStringV2 default_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = getOrDefault__pureZstrtabs_u390((*conf_p0).configVars, key_p1, default_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u144)(tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)0):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_158;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_160;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_162;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_164;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)4):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_166;
	}
	break;
	default:
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_167;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_u629)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NIM_BOOL result;
{	result = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)43)))&63U)))!=0);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdup___options_u1625)(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* src_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* Result) {
	nimZeroMem((void*)Result, sizeof(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg));
	(*Result).nimname = eqdup___system_u2697((*src_p0).nimname);
	(*Result).cname = eqdup___system_u2697((*src_p0).cname);
	(*Result).obj = eqdup___system_u2697((*src_p0).obj);
	(*Result).flags = (*src_p0).flags;
	(*Result).customArgs = eqdup___system_u2697((*src_p0).customArgs);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1619)(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).customArgs);
	eqdestroy___system_u2691((*dest_p0).obj);
	eqdestroy___system_u2691((*dest_p0).cname);
	eqdestroy___system_u2691((*dest_p0).nimname);
}
static N_INLINE(NIM_BOOL, startsWith__pureZstrutils_u1394)(NimStringV2 s_p0, NIM_CHAR prefix_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (((NI)0) < s_p0.len);
	if (!(T1_)) goto LA2_;
	T1_ = ((NU8)(s_p0.p->data[((NI)0)]) == (NU8)(prefix_p1));
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findModule__options_u4101)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 modulename_p1, NimStringV2 currentModule_p2) {
	NimStringV2 result;
	NimStringV2 m_1;
	NIM_BOOL hasRelativeDot_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	m_1.len = 0; m_1.p = NIM_NIL;
	m_1 = nosaddFileExt(modulename_p1, TM__zQHipMPUXFgsDrLbMR9atnA_168);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	hasRelativeDot_1 = NIM_FALSE;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD_;
		T4_ = (NIM_BOOL)0;
		T4_ = nsuStartsWith(m_1, TM__zQHipMPUXFgsDrLbMR9atnA_170);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = substr__system_u8664(m_1, ((NI)4));
		result = findFile__options_u4081(conf_p0, colontmpD_, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA5_: ;
	{
		{
			NIM_BOOL T13_;
			NimStringV2 stripped_1;
			T13_ = (NIM_BOOL)0;
			T13_ = nsuStartsWith(m_1, TM__zQHipMPUXFgsDrLbMR9atnA_171);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T13_) goto LA14_;
			stripped_1.len = 0; stripped_1.p = NIM_NIL;
			result = TM__zQHipMPUXFgsDrLbMR9atnA_173;
			stripped_1 = substr__system_u8664(m_1, ((NI)4));
			{
				NimStringV2 candidate_1;
				NI i_1;
				candidate_1.len = 0; candidate_1.p = NIM_NIL;
				i_1 = ((NI)0);
				{
					while (1) {
						NimStringV2 path_1;
						NimStringV2 colontmpD__2;
						path_1.len = 0; path_1.p = NIM_NIL;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						eqcopy___system_u2694((&candidate_1), stdlibDirs__options_u3931[(i_1)- 0]);
						colontmpD__2 = slash___stdZprivateZospaths2_u91((*conf_p0).libpath, candidate_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						path_1 = slash___stdZprivateZospaths2_u91(colontmpD__2, stripped_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						{
							NIM_BOOL T24_;
							NimStringV2 blitTmp_1;
							T24_ = (NIM_BOOL)0;
							T24_ = nosfileExists(path_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
							if (!T24_) goto LA25_;
							blitTmp_1 = path_1;
							eqwasMoved___system_u2688((&path_1));
							eqsink___system_u2700((&result), blitTmp_1);
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___system_u2691(path_1);
							eqdestroy___system_u2691(candidate_1);
							goto LA17;
						}
LA25_: ;
						{
							if (!(((NI)12) <= i_1)) goto LA29_;
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___system_u2691(path_1);
							goto LA19;
						}
LA29_: ;
						i_1 += ((NI)1);
						{
							LA21_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___system_u2691(path_1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					}
				} LA19: ;
				{
					LA18_:;
				}
				{
					eqdestroy___system_u2691(candidate_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			} LA17: ;
			{
				LA16_:;
			}
			{
				eqdestroy___system_u2691(stripped_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA11_;
LA14_: ;
		{
			NimStringV2 currentPath_1;
			tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__3;
			currentPath_1.len = 0; currentPath_1.p = NIM_NIL;
			nimZeroMem((void*)(&colontmpD__3), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
			nossplitFile(currentModule_p2, (&colontmpD__3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			currentPath_1 = colontmpD__3.Field0;
			eqwasMoved___system_u2688((&colontmpD__3.Field0));
			result = slash___stdZprivateZospaths2_u91(currentPath_1, m_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				NIM_BOOL T40_;
				NIM_BOOL T42_;
				T40_ = (NIM_BOOL)0;
				T40_ = startsWith__pureZstrutils_u1394(m_1, 46);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(T40_)) goto LA41_;
				T42_ = (NIM_BOOL)0;
				T42_ = nosfileExists(result);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T40_ = !(T42_);
LA41_: ;
				if (!T40_) goto LA43_;
				eqsink___system_u2700((&result), TM__zQHipMPUXFgsDrLbMR9atnA_174);
				hasRelativeDot_1 = NIM_TRUE;
			}
LA43_: ;
			eqdestroy___pureZos_u200((&colontmpD__3));
			eqdestroy___system_u2691(currentPath_1);
		}
LA11_: ;
		{
			NIM_BOOL T47_;
			NIM_BOOL T48_;
			NimStringV2 T52_;
			T47_ = (NIM_BOOL)0;
			T48_ = (NIM_BOOL)0;
			T48_ = nosfileExists(result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T47_ = !(T48_);
			if (!(T47_)) goto LA49_;
			T47_ = !(hasRelativeDot_1);
LA49_: ;
			if (!T47_) goto LA50_;
			T52_.len = 0; T52_.p = NIM_NIL;
			T52_ = findFile__options_u4081(conf_p0, m_1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T52_); goto LA1_;}
			eqsink___system_u2700((&result), T52_);
		}
LA50_: ;
	}
LA2_: ;
	{
		NIM_BOOL T55_;
		NIM_BOOL T56_;
		NI T58_;
		NimStringV2 key_1;
		NimStringV2 colontmpD__4;
		tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD__5;
		NimStringV2 T62_;
		T55_ = (NIM_BOOL)0;
		T56_ = (NIM_BOOL)0;
		T56_ = isEmpty__options_u4086(result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T55_ = !(T56_);
		if (!(T55_)) goto LA57_;
		T58_ = (NI)0;
		T58_ = nstlen((*conf_p0).moduleOverrides);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T55_ = (((NI)0) < T58_);
LA57_: ;
		if (!T55_) goto LA59_;
		key_1.len = 0; key_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__5), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
		T62_.len = 0; T62_.p = NIM_NIL;
		colontmpD__4 = getPackageName__options_u3730(conf_p0, result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		splitFile__pathutils_u39(result, (&colontmpD__5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		T62_ = rawNewString(colontmpD__4.len + colontmpD__5.Field1.len + 1);
appendString((&T62_), colontmpD__4);
appendString((&T62_), TM__zQHipMPUXFgsDrLbMR9atnA_175);
appendString((&T62_), colontmpD__5.Field1);
		key_1 = T62_;
		{
			NIM_BOOL T65_;
			NimStringV2 ov_1;
			NimStringV2* T69_;
			T65_ = (NIM_BOOL)0;
			T65_ = nsthasKey((*conf_p0).moduleOverrides, key_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			if (!T65_) goto LA66_;
			ov_1.len = 0; ov_1.p = NIM_NIL;
			T69_ = (NimStringV2*)0;
			T69_ = nstTake((*conf_p0).moduleOverrides, key_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
			eqcopy___system_u2694((&ov_1), (*T69_));
			{
				NimStringV2 blitTmp_2;
				if (!(((NI)0) < ov_1.len)) goto LA72_;
				blitTmp_2 = ov_1;
				eqwasMoved___system_u2688((&ov_1));
				eqsink___system_u2700((&result), blitTmp_2);
			}
LA72_: ;
			{
				LA68_:;
			}
			{
				eqdestroy___system_u2691(ov_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		}
LA66_: ;
		{
			LA61_:;
		}
		{
			eqdestroy___pathutils_u73((&colontmpD__5));
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(key_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA59_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(m_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonDynlibName__options_u4258)(NimStringV2 s_p0) {
	NimStringV2 result;
	NI colontmpD_;
	NI colontmpD__2;
	NI start_1;
	NI ende_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_ = (NI)0;
	colontmpD__2 = (NI)0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nsuStartsWith(s_p0, TM__zQHipMPUXFgsDrLbMR9atnA_176);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		colontmpD_ = ((NI)3);
		start_1 = colontmpD_;
	}
	goto LA1_;
LA4_: ;
	{
		colontmpD__2 = ((NI)0);
		start_1 = colontmpD__2;
	}
LA1_: ;
	ende_1 = nsuFindCharSet(s_p0, TM__zQHipMPUXFgsDrLbMR9atnA_177, ((NI)0), ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= ende_1)) goto LA9_;
		result = substr__system_u8651(s_p0, start_1, (NI)(ende_1 - ((NI)1)));
	}
	goto LA7_;
LA9_: ;
	{
		result = substr__system_u8664(s_p0, start_1);
	}
LA7_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, inclDynlibOverride__options_u4263)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 lib_p1) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = canonDynlibName__options_u4258(lib_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nstPut((*conf_p0).dllOverrides, colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_179);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, showNonExportedFields__options_u4274)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	(*conf_p0).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)55))) & 63);
}
N_LIB_PRIVATE N_NIMCALL(void, docRawOutput__options_u4280)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	(*conf_p0).globalOptions |= ((NU64)1)<<(((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)57))) & 63);
}
N_LIB_PRIVATE N_NIMCALL(void, cppDefine__options_u2159)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* c_p0, NimStringV2 define_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	incl__options_u2181((&(*c_p0).cppDefines), define_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setConfigVar__options_u3608)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, NimStringV2 val_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nstPut((*conf_p0).configVars, key_p1, val_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u265)(tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)0):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_181;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)1):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_183;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)2):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_185;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)3):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_187;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)4):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_189;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)5):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_191;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)6):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_193;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)7):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_195;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)8):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_197;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)9):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_199;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)10):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_201;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)11):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_203;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)12):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_205;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)13):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_207;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)14):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_209;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)15):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_211;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)16):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_213;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)17):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_215;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)18):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_217;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)19):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_219;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)20):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_221;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)21):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_223;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)22):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_225;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)23):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_227;
	}
	break;
	case ((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)24):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_229;
	}
	break;
	default:
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_230;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11820)(tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).tooltip);
	eqdestroy___system_u2691((*dest_p0).label);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11782)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0).inlayHintInfo);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u11820((&(*(*dest_p0).inlayHintInfo)));
		nimRawDispose((*dest_p0).inlayHintInfo, ((NI)8));
	}
LA4_: ;
	eqdestroy___system_u2691((*dest_p0).forth);
	eqdestroy___system_u2691((*dest_p0).doc);
	eqdestroy___system_u2691((*dest_p0).filePath);
	eqdestroy___system_u5506((*dest_p0).qualifiedPath);
}
N_LIB_PRIVATE N_NIMCALL(void, setFromProjectName__options_u3673)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 projectName_p1) {
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg p_1;
	NimStringV2 dir_1;
	NimStringV2 T3_;
	NimStringV2 T7_;
	NimStringV2 T16_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&p_1), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	dir_1.len = 0; dir_1.p = NIM_NIL;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = canonicalizePath__options_u3669(conf_p0, projectName_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA2_;}
	eqsink___system_u2700((&(*conf_p0).projectFull), T3_);
	if (NIM_UNLIKELY(*nimErr_)) {
		LA2_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			NimStringV2 colontmpD_;
			*nimErr_ = NIM_FALSE;
			colontmpD_ = eqdup___system_u2697(projectName_p1);
			eqsink___system_u2700((&(*conf_p0).projectFull), colontmpD_);
			popCurrentException();
			LA5_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	splitFile__pathutils_u39((*conf_p0).projectFull, (&p_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T7_.len = 0; T7_.p = NIM_NIL;
	{
		NIM_BOOL T10_;
		NimStringV2 T13_;
		T10_ = (NIM_BOOL)0;
		T10_ = isEmpty__pathutils_u139(p_1.Field0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T10_) goto LA11_;
		T13_.len = 0; T13_.p = NIM_NIL;
		T13_ = nosgetCurrentDir();
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T13_); goto LA1_;}
		dir_1 = T13_;
	}
	goto LA8_;
LA11_: ;
	{
		dir_1 = p_1.Field0;
		eqwasMoved___system_u2688((&p_1.Field0));
	}
LA8_: ;
	T16_.len = 0; T16_.p = NIM_NIL;
	T16_ = canonicalizePath__options_u3669(conf_p0, dir_1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T16_); goto LA15_;}
	eqsink___system_u2700((&(*conf_p0).projectPath), T16_);
	if (NIM_UNLIKELY(*nimErr_)) {
		LA15_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			*nimErr_ = NIM_FALSE;
			eqsink___system_u2700((&(*conf_p0).projectPath), dir_1);
			eqwasMoved___system_u2688((&dir_1));
			popCurrentException();
			LA18_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___system_u2700((&(*conf_p0).projectName), p_1.Field1);
	eqwasMoved___system_u2688((&p_1.Field1));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(dir_1);
		eqdestroy___pathutils_u73((&p_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u2138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg** dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p1) {
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___options_u1751((&(*(*dest_p0))));
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setDefaultLibpath__options_u3661)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 prefix_1;
		NimStringV2 realNimPath_1;
		NimStringV2 parentNimLibPath_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__pathutils_u139((*conf_p0).libpath);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		prefix_1.len = 0; prefix_1.p = NIM_NIL;
		realNimPath_1.len = 0; realNimPath_1.p = NIM_NIL;
		parentNimLibPath_1.len = 0; parentNimLibPath_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		prefix_1 = getPrefixDir__options_u3645(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = slash___pathutils_u166(prefix_1, TM__zQHipMPUXFgsDrLbMR9atnA_232);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA6_;}
		eqsink___system_u2700((&(*conf_p0).libpath), T7_);
		realNimPath_1 = findExe__pureZos_u76(TM__zQHipMPUXFgsDrLbMR9atnA_233, NIM_TRUE, ExeExts__pureZos_u75, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD_ = nosparentDir(realNimPath_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__2 = nosparentDir(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		parentNimLibPath_1 = slash___stdZprivateZospaths2_u91(colontmpD__2, TM__zQHipMPUXFgsDrLbMR9atnA_234);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			NIM_BOOL T10_;
			NIM_BOOL T11_;
			NimStringV2 blitTmp_1;
			T10_ = (NIM_BOOL)0;
			colontmpD__3 = slash___stdZprivateZospaths2_u91((*conf_p0).libpath, TM__zQHipMPUXFgsDrLbMR9atnA_236);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T11_ = (NIM_BOOL)0;
			T11_ = nosfileExists(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T10_ = !(T11_);
			if (!(T10_)) goto LA12_;
			colontmpD__4 = slash___stdZprivateZospaths2_u91(parentNimLibPath_1, TM__zQHipMPUXFgsDrLbMR9atnA_237);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T10_ = nosfileExists(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
LA12_: ;
			if (!T10_) goto LA13_;
			blitTmp_1 = parentNimLibPath_1;
			eqwasMoved___system_u2688((&parentNimLibPath_1));
			eqsink___system_u2700((&(*conf_p0).libpath), blitTmp_1);
		}
LA13_: ;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(parentNimLibPath_1);
			eqdestroy___system_u2691(realNimPath_1);
			eqdestroy___system_u2691(prefix_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*, eqdup___options_u2141)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p0) {
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*, newPartialConfigRef__options_u2157)(void) {
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* result;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = NIM_NIL;
	T1_ = (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) nimNewObj(sizeof(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg), NIM_ALIGNOF(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg));
	result = T1_;
	initConfigRefCommon__options_u962(result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11905)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u11782((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___sigmatch_u1748)(tyProc__k2HFjxisIgDALbEUFojxaQ* dest_p0, tyProc__k2HFjxisIgDALbEUFojxaQ src_p1) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1) {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* h_1;
	NI T1_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	h_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_));
	(*h_1).rc = pluspercent___system_u785((*h_1).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___sigmatch_u1740)(tyProc__k2HFjxisIgDALbEUFojxaQ* dest_p0, tyProc__k2HFjxisIgDALbEUFojxaQ src_p1, NIM_BOOL cyclic_p2) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	{
		if (!src_p1.ClE_0) goto LA3_;
		nimIncRefCyclic(src_p1.ClE_0, cyclic_p2);
	}
LA3_: ;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T7_) goto LA8_;
		nimDestroyAndDispose(colontmp_);
	}
LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11902)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11914)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA** dest_p0, tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* src_p1) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u11782((&(*(*dest_p0))));
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u346)(tyEnum_SuggestInlayHintKind__jagzSIzxhae5PXBOg9atNeg e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_SuggestInlayHintKind__jagzSIzxhae5PXBOg9atNeg)0):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_239;
	}
	break;
	case ((tyEnum_SuggestInlayHintKind__jagzSIzxhae5PXBOg9atNeg)1):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_241;
	}
	break;
	case ((tyEnum_SuggestInlayHintKind__jagzSIzxhae5PXBOg9atNeg)2):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_243;
	}
	break;
	default:
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_244;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u4316)(tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng c_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
	T1_.len = 0; T1_.p = NIM_NIL;
	switch (c_p0) {
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)1):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_246;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)2):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_248;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)3):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_250;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)4):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_252;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)5):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_254;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)6):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_256;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)7):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_258;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)8):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_260;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)0):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_262;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)9):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_264;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)10):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_266;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)11):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_268;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)12):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_270;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)13):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_272;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)14):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_274;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)18):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_276;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)19):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_278;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)15):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_280;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)16):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_282;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)17):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_284;
	}
	break;
	case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)20):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_286;
	}
	break;
	default: __builtin_unreachable();
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI16, floatInt64Align__options_u4319)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NI16 result;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !((conf_p0 == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*conf_p0).target.targetCPU == ((tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw)1));
LA4_: ;
		if (!T3_) goto LA5_;
		{
			if (!!(((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)2)))) goto LA9_;
			result = ((NI16)4);
			goto BeforeRet_;
		}
LA9_: ;
	}
LA5_: ;
	result = ((NI16)8);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDynlibOverride__options_u4266)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 lib_p1) {
	NIM_BOOL result;
	NimStringV2 colontmpD_;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)44)))&63U)))!=0);
	if (T1_) goto LA2_;
	colontmpD_ = canonDynlibName__options_u4258(lib_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = nsthasKey((*conf_p0).dllOverrides, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA2_: ;
	result = T1_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u213)(tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)0):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_288;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)1):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_290;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)2):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_292;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)3):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_294;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_296;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_298;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_300;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)7):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_302;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)8):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_304;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)9):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_306;
	}
	break;
	case ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_308;
	}
	break;
	default:
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_309;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getSrcTimestamp__options_u641)(tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw* Result) {
	NimStringV2 colontmpD_;
	NimStringV2 T3_;
	NI T4_;
	tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw));
	(*Result).Sup.m_type = (&NTIv2__JiByOtYhsb3evWoWLWfUBw_);
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = getEnv__stdZenvvars_u16(TM__zQHipMPUXFgsDrLbMR9atnA_311, TM__zQHipMPUXFgsDrLbMR9atnA_313);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA2_;}
	colontmpD_ = T3_;
	T4_ = (NI)0;
	T4_ = nsuParseInt(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	T5_ = fromUnix__pureZtimes_u1237(((NI64) (T4_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	utc__pureZtimes_u2061(T5_, Result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
	{
		LA2_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA1_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
			tyObject_Time__f9czJU2iP3D49bUN3jzSsOfA T11_;
			*nimErr_ = NIM_FALSE;
			T11_ = getTime__pureZtimes_u1291();
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			utc__pureZtimes_u2061(T11_, Result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			popCurrentException();
			LA9_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getDateStr__options_u643)(void) {
	NimStringV2 result;
	tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw));
	colontmpD_.Sup.m_type = (&NTIv2__JiByOtYhsb3evWoWLWfUBw_);
	getSrcTimestamp__options_u641((&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = format__options_u645((&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___pureZtimes_u1713((&colontmpD_));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getClockStr__options_u651)(void) {
	NimStringV2 result;
	tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyObject_DateTime__JiByOtYhsb3evWoWLWfUBw));
	colontmpD_.Sup.m_type = (&NTIv2__JiByOtYhsb3evWoWLWfUBw_);
	getSrcTimestamp__options_u641((&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = format__options_u653((&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___pureZtimes_u1713((&colontmpD_));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmprofiler_u1182)(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw* dest_p0) {
	(*dest_p0).time = 0;
	(*dest_p0).count = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, absOutFile__options_u3622)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__pathutils_u139((*conf_p0).outDir);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(!(T3_))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__zQHipMPUXFgsDrLbMR9atnA_315);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = isEmpty__options_u3633((*conf_p0).outFile);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(!(T8_))) goto LA9_;
		failedAssertImpl__stdZassertions_u79(TM__zQHipMPUXFgsDrLbMR9atnA_317);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA9_: ;
	result = slash___pathutils_u135((*conf_p0).outDir, (*conf_p0).outFile);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nosdirExists(result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T13_) goto LA14_;
		prepareAdd((&result), 4);
appendString((&result), TM__zQHipMPUXFgsDrLbMR9atnA_319);
	}
LA14_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOutFile__options_u3612)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NimStringV2 ext_p2) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		if (!!((((NI)0) < (*conf_p0).outDir.len))) goto LA4_;
		failedAssertImpl__stdZassertions_u79(TM__zQHipMPUXFgsDrLbMR9atnA_321);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	colontmpD_ = noschangeFileExt(filename_p1, ext_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = slash___pathutils_u135((*conf_p0).outDir, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonicalImport__options_u4253)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 file_p1) {
	NimStringV2 result;
	NimStringV2 ret_1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	ret_1.len = 0; ret_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	ret_1 = canonicalImportAux__options_u4231(conf_p0, file_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = nativeToUnixPath__stdZprivateZglobs_u96(ret_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = noschangeFileExt(colontmpD_, TM__zQHipMPUXFgsDrLbMR9atnA_322);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(ret_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, prepareToWriteOutput__options_u3642)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = absOutFile__options_u3622(conf_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = nosparentDir(result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	noscreateDir(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___options_u2144)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg** dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p1) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___options_u1751((&(*(*dest_p0))));
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
}
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1) {
	NIM_BOOL result;
	result = ((*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (x_p0))).p == (*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (y_p1))).p);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u1871)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p1) {
	NI T6_;
	NI colontmp_;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__options_u1889((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_]), src_p1.p->data[colontmp_]);
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u1622)(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* dest_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* src_p1) {
	eqcopy___system_u2694((&(*dest_p0).nimname), (*src_p1).nimname);
	eqcopy___system_u2694((&(*dest_p0).cname), (*src_p1).cname);
	eqcopy___system_u2694((&(*dest_p0).obj), (*src_p1).obj);
	(*dest_p0).flags = (*src_p1).flags;
	eqcopy___system_u2694((&(*dest_p0).customArgs), (*src_p1).customArgs);
}
N_LIB_PRIVATE N_NIMCALL(void, setNoteDefaults__options_u510)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw note_p1, NIM_BOOL enabled_p2) {
	{
		if (!enabled_p2) goto LA3_;
		(*conf_p0).notes[(NU)((note_p1 - 20))>>3] |=(1U<<((note_p1 - 20)&7U));
		(*conf_p0).mainPackageNotes[(NU)((note_p1 - 20))>>3] |=(1U<<((note_p1 - 20)&7U));
		(*conf_p0).foreignPackageNotes[(NU)((note_p1 - 20))>>3] |=(1U<<((note_p1 - 20)&7U));
	}
	goto LA1_;
LA3_: ;
	{
		(*conf_p0).notes[(NU)((note_p1 - 20))>>3] &= ~(1U<<((note_p1 - 20)&7U));
		(*conf_p0).mainPackageNotes[(NU)((note_p1 - 20))>>3] &= ~(1U<<((note_p1 - 20)&7U));
		(*conf_p0).foreignPackageNotes[(NU)((note_p1 - 20))>>3] &= ~(1U<<((note_p1 - 20)&7U));
	}
LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, assignIfDefault__main_u689)(NI* result_p0, NI val_p1, NI def_p2) {
	{
		if (!((*result_p0) == def_p2)) goto LA3_;
		(*result_p0) = val_p1;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mainCommandArg__options_u3593)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	{
		NI T3_;
		T3_ = (*conf_p0).commandArgs.len;
		if (!(((NI)0) < T3_)) goto LA4_;
		eqcopy___system_u2694((&result), (*conf_p0).commandArgs.p->data[((NI)0)]);
	}
	goto LA1_;
LA4_: ;
	{
		eqcopy___system_u2694((&result), (*conf_p0).projectName);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmprofiler_u1185)(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw dest_p0) {
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u177)(tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)0):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_324;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)1):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_326;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)2):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_328;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)3):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_330;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)4):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_332;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)5):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_334;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)6):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_336;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)7):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_338;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_340;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)9):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_342;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)10):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_344;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)11):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_346;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)12):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_348;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)13):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_350;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)14):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_352;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)15):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_354;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_356;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)17):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_358;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)18):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_360;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)19):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_362;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)20):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_364;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)21):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_366;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)22):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_368;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)23):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_370;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)24):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_372;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)25):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_374;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)26):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_376;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)27):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_378;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)28):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_380;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)29):
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_382;
	}
	break;
	default:
	{
		result = TM__zQHipMPUXFgsDrLbMR9atnA_383;
	}
	break;
	}
	return result;
}
