/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw;
typedef struct tySequence__7Eqk7CViYtlAWKDoMfuEcw tySequence__7Eqk7CViYtlAWKDoMfuEcw;
typedef struct tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content;
typedef struct tySequence__jXZVXmhly1BClQDJpGni9ag tySequence__jXZVXmhly1BClQDJpGni9ag;
typedef struct tySequence__jXZVXmhly1BClQDJpGni9ag_Content tySequence__jXZVXmhly1BClQDJpGni9ag_Content;
typedef struct tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg;
typedef struct tyTuple__ILpLBib1l58GvVZ4BcToSg tyTuple__ILpLBib1l58GvVZ4BcToSg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct RootObj RootObj;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct tySequence__7Eqk7CViYtlAWKDoMfuEcw {
  NI len; tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content* p;
};
struct tySequence__jXZVXmhly1BClQDJpGni9ag {
  NI len; tySequence__jXZVXmhly1BClQDJpGni9ag_Content* p;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw {
	tySequence__9ahcSjIErJohSBBFLwuF56Q s;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g;
	NIM_BOOL beSmart;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw {
	tySequence__7Eqk7CViYtlAWKDoMfuEcw locals;
	tySequence__jXZVXmhly1BClQDJpGni9ag slices;
	tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw guards;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA args;
	NI spawns;
	NI currentSpawnId;
	NI inLoop;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
};
typedef NU8 tyEnum_TDirection__Pz9b8tDdgaM43b9cFTDRlyRg;
struct tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* alias;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lower;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* upper;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* stride;
	tyEnum_TDirection__Pz9b8tDdgaM43b9cFTDRlyRg dir;
	NIM_BOOL blacklisted;
};
struct tyTuple__ILpLBib1l58GvVZ4BcToSg {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
	NI Field3;
	NIM_BOOL Field4;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef NU8 tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw;
typedef NU16 tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
typedef NimStringV2 tyArray__A2YC0h9cZydgH7zGAndH9bLg[6];
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
typedef NU8 tyEnum_TSpawnResult__Fi6IYHzmOR0d8zopbmZXuw;
struct tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content { NI cap; tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg data[SEQ_DECL_SIZE]; };
struct tySequence__jXZVXmhly1BClQDJpGni9ag_Content { NI cap; tyTuple__ILpLBib1l58GvVZ4BcToSg data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, initAnalysisCtx__semparallel_u44)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* Result);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw*, eqdup___modulegraphs_u14759)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3705)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u14756)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw** dest_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, analyse__semparallel_u1034)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipConv__types_u3715)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSingleAssignable__semparallel_u746)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocal__semparallel_u766)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg*, getSlot__semparallel_u631)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1);
N_LIB_PRIVATE N_NIMCALL(NI, lookupSlot__semparallel_u611)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semparallel_u92)(tySequence__7Eqk7CViYtlAWKDoMfuEcw* s_p0, NI newlen_p1);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3125)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
static N_INLINE(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg*, X5BX5D___semparallel_u643)(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, invalidateFacts__guards_u610)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg, getMagic__trees_u122)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* op_p0);
N_LIB_PRIVATE N_NIMCALL(void, gatherArgs__semparallel_u720)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getRoot__trees_u373)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__renderer_u83)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, analyseSons__semparallel_u1037)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, addAsgnFact__guards_u1619)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, analyseCall__semparallel_u1055)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_p2);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(NIM_BOOL, fromSystem__astalgo_u184)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getModule__astalgo_u156)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, min__semparallel_u1045)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipStmtList__ast_u7252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, addSlice__semparallel_u850)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p4);
N_LIB_PRIVATE N_NIMCALL(void, checkLocal__semparallel_u786)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, canon__guards_u289)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* o_p1);
N_LIB_PRIVATE N_NIMCALL(void, addLowerBoundAsFacts__semparallel_u809)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, addFactLe__guards_u1553)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5168)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__semparallel_u805)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arr_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* idx_p2);
N_LIB_PRIVATE N_NIMCALL(void, checkLe__semparallel_u801)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw, proveLe__guards_u1542)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderTree__renderer_u59)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lowBound__guards_u230)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, highBound__guards_u234)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p1, tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* o_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3718)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__semparallel_u866)(tySequence__jXZVXmhly1BClQDJpGni9ag* x_p0, tyTuple__ILpLBib1l58GvVZ4BcToSg y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, eqdup___ast_u3258)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p3);
N_LIB_PRIVATE N_NIMCALL(void, analyseCase__semparallel_u1081)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, addCaseBranchFacts__guards_u1638)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NI i_p2);
N_LIB_PRIVATE N_NIMCALL(void, analyseIf__semparallel_u1107)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, addFact__guards_u476)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nn_p1);
N_LIB_PRIVATE N_NIMCALL(void, addFactNeg__guards_u497)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__ast_u7675)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__ast_u7029)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p1);
N_LIB_PRIVATE N_NIMCALL(void, checkSlicesAreDisjoint__semparallel_u925)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, overlap__semparallel_u886)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw m_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* c_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* d_p5);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, subStride__semparallel_u911)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, buildAdd__guards_u390)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, NI64 b_p1, tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* o_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, shallowCopy__ast_u6876)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semparallel_u407)(tyTuple__ILpLBib1l58GvVZ4BcToSg* dest_p0, tyTuple__ILpLBib1l58GvVZ4BcToSg src_p1);
static N_INLINE(void, nimIncRef)(void* p_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameTree__guards_u545)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, simpleSlice__guards_u806)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, stride__semparallel_u893)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u404)(tyTuple__ILpLBib1l58GvVZ4BcToSg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, checkArgs__semparallel_u1302)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getCompilerProc__magicsys_u150)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NimStringV2 name_p1);
N_LIB_PRIVATE N_NIMCALL(void, addVar__lowerings_u34)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* v_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, genAddrOf__lowerings_u418)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg typeKind_p2);
N_LIB_PRIVATE N_NIMCALL(void, generateAliasChecks__semparallel_u1305)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, callCodegenProc__lowerings_u430)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NimStringV2 name_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg1_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg2_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg3_p5, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* optionalArgs_p6);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformSpawn__semparallel_u1244)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* barrier_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformSlices__semparallel_u1219)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyNode__ast_u6736)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newType__ast_u5900)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p3);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3881)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3375)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, createMagic__modulegraphs_u10814)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, NimStringV2 name_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getSysType__magicsys_u55)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p2);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpawnResult__Fi6IYHzmOR0d8zopbmZXuw, spawnResult__spawn_u29)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, NIM_BOOL inParallel_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, wrapProcForSpawn__spawn_u349)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* spawnExpr_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* retType_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* barrier_p5, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p6);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformSpawnSons__semparallel_u1250)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* barrier_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u570)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13532)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3696)(tySequence__9ahcSjIErJohSBBFLwuF56Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u335)(tySequence__jXZVXmhly1BClQDJpGni9ag dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u66)(tySequence__7Eqk7CViYtlAWKDoMfuEcw dest_p0);
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Itl65swq3r8pqY8Wou1vYA_2 = { 2 | NIM_STRLIT_FLAG, "+=" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_3 = {2, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_2};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Itl65swq3r8pqY8Wou1vYA_4 = { 2 | NIM_STRLIT_FLAG, "[]" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_5 = {2, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_4};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__Itl65swq3r8pqY8Wou1vYA_6 = { 40 | NIM_STRLIT_FLAG, "invalid usage of counter after increment" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_7 = {40, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_6};
static const struct {
  NI cap; NIM_CHAR data[66+1];
} TM__Itl65swq3r8pqY8Wou1vYA_9 = { 66 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/semparallel.nim" };
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__Itl65swq3r8pqY8Wou1vYA_10 = { 14 | NIM_STRLIT_FLAG, "cannot prove: " };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_11 = {14, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_10};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__Itl65swq3r8pqY8Wou1vYA_12 = { 4 | NIM_STRLIT_FLAG, " <= " };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_13 = {4, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_12};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__Itl65swq3r8pqY8Wou1vYA_15 = { 11 | NIM_STRLIT_FLAG, "can prove: " };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_16 = {11, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_15};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__Itl65swq3r8pqY8Wou1vYA_17 = { 3 | NIM_STRLIT_FLAG, " > " };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_18 = {3, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_17};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__Itl65swq3r8pqY8Wou1vYA_20 = { 3 | NIM_STRLIT_FLAG, "[]=" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_21 = {3, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_20};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__Itl65swq3r8pqY8Wou1vYA_22 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__Itl65swq3r8pqY8Wou1vYA_23 = { 35 | NIM_STRLIT_FLAG, "invalid control flow for \'parallel\'" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_24 = {35, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_23};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__Itl65swq3r8pqY8Wou1vYA_26 = { 30 | NIM_STRLIT_FLAG, "slot already has a lower bound" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_27 = {30, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_26};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__Itl65swq3r8pqY8Wou1vYA_29 = { 34 | NIM_STRLIT_FLAG, "\'parallel\' section without \'spawn\'" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_30 = {34, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_29};
static const struct {
  NI cap; NIM_CHAR data[71+1];
} TM__Itl65swq3r8pqY8Wou1vYA_32 = { 71 | NIM_STRLIT_FLAG, "cannot prove: $# > $#; required for ($#)..($#) disjoint from ($#)..($#)" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_33 = {71, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_32};
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_35 = {71, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_32};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__Itl65swq3r8pqY8Wou1vYA_37 = { 39 | NIM_STRLIT_FLAG, "($#)..($#) not disjoint from ($#)..($#)" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_38 = {39, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_37};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__Itl65swq3r8pqY8Wou1vYA_40 = { 48 | NIM_STRLIT_FLAG, "cannot prove ($#)..($#) disjoint from ($#)..($#)" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_41 = {48, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_40};
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_43 = {48, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_40};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__Itl65swq3r8pqY8Wou1vYA_45 = { 7 | NIM_STRLIT_FLAG, "barrier" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_46 = {7, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_45};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__Itl65swq3r8pqY8Wou1vYA_47 = { 7 | NIM_STRLIT_FLAG, "Barrier" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_48 = {7, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_47};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__Itl65swq3r8pqY8Wou1vYA_49 = { 11 | NIM_STRLIT_FLAG, "openBarrier" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_50 = {11, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_49};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__Itl65swq3r8pqY8Wou1vYA_51 = { 27 | NIM_STRLIT_FLAG, "invalid context for \'spawn\'" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_52 = {27, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_51};
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_54 = {2, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_4};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__Itl65swq3r8pqY8Wou1vYA_55 = { 5 | NIM_STRLIT_FLAG, "slice" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_56 = {5, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_55};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__Itl65swq3r8pqY8Wou1vYA_57 = { 12 | NIM_STRLIT_FLAG, "closeBarrier" };
static const NimStringV2 TM__Itl65swq3r8pqY8Wou1vYA_58 = {12, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_57};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_8 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)123),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_14 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)132),
((NI)11)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_19 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)136),
((NI)11)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_25 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)358),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_28 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)374),
((NI)31)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_31 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)487),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_34 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)167),
((NI)13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_36 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)173),
((NI)13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_39 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)177),
((NI)13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_42 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)253),
((NI)22)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_44 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)256),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__Itl65swq3r8pqY8Wou1vYA_53 = {{66, (NimStrPayload*)&TM__Itl65swq3r8pqY8Wou1vYA_9},
((NI)439),
((NI)34)}
;
extern NIM_BOOL nimInErrorMode__system_u4141;
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4141);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initAnalysisCtx__semparallel_u44)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* Result) {
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* colontmpD_;
	tySequence__9ahcSjIErJohSBBFLwuF56Q T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw));
	nimZeroMem((void*)Result, sizeof(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw));
	(*Result).locals.len = 0; (*Result).locals.p = (tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content*) newSeqPayload(0, sizeof(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg), NIM_ALIGNOF(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg));
	(*Result).slices.len = 0; (*Result).slices.p = (tySequence__jXZVXmhly1BClQDJpGni9ag_Content*) newSeqPayload(0, sizeof(tyTuple__ILpLBib1l58GvVZ4BcToSg), NIM_ALIGNOF(tyTuple__ILpLBib1l58GvVZ4BcToSg));
	(*Result).args.len = 0; (*Result).args.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	colontmpD_ = eqdup___modulegraphs_u14759(g_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).graph = colontmpD_;
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_.len = 0; T1_.p = (tySequence__9ahcSjIErJohSBBFLwuF56Q_Content*) newSeqPayload(0, sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
	eqsink___ast_u3705((&(*Result).guards.s), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___modulegraphs_u14756(&(*Result).guards.g, g_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	T1_ = X5BX5D___ast_u5211((((*n_p0)._kind_6.sons).p) ? ((*n_p0)._kind_6.sons.p->data) : NIM_NIL, (*n_p0)._kind_6.sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSingleAssignable__semparallel_u746)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T5_;
	s_1 = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
	if (!(T1_)) goto LA2_;
	s_1 = (*n_p0)._kind_4.sym;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9));
	if (!(T3_)) goto LA4_;
	T5_ = 0;
	T3_ = ((131080 & (*s_1).flags) == T5_);
LA4_: ;
	T1_ = T3_;
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLocal__semparallel_u766)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T5_;
	s_1 = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
	if (!(T1_)) goto LA2_;
	s_1 = (*n_p0)._kind_4.sym;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9));
	if (!(T3_)) goto LA4_;
	T5_ = 0;
	T3_ = ((131080 & (*s_1).flags) == T5_);
LA4_: ;
	T1_ = T3_;
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, lookupSlot__semparallel_u611)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NI result;
{	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*c_p0).locals.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				{
					NIM_BOOL T7_;
					T7_ = (NIM_BOOL)0;
					T7_ = ((*c_p0).locals.p->data[i_1].v == s_p1);
					if (T7_) goto LA8_;
					T7_ = ((*c_p0).locals.p->data[i_1].alias == s_p1);
LA8_: ;
					if (!T7_) goto LA9_;
					result = i_1;
					goto BeforeRet_;
				}
LA9_: ;
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	result = ((NI)-1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) - (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3125(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u137)(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.stride);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.stride)));
		nimRawDispose(dest_p0.stride, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn(dest_p0.upper);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3270((&(*dest_p0.upper)));
		nimRawDispose(dest_p0.upper, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn(dest_p0.lower);
		if (!T13_) goto LA14_;
		eqdestroy___ast_u3270((&(*dest_p0.lower)));
		nimRawDispose(dest_p0.lower, ((NI)8));
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastDyn(dest_p0.alias);
		if (!T18_) goto LA19_;
		eqdestroy___ast_u3469((&(*dest_p0.alias)));
		nimRawDispose(dest_p0.alias, ((NI)8));
	}
LA19_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn(dest_p0.v);
		if (!T23_) goto LA24_;
		eqdestroy___ast_u3469((&(*dest_p0.v)));
		nimRawDispose(dest_p0.v, ((NI)8));
	}
LA24_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semparallel_u134)(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* dest_p0) {
	(*dest_p0).v = 0;
	(*dest_p0).alias = 0;
	(*dest_p0).lower = 0;
	(*dest_p0).upper = 0;
	(*dest_p0).stride = 0;
	(*dest_p0).dir = 0;
	(*dest_p0).blacklisted = 0;
}
static N_INLINE(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg*, X5BX5D___semparallel_u643)(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* result;
	result = (&s_p0[(NI)(s_p0Len_0 - i_p1)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg*, getSlot__semparallel_u631)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1) {
	tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* result;
	NI s_1;
	NI T5_;
	tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg*)0;
	s_1 = lookupSlot__semparallel_u611((&(*c_p0)), v_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= s_1)) goto LA3_;
		result = (&(*c_p0).locals.p->data[s_1]);
		goto BeforeRet_;
	}
LA3_: ;
	T5_ = (*c_p0).locals.len;
	setLen__semparallel_u92((&(*c_p0).locals), ((NI)(T5_ + ((NI)1))));
	T6_ = (tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg*)0;
	T6_ = X5BX5D___semparallel_u643((((*c_p0).locals).p) ? ((*c_p0).locals.p->data) : NIM_NIL, (*c_p0).locals.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u4577(&(*T6_).v, v_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = X5BX5D___semparallel_u643((((*c_p0).locals).p) ? ((*c_p0).locals.p->data) : NIM_NIL, (*c_p0).locals.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, gatherArgs__semparallel_u720)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__ast_u3197(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* root_1;
				if (!(i_2 < colontmp_)) goto LA3;
				root_1 = NIM_NIL;
				i_1 = i_2;
				root_1 = getRoot__trees_u373((*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				{
					if (!!((root_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA7_;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
						{
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** r_1;
							NI i_3;
							NI L_1;
							NI T11_;
							r_1 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
							i_3 = ((NI)0);
							T11_ = (*c_p0).args.len;
							L_1 = T11_;
							{
								while (1) {
									if (!(i_3 < L_1)) goto LA13;
									r_1 = &(*c_p0).args.p->data[i_3];
									{
										if (!((*r_1) == root_1)) goto LA16_;
										goto LA9;
									}
LA16_: ;
									i_3 += ((NI)1);
								} LA13: ;
							}
						}
						blitTmp_1 = root_1;
						eqwasMoved___ast_u4571(&root_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						add__renderer_u83((&(*c_p0).args), blitTmp_1);
					} LA9: ;
				}
LA7_: ;
				gatherArgs__semparallel_u720(c_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(root_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, analyseSons__semparallel_u1037)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = safeLen__ast_u3197(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i_1 = i_2;
				analyse__semparallel_u1034(c_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, fromSystem__astalgo_u184)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_p0) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getModule__astalgo_u156(op_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((*colontmpD_).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0);
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, min__semparallel_u1045)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!(a_p0 == 0)) goto LA3_;
		eqcopy___ast_u3255(&result, b_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		if (!((*a_p0)._kind_1.intVal < (*b_p1)._kind_1.intVal)) goto LA6_;
		eqcopy___ast_u3255(&result, a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		eqcopy___ast_u3255(&result, b_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkLocal__semparallel_u786)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NI s_1;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__semparallel_u766(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		s_1 = lookupSlot__semparallel_u611(c_p0, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI)0) <= s_1);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c_p0).locals.p->data[s_1].stride == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA9_: ;
			if (!T8_) goto LA10_;
			liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__Itl65swq3r8pqY8Wou1vYA_7, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_8, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA10_: ;
	}
	goto LA1_;
LA4_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA15;
					i_1 = i_2;
					checkLocal__semparallel_u786(c_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA15: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addLowerBoundAsFacts__semparallel_u809)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0) {
NIM_BOOL oldNimErrFin9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* v_1;
		NI i_1;
		NI L_1;
		NI T2_;
		v_1 = (tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg*)0;
		i_1 = ((NI)0);
		T2_ = (*c_p0).locals.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				v_1 = (&(*c_p0).locals.p->data[i_1]);
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
					if (!!((*v_1).blacklisted)) goto LA7_;
					colontmpD_ = NIM_NIL;
					colontmpD_ = newSymNode__ast_u5168((*v_1).v);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					addFactLe__guards_u1553((&(*c_p0).guards), (*v_1).lower, colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					{
						LA9_:;
					}
					{
						oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin9_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA7_: ;
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkLe__semparallel_u801)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2) {
	tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)0;
	T1_ = proveLe__guards_u1542((*c_p0).guards, a_p1, b_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch (T1_) {
	case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)0):
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T4_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T5_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T4_.len = 0; T4_.p = NIM_NIL;
		T5_ = 0;
		colontmpD_ = renderTree__renderer_u59(a_p1, T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		T6_ = 0;
		colontmpD__2 = renderTree__renderer_u59(b_p2, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		T4_ = rawNewString(colontmpD_.len + colontmpD__2.len + 18);
appendString((&T4_), TM__Itl65swq3r8pqY8Wou1vYA_11);
appendString((&T4_), colontmpD_);
appendString((&T4_), TM__Itl65swq3r8pqY8Wou1vYA_13);
appendString((&T4_), colontmpD__2);
		colontmpD__3 = T4_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*a_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)52), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_14, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		{
			LA3_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)2):
	{
	}
	break;
	case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)1):
	{
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 T12_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T13_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T14_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		T12_.len = 0; T12_.p = NIM_NIL;
		T13_ = 0;
		colontmpD__4 = renderTree__renderer_u59(a_p1, T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		T14_ = 0;
		colontmpD__5 = renderTree__renderer_u59(b_p2, T14_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		T12_ = rawNewString(colontmpD__4.len + colontmpD__5.len + 14);
appendString((&T12_), TM__Itl65swq3r8pqY8Wou1vYA_16);
appendString((&T12_), colontmpD__4);
appendString((&T12_), TM__Itl65swq3r8pqY8Wou1vYA_18);
appendString((&T12_), colontmpD__5);
		colontmpD__6 = T12_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*a_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)52), colontmpD__6, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_19, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		{
			LA11_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkBounds__semparallel_u805)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arr_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* idx_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD_ = lowBound__guards_u230((*(*c_p0).graph).config, arr_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	checkLe__semparallel_u801(c_p0, colontmpD_, idx_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = highBound__guards_u234((*(*c_p0).graph).config, arr_p1, (&(*(*c_p0).graph).operators));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	checkLe__semparallel_u801(c_p0, idx_p2, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addSlice__semparallel_u850)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NI oldState_1;
	NI T2_;
	tyTuple__ILpLBib1l58GvVZ4BcToSg T3_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	le_2 = NIM_NIL;
	ri_2 = NIM_NIL;
	checkLocal__semparallel_u786((&(*c_p0)), n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	le_2 = canon__guards_u289(le_p3, (&(*(*c_p0).graph).operators));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ri_2 = canon__guards_u289(ri_p4, (&(*(*c_p0).graph).operators));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (*c_p0).guards.s.len;
	oldState_1 = T2_;
	addLowerBoundAsFacts__semparallel_u809(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	checkBounds__semparallel_u805((&(*c_p0)), x_p2, le_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	checkBounds__semparallel_u805((&(*c_p0)), x_p2, ri_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setLen__ast_u3718((&(*c_p0).guards.s), (oldState_1));
	nimZeroMem((void*)(&T3_), sizeof(tyTuple__ILpLBib1l58GvVZ4BcToSg));
	colontmpD_ = eqdup___ast_u3258(x_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_.Field0 = colontmpD_;
	blitTmp_1 = le_2;
	eqwasMoved___ast_u3249(&le_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_.Field1 = blitTmp_1;
	blitTmp_2 = ri_2;
	eqwasMoved___ast_u3249(&ri_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_.Field2 = blitTmp_2;
	T3_.Field3 = (*c_p0).currentSpawnId;
	T3_.Field4 = (((NI)0) < (*c_p0).inLoop);
	add__semparallel_u866((&(*c_p0).slices), T3_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(ri_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(le_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, analyseCall__semparallel_u1055)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_p2) {
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin37_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI oldSpawnId_1;
		if (!((*op_p2).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)199))) goto LA3_;
		(*c_p0).spawns += ((NI)1);
		oldSpawnId_1 = (*c_p0).currentSpawnId;
		(*c_p0).currentSpawnId = (*c_p0).spawns;
		gatherArgs__semparallel_u720(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		analyseSons__semparallel_u1037(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*c_p0).currentSpawnId = oldSpawnId_1;
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL T6_;
		NIM_BOOL T8_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((*op_p2).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)29));
		if (T6_) goto LA7_;
		T8_ = (NIM_BOOL)0;
		T8_ = eqStrings((*(*op_p2).name).s, TM__Itl65swq3r8pqY8Wou1vYA_3);
		if (!(T8_)) goto LA9_;
		T8_ = fromSystem__astalgo_u184(op_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA9_: ;
		T6_ = T8_;
LA7_: ;
		if (!T6_) goto LA10_;
		{
			NIM_BOOL T14_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* incr_1;
			T14_ = (NIM_BOOL)0;
			T14_ = isLocal__semparallel_u766((*n_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA15_;
			incr_1 = NIM_NIL;
			incr_1 = skipConv__types_u3715((*n_p1)._kind_6.sons.p->data[((NI)2)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				NIM_BOOL T19_;
				tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* slot_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T23_;
				T19_ = (NIM_BOOL)0;
				T19_ = ((*incr_1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) && (*incr_1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)14));
				if (!(T19_)) goto LA20_;
				T19_ = (IL64(0) < (*incr_1)._kind_1.intVal);
LA20_: ;
				if (!T19_) goto LA21_;
				slot_1 = getSlot__semparallel_u631(c_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T23_ = NIM_NIL;
				T23_ = min__semparallel_u1045((*slot_1).stride, incr_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T23_); goto BeforeRet_;}
				eqsink___ast_u3261(&(*slot_1).stride, T23_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA21_: ;
			eqdestroy___ast_u3252(incr_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA15_: ;
		analyseSons__semparallel_u1037(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA10_: ;
	{
		NIM_BOOL T25_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* slice_1;
		T25_ = (NIM_BOOL)0;
		T25_ = eqStrings((*(*op_p2).name).s, TM__Itl65swq3r8pqY8Wou1vYA_5);
		if (!(T25_)) goto LA26_;
		T25_ = fromSystem__astalgo_u184(op_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA26_: ;
		if (!T25_) goto LA27_;
		slice_1 = NIM_NIL;
		slice_1 = skipStmtList__ast_u7252((*n_p1)._kind_6.sons.p->data[((NI)2)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		addSlice__semparallel_u850(c_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)1)], (*slice_1)._kind_6.sons.p->data[((NI)1)], (*slice_1)._kind_6.sons.p->data[((NI)2)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		analyseSons__semparallel_u1037(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		{
			LA29_:;
		}
		{
			oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(slice_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin29_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA27_: ;
	{
		NIM_BOOL T33_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* slice_2;
		T33_ = (NIM_BOOL)0;
		T33_ = eqStrings((*(*op_p2).name).s, TM__Itl65swq3r8pqY8Wou1vYA_21);
		if (!(T33_)) goto LA34_;
		T33_ = fromSystem__astalgo_u184(op_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA34_: ;
		if (!T33_) goto LA35_;
		slice_2 = NIM_NIL;
		slice_2 = skipStmtList__ast_u7252((*n_p1)._kind_6.sons.p->data[((NI)2)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		addSlice__semparallel_u850(c_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)1)], (*slice_2)._kind_6.sons.p->data[((NI)1)], (*slice_2)._kind_6.sons.p->data[((NI)2)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		analyseSons__semparallel_u1037(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		{
			LA37_:;
		}
		{
			oldNimErrFin37_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(slice_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin37_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA35_: ;
	{
		analyseSons__semparallel_u1037(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, analyseCase__semparallel_u1081)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NI oldFacts_1;
	NI T1_;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	analyse__semparallel_u1034(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (*c_p0).guards.s.len;
	oldFacts_1 = T1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)1);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_1;
				if (!(i_2 < colontmp_)) goto LA4;
				branch_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&branch_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				setLen__ast_u3718((&(*c_p0).guards.s), (oldFacts_1));
				addCaseBranchFacts__guards_u1638((&(*c_p0).guards), n_p1, i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					NI i_3;
					NI colontmp__2;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = len__ast_u3190(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					i_4 = ((NI)0);
					{
						while (1) {
							if (!(i_4 < colontmp__2)) goto LA8;
							i_3 = i_4;
							analyse__semparallel_u1034(c_p0, (*branch_1)._kind_6.sons.p->data[i_3]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
							i_4 += ((NI)1);
						} LA8: ;
					}
				}
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin5_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA4: ;
		}
	}
	setLen__ast_u3718((&(*c_p0).guards.s), (oldFacts_1));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, analyseIf__semparallel_u1107)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NI oldFacts_1;
	NI T2_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin18_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	analyse__semparallel_u1034(c_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (*c_p0).guards.s.len;
	oldFacts_1 = T2_;
	colontmpD_ = canon__guards_u289((*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)], (&(*(*c_p0).graph).operators));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addFact__guards_u476((&(*c_p0).guards), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	analyse__semparallel_u1034(c_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_1;
				if (!(i_2 < colontmp_)) goto LA5;
				branch_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&branch_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				setLen__ast_u3718((&(*c_p0).guards.s), (oldFacts_1));
				{
					NI j_1;
					NI colontmp__2;
					NI res_1;
					j_1 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__2 = (NI)(i_1 - ((NI)1));
					res_1 = ((NI)0);
					{
						while (1) {
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
							if (!(res_1 <= colontmp__2)) goto LA9;
							colontmpD__2 = NIM_NIL;
							j_1 = ((NI) (res_1));
							colontmpD__2 = canon__guards_u289((*(*n_p1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)0)], (&(*(*c_p0).graph).operators));
							if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
							addFactNeg__guards_u497((&(*c_p0).guards), colontmpD__2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
							res_1 += ((NI)1);
							{
								LA10_:;
							}
							{
								oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(colontmpD__2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
								*nimErr_ = oldNimErrFin10_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						} LA9: ;
					}
				}
				{
					NI T15_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
					T15_ = (NI)0;
					T15_ = len__ast_u3190(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					if (!(((NI)1) < T15_)) goto LA16_;
					colontmpD__3 = NIM_NIL;
					colontmpD__3 = canon__guards_u289((*branch_1)._kind_6.sons.p->data[((NI)0)], (&(*(*c_p0).graph).operators));
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					addFact__guards_u476((&(*c_p0).guards), colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					{
						LA18_:;
					}
					{
						oldNimErrFin18_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						*nimErr_ = oldNimErrFin18_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				}
LA16_: ;
				{
					NI i_3;
					NI colontmp__3;
					NI i_4;
					i_3 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__3 = len__ast_u3190(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					i_4 = ((NI)0);
					{
						while (1) {
							if (!(i_4 < colontmp__3)) goto LA23;
							i_3 = i_4;
							analyse__semparallel_u1034(c_p0, (*branch_1)._kind_6.sons.p->data[i_3]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
							i_4 += ((NI)1);
						} LA23: ;
					}
				}
				i_2 += ((NI)1);
				{
					LA6_:;
				}
				{
					oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin6_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA5: ;
		}
	}
	setLen__ast_u3718((&(*c_p0).guards.s), (oldFacts_1));
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, analyse__semparallel_u1034)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin2_;
NIM_BOOL oldNimErrFin28_;
NIM_BOOL oldNimErrFin44_;
NIM_BOOL oldNimErrFin40_;
NIM_BOOL oldNimErrFin93_;
NIM_BOOL oldNimErrFin85_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)74):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_1;
		y_1 = NIM_NIL;
		value_1 = NIM_NIL;
		y_1 = skipConv__types_u3715((*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		{
			NIM_BOOL T5_;
			tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* slot_1;
			T5_ = (NIM_BOOL)0;
			T5_ = isSingleAssignable__semparallel_u746((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			if (!(T5_)) goto LA6_;
			T5_ = isLocal__semparallel_u766(y_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
LA6_: ;
			if (!T5_) goto LA7_;
			slot_1 = getSlot__semparallel_u631(c_p0, (*y_1)._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			eqcopy___ast_u4577(&(*slot_1).alias, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		goto LA3_;
LA7_: ;
		{
			NIM_BOOL T10_;
			tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* slot_2;
			T10_ = (NIM_BOOL)0;
			T10_ = isLocal__semparallel_u766((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			if (!T10_) goto LA11_;
			slot_2 = getSlot__semparallel_u631(c_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			(*slot_2).blacklisted = NIM_TRUE;
		}
		goto LA3_;
LA11_: ;
LA3_: ;
		invalidateFacts__guards_u610((&(*c_p0).guards), (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		eqcopy___ast_u3255(&value_1, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		{
			tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg T15_;
			NI oldSpawnId_1;
			T15_ = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
			T15_ = getMagic__trees_u122(value_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			if (!(T15_ == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)199))) goto LA16_;
			(*c_p0).spawns += ((NI)1);
			oldSpawnId_1 = (*c_p0).currentSpawnId;
			(*c_p0).currentSpawnId = (*c_p0).spawns;
			gatherArgs__semparallel_u720(c_p0, (*value_1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			analyseSons__semparallel_u1037(c_p0, (*value_1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			analyse__semparallel_u1034(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			(*c_p0).currentSpawnId = oldSpawnId_1;
		}
		goto LA13_;
LA16_: ;
		{
			analyseSons__semparallel_u1037(c_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
LA13_: ;
		addAsgnFact__guards_u1619((&(*c_p0).guards), (*n_p1)._kind_6.sons.p->data[((NI)0)], y_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(value_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(y_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		{
			if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA24_;
			analyseCall__semparallel_u1055(c_p0, n_p1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA22_;
LA24_: ;
		{
			analyseSons__semparallel_u1037(c_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA22_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = !(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
			if (!(T31_)) goto LA32_;
			colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__Itl65swq3r8pqY8Wou1vYA_22);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			T31_ = !(((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18)));
LA32_: ;
			if (!T31_) goto LA33_;
			addSlice__semparallel_u850(c_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)1)], (*n_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		}
LA33_: ;
		analyseSons__semparallel_u1037(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		{
			LA28_:;
		}
		{
			oldNimErrFin28_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin28_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)109):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)108):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)106):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)154):
	{
		liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__Itl65swq3r8pqY8Wou1vYA_24, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_25, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
			it_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
				i_2 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_2;
						NIM_BOOL isSpawned_1;
						tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg T45_;
						if (!(i_2 < colontmp_)) goto LA43;
						value_2 = NIM_NIL;
						i_1 = i_2;
						eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
						value_2 = lastSon__ast_u5208(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
						T45_ = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
						T45_ = getMagic__trees_u122(value_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
						isSpawned_1 = (T45_ == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)199));
						{
							NI oldSpawnId_2;
							if (!isSpawned_1) goto LA48_;
							(*c_p0).spawns += ((NI)1);
							oldSpawnId_2 = (*c_p0).currentSpawnId;
							(*c_p0).currentSpawnId = (*c_p0).spawns;
							gatherArgs__semparallel_u720(c_p0, (*value_2)._kind_6.sons.p->data[((NI)1)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							analyseSons__semparallel_u1037(c_p0, (*value_2)._kind_6.sons.p->data[((NI)1)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							(*c_p0).currentSpawnId = oldSpawnId_2;
						}
LA48_: ;
						{
							if (!!(((*value_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA52_;
							{
								NI j_1;
								NI colontmp__2;
								NI T55_;
								NI i_3;
								j_1 = (NI)0;
								colontmp__2 = (NI)0;
								T55_ = (NI)0;
								T55_ = len__ast_u3190(it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
								colontmp__2 = (NI)(T55_ - ((NI)2));
								i_3 = ((NI)0);
								{
									while (1) {
										if (!(i_3 < colontmp__2)) goto LA57;
										j_1 = i_3;
										{
											NIM_BOOL T60_;
											tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* slot_3;
											T60_ = (NIM_BOOL)0;
											T60_ = isLocal__semparallel_u766((*it_1)._kind_6.sons.p->data[j_1]);
											if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
											if (!T60_) goto LA61_;
											slot_3 = getSlot__semparallel_u631(c_p0, (*(*it_1)._kind_6.sons.p->data[j_1])._kind_4.sym);
											if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
											{
												if (!((*slot_3).lower == 0)) goto LA65_;
												eqcopy___ast_u3255(&(*slot_3).lower, value_2);
												if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
											}
											goto LA63_;
LA65_: ;
											{
												internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*it_1).info, TM__Itl65swq3r8pqY8Wou1vYA_27, TM__Itl65swq3r8pqY8Wou1vYA_28);
												if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
											}
LA63_: ;
										}
LA61_: ;
										i_3 += ((NI)1);
									} LA57: ;
								}
							}
							{
								if (!!(isSpawned_1)) goto LA70_;
								analyse__semparallel_u1034(c_p0, value_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
							}
LA70_: ;
						}
LA52_: ;
						i_2 += ((NI)1);
						{
							LA44_:;
						}
						{
							oldNimErrFin44_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(value_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							*nimErr_ = oldNimErrFin44_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					} LA43: ;
				}
			}
			{
				LA40_:;
			}
			{
				oldNimErrFin40_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin40_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)97):
	{
		analyseCase__semparallel_u1081(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)93):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)92):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)48):
	{
		analyseIf__semparallel_u1107(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)96):
	{
		analyse__semparallel_u1034(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*c_p0).inLoop += ((NI)1);
		{
			NIM_BOOL T81_;
			T81_ = (NIM_BOOL)0;
			T81_ = isTrue__ast_u7675((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T81_) goto LA82_;
			analyseSons__semparallel_u1037(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA79_;
LA82_: ;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
			NI oldState_1;
			NI T86_;
			NI oldFacts_1;
			NI T87_;
			colontmpD__2 = NIM_NIL;
			T86_ = (*c_p0).locals.len;
			oldState_1 = T86_;
			T87_ = (*c_p0).guards.s.len;
			oldFacts_1 = T87_;
			colontmpD__2 = canon__guards_u289((*n_p1)._kind_6.sons.p->data[((NI)0)], (&(*(*c_p0).graph).operators));
			if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
			addFact__guards_u476((&(*c_p0).guards), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
			analyse__semparallel_u1034(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
			setLen__semparallel_u92((&(*c_p0).locals), (oldState_1));
			setLen__ast_u3718((&(*c_p0).guards.s), (oldFacts_1));
			{
				NIM_BOOL T90_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
				T90_ = (NIM_BOOL)0;
				T90_ = hasSubnodeWith__ast_u7029((*n_p1)._kind_6.sons.p->data[((NI)1)], ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)110));
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				if (!!(T90_)) goto LA91_;
				colontmpD__3 = NIM_NIL;
				colontmpD__3 = canon__guards_u289((*n_p1)._kind_6.sons.p->data[((NI)0)], (&(*(*c_p0).graph).operators));
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				addFactNeg__guards_u497((&(*c_p0).guards), colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				{
					LA93_:;
				}
				{
					oldNimErrFin93_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
					*nimErr_ = oldNimErrFin93_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
			}
LA91_: ;
			{
				LA85_:;
			}
			{
				oldNimErrFin85_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin85_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA79_: ;
		(*c_p0).inLoop -= ((NI)1);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)123):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)122):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)118):
	{
	}
	break;
	default:
	{
		analyseSons__semparallel_u1037(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, overlap__semparallel_u886)(tyObject_TModel__Z9bHL8dtMWJj2bnAnSvH1aw m_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* c_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* d_p5) {
	tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)0;
	T1_ = proveLe__guards_u1542(m_p0, c_p4, y_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch (T1_) {
	case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)0):
	{
		tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw T3_;
		T3_ = (tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)0;
		T3_ = proveLe__guards_u1542(m_p0, x_p2, d_p5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (T3_) {
		case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)1):
		{
		}
		break;
		case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)0):
		case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)2):
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			tyArray__A2YC0h9cZydgH7zGAndH9bLg T7_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T8_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T9_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T10_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T11_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T12_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T13_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			T8_ = 0;
			colontmpD_ = renderTree__renderer_u59(c_p4, T8_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T7_[0] = colontmpD_;
			T9_ = 0;
			colontmpD__2 = renderTree__renderer_u59(y_p3, T9_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T7_[1] = colontmpD__2;
			T10_ = 0;
			colontmpD__3 = renderTree__renderer_u59(x_p2, T10_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T7_[2] = colontmpD__3;
			T11_ = 0;
			colontmpD__4 = renderTree__renderer_u59(y_p3, T11_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T7_[3] = colontmpD__4;
			T12_ = 0;
			colontmpD__5 = renderTree__renderer_u59(c_p4, T12_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T7_[4] = colontmpD__5;
			T13_ = 0;
			colontmpD__6 = renderTree__renderer_u59(d_p5, T13_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T7_[5] = colontmpD__6;
			colontmpD__7 = nsuFormatOpenArray(TM__Itl65swq3r8pqY8Wou1vYA_33, T7_, 6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			liMessage__msgs_u1227(conf_p1, (*x_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)52), colontmpD__7, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_34, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			{
				LA6_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		default: __builtin_unreachable();
		}
	}
	break;
	case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)2):
	{
		tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw T17_;
		T17_ = (tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)0;
		T17_ = proveLe__guards_u1542(m_p0, x_p2, d_p5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (T17_) {
		case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)0):
		{
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			tyArray__A2YC0h9cZydgH7zGAndH9bLg T20_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T21_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T22_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T23_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T24_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T25_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T26_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			T21_ = 0;
			colontmpD__8 = renderTree__renderer_u59(x_p2, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			T20_[0] = colontmpD__8;
			T22_ = 0;
			colontmpD__9 = renderTree__renderer_u59(d_p5, T22_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			T20_[1] = colontmpD__9;
			T23_ = 0;
			colontmpD__10 = renderTree__renderer_u59(x_p2, T23_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			T20_[2] = colontmpD__10;
			T24_ = 0;
			colontmpD__11 = renderTree__renderer_u59(y_p3, T24_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			T20_[3] = colontmpD__11;
			T25_ = 0;
			colontmpD__12 = renderTree__renderer_u59(c_p4, T25_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			T20_[4] = colontmpD__12;
			T26_ = 0;
			colontmpD__13 = renderTree__renderer_u59(d_p5, T26_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			T20_[5] = colontmpD__13;
			colontmpD__14 = nsuFormatOpenArray(TM__Itl65swq3r8pqY8Wou1vYA_35, T20_, 6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			liMessage__msgs_u1227(conf_p1, (*x_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)52), colontmpD__14, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_36, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			{
				LA19_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)2):
		{
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			NimStringV2 colontmpD__18;
			NimStringV2 colontmpD__19;
			NimStringV2 colontmpD__20;
			NimStringV2 colontmpD__21;
			tyArray__A2YC0h9cZydgH7zGAndH9bLg T31_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T32_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T33_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T34_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T35_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T36_;
			tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T37_;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
			colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
			colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
			T32_ = 0;
			colontmpD__15 = renderTree__renderer_u59(c_p4, T32_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T31_[0] = colontmpD__15;
			T33_ = 0;
			colontmpD__16 = renderTree__renderer_u59(y_p3, T33_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T31_[1] = colontmpD__16;
			T34_ = 0;
			colontmpD__17 = renderTree__renderer_u59(x_p2, T34_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T31_[2] = colontmpD__17;
			T35_ = 0;
			colontmpD__18 = renderTree__renderer_u59(y_p3, T35_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T31_[3] = colontmpD__18;
			T36_ = 0;
			colontmpD__19 = renderTree__renderer_u59(c_p4, T36_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T31_[4] = colontmpD__19;
			T37_ = 0;
			colontmpD__20 = renderTree__renderer_u59(d_p5, T37_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T31_[5] = colontmpD__20;
			colontmpD__21 = nsuFormatOpenArray(TM__Itl65swq3r8pqY8Wou1vYA_38, T31_, 6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			liMessage__msgs_u1227(conf_p1, (*x_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)52), colontmpD__21, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_39, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			{
				LA30_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__21);
				eqdestroy___system_u2691(colontmpD__20);
				eqdestroy___system_u2691(colontmpD__19);
				eqdestroy___system_u2691(colontmpD__18);
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)1):
		{
		}
		break;
		default: __builtin_unreachable();
		}
	}
	break;
	case ((tyEnum_TImplication__Sad0CRSLBr9a9afuxo9akd9aqw)1):
	{
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, subStride__semparallel_u911)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NI s_1;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__semparallel_u766(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		s_1 = lookupSlot__semparallel_u611(c_p0, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI)0) <= s_1);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c_p0).locals.p->data[s_1].stride == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA9_: ;
			if (!T8_) goto LA10_;
			result = buildAdd__guards_u390(n_p1, (*(*c_p0).locals.p->data[s_1].stride)._kind_1.intVal, (&(*(*c_p0).graph).operators));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA6_;
LA10_: ;
		{
			eqcopy___ast_u3255(&result, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA6_: ;
	}
	goto LA1_;
LA4_: ;
	{
		NI T14_;
		T14_ = (NI)0;
		T14_ = safeLen__ast_u3197(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(((NI)0) < T14_)) goto LA15_;
		result = shallowCopy__ast_u6876(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T20_;
					if (!(i_2 < colontmp_)) goto LA19;
					i_1 = i_2;
					T20_ = NIM_NIL;
					T20_ = subStride__semparallel_u911(c_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T20_); goto BeforeRet_;}
					eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[i_1], T20_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA19: ;
			}
		}
	}
	goto LA1_;
LA15_: ;
	{
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) + (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semparallel_u407)(tyTuple__ILpLBib1l58GvVZ4BcToSg* dest_p0, tyTuple__ILpLBib1l58GvVZ4BcToSg src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1.Field0) goto LA3_;
		nimIncRef(src_p1.Field0);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3270((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)8));
	}
LA8_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	{
		if (!src_p1.Field1) goto LA12_;
		nimIncRef(src_p1.Field1);
	}
LA12_: ;
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = nimDecRefIsLastDyn((*dest_p0).Field1);
		if (!T16_) goto LA17_;
		eqdestroy___ast_u3270((&(*(*dest_p0).Field1)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field1, ((NI)8));
	}
LA17_: ;
	(*dest_p0).Field1 = src_p1.Field1;
	{
		if (!src_p1.Field2) goto LA21_;
		nimIncRef(src_p1.Field2);
	}
LA21_: ;
	{
		NIM_BOOL T25_;
		T25_ = (NIM_BOOL)0;
		T25_ = nimDecRefIsLastDyn((*dest_p0).Field2);
		if (!T25_) goto LA26_;
		eqdestroy___ast_u3270((&(*(*dest_p0).Field2)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field2, ((NI)8));
	}
LA26_: ;
	(*dest_p0).Field2 = src_p1.Field2;
	(*dest_p0).Field3 = src_p1.Field3;
	(*dest_p0).Field4 = src_p1.Field4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI64, stride__semparallel_u893)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NI64 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI64)0;
	{
		NIM_BOOL T3_;
		NI s_1;
		T3_ = (NIM_BOOL)0;
		T3_ = isLocal__semparallel_u766(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		s_1 = lookupSlot__semparallel_u611(c_p0, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (((NI)0) <= s_1);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*c_p0).locals.p->data[s_1].stride == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA9_: ;
			if (!T8_) goto LA10_;
			result = (*(*c_p0).locals.p->data[s_1].stride)._kind_1.intVal;
		}
		goto LA6_;
LA10_: ;
		{
			result = IL64(0);
		}
LA6_: ;
	}
	goto LA1_;
LA4_: ;
	{
		result = IL64(0);
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					NI64 T17_;
					if (!(i_2 < colontmp_)) goto LA16;
					i_1 = i_2;
					T17_ = (NI64)0;
					T17_ = stride__semparallel_u893(c_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					result += T17_;
					i_2 += ((NI)1);
				} LA16: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u404)(tyTuple__ILpLBib1l58GvVZ4BcToSg dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn(dest_p0.Field1);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3270((&(*dest_p0.Field1)));
		nimRawDispose(dest_p0.Field1, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn(dest_p0.Field2);
		if (!T13_) goto LA14_;
		eqdestroy___ast_u3270((&(*dest_p0.Field2)));
		nimRawDispose(dest_p0.Field2, ((NI)8));
	}
LA14_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkSlicesAreDisjoint__semparallel_u925)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* c_p0) {
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin20_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addLowerBoundAsFacts__semparallel_u809(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** x_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** a_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** b_1;
		NI* id_1;
		NIM_BOOL* inLoop_1;
		NI i_1;
		NI L_1;
		NI T2_;
		x_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
		a_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
		b_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
		id_1 = (NI*)0;
		inLoop_1 = (NIM_BOOL*)0;
		i_1 = ((NI)0);
		T2_ = (*c_p0).slices.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				x_1 = &(*c_p0).slices.p->data[i_1].Field0;
				a_1 = &(*c_p0).slices.p->data[i_1].Field1;
				b_1 = &(*c_p0).slices.p->data[i_1].Field2;
				id_1 = (&(*c_p0).slices.p->data[i_1].Field3);
				inLoop_1 = (&(*c_p0).slices.p->data[i_1].Field4);
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
					if (!(*inLoop_1)) goto LA7_;
					colontmpD_ = NIM_NIL;
					colontmpD__2 = NIM_NIL;
					colontmpD_ = subStride__semparallel_u911((&(*c_p0)), (*a_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					colontmpD__2 = subStride__semparallel_u911((&(*c_p0)), (*b_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					overlap__semparallel_u886((*c_p0).guards, (*(*c_p0).graph).config, (*a_1), (*b_1), colontmpD_, colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					{
						LA9_:;
					}
					{
						oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___ast_u3252(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin9_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA7_: ;
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	{
		NI i_2;
		NI colontmp_;
		NI T13_;
		NI res_1;
		i_2 = (NI)0;
		colontmp_ = (NI)0;
		T13_ = ((*c_p0).slices.len-1);
		colontmp_ = T13_;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA15;
				i_2 = ((NI) (res_1));
				{
					NI j_1;
					NI colontmp__2;
					NI colontmp__3;
					NI T17_;
					NI res_2;
					j_1 = (NI)0;
					colontmp__2 = (NI)0;
					colontmp__3 = (NI)0;
					colontmp__2 = (NI)(i_2 + ((NI)1));
					T17_ = ((*c_p0).slices.len-1);
					colontmp__3 = T17_;
					res_2 = colontmp__2;
					{
						while (1) {
							tyTuple__ILpLBib1l58GvVZ4BcToSg x_2;
							tyTuple__ILpLBib1l58GvVZ4BcToSg y_1;
							if (!(res_2 <= colontmp__3)) goto LA19;
							nimZeroMem((void*)(&x_2), sizeof(tyTuple__ILpLBib1l58GvVZ4BcToSg));
							nimZeroMem((void*)(&y_1), sizeof(tyTuple__ILpLBib1l58GvVZ4BcToSg));
							j_1 = ((NI) (res_2));
							eqcopy___semparallel_u407((&x_2), (*c_p0).slices.p->data[i_2]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
							eqcopy___semparallel_u407((&y_1), (*c_p0).slices.p->data[j_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
							{
								NIM_BOOL T23_;
								T23_ = (NIM_BOOL)0;
								T23_ = !((x_2.Field3 == y_1.Field3));
								if (!(T23_)) goto LA24_;
								T23_ = sameTree__guards_u545(x_2.Field0, y_1.Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
LA24_: ;
								if (!T23_) goto LA25_;
								{
									NIM_BOOL T29_;
									T29_ = (NIM_BOOL)0;
									T29_ = !(x_2.Field4);
									if (T29_) goto LA30_;
									T29_ = !(y_1.Field4);
LA30_: ;
									if (!T29_) goto LA31_;
									overlap__semparallel_u886((*c_p0).guards, (*(*c_p0).graph).config, x_2.Field1, x_2.Field2, y_1.Field1, y_1.Field2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
								}
								goto LA27_;
LA31_: ;
								{
									NI64 k_1;
									NI64 m_1;
									NIM_BOOL T34_;
									NI64 stride_1;
									NI64 T38_;
									NI64 T39_;
									k_1 = simpleSlice__guards_u806(x_2.Field1, x_2.Field2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
									m_1 = simpleSlice__guards_u806(y_1.Field1, y_1.Field2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
									T34_ = (NIM_BOOL)0;
									T34_ = (IL64(0) <= k_1);
									if (!(T34_)) goto LA35_;
									T34_ = (IL64(0) <= m_1);
LA35_: ;
									if (!T34_) goto LA36_;
									overlap__semparallel_u886((*c_p0).guards, (*(*c_p0).graph).config, x_2.Field1, x_2.Field2, y_1.Field1, y_1.Field2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
									T38_ = (NI64)0;
									T38_ = stride__semparallel_u893((&(*c_p0)), x_2.Field1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
									T39_ = (NI64)0;
									T39_ = stride__semparallel_u893((&(*c_p0)), y_1.Field1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
									stride_1 = ((T38_ <= T39_) ? T38_ : T39_);
									{
										NIM_BOOL T42_;
										T42_ = (NIM_BOOL)0;
										T42_ = (k_1 < stride_1);
										if (!(T42_)) goto LA43_;
										T42_ = (m_1 < stride_1);
LA43_: ;
										if (!T42_) goto LA44_;
									}
									goto LA40_;
LA44_: ;
									{
										NimStringV2 colontmpD__3;
										NimStringV2 colontmpD__4;
										NimStringV2 colontmpD__5;
										NimStringV2 colontmpD__6;
										NimStringV2 colontmpD__7;
										tyArray__Seu7uK9aaOSN0BK3EAjjSHw T48_;
										tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T49_;
										tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T50_;
										tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T51_;
										tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T52_;
										colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
										colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
										colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
										colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
										colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
										T49_ = 0;
										colontmpD__3 = renderTree__renderer_u59(x_2.Field1, T49_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										T48_[0] = colontmpD__3;
										T50_ = 0;
										colontmpD__4 = renderTree__renderer_u59(x_2.Field2, T50_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										T48_[1] = colontmpD__4;
										T51_ = 0;
										colontmpD__5 = renderTree__renderer_u59(y_1.Field1, T51_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										T48_[2] = colontmpD__5;
										T52_ = 0;
										colontmpD__6 = renderTree__renderer_u59(y_1.Field2, T52_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										T48_[3] = colontmpD__6;
										colontmpD__7 = nsuFormatOpenArray(TM__Itl65swq3r8pqY8Wou1vYA_41, T48_, 4);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										liMessage__msgs_u1227((*(*c_p0).graph).config, (*x_2.Field0).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__7, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_42, NIM_FALSE, NIM_FALSE);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										{
											LA47_:;
										}
										{
											eqdestroy___system_u2691(colontmpD__7);
											eqdestroy___system_u2691(colontmpD__6);
											eqdestroy___system_u2691(colontmpD__5);
											eqdestroy___system_u2691(colontmpD__4);
											eqdestroy___system_u2691(colontmpD__3);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
									}
LA40_: ;
								}
								goto LA27_;
LA36_: ;
								{
									NimStringV2 colontmpD__8;
									NimStringV2 colontmpD__9;
									NimStringV2 colontmpD__10;
									NimStringV2 colontmpD__11;
									NimStringV2 colontmpD__12;
									tyArray__Seu7uK9aaOSN0BK3EAjjSHw T57_;
									tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T58_;
									tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T59_;
									tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T60_;
									tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T61_;
									colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
									colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
									colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
									colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
									colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
									T58_ = 0;
									colontmpD__8 = renderTree__renderer_u59(x_2.Field1, T58_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
									T57_[0] = colontmpD__8;
									T59_ = 0;
									colontmpD__9 = renderTree__renderer_u59(x_2.Field2, T59_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
									T57_[1] = colontmpD__9;
									T60_ = 0;
									colontmpD__10 = renderTree__renderer_u59(y_1.Field1, T60_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
									T57_[2] = colontmpD__10;
									T61_ = 0;
									colontmpD__11 = renderTree__renderer_u59(y_1.Field2, T61_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
									T57_[3] = colontmpD__11;
									colontmpD__12 = nsuFormatOpenArray(TM__Itl65swq3r8pqY8Wou1vYA_43, T57_, 4);
									if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
									liMessage__msgs_u1227((*(*c_p0).graph).config, (*x_2.Field0).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__12, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_44, NIM_FALSE, NIM_FALSE);
									if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
									{
										LA56_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__12);
										eqdestroy___system_u2691(colontmpD__11);
										eqdestroy___system_u2691(colontmpD__10);
										eqdestroy___system_u2691(colontmpD__9);
										eqdestroy___system_u2691(colontmpD__8);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
								}
LA27_: ;
							}
LA25_: ;
							res_2 += ((NI)1);
							{
								LA20_:;
							}
							{
								oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___semparallel_u404(y_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								eqdestroy___semparallel_u404(x_2);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								*nimErr_ = oldNimErrFin20_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA19: ;
					}
				}
				res_1 += ((NI)1);
			} LA15: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, checkArgs__semparallel_u1302)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
}
N_LIB_PRIVATE N_NIMCALL(void, generateAliasChecks__semparallel_u1305)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result_p1) {
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformSlices__semparallel_u1219)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*n_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA4_: ;
		if (!T3_) goto LA5_;
		op_1 = NIM_NIL;
		eqcopy___ast_u4577(&op_1, (*(*n_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			NIM_BOOL T10_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* opSlice_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* slice_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T15_;
			T10_ = (NIM_BOOL)0;
			T10_ = eqStrings((*(*op_1).name).s, TM__Itl65swq3r8pqY8Wou1vYA_54);
			if (!(T10_)) goto LA11_;
			T10_ = fromSystem__astalgo_u184(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
LA11_: ;
			if (!T10_) goto LA12_;
			typ_1 = NIM_NIL;
			colontmpD_ = NIM_NIL;
			colontmpD__2 = NIM_NIL;
			opSlice_1 = NIM_NIL;
			colontmpD__3 = NIM_NIL;
			slice_1 = NIM_NIL;
			result = copyNode__ast_u6736(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			colontmpD_ = owner__ast_u6246((*result).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			typ_1 = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27), idgen_p1, colontmpD_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			colontmpD__2 = elementType__ast_u5331((*result).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			add__ast_u3881(typ_1, colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			eqsink___ast_u3387(&(*result).typField, typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			eqwasMoved___ast_u3375(&typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			colontmpD__3 = createMagic__modulegraphs_u10814(g_p0, idgen_p1, TM__Itl65swq3r8pqY8Wou1vYA_56, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)124));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			opSlice_1 = newSymNode__ast_u5168(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			T15_ = NIM_NIL;
			T15_ = getSysType__magicsys_u55(g_p0, (*n_p2).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T15_); goto LA14_;}
			eqsink___ast_u3387(&(*opSlice_1).typField, T15_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			add__ast_u3215(result, opSlice_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			add__ast_u3215(result, (*n_p2)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			slice_1 = skipStmtList__ast_u7252((*n_p2)._kind_6.sons.p->data[((NI)2)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			add__ast_u3215(result, (*slice_1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			add__ast_u3215(result, (*slice_1)._kind_6.sons.p->data[((NI)2)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			eqdestroy___ast_u3252(slice_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqdestroy___ast_u4574(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqdestroy___ast_u3252(opSlice_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqdestroy___ast_u4574(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqdestroy___ast_u4574(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
			{
				LA14_:;
			}
			{
				oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(slice_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				eqdestroy___ast_u4574(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				eqdestroy___ast_u3252(opSlice_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				eqdestroy___ast_u3378(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				eqdestroy___ast_u4574(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				eqdestroy___ast_u3378(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				*nimErr_ = oldNimErrFin14_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA12_: ;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	{
		NI T22_;
		T22_ = (NI)0;
		T22_ = safeLen__ast_u3197(n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(((NI)0) < T22_)) goto LA23_;
		result = shallowCopy__ast_u6876(n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T28_;
					if (!(i_2 < colontmp_)) goto LA27;
					i_1 = i_2;
					T28_ = NIM_NIL;
					T28_ = transformSlices__semparallel_u1219(g_p0, idgen_p1, (*n_p2)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T28_); goto BeforeRet_;}
					eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[i_1], T28_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA27: ;
			}
		}
	}
	goto LA20_;
LA23_: ;
	{
		eqcopy___ast_u3255(&result, n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA20_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformSpawnSons__semparallel_u1250)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* barrier_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = shallowCopy__ast_u6876(n_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T4_;
				if (!(i_2 < colontmp_)) goto LA3;
				i_1 = i_2;
				T4_ = NIM_NIL;
				T4_ = transformSpawn__semparallel_u1244(g_p0, idgen_p1, owner_p2, (*n_p3)._kind_6.sons.p->data[i_1], barrier_p4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T4_); goto BeforeRet_;}
				eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[i_1], T4_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformSpawn__semparallel_u1244)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* barrier_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin57_;
NIM_BOOL oldNimErrFin48_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	switch ((*n_p3).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
			it_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(n_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				i_2 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
						if (!(i_2 < colontmp_)) goto LA6;
						b_1 = NIM_NIL;
						i_1 = i_2;
						eqcopy___ast_u3255(&it_1, (*n_p3)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						b_1 = lastSon__ast_u5208(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						{
							tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg T10_;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* m_1;
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
							T10_ = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
							T10_ = getMagic__trees_u122(b_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
							if (!(T10_ == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)199))) goto LA11_;
							m_1 = NIM_NIL;
							t_1 = NIM_NIL;
							{
								NI T16_;
								T16_ = (NI)0;
								T16_ = len__ast_u3190(it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								if (!!((T16_ == ((NI)3)))) goto LA17_;
								liMessage__msgs_u1227((*g_p0).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__Itl65swq3r8pqY8Wou1vYA_52, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_53, NIM_FALSE, NIM_FALSE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							}
LA17_: ;
							m_1 = transformSlices__semparallel_u1219(g_p0, idgen_p1, b_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							{
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T23_;
								if (!(result == 0)) goto LA21_;
								T23_ = NIM_NIL;
								T23_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), (*n_p3).info);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T23_); goto LA13_;}
								eqsink___ast_u3261(&result, T23_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								add__ast_u3215(result, n_p3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							}
LA21_: ;
							t_1 = returnType__ast_u5354((*(*(*b_1)._kind_6.sons.p->data[((NI)1)])._kind_6.sons.p->data[((NI)0)]).typField);
							if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							{
								tyEnum_TSpawnResult__Fi6IYHzmOR0d8zopbmZXuw T26_;
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
								NI T30_;
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T31_;
								T26_ = (tyEnum_TSpawnResult__Fi6IYHzmOR0d8zopbmZXuw)0;
								T26_ = spawnResult__spawn_u29(t_1, NIM_TRUE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								if (!(T26_ == ((tyEnum_TSpawnResult__Fi6IYHzmOR0d8zopbmZXuw)2))) goto LA27_;
								colontmpD_ = NIM_NIL;
								colontmpD_ = wrapProcForSpawn__spawn_u349(g_p0, idgen_p1, owner_p2, m_1, (*b_1).typField, barrier_p4, (*it_1)._kind_6.sons.p->data[((NI)0)]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
								add__ast_u3215(result, colontmpD_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
								T30_ = (NI)0;
								T30_ = len__ast_u3190(it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
								T31_ = NIM_NIL;
								T31_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), (*it_1).info);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T31_); goto LA29_;}
								eqsink___ast_u3261(&(*it_1)._kind_6.sons.p->data[(NI)(T30_ - ((NI)1))], T31_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
								{
									LA29_:;
								}
								{
									oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___ast_u3252(colontmpD_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
									*nimErr_ = oldNimErrFin29_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							}
							goto LA24_;
LA27_: ;
							{
								NI T35_;
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T36_;
								T35_ = (NI)0;
								T35_ = len__ast_u3190(it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								T36_ = NIM_NIL;
								T36_ = wrapProcForSpawn__spawn_u349(g_p0, idgen_p1, owner_p2, m_1, (*b_1).typField, barrier_p4, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T36_); goto LA13_;}
								eqsink___ast_u3261(&(*it_1)._kind_6.sons.p->data[(NI)(T35_ - ((NI)1))], T36_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							}
LA24_: ;
							{
								LA13_:;
							}
							{
								oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3378(t_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
								eqdestroy___ast_u3252(m_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
								*nimErr_ = oldNimErrFin13_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						}
LA11_: ;
						i_2 += ((NI)1);
						{
							LA7_:;
						}
						{
							oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(b_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
							*nimErr_ = oldNimErrFin7_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					} LA6: ;
				}
			}
			{
				LA3_:;
			}
			{
				oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin3_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		{
			if (!(result == 0)) goto LA45_;
			eqcopy___ast_u3255(&result, n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA45_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)74):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
		b_2 = NIM_NIL;
		t_2 = NIM_NIL;
		eqcopy___ast_u3255(&b_2, (*n_p3)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		{
			NIM_BOOL T51_;
			tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg T52_;
			tyEnum_TSpawnResult__Fi6IYHzmOR0d8zopbmZXuw T54_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* m_2;
			T51_ = (NIM_BOOL)0;
			T52_ = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
			T52_ = getMagic__trees_u122(b_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			T51_ = (T52_ == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)199));
			if (!(T51_)) goto LA53_;
			t_2 = returnType__ast_u5354((*(*(*b_2)._kind_6.sons.p->data[((NI)1)])._kind_6.sons.p->data[((NI)0)]).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			T54_ = (tyEnum_TSpawnResult__Fi6IYHzmOR0d8zopbmZXuw)0;
			T54_ = spawnResult__spawn_u29(t_2, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			T51_ = (T54_ == ((tyEnum_TSpawnResult__Fi6IYHzmOR0d8zopbmZXuw)2));
LA53_: ;
			if (!T51_) goto LA55_;
			m_2 = NIM_NIL;
			m_2 = transformSlices__semparallel_u1219(g_p0, idgen_p1, b_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
			result = wrapProcForSpawn__spawn_u349(g_p0, idgen_p1, owner_p2, m_2, (*b_2).typField, barrier_p4, (*n_p3)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
			eqdestroy___ast_u3252(m_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			eqdestroy___ast_u3378(t_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(b_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
			{
				LA57_:;
			}
			{
				oldNimErrFin57_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(m_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				*nimErr_ = oldNimErrFin57_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		}
LA55_: ;
		result = transformSpawnSons__semparallel_u1250(g_p0, idgen_p1, owner_p2, n_p3, barrier_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		{
			LA48_:;
		}
		{
			oldNimErrFin48_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(t_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(b_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin48_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		{
			tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg T65_;
			T65_ = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
			T65_ = getMagic__trees_u122(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T65_ == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)199))) goto LA66_;
			result = transformSlices__semparallel_u1219(g_p0, idgen_p1, n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = wrapProcForSpawn__spawn_u349(g_p0, idgen_p1, owner_p2, result, (*n_p3).typField, barrier_p4, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA66_: ;
		result = transformSpawnSons__semparallel_u1250(g_p0, idgen_p1, owner_p2, n_p3, barrier_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		{
			NI T71_;
			T71_ = (NI)0;
			T71_ = safeLen__ast_u3197(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(((NI)0) < T71_)) goto LA72_;
			result = transformSpawnSons__semparallel_u1250(g_p0, idgen_p1, owner_p2, n_p3, barrier_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA69_;
LA72_: ;
		{
			eqcopy___ast_u3255(&result, n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA69_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u570)(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).graph);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0).graph)));
		nimRawDispose((*dest_p0).graph, ((NI)8));
	}
LA4_: ;
	eqdestroy___ast_u4848((*dest_p0).args);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).guards.g);
		if (!T8_) goto LA9_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0).guards.g)));
		nimRawDispose((*dest_p0).guards.g, ((NI)8));
	}
LA9_: ;
	eqdestroy___ast_u3696((*dest_p0).guards.s);
	eqdestroy___semparallel_u335((*dest_p0).slices);
	eqdestroy___semparallel_u66((*dest_p0).locals);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, liftParallel__semparallel_u1308)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw a_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* varSection_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* temp_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tempNode_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* barrier_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__5;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_AnalysisCtx__tzvG9b19a69aXqGpxHy3sMcRw));
	body_1 = NIM_NIL;
	varSection_1 = NIM_NIL;
	temp_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	tempNode_1 = NIM_NIL;
	barrier_1 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	colontmpD__5 = NIM_NIL;
	initAnalysisCtx__semparallel_u44(g_p0, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	body_1 = lastSon__ast_u5208(n_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	analyse__semparallel_u1034((&a_1), body_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(a_1.spawns == ((NI)0))) goto LA4_;
		liMessage__msgs_u1227((*g_p0).config, (*n_p3).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__Itl65swq3r8pqY8Wou1vYA_30, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__Itl65swq3r8pqY8Wou1vYA_31, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	checkSlicesAreDisjoint__semparallel_u925((&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	checkArgs__semparallel_u1302((&a_1), body_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	varSection_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99), (*n_p3).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getIdent__idents_u206((*g_p0).cache, TM__Itl65swq3r8pqY8Wou1vYA_46);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = 0;
	temp_1 = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5), colontmpD_, idgen_p1, owner_p2, (*n_p3).info, T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getCompilerProc__magicsys_u150(g_p0, TM__Itl65swq3r8pqY8Wou1vYA_48);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&(*temp_1).typ, (*colontmpD__2).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*temp_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)2))) & 63);
	tempNode_1 = newSymNode__ast_u5168(temp_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addVar__lowerings_u34(varSection_1, tempNode_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	barrier_1 = genAddrOf__lowerings_u418(tempNode_1, idgen_p1, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), (*n_p3).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	generateAliasChecks__semparallel_u1305((&a_1), result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3215(result, varSection_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = callCodegenProc__lowerings_u430(g_p0, TM__Itl65swq3r8pqY8Wou1vYA_50, (*barrier_1).info, barrier_1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL), ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL), ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3215(result, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = transformSpawn__semparallel_u1244(g_p0, idgen_p1, owner_p2, body_1, barrier_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3215(result, colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = callCodegenProc__lowerings_u430(g_p0, TM__Itl65swq3r8pqY8Wou1vYA_58, (*barrier_1).info, barrier_1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL), ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL), ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3215(result, colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(barrier_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(tempNode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(temp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(varSection_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(body_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___semparallel_u570((&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
