/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_Table__A49ak19aStos8ZFsiM37JH6w tyObject_Table__A49ak19aStos8ZFsiM37JH6w;
typedef struct tySequence__9chP3SzkaldXzawWQCDsqqg tySequence__9chP3SzkaldXzawWQCDsqqg;
typedef struct tySequence__9chP3SzkaldXzawWQCDsqqg_Content tySequence__9chP3SzkaldXzawWQCDsqqg_Content;
typedef struct tyTuple__aGv2fk9ceddvdC01ZJC2Q2g tyTuple__aGv2fk9ceddvdC01ZJC2Q2g;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_Table__r6SySATn9aFiGJCuriaCXGg tyObject_Table__r6SySATn9aFiGJCuriaCXGg;
typedef struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ tySequence__7s5HyddQ0f9bxMNILHrXwJQ;
typedef struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content;
typedef struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g tyTuple__kuMQ1fbjJlHtwKTmBGAe6g;
typedef struct tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q;
typedef struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA;
typedef struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_Table__g39amaj5esSUbnvSF2f9bVgg tyObject_Table__g39amaj5esSUbnvSF2f9bVgg;
typedef struct tySequence__FGxE1Nuen6pVDc58PZudJw tySequence__FGxE1Nuen6pVDc58PZudJw;
typedef struct tySequence__FGxE1Nuen6pVDc58PZudJw_Content tySequence__FGxE1Nuen6pVDc58PZudJw_Content;
typedef struct tyTuple__7xc1P89akJWzo77UAKrb3aA tyTuple__7xc1P89akJWzo77UAKrb3aA;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ;
typedef struct tySequence__6j25whH7XTBoIXcM0x1T7A tySequence__6j25whH7XTBoIXcM0x1T7A;
typedef struct tySequence__6j25whH7XTBoIXcM0x1T7A_Content tySequence__6j25whH7XTBoIXcM0x1T7A_Content;
typedef struct tyTuple__9cdgeqdY7FRioNKBoD6G66A tyTuple__9cdgeqdY7FRioNKBoD6G66A;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw tySequence__hRbbzIynOoxrYjHTIKZ3Gw;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content;
typedef struct tyTuple__Oubp8LPEu86EPyDuc56AXg tyTuple__Oubp8LPEu86EPyDuc56AXg;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w tySequence__3B6hFqG0Do0FxDvnNucL7w;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content tySequence__3B6hFqG0Do0FxDvnNucL7w_Content;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ tySequence__KYLoGmc5aaHsSDjEH1FTxQ;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content;
typedef struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content tySequence__E8pi9b5QNahsURYzXMjh3qw_Content;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg tyObject_Table__toCaB3NxiVHPRVLgcez0Xg;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q tySequence__Fc8Q26tsngy2yxcpyrnT4Q;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content;
typedef struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g tyTuple__y6bKAf9a9aaVwun6lVDxSX7g;
typedef struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ tyObject_Table__tro5f9chxPVpES1mQpDwZtQ;
typedef struct tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ;
typedef struct tySequence__e9ciFfeAg1p88UzCBnAPeVQ tySequence__e9ciFfeAg1p88UzCBnAPeVQ;
typedef struct tySequence__e9ciFfeAg1p88UzCBnAPeVQ_Content tySequence__e9ciFfeAg1p88UzCBnAPeVQ_Content;
typedef struct tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg;
typedef struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ tyObject_Table__lPs28yjGTxD0LzUoPspSBQ;
typedef struct tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ;
typedef struct tySequence__mnb4N9bRCddoL53waHA7kHQ tySequence__mnb4N9bRCddoL53waHA7kHQ;
typedef struct tySequence__mnb4N9bRCddoL53waHA7kHQ_Content tySequence__mnb4N9bRCddoL53waHA7kHQ_Content;
typedef struct tyTuple__bxYrf1dnwYK6GanDNddhgQ tyTuple__bxYrf1dnwYK6GanDNddhgQ;
typedef struct tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg;
typedef struct tySequence__R1mQMFmsdp1ChoJDXa9a0xQ tySequence__R1mQMFmsdp1ChoJDXa9a0xQ;
typedef struct tySequence__R1mQMFmsdp1ChoJDXa9a0xQ_Content tySequence__R1mQMFmsdp1ChoJDXa9a0xQ_Content;
typedef struct tyTuple__rczUtx07rG4YmHOEmcEUJw tyTuple__rczUtx07rG4YmHOEmcEUJw;
typedef struct tyObject_Table__GdZqMtWDe86MuMz9cop7uxw tyObject_Table__GdZqMtWDe86MuMz9cop7uxw;
typedef struct tySequence__kP47rw9c8bgVA53QKWe9bp7g tySequence__kP47rw9c8bgVA53QKWe9bp7g;
typedef struct tySequence__kP47rw9c8bgVA53QKWe9bp7g_Content tySequence__kP47rw9c8bgVA53QKWe9bp7g_Content;
typedef struct tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tyObject_Table__g77QNejuRRKraNk8K2YkoA tyObject_Table__g77QNejuRRKraNk8K2YkoA;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tyObject_Table__64AfBrTBCyxlEANlKol6Ew tyObject_Table__64AfBrTBCyxlEANlKol6Ew;
typedef struct tySequence__dAjyAaabi52TN36Jp0fAXQ tySequence__dAjyAaabi52TN36Jp0fAXQ;
typedef struct tySequence__dAjyAaabi52TN36Jp0fAXQ_Content tySequence__dAjyAaabi52TN36Jp0fAXQ_Content;
typedef struct tyTuple__X9bWVAqRSgByRpQwn6owzEA tyTuple__X9bWVAqRSgByRpQwn6owzEA;
typedef struct tyTuple__cyDO9czMbIL47POKM3sIQng tyTuple__cyDO9czMbIL47POKM3sIQng;
typedef struct tySequence__zpKGgayc1mFyemMGMuK9a2w tySequence__zpKGgayc1mFyemMGMuK9a2w;
typedef struct tySequence__zpKGgayc1mFyemMGMuK9a2w_Content tySequence__zpKGgayc1mFyemMGMuK9a2w_Content;
typedef struct tyTuple__DfjLoSEvFkvlneCb5GSa9cQ tyTuple__DfjLoSEvFkvlneCb5GSa9cQ;
typedef struct tyTuple__w31HlKXGH5QCPFggOmKfbQ tyTuple__w31HlKXGH5QCPFggOmKfbQ;
typedef struct tyObject_Table__hBsih9beFksASOhhFeS9aGZw tyObject_Table__hBsih9beFksASOhhFeS9aGZw;
typedef struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg tySequence__9bRXJy1JXrQ4hWpStaKBpXg;
typedef struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content;
typedef struct tyTuple__9agFg9cuYsNvckAbTfHAsTSA tyTuple__9agFg9cuYsNvckAbTfHAsTSA;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw tySequence__jwzrUFjG9akTIJTBBFvvqxw;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tySequence__9cbEQVGky3gHl4QEC3q4Sow tySequence__9cbEQVGky3gHl4QEC3q4Sow;
typedef struct tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content;
typedef struct tyTuple__GhsGHTmri9bgdv8XapNtpTg tyTuple__GhsGHTmri9bgdv8XapNtpTg;
typedef struct tyObject_Table__0Na0d2dQ8AYACjty2CqMPA tyObject_Table__0Na0d2dQ8AYACjty2CqMPA;
typedef struct tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA;
typedef struct tyObject_CountTable__LyKUoYAaSNoaROywBdHQow tyObject_CountTable__LyKUoYAaSNoaROywBdHQow;
typedef struct tySequence__lCWXucMn9bU7PUqVDK7772w tySequence__lCWXucMn9bU7PUqVDK7772w;
typedef struct tySequence__lCWXucMn9bU7PUqVDK7772w_Content tySequence__lCWXucMn9bU7PUqVDK7772w_Content;
typedef struct tyTuple__kNIN44R9cL9cYoYzXmSW4y7w tyTuple__kNIN44R9cL9cYoYzXmSW4y7w;
typedef struct tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ;
typedef struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg;
typedef struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content;
typedef struct tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng;
typedef struct tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ;
typedef struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA;
typedef struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw tySequence__O9a9cp2XDKWshwC0UDgFP6Pw;
typedef struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content;
typedef struct tyTuple__Na59bk2YQTCLBWTLyeMrWdA tyTuple__Na59bk2YQTCLBWTLyeMrWdA;
typedef struct tySequence__ib5UTyrs9aC6K60sNqKElQA tySequence__ib5UTyrs9aC6K60sNqKElQA;
typedef struct tySequence__ib5UTyrs9aC6K60sNqKElQA_Content tySequence__ib5UTyrs9aC6K60sNqKElQA_Content;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA tySequence__m9axZwxFfhSNLcoofvKZJYA;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content tySequence__m9axZwxFfhSNLcoofvKZJYA_Content;
typedef struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ;
typedef struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g;
typedef struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw tySequence__fXWXs2NlFKREhy9cn6vokJw;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content tySequence__fXWXs2NlFKREhy9cn6vokJw_Content;
typedef struct tySequence__9at3Cmn7xIajy679cMZSmybg tySequence__9at3Cmn7xIajy679cMZSmybg;
typedef struct tySequence__9at3Cmn7xIajy679cMZSmybg_Content tySequence__9at3Cmn7xIajy679cMZSmybg_Content;
typedef struct tyTuple__RrY3dT8dfTceE0s6Bv9bxJw tyTuple__RrY3dT8dfTceE0s6Bv9bxJw;
typedef struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg;
typedef struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content;
typedef struct tySequence__uAwiTxV3boseSy9a9cSsXHEA tySequence__uAwiTxV3boseSy9a9cSsXHEA;
typedef struct tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content;
typedef struct tyTuple__30Ti2rm9aDSr5neUSZP6EVQ tyTuple__30Ti2rm9aDSr5neUSZP6EVQ;
typedef struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA tySequence__b9cVyuSHmrW80P0ZGgU2KHA;
typedef struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content;
typedef struct tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tyObject_Table__fncSH0hxktvgfMu5tiOgpw tyObject_Table__fncSH0hxktvgfMu5tiOgpw;
typedef struct tyObject_Table__bzy14J3py7GGCrkIhTsFXw tyObject_Table__bzy14J3py7GGCrkIhTsFXw;
typedef struct tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA;
typedef struct tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg;
typedef struct tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg;
typedef struct tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw;
typedef struct tyObject_Table__I1hAea2wVUrLyIxtQj9cheA tyObject_Table__I1hAea2wVUrLyIxtQj9cheA;
typedef struct tySequence__SFipDZIkFtPcrLs0AGBBjQ tySequence__SFipDZIkFtPcrLs0AGBBjQ;
typedef struct tySequence__SFipDZIkFtPcrLs0AGBBjQ_Content tySequence__SFipDZIkFtPcrLs0AGBBjQ_Content;
typedef struct tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ;
typedef struct tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ;
typedef struct tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ_Content tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ_Content;
typedef struct tyTuple__fgn415DvsSyiHk3o9aIYr0w tyTuple__fgn415DvsSyiHk3o9aIYr0w;
typedef struct tyTuple__Ll5iolPASSzOEheeSNjmiw tyTuple__Ll5iolPASSzOEheeSNjmiw;
typedef struct tyObject_Table__t60gWhquDic6PI6CgxHkgw tyObject_Table__t60gWhquDic6PI6CgxHkgw;
typedef struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w tySequence__UuiPn6QjIiUTdSVwX2PZ6w;
typedef struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content;
typedef struct tyTuple__9a3DhYVfcy14Fx42tD0lSEQ tyTuple__9a3DhYVfcy14Fx42tD0lSEQ;
typedef struct tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw;
typedef struct tySequence__mg32q50AXD9cQ6jovpBmgWA tySequence__mg32q50AXD9cQ6jovpBmgWA;
typedef struct tySequence__mg32q50AXD9cQ6jovpBmgWA_Content tySequence__mg32q50AXD9cQ6jovpBmgWA_Content;
typedef struct tyTuple__bvjw5f4vMpB9bESWLU7nvyA tyTuple__bvjw5f4vMpB9bESWLU7nvyA;
typedef struct tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ;
typedef struct tySequence__36jA1xDCIBAS29cySYLQ7kQ tySequence__36jA1xDCIBAS29cySYLQ7kQ;
typedef struct tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ;
typedef struct tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA;
typedef struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA;
typedef struct tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q tySequence__4eQHGndY6XBYpFOH09apV8Q;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content tySequence__4eQHGndY6XBYpFOH09apV8Q_Content;
typedef struct tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg;
typedef struct tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg;
typedef struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ;
typedef struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyTuple__8ZxhPt1NwfElsJs8zUSV9bg tyTuple__8ZxhPt1NwfElsJs8zUSV9bg;
typedef struct tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ;
struct tySequence__9chP3SzkaldXzawWQCDsqqg {
  NI len; tySequence__9chP3SzkaldXzawWQCDsqqg_Content* p;
};
struct tyObject_Table__A49ak19aStos8ZFsiM37JH6w {
	tySequence__9chP3SzkaldXzawWQCDsqqg data;
	NI counter;
};
struct tyTuple__aGv2fk9ceddvdC01ZJC2Q2g {
	NI Field0;
	void* Field1;
	NI Field2;
};
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ {
  NI len; tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content* p;
};
struct tyObject_Table__r6SySATn9aFiGJCuriaCXGg {
	tySequence__7s5HyddQ0f9bxMNILHrXwJQ data;
	NI counter;
};
struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg {
	Exception Sup;
};
struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA {
	tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg Sup;
};
struct tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q {
	tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA Sup;
};
struct tySequence__FGxE1Nuen6pVDc58PZudJw {
  NI len; tySequence__FGxE1Nuen6pVDc58PZudJw_Content* p;
};
struct tyObject_Table__g39amaj5esSUbnvSF2f9bVgg {
	tySequence__FGxE1Nuen6pVDc58PZudJw data;
	NI counter;
};
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw {
	NF time;
	NI count;
};
struct tyTuple__7xc1P89akJWzo77UAKrb3aA {
	NI Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
	tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tySequence__6j25whH7XTBoIXcM0x1T7A {
  NI len; tySequence__6j25whH7XTBoIXcM0x1T7A_Content* p;
};
struct tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ {
	tySequence__6j25whH7XTBoIXcM0x1T7A data;
	NI counter;
};
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
struct tyTuple__9cdgeqdY7FRioNKBoD6G66A {
	NI Field0;
	NimStringV2 Field1;
	tyTuple__UV3llMMYFckfui8YMBuUZA Field2;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw {
  NI len; tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content* p;
};
struct tyTuple__Oubp8LPEu86EPyDuc56AXg {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field0;
	NI Field1;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
typedef NimStringV2 tyArray__mwX29agX3Ej9aN4i06bmNBzw[512];
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__aWbWtSQ9c5GC1oFcQOIBaOw[512];
typedef tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* tyArray__LFBH1wNvhjP9blmECBD9bOMA[512];
struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q {
	NI entries;
	tyArray__mwX29agX3Ej9aN4i06bmNBzw keys;
	NIM_BOOL isInternal;
union{
	struct {
	tyArray__aWbWtSQ9c5GC1oFcQOIBaOw vals;
} _isInternal_1;
	struct {
	tyArray__LFBH1wNvhjP9blmECBD9bOMA links;
} _isInternal_2;
};
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
typedef NU tyArray__KznKlIbW0OmA9ckg0NfmHVQ[8];
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ {
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  NI len; tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content* p;
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
	NI Field0;
	NI Field1;
	tySequence__qwqHTkRvwhrRyENtudHQ7g Field2;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w {
  NI len; tySequence__3B6hFqG0Do0FxDvnNucL7w_Content* p;
};
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ {
  NI len; tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content* p;
};
struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw {
	NI Field0;
	NI Field1;
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ Field2;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  NI len; tySequence__E8pi9b5QNahsURYzXMjh3qw_Content* p;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
	NI Field0;
	NI Field1;
	NI Field2;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ {
	NI len;
	void* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw {
	tySequence__E8pi9b5QNahsURYzXMjh3qw data;
	NI counter;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg {
	tySequence__QqvaCqCpEE1QmQZbcZLi5A data;
	NI counter;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q {
  NI len; tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content* p;
};
struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg {
	NI32 pc;
	NI32 usedRegisters;
};
struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g {
	NI Field0;
	NI Field1;
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg Field2;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  NI len; tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content* p;
};
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
	NI Field0;
	NimStringV2 Field1;
	NI Field2;
};
struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og data;
	NI counter;
};
struct tySequence__e9ciFfeAg1p88UzCBnAPeVQ {
  NI len; tySequence__e9ciFfeAg1p88UzCBnAPeVQ_Content* p;
};
struct tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ {
	tySequence__e9ciFfeAg1p88UzCBnAPeVQ data;
	NI counter;
};
struct tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg {
	NI Field0;
	NI64 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ {
	tySequence__Fc8Q26tsngy2yxcpyrnT4Q data;
	NI counter;
};
struct tySequence__mnb4N9bRCddoL53waHA7kHQ {
  NI len; tySequence__mnb4N9bRCddoL53waHA7kHQ_Content* p;
};
struct tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ {
	tySequence__mnb4N9bRCddoL53waHA7kHQ data;
	NI counter;
};
struct tyTuple__bxYrf1dnwYK6GanDNddhgQ {
	NI Field0;
	NI Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__R1mQMFmsdp1ChoJDXa9a0xQ {
  NI len; tySequence__R1mQMFmsdp1ChoJDXa9a0xQ_Content* p;
};
struct tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg {
	tySequence__R1mQMFmsdp1ChoJDXa9a0xQ data;
	NI counter;
};
struct tyTuple__rczUtx07rG4YmHOEmcEUJw {
	NI Field0;
	NI Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__kP47rw9c8bgVA53QKWe9bp7g {
  NI len; tySequence__kP47rw9c8bgVA53QKWe9bp7g_Content* p;
};
struct tyObject_Table__GdZqMtWDe86MuMz9cop7uxw {
	tySequence__kP47rw9c8bgVA53QKWe9bp7g data;
	NI counter;
};
struct tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	NI Field2;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_Table__g77QNejuRRKraNk8K2YkoA {
	tySequence__3B6hFqG0Do0FxDvnNucL7w data;
	NI counter;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__dAjyAaabi52TN36Jp0fAXQ {
  NI len; tySequence__dAjyAaabi52TN36Jp0fAXQ_Content* p;
};
struct tyObject_Table__64AfBrTBCyxlEANlKol6Ew {
	tySequence__dAjyAaabi52TN36Jp0fAXQ data;
	NI counter;
};
struct tyTuple__X9bWVAqRSgByRpQwn6owzEA {
	NI Field0;
	NI Field1;
	NI16 Field2;
};
struct tyTuple__cyDO9czMbIL47POKM3sIQng {
	NI Field0;
	NI16 Field1;
};
struct tySequence__zpKGgayc1mFyemMGMuK9a2w {
  NI len; tySequence__zpKGgayc1mFyemMGMuK9a2w_Content* p;
};
struct tyTuple__w31HlKXGH5QCPFggOmKfbQ {
	NimStringV2 Field0;
	NI32 Field1;
};
struct tyTuple__DfjLoSEvFkvlneCb5GSa9cQ {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyTuple__w31HlKXGH5QCPFggOmKfbQ Field2;
};
struct tyObject_Table__hBsih9beFksASOhhFeS9aGZw {
	tySequence__zpKGgayc1mFyemMGMuK9a2w data;
	NI counter;
};
struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg {
  NI len; tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content* p;
};
struct tyTuple__9agFg9cuYsNvckAbTfHAsTSA {
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field0;
	NI Field1;
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw {
  NI len; tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content* p;
};
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
	NimStringV2 Field0;
	NI Field1;
};
struct tySequence__9cbEQVGky3gHl4QEC3q4Sow {
  NI len; tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content* p;
};
struct tyTuple__GhsGHTmri9bgdv8XapNtpTg {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	NimStringV2 Field2;
};
struct tyObject_Table__0Na0d2dQ8AYACjty2CqMPA {
	tySequence__9cbEQVGky3gHl4QEC3q4Sow data;
	NI counter;
};
struct tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA {
	tySequence__9bRXJy1JXrQ4hWpStaKBpXg data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_CountTable__LyKUoYAaSNoaROywBdHQow {
	tySequence__jwzrUFjG9akTIJTBBFvvqxw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__lCWXucMn9bU7PUqVDK7772w {
  NI len; tySequence__lCWXucMn9bU7PUqVDK7772w_Content* p;
};
struct tyTuple__kNIN44R9cL9cYoYzXmSW4y7w {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* Field3;
};
struct tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ {
	NimStringV2 rdoccmd;
	NimStringV2 docCmd;
	NimStringV2 code;
	NI index;
};
struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg {
  NI len; tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content* p;
};
struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ {
	NIM_BOOL used;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA fromInfo;
	NimStringV2 idxPath;
	NimStringV2 linkRelPath;
	NimStringV2 title;
};
struct tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng {
	NI Field0;
	NimStringV2 Field1;
	tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ Field2;
};
struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw {
  NI len; tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content* p;
};
struct tySequence__ib5UTyrs9aC6K60sNqKElQA {
  NI len; tySequence__ib5UTyrs9aC6K60sNqKElQA_Content* p;
};
struct tyTuple__Na59bk2YQTCLBWTLyeMrWdA {
	NI Field0;
	NimStringV2 Field1;
	tySequence__ib5UTyrs9aC6K60sNqKElQA Field2;
};
struct tySequence__m9axZwxFfhSNLcoofvKZJYA {
  NI len; tySequence__m9axZwxFfhSNLcoofvKZJYA_Content* p;
};
struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field3;
};
typedef NU8 tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA;
struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ {
	tySequence__m9axZwxFfhSNLcoofvKZJYA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__fXWXs2NlFKREhy9cn6vokJw {
  NI len; tySequence__fXWXs2NlFKREhy9cn6vokJw_Content* p;
};
struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g {
	NIM_BOOL isUnquoted;
	tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA kind;
union{
	struct {
	NimStringV2 str;
} _kind_1;
	struct {
	NI64 num;
} _kind_2;
	struct {
	NF fnum;
} _kind_3;
	struct {
	NIM_BOOL bval;
} _kind_4;
	struct {
	tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ fields;
} _kind_6;
	struct {
	tySequence__fXWXs2NlFKREhy9cn6vokJw elems;
} _kind_7;
};
};
struct tySequence__9at3Cmn7xIajy679cMZSmybg {
  NI len; tySequence__9at3Cmn7xIajy679cMZSmybg_Content* p;
};
struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg {
  NI len; tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content* p;
};
struct tyTuple__RrY3dT8dfTceE0s6Bv9bxJw {
	NI Field0;
	NimStringV2 Field1;
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg Field2;
};
struct tySequence__uAwiTxV3boseSy9a9cSsXHEA {
  NI len; tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content* p;
};
struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA {
  NI len; tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content* p;
};
struct tyTuple__30Ti2rm9aDSr5neUSZP6EVQ {
	NI Field0;
	NimStringV2 Field1;
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA Field2;
};
struct tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tyObject_Table__fncSH0hxktvgfMu5tiOgpw {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tyObject_Table__bzy14J3py7GGCrkIhTsFXw {
	tySequence__O9a9cp2XDKWshwC0UDgFP6Pw data;
	NI counter;
};
struct tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA {
	tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg data;
	NI counter;
};
struct tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg {
	tySequence__lCWXucMn9bU7PUqVDK7772w data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg {
	tySequence__uAwiTxV3boseSy9a9cSsXHEA data;
	NI counter;
};
struct tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw {
	tySequence__9at3Cmn7xIajy679cMZSmybg data;
	NI counter;
};
struct tySequence__SFipDZIkFtPcrLs0AGBBjQ {
  NI len; tySequence__SFipDZIkFtPcrLs0AGBBjQ_Content* p;
};
struct tyObject_Table__I1hAea2wVUrLyIxtQj9cheA {
	tySequence__SFipDZIkFtPcrLs0AGBBjQ data;
	NI counter;
};
struct tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ {
  NI len; tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ_Content* p;
};
struct tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ {
	tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ data;
	NI counter;
};
struct tyTuple__fgn415DvsSyiHk3o9aIYr0w {
	NI Field0;
	tyTuple__UV3llMMYFckfui8YMBuUZA Field1;
	tySequence__ib5UTyrs9aC6K60sNqKElQA Field2;
};
struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w {
  NI len; tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content* p;
};
struct tyObject_Table__t60gWhquDic6PI6CgxHkgw {
	tySequence__UuiPn6QjIiUTdSVwX2PZ6w data;
	NI counter;
};
struct tyTuple__Ll5iolPASSzOEheeSNjmiw {
	NI Field0;
	NI32 Field1;
};
struct tyTuple__9a3DhYVfcy14Fx42tD0lSEQ {
	NI Field0;
	NimStringV2 Field1;
	tyTuple__Ll5iolPASSzOEheeSNjmiw Field2;
};
struct tySequence__mg32q50AXD9cQ6jovpBmgWA {
  NI len; tySequence__mg32q50AXD9cQ6jovpBmgWA_Content* p;
};
struct tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw {
	tySequence__mg32q50AXD9cQ6jovpBmgWA data;
	NI counter;
};
typedef NU8 tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ;
struct tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ {
	tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ kind;
	NimStringV2 keyword;
	NimStringV2 link;
	NimStringV2 linkTitle;
	NimStringV2 linkDesc;
	NI line;
	NimStringV2 module;
	NimStringV2 aux;
};
struct tySequence__36jA1xDCIBAS29cySYLQ7kQ {
  NI len; tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content* p;
};
struct tyTuple__bvjw5f4vMpB9bESWLU7nvyA {
	NI Field0;
	tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ Field1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ Field2;
};
struct tySequence__9chP3SzkaldXzawWQCDsqqg_Content { NI cap; tyTuple__aGv2fk9ceddvdC01ZJC2Q2g data[SEQ_DECL_SIZE]; };
struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content { NI cap; tyTuple__kuMQ1fbjJlHtwKTmBGAe6g data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
struct tySequence__FGxE1Nuen6pVDc58PZudJw_Content { NI cap; tyTuple__7xc1P89akJWzo77UAKrb3aA data[SEQ_DECL_SIZE]; };
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__6j25whH7XTBoIXcM0x1T7A_Content { NI cap; tyTuple__9cdgeqdY7FRioNKBoD6G66A data[SEQ_DECL_SIZE]; };
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content { NI cap; tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE]; };
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content { NI cap; tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content { NI cap; tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw data[SEQ_DECL_SIZE]; };
struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content { NI cap; tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ data[SEQ_DECL_SIZE]; };
struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content { NI cap; tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE]; };
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content { NI cap; tyTuple__y6bKAf9a9aaVwun6lVDxSX7g data[SEQ_DECL_SIZE]; };
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content { NI cap; tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE]; };
struct tySequence__e9ciFfeAg1p88UzCBnAPeVQ_Content { NI cap; tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg data[SEQ_DECL_SIZE]; };
struct tySequence__mnb4N9bRCddoL53waHA7kHQ_Content { NI cap; tyTuple__bxYrf1dnwYK6GanDNddhgQ data[SEQ_DECL_SIZE]; };
struct tySequence__R1mQMFmsdp1ChoJDXa9a0xQ_Content { NI cap; tyTuple__rczUtx07rG4YmHOEmcEUJw data[SEQ_DECL_SIZE]; };
struct tySequence__kP47rw9c8bgVA53QKWe9bp7g_Content { NI cap; tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw data[SEQ_DECL_SIZE]; };
struct tySequence__dAjyAaabi52TN36Jp0fAXQ_Content { NI cap; tyTuple__X9bWVAqRSgByRpQwn6owzEA data[SEQ_DECL_SIZE]; };
struct tySequence__zpKGgayc1mFyemMGMuK9a2w_Content { NI cap; tyTuple__DfjLoSEvFkvlneCb5GSa9cQ data[SEQ_DECL_SIZE]; };
struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content { NI cap; tyTuple__9agFg9cuYsNvckAbTfHAsTSA data[SEQ_DECL_SIZE]; };
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content { NI cap; tyTuple__XOVT24GHXwqiEj5GCsEGCA data[SEQ_DECL_SIZE]; };
struct tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content { NI cap; tyTuple__GhsGHTmri9bgdv8XapNtpTg data[SEQ_DECL_SIZE]; };
struct tySequence__lCWXucMn9bU7PUqVDK7772w_Content { NI cap; tyTuple__kNIN44R9cL9cYoYzXmSW4y7w data[SEQ_DECL_SIZE]; };
struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content { NI cap; tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng data[SEQ_DECL_SIZE]; };
struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content { NI cap; tyTuple__Na59bk2YQTCLBWTLyeMrWdA data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_AnchorRule__EbWqr3fy26ujwRNegmj44Q;
typedef NU8 tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ;
struct tySequence__4eQHGndY6XBYpFOH09apV8Q {
  NI len; tySequence__4eQHGndY6XBYpFOH09apV8Q_Content* p;
};
struct tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw {
	NimStringV2 symKind;
	NimStringV2 symTypeKind;
	NimStringV2 name;
	NimStringV2 generics;
	NIM_BOOL isGroup;
	NIM_BOOL parametersProvided;
	tySequence__4eQHGndY6XBYpFOH09apV8Q parameters;
	NimStringV2 outType;
};
struct tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA {
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
	NI priority;
	tyEnum_AnchorRule__EbWqr3fy26ujwRNegmj44Q kind;
union{
	struct {
	tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ anchorType;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* target;
} _kind_1;
	struct {
	tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ anchorTypeExt;
	NimStringV2 refnameExt;
} _kind_2;
	struct {
	NI32 module;
	NimStringV2 tooltip;
	tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw langSym;
	NimStringV2 refname;
	NIM_BOOL external;
} _kind_3;
};
};
struct tySequence__ib5UTyrs9aC6K60sNqKElQA_Content { NI cap; tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA data[SEQ_DECL_SIZE]; };
struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content { NI cap; tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ data[SEQ_DECL_SIZE]; };
struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content { NI cap; tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* data[SEQ_DECL_SIZE]; };
struct tySequence__9at3Cmn7xIajy679cMZSmybg_Content { NI cap; tyTuple__RrY3dT8dfTceE0s6Bv9bxJw data[SEQ_DECL_SIZE]; };
struct tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg {
	NimStringV2 content;
	NimStringV2 sortName;
};
struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content { NI cap; tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg data[SEQ_DECL_SIZE]; };
struct tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content { NI cap; tyTuple__30Ti2rm9aDSr5neUSZP6EVQ data[SEQ_DECL_SIZE]; };
struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ {
  NI len; tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content* p;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
struct tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg {
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ descRst;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ substitutions;
	NimStringV2 sortName;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
	NimStringV2 anchor;
	NimStringV2 name;
	NimStringV2 detailedName;
};
struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content { NI cap; tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg data[SEQ_DECL_SIZE]; };
struct tyTuple__8ZxhPt1NwfElsJs8zUSV9bg {
	NI Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
struct tySequence__SFipDZIkFtPcrLs0AGBBjQ_Content { NI cap; tyTuple__8ZxhPt1NwfElsJs8zUSV9bg data[SEQ_DECL_SIZE]; };
struct tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ_Content { NI cap; tyTuple__fgn415DvsSyiHk3o9aIYr0w data[SEQ_DECL_SIZE]; };
struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content { NI cap; tyTuple__9a3DhYVfcy14Fx42tD0lSEQ data[SEQ_DECL_SIZE]; };
struct tySequence__mg32q50AXD9cQ6jovpBmgWA_Content { NI cap; tyTuple__bvjw5f4vMpB9bESWLU7nvyA data[SEQ_DECL_SIZE]; };
struct tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content { NI cap; tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content { NI cap; tyTuple__UV3llMMYFckfui8YMBuUZA data[SEQ_DECL_SIZE]; };
struct tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ {
	NIM_BOOL isRst;
union{
	struct {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* rst;
} _isRst_1;
	struct {
	NimStringV2 str;
} _isRst_2;
};
};
struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content { NI cap; tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
static N_INLINE(NI, slotsNeeded__pureZcollectionsZtables_u43)(NI count_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nextPowerOfTwo__pureZmath_u256)(NI x_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__astalgo_u903)(tySequence__9chP3SzkaldXzawWQCDsqqg* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__astalgo_u426)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w t_p0, void* key_p1, NI* hc_p2);
static N_INLINE(NI, hash__pureZhashes_u128)(void* x_p0);
static N_INLINE(NI, hash__pureZhashes_u132)(NI x_p0);
static N_INLINE(NI, hashWangYi1__pureZhashes_u140)(NU64 x_p0);
static N_INLINE(NU64, hiXorLo__pureZhashes_u81)(NU64 a_p0, NU64 b_p1);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0);
static N_INLINE(NI, nextTry__pureZcollectionsZtables_u35)(NI h_p0, NI maxHash_p1);
static N_INLINE(NIM_BOOL, mustRehash__astalgo_u1031)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__astalgo_u1190)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__astalgo_u1480)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w* t_p0, tySequence__9chP3SzkaldXzawWQCDsqqg* data_p1, void* key_p2, NI val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u8088)(NI* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___astalgo_u661)(tySequence__9chP3SzkaldXzawWQCDsqqg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
static N_INLINE(NI, rawGetKnownHC__astalgo_u1637)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w t_p0, void* key_p1, NI hc_p2);
static N_INLINE(NI, rawGet__ast_u900)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg t_p0, NI key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__ast_u1330)(NI key_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u820)(tySequence__FGxE1Nuen6pVDc58PZudJw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lineinfos_u424)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u566)(tySequence__7lEisrXlQEzwtUKW5pzRCw dest_p0);
static N_INLINE(NI, rawGet__lineinfos_u707)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hash__pureZhashes_u587)(NimStringV2 x_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(NIM_BOOL, mustRehash__lineinfos_u1034)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__lineinfos_u1175)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__lineinfos_u1459)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0, tySequence__7lEisrXlQEzwtUKW5pzRCw* data_p1, NimStringV2 key_p2, NI32 val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZoserrors_u34)(NI32* dest_p0);
static N_INLINE(NI, rawGetKnownHC__lineinfos_u1616)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u886)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u802)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___options_u811)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* dest_p0, tyObject_Table__g39amaj5esSUbnvSF2f9bVgg src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg, initTable__options_u708)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__options_u722)(tySequence__FGxE1Nuen6pVDc58PZudJw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nimblecmd_u898)(tySequence__6j25whH7XTBoIXcM0x1T7A* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__nimblecmd_u332)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___stdZprivateZospaths2_u309)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___stdZprivateZospaths2_u315)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* src_p1);
static N_INLINE(NIM_BOOL, mustRehash__nimblecmd_u1020)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__nimblecmd_u1161)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__nimblecmd_u1445)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ* t_p0, tySequence__6j25whH7XTBoIXcM0x1T7A* data_p1, NimStringV2 key_p2, tyTuple__UV3llMMYFckfui8YMBuUZA* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZprivateZospaths2_u303)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nimblecmd_u564)(tySequence__6j25whH7XTBoIXcM0x1T7A dest_p0);
static N_INLINE(NI, rawGetKnownHC__nimblecmd_u1602)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__msgs_u316)(NimStringV2 key_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u173)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12632)(tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3288)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2823)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14134)(tySequence__juxPMVNF1FoR2ltzeQu8NQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11761)(tySequence__nSO1ltijM4vhc0UrrXKEqA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u100)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u66)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___suggestsymdb_u858)(tySequence__yUWoZehF86MIc40opFgacw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___suggestsymdb_u735)(tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u16091)(tySequence__48JTohSgTy339bRxHzUD8KA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2212)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1156)(tySequence__apM9bRAO19cVjhWlxqd1PGeA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u672)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u3941)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11373)(tySequence__fdmz6VkIf1ewwrssKYqRFg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u11231)(tySequence__fdmz6VkIf1ewwrssKYqRFg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11545)(tySequence__kxu4GK0onha2t9bo86mdVAg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u11447)(tySequence__kxu4GK0onha2t9bo86mdVAg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___suggestsymdb_u1866)(tySequence__fz0REU1l0nYmKHXgMLRrIg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__suggestsymdb_u1447)(tySequence__fz0REU1l0nYmKHXgMLRrIg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12037)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u11663)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12255)(tySequence__R9c39btP6BwOBBPnbaNUtMQg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u12107)(tySequence__R9c39btP6BwOBBPnbaNUtMQg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12466)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u12324)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12789)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u12534)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13005)(tySequence__vJcM7B74R2U5db9cxyXT9coA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u12858)(tySequence__vJcM7B74R2U5db9cxyXT9coA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13172)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u13074)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__ast_u4301)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1);
static N_INLINE(NI, hash__idents_u363)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* x_p0);
static N_INLINE(NIM_BOOL, eqeq___idents_u366)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* a_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* b_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u4392)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u2522)(NI* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u2968)(tyTuple__Oubp8LPEu86EPyDuc56AXg* dest_p0, tyTuple__Oubp8LPEu86EPyDuc56AXg src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u2956)(tyTuple__Oubp8LPEu86EPyDuc56AXg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u2881)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__ast_u4425)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__ast_u4459)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, ctRawInsert__ast_u4496)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0, tySequence__hRbbzIynOoxrYjHTIKZ3Gw* data_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p2, NI val_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___idents_u158)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___idents_u152)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3027)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u1429)(tySequence__7s5HyddQ0f9bxMNILHrXwJQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(NIM_BOOL, mustRehash__ast_u1551)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__ast_u1692)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__ast_u1976)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0, tySequence__7s5HyddQ0f9bxMNILHrXwJQ* data_p1, NI key_p2, NimStringV2 val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u1135)(tySequence__7s5HyddQ0f9bxMNILHrXwJQ dest_p0);
static N_INLINE(NI, rawGetKnownHC__ast_u2133)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg t_p0, NI key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, reset__system_u5461)(NimStringV2* obj_p0);
static N_INLINE(NIM_BOOL, isEmpty__pureZcollectionsZtables_u29)(NI hcode_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u1209)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* dest_p0, tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u1197)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* dest_p0);
static N_INLINE(NI, rawGet__modulegraphs_u15020)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA t_p0, NI32 key_p1, NI* hc_p2);
static N_INLINE(NI, hash__ast_u624)(NI32 x_p0);
static N_INLINE(NIM_BOOL, mustRehash__modulegraphs_u15331)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__modulegraphs_u15526)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__modulegraphs_u15824)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* t_p0, tySequence__kxu4GK0onha2t9bo86mdVAg* data_p1, NI32 key_p2, NI32 val_p3, NI hc_p4, NI h_p5);
static N_INLINE(NI, rawGetKnownHC__modulegraphs_u15981)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA t_p0, NI32 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u559)(tySequence__Vl1abU3gfp0RqCb1KKfmDA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u5847)(tySequence__Vl1abU3gfp0RqCb1KKfmDA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__icZic_u5872)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__icZic_u6213)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u6386)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u6848)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, tySequence__Vl1abU3gfp0RqCb1KKfmDA* data_p1, NI32 key_p2, tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u6748)(tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__icZic_u7130)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u4339)(tySequence__qyyNkmlc4fzOzelC8spUkQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u3839)(tySequence__qyyNkmlc4fzOzelC8spUkQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__icZic_u4085)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u5038)(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* dest_p0, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* src_p1);
static N_INLINE(NIM_BOOL, mustRehash__icZic_u4487)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u4660)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u5114)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, tySequence__qyyNkmlc4fzOzelC8spUkQ* data_p1, NI32 key_p2, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u5026)(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__icZic_u5396)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13380)(tySequence__FmsTQiIcS9arxHxs3QY48vA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u18932)(tySequence__FmsTQiIcS9arxHxs3QY48vA* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__icZic_u19193)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__icZic_u19500)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u19665)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u19973)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* t_p0, tySequence__FmsTQiIcS9arxHxs3QY48vA* data_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p2, tySequence__qBes3XzcQQ9cyia9bRwnmbJw val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u3950)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* dest_p0, tySequence__qBes3XzcQQ9cyia9bRwnmbJw src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u3938)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* dest_p0);
static N_INLINE(NI, rawGetKnownHC__icZic_u20142)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__qBes3XzcQQ9cyia9bRwnmbJw, eqdup___icZic_u3947)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw src_p0);
static N_INLINE(NI, rawGet__icZic_u16418)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
static N_INLINE(NI, rawGet__icZic_u16788)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__icZic_u711)(NI32 key_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u24)(NI32 xX60gensym3__p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u17189)(tySequence__UE4b6iUkm1b3zTPamTTkDw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__icZic_u17214)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
static N_INLINE(NIM_BOOL, mustRehash__icZic_u17555)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u17728)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u18139)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, tySequence__UE4b6iUkm1b3zTPamTTkDw* data_p1, NI32 key_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3375)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13216)(tySequence__UE4b6iUkm1b3zTPamTTkDw dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__icZic_u18421)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1, NI hc_p2);
static N_INLINE(NI, rawGet__icZic_u13749)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
static N_INLINE(NI, rawGet__icZic_u307)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u14358)(tySequence__K0j67V58u5FW0dCC534FQw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__icZic_u14383)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
static N_INLINE(NIM_BOOL, mustRehash__icZic_u14724)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u14897)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u15308)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, tySequence__K0j67V58u5FW0dCC534FQw* data_p1, NI32 key_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13054)(tySequence__K0j67V58u5FW0dCC534FQw dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__icZic_u15590)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u474)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3609)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ dest_p0);
static N_INLINE(NI, rawGet__icZic_u1141)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg t_p0, NI32 key_p1, NI* hc_p2);
static N_INLINE(NI, hash__suggestsymdb_u1622)(NI32 x_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u1853)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__icZic_u1987)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u2152)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u2456)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg* t_p0, tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data_p1, NI32 key_p2, NU32 val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZiclineinfos_u100)(NU32* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u1393)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ dest_p0);
static N_INLINE(NI, rawGetKnownHC__icZic_u2625)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg t_p0, NI32 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___icZic_u13383)(tySequence__FmsTQiIcS9arxHxs3QY48vA* dest_p0, tySequence__FmsTQiIcS9arxHxs3QY48vA src_p1);
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u13402)(tySequence__FmsTQiIcS9arxHxs3QY48vA* s_p0, NI newlen_p1);
static N_INLINE(void, nimIncRef)(void* p_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___icZic_u3944)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* dest_p0, tySequence__qBes3XzcQQ9cyia9bRwnmbJw src_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u3678)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
static N_INLINE(NI, rawGet__modulegraphs_u3685)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hash__ast_u621)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA x_p0);
static N_INLINE(NIM_BOOL, eqeq___ast_u617)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA a_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA b_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__modulegraphs_u4192)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u614)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA x_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u5069)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
static N_INLINE(NI, rawGet__modulegraphs_u5076)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u5732)(tySequence__3vEEVfBECLN6NIRA3FIp5g* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u1867)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* dest_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA src_p1);
static N_INLINE(NIM_BOOL, mustRehash__modulegraphs_u5872)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__modulegraphs_u6067)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__modulegraphs_u6373)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0, tySequence__3vEEVfBECLN6NIRA3FIp5g* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3148)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1855)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u5326)(tySequence__3vEEVfBECLN6NIRA3FIp5g dest_p0);
static N_INLINE(NI, rawGetKnownHC__modulegraphs_u6530)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__semdata_u6154)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__semdata_u6244)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__semdata_u6436)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__semdata_u6753)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0, tySequence__8y0Gi4GwtXi2wk2mK1IOzw* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__vb3AGHvMJTxdOSSwMmBmTQ val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u681)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* dest_p0, tySequence__vb3AGHvMJTxdOSSwMmBmTQ src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u669)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3934)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw dest_p0);
static N_INLINE(NI, rawGetKnownHC__semdata_u6922)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__vb3AGHvMJTxdOSSwMmBmTQ, eqdup___modulegraphs_u678)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ src_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u8874)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
static N_INLINE(NI, rawGet__modulegraphs_u8881)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
static N_INLINE(NI, rawGet__lookups_u3362)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw t_p0, NI key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u4373)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
static N_INLINE(NI, rawGet__modulegraphs_u4380)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__semdata_u4929)(tySequence__C2ivDnhTZ6IxAdui1rfuqw* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__semdata_u5019)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__semdata_u5211)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__semdata_u5528)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0, tySequence__C2ivDnhTZ6IxAdui1rfuqw* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__apM9bRAO19cVjhWlxqd1PGeA val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u1165)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* dest_p0, tySequence__apM9bRAO19cVjhWlxqd1PGeA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1153)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u4629)(tySequence__C2ivDnhTZ6IxAdui1rfuqw dest_p0);
static N_INLINE(NI, rawGetKnownHC__semdata_u5697)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__apM9bRAO19cVjhWlxqd1PGeA, eqdup___modulegraphs_u1162)(tySequence__apM9bRAO19cVjhWlxqd1PGeA src_p0);
static N_INLINE(NI, rawGet__lookups_u5405)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg t_p0, NI key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZosproc_u477)(tySequence__qwqHTkRvwhrRyENtudHQ7g* dest_p0, tySequence__qwqHTkRvwhrRyENtudHQ7g src_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vmdef_u435)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__vmdef_u2388)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__vmdef_u2727)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vmdef_u2886)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vmdef_u3172)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* t_p0, tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* data_p1, NimStringV2 key_p2, NI val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u577)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og dest_p0);
static N_INLINE(NI, rawGetKnownHC__vmdef_u3329)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1, NI hc_p2);
static N_INLINE(NI, rawGet__sighashes_u616)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg t_p0, NI key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__sighashes_u1127)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sighashes_u1268)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sighashes_u1552)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* t_p0, tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg* data_p1, NI key_p2, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___OOZdistZchecksumsZsrcZchecksumsZmd5_u241)(NU8* dest_p0);
static N_INLINE(NI, rawGetKnownHC__sighashes_u1709)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg t_p0, NI key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vm_u8148)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1);
static N_INLINE(NI, rawGet__vm_u8155)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vmmarshal_u930)(tySequence__e9ciFfeAg1p88UzCBnAPeVQ* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__vmmarshal_u380)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ t_p0, NI64 key_p1, NI* hc_p2);
static N_INLINE(NI, hash__pureZjson_u3377)(NI64 x_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
static N_INLINE(NIM_BOOL, mustRehash__vmmarshal_u1058)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vmmarshal_u1217)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vmmarshal_u1503)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ* t_p0, tySequence__e9ciFfeAg1p88UzCBnAPeVQ* data_p1, NI64 key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmmarshal_u622)(tySequence__e9ciFfeAg1p88UzCBnAPeVQ dest_p0);
static N_INLINE(NI, rawGetKnownHC__vmmarshal_u1660)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ t_p0, NI64 key_p1, NI hc_p2);
static N_INLINE(NI, rawGet__vmgen_u3713)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ t_p0, NI key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vmgen_u4143)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__vmgen_u4271)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vmgen_u4430)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vmgen_u4720)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ* t_p0, tySequence__Fc8Q26tsngy2yxcpyrnT4Q* data_p1, NI key_p2, tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u3574)(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u2010)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q dest_p0);
static N_INLINE(NI, rawGetKnownHC__vmgen_u4877)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ t_p0, NI key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lambdalifting_u353)(tySequence__mnb4N9bRCddoL53waHA7kHQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u500)(tySequence__mnb4N9bRCddoL53waHA7kHQ dest_p0);
static N_INLINE(NI, rawGet__lambdalifting_u702)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ t_p0, NI key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__lambdalifting_u1252)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__lambdalifting_u1411)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__lambdalifting_u1697)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ* t_p0, tySequence__mnb4N9bRCddoL53waHA7kHQ* data_p1, NI key_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p3, NI hc_p4, NI h_p5);
static N_INLINE(NI, rawGetKnownHC__lambdalifting_u1854)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ t_p0, NI key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lambdalifting_u2573)(tySequence__R1mQMFmsdp1ChoJDXa9a0xQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u2720)(tySequence__R1mQMFmsdp1ChoJDXa9a0xQ dest_p0);
static N_INLINE(NI, rawGet__lambdalifting_u2945)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg t_p0, NI key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__lambdalifting_u3573)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__lambdalifting_u3732)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__lambdalifting_u4018)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* t_p0, tySequence__R1mQMFmsdp1ChoJDXa9a0xQ* data_p1, NI key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3, NI hc_p4, NI h_p5);
static N_INLINE(NI, rawGetKnownHC__lambdalifting_u4175)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg t_p0, NI key_p1, NI hc_p2);
static N_INLINE(NI, rawGet__liftdestructors_u837)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hash__modulegraphs_u10758)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow u_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___modulegraphs_u10735)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow a_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow b_p1);
static N_INLINE(NIM_BOOL, mustRehash__liftdestructors_u2147)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__liftdestructors_u2288)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__liftdestructors_u2568)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* t_p0, tySequence__vJcM7B74R2U5db9cxyXT9coA* data_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p3, NI hc_p4, NI h_p5);
static N_INLINE(NI, rawGetKnownHC__liftdestructors_u2725)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI hc_p2);
static N_INLINE(NI, rawGet__closureiters_u523)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__closureiters_u987)(tySequence__kP47rw9c8bgVA53QKWe9bp7g* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__closureiters_u1109)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__closureiters_u1250)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__closureiters_u1530)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw* t_p0, tySequence__kP47rw9c8bgVA53QKWe9bp7g* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, NI val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___closureiters_u752)(tySequence__kP47rw9c8bgVA53QKWe9bp7g dest_p0);
static N_INLINE(NI, rawGetKnownHC__closureiters_u1687)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vmgen_u3190)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1);
static N_INLINE(NI, rawGet__vm_u4367)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0, NimStringV2 key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__vm_u4993)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vm_u5188)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vm_u5490)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* t_p0, tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data_p1, NimStringV2 key_p2, NI64 val_p3, NI hc_p4, NI h_p5);
static N_INLINE(NI, rawGetKnownHC__vm_u5647)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vm_u5977)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1);
static N_INLINE(NI, rawGet__vm_u5984)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__vm_u6468)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vm_u6663)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vm_u6961)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0, tySequence__R9c39btP6BwOBBPnbaNUtMQg* data_p1, NimStringV2 key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3, NI hc_p4, NI h_p5);
static N_INLINE(NI, rawGetKnownHC__vm_u7118)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vm_u8516)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* dest_p0, tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw src_p1);
static N_INLINE(NIM_BOOL, mustRehash__vm_u8749)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vm_u8944)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vm_u9246)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0, tySequence__3nALyQgqjnfK2Qjc6ny2Uw* data_p1, NimStringV2 key_p2, tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vm_u8504)(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* dest_p0);
static N_INLINE(NI, rawGetKnownHC__vm_u9403)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vmprofiler_u138)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vmprofiler_u229)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1);
static N_INLINE(NI, rawGet__vmprofiler_u236)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hash__lineinfos_u261)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_u1103)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA a_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA b_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmprofiler_u588)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1, tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw val_p2);
static N_INLINE(NIM_BOOL, mustRehash__vmprofiler_u753)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vmprofiler_u894)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vmprofiler_u1202)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tySequence__FGxE1Nuen6pVDc58PZudJw* data_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p2, tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lineinfos_u2028)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmprofiler_u1182)(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw* dest_p0);
static N_INLINE(NI, rawGetKnownHC__vmprofiler_u1359)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw*, X5BX5D___vmprofiler_u1734)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__vmprofiler_u1797)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sem_u18847)(tySequence__N589c2UsUgqqOITU2JfIuAQ* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__cgen_u4153)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__sem_u18926)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sem_u19085)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sem_u19375)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* t_p0, tySequence__N589c2UsUgqqOITU2JfIuAQ* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__ZCZaCk14bTmSb6LMW9aWPVA val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4857)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0, tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4845)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13652)(tySequence__N589c2UsUgqqOITU2JfIuAQ dest_p0);
static N_INLINE(NI, rawGetKnownHC__sem_u19532)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, eqdup___ast_u4854)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__cgen_u4646)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
static N_INLINE(NI, rawGet__cgen_u4653)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sem_u19995)(tySequence__GYDW6wGgERshoSd16jJ3eQ* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__sem_u20123)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sem_u20282)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sem_u20568)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* t_p0, tySequence__GYDW6wGgERshoSd16jJ3eQ* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13804)(tySequence__GYDW6wGgERshoSd16jJ3eQ dest_p0);
static N_INLINE(NI, rawGetKnownHC__sem_u20725)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u9607)(tySequence__9aSa87aKMiolq9a7z3kC0jTw* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__modulegraphs_u9698)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__modulegraphs_u9893)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__modulegraphs_u10195)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0, tySequence__9aSa87aKMiolq9a7z3kC0jTw* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__9bW2eTK9b7vXE70Sx5VPH1mw val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u2221)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* dest_p0, tySequence__9bW2eTK9b7vXE70Sx5VPH1mw src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u2209)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u9130)(tySequence__9aSa87aKMiolq9a7z3kC0jTw dest_p0);
static N_INLINE(NI, rawGetKnownHC__modulegraphs_u10352)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw, eqdup___modulegraphs_u2218)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw src_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__cgmeth_u311)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__cgmeth_u332)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u592)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgmeth_u448)(tyTuple__2QDyOgS51ZMPO0W1pWCY6g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgmeth_u495)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__cgmeth_u507)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgmeth_u541)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, ctRawInsert__cgmeth_u574)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tySequence__Wd0Vle6gxRCPPoSlNEvfTA* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, NI val_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14008)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sempass2_u2358)(tySequence__E8pi9b5QNahsURYzXMjh3qw* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__sempass2_u2486)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sempass2_u2645)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sempass2_u2931)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0, tySequence__E8pi9b5QNahsURYzXMjh3qw* data_p1, NI key_p2, NI val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3481)(tySequence__E8pi9b5QNahsURYzXMjh3qw dest_p0);
static N_INLINE(NI, rawGetKnownHC__sempass2_u3088)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw t_p0, NI key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sempass2_u4343)(tySequence__3B6hFqG0Do0FxDvnNucL7w* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__sempass2_u3685)(tyObject_Table__g77QNejuRRKraNk8K2YkoA t_p0, NI key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__sempass2_u4422)(tyObject_Table__g77QNejuRRKraNk8K2YkoA t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sempass2_u4581)(tyObject_Table__g77QNejuRRKraNk8K2YkoA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sempass2_u4871)(tyObject_Table__g77QNejuRRKraNk8K2YkoA* t_p0, tySequence__3B6hFqG0Do0FxDvnNucL7w* data_p1, NI key_p2, tySequence__KYLoGmc5aaHsSDjEH1FTxQ val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u3618)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* dest_p0, tySequence__KYLoGmc5aaHsSDjEH1FTxQ src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3606)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3588)(tySequence__3B6hFqG0Do0FxDvnNucL7w dest_p0);
static N_INLINE(NI, rawGetKnownHC__sempass2_u5028)(tyObject_Table__g77QNejuRRKraNk8K2YkoA t_p0, NI key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__KYLoGmc5aaHsSDjEH1FTxQ, eqdup___semdata_u3615)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ src_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sempass2_u514)(tySequence__T7nNEWoEbKBa0G5Htr45Xw* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__sempass2_u531)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u14143)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* dest_p0, tySequence__juxPMVNF1FoR2ltzeQu8NQ src_p1);
static N_INLINE(NIM_BOOL, mustRehash__sempass2_u870)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sempass2_u1029)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sempass2_u1319)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag* t_p0, tySequence__T7nNEWoEbKBa0G5Htr45Xw* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__juxPMVNF1FoR2ltzeQu8NQ val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u14131)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14113)(tySequence__T7nNEWoEbKBa0G5Htr45Xw dest_p0);
static N_INLINE(NI, rawGetKnownHC__sempass2_u1476)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__sempass2_u1769)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u3874)(tySequence__dAjyAaabi52TN36Jp0fAXQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__64AfBrTBCyxlEANlKol6Ew, initTable__nilcheck_u10837)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u9279)(tySequence__dAjyAaabi52TN36Jp0fAXQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_u9211)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew* t_p0, NI key_p1, NI16 val_p2);
static N_INLINE(NI, rawGet__nilcheck_u3605)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0, NI key_p1, NI* hc_p2);
static N_INLINE(NI, hash__nilcheck_u3612)(NI x_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___nilcheck_u3548)(NI a_p0, NI b_p1);
static N_INLINE(NIM_BOOL, mustRehash__nilcheck_u9422)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__nilcheck_u9614)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__nilcheck_u9935)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew* t_p0, tySequence__dAjyAaabi52TN36Jp0fAXQ* data_p1, NI key_p2, NI16 val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZwidestrs_u81)(NI16* dest_p0);
static N_INLINE(NI, rawGetKnownHC__nilcheck_u10104)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0, NI key_p1, NI hc_p2);
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__nilcheck_u4092)(NI key_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___nilcheck_u3552)(NI a_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__nilcheck_u3598)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__importer_u2416)(tySequence__QqvaCqCpEE1QmQZbcZLi5A* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__importer_u2506)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__importer_u2698)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__importer_u3015)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg* t_p0, tySequence__QqvaCqCpEE1QmQZbcZLi5A* data_p1, NI key_p2, tySequence__qwqHTkRvwhrRyENtudHQ7g val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZosproc_u483)(tySequence__qwqHTkRvwhrRyENtudHQ7g* dest_p0, tySequence__qwqHTkRvwhrRyENtudHQ7g src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZosproc_u471)(tySequence__qwqHTkRvwhrRyENtudHQ7g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3898)(tySequence__QqvaCqCpEE1QmQZbcZLi5A dest_p0);
static N_INLINE(NI, rawGetKnownHC__importer_u3184)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg t_p0, NI key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g, eqdup___pureZosproc_u480)(tySequence__qwqHTkRvwhrRyENtudHQ7g src_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgendata_u2155)(tySequence__zpKGgayc1mFyemMGMuK9a2w* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u768)(tySequence__9cbEQVGky3gHl4QEC3q4Sow dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgen_u2035)(tySequence__9cbEQVGky3gHl4QEC3q4Sow* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1411)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sighashes_u2239)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgendata_u550)(tySequence__jwzrUFjG9akTIJTBBFvvqxw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3106)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u2877)(tySequence__ib5UTyrs9aC6K60sNqKElQA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u70)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2579)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2284)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA dest_p0);
static N_INLINE(NI, rawGet__packagesZdocutilsZrst_u940)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u1472)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrst_u1594)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrst_u1735)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrst_u2019)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ* t_p0, tySequence__7lEisrXlQEzwtUKW5pzRCw* data_p1, NimStringV2 key_p2, NI32 val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u1172)(tySequence__7lEisrXlQEzwtUKW5pzRCw dest_p0);
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrst_u2176)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u1193)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u7025)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u8528)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
static N_INLINE(NI, rawGet__modulegraphs_u7151)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u2832)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* dest_p0, tySequence__olFOFaYzOJN9aV5BWqK4b9bA src_p1);
static N_INLINE(NIM_BOOL, mustRehash__modulegraphs_u7554)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__modulegraphs_u7749)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__modulegraphs_u8051)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0, tySequence__q9cHvMDDxYU1hSCdG4YwIhA* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__olFOFaYzOJN9aV5BWqK4b9bA val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u2820)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u7400)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA dest_p0);
static N_INLINE(NI, rawGetKnownHC__modulegraphs_u8208)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__sighashes_u2099)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__sighashes_u2191)(NU8* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___sighashes_u2214)(tyTuple__9agFg9cuYsNvckAbTfHAsTSA* dest_p0);
static N_INLINE(NIM_BOOL, mustRehash__sighashes_u2251)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sighashes_u2285)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, ctRawInsert__sighashes_u2318)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0, tySequence__9bRXJy1JXrQ4hWpStaKBpXg* data_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p2, NI val_p3);
static N_INLINE(NI, rawGet__cgen_u1549)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__cgen_u2178)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgen_u2370)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__cgen_u2683)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* t_p0, tySequence__9cbEQVGky3gHl4QEC3q4Sow* data_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p2, NimStringV2 val_p3, NI hc_p4, NI h_p5);
static N_INLINE(NI, rawGetKnownHC__cgen_u2852)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI hc_p2);
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__cgen_u3388)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___modulegraphs_u10732)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow u_p0);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__cgen_u1020)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZosproc_u2043)(tyTuple__XOVT24GHXwqiEj5GCsEGCA* dest_p0, tyTuple__XOVT24GHXwqiEj5GCsEGCA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZosproc_u2031)(tyTuple__XOVT24GHXwqiEj5GCsEGCA* dest_p0);
static N_INLINE(NIM_BOOL, mustRehash__cgen_u1142)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgen_u1176)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, ctRawInsert__cgen_u1209)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, tySequence__jwzrUFjG9akTIJTBBFvvqxw* data_p1, NimStringV2 key_p2, NI val_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u670)(tySequence__jwzrUFjG9akTIJTBBFvvqxw dest_p0);
static N_INLINE(NI, rawGet__cgen_u10594)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___cgen_u10911)(tyTuple__w31HlKXGH5QCPFggOmKfbQ* dest_p0, tyTuple__w31HlKXGH5QCPFggOmKfbQ src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___cgen_u10917)(tyTuple__w31HlKXGH5QCPFggOmKfbQ* dest_p0, tyTuple__w31HlKXGH5QCPFggOmKfbQ src_p1);
static N_INLINE(NIM_BOOL, mustRehash__cgen_u11270)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgen_u11462)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__cgen_u11779)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw* t_p0, tySequence__zpKGgayc1mFyemMGMuK9a2w* data_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p2, tyTuple__w31HlKXGH5QCPFggOmKfbQ val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgen_u10905)(tyTuple__w31HlKXGH5QCPFggOmKfbQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1675)(tySequence__zpKGgayc1mFyemMGMuK9a2w dest_p0);
static N_INLINE(NI, rawGetKnownHC__cgen_u11948)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__cgen_u4146)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
static N_INLINE(NI, rawGet__docgen_u281)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u765)(tySequence__kxu4GK0onha2t9bo86mdVAg* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__docgen_u893)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__docgen_u1052)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__docgen_u1338)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw* t_p0, tySequence__kxu4GK0onha2t9bo86mdVAg* data_p1, NI32 key_p2, NI32 val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u519)(tySequence__kxu4GK0onha2t9bo86mdVAg dest_p0);
static N_INLINE(NI, rawGetKnownHC__docgen_u1495)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw t_p0, NI32 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u4384)(tySequence__O9a9cp2XDKWshwC0UDgFP6Pw* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__packagesZdocutilsZrst_u4401)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw t_p0, NimStringV2 key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrst_u4679)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrst_u4820)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrst_u5104)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw* t_p0, tySequence__O9a9cp2XDKWshwC0UDgFP6Pw* data_p1, NimStringV2 key_p2, tySequence__ib5UTyrs9aC6K60sNqKElQA val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrst_u2886)(tySequence__ib5UTyrs9aC6K60sNqKElQA* dest_p0, tySequence__ib5UTyrs9aC6K60sNqKElQA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u2874)(tySequence__ib5UTyrs9aC6K60sNqKElQA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u2856)(tySequence__O9a9cp2XDKWshwC0UDgFP6Pw dest_p0);
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrst_u5261)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__ib5UTyrs9aC6K60sNqKElQA, eqdup___packagesZdocutilsZrst_u2883)(tySequence__ib5UTyrs9aC6K60sNqKElQA src_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u14254)(tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__packagesZdocutilsZrst_u14271)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrst_u15035)(tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ* dest_p0, tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ* src_p1);
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrst_u14598)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrst_u14739)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrst_u15051)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA* t_p0, tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg* data_p1, NimStringV2 key_p2, tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u15023)(tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3536)(tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg dest_p0);
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrst_u15208)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__docgen_u4279)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__docgen_u4298)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u4680)(tySequence__lCWXucMn9bU7PUqVDK7772w* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u4012)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ** dest_p0, tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* src_p1);
static N_INLINE(NIM_BOOL, mustRehash__docgen_u4816)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__docgen_u4983)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__docgen_u5372)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, tySequence__lCWXucMn9bU7PUqVDK7772w* data_p1, NimStringV2 key_p2, tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u4000)(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3085)(tySequence__lCWXucMn9bU7PUqVDK7772w dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__docgen_u5634)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1, NI hc_p2);
static N_INLINE(NI, rawGet__docgen_u5925)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u6771)(tySequence__uAwiTxV3boseSy9a9cSsXHEA* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__docgen_u6788)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg t_p0, NimStringV2 key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__docgen_u7078)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__docgen_u7237)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__docgen_u7527)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0, tySequence__uAwiTxV3boseSy9a9cSsXHEA* data_p1, NimStringV2 key_p2, tySequence__b9cVyuSHmrW80P0ZGgU2KHA val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u2293)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* dest_p0, tySequence__b9cVyuSHmrW80P0ZGgU2KHA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2281)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2263)(tySequence__uAwiTxV3boseSy9a9cSsXHEA dest_p0);
static N_INLINE(NI, rawGetKnownHC__docgen_u7684)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__b9cVyuSHmrW80P0ZGgU2KHA, eqdup___docgen_u2290)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA src_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u8202)(tySequence__9at3Cmn7xIajy679cMZSmybg* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__docgen_u8219)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw t_p0, NimStringV2 key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__docgen_u8509)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__docgen_u8668)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__docgen_u8958)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* t_p0, tySequence__9at3Cmn7xIajy679cMZSmybg* data_p1, NimStringV2 key_p2, tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u2588)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* dest_p0, tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2576)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2732)(tySequence__9at3Cmn7xIajy679cMZSmybg dest_p0);
static N_INLINE(NI, rawGetKnownHC__docgen_u9115)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg, eqdup___docgen_u2585)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg src_p0);
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__pureZjson_u807)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, NI* hc_p2);
static N_INLINE(NI, rawGet__pureZjson_u3055)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZjson_u471)(tySequence__m9axZwxFfhSNLcoofvKZJYA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZjson_u333)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** dest_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* src_p1);
static N_INLINE(NIM_BOOL, mustRehash__pureZjson_u1135)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__pureZjson_u1284)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__pureZjson_u1667)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, tySequence__m9axZwxFfhSNLcoofvKZJYA* data_p1, NimStringV2 key_p2, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZjson_u321)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u94)(tySequence__m9axZwxFfhSNLcoofvKZJYA dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__pureZjson_u1929)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZjson_u97)(tySequence__m9axZwxFfhSNLcoofvKZJYA* dest_p0, tySequence__m9axZwxFfhSNLcoofvKZJYA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZjson_u116)(tySequence__m9axZwxFfhSNLcoofvKZJYA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrst_u2880)(tySequence__ib5UTyrs9aC6K60sNqKElQA* dest_p0, tySequence__ib5UTyrs9aC6K60sNqKElQA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u6726)(tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u6349)(tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__packagesZdocutilsZrst_u6477)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ t_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hash__packagesZdocutilsZrst_u6484)(tyTuple__UV3llMMYFckfui8YMBuUZA* x_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrst_u6689)(tyTuple__UV3llMMYFckfui8YMBuUZA* x_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* y_p1);
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrst_u6813)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrst_u6954)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrst_u7238)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ* t_p0, tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ* data_p1, tyTuple__UV3llMMYFckfui8YMBuUZA* key_p2, tySequence__ib5UTyrs9aC6K60sNqKElQA val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZprivateZospaths2_u306)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrst_u7395)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ t_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u11611)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__olFOFaYzOJN9aV5BWqK4b9bA, eqdup___modulegraphs_u2829)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA src_p0);
static N_INLINE(NI, rawGet__suggestsymdb_u1615)(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u16760)(NI32* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u16822)(tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___suggestsymdb_u1533)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* dest_p0, tyTuple__tG5yYi8DnD7bl00aT9cgctQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___suggestsymdb_u1521)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* dest_p0);
static N_INLINE(NI, rawGet__modulegraphs_u17072)(tyObject_Table__w2vCG1OPnHmNolvQVT168g t_p0, NI32 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u17481)(tySequence__nSO1ltijM4vhc0UrrXKEqA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11750)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* dest_p0, tyTuple__gnRkA1L4XiR4uByriyHW8Q* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11738)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* dest_p0);
static N_INLINE(NI, rawGet__cgen_u29842)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw t_p0, NI32 key_p1, NI* hc_p2);
static N_INLINE(NIM_BOOL, mustRehash__pipelines_u771)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__pipelines_u912)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__pipelines_u1196)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* t_p0, tySequence__fdmz6VkIf1ewwrssKYqRFg* data_p1, NI32 key_p2, tySequence__48JTohSgTy339bRxHzUD8KA val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u16100)(tySequence__48JTohSgTy339bRxHzUD8KA* dest_p0, tySequence__48JTohSgTy339bRxHzUD8KA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u16088)(tySequence__48JTohSgTy339bRxHzUD8KA* dest_p0);
static N_INLINE(NI, rawGetKnownHC__pipelines_u1353)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw t_p0, NI32 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__48JTohSgTy339bRxHzUD8KA, eqdup___icZic_u16097)(tySequence__48JTohSgTy339bRxHzUD8KA src_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u655)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u1139)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u1841)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u2195)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u2806)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* obj_p0);
static N_INLINE(NI, rawGet__icZdce_u390)(tyObject_Table__t60gWhquDic6PI6CgxHkgw t_p0, NimStringV2 key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZdce_u264)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w* s_p0, NI len_p1);
static N_INLINE(NIM_BOOL, mustRehash__icZdce_u789)(tyObject_Table__t60gWhquDic6PI6CgxHkgw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZdce_u954)(tyObject_Table__t60gWhquDic6PI6CgxHkgw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZdce_u1282)(tyObject_Table__t60gWhquDic6PI6CgxHkgw* t_p0, tySequence__UuiPn6QjIiUTdSVwX2PZ6w* data_p1, NimStringV2 key_p2, tyTuple__Ll5iolPASSzOEheeSNjmiw val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZdce_u1262)(tyTuple__Ll5iolPASSzOEheeSNjmiw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u641)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w dest_p0);
static N_INLINE(NI, rawGetKnownHC__icZdce_u1451)(tyObject_Table__t60gWhquDic6PI6CgxHkgw t_p0, NimStringV2 key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__cgendata_u538)(NI initialSize_p0, tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* Result);
N_LIB_PRIVATE N_NIMCALL(void, inc__cgen_u1077)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1, NI val_p2);
N_LIB_PRIVATE N_NIMCALL(NI, len__main_u481)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__main_u578)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__cgen_u1001)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1, NI def_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u1198)(tySequence__mg32q50AXD9cQ6jovpBmgWA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstidx_u281)(tySequence__36jA1xDCIBAS29cySYLQ7kQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrstgen_u2347)(tySequence__mg32q50AXD9cQ6jovpBmgWA* s_p0, NI len_p1);
static N_INLINE(NI, rawGet__packagesZdocutilsZrstgen_u1880)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* key_p1, NI* hc_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hash__packagesZdocutilsZrstidx_u322)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* x_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrstgen_u2085)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* x_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrstidx_u290)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* dest_p0, tySequence__36jA1xDCIBAS29cySYLQ7kQ src_p1);
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrstgen_u2714)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrstgen_u2855)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrstgen_u3139)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* t_p0, tySequence__mg32q50AXD9cQ6jovpBmgWA* data_p1, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* key_p2, tySequence__36jA1xDCIBAS29cySYLQ7kQ val_p3, NI hc_p4, NI h_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrstidx_u200)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstidx_u194)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstidx_u278)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstidx_u197)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0);
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrstgen_u3296)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* key_p1, NI hc_p2);
N_LIB_PRIVATE N_NIMCALL(void, del__vmprofiler_u2319)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__vmprofiler_u2442)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__vmprofiler_u2504)(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmprofiler_u2707)(tyTuple__7xc1P89akJWzo77UAKrb3aA* dest_p0);
extern TNimTypeV2 NTIv2__jzGRfzBmxnPANjp71FNw5Q_;
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__4SoG2KRQy3oMm9aUzSLtGrA_2 = { 15 | NIM_STRLIT_FLAG, "key not found: " };
static const NimStringV2 TM__4SoG2KRQy3oMm9aUzSLtGrA_3 = {15, (NimStrPayload*)&TM__4SoG2KRQy3oMm9aUzSLtGrA_2};
static const NimStringV2 TM__4SoG2KRQy3oMm9aUzSLtGrA_4 = {15, (NimStrPayload*)&TM__4SoG2KRQy3oMm9aUzSLtGrA_2};
static const NimStringV2 TM__4SoG2KRQy3oMm9aUzSLtGrA_5 = {15, (NimStrPayload*)&TM__4SoG2KRQy3oMm9aUzSLtGrA_2};
static const NimStringV2 TM__4SoG2KRQy3oMm9aUzSLtGrA_6 = {15, (NimStrPayload*)&TM__4SoG2KRQy3oMm9aUzSLtGrA_2};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__4SoG2KRQy3oMm9aUzSLtGrA_7 = { 13 | NIM_STRLIT_FLAG, "key not found" };
static const NimStringV2 TM__4SoG2KRQy3oMm9aUzSLtGrA_8 = {13, (NimStrPayload*)&TM__4SoG2KRQy3oMm9aUzSLtGrA_7};
static const NimStringV2 TM__4SoG2KRQy3oMm9aUzSLtGrA_9 = {15, (NimStrPayload*)&TM__4SoG2KRQy3oMm9aUzSLtGrA_2};
static const NimStringV2 TM__4SoG2KRQy3oMm9aUzSLtGrA_10 = {15, (NimStrPayload*)&TM__4SoG2KRQy3oMm9aUzSLtGrA_2};
extern NIM_BOOL nimInErrorMode__system_u4143;
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
static N_INLINE(NI, slotsNeeded__pureZcollectionsZtables_u43)(NI count_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = nextPowerOfTwo__pureZmath_u256((NI)((NI)((NI)(count_p0 / ((NI)2)) + count_p0) + ((NI)4)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__A49ak19aStos8ZFsiM37JH6w, initTable__astalgo_u2329)(NI initialSize_p0) {
	tyObject_Table__A49ak19aStos8ZFsiM37JH6w result;
	NI correctSizeX60gensym84__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__A49ak19aStos8ZFsiM37JH6w));
	correctSizeX60gensym84__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__astalgo_u903((&result.data), (correctSizeX60gensym84__1));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NU64, hiXorLo__pureZhashes_u81)(NU64 a_p0, NU64 b_p1) {
	NU64 result;
	result = (NU64)0;
	result = 0ULL;
	__uint128_t r = a_p0; r *= b_p1; result = (r >> 64) ^ r;
	return result;
}
static N_INLINE(NI, hashWangYi1__pureZhashes_u140)(NU64 x_p0) {
	NI result;
	NU64 T1_;
	NU64 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NU64)0;
	T1_ = hiXorLo__pureZhashes_u81(11562461410679940143ULL, (NU64)(x_p0 ^ 16646288086500911323ULL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NU64)0;
	T2_ = hiXorLo__pureZhashes_u81(T1_, 16952864883938283885ULL);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = ((NI) (T2_));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, hash__pureZhashes_u132)(NI x_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = hashWangYi1__pureZhashes_u140(((NU64) (x_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, hash__pureZhashes_u128)(void* x_p0) {
	NI result;
	NI y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	y_1 = ((NI) (ptrdiff_t) (x_p0));
	result = hash__pureZhashes_u132(y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0) {
	NIM_BOOL result;
	result = !((hcode_p0 == ((NI)0)));
	return result;
}
static N_INLINE(NI, nextTry__pureZcollectionsZtables_u35)(NI h_p0, NI maxHash_p1) {
	NI result;
	result = (NI)((NI)(h_p0 + ((NI)1)) & maxHash_p1);
	return result;
}
static N_INLINE(NI, rawGet__astalgo_u426)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w t_p0, void* key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u128(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__astalgo_u416)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w t_p0, void* key_p1, NI def_p2) {
	NI result;
	NI hcX60gensym40__1;
	NI indexX60gensym40__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	hcX60gensym40__1 = (NI)0;
	indexX60gensym40__1 = rawGet__astalgo_u426(t_p0, key_p1, (&hcX60gensym40__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	{
		if (!(((NI)0) <= indexX60gensym40__1)) goto LA4_;
		result = t_p0.data.p->data[indexX60gensym40__1].Field2;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__astalgo_u1031)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__astalgo_u1480)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w* t_p0, tySequence__9chP3SzkaldXzawWQCDsqqg* data_p1, void* key_p2, NI val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___astalgo_u661)(tySequence__9chP3SzkaldXzawWQCDsqqg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__aGv2fk9ceddvdC01ZJC2Q2g));
}
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__astalgo_u1190)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w* t_p0) {
	tySequence__9chP3SzkaldXzawWQCDsqqg n_1;
	NI T1_;
	tySequence__9chP3SzkaldXzawWQCDsqqg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__astalgo_u903((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__A49ak19aStos8ZFsiM37JH6w* T17_;
					void* T18_;
					NI T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__A49ak19aStos8ZFsiM37JH6w*)0;
					T17_ = t_p0;
					T18_ = (void*)0;
					T18_ = n_1.p->data[i_1].Field1;
					n_1.p->data[i_1].Field1 = 0;
					T19_ = (NI)0;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field2));
					rawInsert__astalgo_u1480(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___astalgo_u661(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__astalgo_u1637)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w t_p0, void* key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___astalgo_u846)(tyObject_Table__A49ak19aStos8ZFsiM37JH6w* t_p0, void* key_p1, NI val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym45__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym45__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__astalgo_u903((&(*t_p0).data), (correctSizeX60gensym45__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__astalgo_u426((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__A49ak19aStos8ZFsiM37JH6w* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym48__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym48__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__astalgo_u903((&(*t_p0).data), (correctSizeX60gensym48__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__astalgo_u1031((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__astalgo_u1190(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__astalgo_u1637((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__A49ak19aStos8ZFsiM37JH6w*)0;
		T21_ = t_p0;
		rawInsert__astalgo_u1480(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__ast_u900)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u132(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__ast_u1330)(NI key_p0) {
	NimStringV2 colontmpD_;
	tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q* T2_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q*) nimNewObj(sizeof(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q), NIM_ALIGNOF(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q));
	(*T2_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__jzGRfzBmxnPANjp71FNw5Q_);
	(*T2_).Sup.Sup.Sup.name = "KeyError";
	T3_.len = 0; T3_.p = NIM_NIL;
	colontmpD_ = dollar___systemZdollars_u9(key_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = rawNewString(colontmpD_.len + 15);
appendString((&T3_), TM__4SoG2KRQy3oMm9aUzSLtGrA_3);
appendString((&T3_), colontmpD_);
	(*T2_).Sup.Sup.Sup.message = T3_;
	(*T2_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T2_, "KeyError", "raiseKeyError", "tables.nim", 232);
goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2*, X5BX5D___ast_u893)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0, NI key_p1) {
	NimStringV2* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NimStringV2*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__ast_u900((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__ast_u1330(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u820)(tySequence__FGxE1Nuen6pVDc58PZudJw dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__7xc1P89akJWzo77UAKrb3aA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u802)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg dest_p0) {
	eqdestroy___options_u820(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u566)(tySequence__7lEisrXlQEzwtUKW5pzRCw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__xYhUhS7X82rKTqbT9bRfCnw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u502)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lineinfos_u499)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A, initTable__lineinfos_u410)(NI initialSize_p0) {
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A result;
	NI correctSizeX60gensym2__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A));
	correctSizeX60gensym2__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__lineinfos_u424((&result.data), (correctSizeX60gensym2__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u548)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A dest_p0) {
	eqdestroy___lineinfos_u566(dest_p0.data);
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__lineinfos_u707)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__lineinfos_u1034)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__lineinfos_u1459)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0, tySequence__7lEisrXlQEzwtUKW5pzRCw* data_p1, NimStringV2 key_p2, NI32 val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__lineinfos_u1175)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0) {
	tySequence__7lEisrXlQEzwtUKW5pzRCw n_1;
	NI T1_;
	tySequence__7lEisrXlQEzwtUKW5pzRCw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__lineinfos_u424((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* T17_;
					NI32 T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_ = (NI32)0;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___stdZoserrors_u34((&n_1.p->data[i_1].Field2));
					rawInsert__lineinfos_u1459(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___lineinfos_u566(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__lineinfos_u1616)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lineinfos_u646)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0, NimStringV2 key_p1, NI32 val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym5__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym5__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__lineinfos_u424((&(*t_p0).data), (correctSizeX60gensym5__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__lineinfos_u707((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym10__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym10__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__lineinfos_u424((&(*t_p0).data), (correctSizeX60gensym10__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__lineinfos_u1034((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__lineinfos_u1175(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__lineinfos_u1616((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A*)0;
		T21_ = t_p0;
		rawInsert__lineinfos_u1459(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u886)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___options_u802((*dest_p0));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___options_u811)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* dest_p0, tyObject_Table__g39amaj5esSUbnvSF2f9bVgg src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___options_u820((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg, initTable__options_u708)(NI initialSize_p0) {
	tyObject_Table__g39amaj5esSUbnvSF2f9bVgg result;
	NI correctSizeX60gensym10__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg));
	correctSizeX60gensym10__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__options_u722((&result.data), (correctSizeX60gensym10__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg*, newTable__options_u678)(NI initialSize_p0) {
	tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* result;
	tyObject_Table__g39amaj5esSUbnvSF2f9bVgg T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqdestroy___options_u886(result);
	result = (tyObject_Table__g39amaj5esSUbnvSF2f9bVgg*) nimNewObj(sizeof(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg), NIM_ALIGNOF(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg));
	T1_ = initTable__options_u708(initialSize_p0);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___options_u802(T1_); goto BeforeRet_;}
	eqsink___options_u811((&(*result)), T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nimblecmd_u629)(tyTuple__9cdgeqdY7FRioNKBoD6G66A* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
	eqdestroy___system_u2691((*dest_p0).Field2.Field0);
	eqdestroy___system_u2691((*dest_p0).Field2.Field1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___nimblecmd_u626)(tyTuple__9cdgeqdY7FRioNKBoD6G66A* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2.Field0.len = 0; (*dest_p0).Field2.Field0.p = NIM_NIL;
	(*dest_p0).Field2.Field1.len = 0; (*dest_p0).Field2.Field1.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ, initTable__nimblecmd_u2221)(NI initialSize_p0) {
	tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ result;
	NI correctSizeX60gensym44__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ));
	correctSizeX60gensym44__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__nimblecmd_u898((&result.data), (correctSizeX60gensym44__1));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__nimblecmd_u332)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getOrDefault__nimblecmd_u318)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0, NimStringV2 key_p1, tyTuple__UV3llMMYFckfui8YMBuUZA* Result) {
	NI hcX60gensym16__1;
	NI indexX60gensym16__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	hcX60gensym16__1 = (NI)0;
	indexX60gensym16__1 = rawGet__nimblecmd_u332(t_p0, key_p1, (&hcX60gensym16__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym16__1)) goto LA3_;
		eqcopy___stdZprivateZospaths2_u309(Result, (&t_p0.data.p->data[indexX60gensym16__1].Field2));
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__nimblecmd_u798)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__nimblecmd_u332(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__nimblecmd_u1020)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__nimblecmd_u1445)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ* t_p0, tySequence__6j25whH7XTBoIXcM0x1T7A* data_p1, NimStringV2 key_p2, tyTuple__UV3llMMYFckfui8YMBuUZA* val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___stdZprivateZospaths2_u315((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nimblecmd_u564)(tySequence__6j25whH7XTBoIXcM0x1T7A dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2.Field0);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2.Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__9cdgeqdY7FRioNKBoD6G66A));
}
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__nimblecmd_u1161)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ* t_p0) {
	tySequence__6j25whH7XTBoIXcM0x1T7A n_1;
	NI T1_;
	tySequence__6j25whH7XTBoIXcM0x1T7A T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__nimblecmd_u898((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ* T17_;
					tyTuple__UV3llMMYFckfui8YMBuUZA T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___stdZprivateZospaths2_u303((&n_1.p->data[i_1].Field2));
					rawInsert__nimblecmd_u1445(T17_, (&(*t_p0).data), colontmpD_, (&T18_), eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___nimblecmd_u564(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__nimblecmd_u1602)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nimblecmd_u847)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ* t_p0, NimStringV2 key_p1, tyTuple__UV3llMMYFckfui8YMBuUZA* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym21__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym21__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__nimblecmd_u898((&(*t_p0).data), (correctSizeX60gensym21__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__nimblecmd_u332((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___stdZprivateZospaths2_u315((&(*t_p0).data.p->data[index_1].Field2), val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ* T21_;
		tyTuple__UV3llMMYFckfui8YMBuUZA blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym24__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym24__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__nimblecmd_u898((&(*t_p0).data), (correctSizeX60gensym24__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__nimblecmd_u1020((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__nimblecmd_u1161(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__nimblecmd_u1602((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ*)0;
		T21_ = t_p0;
		nimZeroMem((void*)(&blitTmp_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		blitTmp_1 = (*val_p2);
		rawInsert__nimblecmd_u1445(T21_, (&(*t_p0).data), key_p1, (&blitTmp_1), hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__nimblecmd_u1912)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nimblecmd_u2150)(tyObject_Table__dvCGcgGns3Ybmlba9cIaZMQ dest_p0) {
	eqdestroy___nimblecmd_u564(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__msgs_u142)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__lineinfos_u707(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__msgs_u316)(NimStringV2 key_p0) {
	tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q* T1_;
	NimStringV2 T2_;
{	T1_ = NIM_NIL;
	T1_ = (tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q*) nimNewObj(sizeof(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q), NIM_ALIGNOF(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__jzGRfzBmxnPANjp71FNw5Q_);
	(*T1_).Sup.Sup.Sup.name = "KeyError";
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = rawNewString(key_p0.len + 15);
appendString((&T2_), TM__4SoG2KRQy3oMm9aUzSLtGrA_4);
appendString((&T2_), key_p0);
	(*T1_).Sup.Sup.Sup.message = T2_;
	(*T1_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T1_, "KeyError", "raiseKeyError", "tables.nim", 232);
goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI32*, X5BX5D___msgs_u253)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0, NimStringV2 key_p1) {
	NI32* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI32*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__lineinfos_u707((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3027)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___idents_u173((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__Oubp8LPEu86EPyDuc56AXg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12789)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2.root);
				if (!T6_) goto LA7_;
				eqdestroy___modulegraphs_u12632((&(*dest_p0.p->data[colontmp_].Field2.root)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2.root, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12466)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12255)(tySequence__R9c39btP6BwOBBPnbaNUtMQg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field2)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__OtlgAx3kBps9cOSMNDZSzBA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13172)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__EdLY4EJQ37VFgbAn5g5rXQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13005)(tySequence__vJcM7B74R2U5db9cxyXT9coA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].Field2)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__XrHNJHOzS3O7uwF9bvCySiA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u7400)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___modulegraphs_u2823(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__zExIg9bDTcVf2FHROUpzoow));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14113)(tySequence__T7nNEWoEbKBa0G5Htr45Xw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___modulegraphs_u14134(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__UbCNQED4XJUgxOgPHJUcAQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14008)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__2QDyOgS51ZMPO0W1pWCY6g));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12037)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___modulegraphs_u11761(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__gnRkA1L4XiR4uByriyHW8Q));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___suggestsymdb_u1866)(tySequence__fz0REU1l0nYmKHXgMLRrIg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_].Field2.isGenericInstance.s.data);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2.isGenericInstance.s.head);
				if (!T6_) goto LA7_;
				eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_].Field2.isGenericInstance.s.head)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2.isGenericInstance.s.head, ((NI)8));
			}
LA7_: ;
			eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_].Field2.isDecl.s.data);
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2.isDecl.s.head);
				if (!T11_) goto LA12_;
				eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_].Field2.isDecl.s.head)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2.isDecl.s.head, ((NI)8));
			}
LA12_: ;
			eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_].Field2.caughtExceptionsSet.s.data);
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2.caughtExceptionsSet.s.head);
				if (!T16_) goto LA17_;
				eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_].Field2.caughtExceptionsSet.s.head)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2.caughtExceptionsSet.s.head, ((NI)8));
			}
LA17_: ;
			eqdestroy___suggestsymdb_u858(dest_p0.p->data[colontmp_].Field2.caughtExceptions);
			eqdestroy___ast_u4848(dest_p0.p->data[colontmp_].Field2.sym);
			eqdestroy___suggestsymdb_u735(dest_p0.p->data[colontmp_].Field2.lineInfo);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__tG5yYi8DnD7bl00aT9cgctQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11545)(tySequence__kxu4GK0onha2t9bo86mdVAg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11373)(tySequence__fdmz6VkIf1ewwrssKYqRFg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___icZic_u16091(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u5326)(tySequence__3vEEVfBECLN6NIRA3FIp5g dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2.sym);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field2.sym)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2.sym, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13804)(tySequence__GYDW6wGgERshoSd16jJ3eQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field2)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__YG7h1OUHzgfgTeH9cl0U0dw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13652)(tySequence__N589c2UsUgqqOITU2JfIuAQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___ast_u4848(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__bnJwOH0eJlAwCAMbr1inhw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u9130)(tySequence__9aSa87aKMiolq9a7z3kC0jTw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___modulegraphs_u2212(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u4629)(tySequence__C2ivDnhTZ6IxAdui1rfuqw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___modulegraphs_u1156(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__F1mMODXmKFMNQ5rLCtcv0Q));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3934)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___modulegraphs_u672(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u1393)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__UvldbCB6B9ayi9bGYW7vJNLA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13380)(tySequence__FmsTQiIcS9arxHxs3QY48vA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1);
				if (!T6_) goto LA7_;
				eqdestroy___idents_u173((&(*dest_p0.p->data[colontmp_].Field1)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1, ((NI)8));
			}
LA7_: ;
			eqdestroy___icZic_u3941(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__MZVSn3SE3XUBJOaMu7ofRQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13216)(tySequence__UE4b6iUkm1b3zTPamTTkDw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field3);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].Field3)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field3, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__1xWeGeoNoZxaLhTUDDWYyA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13054)(tySequence__K0j67V58u5FW0dCC534FQw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field3);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field3)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field3, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u4339)(tySequence__qyyNkmlc4fzOzelC8spUkQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___icZic_u3941(dest_p0.p->data[colontmp_].Field3.types);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__anemVmHCFglLFt6LiEhFvg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u559)(tySequence__Vl1abU3gfp0RqCb1KKfmDA dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__V1VWX9bHapuzCjpMfFfys5Q));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11364)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* dest_p0, tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___modulegraphs_u11373((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11309)(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q* dest_p0) {
	eqdestroy___icZic_u16091((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11306)(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw, initTable__modulegraphs_u11217)(NI initialSize_p0) {
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw result;
	NI correctSizeX60gensym128__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw));
	correctSizeX60gensym128__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u11231((&result.data), (correctSizeX60gensym128__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11355)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw dest_p0) {
	eqdestroy___modulegraphs_u11373(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11536)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* dest_p0, tyObject_Table__AC9bec2JdoOuC3xQePGWgmA src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___modulegraphs_u11545((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA, initTable__modulegraphs_u11433)(NI initialSize_p0) {
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA result;
	NI correctSizeX60gensym130__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA));
	correctSizeX60gensym130__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u11447((&result.data), (correctSizeX60gensym130__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11527)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA dest_p0) {
	eqdestroy___modulegraphs_u11545(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11628)(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ* dest_p0, tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___suggestsymdb_u1866((*dest_p0).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___suggestsymdb_u1524)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* dest_p0) {
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).Field2.isGenericInstance.s.data);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field2.isGenericInstance.s.head);
		if (!T3_) goto LA4_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).Field2.isGenericInstance.s.head)));
		nimRawDispose((*dest_p0).Field2.isGenericInstance.s.head, ((NI)8));
	}
LA4_: ;
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).Field2.isDecl.s.data);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).Field2.isDecl.s.head);
		if (!T8_) goto LA9_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).Field2.isDecl.s.head)));
		nimRawDispose((*dest_p0).Field2.isDecl.s.head, ((NI)8));
	}
LA9_: ;
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).Field2.caughtExceptionsSet.s.data);
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).Field2.caughtExceptionsSet.s.head);
		if (!T13_) goto LA14_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).Field2.caughtExceptionsSet.s.head)));
		nimRawDispose((*dest_p0).Field2.caughtExceptionsSet.s.head, ((NI)8));
	}
LA14_: ;
	eqdestroy___suggestsymdb_u858((*dest_p0).Field2.caughtExceptions);
	eqdestroy___ast_u4848((*dest_p0).Field2.sym);
	eqdestroy___suggestsymdb_u735((*dest_p0).Field2.lineInfo);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___suggestsymdb_u1521)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.lineInfo.len = 0; (*dest_p0).Field2.lineInfo.p = NIM_NIL;
	(*dest_p0).Field2.sym.len = 0; (*dest_p0).Field2.sym.p = NIM_NIL;
	(*dest_p0).Field2.caughtExceptions.len = 0; (*dest_p0).Field2.caughtExceptions.p = NIM_NIL;
	(*dest_p0).Field2.caughtExceptionsSet.s.elems = 0;
	(*dest_p0).Field2.caughtExceptionsSet.s.counter = 0;
	(*dest_p0).Field2.caughtExceptionsSet.s.max = 0;
	(*dest_p0).Field2.caughtExceptionsSet.s.head = 0;
	(*dest_p0).Field2.caughtExceptionsSet.s.data.len = 0; (*dest_p0).Field2.caughtExceptionsSet.s.data.p = NIM_NIL;
	nimZeroMem((void*)(*dest_p0).Field2.caughtExceptionsSet.s.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
	(*dest_p0).Field2.caughtExceptionsSet.len = 0;
	(*dest_p0).Field2.isDecl.s.elems = 0;
	(*dest_p0).Field2.isDecl.s.counter = 0;
	(*dest_p0).Field2.isDecl.s.max = 0;
	(*dest_p0).Field2.isDecl.s.head = 0;
	(*dest_p0).Field2.isDecl.s.data.len = 0; (*dest_p0).Field2.isDecl.s.data.p = NIM_NIL;
	nimZeroMem((void*)(*dest_p0).Field2.isDecl.s.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
	(*dest_p0).Field2.isDecl.len = 0;
	(*dest_p0).Field2.isGenericInstance.s.elems = 0;
	(*dest_p0).Field2.isGenericInstance.s.counter = 0;
	(*dest_p0).Field2.isGenericInstance.s.max = 0;
	(*dest_p0).Field2.isGenericInstance.s.head = 0;
	(*dest_p0).Field2.isGenericInstance.s.data.len = 0; (*dest_p0).Field2.isGenericInstance.s.data.p = NIM_NIL;
	nimZeroMem((void*)(*dest_p0).Field2.isGenericInstance.s.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
	(*dest_p0).Field2.isGenericInstance.len = 0;
	(*dest_p0).Field2.fileIndex = 0;
	(*dest_p0).Field2.trackCaughtExceptions = 0;
	(*dest_p0).Field2.isSorted = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ, initTable__modulegraphs_u11598)(NI initialSize_p0) {
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ result;
	NI correctSizeX60gensym132__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ));
	correctSizeX60gensym132__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__suggestsymdb_u1447((&result.data), (correctSizeX60gensym132__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11619)(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ dest_p0) {
	eqdestroy___suggestsymdb_u1866(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12028)(tyObject_Table__w2vCG1OPnHmNolvQVT168g* dest_p0, tyObject_Table__w2vCG1OPnHmNolvQVT168g src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___modulegraphs_u12037((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11741)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* dest_p0) {
	eqdestroy___modulegraphs_u11761((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11738)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__w2vCG1OPnHmNolvQVT168g, initTable__modulegraphs_u11649)(NI initialSize_p0) {
	tyObject_Table__w2vCG1OPnHmNolvQVT168g result;
	NI correctSizeX60gensym134__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__w2vCG1OPnHmNolvQVT168g));
	correctSizeX60gensym134__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u11663((&result.data), (correctSizeX60gensym134__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12019)(tyObject_Table__w2vCG1OPnHmNolvQVT168g dest_p0) {
	eqdestroy___modulegraphs_u12037(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12246)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* dest_p0, tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___modulegraphs_u12255((*dest_p0).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12185)(tyTuple__OtlgAx3kBps9cOSMNDZSzBA* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field2);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0).Field2)));
		nimRawDispose((*dest_p0).Field2, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u12182)(tyTuple__OtlgAx3kBps9cOSMNDZSzBA* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ, initTable__modulegraphs_u12093)(NI initialSize_p0) {
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ result;
	NI correctSizeX60gensym136__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ));
	correctSizeX60gensym136__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u12107((&result.data), (correctSizeX60gensym136__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12237)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ dest_p0) {
	eqdestroy___modulegraphs_u12255(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12457)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* dest_p0, tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___modulegraphs_u12466((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12402)(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u12399)(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw, initTable__modulegraphs_u12310)(NI initialSize_p0) {
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw result;
	NI correctSizeX60gensym138__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw));
	correctSizeX60gensym138__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u12324((&result.data), (correctSizeX60gensym138__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12448)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw dest_p0) {
	eqdestroy___modulegraphs_u12466(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12780)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* dest_p0, tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___modulegraphs_u12789((*dest_p0).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12612)(tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field2.root);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u12632((&(*(*dest_p0).Field2.root)));
		nimRawDispose((*dest_p0).Field2.root, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u12609)(tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2.root = 0;
	(*dest_p0).Field2.entries = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ, initTable__modulegraphs_u12520)(NI initialSize_p0) {
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ result;
	NI correctSizeX60gensym140__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ));
	correctSizeX60gensym140__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u12534((&result.data), (correctSizeX60gensym140__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12771)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ dest_p0) {
	eqdestroy___modulegraphs_u12789(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12996)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* dest_p0, tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___modulegraphs_u13005((*dest_p0).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12936)(tyTuple__XrHNJHOzS3O7uwF9bvCySiA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field2);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*(*dest_p0).Field2)));
		nimRawDispose((*dest_p0).Field2, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u12933)(tyTuple__XrHNJHOzS3O7uwF9bvCySiA* dest_p0) {
	(*dest_p0).Field0 = 0;
	nimZeroMem((void*)(*dest_p0).Field1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	(*dest_p0).Field2 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw, initTable__modulegraphs_u12844)(NI initialSize_p0) {
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw result;
	NI correctSizeX60gensym142__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw));
	correctSizeX60gensym142__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u12858((&result.data), (correctSizeX60gensym142__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12987)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw dest_p0) {
	eqdestroy___modulegraphs_u13005(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u13163)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* dest_p0, tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___modulegraphs_u13172((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg, initTable__modulegraphs_u13060)(NI initialSize_p0) {
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg result;
	NI correctSizeX60gensym144__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg));
	correctSizeX60gensym144__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u13074((&result.data), (correctSizeX60gensym144__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13154)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg dest_p0) {
	eqdestroy___modulegraphs_u13172(dest_p0.data);
}
static N_INLINE(NI, hash__idents_u363)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* x_p0) {
	NI result;
	result = (*x_p0).h;
	return result;
}
static N_INLINE(NIM_BOOL, eqeq___idents_u366)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* a_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* b_p1) {
	NIM_BOOL result;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (a_p0 == 0);
		if (T3_) goto LA4_;
		T3_ = (b_p1 == 0);
LA4_: ;
		if (!T3_) goto LA5_;
		result = (a_p0 == b_p1);
	}
	goto LA1_;
LA5_: ;
	{
		result = ((*a_p0).id == (*b_p1).id);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__ast_u4301)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1) {
	NI result;
	NI h_1;
	NI T6_;
	NI T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NI)0;
	T6_ = hash__idents_u363(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = ((*t_p0).data.len-1);
	h_1 = (NI)(T6_ & T7_);
	{
		while (1) {
			NI T15_;
			if (!!(((*t_p0).data.p->data[h_1].Field1 == ((NI)0)))) goto LA9;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = eqeq___idents_u366((*t_p0).data.p->data[h_1].Field0, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T12_) goto LA13_;
				result = h_1;
				goto BeforeRet_;
			}
LA13_: ;
			T15_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T15_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA9: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__ast_u4282)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, NI def_p2) {
	NI result;
	NI indexX60gensym214__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	indexX60gensym214__1 = rawGet__ast_u4301(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	{
		if (!(((NI)0) <= indexX60gensym214__1)) goto LA4_;
		result = (*t_p0).data.p->data[indexX60gensym214__1].Field1;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u2968)(tyTuple__Oubp8LPEu86EPyDuc56AXg* dest_p0, tyTuple__Oubp8LPEu86EPyDuc56AXg src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T3_) goto LA4_;
		eqdestroy___idents_u173((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)8));
	}
LA4_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	(*dest_p0).Field1 = src_p1.Field1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u2956)(tyTuple__Oubp8LPEu86EPyDuc56AXg* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u2959)(tyTuple__Oubp8LPEu86EPyDuc56AXg dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___idents_u173((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(NIM_BOOL, mustRehash__ast_u4425)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ctRawInsert__ast_u4496)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0, tySequence__hRbbzIynOoxrYjHTIKZ3Gw* data_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p2, NI val_p3) {
	NI h_1;
	NI T1_;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI)0;
	T1_ = hash__idents_u363(key_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = ((*data_p1).len-1);
	h_1 = (NI)(T1_ & T2_);
	{
		while (1) {
			NI T5_;
			if (!!(((*data_p1).p->data[h_1].Field1 == ((NI)0)))) goto LA4;
			T5_ = ((*data_p1).len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA4: ;
	}
	eqcopy___idents_u158(&(*data_p1).p->data[h_1].Field0, key_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_1].Field1 = val_p3;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__ast_u4459)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0) {
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw n_1;
	NI T1_;
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__ast_u2881((&n_1), ((NI)(T1_ * ((NI)2))));
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((*t_p0).data.len-1);
		colontmp_ = T3_;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA5;
				i_1 = ((NI) (res_1));
				{
					tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
					NI T10_;
					if (!!(((*t_p0).data.p->data[i_1].Field1 == ((NI)0)))) goto LA8_;
					colontmpD_ = NIM_NIL;
					colontmpD_ = (*t_p0).data.p->data[i_1].Field0;
					eqwasMoved___idents_u152((&(*t_p0).data.p->data[i_1].Field0));
					T10_ = (NI)0;
					T10_ = (*t_p0).data.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&(*t_p0).data.p->data[i_1].Field1));
					ctRawInsert__ast_u4496((&(*t_p0)), (&n_1), colontmpD_, T10_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___idents_u155(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA8_: ;
				res_1 += ((NI)1);
			} LA5: ;
		}
	}
	T11_.len = 0; T11_.p = NIM_NIL;
	T11_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T11_;
	eqdestroy___ast_u3027(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, inc__ast_u4349)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, NI val_p2) {
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	index_1 = rawGet__ast_u4301((&(*t_p0)), key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA3_;
		(*t_p0).data.p->data[index_1].Field1 += val_p2;
		{
			NI mskX60gensym195__1;
			NI T9_;
			if (!((*t_p0).data.p->data[index_1].Field1 == ((NI)0))) goto LA7_;
			T9_ = ((*t_p0).data.len-1);
			mskX60gensym195__1 = T9_;
			{
				if (!(((NI)0) <= index_1)) goto LA12_;
				(*t_p0).counter -= ((NI)1);
				{
					{
						while (1) {
							NI jX60gensym195__1;
							NI rX60gensym195__1;
							tyTuple__Oubp8LPEu86EPyDuc56AXg T38_;
							jX60gensym195__1 = index_1;
							rX60gensym195__1 = jX60gensym195__1;
							(*t_p0).data.p->data[index_1].Field1 = ((NI)0);
							reset__ast_u4392(&(*t_p0).data.p->data[index_1].Field0);
							reset__ast_u2522((&(*t_p0).data.p->data[index_1].Field1));
							{
								while (1) {
									NI T23_;
									index_1 = (NI)((NI)(index_1 + ((NI)1)) & mskX60gensym195__1);
									{
										if (!((*t_p0).data.p->data[index_1].Field1 == ((NI)0))) goto LA21_;
										goto LA14;
									}
LA21_: ;
									T23_ = (NI)0;
									T23_ = hash__idents_u363((*t_p0).data.p->data[index_1].Field0);
									if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
									rX60gensym195__1 = (NI)(T23_ & mskX60gensym195__1);
									{
										NIM_BOOL T26_;
										NIM_BOOL T27_;
										NIM_BOOL T28_;
										NIM_BOOL T31_;
										NIM_BOOL T34_;
										T26_ = (NIM_BOOL)0;
										T27_ = (NIM_BOOL)0;
										T28_ = (NIM_BOOL)0;
										T28_ = (rX60gensym195__1 <= index_1);
										if (!(T28_)) goto LA29_;
										T28_ = (jX60gensym195__1 < rX60gensym195__1);
LA29_: ;
										T27_ = T28_;
										if (T27_) goto LA30_;
										T31_ = (NIM_BOOL)0;
										T31_ = (jX60gensym195__1 < rX60gensym195__1);
										if (!(T31_)) goto LA32_;
										T31_ = (index_1 < jX60gensym195__1);
LA32_: ;
										T27_ = T31_;
LA30_: ;
										T26_ = T27_;
										if (T26_) goto LA33_;
										T34_ = (NIM_BOOL)0;
										T34_ = (index_1 < jX60gensym195__1);
										if (!(T34_)) goto LA35_;
										T34_ = (rX60gensym195__1 <= index_1);
LA35_: ;
										T26_ = T34_;
LA33_: ;
										if (!!(T26_)) goto LA36_;
										goto LA17;
									}
LA36_: ;
								}
							} LA17: ;
							nimZeroMem((void*)(&T38_), sizeof(tyTuple__Oubp8LPEu86EPyDuc56AXg));
							T38_.Field0 = (*t_p0).data.p->data[index_1].Field0;
							T38_.Field1 = (*t_p0).data.p->data[index_1].Field1;
							eqwasMoved___ast_u2956((&(*t_p0).data.p->data[index_1]));
							eqsink___ast_u2968((&(*t_p0).data.p->data[jX60gensym195__1]), T38_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						}
					}
				} LA14: ;
			}
LA12_: ;
		}
LA7_: ;
	}
	goto LA1_;
LA3_: ;
	{
		{
			tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ T54_;
			if (!!((val_p2 == ((NI)0)))) goto LA42_;
			{
				NI T46_;
				NI correctSizeX60gensym92__1;
				T46_ = (*t_p0).data.len;
				if (!(T46_ == ((NI)0))) goto LA47_;
				correctSizeX60gensym92__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				(*t_p0).counter = ((NI)0);
				newSeq__ast_u2881((&(*t_p0).data), (correctSizeX60gensym92__1));
			}
LA47_: ;
			{
				NIM_BOOL T51_;
				T51_ = (NIM_BOOL)0;
				T51_ = mustRehash__ast_u4425((&(*t_p0)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T51_) goto LA52_;
				enlarge__ast_u4459(t_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA52_: ;
			T54_ = (*t_p0);
			ctRawInsert__ast_u4496((&T54_), (&(*t_p0).data), key_p1, val_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter += ((NI)1);
		}
LA42_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___lineinfos_u557)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* dest_p0, tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___lineinfos_u566((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u1200)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u1197)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NIM_BOOL, mustRehash__ast_u1551)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__ast_u1976)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0, tySequence__7s5HyddQ0f9bxMNILHrXwJQ* data_p1, NI key_p2, NimStringV2 val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___system_u2700((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u1135)(tySequence__7s5HyddQ0f9bxMNILHrXwJQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g));
}
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__ast_u1692)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0) {
	tySequence__7s5HyddQ0f9bxMNILHrXwJQ n_1;
	NI T1_;
	tySequence__7s5HyddQ0f9bxMNILHrXwJQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__ast_u1429((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__r6SySATn9aFiGJCuriaCXGg* T17_;
					NI T18_;
					NimStringV2 T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__r6SySATn9aFiGJCuriaCXGg*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field2));
					rawInsert__ast_u1976(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___ast_u1135(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__ast_u2133)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___ast_u1378)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0, NI key_p1, NimStringV2 val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym8__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym8__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__ast_u1429((&(*t_p0).data), (correctSizeX60gensym8__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__ast_u900((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___system_u2700((&(*t_p0).data.p->data[index_1].Field2), val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__r6SySATn9aFiGJCuriaCXGg* T21_;
		NimStringV2 blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym11__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym11__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__ast_u1429((&(*t_p0).data), (correctSizeX60gensym11__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__ast_u1551((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__ast_u1692(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__ast_u2133((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__r6SySATn9aFiGJCuriaCXGg*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__ast_u1976(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__pureZcollectionsZtables_u29)(NI hcode_p0) {
	NIM_BOOL result;
	result = (hcode_p0 == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u1209)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* dest_p0, tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* src_p1) {
	(*dest_p0).Field0 = (*src_p1).Field0;
	(*dest_p0).Field1 = (*src_p1).Field1;
	if ((*dest_p0).Field2.p != (*src_p1).Field2.p) {	eqdestroy___system_u2691((*dest_p0).Field2);
	}
(*dest_p0).Field2.len = (*src_p1).Field2.len; (*dest_p0).Field2.p = (*src_p1).Field2.p;
}
N_LIB_PRIVATE N_NIMCALL(void, del__ast_u2399)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0, NI key_p1) {
	NI hc_1;
	NI i_1;
	NI mskX60gensym44__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	hc_1 = (NI)0;
	i_1 = rawGet__ast_u900((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = ((*t_p0).data.len-1);
	mskX60gensym44__1 = T1_;
	{
		if (!(((NI)0) <= i_1)) goto LA4_;
		(*t_p0).counter -= ((NI)1);
		{
			{
				while (1) {
					NI jX60gensym44__1;
					NI rX60gensym44__1;
					tyTuple__kuMQ1fbjJlHtwKTmBGAe6g T30_;
					jX60gensym44__1 = i_1;
					rX60gensym44__1 = jX60gensym44__1;
					(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
					reset__ast_u2522((&(*t_p0).data.p->data[i_1].Field1));
					reset__system_u5461((&(*t_p0).data.p->data[i_1].Field2));
					{
						while (1) {
							i_1 = (NI)((NI)(i_1 + ((NI)1)) & mskX60gensym44__1);
							{
								NIM_BOOL T13_;
								T13_ = (NIM_BOOL)0;
								T13_ = isEmpty__pureZcollectionsZtables_u29((*t_p0).data.p->data[i_1].Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								if (!T13_) goto LA14_;
								goto LA6;
							}
LA14_: ;
							rX60gensym44__1 = (NI)((*t_p0).data.p->data[i_1].Field0 & mskX60gensym44__1);
							{
								NIM_BOOL T18_;
								NIM_BOOL T19_;
								NIM_BOOL T20_;
								NIM_BOOL T23_;
								NIM_BOOL T26_;
								T18_ = (NIM_BOOL)0;
								T19_ = (NIM_BOOL)0;
								T20_ = (NIM_BOOL)0;
								T20_ = (rX60gensym44__1 <= i_1);
								if (!(T20_)) goto LA21_;
								T20_ = (jX60gensym44__1 < rX60gensym44__1);
LA21_: ;
								T19_ = T20_;
								if (T19_) goto LA22_;
								T23_ = (NIM_BOOL)0;
								T23_ = (jX60gensym44__1 < rX60gensym44__1);
								if (!(T23_)) goto LA24_;
								T23_ = (i_1 < jX60gensym44__1);
LA24_: ;
								T19_ = T23_;
LA22_: ;
								T18_ = T19_;
								if (T18_) goto LA25_;
								T26_ = (NIM_BOOL)0;
								T26_ = (i_1 < jX60gensym44__1);
								if (!(T26_)) goto LA27_;
								T26_ = (rX60gensym44__1 <= i_1);
LA27_: ;
								T18_ = T26_;
LA25_: ;
								if (!!(T18_)) goto LA28_;
								goto LA9;
							}
LA28_: ;
						}
					} LA9: ;
					T30_ = (*t_p0).data.p->data[i_1];
					eqwasMoved___ast_u1197((&(*t_p0).data.p->data[i_1]));
					eqsink___ast_u1209((&(*t_p0).data.p->data[jX60gensym44__1]), (&T30_));
				}
			}
		} LA6: ;
	}
LA4_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, hash__ast_u624)(NI32 x_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = hashWangYi1__pureZhashes_u140(((NU64) (x_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__modulegraphs_u15020)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__modulegraphs_u15331)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__modulegraphs_u15824)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* t_p0, tySequence__kxu4GK0onha2t9bo86mdVAg* data_p1, NI32 key_p2, NI32 val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__modulegraphs_u15526)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* t_p0) {
	tySequence__kxu4GK0onha2t9bo86mdVAg n_1;
	NI T1_;
	tySequence__kxu4GK0onha2t9bo86mdVAg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u11447((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* T17_;
					NI32 T18_;
					NI32 T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__AC9bec2JdoOuC3xQePGWgmA*)0;
					T17_ = t_p0;
					T18_ = (NI32)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___stdZoserrors_u34((&n_1.p->data[i_1].Field1));
					T19_ = (NI32)0;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___stdZoserrors_u34((&n_1.p->data[i_1].Field2));
					rawInsert__modulegraphs_u15824(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u11545(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__modulegraphs_u15981)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA t_p0, NI32 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKeyOrPut__modulegraphs_u14941)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* t_p0, NI32 key_p1, NI32 val_p2) {
	NIM_BOOL result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		NI T3_;
		NI correctSizeX60gensym170__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym170__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u11447((&(*t_p0).data), (correctSizeX60gensym170__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__modulegraphs_u15020((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		result = NIM_FALSE;
		{
			NI T12_;
			NI correctSizeX60gensym175__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym175__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u11447((&(*t_p0).data), (correctSizeX60gensym175__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__modulegraphs_u15331((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__modulegraphs_u15526(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__modulegraphs_u15981((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__AC9bec2JdoOuC3xQePGWgmA*)0;
		T20_ = t_p0;
		rawInsert__modulegraphs_u15824(T20_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
	goto LA6_;
LA8_: ;
	{
		result = NIM_TRUE;
	}
LA6_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8922)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* dest_p0, tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* src_p1) {
	if ((*dest_p0).data.p != (*src_p1).data.p) {	eqdestroy___icZic_u559((*dest_p0).data);
	}
(*dest_p0).data.len = (*src_p1).data.len; (*dest_p0).data.p = (*src_p1).data.p;
	(*dest_p0).counter = (*src_p1).counter;
	(*dest_p0).first = (*src_p1).first;
	(*dest_p0).last = (*src_p1).last;
}
N_LIB_PRIVATE N_NIMCALL(void, initOrderedTable__icZic_u8892)(NI initialSize_p0, tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* Result) {
	NI correctSizeX60gensym214__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw));
	correctSizeX60gensym214__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).counter = ((NI)0);
	newSeq__icZic_u5847((&(*Result).data), (correctSizeX60gensym214__1));
	(*Result).first = ((NI)-1);
	(*Result).last = ((NI)-1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__icZic_u5872)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__icZic_u6213)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u6848)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, tySequence__Vl1abU3gfp0RqCb1KKfmDA* data_p1, NI32 key_p2, tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field2 = key_p2;
	(*data_p1).p->data[h_p5].Field3 = (*val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	(*data_p1).p->data[h_p5].Field1 = ((NI)-1);
	{
		if (!((*t_p0).first < ((NI)0))) goto LA3_;
		(*t_p0).first = h_p5;
	}
LA3_: ;
	{
		if (!(((NI)0) <= (*t_p0).last)) goto LA7_;
		(*data_p1).p->data[(*t_p0).last].Field1 = h_p5;
	}
LA7_: ;
	(*t_p0).last = h_p5;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u6386)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0) {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA n_1;
	NI T1_;
	NI h_1;
	tySequence__Vl1abU3gfp0RqCb1KKfmDA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__icZic_u5847((&n_1), ((NI)(T1_ * ((NI)2))));
	h_1 = (*t_p0).first;
	(*t_p0).first = ((NI)-1);
	(*t_p0).last = ((NI)-1);
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		while (1) {
			NI nxt_1;
			NI eh_1;
			if (!(((NI)0) <= h_1)) goto LA4;
			nxt_1 = n_1.p->data[h_1].Field1;
			eh_1 = n_1.p->data[h_1].Field0;
			{
				NIM_BOOL T7_;
				NI j_1;
				NI T10_;
				tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* T15_;
				NI32 T16_;
				tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw T17_;
				T7_ = (NIM_BOOL)0;
				T7_ = isFilled__pureZcollectionsZtables_u32(eh_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T7_) goto LA8_;
				T10_ = ((*t_p0).data.len-1);
				j_1 = (NI)(eh_1 & T10_);
				{
					while (1) {
						NIM_BOOL T13_;
						NI T14_;
						T13_ = (NIM_BOOL)0;
						T13_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T13_) goto LA12;
						T14_ = ((*t_p0).data.len-1);
						j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T14_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					} LA12: ;
				}
				T15_ = (tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw*)0;
				T15_ = t_p0;
				T16_ = (NI32)0;
				T16_ = n_1.p->data[h_1].Field2;
				eqwasMoved___stdZoserrors_u34((&n_1.p->data[h_1].Field2));
				T17_ = n_1.p->data[h_1].Field3;
				eqwasMoved___icZic_u6748((&n_1.p->data[h_1].Field3));
				rawInsert__icZic_u6848(T15_, (&(*t_p0).data), T16_, (&T17_), n_1.p->data[h_1].Field0, j_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA8_: ;
			h_1 = nxt_1;
		} LA4: ;
	}
	eqdestroy___icZic_u559(n_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__icZic_u7130)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = ((*t_p0).data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*t_p0).data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZic_u5788)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1, tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym153__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym153__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__icZic_u5847((&(*t_p0).data), (correctSizeX60gensym153__1));
		(*t_p0).first = ((NI)-1);
		(*t_p0).last = ((NI)-1);
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__icZic_u5872((&(*t_p0)), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field3 = (*val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym158__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym158__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__icZic_u5847((&(*t_p0).data), (correctSizeX60gensym158__1));
			(*t_p0).first = ((NI)-1);
			(*t_p0).last = ((NI)-1);
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__icZic_u6213((&(*t_p0)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__icZic_u6386(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__icZic_u7130((&(*t_p0)), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw*)0;
		T21_ = t_p0;
		rawInsert__icZic_u6848(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u9084)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* dest_p0, tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* src_p1) {
	if ((*dest_p0).data.p != (*src_p1).data.p) {	eqdestroy___icZic_u4339((*dest_p0).data);
	}
(*dest_p0).data.len = (*src_p1).data.len; (*dest_p0).data.p = (*src_p1).data.p;
	(*dest_p0).counter = (*src_p1).counter;
	(*dest_p0).first = (*src_p1).first;
	(*dest_p0).last = (*src_p1).last;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u3916)(tyTuple__anemVmHCFglLFt6LiEhFvg* dest_p0) {
	eqdestroy___icZic_u3941((*dest_p0).Field3.types);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u3913)(tyTuple__anemVmHCFglLFt6LiEhFvg* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2 = 0;
	(*dest_p0).Field3.id = 0;
	(*dest_p0).Field3.kind = 0;
	(*dest_p0).Field3.callConv = 0;
	nimZeroMem((void*)(&(*dest_p0).Field3.flags), sizeof(tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A));
	(*dest_p0).Field3.types.len = 0; (*dest_p0).Field3.types.p = NIM_NIL;
	(*dest_p0).Field3.n = 0;
	(*dest_p0).Field3.sym.module = 0;
	(*dest_p0).Field3.sym.item = 0;
	(*dest_p0).Field3.owner.module = 0;
	(*dest_p0).Field3.owner.item = 0;
	(*dest_p0).Field3.size = 0;
	(*dest_p0).Field3.align = 0;
	(*dest_p0).Field3.paddingAtEnd = 0;
	(*dest_p0).Field3.typeInst.module = 0;
	(*dest_p0).Field3.typeInst.item = 0;
	(*dest_p0).Field3.nonUniqueId = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, initOrderedTable__icZic_u9054)(NI initialSize_p0, tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* Result) {
	NI correctSizeX60gensym217__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw));
	correctSizeX60gensym217__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).counter = ((NI)0);
	newSeq__icZic_u3839((&(*Result).data), (correctSizeX60gensym217__1));
	(*Result).first = ((NI)-1);
	(*Result).last = ((NI)-1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__icZic_u4085)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__icZic_u4487)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u5114)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, tySequence__qyyNkmlc4fzOzelC8spUkQ* data_p1, NI32 key_p2, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field2 = key_p2;
	eqsink___icZic_u5038((&(*data_p1).p->data[h_p5].Field3), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	(*data_p1).p->data[h_p5].Field1 = ((NI)-1);
	{
		if (!((*t_p0).first < ((NI)0))) goto LA3_;
		(*t_p0).first = h_p5;
	}
LA3_: ;
	{
		if (!(((NI)0) <= (*t_p0).last)) goto LA7_;
		(*data_p1).p->data[(*t_p0).last].Field1 = h_p5;
	}
LA7_: ;
	(*t_p0).last = h_p5;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u4660)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0) {
	tySequence__qyyNkmlc4fzOzelC8spUkQ n_1;
	NI T1_;
	NI h_1;
	tySequence__qyyNkmlc4fzOzelC8spUkQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__icZic_u3839((&n_1), ((NI)(T1_ * ((NI)2))));
	h_1 = (*t_p0).first;
	(*t_p0).first = ((NI)-1);
	(*t_p0).last = ((NI)-1);
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		while (1) {
			NI nxt_1;
			NI eh_1;
			if (!(((NI)0) <= h_1)) goto LA4;
			nxt_1 = n_1.p->data[h_1].Field1;
			eh_1 = n_1.p->data[h_1].Field0;
			{
				NIM_BOOL T7_;
				NI j_1;
				NI T10_;
				tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* T15_;
				NI32 T16_;
				tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ T17_;
				T7_ = (NIM_BOOL)0;
				T7_ = isFilled__pureZcollectionsZtables_u32(eh_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T7_) goto LA8_;
				T10_ = ((*t_p0).data.len-1);
				j_1 = (NI)(eh_1 & T10_);
				{
					while (1) {
						NIM_BOOL T13_;
						NI T14_;
						T13_ = (NIM_BOOL)0;
						T13_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T13_) goto LA12;
						T14_ = ((*t_p0).data.len-1);
						j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T14_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					} LA12: ;
				}
				T15_ = (tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw*)0;
				T15_ = t_p0;
				T16_ = (NI32)0;
				T16_ = n_1.p->data[h_1].Field2;
				eqwasMoved___stdZoserrors_u34((&n_1.p->data[h_1].Field2));
				T17_ = n_1.p->data[h_1].Field3;
				eqwasMoved___icZic_u5026((&n_1.p->data[h_1].Field3));
				rawInsert__icZic_u5114(T15_, (&(*t_p0).data), T16_, (&T17_), n_1.p->data[h_1].Field0, j_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA8_: ;
			h_1 = nxt_1;
		} LA4: ;
	}
	eqdestroy___icZic_u4339(n_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__icZic_u5396)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = ((*t_p0).data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*t_p0).data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZic_u3779)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1, tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym126__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym126__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__icZic_u3839((&(*t_p0).data), (correctSizeX60gensym126__1));
		(*t_p0).first = ((NI)-1);
		(*t_p0).last = ((NI)-1);
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__icZic_u4085((&(*t_p0)), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___icZic_u5038((&(*t_p0).data.p->data[index_1].Field3), val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* T21_;
		tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym131__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym131__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__icZic_u3839((&(*t_p0).data), (correctSizeX60gensym131__1));
			(*t_p0).first = ((NI)-1);
			(*t_p0).last = ((NI)-1);
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__icZic_u4487((&(*t_p0)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__icZic_u4660(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__icZic_u5396((&(*t_p0)), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw*)0;
		T21_ = t_p0;
		nimZeroMem((void*)(&blitTmp_1), sizeof(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ));
		blitTmp_1 = (*val_p2);
		rawInsert__icZic_u5114(T21_, (&(*t_p0).data), key_p1, (&blitTmp_1), hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u18956)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* dest_p0, tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___icZic_u13380((*dest_p0).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13447)(tyTuple__MZVSn3SE3XUBJOaMu7ofRQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field1);
		if (!T3_) goto LA4_;
		eqdestroy___idents_u173((&(*(*dest_p0).Field1)));
		nimRawDispose((*dest_p0).Field1, ((NI)8));
	}
LA4_: ;
	eqdestroy___icZic_u3941((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u13444)(tyTuple__MZVSn3SE3XUBJOaMu7ofRQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg, initTable__icZic_u18918)(NI initialSize_p0) {
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg result;
	NI correctSizeX60gensym424__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg));
	correctSizeX60gensym424__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__icZic_u18932((&result.data), (correctSizeX60gensym424__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u18947)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg dest_p0) {
	eqdestroy___icZic_u13380(dest_p0.data);
}
static N_INLINE(NI, rawGet__icZic_u19193)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__idents_u363(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___idents_u366(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__icZic_u19500)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u19973)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* t_p0, tySequence__FmsTQiIcS9arxHxs3QY48vA* data_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p2, tySequence__qBes3XzcQQ9cyia9bRwnmbJw val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___idents_u158(&(*data_p1).p->data[h_p5].Field1, key_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___icZic_u3950((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u19665)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* t_p0) {
	tySequence__FmsTQiIcS9arxHxs3QY48vA n_1;
	NI T1_;
	tySequence__FmsTQiIcS9arxHxs3QY48vA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__icZic_u18932((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* T17_;
					tySequence__qBes3XzcQQ9cyia9bRwnmbJw T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_ = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___idents_u152((&n_1.p->data[i_1].Field1));
					T18_.len = 0; T18_.p = NIM_NIL;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___icZic_u3938((&n_1.p->data[i_1].Field2));
					rawInsert__icZic_u19973(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___idents_u155(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___icZic_u13380(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__icZic_u20142)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___idents_u366(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qBes3XzcQQ9cyia9bRwnmbJw*, mgetOrPut__icZic_u19124)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, tySequence__qBes3XzcQQ9cyia9bRwnmbJw val_p2) {
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__qBes3XzcQQ9cyia9bRwnmbJw*)0;
	{
		NI T3_;
		NI correctSizeX60gensym430__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym430__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__icZic_u18932((&(*t_p0).data), (correctSizeX60gensym430__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__icZic_u19193((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__qBes3XzcQQ9cyia9bRwnmbJw colontmpD_;
		tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym435__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym435__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__icZic_u18932((&(*t_p0).data), (correctSizeX60gensym435__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__icZic_u19500((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__icZic_u19665(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__icZic_u20142((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___icZic_u3947(val_p2);
		rawInsert__icZic_u19973(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__ast_u2869)(NI initialSize_p0, tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* Result) {
	NI correctSizeX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ));
	correctSizeX60gensym22__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).counter = ((NI)0);
	newSeq__ast_u2881((&(*Result).data), (correctSizeX60gensym22__1));
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__icZic_u16418)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getOrDefault__icZic_u16405)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	NI hcX60gensym387__1;
	NI indexX60gensym387__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym387__1 = (NI)0;
	indexX60gensym387__1 = rawGet__icZic_u16418(t_p0, key_p1, (&hcX60gensym387__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym387__1)) goto LA3_;
		eqcopy___ast_u3381(&result, (*t_p0).data.p->data[indexX60gensym387__1].Field3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__icZic_u16788)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__icZic_u711)(NI32 key_p0) {
	NimStringV2 colontmpD_;
	tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q* T2_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q*) nimNewObj(sizeof(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q), NIM_ALIGNOF(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q));
	(*T2_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__jzGRfzBmxnPANjp71FNw5Q_);
	(*T2_).Sup.Sup.Sup.name = "KeyError";
	T3_.len = 0; T3_.p = NIM_NIL;
	colontmpD_ = dollar___systemZdollars_u24(key_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = rawNewString(colontmpD_.len + 15);
appendString((&T3_), TM__4SoG2KRQy3oMm9aUzSLtGrA_5);
appendString((&T3_), colontmpD_);
	(*T2_).Sup.Sup.Sup.message = T3_;
	(*T2_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T2_, "KeyError", "raiseKeyError", "tables.nim", 232);
goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ*, X5BX5D___icZic_u16781)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1) {
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* result;
	NI hcX60gensym97__1;
	NI indexX60gensym97__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ*)0;
	hcX60gensym97__1 = (NI)0;
	indexX60gensym97__1 = rawGet__icZic_u16788((&(*t_p0)), key_p1, (&hcX60gensym97__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym97__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym97__1].Field3);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__icZic_u711(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13283)(tyTuple__1xWeGeoNoZxaLhTUDDWYyA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field3);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*(*dest_p0).Field3)));
		nimRawDispose((*dest_p0).Field3, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u13280)(tyTuple__1xWeGeoNoZxaLhTUDDWYyA* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2 = 0;
	(*dest_p0).Field3 = 0;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__icZic_u17214)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__icZic_u17555)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u18139)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, tySequence__UE4b6iUkm1b3zTPamTTkDw* data_p1, NI32 key_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field2 = key_p2;
	eqsink___ast_u3387(&(*data_p1).p->data[h_p5].Field3, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	(*data_p1).p->data[h_p5].Field1 = ((NI)-1);
	{
		if (!((*t_p0).first < ((NI)0))) goto LA3_;
		(*t_p0).first = h_p5;
	}
LA3_: ;
	{
		if (!(((NI)0) <= (*t_p0).last)) goto LA7_;
		(*data_p1).p->data[(*t_p0).last].Field1 = h_p5;
	}
LA7_: ;
	(*t_p0).last = h_p5;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u17728)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0) {
	tySequence__UE4b6iUkm1b3zTPamTTkDw n_1;
	NI T1_;
	NI h_1;
	tySequence__UE4b6iUkm1b3zTPamTTkDw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__icZic_u17189((&n_1), ((NI)(T1_ * ((NI)2))));
	h_1 = (*t_p0).first;
	(*t_p0).first = ((NI)-1);
	(*t_p0).last = ((NI)-1);
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		while (1) {
			NI nxt_1;
			NI eh_1;
			if (!(((NI)0) <= h_1)) goto LA4;
			nxt_1 = n_1.p->data[h_1].Field1;
			eh_1 = n_1.p->data[h_1].Field0;
			{
				NIM_BOOL T7_;
				NI j_1;
				NI T10_;
				tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* T15_;
				NI32 T16_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T17_;
				T7_ = (NIM_BOOL)0;
				T7_ = isFilled__pureZcollectionsZtables_u32(eh_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T7_) goto LA8_;
				T10_ = ((*t_p0).data.len-1);
				j_1 = (NI)(eh_1 & T10_);
				{
					while (1) {
						NIM_BOOL T13_;
						NI T14_;
						T13_ = (NIM_BOOL)0;
						T13_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T13_) goto LA12;
						T14_ = ((*t_p0).data.len-1);
						j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T14_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					} LA12: ;
				}
				T15_ = (tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ*)0;
				T15_ = t_p0;
				T16_ = (NI32)0;
				T16_ = n_1.p->data[h_1].Field2;
				eqwasMoved___stdZoserrors_u34((&n_1.p->data[h_1].Field2));
				T17_ = NIM_NIL;
				T17_ = n_1.p->data[h_1].Field3;
				eqwasMoved___ast_u3375((&n_1.p->data[h_1].Field3));
				rawInsert__icZic_u18139(T15_, (&(*t_p0).data), T16_, T17_, n_1.p->data[h_1].Field0, j_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA8_: ;
			h_1 = nxt_1;
		} LA4: ;
	}
	eqdestroy___icZic_u13216(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__icZic_u18421)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = ((*t_p0).data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*t_p0).data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZic_u17130)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym396__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym396__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__icZic_u17189((&(*t_p0).data), (correctSizeX60gensym396__1));
		(*t_p0).first = ((NI)-1);
		(*t_p0).last = ((NI)-1);
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__icZic_u17214((&(*t_p0)), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___ast_u3387(&(*t_p0).data.p->data[index_1].Field3, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* T21_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym401__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym401__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__icZic_u17189((&(*t_p0).data), (correctSizeX60gensym401__1));
			(*t_p0).first = ((NI)-1);
			(*t_p0).last = ((NI)-1);
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__icZic_u17555((&(*t_p0)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__icZic_u17728(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__icZic_u18421((&(*t_p0)), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__icZic_u18139(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__icZic_u13749)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getOrDefault__icZic_u13736)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NI hcX60gensym345__1;
	NI indexX60gensym345__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym345__1 = (NI)0;
	indexX60gensym345__1 = rawGet__icZic_u13749(t_p0, key_p1, (&hcX60gensym345__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym345__1)) goto LA3_;
		eqcopy___ast_u4577(&result, (*t_p0).data.p->data[indexX60gensym345__1].Field3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__icZic_u307)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw*, X5BX5D___icZic_u14112)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1) {
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* result;
	NI hcX60gensym97__1;
	NI indexX60gensym97__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw*)0;
	hcX60gensym97__1 = (NI)0;
	indexX60gensym97__1 = rawGet__icZic_u307((&(*t_p0)), key_p1, (&hcX60gensym97__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym97__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym97__1].Field3);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__icZic_u711(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13121)(tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field3);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).Field3)));
		nimRawDispose((*dest_p0).Field3, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u13118)(tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2 = 0;
	(*dest_p0).Field3 = 0;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__icZic_u14383)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__icZic_u14724)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u15308)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, tySequence__K0j67V58u5FW0dCC534FQw* data_p1, NI32 key_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field2 = key_p2;
	eqsink___ast_u4583(&(*data_p1).p->data[h_p5].Field3, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	(*data_p1).p->data[h_p5].Field1 = ((NI)-1);
	{
		if (!((*t_p0).first < ((NI)0))) goto LA3_;
		(*t_p0).first = h_p5;
	}
LA3_: ;
	{
		if (!(((NI)0) <= (*t_p0).last)) goto LA7_;
		(*data_p1).p->data[(*t_p0).last].Field1 = h_p5;
	}
LA7_: ;
	(*t_p0).last = h_p5;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u14897)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0) {
	tySequence__K0j67V58u5FW0dCC534FQw n_1;
	NI T1_;
	NI h_1;
	tySequence__K0j67V58u5FW0dCC534FQw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__icZic_u14358((&n_1), ((NI)(T1_ * ((NI)2))));
	h_1 = (*t_p0).first;
	(*t_p0).first = ((NI)-1);
	(*t_p0).last = ((NI)-1);
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		while (1) {
			NI nxt_1;
			NI eh_1;
			if (!(((NI)0) <= h_1)) goto LA4;
			nxt_1 = n_1.p->data[h_1].Field1;
			eh_1 = n_1.p->data[h_1].Field0;
			{
				NIM_BOOL T7_;
				NI j_1;
				NI T10_;
				tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* T15_;
				NI32 T16_;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T17_;
				T7_ = (NIM_BOOL)0;
				T7_ = isFilled__pureZcollectionsZtables_u32(eh_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T7_) goto LA8_;
				T10_ = ((*t_p0).data.len-1);
				j_1 = (NI)(eh_1 & T10_);
				{
					while (1) {
						NIM_BOOL T13_;
						NI T14_;
						T13_ = (NIM_BOOL)0;
						T13_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T13_) goto LA12;
						T14_ = ((*t_p0).data.len-1);
						j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T14_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					} LA12: ;
				}
				T15_ = (tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ*)0;
				T15_ = t_p0;
				T16_ = (NI32)0;
				T16_ = n_1.p->data[h_1].Field2;
				eqwasMoved___stdZoserrors_u34((&n_1.p->data[h_1].Field2));
				T17_ = NIM_NIL;
				T17_ = n_1.p->data[h_1].Field3;
				eqwasMoved___ast_u4571((&n_1.p->data[h_1].Field3));
				rawInsert__icZic_u15308(T15_, (&(*t_p0).data), T16_, T17_, n_1.p->data[h_1].Field0, j_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA8_: ;
			h_1 = nxt_1;
		} LA4: ;
	}
	eqdestroy___icZic_u13054(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__icZic_u15590)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = ((*t_p0).data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*t_p0).data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = ((*t_p0).data.p->data[h_1].Field2 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZic_u14299)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym354__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym354__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__icZic_u14358((&(*t_p0).data), (correctSizeX60gensym354__1));
		(*t_p0).first = ((NI)-1);
		(*t_p0).last = ((NI)-1);
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__icZic_u14383((&(*t_p0)), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___ast_u4583(&(*t_p0).data.p->data[index_1].Field3, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* T21_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym359__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym359__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__icZic_u14358((&(*t_p0).data), (correctSizeX60gensym359__1));
			(*t_p0).first = ((NI)-1);
			(*t_p0).last = ((NI)-1);
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__icZic_u14724((&(*t_p0)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__icZic_u14897(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__icZic_u15590((&(*t_p0)), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__icZic_u15308(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**, X5BX5D___icZic_u15999)(tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ* t_p0, NI32 key_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** result;
	NI hcX60gensym97__1;
	NI indexX60gensym97__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
	hcX60gensym97__1 = (NI)0;
	indexX60gensym97__1 = rawGet__icZic_u13749((&(*t_p0)), key_p1, (&hcX60gensym97__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym97__1)) goto LA3_;
		result = &(*t_p0).data.p->data[indexX60gensym97__1].Field3;
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__icZic_u711(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___icZic_u18827)(tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ* t_p0, NI32 key_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** result;
	NI hcX60gensym97__1;
	NI indexX60gensym97__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	hcX60gensym97__1 = (NI)0;
	indexX60gensym97__1 = rawGet__icZic_u16418((&(*t_p0)), key_p1, (&hcX60gensym97__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym97__1)) goto LA3_;
		result = &(*t_p0).data.p->data[indexX60gensym97__1].Field3;
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__icZic_u711(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3898)(tySequence__QqvaCqCpEE1QmQZbcZLi5A dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___pureZosproc_u474(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__EbsafWGli8bW2GRJQ9apsjA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3588)(tySequence__3B6hFqG0Do0FxDvnNucL7w dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___semdata_u3609(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3481)(tySequence__E8pi9b5QNahsURYzXMjh3qw dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__47w2DboNEPf69aPgubZdd7Q));
}
}
static N_INLINE(NI, hash__suggestsymdb_u1622)(NI32 x_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = hashWangYi1__pureZhashes_u140(((NU64) (x_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__icZic_u1141)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__suggestsymdb_u1622(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NU32, getOrDefault__icZic_u1127)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg t_p0, NI32 key_p1) {
	NU32 result;
	NI hcX60gensym35__1;
	NI indexX60gensym35__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym35__1 = (NI)0;
	indexX60gensym35__1 = rawGet__icZic_u1141(t_p0, key_p1, (&hcX60gensym35__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym35__1)) goto LA3_;
		result = t_p0.data.p->data[indexX60gensym35__1].Field2;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__icZic_u1987)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZic_u2456)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg* t_p0, tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* data_p1, NI32 key_p2, NU32 val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZic_u2152)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg* t_p0) {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ n_1;
	NI T1_;
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__icZic_u1853((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__uaQEKxLZNO5fpFluyxnhTg* T17_;
					NI32 T18_;
					NU32 T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__uaQEKxLZNO5fpFluyxnhTg*)0;
					T17_ = t_p0;
					T18_ = (NI32)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___stdZoserrors_u34((&n_1.p->data[i_1].Field1));
					T19_ = (NU32)0;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___icZiclineinfos_u100((&n_1.p->data[i_1].Field2));
					rawInsert__icZic_u2456(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___icZic_u1393(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__icZic_u2625)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg t_p0, NI32 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZic_u1794)(tyObject_Table__uaQEKxLZNO5fpFluyxnhTg* t_p0, NI32 key_p1, NU32 val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym50__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym50__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__icZic_u1853((&(*t_p0).data), (correctSizeX60gensym50__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__icZic_u1141((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__uaQEKxLZNO5fpFluyxnhTg* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym53__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym53__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__icZic_u1853((&(*t_p0).data), (correctSizeX60gensym53__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__icZic_u1987((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__icZic_u2152(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__icZic_u2625((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__uaQEKxLZNO5fpFluyxnhTg*)0;
		T21_ = t_p0;
		rawInsert__icZic_u2456(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1) {
	NIM_BOOL result;
	result = ((*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (x_p0))).p == (*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (y_p1))).p);
	return result;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___icZic_u13383)(tySequence__FmsTQiIcS9arxHxs3QY48vA* dest_p0, tySequence__FmsTQiIcS9arxHxs3QY48vA src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__icZic_u13402((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			(*dest_p0).p->data[colontmp_].Field0 = src_p1.p->data[colontmp_].Field0;
			{
				if (!src_p1.p->data[colontmp_].Field1) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_].Field1);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_].Field1);
				if (!T16_) goto LA17_;
				eqdestroy___idents_u173((&(*(*dest_p0).p->data[colontmp_].Field1)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_].Field1, ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_].Field1 = src_p1.p->data[colontmp_].Field1;
			eqcopy___icZic_u3944((&(*dest_p0).p->data[colontmp_].Field2), src_p1.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___icZic_u18950)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* dest_p0, tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___icZic_u13383((&(*dest_p0).data), src_p1.data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*dest_p0).counter = src_p1.counter;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__icZic_u21704)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
static N_INLINE(NIM_BOOL, eqeq___ast_u617)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA a_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA b_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (a_p0.item == b_p1.item);
	if (!(T1_)) goto LA2_;
	T1_ = (a_p0.module == b_p1.module);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NI, rawGet__modulegraphs_u3685)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u3678)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__modulegraphs_u3685(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_u3657)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__modulegraphs_u3678(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__modulegraphs_u4192)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p0) {
	NimStringV2 colontmpD_;
	tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q* T2_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q*) nimNewObj(sizeof(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q), NIM_ALIGNOF(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q));
	(*T2_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__jzGRfzBmxnPANjp71FNw5Q_);
	(*T2_).Sup.Sup.Sup.name = "KeyError";
	T3_.len = 0; T3_.p = NIM_NIL;
	colontmpD_ = dollar___ast_u614(key_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = rawNewString(colontmpD_.len + 15);
appendString((&T3_), TM__4SoG2KRQy3oMm9aUzSLtGrA_6);
appendString((&T3_), colontmpD_);
	(*T2_).Sup.Sup.Sup.message = T3_;
	(*T2_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T2_, "KeyError", "raiseKeyError", "tables.nim", 232);
goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__vb3AGHvMJTxdOSSwMmBmTQ*, X5BX5D___modulegraphs_u4129)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__vb3AGHvMJTxdOSSwMmBmTQ*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__modulegraphs_u3685((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__modulegraphs_u4192(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__modulegraphs_u5076)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u5069)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__modulegraphs_u5076(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_u5048)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__modulegraphs_u5069(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*, X5BX5D___modulegraphs_u5532)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__modulegraphs_u5076((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__modulegraphs_u4192(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u5392)(tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field2.sym);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).Field2.sym)));
		nimRawDispose((*dest_p0).Field2.sym, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u5389)(tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.module = 0;
	(*dest_p0).Field1.item = 0;
	(*dest_p0).Field2.id.module = 0;
	(*dest_p0).Field2.id.packed_0.module = 0;
	(*dest_p0).Field2.id.packed_0.item = 0;
	(*dest_p0).Field2.sym = 0;
}
static N_INLINE(NIM_BOOL, mustRehash__modulegraphs_u5872)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__modulegraphs_u6373)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0, tySequence__3vEEVfBECLN6NIRA3FIp5g* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___modulegraphs_u1867((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__modulegraphs_u6067)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0) {
	tySequence__3vEEVfBECLN6NIRA3FIp5g n_1;
	NI T1_;
	tySequence__3vEEVfBECLN6NIRA3FIp5g T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u5732((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					nimZeroMem((void*)(&T19_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
					T19_.id = n_1.p->data[i_1].Field2.id;
					T19_.sym = n_1.p->data[i_1].Field2.sym;
					eqwasMoved___modulegraphs_u1855((&n_1.p->data[i_1].Field2));
					rawInsert__modulegraphs_u6373(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u5326(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__modulegraphs_u6530)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___modulegraphs_u5663)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym56__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym56__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u5732((&(*t_p0).data), (correctSizeX60gensym56__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__modulegraphs_u5076((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___modulegraphs_u1867((&(*t_p0).data.p->data[index_1].Field2), val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* T21_;
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym59__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym59__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u5732((&(*t_p0).data), (correctSizeX60gensym59__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__modulegraphs_u5872((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__modulegraphs_u6067(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__modulegraphs_u6530((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA*)0;
		T21_ = t_p0;
		nimZeroMem((void*)(&blitTmp_1), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
		blitTmp_1.id = val_p2.id;
		blitTmp_1.sym = val_p2.sym;
		rawInsert__modulegraphs_u6373(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3999)(tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q* dest_p0) {
	eqdestroy___modulegraphs_u672((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u3996)(tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.module = 0;
	(*dest_p0).Field1.item = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NIM_BOOL, mustRehash__semdata_u6244)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__semdata_u6753)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0, tySequence__8y0Gi4GwtXi2wk2mK1IOzw* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__vb3AGHvMJTxdOSSwMmBmTQ val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___modulegraphs_u681((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__semdata_u6436)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0) {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw n_1;
	NI T1_;
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__semdata_u6154((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					tySequence__vb3AGHvMJTxdOSSwMmBmTQ T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___modulegraphs_u669((&n_1.p->data[i_1].Field2));
					rawInsert__semdata_u6753(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u3934(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__semdata_u6922)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__vb3AGHvMJTxdOSSwMmBmTQ*, mgetOrPut__semdata_u6085)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__vb3AGHvMJTxdOSSwMmBmTQ val_p2) {
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__vb3AGHvMJTxdOSSwMmBmTQ*)0;
	{
		NI T3_;
		NI correctSizeX60gensym185__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym185__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__semdata_u6154((&(*t_p0).data), (correctSizeX60gensym185__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__modulegraphs_u3685((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__vb3AGHvMJTxdOSSwMmBmTQ colontmpD_;
		tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym188__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym188__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__semdata_u6154((&(*t_p0).data), (correctSizeX60gensym188__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__semdata_u6244((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__semdata_u6436(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__semdata_u6922((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___modulegraphs_u678(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__semdata_u6753(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__modulegraphs_u8881)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u8874)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__modulegraphs_u8881(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_u8853)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__modulegraphs_u8874(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw*, X5BX5D___modulegraphs_u9325)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__9bW2eTK9b7vXE70Sx5VPH1mw*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__modulegraphs_u8881((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__modulegraphs_u4192(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qBes3XzcQQ9cyia9bRwnmbJw, getOrDefault__icZic_u21531)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1) {
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw result;
	NI hcX60gensym497__1;
	NI indexX60gensym497__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	hcX60gensym497__1 = (NI)0;
	indexX60gensym497__1 = rawGet__icZic_u19193(t_p0, key_p1, (&hcX60gensym497__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym497__1)) goto LA3_;
		eqcopy___icZic_u3944((&result), t_p0.data.p->data[indexX60gensym497__1].Field2);
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__lookups_u3362)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u132(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI*, X5BX5D___lookups_u3355)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0, NI key_p1) {
	NI* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__lookups_u3362((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__ast_u1330(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__sigmatch_u6826)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw t_p0, NI key_p1, NI def_p2) {
	NI result;
	NI hcX60gensym1229__1;
	NI indexX60gensym1229__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	hcX60gensym1229__1 = (NI)0;
	indexX60gensym1229__1 = rawGet__lookups_u3362(t_p0, key_p1, (&hcX60gensym1229__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	{
		if (!(((NI)0) <= indexX60gensym1229__1)) goto LA4_;
		result = t_p0.data.p->data[indexX60gensym1229__1].Field2;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__modulegraphs_u4380)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u4373)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__modulegraphs_u4380(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_u4352)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__modulegraphs_u4373(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__apM9bRAO19cVjhWlxqd1PGeA*, X5BX5D___modulegraphs_u4824)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	tySequence__apM9bRAO19cVjhWlxqd1PGeA* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__apM9bRAO19cVjhWlxqd1PGeA*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__modulegraphs_u4380((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__modulegraphs_u4192(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u4694)(tyTuple__F1mMODXmKFMNQ5rLCtcv0Q* dest_p0) {
	eqdestroy___modulegraphs_u1156((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u4691)(tyTuple__F1mMODXmKFMNQ5rLCtcv0Q* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.module = 0;
	(*dest_p0).Field1.item = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NIM_BOOL, mustRehash__semdata_u5019)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__semdata_u5528)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0, tySequence__C2ivDnhTZ6IxAdui1rfuqw* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__apM9bRAO19cVjhWlxqd1PGeA val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___modulegraphs_u1165((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__semdata_u5211)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0) {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw n_1;
	NI T1_;
	tySequence__C2ivDnhTZ6IxAdui1rfuqw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__semdata_u4929((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					tySequence__apM9bRAO19cVjhWlxqd1PGeA T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___modulegraphs_u1153((&n_1.p->data[i_1].Field2));
					rawInsert__semdata_u5528(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u4629(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__semdata_u5697)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__apM9bRAO19cVjhWlxqd1PGeA*, mgetOrPut__semdata_u4860)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__apM9bRAO19cVjhWlxqd1PGeA val_p2) {
	tySequence__apM9bRAO19cVjhWlxqd1PGeA* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__apM9bRAO19cVjhWlxqd1PGeA*)0;
	{
		NI T3_;
		NI correctSizeX60gensym168__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym168__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__semdata_u4929((&(*t_p0).data), (correctSizeX60gensym168__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__modulegraphs_u4380((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__apM9bRAO19cVjhWlxqd1PGeA colontmpD_;
		tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym171__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym171__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__semdata_u4929((&(*t_p0).data), (correctSizeX60gensym171__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__semdata_u5019((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__semdata_u5211(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__semdata_u5697((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___modulegraphs_u1162(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__semdata_u5528(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__lookups_u5405)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u132(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g, getOrDefault__lookups_u5391)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg t_p0, NI key_p1) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g result;
	NI hcX60gensym188__1;
	NI indexX60gensym188__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	hcX60gensym188__1 = (NI)0;
	indexX60gensym188__1 = rawGet__lookups_u5405(t_p0, key_p1, (&hcX60gensym188__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym188__1)) goto LA3_;
		eqcopy___pureZosproc_u477((&result), t_p0.data.p->data[indexX60gensym188__1].Field2);
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u2010)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__y6bKAf9a9aaVwun6lVDxSX7g));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u577)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u513)(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u510)(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ, initTable__vmdef_u421)(NI initialSize_p0) {
	tyObject_Table__tro5f9chxPVpES1mQpDwZtQ result;
	NI correctSizeX60gensym0__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ));
	correctSizeX60gensym0__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__vmdef_u435((&result.data), (correctSizeX60gensym0__1));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__vmdef_u2388)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__vmdef_u2727)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vmdef_u3172)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* t_p0, tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* data_p1, NimStringV2 key_p2, NI val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vmdef_u2886)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* t_p0) {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og n_1;
	NI T1_;
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__vmdef_u435((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* T17_;
					NI T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__tro5f9chxPVpES1mQpDwZtQ*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field2));
					rawInsert__vmdef_u3172(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___vmdef_u577(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__vmdef_u3329)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmdef_u2322)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* t_p0, NimStringV2 key_p1, NI val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym5__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym5__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__vmdef_u435((&(*t_p0).data), (correctSizeX60gensym5__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__vmdef_u2388((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym10__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym10__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__vmdef_u435((&(*t_p0).data), (correctSizeX60gensym10__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__vmdef_u2727((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__vmdef_u2886(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__vmdef_u3329((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__tro5f9chxPVpES1mQpDwZtQ*)0;
		T21_ = t_p0;
		rawInsert__vmdef_u3172(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__sighashes_u616)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u132(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__sighashes_u1127)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sighashes_u1552)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* t_p0, tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg* data_p1, NI key_p2, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	nimCopyMem((void*)(*data_p1).p->data[h_p5].Field2, (NIM_CONST void*)val_p3, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sighashes_u1268)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* t_p0) {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg n_1;
	NI T1_;
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u13074((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* T17_;
					NI T18_;
					tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					nimCopyMem((void*)T19_, (NIM_CONST void*)n_1.p->data[i_1].Field2, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
					eqwasMoved___OOZdistZchecksumsZsrcZchecksumsZmd5_u241(n_1.p->data[i_1].Field2);
					rawInsert__sighashes_u1552(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u13172(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__sighashes_u1709)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___sighashes_u962)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* t_p0, NI key_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym90__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym90__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u13074((&(*t_p0).data), (correctSizeX60gensym90__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__sighashes_u616((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		nimCopyMem((void*)(*t_p0).data.p->data[index_1].Field2, (NIM_CONST void*)val_p2, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym93__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym93__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u13074((&(*t_p0).data), (correctSizeX60gensym93__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__sighashes_u1127((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__sighashes_u1268(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__sighashes_u1709((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg*)0;
		T21_ = t_p0;
		rawInsert__sighashes_u1552(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__vm_u8155)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vm_u8148)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__vm_u8155(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_u8127)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__vm_u8148(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*, X5BX5D___vm_u9692)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0, NimStringV2 key_p1) {
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__vm_u8155((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmmarshal_u688)(tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field2);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.Field2)));
		nimRawDispose(dest_p0.Field2, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmmarshal_u685)(tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ, initTable__vmmarshal_u1919)(NI initialSize_p0) {
	tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ result;
	NI correctSizeX60gensym71__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ));
	correctSizeX60gensym71__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__vmmarshal_u930((&result.data), (correctSizeX60gensym71__1));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, hash__pureZjson_u3377)(NI64 x_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = hashWangYi1__pureZhashes_u140(((NU64) (x_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__vmmarshal_u380)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ t_p0, NI64 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZjson_u3377(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getOrDefault__vmmarshal_u367)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ t_p0, NI64 key_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NI hcX60gensym53__1;
	NI indexX60gensym53__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym53__1 = (NI)0;
	indexX60gensym53__1 = rawGet__vmmarshal_u380(t_p0, key_p1, (&hcX60gensym53__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym53__1)) goto LA3_;
		eqcopy___ast_u3255(&result, t_p0.data.p->data[indexX60gensym53__1].Field2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__vmmarshal_u1058)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vmmarshal_u1503)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ* t_p0, tySequence__e9ciFfeAg1p88UzCBnAPeVQ* data_p1, NI64 key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___ast_u3261(&(*data_p1).p->data[h_p5].Field2, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmmarshal_u622)(tySequence__e9ciFfeAg1p88UzCBnAPeVQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field2)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vmmarshal_u1217)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ* t_p0) {
	tySequence__e9ciFfeAg1p88UzCBnAPeVQ n_1;
	NI T1_;
	tySequence__e9ciFfeAg1p88UzCBnAPeVQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__vmmarshal_u930((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ* T17_;
					NI64 T18_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ*)0;
					T17_ = t_p0;
					T18_ = (NI64)0;
					T18_ = n_1.p->data[i_1].Field1;
					n_1.p->data[i_1].Field1 = 0;
					T19_ = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___ast_u3249((&n_1.p->data[i_1].Field2));
					rawInsert__vmmarshal_u1503(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___vmmarshal_u622(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__vmmarshal_u1660)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ t_p0, NI64 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmmarshal_u873)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ* t_p0, NI64 key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym58__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym58__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__vmmarshal_u930((&(*t_p0).data), (correctSizeX60gensym58__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__vmmarshal_u380((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___ast_u3261(&(*t_p0).data.p->data[index_1].Field2, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ* T21_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym61__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym61__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__vmmarshal_u930((&(*t_p0).data), (correctSizeX60gensym61__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__vmmarshal_u1058((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__vmmarshal_u1217(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__vmmarshal_u1660((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__vmmarshal_u1503(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmmarshal_u1940)(tyObject_Table__wQe729aj2t9bQfHvWdVt17AQ dest_p0) {
	eqdestroy___vmmarshal_u622(dest_p0.data);
}
static N_INLINE(NI, rawGet__vmgen_u3713)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u132(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg, getOrDefault__vmgen_u3703)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ t_p0, NI key_p1, tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg def_p2) {
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg result;
	NI hcX60gensym887__1;
	NI indexX60gensym887__1;
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg));
	hcX60gensym887__1 = (NI)0;
	indexX60gensym887__1 = rawGet__vmgen_u3713(t_p0, key_p1, (&hcX60gensym887__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym887__1)) goto LA4_;
		result = t_p0.data.p->data[indexX60gensym887__1].Field2;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__vmgen_u4271)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vmgen_u4720)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ* t_p0, tySequence__Fc8Q26tsngy2yxcpyrnT4Q* data_p1, NI key_p2, tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vmgen_u4430)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ* t_p0) {
	tySequence__Fc8Q26tsngy2yxcpyrnT4Q n_1;
	NI T1_;
	tySequence__Fc8Q26tsngy2yxcpyrnT4Q T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__vmgen_u4143((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__lPs28yjGTxD0LzUoPspSBQ* T17_;
					NI T18_;
					tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__lPs28yjGTxD0LzUoPspSBQ*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___vmdef_u3574((&n_1.p->data[i_1].Field2));
					rawInsert__vmgen_u4720(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___vmdef_u2010(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__vmgen_u4877)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmgen_u4086)(tyObject_Table__lPs28yjGTxD0LzUoPspSBQ* t_p0, NI key_p1, tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym896__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym896__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__vmgen_u4143((&(*t_p0).data), (correctSizeX60gensym896__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__vmgen_u3713((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__lPs28yjGTxD0LzUoPspSBQ* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym899__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym899__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__vmgen_u4143((&(*t_p0).data), (correctSizeX60gensym899__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__vmgen_u4271((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__vmgen_u4430(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__vmgen_u4877((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__lPs28yjGTxD0LzUoPspSBQ*)0;
		T21_ = t_p0;
		rawInsert__vmgen_u4720(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u431)(tyTuple__bxYrf1dnwYK6GanDNddhgQ dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field2);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*dest_p0.Field2)));
		nimRawDispose(dest_p0.Field2, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lambdalifting_u428)(tyTuple__bxYrf1dnwYK6GanDNddhgQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ, initTable__lambdalifting_u339)(NI initialSize_p0) {
	tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ result;
	NI correctSizeX60gensym48__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ));
	correctSizeX60gensym48__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__lambdalifting_u353((&result.data), (correctSizeX60gensym48__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u500)(tySequence__mnb4N9bRCddoL53waHA7kHQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].Field2)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__bxYrf1dnwYK6GanDNddhgQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u482)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ dest_p0) {
	eqdestroy___lambdalifting_u500(dest_p0.data);
}
static N_INLINE(NI, rawGet__lambdalifting_u702)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u132(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getOrDefault__lambdalifting_u689)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ t_p0, NI key_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	NI hcX60gensym52__1;
	NI indexX60gensym52__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym52__1 = (NI)0;
	indexX60gensym52__1 = rawGet__lambdalifting_u702(t_p0, key_p1, (&hcX60gensym52__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym52__1)) goto LA3_;
		eqcopy___ast_u3381(&result, t_p0.data.p->data[indexX60gensym52__1].Field2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__lambdalifting_u1252)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__lambdalifting_u1697)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ* t_p0, tySequence__mnb4N9bRCddoL53waHA7kHQ* data_p1, NI key_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___ast_u3387(&(*data_p1).p->data[h_p5].Field2, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__lambdalifting_u1411)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ* t_p0) {
	tySequence__mnb4N9bRCddoL53waHA7kHQ n_1;
	NI T1_;
	tySequence__mnb4N9bRCddoL53waHA7kHQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__lambdalifting_u353((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ* T17_;
					NI T18_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					T19_ = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___ast_u3375((&n_1.p->data[i_1].Field2));
					rawInsert__lambdalifting_u1697(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___lambdalifting_u500(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__lambdalifting_u1854)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lambdalifting_u1075)(tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ* t_p0, NI key_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym60__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym60__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__lambdalifting_u353((&(*t_p0).data), (correctSizeX60gensym60__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__lambdalifting_u702((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___ast_u3387(&(*t_p0).data.p->data[index_1].Field2, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ* T21_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym63__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym63__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__lambdalifting_u353((&(*t_p0).data), (correctSizeX60gensym63__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__lambdalifting_u1252((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__lambdalifting_u1411(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__lambdalifting_u1854((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__GUbI9btx7o12c3PxZ9cboQZQ*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__lambdalifting_u1697(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u2651)(tyTuple__rczUtx07rG4YmHOEmcEUJw dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field2);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.Field2)));
		nimRawDispose(dest_p0.Field2, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lambdalifting_u2648)(tyTuple__rczUtx07rG4YmHOEmcEUJw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg, initTable__lambdalifting_u2559)(NI initialSize_p0) {
	tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg result;
	NI correctSizeX60gensym123__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg));
	correctSizeX60gensym123__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__lambdalifting_u2573((&result.data), (correctSizeX60gensym123__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u2720)(tySequence__R1mQMFmsdp1ChoJDXa9a0xQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field2)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__rczUtx07rG4YmHOEmcEUJw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u2702)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg dest_p0) {
	eqdestroy___lambdalifting_u2720(dest_p0.data);
}
static N_INLINE(NI, rawGet__lambdalifting_u2945)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u132(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getOrDefault__lambdalifting_u2932)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg t_p0, NI key_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NI hcX60gensym135__1;
	NI indexX60gensym135__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym135__1 = (NI)0;
	indexX60gensym135__1 = rawGet__lambdalifting_u2945(t_p0, key_p1, (&hcX60gensym135__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym135__1)) goto LA3_;
		eqcopy___ast_u3255(&result, t_p0.data.p->data[indexX60gensym135__1].Field2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__lambdalifting_u3573)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__lambdalifting_u4018)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* t_p0, tySequence__R1mQMFmsdp1ChoJDXa9a0xQ* data_p1, NI key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___ast_u3261(&(*data_p1).p->data[h_p5].Field2, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__lambdalifting_u3732)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* t_p0) {
	tySequence__R1mQMFmsdp1ChoJDXa9a0xQ n_1;
	NI T1_;
	tySequence__R1mQMFmsdp1ChoJDXa9a0xQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__lambdalifting_u2573((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* T17_;
					NI T18_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					T19_ = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___ast_u3249((&n_1.p->data[i_1].Field2));
					rawInsert__lambdalifting_u4018(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___lambdalifting_u2720(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__lambdalifting_u4175)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lambdalifting_u3396)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* t_p0, NI key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym146__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym146__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__lambdalifting_u2573((&(*t_p0).data), (correctSizeX60gensym146__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__lambdalifting_u2945((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___ast_u3261(&(*t_p0).data.p->data[index_1].Field2, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* T21_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym149__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym149__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__lambdalifting_u2573((&(*t_p0).data), (correctSizeX60gensym149__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__lambdalifting_u3573((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__lambdalifting_u3732(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__lambdalifting_u4175((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__lambdalifting_u4018(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___lambdalifting_u4602)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* t_p0, NI key_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__lambdalifting_u2945((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = &(*t_p0).data.p->data[indexX60gensym22__1].Field2;
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__ast_u1330(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__liftdestructors_u837)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__modulegraphs_u10758(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___modulegraphs_u10735(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getOrDefault__liftdestructors_u824)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	NI hcX60gensym153__1;
	NI indexX60gensym153__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym153__1 = (NI)0;
	indexX60gensym153__1 = rawGet__liftdestructors_u837(t_p0, key_p1, (&hcX60gensym153__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym153__1)) goto LA3_;
		eqcopy___ast_u3381(&result, t_p0.data.p->data[indexX60gensym153__1].Field2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__liftdestructors_u2147)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__liftdestructors_u2568)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* t_p0, tySequence__vJcM7B74R2U5db9cxyXT9coA* data_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimCopyMem((void*)(*data_p1).p->data[h_p5].Field1, (NIM_CONST void*)key_p2, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	eqsink___ast_u3387(&(*data_p1).p->data[h_p5].Field2, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__liftdestructors_u2288)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* t_p0) {
	tySequence__vJcM7B74R2U5db9cxyXT9coA n_1;
	NI T1_;
	tySequence__vJcM7B74R2U5db9cxyXT9coA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u12858((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* T17_;
					tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T18_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw*)0;
					T17_ = t_p0;
					nimCopyMem((void*)T18_, (NIM_CONST void*)n_1.p->data[i_1].Field1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
					eqwasMoved___OOZdistZchecksumsZsrcZchecksumsZmd5_u241(n_1.p->data[i_1].Field1);
					T19_ = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___ast_u3375((&n_1.p->data[i_1].Field2));
					rawInsert__liftdestructors_u2568(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u13005(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__liftdestructors_u2725)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___modulegraphs_u10735(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___liftdestructors_u1982)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym292__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym292__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u12858((&(*t_p0).data), (correctSizeX60gensym292__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__liftdestructors_u837((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___ast_u3387(&(*t_p0).data.p->data[index_1].Field2, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* T21_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym295__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym295__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u12858((&(*t_p0).data), (correctSizeX60gensym295__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__liftdestructors_u2147((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__liftdestructors_u2288(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__liftdestructors_u2725((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__liftdestructors_u2568(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___lambdalifting_u4950)(tyObject_Table__01H8mjk9bzeSBsWX9ctnNFpg* t_p0, NI key_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	NI hcX60gensym20__1;
	NI indexX60gensym20__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	hcX60gensym20__1 = (NI)0;
	indexX60gensym20__1 = rawGet__lambdalifting_u2945((*t_p0), key_p1, (&hcX60gensym20__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym20__1)) goto LA3_;
		result = &(*t_p0).data.p->data[indexX60gensym20__1].Field2;
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__ast_u1330(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__closureiters_u523)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__closureiters_u510)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NI result;
	NI hcX60gensym48__1;
	NI indexX60gensym48__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym48__1 = (NI)0;
	indexX60gensym48__1 = rawGet__closureiters_u523(t_p0, key_p1, (&hcX60gensym48__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym48__1)) goto LA3_;
		result = t_p0.data.p->data[indexX60gensym48__1].Field2;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__closureiters_u1109)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__closureiters_u1530)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw* t_p0, tySequence__kP47rw9c8bgVA53QKWe9bp7g* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, NI val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___closureiters_u752)(tySequence__kP47rw9c8bgVA53QKWe9bp7g dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__closureiters_u1250)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw* t_p0) {
	tySequence__kP47rw9c8bgVA53QKWe9bp7g n_1;
	NI T1_;
	tySequence__kP47rw9c8bgVA53QKWe9bp7g T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__closureiters_u987((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__GdZqMtWDe86MuMz9cop7uxw* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					NI T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__GdZqMtWDe86MuMz9cop7uxw*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					T19_ = (NI)0;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field2));
					rawInsert__closureiters_u1530(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___closureiters_u752(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__closureiters_u1687)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___closureiters_u936)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym53__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym53__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__closureiters_u987((&(*t_p0).data), (correctSizeX60gensym53__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__closureiters_u523((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__GdZqMtWDe86MuMz9cop7uxw* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym56__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym56__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__closureiters_u987((&(*t_p0).data), (correctSizeX60gensym56__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__closureiters_u1109((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__closureiters_u1250(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__closureiters_u1687((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__GdZqMtWDe86MuMz9cop7uxw*)0;
		T21_ = t_p0;
		rawInsert__closureiters_u1530(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__closureiters_u3373)(tyObject_Table__GdZqMtWDe86MuMz9cop7uxw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI def_p2) {
	NI result;
	NI hcX60gensym354__1;
	NI indexX60gensym354__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	hcX60gensym354__1 = (NI)0;
	indexX60gensym354__1 = rawGet__closureiters_u523(t_p0, key_p1, (&hcX60gensym354__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	{
		if (!(((NI)0) <= indexX60gensym354__1)) goto LA4_;
		result = t_p0.data.p->data[indexX60gensym354__1].Field2;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vmgen_u3190)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__vmdef_u2388(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vmgen_u3169)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__vmgen_u3190(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI*, X5BX5D___vmgen_u3252)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* t_p0, NimStringV2 key_p1) {
	NI* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__vmdef_u2388((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__vm_u4367)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI64, getOrDefault__vm_u4354)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0, NimStringV2 key_p1) {
	NI64 result;
	NI hcX60gensym1962__1;
	NI indexX60gensym1962__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym1962__1 = (NI)0;
	indexX60gensym1962__1 = rawGet__vm_u4367(t_p0, key_p1, (&hcX60gensym1962__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym1962__1)) goto LA3_;
		result = t_p0.data.p->data[indexX60gensym1962__1].Field2;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__vm_u4993)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vm_u5490)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* t_p0, tySequence__squ9b9bUH4OLHf6cEMrt6hVA* data_p1, NimStringV2 key_p2, NI64 val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vm_u5188)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* t_p0) {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA n_1;
	NI T1_;
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u12324((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* T17_;
					NI64 T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_ = (NI64)0;
					T18_ = n_1.p->data[i_1].Field2;
					n_1.p->data[i_1].Field2 = 0;
					rawInsert__vm_u5490(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u12466(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__vm_u5647)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u4792)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* t_p0, NimStringV2 key_p1, NI64 val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym1972__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym1972__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u12324((&(*t_p0).data), (correctSizeX60gensym1972__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__vm_u4367((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym1975__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym1975__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u12324((&(*t_p0).data), (correctSizeX60gensym1975__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__vm_u4993((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__vm_u5188(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__vm_u5647((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw*)0;
		T21_ = t_p0;
		rawInsert__vm_u5490(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__vm_u5984)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vm_u5977)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__vm_u5984(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vm_u5956)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__vm_u5977(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__vm_u6468)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vm_u6961)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0, tySequence__R9c39btP6BwOBBPnbaNUtMQg* data_p1, NimStringV2 key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___ast_u3261(&(*data_p1).p->data[h_p5].Field2, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vm_u6663)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0) {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg n_1;
	NI T1_;
	tySequence__R9c39btP6BwOBBPnbaNUtMQg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u12107((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* T17_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_ = NIM_NIL;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___ast_u3249((&n_1.p->data[i_1].Field2));
					rawInsert__vm_u6961(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u12255(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__vm_u7118)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u6267)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0, NimStringV2 key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym1991__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym1991__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u12107((&(*t_p0).data), (correctSizeX60gensym1991__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__vm_u5984((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___ast_u3261(&(*t_p0).data.p->data[index_1].Field2, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* T21_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym1994__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym1994__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u12107((&(*t_p0).data), (correctSizeX60gensym1994__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__vm_u6468((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__vm_u6663(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__vm_u7118((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__vm_u6961(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___vm_u7407)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* t_p0, NimStringV2 key_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__vm_u5984((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = &(*t_p0).data.p->data[indexX60gensym22__1].Field2;
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__vm_u8749)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vm_u9246)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0, tySequence__3nALyQgqjnfK2Qjc6ny2Uw* data_p1, NimStringV2 key_p2, tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___vm_u8516((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vm_u8944)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0) {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw n_1;
	NI T1_;
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u12534((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* T17_;
					tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					nimZeroMem((void*)(&T18_), sizeof(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw));
					T18_.root = n_1.p->data[i_1].Field2.root;
					T18_.entries = n_1.p->data[i_1].Field2.entries;
					eqwasMoved___vm_u8504((&n_1.p->data[i_1].Field2));
					rawInsert__vm_u9246(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u12789(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__vm_u9403)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vm_u8548)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* t_p0, NimStringV2 key_p1, tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym2033__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym2033__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u12534((&(*t_p0).data), (correctSizeX60gensym2033__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__vm_u8155((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___vm_u8516((&(*t_p0).data.p->data[index_1].Field2), val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* T21_;
		tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym2036__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym2036__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u12534((&(*t_p0).data), (correctSizeX60gensym2036__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__vm_u8749((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__vm_u8944(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__vm_u9403((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ*)0;
		T21_ = t_p0;
		nimZeroMem((void*)(&blitTmp_1), sizeof(tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw));
		blitTmp_1.root = val_p2.root;
		blitTmp_1.entries = val_p2.entries;
		rawInsert__vm_u9246(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u889)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg** dest_p0, tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* src_p1) {
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLast((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___options_u802((*(*dest_p0)));
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
}
static N_INLINE(NI, rawGet__vmprofiler_u236)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__lineinfos_u261(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___msgs_u1103(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vmprofiler_u229)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__vmprofiler_u236(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vmprofiler_u138)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__vmprofiler_u229((*t_p0), key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__vmprofiler_u94)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__vmprofiler_u138(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__vmprofiler_u753)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__vmprofiler_u1202)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tySequence__FGxE1Nuen6pVDc58PZudJw* data_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p2, tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__vmprofiler_u894)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0) {
	tySequence__FGxE1Nuen6pVDc58PZudJw n_1;
	NI T1_;
	tySequence__FGxE1Nuen6pVDc58PZudJw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__options_u722((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* T17_;
					tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA T18_;
					tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__g39amaj5esSUbnvSF2f9bVgg*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___lineinfos_u2028((&n_1.p->data[i_1].Field1));
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___vmprofiler_u1182((&n_1.p->data[i_1].Field2));
					rawInsert__vmprofiler_u1202(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___options_u820(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__vmprofiler_u1359)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___msgs_u1103(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmprofiler_u588)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1, tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym7__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym7__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__options_u722((&(*t_p0).data), (correctSizeX60gensym7__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__vmprofiler_u236((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym10__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym10__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__options_u722((&(*t_p0).data), (correctSizeX60gensym10__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__vmprofiler_u753((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__vmprofiler_u894(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__vmprofiler_u1359((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__g39amaj5esSUbnvSF2f9bVgg*)0;
		T21_ = t_p0;
		rawInsert__vmprofiler_u1202(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmprofiler_u497)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1, tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw val_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	X5BX5Deq___vmprofiler_u588(t_p0, key_p1, val_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__vmprofiler_u1797)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p0) {
	tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q* T1_;
{	T1_ = NIM_NIL;
	T1_ = (tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q*) nimNewObj(sizeof(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q), NIM_ALIGNOF(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__jzGRfzBmxnPANjp71FNw5Q_);
	(*T1_).Sup.Sup.Sup.name = "KeyError";
	(*T1_).Sup.Sup.Sup.message = TM__4SoG2KRQy3oMm9aUzSLtGrA_8;
	(*T1_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T1_, "KeyError", "raiseKeyError", "tables.nim", 234);
goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw*, X5BX5D___vmprofiler_u1734)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1) {
	tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__vmprofiler_u236((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__vmprofiler_u1797(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw*, X5BX5D___vmprofiler_u1630)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1) {
	tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw*)0;
	result = X5BX5D___vmprofiler_u1734(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13718)(tyTuple__bnJwOH0eJlAwCAMbr1inhw* dest_p0) {
	eqdestroy___ast_u4848((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u13715)(tyTuple__bnJwOH0eJlAwCAMbr1inhw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.module = 0;
	(*dest_p0).Field1.item = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NI, rawGet__cgen_u4153)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__sem_u18926)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sem_u19375)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* t_p0, tySequence__N589c2UsUgqqOITU2JfIuAQ* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__ZCZaCk14bTmSb6LMW9aWPVA val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___ast_u4857((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sem_u19085)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* t_p0) {
	tySequence__N589c2UsUgqqOITU2JfIuAQ n_1;
	NI T1_;
	tySequence__N589c2UsUgqqOITU2JfIuAQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__sem_u18847((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					tySequence__ZCZaCk14bTmSb6LMW9aWPVA T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___ast_u4845((&n_1.p->data[i_1].Field2));
					rawInsert__sem_u19375(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u13652(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__sem_u19532)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA*, mgetOrPut__sem_u18789)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__ZCZaCk14bTmSb6LMW9aWPVA val_p2) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA*)0;
	{
		NI T3_;
		NI correctSizeX60gensym4599__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym4599__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__sem_u18847((&(*t_p0).data), (correctSizeX60gensym4599__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__cgen_u4153((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__ZCZaCk14bTmSb6LMW9aWPVA colontmpD_;
		tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym4602__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym4602__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__sem_u18847((&(*t_p0).data), (correctSizeX60gensym4602__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__sem_u18926((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__sem_u19085(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__sem_u19532((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___ast_u4854(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__sem_u19375(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__cgen_u4653)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__cgen_u4646)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__cgen_u4653(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__cgen_u4625)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__cgen_u4646(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13871)(tyTuple__YG7h1OUHzgfgTeH9cl0U0dw dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field2);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.Field2)));
		nimRawDispose(dest_p0.Field2, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u13868)(tyTuple__YG7h1OUHzgfgTeH9cl0U0dw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.module = 0;
	(*dest_p0).Field1.item = 0;
	(*dest_p0).Field2 = 0;
}
static N_INLINE(NIM_BOOL, mustRehash__sem_u20123)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sem_u20568)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* t_p0, tySequence__GYDW6wGgERshoSd16jJ3eQ* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___ast_u3261(&(*data_p1).p->data[h_p5].Field2, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sem_u20282)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* t_p0) {
	tySequence__GYDW6wGgERshoSd16jJ3eQ n_1;
	NI T1_;
	tySequence__GYDW6wGgERshoSd16jJ3eQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__sem_u19995((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					T19_ = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___ast_u3249((&n_1.p->data[i_1].Field2));
					rawInsert__sem_u20568(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u13804(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__sem_u20725)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___sem_u19938)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym4629__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym4629__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__sem_u19995((&(*t_p0).data), (correctSizeX60gensym4629__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__cgen_u4653((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___ast_u3261(&(*t_p0).data.p->data[index_1].Field2, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* T21_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym4632__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym4632__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__sem_u19995((&(*t_p0).data), (correctSizeX60gensym4632__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__sem_u20123((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__sem_u20282(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__sem_u20725((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__sem_u20568(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u9195)(tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ* dest_p0) {
	eqdestroy___modulegraphs_u2212((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u9192)(tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.module = 0;
	(*dest_p0).Field1.item = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NIM_BOOL, mustRehash__modulegraphs_u9698)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__modulegraphs_u10195)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0, tySequence__9aSa87aKMiolq9a7z3kC0jTw* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__9bW2eTK9b7vXE70Sx5VPH1mw val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___modulegraphs_u2221((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__modulegraphs_u9893)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0) {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw n_1;
	NI T1_;
	tySequence__9aSa87aKMiolq9a7z3kC0jTw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u9607((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					tySequence__9bW2eTK9b7vXE70Sx5VPH1mw T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__tEqt8LkShErhjQ9acvGyE7g*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___modulegraphs_u2209((&n_1.p->data[i_1].Field2));
					rawInsert__modulegraphs_u10195(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u9130(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__modulegraphs_u10352)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw*, mgetOrPut__modulegraphs_u9537)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__9bW2eTK9b7vXE70Sx5VPH1mw val_p2) {
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__9bW2eTK9b7vXE70Sx5VPH1mw*)0;
	{
		NI T3_;
		NI correctSizeX60gensym97__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym97__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u9607((&(*t_p0).data), (correctSizeX60gensym97__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__modulegraphs_u8881((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__9bW2eTK9b7vXE70Sx5VPH1mw colontmpD_;
		tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym100__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym100__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u9607((&(*t_p0).data), (correctSizeX60gensym100__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__modulegraphs_u9698((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__modulegraphs_u9893(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__modulegraphs_u10352((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__tEqt8LkShErhjQ9acvGyE7g*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___modulegraphs_u2218(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__modulegraphs_u10195(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__cgmeth_u332)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NI result;
	NI h_1;
	NI T6_;
	NI T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NI)0;
	T6_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = ((*t_p0).data.len-1);
	h_1 = (NI)(T6_ & T7_);
	{
		while (1) {
			NI T15_;
			if (!!(((*t_p0).data.p->data[h_1].Field1 == ((NI)0)))) goto LA9;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = eqeq___ast_u617((*t_p0).data.p->data[h_1].Field0, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T12_) goto LA13_;
				result = h_1;
				goto BeforeRet_;
			}
LA13_: ;
			T15_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T15_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA9: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__cgmeth_u311)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = rawGet__cgmeth_u332(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__cgmeth_u298)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__cgmeth_u311(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgmeth_u448)(tyTuple__2QDyOgS51ZMPO0W1pWCY6g* dest_p0) {
	(*dest_p0).Field0.module = 0;
	(*dest_p0).Field0.item = 0;
	(*dest_p0).Field1 = 0;
}
static N_INLINE(NIM_BOOL, mustRehash__cgmeth_u507)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ctRawInsert__cgmeth_u574)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tySequence__Wd0Vle6gxRCPPoSlNEvfTA* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, NI val_p3) {
	NI h_1;
	NI T1_;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = ((*data_p1).len-1);
	h_1 = (NI)(T1_ & T2_);
	{
		while (1) {
			NI T5_;
			if (!!(((*data_p1).p->data[h_1].Field1 == ((NI)0)))) goto LA4;
			T5_ = ((*data_p1).len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA4: ;
	}
	(*data_p1).p->data[h_1].Field0 = key_p2;
	(*data_p1).p->data[h_1].Field1 = val_p3;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgmeth_u541)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0) {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA n_1;
	NI T1_;
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA T12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__cgmeth_u495((&n_1), ((NI)(T1_ * ((NI)2))));
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((*t_p0).data.len-1);
		colontmp_ = T3_;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA5;
				i_1 = ((NI) (res_1));
				{
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T10_;
					NI T11_;
					if (!!(((*t_p0).data.p->data[i_1].Field1 == ((NI)0)))) goto LA8_;
					T10_ = (*t_p0).data.p->data[i_1].Field0;
					eqwasMoved___ast_u3148((&(*t_p0).data.p->data[i_1].Field0));
					T11_ = (NI)0;
					T11_ = (*t_p0).data.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&(*t_p0).data.p->data[i_1].Field1));
					ctRawInsert__cgmeth_u574((&(*t_p0)), (&n_1), T10_, T11_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA8_: ;
				res_1 += ((NI)1);
			} LA5: ;
		}
	}
	T12_.len = 0; T12_.p = NIM_NIL;
	T12_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T12_;
	eqdestroy___modulegraphs_u14008(n_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___cgmeth_u405)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI val_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(val_p2 == ((NI)0))) goto LA3_;
		{
			NI T7_;
			NI i_1;
			NI T10_;
			NI T11_;
			T7_ = (*t_p0).data.len;
			if (!(((NI)0) < T7_)) goto LA8_;
			T10_ = (NI)0;
			T10_ = hash__ast_u621(key_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T11_ = ((*t_p0).data.len-1);
			i_1 = (NI)(T10_ & T11_);
			{
				while (1) {
					NI T48_;
					if (!!(((*t_p0).data.p->data[i_1].Field1 == ((NI)0)))) goto LA13;
					{
						NIM_BOOL T16_;
						NI mskX60gensym179__1;
						NI T19_;
						T16_ = (NIM_BOOL)0;
						T16_ = eqeq___ast_u617((*t_p0).data.p->data[i_1].Field0, key_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T16_) goto LA17_;
						T19_ = ((*t_p0).data.len-1);
						mskX60gensym179__1 = T19_;
						{
							if (!(((NI)0) <= i_1)) goto LA22_;
							(*t_p0).counter -= ((NI)1);
							{
								{
									while (1) {
										NI jX60gensym179__1;
										NI rX60gensym179__1;
										jX60gensym179__1 = i_1;
										rX60gensym179__1 = jX60gensym179__1;
										(*t_p0).data.p->data[i_1].Field1 = ((NI)0);
										reset__modulegraphs_u592((&(*t_p0).data.p->data[i_1].Field0));
										reset__ast_u2522((&(*t_p0).data.p->data[i_1].Field1));
										{
											while (1) {
												NI T33_;
												i_1 = (NI)((NI)(i_1 + ((NI)1)) & mskX60gensym179__1);
												{
													if (!((*t_p0).data.p->data[i_1].Field1 == ((NI)0))) goto LA31_;
													goto LA24;
												}
LA31_: ;
												T33_ = (NI)0;
												T33_ = hash__ast_u621((*t_p0).data.p->data[i_1].Field0);
												if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
												rX60gensym179__1 = (NI)(T33_ & mskX60gensym179__1);
												{
													NIM_BOOL T36_;
													NIM_BOOL T37_;
													NIM_BOOL T38_;
													NIM_BOOL T41_;
													NIM_BOOL T44_;
													T36_ = (NIM_BOOL)0;
													T37_ = (NIM_BOOL)0;
													T38_ = (NIM_BOOL)0;
													T38_ = (rX60gensym179__1 <= i_1);
													if (!(T38_)) goto LA39_;
													T38_ = (jX60gensym179__1 < rX60gensym179__1);
LA39_: ;
													T37_ = T38_;
													if (T37_) goto LA40_;
													T41_ = (NIM_BOOL)0;
													T41_ = (jX60gensym179__1 < rX60gensym179__1);
													if (!(T41_)) goto LA42_;
													T41_ = (i_1 < jX60gensym179__1);
LA42_: ;
													T37_ = T41_;
LA40_: ;
													T36_ = T37_;
													if (T36_) goto LA43_;
													T44_ = (NIM_BOOL)0;
													T44_ = (i_1 < jX60gensym179__1);
													if (!(T44_)) goto LA45_;
													T44_ = (rX60gensym179__1 <= i_1);
LA45_: ;
													T36_ = T44_;
LA43_: ;
													if (!!(T36_)) goto LA46_;
													goto LA27;
												}
LA46_: ;
											}
										} LA27: ;
										(*t_p0).data.p->data[jX60gensym179__1] = (*t_p0).data.p->data[i_1];
										eqwasMoved___cgmeth_u448((&(*t_p0).data.p->data[i_1]));
									}
								}
							} LA24: ;
						}
LA22_: ;
						goto LA12;
					}
LA17_: ;
					T48_ = ((*t_p0).data.len-1);
					i_1 = nextTry__pureZcollectionsZtables_u35(i_1, T48_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA13: ;
			} LA12: ;
		}
LA8_: ;
	}
	goto LA1_;
LA3_: ;
	{
		NI h_1;
		h_1 = rawGet__cgmeth_u332((&(*t_p0)), key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!(((NI)0) <= h_1)) goto LA52_;
			(*t_p0).data.p->data[h_1].Field1 = val_p2;
		}
		goto LA50_;
LA52_: ;
		{
			tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA T65_;
			{
				NI T57_;
				NI correctSizeX60gensym64__1;
				T57_ = (*t_p0).data.len;
				if (!(T57_ == ((NI)0))) goto LA58_;
				correctSizeX60gensym64__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				(*t_p0).counter = ((NI)0);
				newSeq__cgmeth_u495((&(*t_p0).data), (correctSizeX60gensym64__1));
			}
LA58_: ;
			{
				NIM_BOOL T62_;
				T62_ = (NIM_BOOL)0;
				T62_ = mustRehash__cgmeth_u507((&(*t_p0)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T62_) goto LA63_;
				enlarge__cgmeth_u541(t_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA63_: ;
			T65_ = (*t_p0);
			ctRawInsert__cgmeth_u574((&T65_), (&(*t_p0).data), key_p1, val_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter += ((NI)1);
		}
LA50_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, inc__cgmeth_u621)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI val_p2) {
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	index_1 = rawGet__cgmeth_u332((&(*t_p0)), key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA3_;
		(*t_p0).data.p->data[index_1].Field1 += val_p2;
		{
			NI mskX60gensym195__1;
			NI T9_;
			if (!((*t_p0).data.p->data[index_1].Field1 == ((NI)0))) goto LA7_;
			T9_ = ((*t_p0).data.len-1);
			mskX60gensym195__1 = T9_;
			{
				if (!(((NI)0) <= index_1)) goto LA12_;
				(*t_p0).counter -= ((NI)1);
				{
					{
						while (1) {
							NI jX60gensym195__1;
							NI rX60gensym195__1;
							jX60gensym195__1 = index_1;
							rX60gensym195__1 = jX60gensym195__1;
							(*t_p0).data.p->data[index_1].Field1 = ((NI)0);
							reset__modulegraphs_u592((&(*t_p0).data.p->data[index_1].Field0));
							reset__ast_u2522((&(*t_p0).data.p->data[index_1].Field1));
							{
								while (1) {
									NI T23_;
									index_1 = (NI)((NI)(index_1 + ((NI)1)) & mskX60gensym195__1);
									{
										if (!((*t_p0).data.p->data[index_1].Field1 == ((NI)0))) goto LA21_;
										goto LA14;
									}
LA21_: ;
									T23_ = (NI)0;
									T23_ = hash__ast_u621((*t_p0).data.p->data[index_1].Field0);
									if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
									rX60gensym195__1 = (NI)(T23_ & mskX60gensym195__1);
									{
										NIM_BOOL T26_;
										NIM_BOOL T27_;
										NIM_BOOL T28_;
										NIM_BOOL T31_;
										NIM_BOOL T34_;
										T26_ = (NIM_BOOL)0;
										T27_ = (NIM_BOOL)0;
										T28_ = (NIM_BOOL)0;
										T28_ = (rX60gensym195__1 <= index_1);
										if (!(T28_)) goto LA29_;
										T28_ = (jX60gensym195__1 < rX60gensym195__1);
LA29_: ;
										T27_ = T28_;
										if (T27_) goto LA30_;
										T31_ = (NIM_BOOL)0;
										T31_ = (jX60gensym195__1 < rX60gensym195__1);
										if (!(T31_)) goto LA32_;
										T31_ = (index_1 < jX60gensym195__1);
LA32_: ;
										T27_ = T31_;
LA30_: ;
										T26_ = T27_;
										if (T26_) goto LA33_;
										T34_ = (NIM_BOOL)0;
										T34_ = (index_1 < jX60gensym195__1);
										if (!(T34_)) goto LA35_;
										T34_ = (rX60gensym195__1 <= index_1);
LA35_: ;
										T26_ = T34_;
LA33_: ;
										if (!!(T26_)) goto LA36_;
										goto LA17;
									}
LA36_: ;
								}
							} LA17: ;
							(*t_p0).data.p->data[jX60gensym195__1] = (*t_p0).data.p->data[index_1];
							eqwasMoved___cgmeth_u448((&(*t_p0).data.p->data[index_1]));
						}
					}
				} LA14: ;
			}
LA12_: ;
		}
LA7_: ;
	}
	goto LA1_;
LA3_: ;
	{
		{
			tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA T53_;
			if (!!((val_p2 == ((NI)0)))) goto LA41_;
			{
				NI T45_;
				NI correctSizeX60gensym74__1;
				T45_ = (*t_p0).data.len;
				if (!(T45_ == ((NI)0))) goto LA46_;
				correctSizeX60gensym74__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				(*t_p0).counter = ((NI)0);
				newSeq__cgmeth_u495((&(*t_p0).data), (correctSizeX60gensym74__1));
			}
LA46_: ;
			{
				NIM_BOOL T50_;
				T50_ = (NIM_BOOL)0;
				T50_ = mustRehash__cgmeth_u507((&(*t_p0)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T50_) goto LA51_;
				enlarge__cgmeth_u541(t_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA51_: ;
			T53_ = (*t_p0);
			ctRawInsert__cgmeth_u574((&T53_), (&(*t_p0).data), key_p1, val_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter += ((NI)1);
		}
LA41_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, mustRehash__sempass2_u2486)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sempass2_u2931)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0, tySequence__E8pi9b5QNahsURYzXMjh3qw* data_p1, NI key_p2, NI val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sempass2_u2645)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0) {
	tySequence__E8pi9b5QNahsURYzXMjh3qw n_1;
	NI T1_;
	tySequence__E8pi9b5QNahsURYzXMjh3qw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__sempass2_u2358((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* T17_;
					NI T18_;
					NI T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					T19_ = (NI)0;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field2));
					rawInsert__sempass2_u2931(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___semdata_u3481(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__sempass2_u3088)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___sempass2_u2301)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0, NI key_p1, NI val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym86__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym86__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__sempass2_u2358((&(*t_p0).data), (correctSizeX60gensym86__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__lookups_u3362((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym89__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym89__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__sempass2_u2358((&(*t_p0).data), (correctSizeX60gensym89__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__sempass2_u2486((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__sempass2_u2645(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__sempass2_u3088((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw*)0;
		T21_ = t_p0;
		rawInsert__sempass2_u2931(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3812)(tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw* dest_p0) {
	eqdestroy___semdata_u3609((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3809)(tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NI, rawGet__sempass2_u3685)(tyObject_Table__g77QNejuRRKraNk8K2YkoA t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u132(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__sempass2_u4422)(tyObject_Table__g77QNejuRRKraNk8K2YkoA t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sempass2_u4871)(tyObject_Table__g77QNejuRRKraNk8K2YkoA* t_p0, tySequence__3B6hFqG0Do0FxDvnNucL7w* data_p1, NI key_p2, tySequence__KYLoGmc5aaHsSDjEH1FTxQ val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___semdata_u3618((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sempass2_u4581)(tyObject_Table__g77QNejuRRKraNk8K2YkoA* t_p0) {
	tySequence__3B6hFqG0Do0FxDvnNucL7w n_1;
	NI T1_;
	tySequence__3B6hFqG0Do0FxDvnNucL7w T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__sempass2_u4343((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__g77QNejuRRKraNk8K2YkoA* T17_;
					NI T18_;
					tySequence__KYLoGmc5aaHsSDjEH1FTxQ T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__g77QNejuRRKraNk8K2YkoA*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___semdata_u3606((&n_1.p->data[i_1].Field2));
					rawInsert__sempass2_u4871(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___semdata_u3588(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__sempass2_u5028)(tyObject_Table__g77QNejuRRKraNk8K2YkoA t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__KYLoGmc5aaHsSDjEH1FTxQ*, mgetOrPut__sempass2_u4285)(tyObject_Table__g77QNejuRRKraNk8K2YkoA* t_p0, NI key_p1, tySequence__KYLoGmc5aaHsSDjEH1FTxQ val_p2) {
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__KYLoGmc5aaHsSDjEH1FTxQ*)0;
	{
		NI T3_;
		NI correctSizeX60gensym156__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym156__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__sempass2_u4343((&(*t_p0).data), (correctSizeX60gensym156__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__sempass2_u3685((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__KYLoGmc5aaHsSDjEH1FTxQ colontmpD_;
		tyObject_Table__g77QNejuRRKraNk8K2YkoA* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym159__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym159__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__sempass2_u4343((&(*t_p0).data), (correctSizeX60gensym159__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__sempass2_u4422((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__sempass2_u4581(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__sempass2_u5028((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__g77QNejuRRKraNk8K2YkoA*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___semdata_u3615(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__sempass2_u4871(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__sempass2_u3445)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw t_p0, NI key_p1) {
	NI result;
	NI hcX60gensym108__1;
	NI indexX60gensym108__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym108__1 = (NI)0;
	indexX60gensym108__1 = rawGet__lookups_u3362(t_p0, key_p1, (&hcX60gensym108__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym108__1)) goto LA3_;
		result = t_p0.data.p->data[indexX60gensym108__1].Field2;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14309)(tyTuple__UbCNQED4XJUgxOgPHJUcAQ* dest_p0) {
	eqdestroy___modulegraphs_u14134((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u14306)(tyTuple__UbCNQED4XJUgxOgPHJUcAQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.module = 0;
	(*dest_p0).Field1.item = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NI, rawGet__sempass2_u531)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__sempass2_u870)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__sempass2_u1319)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag* t_p0, tySequence__T7nNEWoEbKBa0G5Htr45Xw* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__juxPMVNF1FoR2ltzeQu8NQ val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___modulegraphs_u14143((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sempass2_u1029)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag* t_p0) {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw n_1;
	NI T1_;
	tySequence__T7nNEWoEbKBa0G5Htr45Xw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__sempass2_u514((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__fZyCWkMwhdvr3pauCNDaag* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					tySequence__juxPMVNF1FoR2ltzeQu8NQ T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__fZyCWkMwhdvr3pauCNDaag*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___modulegraphs_u14131((&n_1.p->data[i_1].Field2));
					rawInsert__sempass2_u1319(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u14113(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__sempass2_u1476)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___sempass2_u457)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__juxPMVNF1FoR2ltzeQu8NQ val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym33__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym33__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__sempass2_u514((&(*t_p0).data), (correctSizeX60gensym33__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__sempass2_u531((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___modulegraphs_u14143((&(*t_p0).data.p->data[index_1].Field2), val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__fZyCWkMwhdvr3pauCNDaag* T21_;
		tySequence__juxPMVNF1FoR2ltzeQu8NQ blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym38__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym38__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__sempass2_u514((&(*t_p0).data), (correctSizeX60gensym38__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__sempass2_u870((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__sempass2_u1029(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__sempass2_u1476((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__fZyCWkMwhdvr3pauCNDaag*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__sempass2_u1319(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__sempass2_u1769)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__sempass2_u531(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__sempass2_u1748)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__sempass2_u1769(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__juxPMVNF1FoR2ltzeQu8NQ*, X5BX5D___sempass2_u1881)(tyObject_Table__fZyCWkMwhdvr3pauCNDaag* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	tySequence__juxPMVNF1FoR2ltzeQu8NQ* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__juxPMVNF1FoR2ltzeQu8NQ*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__sempass2_u531((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__modulegraphs_u4192(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__sempass2_u3678)(tyObject_Table__g77QNejuRRKraNk8K2YkoA t_p0, NI key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__sempass2_u3685(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__KYLoGmc5aaHsSDjEH1FTxQ*, X5BX5D___sempass2_u3999)(tyObject_Table__g77QNejuRRKraNk8K2YkoA* t_p0, NI key_p1) {
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__KYLoGmc5aaHsSDjEH1FTxQ*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__sempass2_u3685((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__ast_u1330(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u3874)(tySequence__dAjyAaabi52TN36Jp0fAXQ dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__X9bWVAqRSgByRpQwn6owzEA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___nilcheck_u10867)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew* dest_p0, tyObject_Table__64AfBrTBCyxlEANlKol6Ew src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___nilcheck_u3874((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__64AfBrTBCyxlEANlKol6Ew, initTable__nilcheck_u10837)(NI initialSize_p0) {
	tyObject_Table__64AfBrTBCyxlEANlKol6Ew result;
	NI correctSizeX60gensym215__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__64AfBrTBCyxlEANlKol6Ew));
	correctSizeX60gensym215__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__nilcheck_u9279((&result.data), (correctSizeX60gensym215__1));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, hash__nilcheck_u3612)(NI x_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = hashWangYi1__pureZhashes_u140(((NU64) (x_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__nilcheck_u3605)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0, NI key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__nilcheck_u3612(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___nilcheck_u3548(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__nilcheck_u9422)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__nilcheck_u9935)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew* t_p0, tySequence__dAjyAaabi52TN36Jp0fAXQ* data_p1, NI key_p2, NI16 val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__nilcheck_u9614)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew* t_p0) {
	tySequence__dAjyAaabi52TN36Jp0fAXQ n_1;
	NI T1_;
	tySequence__dAjyAaabi52TN36Jp0fAXQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__nilcheck_u9279((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__64AfBrTBCyxlEANlKol6Ew* T17_;
					NI T18_;
					NI16 T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__64AfBrTBCyxlEANlKol6Ew*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					T19_ = (NI16)0;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___stdZwidestrs_u81((&n_1.p->data[i_1].Field2));
					rawInsert__nilcheck_u9935(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___nilcheck_u3874(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__nilcheck_u10104)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___nilcheck_u3548(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___nilcheck_u9211)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew* t_p0, NI key_p1, NI16 val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym192__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym192__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__nilcheck_u9279((&(*t_p0).data), (correctSizeX60gensym192__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__nilcheck_u3605((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__64AfBrTBCyxlEANlKol6Ew* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym195__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym195__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__nilcheck_u9279((&(*t_p0).data), (correctSizeX60gensym195__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__nilcheck_u9422((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__nilcheck_u9614(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__nilcheck_u10104((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__64AfBrTBCyxlEANlKol6Ew*)0;
		T21_ = t_p0;
		rawInsert__nilcheck_u9935(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__64AfBrTBCyxlEANlKol6Ew, toTable__nilcheck_u10816)(tyTuple__cyDO9czMbIL47POKM3sIQng* pairs_p0, NI pairs_p0Len_0) {
	tyObject_Table__64AfBrTBCyxlEANlKol6Ew result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__64AfBrTBCyxlEANlKol6Ew));
	result = initTable__nilcheck_u10837(pairs_p0Len_0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI* key_1;
		NI16* val_1;
		NI i_1;
		key_1 = (NI*)0;
		val_1 = (NI16*)0;
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 < pairs_p0Len_0)) goto LA3;
				key_1 = (&pairs_p0[i_1].Field0);
				val_1 = (&pairs_p0[i_1].Field1);
				X5BX5Deq___nilcheck_u9211((&result), (*key_1), (*val_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u10858)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew dest_p0) {
	eqdestroy___nilcheck_u3874(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__nilcheck_u3598)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0, NI key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__nilcheck_u3605(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__nilcheck_u4092)(NI key_p0) {
	NimStringV2 colontmpD_;
	tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q* T2_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q*) nimNewObj(sizeof(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q), NIM_ALIGNOF(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q));
	(*T2_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__jzGRfzBmxnPANjp71FNw5Q_);
	(*T2_).Sup.Sup.Sup.name = "KeyError";
	T3_.len = 0; T3_.p = NIM_NIL;
	colontmpD_ = dollar___nilcheck_u3552(key_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = rawNewString(colontmpD_.len + 15);
appendString((&T3_), TM__4SoG2KRQy3oMm9aUzSLtGrA_9);
appendString((&T3_), colontmpD_);
	(*T2_).Sup.Sup.Sup.message = T3_;
	(*T2_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T2_, "KeyError", "raiseKeyError", "tables.nim", 232);
goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI16*, X5BX5D___nilcheck_u4025)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew* t_p0, NI key_p1) {
	NI16* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI16*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__nilcheck_u3605((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__nilcheck_u4092(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__nilcheck_u11551)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__nilcheck_u8175)(tyObject_Table__64AfBrTBCyxlEANlKol6Ew t_p0, NI key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__nilcheck_u3598(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3964)(tyTuple__EbsafWGli8bW2GRJQ9apsjA* dest_p0) {
	eqdestroy___pureZosproc_u474((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3961)(tyTuple__EbsafWGli8bW2GRJQ9apsjA* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NIM_BOOL, mustRehash__importer_u2506)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__importer_u3015)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg* t_p0, tySequence__QqvaCqCpEE1QmQZbcZLi5A* data_p1, NI key_p2, tySequence__qwqHTkRvwhrRyENtudHQ7g val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___pureZosproc_u483((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__importer_u2698)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg* t_p0) {
	tySequence__QqvaCqCpEE1QmQZbcZLi5A n_1;
	NI T1_;
	tySequence__QqvaCqCpEE1QmQZbcZLi5A T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__importer_u2416((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__toCaB3NxiVHPRVLgcez0Xg* T17_;
					NI T18_;
					tySequence__qwqHTkRvwhrRyENtudHQ7g T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__toCaB3NxiVHPRVLgcez0Xg*)0;
					T17_ = t_p0;
					T18_ = (NI)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___pureZosproc_u471((&n_1.p->data[i_1].Field2));
					rawInsert__importer_u3015(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___semdata_u3898(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__importer_u3184)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg t_p0, NI key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g*, mgetOrPut__importer_u2347)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg* t_p0, NI key_p1, tySequence__qwqHTkRvwhrRyENtudHQ7g val_p2) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__qwqHTkRvwhrRyENtudHQ7g*)0;
	{
		NI T3_;
		NI correctSizeX60gensym114__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym114__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__importer_u2416((&(*t_p0).data), (correctSizeX60gensym114__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__lookups_u5405((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__qwqHTkRvwhrRyENtudHQ7g colontmpD_;
		tyObject_Table__toCaB3NxiVHPRVLgcez0Xg* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym117__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym117__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__importer_u2416((&(*t_p0).data), (correctSizeX60gensym117__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__importer_u2506((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__importer_u2698(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__importer_u3184((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__toCaB3NxiVHPRVLgcez0Xg*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___pureZosproc_u480(val_p2);
		rawInsert__importer_u3015(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1675)(tySequence__zpKGgayc1mFyemMGMuK9a2w dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2.Field0);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__DfjLoSEvFkvlneCb5GSa9cQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1741)(tyTuple__DfjLoSEvFkvlneCb5GSa9cQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field2.Field0);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u1738)(tyTuple__DfjLoSEvFkvlneCb5GSa9cQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	nimZeroMem((void*)(*dest_p0).Field1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	(*dest_p0).Field2.Field0.len = 0; (*dest_p0).Field2.Field0.p = NIM_NIL;
	(*dest_p0).Field2.Field1 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__hBsih9beFksASOhhFeS9aGZw, initTable__cgendata_u2141)(NI initialSize_p0) {
	tyObject_Table__hBsih9beFksASOhhFeS9aGZw result;
	NI correctSizeX60gensym7__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__hBsih9beFksASOhhFeS9aGZw));
	correctSizeX60gensym7__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__cgendata_u2155((&result.data), (correctSizeX60gensym7__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1411)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__9agFg9cuYsNvckAbTfHAsTSA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u670)(tySequence__jwzrUFjG9akTIJTBBFvvqxw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field0);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__XOVT24GHXwqiEj5GCsEGCA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u768)(tySequence__9cbEQVGky3gHl4QEC3q4Sow dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__GhsGHTmri9bgdv8XapNtpTg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___cgen_u30810)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* dest_p0, tyObject_Table__0Na0d2dQ8AYACjty2CqMPA src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___cgendata_u768((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u834)(tyTuple__GhsGHTmri9bgdv8XapNtpTg* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u831)(tyTuple__GhsGHTmri9bgdv8XapNtpTg* dest_p0) {
	(*dest_p0).Field0 = 0;
	nimZeroMem((void*)(*dest_p0).Field1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA, initTable__cgen_u30780)(NI initialSize_p0) {
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA result;
	NI correctSizeX60gensym7887__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA));
	correctSizeX60gensym7887__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__cgen_u2035((&result.data), (correctSizeX60gensym7887__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u30801)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA dest_p0) {
	eqdestroy___cgendata_u768(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___cgen_u30888)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* dest_p0, tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* src_p1) {
	if ((*dest_p0).data.p != (*src_p1).data.p) {	eqdestroy___cgendata_u1411((*dest_p0).data);
	}
(*dest_p0).data.len = (*src_p1).data.len; (*dest_p0).data.p = (*src_p1).data.p;
	(*dest_p0).counter = (*src_p1).counter;
	(*dest_p0).isSorted = (*src_p1).isSorted;
}
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__cgen_u30860)(NI initialSize_p0, tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* Result) {
	NI correctSizeX60gensym7889__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA));
	correctSizeX60gensym7889__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).counter = ((NI)0);
	newSeq__sighashes_u2239((&(*Result).data), (correctSizeX60gensym7889__1));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__cgendata_u538)(NI initialSize_p0, tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* Result) {
	NI correctSizeX60gensym4__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow));
	correctSizeX60gensym4__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).counter = ((NI)0);
	newSeq__cgendata_u550((&(*Result).data), (correctSizeX60gensym4__1));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u519)(tySequence__kxu4GK0onha2t9bo86mdVAg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3085)(tySequence__lCWXucMn9bU7PUqVDK7772w dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLast(dest_p0.p->data[colontmp_].Field3);
				if (!T6_) goto LA7_;
				eqdestroy___docgen_u3106((&(*dest_p0.p->data[colontmp_].Field3)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field3, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__kNIN44R9cL9cYoYzXmSW4y7w));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3536)(tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2.title);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2.linkRelPath);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2.idxPath);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u1172)(tySequence__7lEisrXlQEzwtUKW5pzRCw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__xYhUhS7X82rKTqbT9bRfCnw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u2856)(tySequence__O9a9cp2XDKWshwC0UDgFP6Pw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			eqdestroy___packagesZdocutilsZrst_u2877(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__Na59bk2YQTCLBWTLyeMrWdA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u94)(tySequence__m9axZwxFfhSNLcoofvKZJYA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field2);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field3);
				if (!T6_) goto LA7_;
				eqdestroy___pureZjson_u70((&(*dest_p0.p->data[colontmp_].Field3)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field3, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2732)(tySequence__9at3Cmn7xIajy679cMZSmybg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			eqdestroy___docgen_u2579(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__RrY3dT8dfTceE0s6Bv9bxJw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2263)(tySequence__uAwiTxV3boseSy9a9cSsXHEA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			eqdestroy___docgen_u2284(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__30Ti2rm9aDSr5neUSZP6EVQ));
}
}
static N_INLINE(NI, rawGet__packagesZdocutilsZrst_u940)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, getOrDefault__packagesZdocutilsZrst_u930)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ t_p0, NimStringV2 key_p1, NI32 def_p2) {
	NI32 result;
	NI hcX60gensym16__1;
	NI indexX60gensym16__1;
	NI32 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI32)0;
	hcX60gensym16__1 = (NI)0;
	indexX60gensym16__1 = rawGet__packagesZdocutilsZrst_u940(t_p0, key_p1, (&hcX60gensym16__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI32)0;
	{
		if (!(((NI)0) <= indexX60gensym16__1)) goto LA4_;
		result = t_p0.data.p->data[indexX60gensym16__1].Field2;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u1237)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u1234)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2 = 0;
}
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrst_u1594)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrst_u2019)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ* t_p0, tySequence__7lEisrXlQEzwtUKW5pzRCw* data_p1, NimStringV2 key_p2, NI32 val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrst_u1735)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ* t_p0) {
	tySequence__7lEisrXlQEzwtUKW5pzRCw n_1;
	NI T1_;
	tySequence__7lEisrXlQEzwtUKW5pzRCw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__packagesZdocutilsZrst_u1472((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ* T17_;
					NI32 T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_ = (NI32)0;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___stdZoserrors_u34((&n_1.p->data[i_1].Field2));
					rawInsert__packagesZdocutilsZrst_u2019(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___packagesZdocutilsZrst_u1172(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrst_u2176)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___packagesZdocutilsZrst_u1421)(tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ* t_p0, NimStringV2 key_p1, NI32 val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym21__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym21__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__packagesZdocutilsZrst_u1472((&(*t_p0).data), (correctSizeX60gensym21__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__packagesZdocutilsZrst_u940((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym24__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym24__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__packagesZdocutilsZrst_u1472((&(*t_p0).data), (correctSizeX60gensym24__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__packagesZdocutilsZrst_u1594((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__packagesZdocutilsZrst_u1735(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__packagesZdocutilsZrst_u2176((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ*)0;
		T21_ = t_p0;
		rawInsert__packagesZdocutilsZrst_u2019(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrst_u1175)(tySequence__7lEisrXlQEzwtUKW5pzRCw* dest_p0, tySequence__7lEisrXlQEzwtUKW5pzRCw src_p1) {
	NI T6_;
	NI colontmp_;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__packagesZdocutilsZrst_u1193((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			(*dest_p0).p->data[colontmp_].Field0 = src_p1.p->data[colontmp_].Field0;
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].Field1), src_p1.p->data[colontmp_].Field1);
			(*dest_p0).p->data[colontmp_].Field2 = src_p1.p->data[colontmp_].Field2;
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vmdef_u568)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* dest_p0, tyObject_Table__tro5f9chxPVpES1mQpDwZtQ src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___vmdef_u577((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u559)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ dest_p0) {
	eqdestroy___vmdef_u577(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u7102)(tyTuple__zExIg9bDTcVf2FHROUpzoow* dest_p0) {
	eqdestroy___modulegraphs_u2823((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u7099)(tyTuple__zExIg9bDTcVf2FHROUpzoow* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.module = 0;
	(*dest_p0).Field1.item = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ, initTable__vtables_u136)(NI initialSize_p0) {
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ result;
	NI correctSizeX60gensym20__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ));
	correctSizeX60gensym20__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__modulegraphs_u7025((&result.data), (correctSizeX60gensym20__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__vtables_u227)(NI initialSize_p0, tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* Result) {
	NI correctSizeX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA));
	correctSizeX60gensym22__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).counter = ((NI)0);
	newSeq__cgmeth_u495((&(*Result).data), (correctSizeX60gensym22__1));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, X5BX5D___vtables_u453)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NI result;
	NI indexX60gensym172__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	indexX60gensym172__1 = rawGet__cgmeth_u332(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	{
		if (!(((NI)0) <= indexX60gensym172__1)) goto LA4_;
		result = (*t_p0).data.p->data[indexX60gensym172__1].Field1;
	}
	goto LA2_;
LA4_: ;
	{
		result = ((NI)0);
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__modulegraphs_u7151)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u621(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__modulegraphs_u8528)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__modulegraphs_u7151(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_u8507)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__modulegraphs_u8528(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__modulegraphs_u7554)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__modulegraphs_u8051)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0, tySequence__q9cHvMDDxYU1hSCdG4YwIhA* data_p1, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p2, tySequence__olFOFaYzOJN9aV5BWqK4b9bA val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___modulegraphs_u2832((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__modulegraphs_u7749)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0) {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA n_1;
	NI T1_;
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u7025((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA T18_;
					tySequence__olFOFaYzOJN9aV5BWqK4b9bA T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__5vmBY49areSIlgIs4A1LLKQ*)0;
					T17_ = t_p0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___ast_u3148((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___modulegraphs_u2820((&n_1.p->data[i_1].Field2));
					rawInsert__modulegraphs_u8051(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u7400(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__modulegraphs_u8208)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___ast_u617(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___modulegraphs_u6956)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__olFOFaYzOJN9aV5BWqK4b9bA val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym76__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym76__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u7025((&(*t_p0).data), (correctSizeX60gensym76__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__modulegraphs_u7151((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___modulegraphs_u2832((&(*t_p0).data.p->data[index_1].Field2), val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* T21_;
		tySequence__olFOFaYzOJN9aV5BWqK4b9bA blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym81__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym81__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u7025((&(*t_p0).data), (correctSizeX60gensym81__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__modulegraphs_u7554((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__modulegraphs_u7749(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__modulegraphs_u8208((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__5vmBY49areSIlgIs4A1LLKQ*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__modulegraphs_u8051(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__olFOFaYzOJN9aV5BWqK4b9bA*, X5BX5D___modulegraphs_u8590)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__modulegraphs_u7151((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__modulegraphs_u4192(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vtables_u246)(tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA* dest_p0) {
	eqdestroy___modulegraphs_u14008((*dest_p0).data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vtables_u157)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ dest_p0) {
	eqdestroy___modulegraphs_u7400(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__sighashes_u2099)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1) {
	NI result;
	NI h_1;
	NI T6_;
	NI T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NI)0;
	T6_ = hash__modulegraphs_u10758(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = ((*t_p0).data.len-1);
	h_1 = (NI)(T6_ & T7_);
	{
		while (1) {
			NI T15_;
			if (!!(((*t_p0).data.p->data[h_1].Field1 == ((NI)0)))) goto LA9;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = eqeq___modulegraphs_u10735((*t_p0).data.p->data[h_1].Field0, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T12_) goto LA13_;
				result = h_1;
				goto BeforeRet_;
			}
LA13_: ;
			T15_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T15_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA9: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__sighashes_u2080)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI def_p2) {
	NI result;
	NI indexX60gensym214__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	indexX60gensym214__1 = rawGet__sighashes_u2099(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	{
		if (!(((NI)0) <= indexX60gensym214__1)) goto LA4_;
		result = (*t_p0).data.p->data[indexX60gensym214__1].Field1;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___sighashes_u2214)(tyTuple__9agFg9cuYsNvckAbTfHAsTSA* dest_p0) {
	nimZeroMem((void*)(*dest_p0).Field0, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	(*dest_p0).Field1 = 0;
}
static N_INLINE(NIM_BOOL, mustRehash__sighashes_u2251)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ctRawInsert__sighashes_u2318)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0, tySequence__9bRXJy1JXrQ4hWpStaKBpXg* data_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p2, NI val_p3) {
	NI h_1;
	NI T1_;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI)0;
	T1_ = hash__modulegraphs_u10758(key_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = ((*data_p1).len-1);
	h_1 = (NI)(T1_ & T2_);
	{
		while (1) {
			NI T5_;
			if (!!(((*data_p1).p->data[h_1].Field1 == ((NI)0)))) goto LA4;
			T5_ = ((*data_p1).len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA4: ;
	}
	nimCopyMem((void*)(*data_p1).p->data[h_1].Field0, (NIM_CONST void*)key_p2, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	(*data_p1).p->data[h_1].Field1 = val_p3;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__sighashes_u2285)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0) {
	tySequence__9bRXJy1JXrQ4hWpStaKBpXg n_1;
	NI T1_;
	tySequence__9bRXJy1JXrQ4hWpStaKBpXg T12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__sighashes_u2239((&n_1), ((NI)(T1_ * ((NI)2))));
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((*t_p0).data.len-1);
		colontmp_ = T3_;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA5;
				i_1 = ((NI) (res_1));
				{
					tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T10_;
					NI T11_;
					if (!!(((*t_p0).data.p->data[i_1].Field1 == ((NI)0)))) goto LA8_;
					nimCopyMem((void*)T10_, (NIM_CONST void*)(*t_p0).data.p->data[i_1].Field0, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
					eqwasMoved___OOZdistZchecksumsZsrcZchecksumsZmd5_u241((*t_p0).data.p->data[i_1].Field0);
					T11_ = (NI)0;
					T11_ = (*t_p0).data.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&(*t_p0).data.p->data[i_1].Field1));
					ctRawInsert__sighashes_u2318((&(*t_p0)), (&n_1), T10_, T11_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA8_: ;
				res_1 += ((NI)1);
			} LA5: ;
		}
	}
	T12_.len = 0; T12_.p = NIM_NIL;
	T12_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T12_;
	eqdestroy___cgendata_u1411(n_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, inc__sighashes_u2148)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI val_p2) {
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	index_1 = rawGet__sighashes_u2099((&(*t_p0)), key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA3_;
		(*t_p0).data.p->data[index_1].Field1 += val_p2;
		{
			NI mskX60gensym195__1;
			NI T9_;
			if (!((*t_p0).data.p->data[index_1].Field1 == ((NI)0))) goto LA7_;
			T9_ = ((*t_p0).data.len-1);
			mskX60gensym195__1 = T9_;
			{
				if (!(((NI)0) <= index_1)) goto LA12_;
				(*t_p0).counter -= ((NI)1);
				{
					{
						while (1) {
							NI jX60gensym195__1;
							NI rX60gensym195__1;
							jX60gensym195__1 = index_1;
							rX60gensym195__1 = jX60gensym195__1;
							(*t_p0).data.p->data[index_1].Field1 = ((NI)0);
							reset__sighashes_u2191((*t_p0).data.p->data[index_1].Field0);
							reset__ast_u2522((&(*t_p0).data.p->data[index_1].Field1));
							{
								while (1) {
									NI T23_;
									index_1 = (NI)((NI)(index_1 + ((NI)1)) & mskX60gensym195__1);
									{
										if (!((*t_p0).data.p->data[index_1].Field1 == ((NI)0))) goto LA21_;
										goto LA14;
									}
LA21_: ;
									T23_ = (NI)0;
									T23_ = hash__modulegraphs_u10758((*t_p0).data.p->data[index_1].Field0);
									if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
									rX60gensym195__1 = (NI)(T23_ & mskX60gensym195__1);
									{
										NIM_BOOL T26_;
										NIM_BOOL T27_;
										NIM_BOOL T28_;
										NIM_BOOL T31_;
										NIM_BOOL T34_;
										T26_ = (NIM_BOOL)0;
										T27_ = (NIM_BOOL)0;
										T28_ = (NIM_BOOL)0;
										T28_ = (rX60gensym195__1 <= index_1);
										if (!(T28_)) goto LA29_;
										T28_ = (jX60gensym195__1 < rX60gensym195__1);
LA29_: ;
										T27_ = T28_;
										if (T27_) goto LA30_;
										T31_ = (NIM_BOOL)0;
										T31_ = (jX60gensym195__1 < rX60gensym195__1);
										if (!(T31_)) goto LA32_;
										T31_ = (index_1 < jX60gensym195__1);
LA32_: ;
										T27_ = T31_;
LA30_: ;
										T26_ = T27_;
										if (T26_) goto LA33_;
										T34_ = (NIM_BOOL)0;
										T34_ = (index_1 < jX60gensym195__1);
										if (!(T34_)) goto LA35_;
										T34_ = (rX60gensym195__1 <= index_1);
LA35_: ;
										T26_ = T34_;
LA33_: ;
										if (!!(T26_)) goto LA36_;
										goto LA17;
									}
LA36_: ;
								}
							} LA17: ;
							(*t_p0).data.p->data[jX60gensym195__1] = (*t_p0).data.p->data[index_1];
							eqwasMoved___sighashes_u2214((&(*t_p0).data.p->data[index_1]));
						}
					}
				} LA14: ;
			}
LA12_: ;
		}
LA7_: ;
	}
	goto LA1_;
LA3_: ;
	{
		{
			tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA T53_;
			if (!!((val_p2 == ((NI)0)))) goto LA41_;
			{
				NI T45_;
				NI correctSizeX60gensym112__1;
				T45_ = (*t_p0).data.len;
				if (!(T45_ == ((NI)0))) goto LA46_;
				correctSizeX60gensym112__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				(*t_p0).counter = ((NI)0);
				newSeq__sighashes_u2239((&(*t_p0).data), (correctSizeX60gensym112__1));
			}
LA46_: ;
			{
				NIM_BOOL T50_;
				T50_ = (NIM_BOOL)0;
				T50_ = mustRehash__sighashes_u2251((&(*t_p0)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T50_) goto LA51_;
				enlarge__sighashes_u2285(t_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA51_: ;
			T53_ = (*t_p0);
			ctRawInsert__sighashes_u2318((&T53_), (&(*t_p0).data), key_p1, val_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter += ((NI)1);
		}
LA41_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__cgen_u1549)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__modulegraphs_u10758(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___modulegraphs_u10735(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOrDefault__cgen_u1536)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1) {
	NimStringV2 result;
	NI hcX60gensym175__1;
	NI indexX60gensym175__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	hcX60gensym175__1 = (NI)0;
	indexX60gensym175__1 = rawGet__cgen_u1549(t_p0, key_p1, (&hcX60gensym175__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym175__1)) goto LA3_;
		eqcopy___system_u2694((&result), t_p0.data.p->data[indexX60gensym175__1].Field2);
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__cgen_u2178)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__cgen_u2683)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* t_p0, tySequence__9cbEQVGky3gHl4QEC3q4Sow* data_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p2, NimStringV2 val_p3, NI hc_p4, NI h_p5) {
	nimCopyMem((void*)(*data_p1).p->data[h_p5].Field1, (NIM_CONST void*)key_p2, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	eqsink___system_u2700((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgen_u2370)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* t_p0) {
	tySequence__9cbEQVGky3gHl4QEC3q4Sow n_1;
	NI T1_;
	tySequence__9cbEQVGky3gHl4QEC3q4Sow T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__cgen_u2035((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* T17_;
					tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T18_;
					NimStringV2 T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__0Na0d2dQ8AYACjty2CqMPA*)0;
					T17_ = t_p0;
					nimCopyMem((void*)T18_, (NIM_CONST void*)n_1.p->data[i_1].Field1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
					eqwasMoved___OOZdistZchecksumsZsrcZchecksumsZmd5_u241(n_1.p->data[i_1].Field1);
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field2));
					rawInsert__cgen_u2683(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___cgendata_u768(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__cgen_u2852)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___modulegraphs_u10735(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___cgen_u1967)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NimStringV2 val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym197__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym197__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__cgen_u2035((&(*t_p0).data), (correctSizeX60gensym197__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__cgen_u1549((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___system_u2700((&(*t_p0).data.p->data[index_1].Field2), val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* T21_;
		NimStringV2 blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym200__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym200__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__cgen_u2035((&(*t_p0).data), (correctSizeX60gensym200__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__cgen_u2178((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__cgen_u2370(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__cgen_u2852((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__0Na0d2dQ8AYACjty2CqMPA*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__cgen_u2683(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, raiseKeyError__cgen_u3388)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p0) {
	NimStringV2 colontmpD_;
	tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q* T2_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q*) nimNewObj(sizeof(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q), NIM_ALIGNOF(tyObject_KeyError__jzGRfzBmxnPANjp71FNw5Q));
	(*T2_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__jzGRfzBmxnPANjp71FNw5Q_);
	(*T2_).Sup.Sup.Sup.name = "KeyError";
	T3_.len = 0; T3_.p = NIM_NIL;
	colontmpD_ = dollar___modulegraphs_u10732(key_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = rawNewString(colontmpD_.len + 15);
appendString((&T3_), TM__4SoG2KRQy3oMm9aUzSLtGrA_10);
appendString((&T3_), colontmpD_);
	(*T2_).Sup.Sup.Sup.message = T3_;
	(*T2_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T2_, "KeyError", "raiseKeyError", "tables.nim", 232);
goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2*, X5BX5D___cgen_u3321)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1) {
	NimStringV2* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NimStringV2*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__cgen_u1549((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__cgen_u3388(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__cgen_u1020)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1) {
	NI result;
	NI h_1;
	NI T6_;
	NI T7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (NI)0;
	T6_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T7_ = ((*t_p0).data.len-1);
	h_1 = (NI)(T6_ & T7_);
	{
		while (1) {
			NI T14_;
			if (!!(((*t_p0).data.p->data[h_1].Field1 == ((NI)0)))) goto LA9;
			{
				if (!eqStrings((*t_p0).data.p->data[h_1].Field0, key_p1)) goto LA12_;
				result = h_1;
				goto BeforeRet_;
			}
LA12_: ;
			T14_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA9: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__cgen_u1001)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1, NI def_p2) {
	NI result;
	NI indexX60gensym214__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	indexX60gensym214__1 = rawGet__cgen_u1020(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	{
		if (!(((NI)0) <= indexX60gensym214__1)) goto LA4_;
		result = (*t_p0).data.p->data[indexX60gensym214__1].Field1;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__cgen_u1142)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ctRawInsert__cgen_u1209)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, tySequence__jwzrUFjG9akTIJTBBFvvqxw* data_p1, NimStringV2 key_p2, NI val_p3) {
	NI h_1;
	NI T1_;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = ((*data_p1).len-1);
	h_1 = (NI)(T1_ & T2_);
	{
		while (1) {
			NI T5_;
			if (!!(((*data_p1).p->data[h_1].Field1 == ((NI)0)))) goto LA4;
			T5_ = ((*data_p1).len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA4: ;
	}
	eqcopy___system_u2694((&(*data_p1).p->data[h_1].Field0), key_p2);
	(*data_p1).p->data[h_1].Field1 = val_p3;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgen_u1176)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0) {
	tySequence__jwzrUFjG9akTIJTBBFvvqxw n_1;
	NI T1_;
	tySequence__jwzrUFjG9akTIJTBBFvvqxw T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__cgendata_u550((&n_1), ((NI)(T1_ * ((NI)2))));
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = ((*t_p0).data.len-1);
		colontmp_ = T3_;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA5;
				i_1 = ((NI) (res_1));
				{
					NimStringV2 colontmpD_;
					NI T10_;
					if (!!(((*t_p0).data.p->data[i_1].Field1 == ((NI)0)))) goto LA8_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD_ = (*t_p0).data.p->data[i_1].Field0;
					eqwasMoved___system_u2688((&(*t_p0).data.p->data[i_1].Field0));
					T10_ = (NI)0;
					T10_ = (*t_p0).data.p->data[i_1].Field1;
					eqwasMoved___system_u8088((&(*t_p0).data.p->data[i_1].Field1));
					ctRawInsert__cgen_u1209((&(*t_p0)), (&n_1), colontmpD_, T10_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA8_: ;
				res_1 += ((NI)1);
			} LA5: ;
		}
	}
	T11_.len = 0; T11_.p = NIM_NIL;
	T11_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T11_;
	eqdestroy___cgendata_u670(n_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, inc__cgen_u1077)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1, NI val_p2) {
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	index_1 = rawGet__cgen_u1020((&(*t_p0)), key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA3_;
		(*t_p0).data.p->data[index_1].Field1 += val_p2;
		{
			NI mskX60gensym195__1;
			NI T9_;
			if (!((*t_p0).data.p->data[index_1].Field1 == ((NI)0))) goto LA7_;
			T9_ = ((*t_p0).data.len-1);
			mskX60gensym195__1 = T9_;
			{
				if (!(((NI)0) <= index_1)) goto LA12_;
				(*t_p0).counter -= ((NI)1);
				{
					{
						while (1) {
							NI jX60gensym195__1;
							NI rX60gensym195__1;
							tyTuple__XOVT24GHXwqiEj5GCsEGCA T38_;
							jX60gensym195__1 = index_1;
							rX60gensym195__1 = jX60gensym195__1;
							(*t_p0).data.p->data[index_1].Field1 = ((NI)0);
							reset__system_u5461((&(*t_p0).data.p->data[index_1].Field0));
							reset__ast_u2522((&(*t_p0).data.p->data[index_1].Field1));
							{
								while (1) {
									NI T23_;
									index_1 = (NI)((NI)(index_1 + ((NI)1)) & mskX60gensym195__1);
									{
										if (!((*t_p0).data.p->data[index_1].Field1 == ((NI)0))) goto LA21_;
										goto LA14;
									}
LA21_: ;
									T23_ = (NI)0;
									T23_ = hash__pureZhashes_u587((*t_p0).data.p->data[index_1].Field0);
									if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
									rX60gensym195__1 = (NI)(T23_ & mskX60gensym195__1);
									{
										NIM_BOOL T26_;
										NIM_BOOL T27_;
										NIM_BOOL T28_;
										NIM_BOOL T31_;
										NIM_BOOL T34_;
										T26_ = (NIM_BOOL)0;
										T27_ = (NIM_BOOL)0;
										T28_ = (NIM_BOOL)0;
										T28_ = (rX60gensym195__1 <= index_1);
										if (!(T28_)) goto LA29_;
										T28_ = (jX60gensym195__1 < rX60gensym195__1);
LA29_: ;
										T27_ = T28_;
										if (T27_) goto LA30_;
										T31_ = (NIM_BOOL)0;
										T31_ = (jX60gensym195__1 < rX60gensym195__1);
										if (!(T31_)) goto LA32_;
										T31_ = (index_1 < jX60gensym195__1);
LA32_: ;
										T27_ = T31_;
LA30_: ;
										T26_ = T27_;
										if (T26_) goto LA33_;
										T34_ = (NIM_BOOL)0;
										T34_ = (index_1 < jX60gensym195__1);
										if (!(T34_)) goto LA35_;
										T34_ = (rX60gensym195__1 <= index_1);
LA35_: ;
										T26_ = T34_;
LA33_: ;
										if (!!(T26_)) goto LA36_;
										goto LA17;
									}
LA36_: ;
								}
							} LA17: ;
							T38_ = (*t_p0).data.p->data[index_1];
							eqwasMoved___pureZosproc_u2031((&(*t_p0).data.p->data[index_1]));
							eqsink___pureZosproc_u2043((&(*t_p0).data.p->data[jX60gensym195__1]), T38_);
						}
					}
				} LA14: ;
			}
LA12_: ;
		}
LA7_: ;
	}
	goto LA1_;
LA3_: ;
	{
		{
			tyObject_CountTable__LyKUoYAaSNoaROywBdHQow T54_;
			if (!!((val_p2 == ((NI)0)))) goto LA42_;
			{
				NI T46_;
				NI correctSizeX60gensym135__1;
				T46_ = (*t_p0).data.len;
				if (!(T46_ == ((NI)0))) goto LA47_;
				correctSizeX60gensym135__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				(*t_p0).counter = ((NI)0);
				newSeq__cgendata_u550((&(*t_p0).data), (correctSizeX60gensym135__1));
			}
LA47_: ;
			{
				NIM_BOOL T51_;
				T51_ = (NIM_BOOL)0;
				T51_ = mustRehash__cgen_u1142((&(*t_p0)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T51_) goto LA52_;
				enlarge__cgen_u1176(t_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA52_: ;
			T54_ = (*t_p0);
			ctRawInsert__cgen_u1209((&T54_), (&(*t_p0).data), key_p1, val_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter += ((NI)1);
		}
LA42_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___cgen_u4964)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__cgen_u4653((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = &(*t_p0).data.p->data[indexX60gensym22__1].Field2;
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__modulegraphs_u4192(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__cgen_u10594)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__modulegraphs_u10758(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___modulegraphs_u10735(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyTuple__w31HlKXGH5QCPFggOmKfbQ, getOrDefault__cgen_u10580)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1) {
	tyTuple__w31HlKXGH5QCPFggOmKfbQ result;
	NI hcX60gensym912__1;
	NI indexX60gensym912__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyTuple__w31HlKXGH5QCPFggOmKfbQ));
	hcX60gensym912__1 = (NI)0;
	indexX60gensym912__1 = rawGet__cgen_u10594(t_p0, key_p1, (&hcX60gensym912__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym912__1)) goto LA3_;
		eqcopy___cgen_u10911((&result), t_p0.data.p->data[indexX60gensym912__1].Field2);
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__cgen_u11270)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__cgen_u11779)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw* t_p0, tySequence__zpKGgayc1mFyemMGMuK9a2w* data_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p2, tyTuple__w31HlKXGH5QCPFggOmKfbQ val_p3, NI hc_p4, NI h_p5) {
	nimCopyMem((void*)(*data_p1).p->data[h_p5].Field1, (NIM_CONST void*)key_p2, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	eqsink___cgen_u10917((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__cgen_u11462)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw* t_p0) {
	tySequence__zpKGgayc1mFyemMGMuK9a2w n_1;
	NI T1_;
	tySequence__zpKGgayc1mFyemMGMuK9a2w T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__cgendata_u2155((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__hBsih9beFksASOhhFeS9aGZw* T17_;
					tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T18_;
					tyTuple__w31HlKXGH5QCPFggOmKfbQ T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__hBsih9beFksASOhhFeS9aGZw*)0;
					T17_ = t_p0;
					nimCopyMem((void*)T18_, (NIM_CONST void*)n_1.p->data[i_1].Field1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
					eqwasMoved___OOZdistZchecksumsZsrcZchecksumsZmd5_u241(n_1.p->data[i_1].Field1);
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___cgen_u10905((&n_1.p->data[i_1].Field2));
					rawInsert__cgen_u11779(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___cgendata_u1675(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__cgen_u11948)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___modulegraphs_u10735(t_p0.data.p->data[h_1].Field1, key_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___cgen_u11067)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, tyTuple__w31HlKXGH5QCPFggOmKfbQ val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym924__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym924__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__cgendata_u2155((&(*t_p0).data), (correctSizeX60gensym924__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__cgen_u10594((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___cgen_u10917((&(*t_p0).data.p->data[index_1].Field2), val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__hBsih9beFksASOhhFeS9aGZw* T21_;
		tyTuple__w31HlKXGH5QCPFggOmKfbQ blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym927__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym927__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__cgendata_u2155((&(*t_p0).data), (correctSizeX60gensym927__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__cgen_u11270((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__cgen_u11462(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__cgen_u11948((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__hBsih9beFksASOhhFeS9aGZw*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__cgen_u11779(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI32, getOrDefault__cgen_u12552)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0, NimStringV2 key_p1) {
	NI32 result;
	NI hcX60gensym949__1;
	NI indexX60gensym949__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym949__1 = (NI)0;
	indexX60gensym949__1 = rawGet__lineinfos_u707(t_p0, key_p1, (&hcX60gensym949__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym949__1)) goto LA3_;
		result = t_p0.data.p->data[indexX60gensym949__1].Field2;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__cgen_u4146)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = (NI)0;
	T1_ = (NI)0;
	T1_ = rawGet__cgen_u4153(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__cgen_u4125)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__cgen_u4146(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA*, X5BX5D___cgen_u4463)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__cgen_u4153((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__modulegraphs_u4192(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__docgen_u281)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__suggestsymdb_u1622(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, getOrDefault__docgen_u271)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw t_p0, NI32 key_p1, NI32 def_p2) {
	NI32 result;
	NI hcX60gensym0__1;
	NI indexX60gensym0__1;
	NI32 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI32)0;
	hcX60gensym0__1 = (NI)0;
	indexX60gensym0__1 = rawGet__docgen_u281(t_p0, key_p1, (&hcX60gensym0__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI32)0;
	{
		if (!(((NI)0) <= indexX60gensym0__1)) goto LA4_;
		result = t_p0.data.p->data[indexX60gensym0__1].Field2;
	}
	goto LA2_;
LA4_: ;
	{
		result = def_p2;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__docgen_u893)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__docgen_u1338)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw* t_p0, tySequence__kxu4GK0onha2t9bo86mdVAg* data_p1, NI32 key_p2, NI32 val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__docgen_u1052)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw* t_p0) {
	tySequence__kxu4GK0onha2t9bo86mdVAg n_1;
	NI T1_;
	tySequence__kxu4GK0onha2t9bo86mdVAg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__docgen_u765((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__fncSH0hxktvgfMu5tiOgpw* T17_;
					NI32 T18_;
					NI32 T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__fncSH0hxktvgfMu5tiOgpw*)0;
					T17_ = t_p0;
					T18_ = (NI32)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___stdZoserrors_u34((&n_1.p->data[i_1].Field1));
					T19_ = (NI32)0;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___stdZoserrors_u34((&n_1.p->data[i_1].Field2));
					rawInsert__docgen_u1338(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___docgen_u519(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__docgen_u1495)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw t_p0, NI32 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___docgen_u708)(tyObject_Table__fncSH0hxktvgfMu5tiOgpw* t_p0, NI32 key_p1, NI32 val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym5__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym5__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__docgen_u765((&(*t_p0).data), (correctSizeX60gensym5__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__docgen_u281((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__fncSH0hxktvgfMu5tiOgpw* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym8__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym8__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__docgen_u765((&(*t_p0).data), (correctSizeX60gensym8__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__docgen_u893((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__docgen_u1052(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__docgen_u1495((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__fncSH0hxktvgfMu5tiOgpw*)0;
		T21_ = t_p0;
		rawInsert__docgen_u1338(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3178)(tyTuple__Na59bk2YQTCLBWTLyeMrWdA* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
	eqdestroy___packagesZdocutilsZrst_u2877((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u3175)(tyTuple__Na59bk2YQTCLBWTLyeMrWdA* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NI, rawGet__packagesZdocutilsZrst_u4401)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrst_u4679)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrst_u5104)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw* t_p0, tySequence__O9a9cp2XDKWshwC0UDgFP6Pw* data_p1, NimStringV2 key_p2, tySequence__ib5UTyrs9aC6K60sNqKElQA val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___packagesZdocutilsZrst_u2886((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrst_u4820)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw* t_p0) {
	tySequence__O9a9cp2XDKWshwC0UDgFP6Pw n_1;
	NI T1_;
	tySequence__O9a9cp2XDKWshwC0UDgFP6Pw T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__packagesZdocutilsZrst_u4384((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__bzy14J3py7GGCrkIhTsFXw* T17_;
					tySequence__ib5UTyrs9aC6K60sNqKElQA T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__bzy14J3py7GGCrkIhTsFXw*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_.len = 0; T18_.p = NIM_NIL;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___packagesZdocutilsZrst_u2874((&n_1.p->data[i_1].Field2));
					rawInsert__packagesZdocutilsZrst_u5104(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___packagesZdocutilsZrst_u2856(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrst_u5261)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ib5UTyrs9aC6K60sNqKElQA*, mgetOrPut__packagesZdocutilsZrst_u4332)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw* t_p0, NimStringV2 key_p1, tySequence__ib5UTyrs9aC6K60sNqKElQA val_p2) {
	tySequence__ib5UTyrs9aC6K60sNqKElQA* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__ib5UTyrs9aC6K60sNqKElQA*)0;
	{
		NI T3_;
		NI correctSizeX60gensym67__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym67__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__packagesZdocutilsZrst_u4384((&(*t_p0).data), (correctSizeX60gensym67__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__packagesZdocutilsZrst_u4401((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__ib5UTyrs9aC6K60sNqKElQA colontmpD_;
		tyObject_Table__bzy14J3py7GGCrkIhTsFXw* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym72__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym72__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__packagesZdocutilsZrst_u4384((&(*t_p0).data), (correctSizeX60gensym72__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__packagesZdocutilsZrst_u4679((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__packagesZdocutilsZrst_u4820(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__packagesZdocutilsZrst_u5261((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__bzy14J3py7GGCrkIhTsFXw*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___packagesZdocutilsZrst_u2883(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__packagesZdocutilsZrst_u5104(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3602)(tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
	eqdestroy___system_u2691((*dest_p0).Field2.title);
	eqdestroy___system_u2691((*dest_p0).Field2.linkRelPath);
	eqdestroy___system_u2691((*dest_p0).Field2.idxPath);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u3599)(tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2.used = 0;
	(*dest_p0).Field2.fromInfo.line = 0;
	(*dest_p0).Field2.fromInfo.col = 0;
	(*dest_p0).Field2.fromInfo.fileIndex = 0;
	(*dest_p0).Field2.idxPath.len = 0; (*dest_p0).Field2.idxPath.p = NIM_NIL;
	(*dest_p0).Field2.linkRelPath.len = 0; (*dest_p0).Field2.linkRelPath.p = NIM_NIL;
	(*dest_p0).Field2.title.len = 0; (*dest_p0).Field2.title.p = NIM_NIL;
}
static N_INLINE(NI, rawGet__packagesZdocutilsZrst_u14271)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrst_u14598)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrst_u15051)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA* t_p0, tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg* data_p1, NimStringV2 key_p2, tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ* val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___packagesZdocutilsZrst_u15035((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrst_u14739)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA* t_p0) {
	tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg n_1;
	NI T1_;
	tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__packagesZdocutilsZrst_u14254((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA* T17_;
					tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___packagesZdocutilsZrst_u15023((&n_1.p->data[i_1].Field2));
					rawInsert__packagesZdocutilsZrst_u15051(T17_, (&(*t_p0).data), colontmpD_, (&T18_), eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___packagesZdocutilsZrst_u3536(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrst_u15208)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___packagesZdocutilsZrst_u14203)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA* t_p0, NimStringV2 key_p1, tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym683__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym683__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__packagesZdocutilsZrst_u14254((&(*t_p0).data), (correctSizeX60gensym683__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__packagesZdocutilsZrst_u14271((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___packagesZdocutilsZrst_u15035((&(*t_p0).data.p->data[index_1].Field2), val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA* T21_;
		tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym688__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym688__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__packagesZdocutilsZrst_u14254((&(*t_p0).data), (correctSizeX60gensym688__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__packagesZdocutilsZrst_u14598((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__packagesZdocutilsZrst_u14739(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__packagesZdocutilsZrst_u15208((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA*)0;
		T21_ = t_p0;
		nimZeroMem((void*)(&blitTmp_1), sizeof(tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ));
		blitTmp_1 = (*val_p2);
		rawInsert__packagesZdocutilsZrst_u15051(T21_, (&(*t_p0).data), key_p1, (&blitTmp_1), hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__docgen_u4298)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings((*t_p0).data.p->data[h_1].Field2, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__docgen_u4279)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = 0;
	T1_ = (NI)0;
	T1_ = rawGet__docgen_u4298(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__docgen_u4238)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hasKey__docgen_u4279(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3177)(tyTuple__kNIN44R9cL9cYoYzXmSW4y7w* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field2);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0).Field3);
		if (!T3_) goto LA4_;
		eqdestroy___docgen_u3106((&(*(*dest_p0).Field3)));
		nimRawDispose((*dest_p0).Field3, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u3174)(tyTuple__kNIN44R9cL9cYoYzXmSW4y7w* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
	(*dest_p0).Field3 = 0;
}
static N_INLINE(NIM_BOOL, mustRehash__docgen_u4816)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__docgen_u5372)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, tySequence__lCWXucMn9bU7PUqVDK7772w* data_p1, NimStringV2 key_p2, tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field2), key_p2);
	eqsink___docgen_u4012(&(*data_p1).p->data[h_p5].Field3, val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	(*data_p1).p->data[h_p5].Field1 = ((NI)-1);
	{
		if (!((*t_p0).first < ((NI)0))) goto LA3_;
		(*t_p0).first = h_p5;
	}
LA3_: ;
	{
		if (!(((NI)0) <= (*t_p0).last)) goto LA7_;
		(*data_p1).p->data[(*t_p0).last].Field1 = h_p5;
	}
LA7_: ;
	(*t_p0).last = h_p5;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__docgen_u4983)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0) {
	tySequence__lCWXucMn9bU7PUqVDK7772w n_1;
	NI T1_;
	NI h_1;
	tySequence__lCWXucMn9bU7PUqVDK7772w T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__docgen_u4680((&n_1), ((NI)(T1_ * ((NI)2))));
	h_1 = (*t_p0).first;
	(*t_p0).first = ((NI)-1);
	(*t_p0).last = ((NI)-1);
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		while (1) {
			NI nxt_1;
			NI eh_1;
			if (!(((NI)0) <= h_1)) goto LA4;
			nxt_1 = n_1.p->data[h_1].Field1;
			eh_1 = n_1.p->data[h_1].Field0;
			{
				NIM_BOOL T7_;
				NimStringV2 colontmpD_;
				NI j_1;
				NI T10_;
				tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* T15_;
				tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* T16_;
				T7_ = (NIM_BOOL)0;
				T7_ = isFilled__pureZcollectionsZtables_u32(eh_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T7_) goto LA8_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				T10_ = ((*t_p0).data.len-1);
				j_1 = (NI)(eh_1 & T10_);
				{
					while (1) {
						NIM_BOOL T13_;
						NI T14_;
						T13_ = (NIM_BOOL)0;
						T13_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T13_) goto LA12;
						T14_ = ((*t_p0).data.len-1);
						j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T14_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					} LA12: ;
				}
				T15_ = (tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg*)0;
				T15_ = t_p0;
				colontmpD_ = n_1.p->data[h_1].Field2;
				eqwasMoved___system_u2688((&n_1.p->data[h_1].Field2));
				T16_ = NIM_NIL;
				T16_ = n_1.p->data[h_1].Field3;
				eqwasMoved___docgen_u4000((&n_1.p->data[h_1].Field3));
				rawInsert__docgen_u5372(T15_, (&(*t_p0).data), colontmpD_, T16_, n_1.p->data[h_1].Field0, j_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___system_u2691(colontmpD_);
			}
LA8_: ;
			h_1 = nxt_1;
		} LA4: ;
	}
	eqdestroy___docgen_u3085(n_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__docgen_u5634)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = ((*t_p0).data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*t_p0).data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings((*t_p0).data.p->data[h_1].Field2, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___docgen_u4623)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1, tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym151__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym151__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__docgen_u4680((&(*t_p0).data), (correctSizeX60gensym151__1));
		(*t_p0).first = ((NI)-1);
		(*t_p0).last = ((NI)-1);
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__docgen_u4298((&(*t_p0)), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___docgen_u4012(&(*t_p0).data.p->data[index_1].Field3, val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* T21_;
		tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym154__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym154__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__docgen_u4680((&(*t_p0).data), (correctSizeX60gensym154__1));
			(*t_p0).first = ((NI)-1);
			(*t_p0).last = ((NI)-1);
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__docgen_u4816((&(*t_p0)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__docgen_u4983(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__docgen_u5634((&(*t_p0)), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__docgen_u5372(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__docgen_u5925)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings((*t_p0).data.p->data[h_1].Field2, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ**, X5BX5D___docgen_u5918)(tyObject_OrderedTable__f19bVHRoDGzI7CUYmFlMPzg* t_p0, NimStringV2 key_p1) {
	tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ** result;
	NI hcX60gensym97__1;
	NI indexX60gensym97__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ**)0;
	hcX60gensym97__1 = (NI)0;
	indexX60gensym97__1 = rawGet__docgen_u5925((&(*t_p0)), key_p1, (&hcX60gensym97__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym97__1)) goto LA3_;
		result = &(*t_p0).data.p->data[indexX60gensym97__1].Field3;
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2489)(tyTuple__30Ti2rm9aDSr5neUSZP6EVQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
	eqdestroy___docgen_u2284((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2486)(tyTuple__30Ti2rm9aDSr5neUSZP6EVQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NI, rawGet__docgen_u6788)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__docgen_u7078)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__docgen_u7527)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0, tySequence__uAwiTxV3boseSy9a9cSsXHEA* data_p1, NimStringV2 key_p2, tySequence__b9cVyuSHmrW80P0ZGgU2KHA val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___docgen_u2293((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__docgen_u7237)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0) {
	tySequence__uAwiTxV3boseSy9a9cSsXHEA n_1;
	NI T1_;
	tySequence__uAwiTxV3boseSy9a9cSsXHEA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__docgen_u6771((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* T17_;
					tySequence__b9cVyuSHmrW80P0ZGgU2KHA T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_.len = 0; T18_.p = NIM_NIL;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___docgen_u2281((&n_1.p->data[i_1].Field2));
					rawInsert__docgen_u7527(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___docgen_u2263(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__docgen_u7684)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__b9cVyuSHmrW80P0ZGgU2KHA*, mgetOrPut__docgen_u6713)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0, NimStringV2 key_p1, tySequence__b9cVyuSHmrW80P0ZGgU2KHA val_p2) {
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__b9cVyuSHmrW80P0ZGgU2KHA*)0;
	{
		NI T3_;
		NI correctSizeX60gensym241__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym241__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__docgen_u6771((&(*t_p0).data), (correctSizeX60gensym241__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__docgen_u6788((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__b9cVyuSHmrW80P0ZGgU2KHA colontmpD_;
		tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym246__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym246__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__docgen_u6771((&(*t_p0).data), (correctSizeX60gensym246__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__docgen_u7078((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__docgen_u7237(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__docgen_u7684((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___docgen_u2290(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__docgen_u7527(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2798)(tyTuple__RrY3dT8dfTceE0s6Bv9bxJw* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
	eqdestroy___docgen_u2579((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2795)(tyTuple__RrY3dT8dfTceE0s6Bv9bxJw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NI, rawGet__docgen_u8219)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__docgen_u8509)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__docgen_u8958)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* t_p0, tySequence__9at3Cmn7xIajy679cMZSmybg* data_p1, NimStringV2 key_p2, tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___docgen_u2588((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__docgen_u8668)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* t_p0) {
	tySequence__9at3Cmn7xIajy679cMZSmybg n_1;
	NI T1_;
	tySequence__9at3Cmn7xIajy679cMZSmybg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__docgen_u8202((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* T17_;
					tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_.len = 0; T18_.p = NIM_NIL;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___docgen_u2576((&n_1.p->data[i_1].Field2));
					rawInsert__docgen_u8958(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___docgen_u2732(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__docgen_u9115)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg*, mgetOrPut__docgen_u8144)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* t_p0, NimStringV2 key_p1, tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg val_p2) {
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg*)0;
	{
		NI T3_;
		NI correctSizeX60gensym259__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym259__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__docgen_u8202((&(*t_p0).data), (correctSizeX60gensym259__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__docgen_u8219((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg colontmpD_;
		tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym264__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym264__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__docgen_u8202((&(*t_p0).data), (correctSizeX60gensym264__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__docgen_u8509((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__docgen_u8668(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__docgen_u9115((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___docgen_u2585(val_p2);
		rawInsert__docgen_u8958(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGet__pureZjson_u807)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings((*t_p0).data.p->data[h_1].Field2, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__pureZjson_u2974)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
	NI hc_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	hc_1 = 0;
	T1_ = (NI)0;
	T1_ = rawGet__pureZjson_u807(t_p0, key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__pureZjson_u3055)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*t_p0).data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = ((*t_p0).data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = ((*t_p0).data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings((*t_p0).data.p->data[h_1].Field2, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g**, X5BX5D___pureZjson_u3048)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** result;
	NI hcX60gensym97__1;
	NI indexX60gensym97__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g**)0;
	hcX60gensym97__1 = (NI)0;
	indexX60gensym97__1 = rawGet__pureZjson_u3055((&(*t_p0)), key_p1, (&hcX60gensym97__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym97__1)) goto LA3_;
		result = &(*t_p0).data.p->data[indexX60gensym97__1].Field3;
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u161)(tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field2);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field3);
		if (!T3_) goto LA4_;
		eqdestroy___pureZjson_u70((&(*(*dest_p0).Field3)));
		nimRawDispose((*dest_p0).Field3, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZjson_u158)(tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
	(*dest_p0).Field3 = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, initOrderedTable__pureZjson_u457)(NI initialSize_p0, tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* Result) {
	NI correctSizeX60gensym0__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ));
	correctSizeX60gensym0__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).counter = ((NI)0);
	newSeq__pureZjson_u471((&(*Result).data), (correctSizeX60gensym0__1));
	(*Result).first = ((NI)-1);
	(*Result).last = ((NI)-1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__docgen_u11865)(tyObject_Table__I1hAea2wVUrLyIxtQj9cheA t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__pureZjson_u1135)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*t_p0).data.len;
	T1_ = (T2_ < (NI)((*t_p0).counter + (NI)((*t_p0).counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = (*t_p0).data.len;
	T1_ = ((NI)(T4_ - (*t_p0).counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__pureZjson_u1667)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, tySequence__m9axZwxFfhSNLcoofvKZJYA* data_p1, NimStringV2 key_p2, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field2), key_p2);
	eqsink___pureZjson_u333(&(*data_p1).p->data[h_p5].Field3, val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	(*data_p1).p->data[h_p5].Field1 = ((NI)-1);
	{
		if (!((*t_p0).first < ((NI)0))) goto LA3_;
		(*t_p0).first = h_p5;
	}
LA3_: ;
	{
		if (!(((NI)0) <= (*t_p0).last)) goto LA7_;
		(*data_p1).p->data[(*t_p0).last].Field1 = h_p5;
	}
LA7_: ;
	(*t_p0).last = h_p5;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__pureZjson_u1284)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0) {
	tySequence__m9axZwxFfhSNLcoofvKZJYA n_1;
	NI T1_;
	NI h_1;
	tySequence__m9axZwxFfhSNLcoofvKZJYA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__pureZjson_u471((&n_1), ((NI)(T1_ * ((NI)2))));
	h_1 = (*t_p0).first;
	(*t_p0).first = ((NI)-1);
	(*t_p0).last = ((NI)-1);
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		while (1) {
			NI nxt_1;
			NI eh_1;
			if (!(((NI)0) <= h_1)) goto LA4;
			nxt_1 = n_1.p->data[h_1].Field1;
			eh_1 = n_1.p->data[h_1].Field0;
			{
				NIM_BOOL T7_;
				NimStringV2 colontmpD_;
				NI j_1;
				NI T10_;
				tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* T15_;
				tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* T16_;
				T7_ = (NIM_BOOL)0;
				T7_ = isFilled__pureZcollectionsZtables_u32(eh_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T7_) goto LA8_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				T10_ = ((*t_p0).data.len-1);
				j_1 = (NI)(eh_1 & T10_);
				{
					while (1) {
						NIM_BOOL T13_;
						NI T14_;
						T13_ = (NIM_BOOL)0;
						T13_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T13_) goto LA12;
						T14_ = ((*t_p0).data.len-1);
						j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T14_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					} LA12: ;
				}
				T15_ = (tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ*)0;
				T15_ = t_p0;
				colontmpD_ = n_1.p->data[h_1].Field2;
				eqwasMoved___system_u2688((&n_1.p->data[h_1].Field2));
				T16_ = NIM_NIL;
				T16_ = n_1.p->data[h_1].Field3;
				eqwasMoved___pureZjson_u321((&n_1.p->data[h_1].Field3));
				rawInsert__pureZjson_u1667(T15_, (&(*t_p0).data), colontmpD_, T16_, n_1.p->data[h_1].Field0, j_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___system_u2691(colontmpD_);
			}
LA8_: ;
			h_1 = nxt_1;
		} LA4: ;
	}
	eqdestroy___pureZjson_u94(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, rawGetKnownHC__pureZjson_u1929)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = ((*t_p0).data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*t_p0).data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings((*t_p0).data.p->data[h_1].Field2, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = ((*t_p0).data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pureZjson_u739)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym13__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym13__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__pureZjson_u471((&(*t_p0).data), (correctSizeX60gensym13__1));
		(*t_p0).first = ((NI)-1);
		(*t_p0).last = ((NI)-1);
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__pureZjson_u807((&(*t_p0)), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___pureZjson_u333(&(*t_p0).data.p->data[index_1].Field3, val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* T21_;
		tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym18__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym18__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__pureZjson_u471((&(*t_p0).data), (correctSizeX60gensym18__1));
			(*t_p0).first = ((NI)-1);
			(*t_p0).last = ((NI)-1);
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__pureZjson_u1135((&(*t_p0)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__pureZjson_u1284(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__pureZjson_u1929((&(*t_p0)), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__pureZjson_u1667(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZjson_u97)(tySequence__m9axZwxFfhSNLcoofvKZJYA* dest_p0, tySequence__m9axZwxFfhSNLcoofvKZJYA src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__pureZjson_u116((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			(*dest_p0).p->data[colontmp_].Field0 = src_p1.p->data[colontmp_].Field0;
			(*dest_p0).p->data[colontmp_].Field1 = src_p1.p->data[colontmp_].Field1;
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].Field2), src_p1.p->data[colontmp_].Field2);
			{
				if (!src_p1.p->data[colontmp_].Field3) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_].Field3);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_].Field3);
				if (!T16_) goto LA17_;
				eqdestroy___pureZjson_u70((&(*(*dest_p0).p->data[colontmp_].Field3)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_].Field3, ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_].Field3 = src_p1.p->data[colontmp_].Field3;
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZjson_u489)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* dest_p0, tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___pureZjson_u97((&(*dest_p0).data), (*src_p1).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*dest_p0).counter = (*src_p1).counter;
	(*dest_p0).first = (*src_p1).first;
	(*dest_p0).last = (*src_p1).last;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u486)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* dest_p0) {
	eqdestroy___pureZjson_u94((*dest_p0).data);
}
N_LIB_PRIVATE N_NIMCALL(NI, len__packagesZdocutilsZrst_u16315)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ*, X5BX5D___packagesZdocutilsZrst_u15736)(tyObject_Table__KmtoFP03CxvNyT9cF9cS2OGA* t_p0, NimStringV2 key_p1) {
	tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__packagesZdocutilsZrst_u14271((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__packagesZdocutilsZrstgen_u506)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1) {
	NI result;
	NI hcX60gensym10__1;
	NI indexX60gensym10__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	hcX60gensym10__1 = (NI)0;
	indexX60gensym10__1 = rawGet__vmdef_u2388(t_p0, key_p1, (&hcX60gensym10__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym10__1)) goto LA3_;
		result = t_p0.data.p->data[indexX60gensym10__1].Field2;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__docgen_u10125)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__b9cVyuSHmrW80P0ZGgU2KHA*, X5BX5D___docgen_u11008)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0, NimStringV2 key_p1) {
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__b9cVyuSHmrW80P0ZGgU2KHA*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__docgen_u6788((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ib5UTyrs9aC6K60sNqKElQA, getOrDefault__packagesZdocutilsZrst_u6115)(tyObject_Table__bzy14J3py7GGCrkIhTsFXw t_p0, NimStringV2 key_p1, tySequence__ib5UTyrs9aC6K60sNqKElQA def_p2) {
	tySequence__ib5UTyrs9aC6K60sNqKElQA result;
	NI hcX60gensym81__1;
	NI indexX60gensym81__1;
	tySequence__ib5UTyrs9aC6K60sNqKElQA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	hcX60gensym81__1 = (NI)0;
	indexX60gensym81__1 = rawGet__packagesZdocutilsZrst_u4401(t_p0, key_p1, (&hcX60gensym81__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		if (!(((NI)0) <= indexX60gensym81__1)) goto LA4_;
		eqcopy___packagesZdocutilsZrst_u2880((&result), t_p0.data.p->data[indexX60gensym81__1].Field2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA4_: ;
	{
		eqcopy___packagesZdocutilsZrst_u2880((&result), def_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u6726)(tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1.Field0);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1.Field1);
			eqdestroy___packagesZdocutilsZrst_u2877(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__fgn415DvsSyiHk3o9aIYr0w));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u7984)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ dest_p0) {
	eqdestroy___packagesZdocutilsZrst_u6726(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u6426)(tyTuple__fgn415DvsSyiHk3o9aIYr0w* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1.Field0);
	eqdestroy___system_u2691((*dest_p0).Field1.Field1);
	eqdestroy___packagesZdocutilsZrst_u2877((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u6423)(tyTuple__fgn415DvsSyiHk3o9aIYr0w* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.Field0.len = 0; (*dest_p0).Field1.Field0.p = NIM_NIL;
	(*dest_p0).Field1.Field1.len = 0; (*dest_p0).Field1.Field1.p = NIM_NIL;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
static N_INLINE(NI, rawGet__packagesZdocutilsZrst_u6477)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ t_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__packagesZdocutilsZrst_u6484(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___packagesZdocutilsZrst_u6689((&t_p0.data.p->data[h_1].Field1), key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrst_u6813)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrst_u7238)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ* t_p0, tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ* data_p1, tyTuple__UV3llMMYFckfui8YMBuUZA* key_p2, tySequence__ib5UTyrs9aC6K60sNqKElQA val_p3, NI hc_p4, NI h_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___stdZprivateZospaths2_u309((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___packagesZdocutilsZrst_u2886((&(*data_p1).p->data[h_p5].Field2), val_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrst_u6954)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ* t_p0) {
	tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ n_1;
	NI T1_;
	tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__packagesZdocutilsZrst_u6349((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					tyTuple__UV3llMMYFckfui8YMBuUZA colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ* T17_;
					tySequence__ib5UTyrs9aC6K60sNqKElQA T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___stdZprivateZospaths2_u303((&n_1.p->data[i_1].Field1));
					T18_.len = 0; T18_.p = NIM_NIL;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___packagesZdocutilsZrst_u2874((&n_1.p->data[i_1].Field2));
					rawInsert__packagesZdocutilsZrst_u7238(T17_, (&(*t_p0).data), (&colontmpD_), T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___stdZprivateZospaths2_u306((&colontmpD_));
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___packagesZdocutilsZrst_u6726(n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrst_u7395)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ t_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___packagesZdocutilsZrst_u6689((&t_p0.data.p->data[h_1].Field1), key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ib5UTyrs9aC6K60sNqKElQA*, mgetOrPut__packagesZdocutilsZrst_u6296)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ* t_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* key_p1, tySequence__ib5UTyrs9aC6K60sNqKElQA val_p2) {
	tySequence__ib5UTyrs9aC6K60sNqKElQA* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__ib5UTyrs9aC6K60sNqKElQA*)0;
	{
		NI T3_;
		NI correctSizeX60gensym86__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym86__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__packagesZdocutilsZrst_u6349((&(*t_p0).data), (correctSizeX60gensym86__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__packagesZdocutilsZrst_u6477((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__ib5UTyrs9aC6K60sNqKElQA colontmpD_;
		tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym91__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym91__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__packagesZdocutilsZrst_u6349((&(*t_p0).data), (correctSizeX60gensym91__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__packagesZdocutilsZrst_u6813((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__packagesZdocutilsZrst_u6954(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__packagesZdocutilsZrst_u7395((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___packagesZdocutilsZrst_u2883(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__packagesZdocutilsZrst_u7238(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__packagesZdocutilsZrst_u7718)(tyObject_Table__N9c3CcsmyVBdM9bJn2kzIHNQ t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, clear__docgen_u11354)(tyObject_Table__9bGsm9bvOR9cgxGDLbRQOZIDg* t_p0) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*t_p0).data.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
				reset__system_u5461((&(*t_p0).data.p->data[i_1].Field1));
				reset__docgen_u11611((&(*t_p0).data.p->data[i_1].Field2));
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	(*t_p0).counter = ((NI)0);
}
N_LIB_PRIVATE N_NIMCALL(NI, len__docgen_u12624)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg*, X5BX5D___docgen_u12867)(tyObject_Table__qrrJLEdXF8N9bmmMHuYCHPw* t_p0, NimStringV2 key_p1) {
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__docgen_u8219((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__olFOFaYzOJN9aV5BWqK4b9bA*, mgetOrPut__icZreplayer_u1090)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__olFOFaYzOJN9aV5BWqK4b9bA val_p2) {
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA*)0;
	{
		NI T3_;
		NI correctSizeX60gensym54__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym54__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u7025((&(*t_p0).data), (correctSizeX60gensym54__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__modulegraphs_u7151((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__olFOFaYzOJN9aV5BWqK4b9bA colontmpD_;
		tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym57__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym57__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u7025((&(*t_p0).data), (correctSizeX60gensym57__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__modulegraphs_u7554((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__modulegraphs_u7749(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__modulegraphs_u8208((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__5vmBY49areSIlgIs4A1LLKQ*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___modulegraphs_u2829(val_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawInsert__modulegraphs_u8051(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__suggestsymdb_u1615)(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__suggestsymdb_u1622(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___suggestsymdb_u1533)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* dest_p0, tyTuple__tG5yYi8DnD7bl00aT9cgctQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).Field0 = (*src_p1).Field0;
	(*dest_p0).Field1 = (*src_p1).Field1;
	if ((*dest_p0).Field2.lineInfo.p != (*src_p1).Field2.lineInfo.p) {	eqdestroy___suggestsymdb_u735((*dest_p0).Field2.lineInfo);
	}
(*dest_p0).Field2.lineInfo.len = (*src_p1).Field2.lineInfo.len; (*dest_p0).Field2.lineInfo.p = (*src_p1).Field2.lineInfo.p;
	if ((*dest_p0).Field2.sym.p != (*src_p1).Field2.sym.p) {	eqdestroy___ast_u4848((*dest_p0).Field2.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).Field2.sym.len = (*src_p1).Field2.sym.len; (*dest_p0).Field2.sym.p = (*src_p1).Field2.sym.p;
	if ((*dest_p0).Field2.caughtExceptions.p != (*src_p1).Field2.caughtExceptions.p) {	eqdestroy___suggestsymdb_u858((*dest_p0).Field2.caughtExceptions);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).Field2.caughtExceptions.len = (*src_p1).Field2.caughtExceptions.len; (*dest_p0).Field2.caughtExceptions.p = (*src_p1).Field2.caughtExceptions.p;
	(*dest_p0).Field2.caughtExceptionsSet.s.elems = (*src_p1).Field2.caughtExceptionsSet.s.elems;
	(*dest_p0).Field2.caughtExceptionsSet.s.counter = (*src_p1).Field2.caughtExceptionsSet.s.counter;
	(*dest_p0).Field2.caughtExceptionsSet.s.max = (*src_p1).Field2.caughtExceptionsSet.s.max;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field2.caughtExceptionsSet.s.head);
		if (!T3_) goto LA4_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).Field2.caughtExceptionsSet.s.head)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field2.caughtExceptionsSet.s.head, ((NI)8));
	}
LA4_: ;
	(*dest_p0).Field2.caughtExceptionsSet.s.head = (*src_p1).Field2.caughtExceptionsSet.s.head;
	if ((*dest_p0).Field2.caughtExceptionsSet.s.data.p != (*src_p1).Field2.caughtExceptionsSet.s.data.p) {	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).Field2.caughtExceptionsSet.s.data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).Field2.caughtExceptionsSet.s.data.len = (*src_p1).Field2.caughtExceptionsSet.s.data.len; (*dest_p0).Field2.caughtExceptionsSet.s.data.p = (*src_p1).Field2.caughtExceptionsSet.s.data.p;
	nimCopyMem((void*)(*dest_p0).Field2.caughtExceptionsSet.s.a, (NIM_CONST void*)(*src_p1).Field2.caughtExceptionsSet.s.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
	(*dest_p0).Field2.caughtExceptionsSet.len = (*src_p1).Field2.caughtExceptionsSet.len;
	(*dest_p0).Field2.isDecl.s.elems = (*src_p1).Field2.isDecl.s.elems;
	(*dest_p0).Field2.isDecl.s.counter = (*src_p1).Field2.isDecl.s.counter;
	(*dest_p0).Field2.isDecl.s.max = (*src_p1).Field2.isDecl.s.max;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).Field2.isDecl.s.head);
		if (!T8_) goto LA9_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).Field2.isDecl.s.head)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field2.isDecl.s.head, ((NI)8));
	}
LA9_: ;
	(*dest_p0).Field2.isDecl.s.head = (*src_p1).Field2.isDecl.s.head;
	if ((*dest_p0).Field2.isDecl.s.data.p != (*src_p1).Field2.isDecl.s.data.p) {	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).Field2.isDecl.s.data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).Field2.isDecl.s.data.len = (*src_p1).Field2.isDecl.s.data.len; (*dest_p0).Field2.isDecl.s.data.p = (*src_p1).Field2.isDecl.s.data.p;
	nimCopyMem((void*)(*dest_p0).Field2.isDecl.s.a, (NIM_CONST void*)(*src_p1).Field2.isDecl.s.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
	(*dest_p0).Field2.isDecl.len = (*src_p1).Field2.isDecl.len;
	(*dest_p0).Field2.isGenericInstance.s.elems = (*src_p1).Field2.isGenericInstance.s.elems;
	(*dest_p0).Field2.isGenericInstance.s.counter = (*src_p1).Field2.isGenericInstance.s.counter;
	(*dest_p0).Field2.isGenericInstance.s.max = (*src_p1).Field2.isGenericInstance.s.max;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).Field2.isGenericInstance.s.head);
		if (!T13_) goto LA14_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).Field2.isGenericInstance.s.head)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field2.isGenericInstance.s.head, ((NI)8));
	}
LA14_: ;
	(*dest_p0).Field2.isGenericInstance.s.head = (*src_p1).Field2.isGenericInstance.s.head;
	if ((*dest_p0).Field2.isGenericInstance.s.data.p != (*src_p1).Field2.isGenericInstance.s.data.p) {	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).Field2.isGenericInstance.s.data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).Field2.isGenericInstance.s.data.len = (*src_p1).Field2.isGenericInstance.s.data.len; (*dest_p0).Field2.isGenericInstance.s.data.p = (*src_p1).Field2.isGenericInstance.s.data.p;
	nimCopyMem((void*)(*dest_p0).Field2.isGenericInstance.s.a, (NIM_CONST void*)(*src_p1).Field2.isGenericInstance.s.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
	(*dest_p0).Field2.isGenericInstance.len = (*src_p1).Field2.isGenericInstance.len;
	(*dest_p0).Field2.fileIndex = (*src_p1).Field2.fileIndex;
	(*dest_p0).Field2.trackCaughtExceptions = (*src_p1).Field2.trackCaughtExceptions;
	(*dest_p0).Field2.isSorted = (*src_p1).Field2.isSorted;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, del__modulegraphs_u16637)(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ* t_p0, NI32 key_p1) {
	NI hc_1;
	NI i_1;
	NI mskX60gensym44__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	hc_1 = (NI)0;
	i_1 = rawGet__suggestsymdb_u1615((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = ((*t_p0).data.len-1);
	mskX60gensym44__1 = T1_;
	{
		if (!(((NI)0) <= i_1)) goto LA4_;
		(*t_p0).counter -= ((NI)1);
		{
			{
				while (1) {
					NI jX60gensym44__1;
					NI rX60gensym44__1;
					tyTuple__tG5yYi8DnD7bl00aT9cgctQ T30_;
					jX60gensym44__1 = i_1;
					rX60gensym44__1 = jX60gensym44__1;
					(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
					reset__modulegraphs_u16760((&(*t_p0).data.p->data[i_1].Field1));
					reset__modulegraphs_u16822((&(*t_p0).data.p->data[i_1].Field2));
					{
						while (1) {
							i_1 = (NI)((NI)(i_1 + ((NI)1)) & mskX60gensym44__1);
							{
								NIM_BOOL T13_;
								T13_ = (NIM_BOOL)0;
								T13_ = isEmpty__pureZcollectionsZtables_u29((*t_p0).data.p->data[i_1].Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								if (!T13_) goto LA14_;
								goto LA6;
							}
LA14_: ;
							rX60gensym44__1 = (NI)((*t_p0).data.p->data[i_1].Field0 & mskX60gensym44__1);
							{
								NIM_BOOL T18_;
								NIM_BOOL T19_;
								NIM_BOOL T20_;
								NIM_BOOL T23_;
								NIM_BOOL T26_;
								T18_ = (NIM_BOOL)0;
								T19_ = (NIM_BOOL)0;
								T20_ = (NIM_BOOL)0;
								T20_ = (rX60gensym44__1 <= i_1);
								if (!(T20_)) goto LA21_;
								T20_ = (jX60gensym44__1 < rX60gensym44__1);
LA21_: ;
								T19_ = T20_;
								if (T19_) goto LA22_;
								T23_ = (NIM_BOOL)0;
								T23_ = (jX60gensym44__1 < rX60gensym44__1);
								if (!(T23_)) goto LA24_;
								T23_ = (i_1 < jX60gensym44__1);
LA24_: ;
								T19_ = T23_;
LA22_: ;
								T18_ = T19_;
								if (T18_) goto LA25_;
								T26_ = (NIM_BOOL)0;
								T26_ = (i_1 < jX60gensym44__1);
								if (!(T26_)) goto LA27_;
								T26_ = (rX60gensym44__1 <= i_1);
LA27_: ;
								T18_ = T26_;
LA25_: ;
								if (!!(T18_)) goto LA28_;
								goto LA9;
							}
LA28_: ;
						}
					} LA9: ;
					nimZeroMem((void*)(&T30_), sizeof(tyTuple__tG5yYi8DnD7bl00aT9cgctQ));
					T30_.Field0 = (*t_p0).data.p->data[i_1].Field0;
					T30_.Field1 = (*t_p0).data.p->data[i_1].Field1;
					T30_.Field2 = (*t_p0).data.p->data[i_1].Field2;
					eqwasMoved___suggestsymdb_u1521((&(*t_p0).data.p->data[i_1]));
					eqsink___suggestsymdb_u1533((&(*t_p0).data.p->data[jX60gensym44__1]), (&T30_));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
			}
		} LA6: ;
	}
LA4_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__modulegraphs_u17072)(tyObject_Table__w2vCG1OPnHmNolvQVT168g t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11750)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* dest_p0, tyTuple__gnRkA1L4XiR4uByriyHW8Q* src_p1) {
	(*dest_p0).Field0 = (*src_p1).Field0;
	(*dest_p0).Field1 = (*src_p1).Field1;
	if ((*dest_p0).Field2.p != (*src_p1).Field2.p) {	eqdestroy___modulegraphs_u11761((*dest_p0).Field2);
	}
(*dest_p0).Field2.len = (*src_p1).Field2.len; (*dest_p0).Field2.p = (*src_p1).Field2.p;
}
N_LIB_PRIVATE N_NIMCALL(void, del__modulegraphs_u17066)(tyObject_Table__w2vCG1OPnHmNolvQVT168g* t_p0, NI32 key_p1) {
	NI hc_1;
	NI i_1;
	NI mskX60gensym44__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	hc_1 = (NI)0;
	i_1 = rawGet__modulegraphs_u17072((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = ((*t_p0).data.len-1);
	mskX60gensym44__1 = T1_;
	{
		if (!(((NI)0) <= i_1)) goto LA4_;
		(*t_p0).counter -= ((NI)1);
		{
			{
				while (1) {
					NI jX60gensym44__1;
					NI rX60gensym44__1;
					tyTuple__gnRkA1L4XiR4uByriyHW8Q T30_;
					jX60gensym44__1 = i_1;
					rX60gensym44__1 = jX60gensym44__1;
					(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
					reset__modulegraphs_u16760((&(*t_p0).data.p->data[i_1].Field1));
					reset__modulegraphs_u17481((&(*t_p0).data.p->data[i_1].Field2));
					{
						while (1) {
							i_1 = (NI)((NI)(i_1 + ((NI)1)) & mskX60gensym44__1);
							{
								NIM_BOOL T13_;
								T13_ = (NIM_BOOL)0;
								T13_ = isEmpty__pureZcollectionsZtables_u29((*t_p0).data.p->data[i_1].Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								if (!T13_) goto LA14_;
								goto LA6;
							}
LA14_: ;
							rX60gensym44__1 = (NI)((*t_p0).data.p->data[i_1].Field0 & mskX60gensym44__1);
							{
								NIM_BOOL T18_;
								NIM_BOOL T19_;
								NIM_BOOL T20_;
								NIM_BOOL T23_;
								NIM_BOOL T26_;
								T18_ = (NIM_BOOL)0;
								T19_ = (NIM_BOOL)0;
								T20_ = (NIM_BOOL)0;
								T20_ = (rX60gensym44__1 <= i_1);
								if (!(T20_)) goto LA21_;
								T20_ = (jX60gensym44__1 < rX60gensym44__1);
LA21_: ;
								T19_ = T20_;
								if (T19_) goto LA22_;
								T23_ = (NIM_BOOL)0;
								T23_ = (jX60gensym44__1 < rX60gensym44__1);
								if (!(T23_)) goto LA24_;
								T23_ = (i_1 < jX60gensym44__1);
LA24_: ;
								T19_ = T23_;
LA22_: ;
								T18_ = T19_;
								if (T18_) goto LA25_;
								T26_ = (NIM_BOOL)0;
								T26_ = (i_1 < jX60gensym44__1);
								if (!(T26_)) goto LA27_;
								T26_ = (rX60gensym44__1 <= i_1);
LA27_: ;
								T18_ = T26_;
LA25_: ;
								if (!!(T18_)) goto LA28_;
								goto LA9;
							}
LA28_: ;
						}
					} LA9: ;
					T30_ = (*t_p0).data.p->data[i_1];
					eqwasMoved___modulegraphs_u11738((&(*t_p0).data.p->data[i_1]));
					eqsink___modulegraphs_u11750((&(*t_p0).data.p->data[jX60gensym44__1]), (&T30_));
				}
			}
		} LA6: ;
	}
LA4_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGet__cgen_u29842)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__pipelines_u771)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__pipelines_u1196)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* t_p0, tySequence__fdmz6VkIf1ewwrssKYqRFg* data_p1, NI32 key_p2, tySequence__48JTohSgTy339bRxHzUD8KA val_p3, NI hc_p4, NI h_p5) {
	(*data_p1).p->data[h_p5].Field1 = key_p2;
	eqsink___icZic_u16100((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__pipelines_u912)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* t_p0) {
	tySequence__fdmz6VkIf1ewwrssKYqRFg n_1;
	NI T1_;
	tySequence__fdmz6VkIf1ewwrssKYqRFg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__modulegraphs_u11231((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NI j_1;
					NI T12_;
					tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* T17_;
					NI32 T18_;
					tySequence__48JTohSgTy339bRxHzUD8KA T19_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw*)0;
					T17_ = t_p0;
					T18_ = (NI32)0;
					T18_ = n_1.p->data[i_1].Field1;
					eqwasMoved___stdZoserrors_u34((&n_1.p->data[i_1].Field1));
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = n_1.p->data[i_1].Field2;
					eqwasMoved___icZic_u16088((&n_1.p->data[i_1].Field2));
					rawInsert__pipelines_u1196(T17_, (&(*t_p0).data), T18_, T19_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___modulegraphs_u11373(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__pipelines_u1353)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw t_p0, NI32 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__48JTohSgTy339bRxHzUD8KA*, mgetOrPut__pipelines_u654)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* t_p0, NI32 key_p1, tySequence__48JTohSgTy339bRxHzUD8KA val_p2) {
	tySequence__48JTohSgTy339bRxHzUD8KA* result;
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tySequence__48JTohSgTy339bRxHzUD8KA*)0;
	{
		NI T3_;
		NI correctSizeX60gensym57__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym57__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__modulegraphs_u11231((&(*t_p0).data), (correctSizeX60gensym57__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__cgen_u29842((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tySequence__48JTohSgTy339bRxHzUD8KA colontmpD_;
		tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* T20_;
		if (!(index_1 < ((NI)0))) goto LA8_;
		{
			NI T12_;
			NI correctSizeX60gensym60__1;
			T12_ = (*t_p0).data.len;
			if (!(T12_ == ((NI)0))) goto LA13_;
			correctSizeX60gensym60__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__modulegraphs_u11231((&(*t_p0).data), (correctSizeX60gensym60__1));
		}
LA13_: ;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = mustRehash__pipelines_u771((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T17_) goto LA18_;
			enlarge__pipelines_u912(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__pipelines_u1353((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T20_ = (tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw*)0;
		T20_ = t_p0;
		colontmpD_ = eqdup___icZic_u16097(val_p2);
		rawInsert__pipelines_u1196(T20_, (&(*t_p0).data), key_p1, colontmpD_, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA8_: ;
	result = (&(*t_p0).data.p->data[index_1].Field2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u374)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*t_p0).data.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
				reset__modulegraphs_u592((&(*t_p0).data.p->data[i_1].Field1));
				reset__modulegraphs_u655((&(*t_p0).data.p->data[i_1].Field2));
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	(*t_p0).counter = ((NI)0);
}
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u869)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*t_p0).data.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
				reset__modulegraphs_u592((&(*t_p0).data.p->data[i_1].Field1));
				reset__modulegraphs_u1139((&(*t_p0).data.p->data[i_1].Field2));
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	(*t_p0).counter = ((NI)0);
}
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u1571)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*t_p0).data.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
				reset__modulegraphs_u592((&(*t_p0).data.p->data[i_1].Field1));
				reset__modulegraphs_u1841((&(*t_p0).data.p->data[i_1].Field2));
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	(*t_p0).counter = ((NI)0);
}
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u1925)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*t_p0).data.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
				reset__modulegraphs_u592((&(*t_p0).data.p->data[i_1].Field1));
				reset__modulegraphs_u2195((&(*t_p0).data.p->data[i_1].Field2));
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	(*t_p0).counter = ((NI)0);
}
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u2536)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*t_p0).data.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
				reset__modulegraphs_u592((&(*t_p0).data.p->data[i_1].Field1));
				reset__modulegraphs_u2806((&(*t_p0).data.p->data[i_1].Field2));
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	(*t_p0).counter = ((NI)0);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw*, X5BX5D___icZic_u300)(tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw* t_p0, NI32 key_p1) {
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw* result;
	NI hcX60gensym95__1;
	NI indexX60gensym95__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw*)0;
	hcX60gensym95__1 = (NI)0;
	indexX60gensym95__1 = rawGet__icZic_u307(t_p0, key_p1, (&hcX60gensym95__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym95__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym95__1].Field3);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__icZic_u711(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ*, X5BX5D___icZdce_u2147)(tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw* t_p0, NI32 key_p1) {
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ* result;
	NI hcX60gensym95__1;
	NI indexX60gensym95__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ*)0;
	hcX60gensym95__1 = (NI)0;
	indexX60gensym95__1 = rawGet__icZic_u16788(t_p0, key_p1, (&hcX60gensym95__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym95__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym95__1].Field3);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__icZic_u711(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, rawGet__icZdce_u390)(tyObject_Table__t60gWhquDic6PI6CgxHkgw t_p0, NimStringV2 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__pureZhashes_u587(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyTuple__Ll5iolPASSzOEheeSNjmiw*, X5BX5D___icZdce_u1993)(tyObject_Table__t60gWhquDic6PI6CgxHkgw* t_p0, NimStringV2 key_p1) {
	tyTuple__Ll5iolPASSzOEheeSNjmiw* result;
	NI hcX60gensym22__1;
	NI indexX60gensym22__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyTuple__Ll5iolPASSzOEheeSNjmiw*)0;
	hcX60gensym22__1 = (NI)0;
	indexX60gensym22__1 = rawGet__icZdce_u390((*t_p0), key_p1, (&hcX60gensym22__1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= indexX60gensym22__1)) goto LA3_;
		result = (&(*t_p0).data.p->data[indexX60gensym22__1].Field2);
	}
	goto LA1_;
LA3_: ;
	{
		raiseKeyError__msgs_u316(key_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u341)(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZdce_u338)(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
	(*dest_p0).Field2.Field0 = 0;
	(*dest_p0).Field2.Field1 = 0;
}
static N_INLINE(NIM_BOOL, mustRehash__icZdce_u789)(tyObject_Table__t60gWhquDic6PI6CgxHkgw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__icZdce_u1282)(tyObject_Table__t60gWhquDic6PI6CgxHkgw* t_p0, tySequence__UuiPn6QjIiUTdSVwX2PZ6w* data_p1, NimStringV2 key_p2, tyTuple__Ll5iolPASSzOEheeSNjmiw val_p3, NI hc_p4, NI h_p5) {
	eqcopy___system_u2694((&(*data_p1).p->data[h_p5].Field1), key_p2);
	(*data_p1).p->data[h_p5].Field2 = val_p3;
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u641)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__icZdce_u954)(tyObject_Table__t60gWhquDic6PI6CgxHkgw* t_p0) {
	tySequence__UuiPn6QjIiUTdSVwX2PZ6w n_1;
	NI T1_;
	tySequence__UuiPn6QjIiUTdSVwX2PZ6w T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__icZdce_u264((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					NimStringV2 colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__t60gWhquDic6PI6CgxHkgw* T17_;
					tyTuple__Ll5iolPASSzOEheeSNjmiw T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__t60gWhquDic6PI6CgxHkgw*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___system_u2688((&n_1.p->data[i_1].Field1));
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___icZdce_u1262((&n_1.p->data[i_1].Field2));
					rawInsert__icZdce_u1282(T17_, (&(*t_p0).data), colontmpD_, T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(colontmpD_);
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___icZdce_u641(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__icZdce_u1451)(tyObject_Table__t60gWhquDic6PI6CgxHkgw t_p0, NimStringV2 key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqStrings(t_p0.data.p->data[h_1].Field1, key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___icZdce_u204)(tyObject_Table__t60gWhquDic6PI6CgxHkgw* t_p0, NimStringV2 key_p1, tyTuple__Ll5iolPASSzOEheeSNjmiw val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym6__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym6__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__icZdce_u264((&(*t_p0).data), (correctSizeX60gensym6__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__icZdce_u390((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		(*t_p0).data.p->data[index_1].Field2 = val_p2;
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__t60gWhquDic6PI6CgxHkgw* T21_;
		{
			NI T13_;
			NI correctSizeX60gensym11__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym11__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__icZdce_u264((&(*t_p0).data), (correctSizeX60gensym11__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__icZdce_u789((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__icZdce_u954(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__icZdce_u1451((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__t60gWhquDic6PI6CgxHkgw*)0;
		T21_ = t_p0;
		rawInsert__icZdce_u1282(T21_, (&(*t_p0).data), key_p1, val_p2, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__main_u111)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toCountTable__main_u313)(NimStringV2* keys_p0, NI keys_p0Len_0, tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow));
	initCountTable__cgendata_u538(keys_p0Len_0, Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2* key_1;
		NI i_1;
		key_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 < keys_p0Len_0)) goto LA3;
				key_1 = (&keys_p0[i_1]);
				inc__cgen_u1077(Result, (*key_1), ((NI)1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__main_u481)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0) {
	NI result;
	result = (*t_p0).counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__main_u578)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1) {
	NIM_BOOL result;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NI)0;
	T1_ = rawGet__cgen_u1020(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (((NI)0) <= T1_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___main_u431)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* s_p0, tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		if (!((*s_p0).counter == (*t_p1).counter)) goto LA3_;
		{
			NimStringV2 keyX60gensym6__1;
			NI valX60gensym6__1;
			NI L_1;
			keyX60gensym6__1.len = 0; keyX60gensym6__1.p = NIM_NIL;
			valX60gensym6__1 = (NI)0;
			L_1 = len__main_u481(s_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			{
				NI h_1;
				NI colontmp_;
				NI T8_;
				NI res_1;
				h_1 = (NI)0;
				colontmp_ = (NI)0;
				T8_ = ((*s_p0).data.len-1);
				colontmp_ = T8_;
				res_1 = ((NI)0);
				{
					while (1) {
						if (!(res_1 <= colontmp_)) goto LA10;
						h_1 = ((NI) (res_1));
						{
							if (!!(((*s_p0).data.p->data[h_1].Field1 == ((NI)0)))) goto LA13_;
							eqcopy___system_u2694((&keyX60gensym6__1), (*s_p0).data.p->data[h_1].Field0);
							valX60gensym6__1 = (*s_p0).data.p->data[h_1].Field1;
							{
								NIM_BOOL T17_;
								T17_ = (NIM_BOOL)0;
								T17_ = hasKey__main_u578(t_p1, keyX60gensym6__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
								if (!!(T17_)) goto LA18_;
								result = NIM_FALSE;
								eqdestroy___system_u2691(keyX60gensym6__1);
								goto BeforeRet_;
							}
LA18_: ;
							{
								NI T22_;
								T22_ = (NI)0;
								T22_ = getOrDefault__cgen_u1001(t_p1, keyX60gensym6__1, ((NI)0));
								if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
								if (!!((T22_ == valX60gensym6__1))) goto LA23_;
								result = NIM_FALSE;
								eqdestroy___system_u2691(keyX60gensym6__1);
								goto BeforeRet_;
							}
LA23_: ;
						}
LA13_: ;
						res_1 += ((NI)1);
					} LA10: ;
				}
			}
			{
				LA6_:;
			}
			{
				eqdestroy___system_u2691(keyX60gensym6__1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u652)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* dest_p0) {
	eqdestroy___cgendata_u670((*dest_p0).data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u1198)(tySequence__mg32q50AXD9cQ6jovpBmgWA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1.aux);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1.module);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1.linkDesc);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1.linkTitle);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1.link);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1.keyword);
			eqdestroy___packagesZdocutilsZrstidx_u281(dest_p0.p->data[colontmp_].Field2);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__bvjw5f4vMpB9bESWLU7nvyA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrstgen_u2165)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* dest_p0, tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw src_p1) {
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___packagesZdocutilsZrstgen_u1198((*dest_p0).data);
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).counter = src_p1.counter;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u1264)(tyTuple__bvjw5f4vMpB9bESWLU7nvyA* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field1.aux);
	eqdestroy___system_u2691((*dest_p0).Field1.module);
	eqdestroy___system_u2691((*dest_p0).Field1.linkDesc);
	eqdestroy___system_u2691((*dest_p0).Field1.linkTitle);
	eqdestroy___system_u2691((*dest_p0).Field1.link);
	eqdestroy___system_u2691((*dest_p0).Field1.keyword);
	eqdestroy___packagesZdocutilsZrstidx_u281((*dest_p0).Field2);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstgen_u1261)(tyTuple__bvjw5f4vMpB9bESWLU7nvyA* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.kind = 0;
	(*dest_p0).Field1.keyword.len = 0; (*dest_p0).Field1.keyword.p = NIM_NIL;
	(*dest_p0).Field1.link.len = 0; (*dest_p0).Field1.link.p = NIM_NIL;
	(*dest_p0).Field1.linkTitle.len = 0; (*dest_p0).Field1.linkTitle.p = NIM_NIL;
	(*dest_p0).Field1.linkDesc.len = 0; (*dest_p0).Field1.linkDesc.p = NIM_NIL;
	(*dest_p0).Field1.line = 0;
	(*dest_p0).Field1.module.len = 0; (*dest_p0).Field1.module.p = NIM_NIL;
	(*dest_p0).Field1.aux.len = 0; (*dest_p0).Field1.aux.p = NIM_NIL;
	(*dest_p0).Field2.len = 0; (*dest_p0).Field2.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw, initTable__packagesZdocutilsZrstgen_u2333)(NI initialSize_p0) {
	tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw result;
	NI correctSizeX60gensym34__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw));
	correctSizeX60gensym34__1 = slotsNeeded__pureZcollectionsZtables_u43((initialSize_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.counter = ((NI)0);
	newSeq__packagesZdocutilsZrstgen_u2347((&result.data), (correctSizeX60gensym34__1));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u2156)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw dest_p0) {
	eqdestroy___packagesZdocutilsZrstgen_u1198(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(NI, len__packagesZdocutilsZrstgen_u1417)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0) {
	NI result;
	result = t_p0.counter;
	return result;
}
static N_INLINE(NI, rawGet__packagesZdocutilsZrstgen_u1880)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__packagesZdocutilsZrstidx_u322(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = eqeq___packagesZdocutilsZrstgen_u2085((&t_p0.data.p->data[h_1].Field1), key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustRehash__packagesZdocutilsZrstgen_u2714)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	NI T4_;
	T1_ = (NIM_BOOL)0;
	T2_ = t_p0.data.len;
	T1_ = (T2_ < (NI)(t_p0.counter + (NI)(t_p0.counter / ((NI)2))));
	if (T1_) goto LA3_;
	T4_ = t_p0.data.len;
	T1_ = ((NI)(T4_ - t_p0.counter) < ((NI)4));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rawInsert__packagesZdocutilsZrstgen_u3139)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* t_p0, tySequence__mg32q50AXD9cQ6jovpBmgWA* data_p1, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* key_p2, tySequence__36jA1xDCIBAS29cySYLQ7kQ val_p3, NI hc_p4, NI h_p5) {
	eqcopy___packagesZdocutilsZrstidx_u200((&(*data_p1).p->data[h_p5].Field1), key_p2);
	eqsink___packagesZdocutilsZrstidx_u290((&(*data_p1).p->data[h_p5].Field2), val_p3);
	(*data_p1).p->data[h_p5].Field0 = hc_p4;
}
N_LIB_PRIVATE N_NIMCALL(void, enlarge__packagesZdocutilsZrstgen_u2855)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* t_p0) {
	tySequence__mg32q50AXD9cQ6jovpBmgWA n_1;
	NI T1_;
	tySequence__mg32q50AXD9cQ6jovpBmgWA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1.len = 0; n_1.p = NIM_NIL;
	T1_ = (*t_p0).data.len;
	newSeq__packagesZdocutilsZrstgen_u2347((&n_1), ((NI)(T1_ * ((NI)2))));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = (*t_p0).data;
	(*t_p0).data = n_1;
	n_1 = T2_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (n_1.len-1);
		colontmp_ = T4_;
		res_1 = ((NI)0);
		{
			while (1) {
				NI eh_1;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				eh_1 = n_1.p->data[i_1].Field0;
				{
					NIM_BOOL T9_;
					tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ colontmpD_;
					NI j_1;
					NI T12_;
					tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* T17_;
					tySequence__36jA1xDCIBAS29cySYLQ7kQ T18_;
					T9_ = (NIM_BOOL)0;
					T9_ = isFilled__pureZcollectionsZtables_u32(eh_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T9_) goto LA10_;
					nimZeroMem((void*)(&colontmpD_), sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
					T12_ = ((*t_p0).data.len-1);
					j_1 = (NI)(eh_1 & T12_);
					{
						while (1) {
							NIM_BOOL T15_;
							NI T16_;
							T15_ = (NIM_BOOL)0;
							T15_ = isFilled__pureZcollectionsZtables_u32((*t_p0).data.p->data[j_1].Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T15_) goto LA14;
							T16_ = ((*t_p0).data.len-1);
							j_1 = nextTry__pureZcollectionsZtables_u35(j_1, T16_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						} LA14: ;
					}
					T17_ = (tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw*)0;
					T17_ = t_p0;
					colontmpD_ = n_1.p->data[i_1].Field1;
					eqwasMoved___packagesZdocutilsZrstidx_u194((&n_1.p->data[i_1].Field1));
					T18_.len = 0; T18_.p = NIM_NIL;
					T18_ = n_1.p->data[i_1].Field2;
					eqwasMoved___packagesZdocutilsZrstidx_u278((&n_1.p->data[i_1].Field2));
					rawInsert__packagesZdocutilsZrstgen_u3139(T17_, (&(*t_p0).data), (&colontmpD_), T18_, eh_1, j_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___packagesZdocutilsZrstidx_u197((&colontmpD_));
				}
LA10_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	eqdestroy___packagesZdocutilsZrstgen_u1198(n_1);
	}BeforeRet_: ;
}
static N_INLINE(NI, rawGetKnownHC__packagesZdocutilsZrstgen_u3296)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* key_p1, NI hc_p2) {
	NI result;
	NI h_1;
	NI T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		NI T3_;
		T3_ = t_p0.data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = (t_p0.data.len-1);
	h_1 = (NI)(hc_p2 & T6_);
	{
		while (1) {
			NIM_BOOL T9_;
			NI T16_;
			T9_ = (NIM_BOOL)0;
			T9_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T9_) goto LA8;
			{
				NIM_BOOL T12_;
				T12_ = (NIM_BOOL)0;
				T12_ = (t_p0.data.p->data[h_1].Field0 == hc_p2);
				if (!(T12_)) goto LA13_;
				T12_ = eqeq___packagesZdocutilsZrstgen_u2085((&t_p0.data.p->data[h_1].Field1), key_p1);
LA13_: ;
				if (!T12_) goto LA14_;
				result = h_1;
				goto BeforeRet_;
			}
LA14_: ;
			T16_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA8: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___packagesZdocutilsZrstgen_u2549)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* t_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* key_p1, tySequence__36jA1xDCIBAS29cySYLQ7kQ val_p2) {
	NI hc_1;
	NI index_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI correctSizeX60gensym41__1;
		T3_ = (*t_p0).data.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		correctSizeX60gensym41__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter = ((NI)0);
		newSeq__packagesZdocutilsZrstgen_u2347((&(*t_p0).data), (correctSizeX60gensym41__1));
	}
LA4_: ;
	hc_1 = 0;
	index_1 = rawGet__packagesZdocutilsZrstgen_u1880((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) <= index_1)) goto LA8_;
		eqsink___packagesZdocutilsZrstidx_u290((&(*t_p0).data.p->data[index_1].Field2), val_p2);
	}
	goto LA6_;
LA8_: ;
	{
		tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* T21_;
		tySequence__36jA1xDCIBAS29cySYLQ7kQ blitTmp_1;
		{
			NI T13_;
			NI correctSizeX60gensym44__1;
			T13_ = (*t_p0).data.len;
			if (!(T13_ == ((NI)0))) goto LA14_;
			correctSizeX60gensym44__1 = slotsNeeded__pureZcollectionsZtables_u43(((NI)32));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*t_p0).counter = ((NI)0);
			newSeq__packagesZdocutilsZrstgen_u2347((&(*t_p0).data), (correctSizeX60gensym44__1));
		}
LA14_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = mustRehash__packagesZdocutilsZrstgen_u2714((*t_p0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			enlarge__packagesZdocutilsZrstgen_u2855(t_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			index_1 = rawGetKnownHC__packagesZdocutilsZrstgen_u3296((*t_p0), key_p1, hc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
		index_1 = (NI)(((NI)-1) - index_1);
		T21_ = (tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw*)0;
		T21_ = t_p0;
		blitTmp_1 = val_p2;
		rawInsert__packagesZdocutilsZrstgen_u3139(T21_, (&(*t_p0).data), key_p1, blitTmp_1, hc_1, index_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*t_p0).counter += ((NI)1);
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstgen_u2153)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* dest_p0) {
	(*dest_p0).data.len = 0; (*dest_p0).data.p = NIM_NIL;
	(*dest_p0).counter = 0;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__vmprofiler_u1960)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0) {
	NI result;
	result = (*t_p0).counter;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmprofiler_u2707)(tyTuple__7xc1P89akJWzo77UAKrb3aA* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.line = 0;
	(*dest_p0).Field1.col = 0;
	(*dest_p0).Field1.fileIndex = 0;
	(*dest_p0).Field2.time = 0;
	(*dest_p0).Field2.count = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, del__vmprofiler_u2319)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1) {
	NI hc_1;
	NI i_1;
	NI mskX60gensym44__1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	hc_1 = (NI)0;
	i_1 = rawGet__vmprofiler_u236((*t_p0), key_p1, (&hc_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = ((*t_p0).data.len-1);
	mskX60gensym44__1 = T1_;
	{
		if (!(((NI)0) <= i_1)) goto LA4_;
		(*t_p0).counter -= ((NI)1);
		{
			{
				while (1) {
					NI jX60gensym44__1;
					NI rX60gensym44__1;
					jX60gensym44__1 = i_1;
					rX60gensym44__1 = jX60gensym44__1;
					(*t_p0).data.p->data[i_1].Field0 = ((NI)0);
					reset__vmprofiler_u2442((&(*t_p0).data.p->data[i_1].Field1));
					reset__vmprofiler_u2504((&(*t_p0).data.p->data[i_1].Field2));
					{
						while (1) {
							i_1 = (NI)((NI)(i_1 + ((NI)1)) & mskX60gensym44__1);
							{
								NIM_BOOL T13_;
								T13_ = (NIM_BOOL)0;
								T13_ = isEmpty__pureZcollectionsZtables_u29((*t_p0).data.p->data[i_1].Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								if (!T13_) goto LA14_;
								goto LA6;
							}
LA14_: ;
							rX60gensym44__1 = (NI)((*t_p0).data.p->data[i_1].Field0 & mskX60gensym44__1);
							{
								NIM_BOOL T18_;
								NIM_BOOL T19_;
								NIM_BOOL T20_;
								NIM_BOOL T23_;
								NIM_BOOL T26_;
								T18_ = (NIM_BOOL)0;
								T19_ = (NIM_BOOL)0;
								T20_ = (NIM_BOOL)0;
								T20_ = (rX60gensym44__1 <= i_1);
								if (!(T20_)) goto LA21_;
								T20_ = (jX60gensym44__1 < rX60gensym44__1);
LA21_: ;
								T19_ = T20_;
								if (T19_) goto LA22_;
								T23_ = (NIM_BOOL)0;
								T23_ = (jX60gensym44__1 < rX60gensym44__1);
								if (!(T23_)) goto LA24_;
								T23_ = (i_1 < jX60gensym44__1);
LA24_: ;
								T19_ = T23_;
LA22_: ;
								T18_ = T19_;
								if (T18_) goto LA25_;
								T26_ = (NIM_BOOL)0;
								T26_ = (i_1 < jX60gensym44__1);
								if (!(T26_)) goto LA27_;
								T26_ = (rX60gensym44__1 <= i_1);
LA27_: ;
								T18_ = T26_;
LA25_: ;
								if (!!(T18_)) goto LA28_;
								goto LA9;
							}
LA28_: ;
						}
					} LA9: ;
					(*t_p0).data.p->data[jX60gensym44__1] = (*t_p0).data.p->data[i_1];
					eqwasMoved___vmprofiler_u2707((&(*t_p0).data.p->data[i_1]));
				}
			}
		} LA6: ;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, del__vmprofiler_u2229)(tyObject_Table__g39amaj5esSUbnvSF2f9bVgg* t_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA key_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	del__vmprofiler_u2319(t_p0, key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
