/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Sha1State__j6RBAsJ9cSyy7wwO7sc05rw tyObject_Sha1State__j6RBAsJ9cSyy7wwO7sc05rw;
typedef struct tyTuple__8TaWyfF78pGKQc2T027bVA tyTuple__8TaWyfF78pGKQc2T027bVA;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyObject_CountTable__LyKUoYAaSNoaROywBdHQow tyObject_CountTable__LyKUoYAaSNoaROywBdHQow;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw tySequence__jwzrUFjG9akTIJTBBFvvqxw;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g;
typedef struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA tySequence__m9axZwxFfhSNLcoofvKZJYA;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content tySequence__m9axZwxFfhSNLcoofvKZJYA_Content;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw tySequence__fXWXs2NlFKREhy9cn6vokJw;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content tySequence__fXWXs2NlFKREhy9cn6vokJw_Content;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ_Content tySequence__xv3aaFd3JCw8NbmALHiezQ_Content;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyTuple__M7ImznM2hk9a9beBDTxcwGeg;
typedef struct tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw;
typedef struct tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg;
typedef struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw tySequence__hRbbzIynOoxrYjHTIKZ3Gw;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ;
typedef struct tyTuple__Oubp8LPEu86EPyDuc56AXg tyTuple__Oubp8LPEu86EPyDuc56AXg;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw {
	RootObj Sup;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf0;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph1;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend_p0, void* ClE_0);
void* ClE_0;
} tyProc__r9aUd06Iwvw1EZFjqV6w69bQ;
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_9) (tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend_p0);
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_16) (tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend_p0);
typedef NU32 tyArray__qEmXVe9a9cxQumtG9bM0PNunQ[5];
typedef NU8 tyArray__cPt4wmOc2JydnlcujLtYUg[64];
struct tyObject_Sha1State__j6RBAsJ9cSyy7wwO7sc05rw {
	NI count;
	tyArray__qEmXVe9a9cxQumtG9bM0PNunQ state;
	tyArray__cPt4wmOc2JydnlcujLtYUg buf;
};
typedef NU8 tyArray__9amPDC9cslxc3W1WNI8aK5gA[20];
typedef NU8 tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg;
struct tyTuple__8TaWyfF78pGKQc2T027bVA {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NimStringV2 Field5;
	NimStringV2 Field6;
	NimStringV2 Field7;
	NimStringV2 Field8;
	NimStringV2 Field9;
	NimStringV2 Field10;
	NimStringV2 Field11;
	tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg Field12;
};
typedef tyTuple__8TaWyfF78pGKQc2T027bVA tyArray__RQFn3NKTp5P7VzZ9bksPIyA[34];
typedef NU8 tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg;
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw {
  NI len; tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content* p;
};
struct tyObject_CountTable__LyKUoYAaSNoaROywBdHQow {
	tySequence__jwzrUFjG9akTIJTBBFvvqxw data;
	NI counter;
	NIM_BOOL isSorted;
};
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__HzVCwACFYM9cx9aV62PdjtuA;
typedef N_CLOSURE_PTR(void, TM__LO85BC9bl7tvXIPU7J9cRbtA_42) (void);
typedef NU8 tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw;
typedef NU8 tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA[16];
typedef NU8 tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA;
struct tySequence__m9axZwxFfhSNLcoofvKZJYA {
  NI len; tySequence__m9axZwxFfhSNLcoofvKZJYA_Content* p;
};
struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ {
	tySequence__m9axZwxFfhSNLcoofvKZJYA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__fXWXs2NlFKREhy9cn6vokJw {
  NI len; tySequence__fXWXs2NlFKREhy9cn6vokJw_Content* p;
};
struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g {
	NIM_BOOL isUnquoted;
	tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA kind;
union{
	struct {
	NimStringV2 str;
} _kind_1;
	struct {
	NI64 num;
} _kind_2;
	struct {
	NF fnum;
} _kind_3;
	struct {
	NIM_BOOL bval;
} _kind_4;
	struct {
	tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ fields;
} _kind_6;
	struct {
	tySequence__fXWXs2NlFKREhy9cn6vokJw elems;
} _kind_7;
};
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  NI len; tySequence__xv3aaFd3JCw8NbmALHiezQ_Content* p;
};
typedef NU8 tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA;
struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg {
	RootObj Sup;
	NI counter;
	tySequence__xv3aaFd3JCw8NbmALHiezQ data;
	tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA mode;
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NIM_BOOL Field2;
};
struct tyTuple__M7ImznM2hk9a9beBDTxcwGeg {
	NimStringV2 Field0;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field1;
};
typedef tyTuple__M7ImznM2hk9a9beBDTxcwGeg tyArray__3bOxgfcU9blxovcrG6Y9bi6w[13];
typedef NU8 tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw;
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw {
	RootObj Sup;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph0;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw {
  NI len; tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content* p;
};
struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ {
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug {
	NI32 module;
	NI32 symId;
	NI32 typeId_0;
	NIM_BOOL sealed;
	tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ disambTable;
};
typedef NU8 tyEnum_TLLStreamKind__zJDOAevuyfVWFMJ82eilbQ;
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg* s_p0, void* buf_p1, NI bufLen_p2, void* ClE_0);
void* ClE_0;
} tyProc__WBr0JFZ9bbIGwzgqNYcBJtQ;
struct tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg {
	RootObj Sup;
	tyEnum_TLLStreamKind__zJDOAevuyfVWFMJ82eilbQ kind;
	FILE* f;
	NimStringV2 s;
	NI rd;
	NI wr;
	NI lineOffset;
	tyProc__WBr0JFZ9bbIGwzgqNYcBJtQ repl;
	tyProc__HzVCwACFYM9cx9aV62PdjtuA onPrompt;
};
typedef N_CLOSURE_PTR(NI, TM__LO85BC9bl7tvXIPU7J9cRbtA_152) (tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg* s_p0, void* buf_p1, NI bufLen_p2, void* ClE_0);
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
	NimStringV2 Field0;
	NI Field1;
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content { NI cap; tyTuple__XOVT24GHXwqiEj5GCsEGCA data[SEQ_DECL_SIZE]; };
struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field3;
};
struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content { NI cap; tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ data[SEQ_DECL_SIZE]; };
struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content { NI cap; tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* data[SEQ_DECL_SIZE]; };
struct tySequence__xv3aaFd3JCw8NbmALHiezQ_Content { NI cap; tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE]; };
struct tyTuple__Oubp8LPEu86EPyDuc56AXg {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field0;
	NI Field1;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content { NI cap; tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__main_u1404)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___main_u1264)(tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13532)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u14756)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw** dest_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u2138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg** dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___idents_u341)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA** dest_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* src_p1);
N_LIB_PRIVATE N_NIMCALL(NF, epochTime__pureZtimes_u5209)(void);
N_LIB_PRIVATE N_NIMCALL(void, add__commands_u1640)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_CLOSURE(void, customizeForBackend__main_u928)(tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend_p0, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, defineSymbol__condsyms_u4)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1, NimStringV2 value_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u144)(tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw e_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_u629)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, undefSymbol__condsyms_u8)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
static N_INLINE(NIM_BOOL, isEmpty__pathutils_u139)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimcacheDir__options_u3737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosisAbsolute)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, slash___pathutils_u166)(NimStringV2 base_p0, NimStringV2 f_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_CLOSURE(void, compileToBackend__main_u945)(void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, setOutFile__main_u890)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
static N_INLINE(NIM_BOOL, isEmpty__options_u3633)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, hashMainCompilationParams__main_u883)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSha1State__OOZdistZchecksumsZsrcZchecksumsZsha1_u11)(tyObject_Sha1State__j6RBAsJ9cSyy7wwO7sc05rw* Result);
N_LIB_PRIVATE N_NIMCALL(void, update__OOZdistZchecksumsZsrcZchecksumsZsha1_u789)(tyObject_Sha1State__j6RBAsJ9cSyy7wwO7sc05rw* ctx_p0, NIM_CHAR* data_p1, NI data_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetAppFilename)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u3939)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___OOZdistZchecksumsZsrcZchecksumsZsha1_u935)(tyArray__9amPDC9cslxc3W1WNI8aK5gA self_p0);
N_LIB_PRIVATE N_NIMCALL(void, finalize__OOZdistZchecksumsZsrcZchecksumsZsha1_u836)(tyObject_Sha1State__j6RBAsJ9cSyy7wwO7sc05rw* ctx_p0, tyArray__9amPDC9cslxc3W1WNI8aK5gA Result);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
static N_INLINE(NimStringV2, libNameTmpl__main_u892)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToC__main_u748)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(void, initVars__extccomp_u922)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, changeDetectedViaJsonBuildInstructions__extccomp_u2399)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 jsonFile_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, jsonBuildInstructionsFile__extccomp_u1824)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u2135)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ccHasSaneOverflow__extccomp_u1200)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, setPipeLinePass__pipelines_u36)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pass_p1);
N_LIB_PRIVATE N_NIMCALL(void, compilePipelineProject__pipelines_u1693)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, NI32 projectFileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, cgenWriteModules__cgen_u31342)(RootObj* backend_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1);
N_LIB_PRIVATE N_NIMCALL(void, checkIntegrity__icZintegrity_u2180)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, generateCode__icZcbackend_u694)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, callCCompiler__extccomp_u1560)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeJsonBuildInstructions__extccomp_u1844)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* deps_p1);
N_LIB_PRIVATE N_NIMCALL(void, writeDepsFile__main_u35)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, slash___pathutils_u135)(NimStringV2 base_p0, NimStringV2 f_p1);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__stdZsyncio_u485)(NimStringV2 filename_p0, tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg mode_p1, NI bufSize_p2);
static N_INLINE(void, writeLine__msgs_u470)(FILE* f_p0, NimStringV2* x_p1, NI x_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, write__stdZsyncio_u254)(FILE* f_p0, NimStringV2 s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(NI, len__main_u111)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA t_p0);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getModule__modulegraphs_u14809)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, close__stdZsyncio_u268)(FILE* f_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeCMakeDepsFile__main_u297)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, noschangeFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, toCountTable__main_u313)(NimStringV2* keys_p0, NI keys_p0Len_0, tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* Result);
N_LIB_PRIVATE N_NIMCALL(void, initCountTable__cgendata_u538)(NI initialSize_p0, tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__stdZsyncio_u412)(FILE** f_p0, NimStringV2 filename_p1, tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg mode_p2, NI bufSize_p3);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, readLine__stdZsyncio_u290)(FILE* f_p0, NimStringV2* line_p1);
N_LIB_PRIVATE N_NIMCALL(void, inc__cgen_u1077)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1, NI val_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___main_u431)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* s_p0, tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u652)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5506)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToJS__main_u793)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(void, setTarget__platform_u750)(tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA* t_p0, tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw o_p1, tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw c_p2);
N_LIB_PRIVATE N_NIMCALL(void, wantMainModule__modules_u39)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadConfigs__nimconf_u293)(NimStringV2 cfg_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3);
N_LIB_PRIVATE N_NIMCALL(void, commandDoc__docgen_u13481)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(void, setNoteDefaults__options_u510)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw note_p1, NIM_BOOL enabled_p2);
N_LIB_PRIVATE N_NIMCALL(void, commandDoc2__main_u721)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(void, handleDocOutputOptions__docgen_u13475)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, assignIfDefault__main_u689)(NI* result_p0, NI val_p1, NI def_p2);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, commandBuildIndex__docgen_u13609)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 dir_p1, NimStringV2 outFile_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u4029)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(void, commandRst2Html__docgen_u13556)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, NIM_BOOL preferMarkdown_p2);
N_LIB_PRIVATE N_NIMCALL(void, commandRst2TeX__docgen_u13560)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, NIM_BOOL preferMarkdown_p2);
N_LIB_PRIVATE N_NIMCALL(void, commandJson__docgen_u13564)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(void, commandBuildIndexJson__docgen_u13661)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 dir_p1, NimStringV2 outFile_p2);
N_LIB_PRIVATE N_NIMCALL(void, commandTags__docgen_u13587)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(void, commandGenDepend__main_u678)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(void, generateDot__depends_u261)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, NimStringV2 project_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, findExe__pureZos_u76)(NimStringV2 exe_p0, NIM_BOOL followSymlinks_p1, NimStringV2* extensions_p2, NI extensions_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(void, quit__system_u7994)(NimStringV2 errormsg_p0, NI errorcode_p1);
N_LIB_PRIVATE N_NIMCALL(void, execExternalProgram__extccomp_u1040)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 cmd_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2);
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getConfigVar__options_u3603)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 key_p1, NimStringV2 default_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, newJArray__pureZjson_u506)(void);
N_LIB_PRIVATE N_NIMCALL(void, add__pureZjson_u672)(tySequence__fXWXs2NlFKREhy9cn6vokJw* x_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___pureZjson_u2158)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u324)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, newJObject__pureZjson_u443)(void);
static N_INLINE(void, X5BX5Deq___pureZjson_u2308)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* obj_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pureZjson_u739)(tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ* t_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, eqdup___pureZjson_u330)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___lineinfos_u134)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA e_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___pureZjson_u2184)(NIM_BOOL b_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g*, percent___pureZjson_u2187)(tyTuple__M7ImznM2hk9a9beBDTxcwGeg* keyVals_p0, NI keyVals_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getPrefixDir__options_u3645)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_u737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1, tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw flags_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___pureZjson_u4831)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0);
N_LIB_PRIVATE N_NIMCALL(void, commandCheck__main_u682)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(void, navDefinition__icZnavigator_u816)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, navUsages__icZnavigator_u818)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, navDefusages__icZnavigator_u820)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeRodFiles__icZnavigator_u822)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, setUseIc__ast_u834)(NIM_BOOL useIc_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, parseFile__syntaxes_u235)(NI32 fileIdx_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, commandView__main_u879)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosaddFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toAbsolute__pathutils_u201)(NimStringV2 file_p0, NimStringV2 base_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mainCommandArg__options_u3593)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetCurrentDir)(void);
N_LIB_PRIVATE N_NIMCALL(void, rodViewer__icZic_u22333)(NimStringV2 rodfile_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p2);
N_LIB_PRIVATE N_NIMCALL(void, commandInteractive__main_u800)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__main_u1529)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___main_u1463)(tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, initDefines__condsyms_u17)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols_p0);
N_LIB_PRIVATE N_NIMCALL(void, compilePipelineSystemModule__pipelines_u1687)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, compilePipelineModule__pipelines_u501)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, NI32 fileIdx_p1, tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fromModule_p3);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u404)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, makeStdinModule__modules_u52)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg*, llStreamOpenStdIn__llstream_u146)(tyProc__WBr0JFZ9bbIGwzgqNYcBJtQ r_p0, tyProc__HzVCwACFYM9cx9aV62PdjtuA onPrompt_p1);
N_LIB_PRIVATE N_NIMCALL(NI, llReadFromStdin__llstream_u142)(tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg* s_p0, void* buf_p1, NI bufLen_p2);
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___main_u835)(void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(void, flushDot__msgs_u40)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, processPipelineModule__pipelines_u418)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg* stream_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___llstream_u112)(tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3100)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___main_u1494)(tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(void, commandJsonScript__main_u791)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0);
N_LIB_PRIVATE N_NIMCALL(void, runJsonBuildInstructions__extccomp_u3207)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 jsonFile_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dump__vmprofiler_u1894)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* pd_p1);
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringV2* args_p0, NI args_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genSuccessX__msgs_u1683)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u338)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___main_u1302)(tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw* dest_p0);
N_LIB_PRIVATE TNimTypeV2 NTIv2__XnfB9bJveLwILB3YJhrlXxw_;
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_3 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_4 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_5 = { 9 | NIM_STRLIT_FLAG, "useNimRtl" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_6 = {9, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_5};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_7 = { 11 | NIM_STRLIT_FLAG, "unreachable" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_8 = {11, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_7};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_10 = { 1 | NIM_STRLIT_FLAG, "/" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_11 = {1, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_10};
static const struct {
  NI cap; NIM_CHAR data[59+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_13 = { 59 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/main.nim" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_14 = { 8 | NIM_STRLIT_FLAG, "htmldocs" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_15 = {8, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_14};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_17 = { 1 | NIM_STRLIT_FLAG, "_" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_18 = {1, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_17};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_19 = { 3 | NIM_STRLIT_FLAG, ".js" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_20 = {3, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_19};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_21 = { 6 | NIM_STRLIT_FLAG, "$1.lib" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_22 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_21};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_23 = { 7 | NIM_STRLIT_FLAG, "lib$1.a" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_24 = {7, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_23};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_25 = { 12 | NIM_STRLIT_FLAG, "nimBetterRun" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_26 = {12, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_25};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_27 = { 24 | NIM_STRLIT_FLAG, "nimEmulateOverflowChecks" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_28 = {24, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_27};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_29 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_30 = { 20 | NIM_STRLIT_FLAG, "nimIcIntegrityChecks" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_31 = {20, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_30};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_32 = { 5 | NIM_STRLIT_FLAG, ".deps" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_33 = {5, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_32};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_34 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_35 = {1, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_34};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_36 = { 5 | NIM_STRLIT_FLAG, "cdeps" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_37 = {5, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_36};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_38 = { 10 | NIM_STRLIT_FLAG, "ecmascript" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_39 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_38};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_40 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_41 = {11, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_7};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_43 = { 50 | NIM_STRLIT_FLAG, "\'run\' command not available; rebuild with -d:tinyc" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_44 = {50, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_43};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_46 = { 14 | NIM_STRLIT_FLAG, "nimdoc.tex.cfg" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_47 = {14, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_46};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_48 = { 10 | NIM_STRLIT_FLAG, "nimdoc.cfg" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_49 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_48};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_50 = { 6 | NIM_STRLIT_FLAG, "nimdoc" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_51 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_50};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_52 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_53 = {14, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_46};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_54 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_48};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_55 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_50};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_56 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_57 = { 3 | NIM_STRLIT_FLAG, "tex" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_58 = {3, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_57};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_59 = { 4 | NIM_STRLIT_FLAG, "json" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_60 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_59};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_61 = { 4 | NIM_STRLIT_FLAG, "html" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_62 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_61};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_63 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_61};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_64 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_65 = {0, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_64};
static NIM_CONST tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA TM__LO85BC9bl7tvXIPU7J9cRbtA_66 = {
0x00, 0x00, 0x00, 0xe0, 0x1f, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_67 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_48};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_68 = {14, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_46};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_69 = {14, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_46};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_70 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_48};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_71 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_50};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_72 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_73 = {3, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_57};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_74 = {14, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_46};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_75 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_48};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_76 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_50};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_77 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_78 = {14, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_46};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_79 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_48};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_80 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_50};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_81 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_82 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_59};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_83 = {0, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_64};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_84 = {14, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_46};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_85 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_48};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_86 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_50};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_87 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_88 = {14, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_46};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_89 = {10, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_48};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_90 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_50};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_91 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_92 = { 3 | NIM_STRLIT_FLAG, "dot" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_93 = {3, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_92};
static const struct {
  NI cap; NIM_CHAR data[92+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_94 = { 92 | NIM_STRLIT_FLAG, "gendepend: Graphviz\'s tool dot is required,see https://graphviz.org/download for downloading" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_95 = {92, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_94};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_96 = { 12 | NIM_STRLIT_FLAG, "dot -Tpng -o" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_97 = {12, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_96};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_98 = { 3 | NIM_STRLIT_FLAG, "png" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_99 = {3, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_98};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_100 = {3, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_92};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_101 = { 11 | NIM_STRLIT_FLAG, "dump.format" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_102 = {11, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_101};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_103 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_104 = {0, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_103};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_105 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_59};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_106 = { 7 | NIM_STRLIT_FLAG, "version" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_107 = {7, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_106};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_108 = { 6 | NIM_STRLIT_FLAG, "2.2.10" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_109 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_108};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_110 = { 6 | NIM_STRLIT_FLAG, "nimExe" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_111 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_110};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_112 = { 9 | NIM_STRLIT_FLAG, "prefixdir" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_113 = {9, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_112};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_114 = { 7 | NIM_STRLIT_FLAG, "libpath" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_115 = {7, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_114};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_116 = { 12 | NIM_STRLIT_FLAG, "project_path" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_117 = {12, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_116};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_118 = { 15 | NIM_STRLIT_FLAG, "defined_symbols" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_119 = {15, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_118};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_120 = { 9 | NIM_STRLIT_FLAG, "lib_paths" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_121 = {9, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_120};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_122 = { 9 | NIM_STRLIT_FLAG, "lazyPaths" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_123 = {9, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_122};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_124 = { 6 | NIM_STRLIT_FLAG, "outdir" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_125 = {6, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_124};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_126 = { 3 | NIM_STRLIT_FLAG, "out" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_127 = {3, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_126};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_128 = { 8 | NIM_STRLIT_FLAG, "nimcache" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_129 = {8, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_128};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_130 = { 5 | NIM_STRLIT_FLAG, "hints" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_131 = {5, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_130};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_132 = { 8 | NIM_STRLIT_FLAG, "warnings" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_133 = {8, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_132};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_134 = { 39 | NIM_STRLIT_FLAG, "-- list of currently defined symbols --" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_135 = {39, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_134};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_136 = { 17 | NIM_STRLIT_FLAG, "-- end of list --" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_137 = {17, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_136};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_138 = { 8 | NIM_STRLIT_FLAG, "nimcheck" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_139 = {8, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_138};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_140 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_141 = { 9 | NIM_STRLIT_FLAG, "nimscript" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_142 = {9, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_141};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_143 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_144 = { 9 | NIM_STRLIT_FLAG, "nimconfig" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_145 = {9, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_144};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_146 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_147 = { 3 | NIM_STRLIT_FLAG, "rod" };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_148 = {3, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_147};
N_LIB_PRIVATE TNimTypeV2 NTIv2__fynYR66Aq30EaZMWpzeFjw_;
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_150 = {9, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_141};
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_151 = {4, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_3};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_153 = { 31 | NIM_STRLIT_FLAG, "NimScript file does not exist: " };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_154 = {31, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_153};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__LO85BC9bl7tvXIPU7J9cRbtA_156 = { 17 | NIM_STRLIT_FLAG, "invalid command: " };
static const NimStringV2 TM__LO85BC9bl7tvXIPU7J9cRbtA_157 = {17, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_156};
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_12 = {{59, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_13},
((NI)299),
((NI)16)}
;
extern NIM_CONST tyArray__RQFn3NKTp5P7VzZ9bksPIyA OS__platform_u534;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_45 = {{59, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_13},
((NI)317),
((NI)16)}
;
extern NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA ExeExts__pureZos_u75;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_155 = {{59, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_13},
((NI)420),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__LO85BC9bl7tvXIPU7J9cRbtA_158 = {{59, (NimStrPayload*)&TM__LO85BC9bl7tvXIPU7J9cRbtA_13},
((NI)427),
((NI)14)}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static NIM_CONST NU32 TM__LO85BC9bl7tvXIPU7J9cRbtA_2[2] = {3701606400, 2009200640};
N_LIB_PRIVATE TNimTypeV2 NTIv2__XnfB9bJveLwILB3YJhrlXxw_ = {.destructor = (void*)rttiDestroy__main_u1404, .size = sizeof(tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw), .align = (NI16) NIM_ALIGNOF(tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw), .depth = 1, .display = TM__LO85BC9bl7tvXIPU7J9cRbtA_2, .traceImpl = (void*)NIM_NIL, .flags = 0};
static NIM_CONST NU32 TM__LO85BC9bl7tvXIPU7J9cRbtA_149[2] = {3701606400, 702039808};
N_LIB_PRIVATE TNimTypeV2 NTIv2__fynYR66Aq30EaZMWpzeFjw_ = {.destructor = (void*)rttiDestroy__main_u1529, .size = sizeof(tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw), .align = (NI16) NIM_ALIGNOF(tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw), .depth = 1, .display = TM__LO85BC9bl7tvXIPU7J9cRbtA_149, .traceImpl = (void*)NIM_NIL, .flags = 0};
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___main_u1264)(tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).graph1);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0).graph1)));
		nimRawDispose((*dest_p0).graph1, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).conf0);
		if (!T8_) goto LA9_;
		eqdestroy___options_u1751((&(*(*dest_p0).conf0)));
		nimRawDispose((*dest_p0).conf0, ((NI)8));
	}
LA9_: ;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__main_u1404)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___main_u1264((&(*((tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, customizeForBackend__main_u928)(tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend_p0, void* ClE_0) {
	tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw* colonenvP__1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw*) ClE_0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		if (!((*(*colonenvP__1).conf0).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)0))) goto LA3_;
		(*(*colonenvP__1).conf0).backend = backend_p0;
	}
LA3_: ;
	colontmpD_ = dollar___options_u144((*(*colonenvP__1).conf0).backend);
	defineSymbol__condsyms_u4((*(*(*colonenvP__1).graph1).config).symbols, colontmpD_, TM__LO85BC9bl7tvXIPU7J9cRbtA_4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*(*colonenvP__1).conf0).backend) {
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1):
	{
		{
			if (!((*(*colonenvP__1).conf0).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)0))) goto LA8_;
			(*(*colonenvP__1).conf0).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)1);
		}
LA8_: ;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2):
	{
		{
			if (!((*(*colonenvP__1).conf0).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)0))) goto LA13_;
			(*(*colonenvP__1).conf0).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)2);
		}
LA13_: ;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)4):
	{
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3):
	{
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = hcrOn__options_u629((*colonenvP__1).conf0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T19_) goto LA20_;
			undefSymbol__condsyms_u8((*(*colonenvP__1).conf0).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_6);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA20_: ;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)0):
	{
		raiseAssert__stdZassertions_u15(TM__LO85BC9bl7tvXIPU7J9cRbtA_8);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NIM_BOOL, isEmpty__pathutils_u139)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__options_u3633)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, hashMainCompilationParams__main_u883)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyObject_Sha1State__j6RBAsJ9cSyy7wwO7sc05rw state_1;
	tyArray__9amPDC9cslxc3W1WNI8aK5gA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	nimZeroMem((void*)(&state_1), sizeof(tyObject_Sha1State__j6RBAsJ9cSyy7wwO7sc05rw));
	newSha1State__OOZdistZchecksumsZsrcZchecksumsZsha1_u11((&state_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = nosgetAppFilename();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	update__OOZdistZchecksumsZsrcZchecksumsZsha1_u789((&state_1), ((colontmpD_).p) ? (colontmpD_.p->data) : NIM_NIL, colontmpD_.len);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	update__OOZdistZchecksumsZsrcZchecksumsZsha1_u789((&state_1), (((*conf_p0).commandLine).p) ? ((*conf_p0).commandLine.p->data) : NIM_NIL, (*conf_p0).commandLine.len);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = dollar___options_u3939((*conf_p0).projectFull);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	update__OOZdistZchecksumsZsrcZchecksumsZsha1_u789((&state_1), ((colontmpD__2).p) ? (colontmpD__2.p->data) : NIM_NIL, colontmpD__2.len);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)T1_, sizeof(tyArray__9amPDC9cslxc3W1WNI8aK5gA));
	finalize__OOZdistZchecksumsZsrcZchecksumsZsha1_u836((&state_1), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = dollar___OOZdistZchecksumsZsrcZchecksumsZsha1_u935(T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, libNameTmpl__main_u892)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		if (!((*conf_p0).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)2))) goto LA4_;
		result = TM__LO85BC9bl7tvXIPU7J9cRbtA_22;
	}
	goto LA2_;
LA4_: ;
	{
		result = TM__LO85BC9bl7tvXIPU7J9cRbtA_24;
	}
LA2_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setOutFile__main_u890)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 base_1;
		NimStringV2 targetName_1;
		NimStringV2 T12_;
		NimStringV2 blitTmp_1;
		T3_ = (NIM_BOOL)0;
		T3_ = isEmpty__options_u3633((*conf_p0).outFile);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		base_1.len = 0; base_1.p = NIM_NIL;
		targetName_1.len = 0; targetName_1.p = NIM_NIL;
		eqcopy___system_u2694((&base_1), (*conf_p0).projectName);
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 T11_;
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)14)))&63U)))!=0)) goto LA9_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T11_.len = 0; T11_.p = NIM_NIL;
			colontmpD_ = hashMainCompilationParams__main_u883(conf_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T11_ = rawNewString(colontmpD_.len + 1);
appendString((&T11_), TM__LO85BC9bl7tvXIPU7J9cRbtA_18);
appendString((&T11_), colontmpD_);
			colontmpD__2 = T11_;
			prepareAdd((&base_1), colontmpD__2.len + 0);
appendString((&base_1), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
LA9_: ;
		T12_.len = 0; T12_.p = NIM_NIL;
		{
			NimStringV2 T17_;
			if (!((*conf_p0).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA15_;
			T17_.len = 0; T17_.p = NIM_NIL;
			T17_ = rawNewString(base_1.len + 3);
appendString((&T17_), base_1);
appendString((&T17_), TM__LO85BC9bl7tvXIPU7J9cRbtA_20);
			targetName_1 = T17_;
		}
		goto LA13_;
LA15_: ;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)7)))&63U)))!=0)) goto LA19_;
			targetName_1 = nsuFormatSingleElem(OS__platform_u534[((*conf_p0).target.targetOS)- 1].Field2, base_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
		goto LA13_;
LA19_: ;
		{
			NimStringV2 colontmpD__3;
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)8)))&63U)))!=0)) goto LA22_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__3 = libNameTmpl__main_u892(conf_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			targetName_1 = nsuFormatSingleElem(colontmpD__3, base_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			{
				LA24_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
		goto LA13_;
LA22_: ;
		{
			NimStringV2 T28_;
			T28_.len = 0; T28_.p = NIM_NIL;
			T28_ = rawNewString(base_1.len + OS__platform_u534[((*conf_p0).target.targetOS)- 1].Field10.len + 0);
appendString((&T28_), base_1);
appendString((&T28_), OS__platform_u534[((*conf_p0).target.targetOS)- 1].Field10);
			targetName_1 = T28_;
		}
LA13_: ;
		blitTmp_1 = targetName_1;
		eqwasMoved___system_u2688((&targetName_1));
		eqsink___system_u2700((&(*conf_p0).outFile), blitTmp_1);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(targetName_1);
			eqdestroy___system_u2691(base_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, writeLine__msgs_u470)(FILE* f_p0, NimStringV2* x_p1, NI x_p1Len_0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2* i_1;
		NI i_2;
		i_1 = (NimStringV2*)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < x_p1Len_0)) goto LA3;
				i_1 = (&x_p1[i_2]);
				write__stdZsyncio_u254(f_p0, (*i_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	write__stdZsyncio_u254(f_p0, TM__LO85BC9bl7tvXIPU7J9cRbtA_35);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0) {
	NIM_BOOL result;
	result = !((hcode_p0 == ((NI)0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeDepsFile__main_u35)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0) {
	NimStringV2 fname_1;
	NimStringV2 colontmpD_;
	NimStringV2 T2_;
	FILE* f_1;
NIM_BOOL oldNimErrFin25_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	fname_1.len = 0; fname_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = rawNewString((*(*g_p0).config).projectName.len + 5);
appendString((&T2_), (*(*g_p0).config).projectName);
appendString((&T2_), TM__LO85BC9bl7tvXIPU7J9cRbtA_33);
	colontmpD_ = T2_;
	fname_1 = slash___pathutils_u135((*(*g_p0).config).nimcacheDir, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	f_1 = open__stdZsyncio_u485(fname_1, ((tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg)1), ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* m_1;
		NI i_1;
		NI L_1;
		NI T4_;
		m_1 = (tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow*)0;
		i_1 = ((NI)0);
		T4_ = (*g_p0).ifaces.len;
		L_1 = T4_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA6;
				m_1 = (&(*g_p0).ifaces.p->data[i_1]);
				{
					NimStringV2 colontmpD__2;
					tyArray__YgExxhfgKcesA5EOUj1MOA T12_;
					if (!!(((*m_1).module == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA9_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__2 = toFullPath__msgs_u624((*g_p0).config, ((NI32) ((*(*m_1).module).position)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					T12_[0] = colontmpD__2;
					writeLine__msgs_u470(f_1, T12_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					{
						LA11_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA9_: ;
				i_1 += ((NI)1);
			} LA6: ;
		}
	}
	{
		NI32* k_1;
		NI L_2;
		k_1 = (NI32*)0;
		L_2 = len__main_u111((*g_p0).inclToMod);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NI h_1;
			NI colontmp_;
			NI T17_;
			NI res_1;
			h_1 = (NI)0;
			colontmp_ = (NI)0;
			T17_ = ((*g_p0).inclToMod.data.len-1);
			colontmp_ = T17_;
			res_1 = ((NI)0);
			{
				while (1) {
					if (!(res_1 <= colontmp_)) goto LA19;
					h_1 = ((NI) (res_1));
					{
						NIM_BOOL T22_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
						T22_ = (NIM_BOOL)0;
						T22_ = isFilled__pureZcollectionsZtables_u32((*g_p0).inclToMod.data.p->data[h_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!T22_) goto LA23_;
						colontmpD__3 = NIM_NIL;
						k_1 = (&(*g_p0).inclToMod.data.p->data[h_1].Field1);
						{
							NimStringV2 colontmpD__4;
							tyArray__YgExxhfgKcesA5EOUj1MOA T31_;
							colontmpD__3 = getModule__modulegraphs_u14809(g_p0, (*k_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
							if (!(colontmpD__3 == 0)) goto LA28_;
							colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
							colontmpD__4 = toFullPath__msgs_u624((*g_p0).config, (*k_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
							T31_[0] = colontmpD__4;
							writeLine__msgs_u470(f_1, T31_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
							{
								LA30_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__4);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
						}
LA28_: ;
						{
							LA25_:;
						}
						{
							oldNimErrFin25_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u4574(colontmpD__3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							*nimErr_ = oldNimErrFin25_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA23_: ;
					res_1 += ((NI)1);
				} LA19: ;
			}
		}
	}
	close__stdZsyncio_u268(f_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(fname_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeCMakeDepsFile__main_u297)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 fname_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cfiles_1;
	tyObject_CountTable__LyKUoYAaSNoaROywBdHQow fileset_1;
	tyObject_CountTable__LyKUoYAaSNoaROywBdHQow prevset_1;
	FILE* fl_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	fname_1.len = 0; fname_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	cfiles_1.len = 0; cfiles_1.p = NIM_NIL;
	nimZeroMem((void*)(&fileset_1), sizeof(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow));
	nimZeroMem((void*)(&prevset_1), sizeof(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow));
	colontmpD_ = getNimcacheDir__options_u3737(conf_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = noschangeFileExt((*conf_p0).outFile, TM__LO85BC9bl7tvXIPU7J9cRbtA_37);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fname_1 = slash___pathutils_u135(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cfiles_1.len = 0; cfiles_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	{
		tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* it_1;
		NI i_1;
		NI L_1;
		NI T3_;
		it_1 = (tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg*)0;
		i_1 = ((NI)0);
		T3_ = (*conf_p0).toCompile.len;
		L_1 = T3_;
		{
			while (1) {
				NimStringV2 colontmpD__3;
				if (!(i_1 < L_1)) goto LA5;
				it_1 = (&(*conf_p0).toCompile.p->data[i_1]);
				colontmpD__3 = eqdup___system_u2697((*it_1).cname);
				add__stdZenumutils_u71((&cfiles_1), colontmpD__3);
				i_1 += ((NI)1);
			} LA5: ;
		}
	}
	toCountTable__main_u313(((cfiles_1).p) ? (cfiles_1.p->data) : NIM_NIL, cfiles_1.len, (&fileset_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fl_1 = 0;
	initCountTable__cgendata_u538(((NI)32), (&prevset_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = open__stdZsyncio_u412(&fl_1, fname_1, ((tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg)0), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T8_) goto LA9_;
		{
			NimStringV2 line_1;
			NimStringV2 res_1;
			line_1.len = 0; line_1.p = NIM_NIL;
			res_1.len = 0; res_1.p = NIM_NIL;
			res_1 = rawNewString(((NI)80));
			{
				while (1) {
					NIM_BOOL T15_;
					T15_ = (NIM_BOOL)0;
					T15_ = readLine__stdZsyncio_u290(fl_1, (&res_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					if (!T15_) goto LA14;
					line_1 = res_1;
					inc__cgen_u1077((&prevset_1), line_1, ((NI)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				} LA14: ;
			}
			{
				LA12_:;
			}
			{
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		close__stdZsyncio_u268(fl_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = eqeq___main_u431((&fileset_1), (&prevset_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T20_)) goto LA21_;
		fl_1 = open__stdZsyncio_u485(fname_1, ((tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg)1), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2* line_2;
			NI i_2;
			NI L_2;
			NI T24_;
			line_2 = (NimStringV2*)0;
			i_2 = ((NI)0);
			T24_ = cfiles_1.len;
			L_2 = T24_;
			{
				while (1) {
					tyArray__YgExxhfgKcesA5EOUj1MOA T27_;
					if (!(i_2 < L_2)) goto LA26;
					line_2 = (&cfiles_1.p->data[i_2]);
					T27_[0] = (*line_2);
					writeLine__msgs_u470(fl_1, T27_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					i_2 += ((NI)1);
				} LA26: ;
			}
		}
		close__stdZsyncio_u268(fl_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA21_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___cgendata_u652((&prevset_1));
		eqdestroy___cgendata_u652((&fileset_1));
		eqdestroy___system_u5506(cfiles_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(fname_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToC__main_u748)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0) {
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	conf_1 = NIM_NIL;
	eqcopy___options_u2138(&conf_1, (*graph_p0).config);
	initVars__extccomp_u922(conf_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*conf_1).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0))) goto LA4_;
		{
			NIM_BOOL T8_;
			NimStringV2 colontmpD_;
			T8_ = (NIM_BOOL)0;
			T8_ = ((8194 & (*conf_1).globalOptions) == 8192);
			if (T8_) goto LA9_;
			T8_ = isDefined__options_u959(conf_1, TM__LO85BC9bl7tvXIPU7J9cRbtA_26);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA9_: ;
			if (!T8_) goto LA10_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			{
				NIM_BOOL T15_;
				colontmpD_ = jsonBuildInstructionsFile__extccomp_u1824(conf_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				T15_ = (NIM_BOOL)0;
				T15_ = changeDetectedViaJsonBuildInstructions__extccomp_u2399(conf_1, colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				if (!!(T15_)) goto LA16_;
				nimCopyMem((void*)(*(*graph_p0).config).notes, (NIM_CONST void*)(*(*graph_p0).config).mainPackageNotes, 13);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___options_u2135(conf_1);
				goto BeforeRet_;
			}
LA16_: ;
			{
				LA12_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA10_: ;
	}
LA4_: ;
	{
		NIM_BOOL T22_;
		T22_ = (NIM_BOOL)0;
		T22_ = ccHasSaneOverflow__extccomp_u1200(conf_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T22_)) goto LA23_;
		defineSymbol__condsyms_u4((*conf_1).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_28, TM__LO85BC9bl7tvXIPU7J9cRbtA_29);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA23_: ;
	{
		if (!((*conf_1).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0))) goto LA27_;
		setPipeLinePass__pipelines_u36(graph_p0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA25_;
LA27_: ;
	{
		setPipeLinePass__pipelines_u36(graph_p0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA25_: ;
	compilePipelineProject__pipelines_u1693(graph_p0, ((NI32)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((NI)0) < (*(*graph_p0).config).errorCounter)) goto LA32_;
		eqdestroy___options_u2135(conf_1);
		goto BeforeRet_;
	}
LA32_: ;
	{
		if (!((*conf_1).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0))) goto LA36_;
		cgenWriteModules__cgen_u31342((*graph_p0).backend, conf_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA34_;
LA36_: ;
	{
		{
			NIM_BOOL T41_;
			T41_ = (NIM_BOOL)0;
			T41_ = isDefined__options_u959(conf_1, TM__LO85BC9bl7tvXIPU7J9cRbtA_31);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T41_) goto LA42_;
			checkIntegrity__icZintegrity_u2180(graph_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA42_: ;
		generateCode__icZcbackend_u694(graph_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!!(((*graph_p0).backend == ((RootObj*) NIM_NIL)))) goto LA46_;
			cgenWriteModules__cgen_u31342((*graph_p0).backend, conf_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA46_: ;
	}
LA34_: ;
	{
		NIM_BOOL T50_;
		T50_ = (NIM_BOOL)0;
		T50_ = !(((*conf_1).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)7)));
		if (!(T50_)) goto LA51_;
		T50_ = !(((*graph_p0).backend == ((RootObj*) NIM_NIL)));
LA51_: ;
		if (!T50_) goto LA52_;
		callCCompiler__extccomp_u1560(conf_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T56_;
			T56_ = (NIM_BOOL)0;
			T56_ = hcrOn__options_u629(conf_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T56_)) goto LA57_;
			writeJsonBuildInstructions__extccomp_u1844(conf_1, (*graph_p0).cachedFiles);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA57_: ;
		{
			if (!(((*(*graph_p0).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)10)))&63U)))!=0)) goto LA61_;
			writeDepsFile__main_u35(graph_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA61_: ;
		{
			if (!(((*(*graph_p0).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)11)))&63U)))!=0)) goto LA65_;
			writeCMakeDepsFile__main_u297(conf_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA65_: ;
	}
LA52_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___options_u2135(conf_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandCompileToJS__main_u793)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0) {
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	conf_1 = NIM_NIL;
	eqcopy___options_u2138(&conf_1, (*graph_p0).config);
	(*conf_1).exc = ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)2);
	setTarget__platform_u750((&(*conf_1).target), ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)27), ((tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw)16));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	defineSymbol__condsyms_u4((*conf_1).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_39, TM__LO85BC9bl7tvXIPU7J9cRbtA_40);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setPipeLinePass__pipelines_u36(graph_p0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	compilePipelineProject__pipelines_u1693(graph_p0, ((NI32)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*conf_1).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)10)))&63U)))!=0)) goto LA4_;
		writeDepsFile__main_u35(graph_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___options_u2135(conf_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, compileToBackend__main_u945)(void* ClE_0) {
	tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw* colonenvP__1;
	tyProc__r9aUd06Iwvw1EZFjqV6w69bQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw*) ClE_0;
	nimZeroMem((void*)(&T1_), sizeof(tyProc__r9aUd06Iwvw1EZFjqV6w69bQ));
	T1_.ClP_0 = customizeForBackend__main_u928; T1_.ClE_0 = colonenvP__1;
	T1_.ClE_0? T1_.ClP_0((*(*colonenvP__1).conf0).backend, T1_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_16)(T1_.ClP_0))((*(*colonenvP__1).conf0).backend);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setOutFile__main_u890((*colonenvP__1).conf0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*(*colonenvP__1).conf0).backend) {
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1):
	{
		commandCompileToC__main_u748((*colonenvP__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2):
	{
		commandCompileToC__main_u748((*colonenvP__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)4):
	{
		commandCompileToC__main_u748((*colonenvP__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3):
	{
		commandCompileToJS__main_u793((*colonenvP__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)0):
	{
		raiseAssert__stdZassertions_u15(TM__LO85BC9bl7tvXIPU7J9cRbtA_41);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, commandDoc2__main_u721)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, NimStringV2 ext_p1) {
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	handleDocOutputOptions__docgen_u13475((*graph_p0).config);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	assignIfDefault__main_u689((&(*(*graph_p0).config).errorMax), ((NI)IL64(9223372036854775807)), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	if (eqStrings(ext_p1, TM__LO85BC9bl7tvXIPU7J9cRbtA_58)) goto LA2_;
	if (eqStrings(ext_p1, TM__LO85BC9bl7tvXIPU7J9cRbtA_60)) goto LA3_;
	if (eqStrings(ext_p1, TM__LO85BC9bl7tvXIPU7J9cRbtA_62)) goto LA4_;
	goto LA5_;
	LA2_: ;
	{
		setPipeLinePass__pipelines_u36(graph_p0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)7));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
	LA3_: ;
	{
		setPipeLinePass__pipelines_u36(graph_p0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
	LA4_: ;
	{
		setPipeLinePass__pipelines_u36(graph_p0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)9));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA6_;
	LA5_: ;
	{
		raiseAssert__stdZassertions_u15(ext_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA6_: ;
	compilePipelineProject__pipelines_u1693(graph_p0, ((NI32)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1) {
	(*(*dest_p0).p).data[(*dest_p0).len] = c_p1;
	(*dest_p0).len += ((NI)1);
	(*(*dest_p0).p).data[(*dest_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, commandGenDepend__main_u678)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0) {
	NimStringV2 project_1;
	NimStringV2 graphvizDotPath_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	project_1.len = 0; project_1.p = NIM_NIL;
	graphvizDotPath_1.len = 0; graphvizDotPath_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	setPipeLinePass__pipelines_u36(graph_p0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)6));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	compilePipelineProject__pipelines_u1693(graph_p0, ((NI32)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&project_1), (*(*graph_p0).config).projectFull);
	writeDepsFile__main_u35(graph_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	generateDot__depends_u261(graph_p0, project_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	graphvizDotPath_1 = findExe__pureZos_u76(TM__LO85BC9bl7tvXIPU7J9cRbtA_93, NIM_TRUE, ExeExts__pureZos_u75, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(graphvizDotPath_1.len == ((NI)0))) goto LA4_;
		quit__system_u7994(TM__LO85BC9bl7tvXIPU7J9cRbtA_95, ((NI)1));
	}
LA4_: ;
	T6_.len = 0; T6_.p = NIM_NIL;
	colontmpD_ = noschangeFileExt(project_1, TM__LO85BC9bl7tvXIPU7J9cRbtA_99);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = noschangeFileExt(project_1, TM__LO85BC9bl7tvXIPU7J9cRbtA_100);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = rawNewString(colontmpD_.len + colontmpD__2.len + 13);
appendString((&T6_), TM__LO85BC9bl7tvXIPU7J9cRbtA_97);
appendString((&T6_), colontmpD_);
appendChar((&T6_), 32);
appendString((&T6_), colontmpD__2);
	colontmpD__3 = T6_;
	execExternalProgram__extccomp_u1040((*graph_p0).config, colontmpD__3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)109));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(graphvizDotPath_1);
		eqdestroy___system_u2691(project_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, X5BX5Deq___pureZjson_u2308)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* obj_p0, NimStringV2 key_p1, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* val_p2) {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___pureZjson_u330(val_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	X5BX5Deq___pureZjson_u739((&(*obj_p0)._kind_6.fields), key_p1, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandCheck__main_u682)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0) {
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_1;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	conf_1 = NIM_NIL;
	eqcopy___options_u2138(&conf_1, (*graph_p0).config);
	T2_ = (NI)0;
	assignIfDefault__main_u689((&(*conf_1).errorMax), ((NI)IL64(9223372036854775807)), T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	defineSymbol__condsyms_u4((*conf_1).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_139, TM__LO85BC9bl7tvXIPU7J9cRbtA_140);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*conf_1).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)2)))&63U)))!=0)) goto LA5_;
		defineSymbol__condsyms_u4((*conf_1).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_142, TM__LO85BC9bl7tvXIPU7J9cRbtA_143);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		defineSymbol__condsyms_u4((*conf_1).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_145, TM__LO85BC9bl7tvXIPU7J9cRbtA_146);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		if (!((*conf_1).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3))) goto LA8_;
		setTarget__platform_u750((&(*conf_1).target), ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)27), ((tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw)16));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA8_: ;
LA3_: ;
	setPipeLinePass__pipelines_u36(graph_p0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	compilePipelineProject__pipelines_u1693(graph_p0, ((NI32)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!(((*conf_1).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA12_;
		switch ((*conf_1).ideCmd) {
		case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)3):
		{
			navDefinition__icZnavigator_u816(graph_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)4):
		{
			navUsages__icZnavigator_u818(graph_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)5):
		{
			navDefusages__icZnavigator_u820(graph_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
		}
		break;
		}
		writeRodFiles__icZnavigator_u822(graph_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA12_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___options_u2135(conf_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandView__main_u879)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0) {
	NimStringV2 f_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	f_1.len = 0; f_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD_ = mainCommandArg__options_u3593((*graph_p0).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = nosgetCurrentDir();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = toAbsolute__pathutils_u201(colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	f_1 = nosaddFileExt(colontmpD__3, TM__LO85BC9bl7tvXIPU7J9cRbtA_148);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rodViewer__icZic_u22333(f_1, (*graph_p0).config, (*graph_p0).cache);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(f_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___main_u1463)(tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).graph0);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0).graph0)));
		nimRawDispose((*dest_p0).graph0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__main_u1529)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___main_u1463((&(*((tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_CLOSURE(void, colonanonymous___main_u835)(void* ClE_0) {
	tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw* colonenvP__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenvP__1 = (tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw*) ClE_0;
	flushDot__msgs_u40((*(*colonenvP__1).graph0).config);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___main_u1494)(tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__fynYR66Aq30EaZMWpzeFjw_))));
		if (!T3_) goto LA4_;
		eqdestroy___main_u1463((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandInteractive__main_u800)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0) {
	tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw* colonenv__1;
	tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw* T2_;
	NI T3_;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenv__1 = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw*) nimNewObj(sizeof(tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw), NIM_ALIGNOF(tyObject_Env_maindotnim_commandInteractive___fynYR66Aq30EaZMWpzeFjw));
	(*T2_).Sup.m_type = (&NTIv2__fynYR66Aq30EaZMWpzeFjw_);
	colonenv__1 = T2_;
	eqcopy___modulegraphs_u14756(&(*colonenv__1).graph0, graph_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = (NI)0;
	assignIfDefault__main_u689((&(*(*(*colonenv__1).graph0).config).errorMax), ((NI)IL64(9223372036854775807)), T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	initDefines__condsyms_u17((*(*(*colonenv__1).graph0).config).symbols);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	defineSymbol__condsyms_u4((*(*(*colonenv__1).graph0).config).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_150, TM__LO85BC9bl7tvXIPU7J9cRbtA_151);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setPipeLinePass__pipelines_u36((*colonenv__1).graph0, ((tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg)5));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	compilePipelineSystemModule__pipelines_u1687((*colonenv__1).graph0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T6_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		NI32 T10_;
		tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T11_;
		T6_ = (*(*(*colonenv__1).graph0).config).commandArgs.len;
		if (!(((NI)0) < T6_)) goto LA7_;
		colontmpD_ = NIM_NIL;
		T10_ = (NI32)0;
		T10_ = fileInfoIdx__msgs_u404((*(*colonenv__1).graph0).config, (*(*(*colonenv__1).graph0).config).projectFull);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T11_ = 0;
		colontmpD_ = compilePipelineModule__pipelines_u501((*colonenv__1).graph0, T10_, T11_, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		(void)(colontmpD_);
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA7_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
		tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_1;
		tyObject_TLLStream__FoDsO8lsQbcCVaLehnuOYg* s_1;
		tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* T16_;
		tyProc__WBr0JFZ9bbIGwzgqNYcBJtQ T17_;
		tyProc__HzVCwACFYM9cx9aV62PdjtuA T18_;
		NIM_BOOL T19_;
		m_1 = NIM_NIL;
		idgen_1 = NIM_NIL;
		s_1 = NIM_NIL;
		m_1 = makeStdinModule__modules_u52((*colonenv__1).graph0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		(*m_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14))) & 63);
		T16_ = NIM_NIL;
		T16_ = (tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug*) nimNewObj(sizeof(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug), NIM_ALIGNOF(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug));
		(*T16_).module = (*m_1).itemId.module;
		(*T16_).symId = (*m_1).itemId.item;
		(*T16_).typeId_0 = ((NI32)0);
		idgen_1 = T16_;
		nimZeroMem((void*)(&T17_), sizeof(tyProc__WBr0JFZ9bbIGwzgqNYcBJtQ));
		T17_.ClP_0 = ((TM__LO85BC9bl7tvXIPU7J9cRbtA_152) (llReadFromStdin__llstream_u142)); T17_.ClE_0 = NIM_NIL;
		nimZeroMem((void*)(&T18_), sizeof(tyProc__HzVCwACFYM9cx9aV62PdjtuA));
		T18_.ClP_0 = colonanonymous___main_u835; T18_.ClE_0 = colonenv__1;
		s_1 = llStreamOpenStdIn__llstream_u146(T17_, T18_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T19_ = (NIM_BOOL)0;
		T19_ = processPipelineModule__pipelines_u418((*colonenv__1).graph0, m_1, idgen_1, s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		(void)(T19_);
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___llstream_u112(s_1);
			eqdestroy___ast_u3100(idgen_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u4574(m_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___main_u1494(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commandJsonScript__main_u791)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = jsonBuildInstructionsFile__extccomp_u1824((*graph_p0).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	runJsonBuildInstructions__extccomp_u3207((*graph_p0).config, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___main_u1302)(tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__XnfB9bJveLwILB3YJhrlXxw_))));
		if (!T3_) goto LA4_;
		eqdestroy___main_u1264((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, mainCommand__main_u920)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0) {
	tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw* colonenv__1;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_1;
	NimStringV2 colontmpD_;
	tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw* T2_;
	NF T3_;
NIM_BOOL oldNimErrFin141_;
NIM_BOOL oldNimErrFin199_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenv__1 = NIM_NIL;
	cache_1 = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw*) nimNewObj(sizeof(tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw), NIM_ALIGNOF(tyObject_Env_maindotnim_mainCommand___XnfB9bJveLwILB3YJhrlXxw));
	(*T2_).Sup.m_type = (&NTIv2__XnfB9bJveLwILB3YJhrlXxw_);
	colonenv__1 = T2_;
	eqcopy___modulegraphs_u14756(&(*colonenv__1).graph1, graph_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___options_u2138(&(*colonenv__1).conf0, (*(*colonenv__1).graph1).config);
	eqcopy___idents_u341(&cache_1, (*(*colonenv__1).graph1).cache);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = (NF)0;
	T3_ = epochTime__pureZtimes_u5209();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*(*colonenv__1).conf0).lastCmdTime = T3_;
	colontmpD_ = eqdup___system_u2697((*(*colonenv__1).conf0).libpath);
	add__commands_u1640((&(*(*colonenv__1).conf0).searchPaths), colontmpD_);
	{
		if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)6))) goto LA6_;
		(*(*colonenv__1).conf0).globalOptions = ((*(*colonenv__1).conf0).globalOptions | 24576);
	}
LA6_: ;
	{
		tyProc__r9aUd06Iwvw1EZFjqV6w69bQ T12_;
		if (!!(((*(*colonenv__1).conf0).cmd >= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)2) && (*(*colonenv__1).conf0).cmd <= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)7)))) goto LA10_;
		nimZeroMem((void*)(&T12_), sizeof(tyProc__r9aUd06Iwvw1EZFjqV6w69bQ));
		T12_.ClP_0 = customizeForBackend__main_u928; T12_.ClE_0 = colonenv__1;
		T12_.ClE_0? T12_.ClP_0(((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1), T12_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_9)(T12_.ClP_0))(((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	{
		NIM_BOOL T15_;
		NimStringV2 ret_1;
		NimStringV2 T19_;
		T15_ = (NIM_BOOL)0;
		T15_ = isEmpty__pathutils_u139((*(*colonenv__1).conf0).outDir);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T15_) goto LA16_;
		ret_1.len = 0; ret_1.p = NIM_NIL;
		T19_.len = 0; T19_.p = NIM_NIL;
		{
			if (!(((*(*colonenv__1).conf0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)14)))&63U)))!=0)) goto LA22_;
			ret_1 = getNimcacheDir__options_u3737((*colonenv__1).conf0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		}
		goto LA20_;
LA22_: ;
		{
			eqcopy___system_u2694((&ret_1), (*(*colonenv__1).conf0).projectPath);
		}
LA20_: ;
		{
			NIM_BOOL T27_;
			NimStringV2 colontmpD__2;
			NimStringV2 T31_;
			T27_ = (NIM_BOOL)0;
			T27_ = nosisAbsolute(ret_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			if (!!(T27_)) goto LA28_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T31_.len = 0; T31_.p = NIM_NIL;
			T31_ = rawNewString(ret_1.len + 1);
appendString((&T31_), ret_1);
appendString((&T31_), TM__LO85BC9bl7tvXIPU7J9cRbtA_11);
			colontmpD__2 = T31_;
			liMessage__msgs_u1227((*colonenv__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__LO85BC9bl7tvXIPU7J9cRbtA_12), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			{
				LA30_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		}
LA28_: ;
		{
			NimStringV2 T38_;
			if (!((*(*colonenv__1).conf0).cmd >= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)14) && (*(*colonenv__1).conf0).cmd <= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)24))) goto LA36_;
			T38_.len = 0; T38_.p = NIM_NIL;
			T38_ = slash___pathutils_u166(ret_1, TM__LO85BC9bl7tvXIPU7J9cRbtA_15);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T38_); goto LA18_;}
			eqsink___system_u2700((&ret_1), T38_);
		}
LA36_: ;
		eqsink___system_u2700((&(*(*colonenv__1).conf0).outDir), ret_1);
		eqwasMoved___system_u2688((&ret_1));
		{
			LA18_:;
		}
		{
			eqdestroy___system_u2691(ret_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA16_: ;
	switch ((*(*colonenv__1).conf0).cmd) {
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)2) ... ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)6):
	{
		tyProc__HzVCwACFYM9cx9aV62PdjtuA T42_;
		nimZeroMem((void*)(&T42_), sizeof(tyProc__HzVCwACFYM9cx9aV62PdjtuA));
		T42_.ClP_0 = compileToBackend__main_u945; T42_.ClE_0 = colonenv__1;
		T42_.ClE_0? T42_.ClP_0(T42_.ClE_0):((TM__LO85BC9bl7tvXIPU7J9cRbtA_42)(T42_.ClP_0))();
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)7):
	{
		liMessage__msgs_u1227((*colonenv__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__LO85BC9bl7tvXIPU7J9cRbtA_44, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__LO85BC9bl7tvXIPU7J9cRbtA_45), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)14):
	{
		NimStringV2 docConfX60gensym39__1;
		NimStringV2 T45_;
		docConfX60gensym39__1.len = 0; docConfX60gensym39__1.p = NIM_NIL;
		wantMainModule__modules_u39((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T45_.len = 0; T45_.p = NIM_NIL;
		{
			if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16))) goto LA48_;
			docConfX60gensym39__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_47;
		}
		goto LA46_;
LA48_: ;
		{
			docConfX60gensym39__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_49;
		}
LA46_: ;
		loadConfigs__nimconf_u293(docConfX60gensym39__1, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		defineSymbol__condsyms_u4((*(*colonenv__1).conf0).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_51, TM__LO85BC9bl7tvXIPU7J9cRbtA_52);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandDoc__docgen_u13481(cache_1, (*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)15):
	{
		NimStringV2 docConfX60gensym40__1;
		NimStringV2 T52_;
		docConfX60gensym40__1.len = 0; docConfX60gensym40__1.p = NIM_NIL;
		wantMainModule__modules_u39((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T52_.len = 0; T52_.p = NIM_NIL;
		{
			if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16))) goto LA55_;
			docConfX60gensym40__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_53;
		}
		goto LA53_;
LA55_: ;
		{
			docConfX60gensym40__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_54;
		}
LA53_: ;
		loadConfigs__nimconf_u293(docConfX60gensym40__1, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		defineSymbol__condsyms_u4((*(*colonenv__1).conf0).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_55, TM__LO85BC9bl7tvXIPU7J9cRbtA_56);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		setNoteDefaults__options_u510((*colonenv__1).conf0, ((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)29), NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandDoc2__main_u721((*colonenv__1).graph1, TM__LO85BC9bl7tvXIPU7J9cRbtA_63);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T60_;
			NimStringV2 colontmpD__3;
			T60_ = (NIM_BOOL)0;
			T60_ = (((*(*colonenv__1).conf0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)29)))&63U)))!=0);
			if (!(T60_)) goto LA61_;
			T60_ = (((*(*colonenv__1).conf0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)38)))&63U)))!=0);
LA61_: ;
			if (!T60_) goto LA62_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__3 = dollar___options_u4029((*(*colonenv__1).conf0).outDir);
			if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
			commandBuildIndex__docgen_u13609((*colonenv__1).conf0, colontmpD__3, TM__LO85BC9bl7tvXIPU7J9cRbtA_65);
			if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
			{
				LA64_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA62_: ;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)17):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)19):
	{
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA warn_1;
			tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmp_;
			NI i_1;
			warn_1 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
			nimZeroMem((void*)colontmp_, sizeof(tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA));
			nimCopyMem((void*)colontmp_, (NIM_CONST void*)TM__LO85BC9bl7tvXIPU7J9cRbtA_66, 16);
			i_1 = ((NI)0);
			{
				while (1) {
					if (!(i_1 <= ((NI)123))) goto LA70;
					{
						if (!((colontmp_[(NU)((((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_1))))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_1))))&7U)))!=0)) goto LA73_;
						warn_1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_1));
						setNoteDefaults__options_u510((*colonenv__1).conf0, (warn_1), NIM_TRUE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA73_: ;
					i_1 += ((NI)1);
				} LA70: ;
			}
		}
		setNoteDefaults__options_u510((*colonenv__1).conf0, ((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)29), NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		loadConfigs__nimconf_u293(TM__LO85BC9bl7tvXIPU7J9cRbtA_67, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandRst2Html__docgen_u13556(cache_1, (*colonenv__1).conf0, ((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)19)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)18):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)20):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16):
	{
		{
			tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA warn_2;
			tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA colontmp__2;
			NI i_2;
			warn_2 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
			nimZeroMem((void*)colontmp__2, sizeof(tySet_tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA));
			nimCopyMem((void*)colontmp__2, (NIM_CONST void*)TM__LO85BC9bl7tvXIPU7J9cRbtA_66, 16);
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 <= ((NI)123))) goto LA78;
					{
						if (!((colontmp__2[(NU)((((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_2))))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_2))))&7U)))!=0)) goto LA81_;
						warn_2 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (i_2));
						setNoteDefaults__options_u510((*colonenv__1).conf0, (warn_2), NIM_TRUE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA81_: ;
					i_2 += ((NI)1);
				} LA78: ;
			}
		}
		{
			if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)18) || (*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)20))) goto LA85_;
			loadConfigs__nimconf_u293(TM__LO85BC9bl7tvXIPU7J9cRbtA_68, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			commandRst2TeX__docgen_u13560(cache_1, (*colonenv__1).conf0, ((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)20)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA83_;
LA85_: ;
		{
			NimStringV2 docConfX60gensym44__1;
			NimStringV2 T88_;
			docConfX60gensym44__1.len = 0; docConfX60gensym44__1.p = NIM_NIL;
			wantMainModule__modules_u39((*colonenv__1).conf0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T88_.len = 0; T88_.p = NIM_NIL;
			{
				if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16))) goto LA91_;
				docConfX60gensym44__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_69;
			}
			goto LA89_;
LA91_: ;
			{
				docConfX60gensym44__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_70;
			}
LA89_: ;
			loadConfigs__nimconf_u293(docConfX60gensym44__1, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			defineSymbol__condsyms_u4((*(*colonenv__1).conf0).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_71, TM__LO85BC9bl7tvXIPU7J9cRbtA_72);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			commandDoc2__main_u721((*colonenv__1).graph1, TM__LO85BC9bl7tvXIPU7J9cRbtA_73);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA83_: ;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)21):
	{
		NimStringV2 docConfX60gensym45__1;
		NimStringV2 T95_;
		docConfX60gensym45__1.len = 0; docConfX60gensym45__1.p = NIM_NIL;
		wantMainModule__modules_u39((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T95_.len = 0; T95_.p = NIM_NIL;
		{
			if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16))) goto LA98_;
			docConfX60gensym45__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_74;
		}
		goto LA96_;
LA98_: ;
		{
			docConfX60gensym45__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_75;
		}
LA96_: ;
		loadConfigs__nimconf_u293(docConfX60gensym45__1, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		defineSymbol__condsyms_u4((*(*colonenv__1).conf0).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_76, TM__LO85BC9bl7tvXIPU7J9cRbtA_77);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandJson__docgen_u13564(cache_1, (*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)22):
	{
		NimStringV2 docConfX60gensym46__1;
		NimStringV2 T102_;
		docConfX60gensym46__1.len = 0; docConfX60gensym46__1.p = NIM_NIL;
		wantMainModule__modules_u39((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T102_.len = 0; T102_.p = NIM_NIL;
		{
			if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16))) goto LA105_;
			docConfX60gensym46__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_78;
		}
		goto LA103_;
LA105_: ;
		{
			docConfX60gensym46__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_79;
		}
LA103_: ;
		loadConfigs__nimconf_u293(docConfX60gensym46__1, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		defineSymbol__condsyms_u4((*(*colonenv__1).conf0).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_80, TM__LO85BC9bl7tvXIPU7J9cRbtA_81);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandDoc2__main_u721((*colonenv__1).graph1, TM__LO85BC9bl7tvXIPU7J9cRbtA_82);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T110_;
			NimStringV2 colontmpD__4;
			T110_ = (NIM_BOOL)0;
			T110_ = (((*(*colonenv__1).conf0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)29)))&63U)))!=0);
			if (!(T110_)) goto LA111_;
			T110_ = (((*(*colonenv__1).conf0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)38)))&63U)))!=0);
LA111_: ;
			if (!T110_) goto LA112_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__4 = dollar___options_u4029((*(*colonenv__1).conf0).outDir);
			if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
			commandBuildIndexJson__docgen_u13661((*colonenv__1).conf0, colontmpD__4, TM__LO85BC9bl7tvXIPU7J9cRbtA_83);
			if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
			{
				LA114_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA112_: ;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)23):
	{
		NimStringV2 docConfX60gensym49__1;
		NimStringV2 T118_;
		docConfX60gensym49__1.len = 0; docConfX60gensym49__1.p = NIM_NIL;
		wantMainModule__modules_u39((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T118_.len = 0; T118_.p = NIM_NIL;
		{
			if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16))) goto LA121_;
			docConfX60gensym49__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_84;
		}
		goto LA119_;
LA121_: ;
		{
			docConfX60gensym49__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_85;
		}
LA119_: ;
		loadConfigs__nimconf_u293(docConfX60gensym49__1, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		defineSymbol__condsyms_u4((*(*colonenv__1).conf0).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_86, TM__LO85BC9bl7tvXIPU7J9cRbtA_87);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandTags__docgen_u13587(cache_1, (*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)24):
	{
		NimStringV2 docConfX60gensym50__1;
		NimStringV2 colontmpD__5;
		NimStringV2 T126_;
		docConfX60gensym50__1.len = 0; docConfX60gensym50__1.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		wantMainModule__modules_u39((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
		T126_.len = 0; T126_.p = NIM_NIL;
		{
			if (!((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16))) goto LA129_;
			docConfX60gensym50__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_88;
		}
		goto LA127_;
LA129_: ;
		{
			docConfX60gensym50__1 = TM__LO85BC9bl7tvXIPU7J9cRbtA_89;
		}
LA127_: ;
		loadConfigs__nimconf_u293(docConfX60gensym50__1, cache_1, (*colonenv__1).conf0, (*(*colonenv__1).graph1).idgen);
		if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
		defineSymbol__condsyms_u4((*(*colonenv__1).conf0).symbols, TM__LO85BC9bl7tvXIPU7J9cRbtA_90, TM__LO85BC9bl7tvXIPU7J9cRbtA_91);
		if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
		colontmpD__5 = dollar___options_u3939((*(*colonenv__1).conf0).projectFull);
		if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
		commandBuildIndex__docgen_u13609((*colonenv__1).conf0, colontmpD__5, (*(*colonenv__1).conf0).outFile);
		if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
		{
			LA125_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)25):
	{
		commandGenDepend__main_u678((*colonenv__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)26):
	{
		NimStringV2 colontmpD__6;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		{
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* definedSymbols_1;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* libpaths_1;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* lazyPaths_1;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* hints_1;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* warnings_1;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* dumpdata_1;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__7;
			NimStringV2 colontmpD__8;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__9;
			NimStringV2 colontmpD__10;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__11;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__12;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__13;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__14;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__15;
			NimStringV2 colontmpD__16;
			tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__17;
			NimStringV2 colontmpD__18;
			tyArray__3bOxgfcU9blxovcrG6Y9bi6w T169_;
			colontmpD__6 = getConfigVar__options_u3603((*colonenv__1).conf0, TM__LO85BC9bl7tvXIPU7J9cRbtA_102, TM__LO85BC9bl7tvXIPU7J9cRbtA_104);
			if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
			if (!eqStrings(colontmpD__6, TM__LO85BC9bl7tvXIPU7J9cRbtA_105)) goto LA139_;
			definedSymbols_1 = NIM_NIL;
			libpaths_1 = NIM_NIL;
			lazyPaths_1 = NIM_NIL;
			hints_1 = NIM_NIL;
			warnings_1 = NIM_NIL;
			dumpdata_1 = NIM_NIL;
			colontmpD__7 = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9 = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11 = NIM_NIL;
			colontmpD__12 = NIM_NIL;
			colontmpD__13 = NIM_NIL;
			colontmpD__14 = NIM_NIL;
			colontmpD__15 = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17 = NIM_NIL;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			wantMainModule__modules_u39((*colonenv__1).conf0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			definedSymbols_1 = newJArray__pureZjson_u506();
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			{
				NimStringV2 s_1;
				s_1.len = 0; s_1.p = NIM_NIL;
				{
					NimStringV2 key_1;
					key_1.len = 0; key_1.p = NIM_NIL;
					{
						NI h_1;
						NI colontmp__3;
						NI T145_;
						NI res_1;
						h_1 = (NI)0;
						colontmp__3 = (NI)0;
						T145_ = ((*(*(*colonenv__1).conf0).symbols).data.len-1);
						colontmp__3 = T145_;
						res_1 = ((NI)0);
						{
							while (1) {
								if (!(res_1 <= colontmp__3)) goto LA147;
								h_1 = ((NI) (res_1));
								{
									tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* T152_;
									if (!(*(*(*colonenv__1).conf0).symbols).data.p->data[h_1].Field2) goto LA150_;
									eqcopy___system_u2694((&key_1), (*(*(*colonenv__1).conf0).symbols).data.p->data[h_1].Field0);
									eqsink___system_u2700((&s_1), key_1);
									eqwasMoved___system_u2688((&key_1));
									T152_ = NIM_NIL;
									T152_ = percent___pureZjson_u2158(s_1);
									if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___pureZjson_u324(T152_); goto LA141_;}
									add__pureZjson_u672((&(*definedSymbols_1)._kind_7.elems), T152_);
								}
LA150_: ;
								res_1 += ((NI)1);
							} LA147: ;
						}
					}
					eqdestroy___system_u2691(key_1);
				}
				eqdestroy___system_u2691(s_1);
			}
			libpaths_1 = newJArray__pureZjson_u506();
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			lazyPaths_1 = newJArray__pureZjson_u506();
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			{
				NimStringV2* dir_1;
				NI i_3;
				NI L_1;
				NI T154_;
				dir_1 = (NimStringV2*)0;
				i_3 = ((NI)0);
				T154_ = (*(*colonenv__1).conf0).searchPaths.len;
				L_1 = T154_;
				{
					while (1) {
						tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* T157_;
						if (!(i_3 < L_1)) goto LA156;
						dir_1 = (&(*(*colonenv__1).conf0).searchPaths.p->data[i_3]);
						T157_ = NIM_NIL;
						T157_ = percent___pureZjson_u2158((*dir_1));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___pureZjson_u324(T157_); goto LA141_;}
						add__pureZjson_u672((&(*libpaths_1)._kind_7.elems), T157_);
						i_3 += ((NI)1);
					} LA156: ;
				}
			}
			{
				NimStringV2* dir_2;
				NI i_4;
				NI L_2;
				NI T159_;
				dir_2 = (NimStringV2*)0;
				i_4 = ((NI)0);
				T159_ = (*(*colonenv__1).conf0).lazyPaths.len;
				L_2 = T159_;
				{
					while (1) {
						tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* T162_;
						if (!(i_4 < L_2)) goto LA161;
						dir_2 = (&(*(*colonenv__1).conf0).lazyPaths.p->data[i_4]);
						T162_ = NIM_NIL;
						T162_ = percent___pureZjson_u2158((*dir_2));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___pureZjson_u324(T162_); goto LA141_;}
						add__pureZjson_u672((&(*lazyPaths_1)._kind_7.elems), T162_);
						i_4 += ((NI)1);
					} LA161: ;
				}
			}
			hints_1 = newJObject__pureZjson_u443();
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			{
				tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA a_1;
				NI res_2;
				a_1 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
				res_2 = ((NI)89);
				{
					while (1) {
						NimStringV2 colontmpD__19;
						tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__20;
						if (!(res_2 <= ((NI)123))) goto LA165;
						colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
						colontmpD__20 = NIM_NIL;
						a_1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (res_2));
						colontmpD__19 = dollar___lineinfos_u134(a_1);
						colontmpD__20 = percent___pureZjson_u2184((((*(*colonenv__1).conf0).notes[(NU)(((a_1) - 20))>>3] &(1U<<((NU)(((a_1) - 20))&7U)))!=0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
						X5BX5Deq___pureZjson_u2308(hints_1, colontmpD__19, colontmpD__20);
						if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
						res_2 += ((NI)1);
						eqdestroy___pureZjson_u324(colontmpD__20);
						if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
						eqdestroy___system_u2691(colontmpD__19);
					} LA165: ;
				}
			}
			warnings_1 = newJObject__pureZjson_u443();
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			{
				tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA a_2;
				NI res_3;
				a_2 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
				res_3 = ((NI)20);
				{
					while (1) {
						NimStringV2 colontmpD__21;
						tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* colontmpD__22;
						if (!(res_3 <= ((NI)88))) goto LA168;
						colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
						colontmpD__22 = NIM_NIL;
						a_2 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (res_3));
						colontmpD__21 = dollar___lineinfos_u134(a_2);
						colontmpD__22 = percent___pureZjson_u2184((((*(*colonenv__1).conf0).notes[(NU)(((a_2) - 20))>>3] &(1U<<((NU)(((a_2) - 20))&7U)))!=0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
						X5BX5Deq___pureZjson_u2308(warnings_1, colontmpD__21, colontmpD__22);
						if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
						res_3 += ((NI)1);
						eqdestroy___pureZjson_u324(colontmpD__22);
						if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
						eqdestroy___system_u2691(colontmpD__21);
					} LA168: ;
				}
			}
			nimZeroMem((void*)T169_, sizeof(tyArray__3bOxgfcU9blxovcrG6Y9bi6w));
			T169_[0].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_107;
			colontmpD__7 = percent___pureZjson_u2158(TM__LO85BC9bl7tvXIPU7J9cRbtA_109);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			T169_[0].Field1 = colontmpD__7;
			T169_[1].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_111;
			colontmpD__8 = nosgetAppFilename();
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			colontmpD__9 = percent___pureZjson_u2158(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			T169_[1].Field1 = colontmpD__9;
			T169_[2].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_113;
			colontmpD__10 = getPrefixDir__options_u3645((*colonenv__1).conf0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			colontmpD__11 = percent___pureZjson_u2158(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			T169_[2].Field1 = colontmpD__11;
			T169_[3].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_115;
			colontmpD__12 = percent___pureZjson_u2158((*(*colonenv__1).conf0).libpath);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			T169_[3].Field1 = colontmpD__12;
			T169_[4].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_117;
			colontmpD__13 = percent___pureZjson_u2158((*(*colonenv__1).conf0).projectFull);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			T169_[4].Field1 = colontmpD__13;
			T169_[5].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_119;
			T169_[5].Field1 = definedSymbols_1;
			T169_[6].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_121;
			T169_[6].Field1 = libpaths_1;
			T169_[7].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_123;
			T169_[7].Field1 = lazyPaths_1;
			T169_[8].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_125;
			colontmpD__14 = percent___pureZjson_u2158((*(*colonenv__1).conf0).outDir);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			T169_[8].Field1 = colontmpD__14;
			T169_[9].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_127;
			colontmpD__15 = percent___pureZjson_u2158((*(*colonenv__1).conf0).outFile);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			T169_[9].Field1 = colontmpD__15;
			T169_[10].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_129;
			colontmpD__16 = getNimcacheDir__options_u3737((*colonenv__1).conf0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			colontmpD__17 = percent___pureZjson_u2158(colontmpD__16);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			T169_[10].Field1 = colontmpD__17;
			T169_[11].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_131;
			T169_[11].Field1 = hints_1;
			T169_[12].Field0 = TM__LO85BC9bl7tvXIPU7J9cRbtA_133;
			T169_[12].Field1 = warnings_1;
			dumpdata_1 = percent___pureZjson_u2187(T169_, 13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			colontmpD__18 = dollar___pureZjson_u4831(dumpdata_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			msgWriteln__msgs_u737((*colonenv__1).conf0, colontmpD__18, 7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			{
				LA141_:;
			}
			{
				oldNimErrFin141_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__18);
				eqdestroy___pureZjson_u324(colontmpD__17);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___pureZjson_u324(colontmpD__15);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___pureZjson_u324(colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___pureZjson_u324(colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(dumpdata_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(warnings_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(hints_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(lazyPaths_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(libpaths_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				eqdestroy___pureZjson_u324(definedSymbols_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				*nimErr_ = oldNimErrFin141_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
		}
		goto LA137_;
LA139_: ;
		{
			msgWriteln__msgs_u737((*colonenv__1).conf0, TM__LO85BC9bl7tvXIPU7J9cRbtA_135, 7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
			{
				NimStringV2 s_2;
				s_2.len = 0; s_2.p = NIM_NIL;
				{
					NimStringV2 key_2;
					key_2.len = 0; key_2.p = NIM_NIL;
					{
						NI h_2;
						NI colontmp__4;
						NI T178_;
						NI res_4;
						h_2 = (NI)0;
						colontmp__4 = (NI)0;
						T178_ = ((*(*(*colonenv__1).conf0).symbols).data.len-1);
						colontmp__4 = T178_;
						res_4 = ((NI)0);
						{
							while (1) {
								if (!(res_4 <= colontmp__4)) goto LA180;
								h_2 = ((NI) (res_4));
								{
									if (!(*(*(*colonenv__1).conf0).symbols).data.p->data[h_2].Field2) goto LA183_;
									eqcopy___system_u2694((&key_2), (*(*(*colonenv__1).conf0).symbols).data.p->data[h_2].Field0);
									eqsink___system_u2700((&s_2), key_2);
									eqwasMoved___system_u2688((&key_2));
									msgWriteln__msgs_u737((*colonenv__1).conf0, s_2, 7);
									if (NIM_UNLIKELY(*nimErr_)) goto LA176_;
								}
LA183_: ;
								res_4 += ((NI)1);
							} LA180: ;
						}
					}
					{
						LA176_:;
					}
					{
						eqdestroy___system_u2691(key_2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA174_;
				}
				{
					LA174_:;
				}
				{
					eqdestroy___system_u2691(s_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
			}
			msgWriteln__msgs_u737((*colonenv__1).conf0, TM__LO85BC9bl7tvXIPU7J9cRbtA_137, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
			{
				NimStringV2* it_1;
				NI i_5;
				NI L_3;
				NI T190_;
				it_1 = (NimStringV2*)0;
				i_5 = ((NI)0);
				T190_ = (*(*colonenv__1).conf0).searchPaths.len;
				L_3 = T190_;
				{
					while (1) {
						tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw T193_;
						if (!(i_5 < L_3)) goto LA192;
						it_1 = (&(*(*colonenv__1).conf0).searchPaths.p->data[i_5]);
						T193_ = 0;
						msgWriteln__msgs_u737((*colonenv__1).conf0, (*it_1), T193_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
						i_5 += ((NI)1);
					} LA192: ;
				}
			}
		}
LA137_: ;
		{
			LA136_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8):
	{
		commandCheck__main_u682((*colonenv__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)9):
	{
		(*(*(*colonenv__1).graph1).config).symbolFiles = ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3);
		setUseIc__ast_u834(!(((*(*(*colonenv__1).graph1).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandCheck__main_u682((*colonenv__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)10):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__23;
		colontmpD__23 = NIM_NIL;
		wantMainModule__modules_u39((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
		colontmpD__23 = parseFile__syntaxes_u235((*(*colonenv__1).conf0).projectMainIdx, cache_1, (*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA199_;
		(void)(colontmpD__23);
		{
			LA199_:;
		}
		{
			oldNimErrFin199_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__23);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin199_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)11):
	{
		wantMainModule__modules_u39((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandView__main_u879((*colonenv__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)27):
	{
		commandInteractive__main_u800((*colonenv__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)13):
	{
		{
			NIM_BOOL T207_;
			T207_ = (NIM_BOOL)0;
			T207_ = (*(*colonenv__1).conf0).projectIsCmd;
			if (T207_) goto LA208_;
			T207_ = (*(*colonenv__1).conf0).projectIsStdin;
LA208_: ;
			if (!T207_) goto LA209_;
		}
		goto LA205_;
LA209_: ;
		{
			NIM_BOOL T212_;
			NimStringV2 colontmpD__24;
			NimStringV2 T216_;
			T212_ = (NIM_BOOL)0;
			T212_ = nosfileExists((*(*colonenv__1).conf0).projectFull);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T212_)) goto LA213_;
			colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
			T216_.len = 0; T216_.p = NIM_NIL;
			T216_ = rawNewString((*(*colonenv__1).conf0).projectFull.len + 31);
appendString((&T216_), TM__LO85BC9bl7tvXIPU7J9cRbtA_154);
appendString((&T216_), (*(*colonenv__1).conf0).projectFull);
			colontmpD__24 = T216_;
			liMessage__msgs_u1227((*colonenv__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__24, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__LO85BC9bl7tvXIPU7J9cRbtA_155), NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA215_;
			{
				LA215_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__24);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA205_;
LA213_: ;
LA205_: ;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)28):
	{
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)29):
	{
		setOutFile__main_u890((*(*colonenv__1).graph1).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		commandJsonScript__main_u791((*colonenv__1).graph1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)1):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)0):
	case ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)12):
	{
		NimStringV2 colontmpD__25;
		NimStringV2 T223_;
		colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
		T223_.len = 0; T223_.p = NIM_NIL;
		T223_ = rawNewString((*(*colonenv__1).conf0).command.len + 17);
appendString((&T223_), TM__LO85BC9bl7tvXIPU7J9cRbtA_157);
appendString((&T223_), (*(*colonenv__1).conf0).command);
		colontmpD__25 = T223_;
		liMessage__msgs_u1227((*colonenv__1).conf0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__25, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__LO85BC9bl7tvXIPU7J9cRbtA_158), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA222_;
		{
			LA222_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__25);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default: __builtin_unreachable();
	}
	{
		NIM_BOOL T228_;
		T228_ = (NIM_BOOL)0;
		T228_ = ((*(*colonenv__1).conf0).errorCounter == ((NI)0));
		if (!(T228_)) goto LA229_;
		T228_ = !(((*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)7) || (*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)26) || (*(*colonenv__1).conf0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)28)));
LA229_: ;
		if (!T228_) goto LA230_;
		{
			NimStringV2 colontmpD__26;
			tyArray__YgExxhfgKcesA5EOUj1MOA T237_;
			if (!(((*(*colonenv__1).conf0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)53)))&63U)))!=0)) goto LA234_;
			colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
			colontmpD__26 = dump__vmprofiler_u1894((*colonenv__1).conf0, (*(*colonenv__1).conf0).vmProfileData);
			if (NIM_UNLIKELY(*nimErr_)) goto LA236_;
			T237_[0] = colontmpD__26;
			echoBinSafe(T237_, 1);
			{
				LA236_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__26);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA234_: ;
		genSuccessX__msgs_u1683((*colonenv__1).conf0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA230_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___idents_u338(cache_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___main_u1302(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
