/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g;
typedef struct RootObj RootObj;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tySequence__fVUhfWxkucMvZhVKGrAHuA tySequence__fVUhfWxkucMvZhVKGrAHuA;
typedef struct tySequence__fVUhfWxkucMvZhVKGrAHuA_Content tySequence__fVUhfWxkucMvZhVKGrAHuA_Content;
typedef struct tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA;
typedef struct tyObject_Table__hBsih9beFksASOhhFeS9aGZw tyObject_Table__hBsih9beFksASOhhFeS9aGZw;
typedef struct tySequence__zpKGgayc1mFyemMGMuK9a2w tySequence__zpKGgayc1mFyemMGMuK9a2w;
typedef struct tySequence__zpKGgayc1mFyemMGMuK9a2w_Content tySequence__zpKGgayc1mFyemMGMuK9a2w_Content;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tyObject_Table__0Na0d2dQ8AYACjty2CqMPA tyObject_Table__0Na0d2dQ8AYACjty2CqMPA;
typedef struct tySequence__9cbEQVGky3gHl4QEC3q4Sow tySequence__9cbEQVGky3gHl4QEC3q4Sow;
typedef struct tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content;
typedef struct tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg;
typedef struct tySequence__kq9c1GdJLvkYJeijBmsJ20A tySequence__kq9c1GdJLvkYJeijBmsJ20A;
typedef struct tySequence__kq9c1GdJLvkYJeijBmsJ20A_Content tySequence__kq9c1GdJLvkYJeijBmsJ20A_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A;
typedef struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w tySequence__GH1mmNKNA2QP4n1tnxJf1w;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content;
typedef struct tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA;
typedef struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg tySequence__9bRXJy1JXrQ4hWpStaKBpXg;
typedef struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content;
typedef struct tySequence__olcP618a61wlx6oJIT9b0sA tySequence__olcP618a61wlx6oJIT9b0sA;
typedef struct tySequence__olcP618a61wlx6oJIT9b0sA_Content tySequence__olcP618a61wlx6oJIT9b0sA_Content;
typedef struct tySequence__W61O50MEQVwc9azCYWJekkw tySequence__W61O50MEQVwc9azCYWJekkw;
typedef struct tySequence__W61O50MEQVwc9azCYWJekkw_Content tySequence__W61O50MEQVwc9azCYWJekkw_Content;
typedef struct tySequence__bdNIx7Bah2llfuqeoTJEWQ tySequence__bdNIx7Bah2llfuqeoTJEWQ;
typedef struct tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content;
typedef struct tyObject_CountTable__LyKUoYAaSNoaROywBdHQow tyObject_CountTable__LyKUoYAaSNoaROywBdHQow;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw tySequence__jwzrUFjG9akTIJTBBFvvqxw;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw;
typedef struct tyTuple__P9bg2wlfPi4dSSTi3ICCeVA tyTuple__P9bg2wlfPi4dSSTi3ICCeVA;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct tyTuple__8TaWyfF78pGKQc2T027bVA tyTuple__8TaWyfF78pGKQc2T027bVA;
typedef struct tySequence__lBgZ7a89beZGYPl8PiANMTA tySequence__lBgZ7a89beZGYPl8PiANMTA;
typedef struct tySequence__lBgZ7a89beZGYPl8PiANMTA_Content tySequence__lBgZ7a89beZGYPl8PiANMTA_Content;
typedef struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA;
typedef struct tyTuple__w31HlKXGH5QCPFggOmKfbQ tyTuple__w31HlKXGH5QCPFggOmKfbQ;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw;
typedef struct tyTuple__Sb9czl1rSUt9cR4FEpnHeteg tyTuple__Sb9czl1rSUt9cR4FEpnHeteg;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ tySequence__6H5Oh5UUvVCLiakt9aTwtUQ;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content;
typedef struct tySequence__shxop0zPIs5Ec3k71aCLuQ tySequence__shxop0zPIs5Ec3k71aCLuQ;
typedef struct tySequence__shxop0zPIs5Ec3k71aCLuQ_Content tySequence__shxop0zPIs5Ec3k71aCLuQ_Content;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tySequence__1cgZIGFge8OGY6Zlwa9aRnw tySequence__1cgZIGFge8OGY6Zlwa9aRnw;
typedef struct tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content;
typedef struct tyTuple__IGtaz2jo9ahodpWjWgc5c5A tyTuple__IGtaz2jo9ahodpWjWgc5c5A;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw;
typedef struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w;
typedef struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg;
typedef struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyTuple__N4J9cV4JZGem3ljqqj5rT0Q;
typedef struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg;
typedef struct tyTuple__DTRsWi2kgTewbhN2TT5mbA tyTuple__DTRsWi2kgTewbhN2TT5mbA;
typedef struct tyTuple__odFiRrDKhZPQ2taWAayfYw tyTuple__odFiRrDKhZPQ2taWAayfYw;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyTuple__DfjLoSEvFkvlneCb5GSa9cQ tyTuple__DfjLoSEvFkvlneCb5GSa9cQ;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyTuple__GhsGHTmri9bgdv8XapNtpTg tyTuple__GhsGHTmri9bgdv8XapNtpTg;
typedef struct tyTuple__UGkfKgNvKJXAR6NX6Y5gaw tyTuple__UGkfKgNvKJXAR6NX6Y5gaw;
typedef struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ;
typedef struct tyTuple__9agFg9cuYsNvckAbTfHAsTSA tyTuple__9agFg9cuYsNvckAbTfHAsTSA;
typedef struct tyTuple__kIcKc1aSJCixG4QCidyBAg tyTuple__kIcKc1aSJCixG4QCidyBAg;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tySequence__fVUhfWxkucMvZhVKGrAHuA {
  NI len; tySequence__fVUhfWxkucMvZhVKGrAHuA_Content* p;
};
struct tySequence__zpKGgayc1mFyemMGMuK9a2w {
  NI len; tySequence__zpKGgayc1mFyemMGMuK9a2w_Content* p;
};
struct tyObject_Table__hBsih9beFksASOhhFeS9aGZw {
	tySequence__zpKGgayc1mFyemMGMuK9a2w data;
	NI counter;
};
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
struct tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g {
	RootObj Sup;
	NimStringV2 mainModProcs;
	NimStringV2 mainModInit;
	NimStringV2 otherModsInit;
	NimStringV2 mainDatInit;
	NimStringV2 mapping;
	tySequence__fVUhfWxkucMvZhVKGrAHuA modules;
	tySequence__fVUhfWxkucMvZhVKGrAHuA modulesClosed;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA forwardedProcs;
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* generatedHeader;
	tyObject_Table__hBsih9beFksASOhhFeS9aGZw typeInfoMarker;
	tyObject_Table__hBsih9beFksASOhhFeS9aGZw typeInfoMarkerV2;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	NI strVersion;
	NI seqVersion;
	NimStringV2 nimtv;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg nimtvDeps;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA nimtvDeclared;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw mangledPrcs;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
typedef NimStringV2 tyArray__WCl78mpHztMcuO2AmOcOQg[16];
typedef NU8 tySet_tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g;
struct tySequence__9cbEQVGky3gHl4QEC3q4Sow {
  NI len; tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content* p;
};
struct tyObject_Table__0Na0d2dQ8AYACjty2CqMPA {
	tySequence__9cbEQVGky3gHl4QEC3q4Sow data;
	NI counter;
};
struct tySequence__kq9c1GdJLvkYJeijBmsJ20A {
  NI len; tySequence__kq9c1GdJLvkYJeijBmsJ20A_Content* p;
};
struct tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg {
	tySequence__kq9c1GdJLvkYJeijBmsJ20A data;
	NI counter;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w {
  NI len; tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content* p;
};
struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g {
	NI counter;
	tySequence__GH1mmNKNA2QP4n1tnxJf1w data;
	NIM_BOOL ignoreTypes;
};
typedef NimStringV2 tyArray__ftd030ZQb0rgyFYIoQaqFA[10];
struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg {
  NI len; tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content* p;
};
struct tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA {
	tySequence__9bRXJy1JXrQ4hWpStaKBpXg data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tyArray__WCl78mpHztMcuO2AmOcOQg s;
	tySet_tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g flags;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	NimStringV2 filename;
	NimStringV2 cfilename;
	NimStringV2 tmpBase;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA typeCache;
	tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg typeABICache;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA forwTypeCache;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA declaredThings;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA declaredProtos;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA alive;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ headerFiles;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA typeInfoMarker;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA typeInfoMarkerV2;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* initProc;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* preInitProc;
	NimStringV2 hcrCreateTypeInfosProc;
	NIM_BOOL inHcrInitGuard;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg typeStack;
	tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g dataCache;
	NI typeNodes;
	NI nimTypes;
	NimStringV2 typeNodesName;
	NimStringV2 nimTypesName;
	NI labels;
	tyArray__ftd030ZQb0rgyFYIoQaqFA extensionLoaders;
	tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA sigConflicts;
	tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g;
};
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
typedef NU8 tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ;
typedef NU8 tySet_tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tySequence__olcP618a61wlx6oJIT9b0sA {
  NI len; tySequence__olcP618a61wlx6oJIT9b0sA_Content* p;
};
struct tySequence__W61O50MEQVwc9azCYWJekkw {
  NI len; tySequence__W61O50MEQVwc9azCYWJekkw_Content* p;
};
struct tySequence__bdNIx7Bah2llfuqeoTJEWQ {
  NI len; tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content* p;
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw {
  NI len; tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content* p;
};
struct tyObject_CountTable__LyKUoYAaSNoaROywBdHQow {
	tySequence__jwzrUFjG9akTIJTBBFvvqxw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc;
	tySet_tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ flags;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA currLineInfo;
	tySequence__olcP618a61wlx6oJIT9b0sA nestedTryStmts;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ finallySafePoints;
	NI labels;
	tySequence__W61O50MEQVwc9azCYWJekkw blocks;
	NI breakIdx;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySequence__bdNIx7Bah2llfuqeoTJEWQ optionsStack;
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* module;
	NI withinLoop;
	NI splitDecls;
	NI withinTryWithExcept;
	NI withinBlockLeaveActions;
	tyObject_CountTable__LyKUoYAaSNoaROywBdHQow sigConflicts;
	NI inUncheckedAssignSection;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ;
typedef NU8 tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g;
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
typedef NU8 tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA;
typedef NU8 tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NimStringV2 tyArray__NOxIfV7vwG2iyabGkP0VWg[3];
struct tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw {
	NI id;
	NimStringV2 label;
	tyArray__NOxIfV7vwG2iyabGkP0VWg sections;
	NIM_BOOL isLoop;
	NI16 nestedTryStmts;
	NI16 nestedExceptStmts;
	NI16 frameLen;
};
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef NimStringV2 tyArray__TonP9cxJgj8gXu71dWIyNlA[1];
typedef NU8 tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g;
struct tyTuple__P9bg2wlfPi4dSSTi3ICCeVA {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	NIM_BOOL Field1;
	NI Field2;
};
typedef NU8 tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw;
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
typedef NU8 tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NimStringV2 name;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* path;
};
typedef NU8 tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q;
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef NU8 tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q;
typedef NU8 tySet_tyEnum_ConsiderFlag__iOxKC1NBHc1yjhSaSfU9aPg;
typedef NU32 tyArray__PPSU5X9aizf5OJq0lL4Og7A[4];
struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg {
	tyArray__PPSU5X9aizf5OJq0lL4Og7A udata;
};
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
typedef NU8 tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg;
struct tyTuple__8TaWyfF78pGKQc2T027bVA {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NimStringV2 Field5;
	NimStringV2 Field6;
	NimStringV2 Field7;
	NimStringV2 Field8;
	NimStringV2 Field9;
	NimStringV2 Field10;
	NimStringV2 Field11;
	tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg Field12;
};
typedef tyTuple__8TaWyfF78pGKQc2T027bVA tyArray__RQFn3NKTp5P7VzZ9bksPIyA[34];
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
typedef NU8 tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA;
struct tySequence__lBgZ7a89beZGYPl8PiANMTA {
  NI len; tySequence__lBgZ7a89beZGYPl8PiANMTA_Content* p;
};
typedef tySequence__sM4lkSb7zS6F7OVMvW9cffQ tyArray__MELNUjckgdZAqcL9cILBY6A[2];
struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA {
	NI a;
	NI b;
};
typedef NimStringV2 tyArray__hSrJSIaqyFxuH67Wd7apZQ[8];
typedef NimStringV2 tyArray__uE8Y0xae4ilky52M2Sfl4Q[12];
typedef NimStringV2 tyArray__awn6UrBeChh9cVy9ccoluuYg[5];
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__iTi2aSteq9cki9bjIjUU2gYg) (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
typedef NU8 tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q;
typedef NU8 tyEnum_TTypeFieldResult__jQSyZUgToorx8YweWMVnag;
struct tyTuple__w31HlKXGH5QCPFggOmKfbQ {
	NimStringV2 Field0;
	NI32 Field1;
};
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__al2p7ldDMvbBVYNFCuu4Rw[2];
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw {
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p;
	NimStringV2 visitorFrmt;
};
typedef NU16 tySet_tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw;
struct tyTuple__Sb9czl1rSUt9cR4FEpnHeteg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NimStringV2 Field5;
	NimStringV2 Field6;
	NimStringV2 Field7;
	NimStringV2 Field8;
	NimStringV2 Field9;
	NimStringV2 Field10;
	NimStringV2 Field11;
	NimStringV2 Field12;
	NimStringV2 Field13;
	NimStringV2 Field14;
	NimStringV2 Field15;
	NimStringV2 Field16;
	NimStringV2 Field17;
	NimStringV2 Field18;
	NimStringV2 Field19;
	NimStringV2 Field20;
	tySet_tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw Field21;
};
typedef tyTuple__Sb9czl1rSUt9cR4FEpnHeteg tyArray__LheWFUTR89bV9bcpnmBZNQig[13];
typedef NU8 tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw;
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef NimStringV2 tyArray__A2YC0h9cZydgH7zGAndH9bLg[6];
typedef NimStringV2 tyArray__hFPV9bffMpPjoz9bsO9crekNg[7];
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ {
  NI len; tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content* p;
};
typedef NU8 tyEnum_TClosureTypeKind__sY8uWROOfudsYU84nI5xdg;
typedef NU8 tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w;
typedef NU8 tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w;
typedef NU8 tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA;
typedef NimStringV2 tyArray__wgmwCG2MY84OFtPmYaVG9bA[14];
typedef NU16 tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
typedef NU8 tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ;
typedef NU8 tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA;
struct tySequence__shxop0zPIs5Ec3k71aCLuQ {
  NI len; tySequence__shxop0zPIs5Ec3k71aCLuQ_Content* p;
};
typedef NU8 tyEnum_AliasKind__lRVSpyjZSQUjiqOwUaCudg;
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
typedef NU8 tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ;
typedef NU8 tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
typedef NU8 tyEnum_TNodeKind__fgQOep3rrztw9aeZI9aS2Ltg;
struct tySequence__1cgZIGFge8OGY6Zlwa9aRnw {
  NI len; tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content* p;
};
struct tyTuple__IGtaz2jo9ahodpWjWgc5c5A {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw Field0;
	NimStringV2 Field1;
};
typedef NU8 tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw {
	RootObj Sup;
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m0;
};
struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg {
	NI len;
	NI cap;
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q* d;
};
struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg {
	NI len;
	NI cap;
	tyTuple__DTRsWi2kgTewbhN2TT5mbA* d;
};
struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w {
	tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg traceStack;
	tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg toFree;
	NI freed;
	NI touched;
	NI edges;
	NI rcSum;
	NIM_BOOL keepThreshold;
};
struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q {
	void** Field0;
	TNimTypeV2* Field1;
};
typedef struct {
N_NIMCALL_PTR(NimStringV2, ClP_0) (NimStringV2 handle_p0, NimStringV2 name_p1, void* ClE_0);
void* ClE_0;
} tyProc__1MHlivbOO3FSj4t5m5NfuA;
typedef N_CLOSURE_PTR(NimStringV2, TM__MQdRN7fpbG7rPm4JpVVAhA_3671) (NimStringV2 handle_p0, NimStringV2 name_p1);
typedef N_CLOSURE_PTR(NimStringV2, TM__MQdRN7fpbG7rPm4JpVVAhA_3678) (NimStringV2 handle_p0, NimStringV2 name_p1);
typedef NU8 tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ;
struct tyTuple__odFiRrDKhZPQ2taWAayfYw {
	NimStringV2 Field0;
	NI Field1;
	tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ Field2;
	NI Field3;
	NI Field4;
};
typedef tyTuple__odFiRrDKhZPQ2taWAayfYw tyArray__BJ38CrWfGxMtyd3CSynibg[29];
typedef NU8 tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__fVUhfWxkucMvZhVKGrAHuA_Content { NI cap; tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* data[SEQ_DECL_SIZE]; };
struct tyTuple__DfjLoSEvFkvlneCb5GSa9cQ {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyTuple__w31HlKXGH5QCPFggOmKfbQ Field2;
};
struct tySequence__zpKGgayc1mFyemMGMuK9a2w_Content { NI cap; tyTuple__DfjLoSEvFkvlneCb5GSa9cQ data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tyTuple__GhsGHTmri9bgdv8XapNtpTg {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	NimStringV2 Field2;
};
struct tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content { NI cap; tyTuple__GhsGHTmri9bgdv8XapNtpTg data[SEQ_DECL_SIZE]; };
struct tyTuple__UGkfKgNvKJXAR6NX6Y5gaw {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
};
struct tySequence__kq9c1GdJLvkYJeijBmsJ20A_Content { NI cap; tyTuple__UGkfKgNvKJXAR6NX6Y5gaw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ {
	NI h;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key;
	NI val;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content { NI cap; tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ data[SEQ_DECL_SIZE]; };
struct tyTuple__9agFg9cuYsNvckAbTfHAsTSA {
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field0;
	NI Field1;
};
struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content { NI cap; tyTuple__9agFg9cuYsNvckAbTfHAsTSA data[SEQ_DECL_SIZE]; };
struct tySequence__olcP618a61wlx6oJIT9b0sA_Content { NI cap; tyTuple__P9bg2wlfPi4dSSTi3ICCeVA data[SEQ_DECL_SIZE]; };
struct tySequence__W61O50MEQVwc9azCYWJekkw_Content { NI cap; tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw data[SEQ_DECL_SIZE]; };
struct tyTuple__kIcKc1aSJCixG4QCidyBAg {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ Field0;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw Field1;
};
struct tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content { NI cap; tyTuple__kIcKc1aSJCixG4QCidyBAg data[SEQ_DECL_SIZE]; };
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
	NimStringV2 Field0;
	NI Field1;
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content { NI cap; tyTuple__XOVT24GHXwqiEj5GCsEGCA data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__lBgZ7a89beZGYPl8PiANMTA_Content { NI cap; NIM_CHAR data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content { NI cap; NU8 data[SEQ_DECL_SIZE]; };
struct tySequence__shxop0zPIs5Ec3k71aCLuQ_Content { NI cap; NIM_BOOL data[SEQ_DECL_SIZE]; };
struct tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content { NI cap; tyTuple__IGtaz2jo9ahodpWjWgc5c5A data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4955)(RootObj** dest_p0, RootObj* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g*, newModuleList__cgendata_u2124)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u2191)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(RootObj*, eqdup___ast_u4951)(RootObj* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, newModule__cgen_u30936)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, rawNewModule__cgen_u30931)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, rawNewModule__cgen_u30756)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, NimStringV2 filename_p2);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___cgendata_u2194)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g** dest_p0, tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___modulegraphs_u10732)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow u_p0);
N_LIB_PRIVATE N_NIMCALL(void, hashOwner__sighashes_u491)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Result);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u5515)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZcollectionsZintsets_u236)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* src_p1);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_u37)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___cgen_u30810)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* dest_p0, tyObject_Table__0Na0d2dQ8AYACjty2CqMPA src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA, initTable__cgen_u30780)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u30801)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___cgen_u30888)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* dest_p0, tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA, initCountTable__cgen_u30860)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u30879)(tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___cgendata_u2082)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A** dest_p0, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A*, newProc__cgendata_u509)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* module_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u2071)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* dest_p0);
static N_INLINE(NimStringV2, newRopeAppender__ropes_u7)(NI cap_p0);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ, initProcOptions__cgen_u30744)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6538)(tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g* dest_p0, tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g, initNodeTable__ast_u6397)(NIM_BOOL ignoreTypes_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6529)(tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3320)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* dest_p0, tySequence__d8ZV4IMgHt9biik9cS9a0hrmg src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTempName__cgen_u462)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rope__ropes_u15)(NI64 i_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1560)(tySequence__fVUhfWxkucMvZhVKGrAHuA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___cgendata_u721)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA** dest_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u718)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3103)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug** dest_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___cgendata_u729)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA** dest_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, noschangeFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, completeCfilePath__extccomp_u929)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 cfile_p1, NIM_BOOL createSubDir_p2);
static N_INLINE(NIM_BOOL, skipCodegen__pipelineutils_u8)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformStmt__transf_u3500)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA flags_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, injectDestructorCalls__injectdestructors_u3431)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__cgen_u49)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__options_u629)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__cgen_u31085)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL* inInitGuard_p2);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, endBlock__cgen_u15767)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16204)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16209)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9681)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, endBlock__cgen_u16185)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 blockEnd_p1);
N_LIB_PRIVATE N_NIMCALL(void, blockBody__cgen_u16177)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* b_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16180)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u311)(tySequence__W61O50MEQVwc9azCYWJekkw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, addIndent__cgen_u315)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLengthStrV2)(NimStringV2* s_p0, NI newLen_p1);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
static N_INLINE(NimStringV2*, s__cgendata_u228)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g s_p1);
static N_INLINE(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw*, X5BX5D___cgendata_u232)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(NI, startBlockInternal__cgen_u15729)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__cgen_u15740)(tySequence__W61O50MEQVwc9azCYWJekkw* x_p0, tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, initBlock__cgendata_u468)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* Result);
N_LIB_PRIVATE N_NIMCALL(NI, inExceptBlockLen__cgen_u15682)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, genStmts__cgen_u14081)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__options_u557)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw note_p1);
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__msgs_u569)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 detail_p2);
N_LIB_PRIVATE N_NIMCALL(void, expr__cgen_u14084)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, fillProcLoc__cgen_u14051)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, fillBackendName__cgen_u896)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleProc__cgen_u767)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NIM_BOOL makeUnique_p2);
static N_INLINE(NI, len__ast_u5502)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, encodeType__ccgutils_u228)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2* staticLists_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, encodeSym__ccgutils_u221)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NIM_BOOL makeUnique_p2, NimStringV2 extra_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__cgen_u837)(tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw s_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, incl__options_u2181)(tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw* s_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangle__mangleutils_u4)(NimStringV2 name_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleProcNameExt__mangleutils_u35)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, idOrSig__sighashes_u2002)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, NimStringV2 currentModule_p1, tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA* sigCollisions_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
static N_INLINE(void, fillLoc__cgen_u88)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p0, tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode_p2, tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg s_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, genProcPrototype__cgen_u523)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, useHeader__cgen_u123)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getStr__ast_u7064)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(void, includeHeader__cgendata_u217)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* this_p0, NimStringV2 header_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astyaml_u223)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_u163)(NimStringV2* result_p0, NimStringV2 value_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isReloadable__cgen_u8812)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeDesc__cgen_u8738)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q kind_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeDescAux__cgen_u1419)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origTyp_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p2, tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q kind_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedCppType__cgen_u1384)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeToString__types_u54)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q prefer_p1);
N_LIB_PRIVATE N_NIMCALL(void, hashType__sighashes_u411)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tySet_tyEnum_ConsiderFlag__iOxKC1NBHc1yjhSaSfU9aPg flags_p2, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypePre__cgen_u3178)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSimpleTypeDesc__cgen_u1917)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeNameOrLiteral__cgen_u1900)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2 literal_p2);
N_LIB_PRIVATE N_NIMCALL(NI, detectStrVersion__cgen_u579)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getCompilerProc__magicsys_u150)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NimStringV2 name_p1);
N_LIB_PRIVATE N_NIMCALL(NI, toInt__int128_u257)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getInt__ast_u7046)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, astdef__ast_u4596)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, cgsym__cgen_u138)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1);
static N_INLINE(void, cgsymImpl__cgen_u28031)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, genProc__cgen_u454)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isActivated__cgen_u29100)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p0);
N_LIB_PRIVATE N_NIMCALL(void, addForwardedProc__cgen_u55)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__renderer_u83)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, genProcNoForward__cgen_u28805)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, findPendingModule__cgen_u62)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getModule__astalgo_u156)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLib__cgen_u27914)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u6219)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGetProcAddr__cgen_u27777)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_p0);
N_LIB_PRIVATE N_NIMCALL(void, loadDynamicLib__cgen_u27793)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27807)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, libCandidates__pureZdynlib_u81)(NimStringV2 s_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p1);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5422)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NimStringV2 strVal_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cgsymValue__cgen_u141)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1);
N_LIB_PRIVATE N_NIMCALL(void, addActualSuffixForHCR__cgen_u15038)(NimStringV2* res_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteral__cgen_u714)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralV1__cgen_u615)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NI, nodeTableTestOrSet__treetab_u225)(tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g* t_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key_p1, NI val_p2);
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralDataOnlyV1__cgen_u605)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 s_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u610)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeCString__msgs_u83)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_u166)(NimStringV2* result_p0, NI64 value_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralV2__cgen_u664)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralDataOnlyV2__cgen_u654)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 s_p1, NimStringV2 result_p2, NIM_BOOL isConst_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u659)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u672)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27845)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27859)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5506)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, initLoc__cgen_u72)(tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode_p1, tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg s_p2, tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, eqdup___ast_u3258)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rdLoc__cgen_u470)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6284)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleDynLibProc__cgen_u5410)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, initLocExpr__cgen_u14111)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6293)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27934)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info_p0);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27971)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, t__cgen_u97)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6216)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u28853)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getModuleDllPath__cgen_u158)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getModuleDllPath__cgen_u146)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg, splitFile__pathutils_u39)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getCFile__cgen_u144)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleModuleName__modulepaths_u40)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pathutils_u73)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLibPartial__cgen_u28028)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, genProcAux__cgen_u28424)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(void, genMemberProcHeader__cgen_u5241)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1, NimStringV2* result_p2, NIM_BOOL asPtr_p3, NIM_BOOL isFwdDecl_p4);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, firstParamType__ast_u5363)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeDescWeak__cgen_u3400)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p2, tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q kind_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeForward__cgen_u3216)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cacheGetType__cgen_u1466)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA tab_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOrDefault__cgen_u1536)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeName__cgen_u1281)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p2);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipModifier__ast_u5338)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, typeName__cgen_u1266)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u182)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg e_p0);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___cgen_u1967)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, NimStringV2 val_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedType__cgen_u1373)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, addForwardStructFormat__cgen_u3187)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 structOrUnion_p1, NimStringV2 typename_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u3199)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u3204)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, structOrUnion__cgen_u545)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, pushType__cgen_u3159)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3891)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* x_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, eqdup___ast_u3384)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2*, X5BX5D___cgen_u3321)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, failedAssertImpl__stdZassertions_u79)(NimStringV2 msg_p0);
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, seqStar__cgen_u3209)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(void, parseVFunctionDecl__cgen_u8828)(NimStringV2 val_p0, NimStringV2* name_p1, NimStringV2* params_p2, NimStringV2* retType_p3, NimStringV2* superCall_p4, NIM_BOOL* isFnConst_p5, NIM_BOOL* isOverride_p6, NIM_BOOL* isMemberVirtual_p7, NIM_BOOL* isStatic_p8, NIM_BOOL isCtor_p9, NIM_BOOL isFunctor_p10);
static N_INLINE(NI, parseUntil__pureZparseutils_u966)(NimStringV2 s_p0, NimStringV2* token_p1, NimStringV2 until_p2, NI start_p3);
static N_INLINE(NI, parseUntil__pureZparseutils_u266)(NIM_CHAR* s_p0, NI s_p0Len_0, NimStringV2* token_p1, NimStringV2 until_p2);
N_LIB_PRIVATE N_NIMCALL(void, fastSubstr__pureZparseutils_u225)(NIM_CHAR* s_p0, NI s_p0Len_0, NimStringV2* token_p1, NI length_p2);
static N_INLINE(NI, skip__pureZparseutils_u929)(NimStringV2 s_p0, NimStringV2 token_p1, NI start_p2);
static N_INLINE(NI, skip__pureZparseutils_u145)(NIM_CHAR* s_p0, NI s_p0Len_0, NIM_CHAR* token_p1, NI token_p1Len_0);
static N_INLINE(NI, skipWhitespace__pureZparseutils_u925)(NimStringV2 s_p0, NI start_p1);
static N_INLINE(NI, skipWhitespace__pureZparseutils_u130)(NIM_CHAR* s_p0, NI s_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuStrip)(NimStringV2 s_p0, NIM_BOOL leading_p1, NIM_BOOL trailing_p2, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p3);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindStr)(NimStringV2 s_p0, NimStringV2 sub_p1, NI start_p2, NI last_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuReplaceStr)(NimStringV2 s_p0, NimStringV2 sub_p1, NimStringV2 by_p2);
N_LIB_PRIVATE N_NIMCALL(void, genMemberProcParams__cgen_u3576)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1, NimStringV2* superCall_p2, NimStringV2* rettype_p3, NimStringV2* name_p4, NimStringV2* params_p5, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p6, NIM_BOOL declareEnvironment_p7, NIM_BOOL weakDep_p8);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInvalidReturnType__cgen_u1424)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NIM_BOOL isProc_p2);
N_LIB_PRIVATE N_NIMCALL(NI64, getSize__types_u3397)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA, mapType__cgen_u1315)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NIM_BOOL isParam_p2);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA, mapSetType__cgen_u1311)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int128_u933)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, NI64 b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, firstOrd__types_u1182)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsGarbageCollectedRef__types_u555)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
static N_INLINE(NIM_BOOL, isObjLackingTypeField__types_u2952)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, baseClass__ast_u5348)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isPureObject__types_u121)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, runtimeFormat__ropes_u39)(NimStringV2 frmt_p0, NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, fillParamName__cgen_u916)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleParamExt__mangleutils_u32)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg, paramStorageLoc__cgen_u3542)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ccgIntroducedPtr__ccgutils_u130)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* retType_p2);
static N_INLINE(NimStringV2*, X5BX5D___cgen_u3675)(NimStringV2* s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, multiFormat__cgen_u3707)(NimStringV2* frmt_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* args_p2, NI args_p2Len_0);
static N_INLINE(NI, find__cgen_u3719)(tySequence__lBgZ7a89beZGYPl8PiANMTA a_p0, NIM_CHAR item_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8632)(NimStringV2 s_p0, NI first_p1, NI last_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuJoinSep)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 sep_p1);
static N_INLINE(void, X5BX5Deq___system_u8114)(NimStringV2* s_p0, NI i_p1, NIM_CHAR x_p2);
N_LIB_PRIVATE N_NIMCALL(void, delete__pureZstrutils_u1360)(NimStringV2* s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA slice_p1);
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8988)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8993)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8998)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u230)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, genProcHeader__cgen_u9040)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1, NimStringV2* result_p2, NIM_BOOL asPtr_p3);
N_LIB_PRIVATE N_NIMCALL(void, genProcParams__cgen_u3939)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2* rettype_p2, NimStringV2* params_p3, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p4, NIM_BOOL declareEnvironment_p5, NIM_BOOL weakDep_p6);
static N_INLINE(NIM_BOOL, isCompileTimeOnly__types_u3641)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u4005)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA, mapReturnType__cgen_u1369)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u4029)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isNonReloadable__cgen_u8820)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9070)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, transformBody__transf_u26)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p2, tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA flags_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, freshLineInfo__cgen_u404)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, easyResultAsgn__cgen_u28177)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsResult__cgen_u28141)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, localVarDecl__cgen_u13649)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, fillLocalName__cgen_u920)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__cgen_u1001)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow t_p0, NimStringV2 key_p1, NI def_p2);
N_LIB_PRIVATE N_NIMCALL(void, inc__cgen_u1077)(tyObject_CountTable__LyKUoYAaSNoaROywBdHQow* t_p0, NimStringV2 key_p1, NI val_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u13670)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_u408)(NimStringV2* r_p0, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3);
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_u382)(NimStringV2* r_p0, NI32 fileIdx_p1, NI line_p2, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, NI32 lastFileIndex_p5);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u24)(NI32 xX60gensym3__p0);
N_LIB_PRIVATE N_NIMCALL(NI, safeLineNm__cgen_u362)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0);
static N_INLINE(NI, toLinenumber__msgs_u695)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0);
N_LIB_PRIVATE N_NIMCALL(void, initLocExprSingleUse__cgen_u14116)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(void, assignLocalVar__cgen_u13691)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOrHasImportedCppType__cgen_u1404)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, searchTypeFor__types_u423)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyProc__iTi2aSteq9cki9bjIjUU2gYg predicate_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genCppInitializer__cgen_u4564)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* prc_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, NIM_BOOL* didGenTemp_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__cgen_u4625)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___cgen_u4964)(tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___cgendata_u2074)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A** dest_p0, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, eqdup___cgendata_u725)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genCppParamsForCtor__cgen_u4560)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_p1, NIM_BOOL* didGenTemp_p2);
N_LIB_PRIVATE N_NIMCALL(void, genOtherArg__cgen_u14099)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, NI i_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, NimStringV2* result_p4, NI* argsCounter_p5);
N_LIB_PRIVATE N_NIMCALL(void, genArgNoParam__cgen_u14798)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2, NIM_BOOL needsTmp_p3);
static N_INLINE(void, genArgStringToCString__cgen_u14678)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2, NIM_BOOL needsTmp_p3);
N_LIB_PRIVATE N_NIMCALL(void, withTmpIfNeeded__cgen_u14661)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, NIM_BOOL needsTmp_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(void, getTemp__cgen_u9546)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NIM_BOOL needsInit_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lodeTyp__cgen_u104)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNode__ast_u4069)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0);
N_LIB_PRIVATE N_NIMCALL(void, constructLoc__cgen_u13487)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* loc_p1, NIM_BOOL isTemp_p2);
static N_INLINE(NIM_BOOL, isComplexValueType__cgen_u13074)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, genRefAssign__cgen_u13070)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2);
static N_INLINE(NIM_BOOL, usesWriteBarrier__options_u3582)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, addrLoc__cgen_u12821)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q, descKindFromSymKind__cgen_u735)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasNoInit__cgen_u1407)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, genObjectInit__cgen_u12909)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g section_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p3, tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q mode_p4);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TTypeFieldResult__jQSyZUgToorx8YweWMVnag, analyseObjectWithTypeField__types_u528)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u12921)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfoV2__cgen_u10426)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u10908)(tyTuple__w31HlKXGH5QCPFggOmKfbQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__w31HlKXGH5QCPFggOmKfbQ, getOrDefault__cgen_u10580)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1);
N_LIB_PRIVATE N_NIMCALL(void, declareNimType__cgen_u9964)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1, NimStringV2 str_p2, NI module_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9970)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9975)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getModuleDllPath__cgen_u154)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NI module_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9980)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10973)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(NIM_BOOL, moduleOpenForCodegen__modulegraphs_u14816)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 m_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___cgen_u11067)(tyObject_Table__hBsih9beFksASOhhFeS9aGZw* t_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1, tyTuple__w31HlKXGH5QCPFggOmKfbQ val_p2);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoV2OldImpl__cgen_u10191)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10197)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canFormAcycle__types_u784)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10204)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genHook__cgen_u10069)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getAttachedOp__modulegraphs_u4987)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p2);
static N_INLINE(NIM_BOOL, isTrivialProc__cgen_u10033)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getBody__modulegraphs_u17880)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, loadProcBody__icZic_u21187)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, generateRttiDestructor__cgen_u10037)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q kind_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p5, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* theProc_p6);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getSysType__magicsys_u55)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newProcType__ast_u7492)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2);
N_LIB_PRIVATE N_NIMCALL(void, addParam__ast_u7497)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* procType_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4095)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NI children_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5168)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makePtrType__magicsys_u184)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* baseType_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTreeI__ast_u4180)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p2, NI children_p2Len_0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newDeref__lowerings_u12)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeIT__ast_u4112)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTreeIT__ast_u4191)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p3, NI children_p3Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10209)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NI16, getObjDepth__cgen_u10096)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfo2Name__cgen_u9985)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10240)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10245)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genDisplay__cgen_u10125)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NI depth_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, newSeq__stdZsyncio_u571)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u49)(NU32 xX60gensym8__p0);
N_LIB_PRIVATE N_NIMCALL(NU32, genDisplayElem__cgen_u10109)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow d_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10252)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10257)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_u8507)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__olFOFaYzOJN9aV5BWqK4b9bA*, X5BX5D___modulegraphs_u8590)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, resolveSym__modulegraphs_u3497)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4845)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10285)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genVTable__cgen_u10180)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA seqs_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10294)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfoV1__cgen_u9076)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u12435)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeToC__cgen_u12225)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c_p0);
N_LIB_PRIVATE N_NIMCALL(NI32, getOrDefault__cgen_u12552)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, rememberEmittedTypeInfo__modulegraphs_u14828)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 m_p1, NimStringV2 ti_p2);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAuxBase__cgen_u9097)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, NimStringV2 base_p4, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p5);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, tiNameForHcr__cgen_u9093)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9117)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9123)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___msgs_u714)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9137)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9142)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9147)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9152)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9157)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, fakeClosureType__cgen_u9529)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newType__ast_u5900)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p3);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_u6706)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1, NIM_BOOL propagateHasAsgn_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, createObj__lowerings_u174)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, NIM_BOOL final_p4);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__cgen_u9403)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimNode__cgen_u9080)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9083)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NI, validTupleTypeFields__cgen_u9394)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
static N_INLINE(NIM_BOOL, isEmptyType__ast_u7234)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, genTNimNodeArray__cgen_u9231)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1, NimStringV2 size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9235)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9240)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9245)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9264)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9420)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9269)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9274)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9380)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAux__cgen_u9162)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
static N_INLINE(NIM_BOOL, hasElementType__ast_u5660)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, last__ast_u5278)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTraverseProc__cgen_u9823)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origTyp_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9832)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9839)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9844)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A*, eqdup___cgendata_u2078)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* src_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProcSeq__cgen_u9642)(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw c_p0, NimStringV2 accessor_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
static N_INLINE(void, freeze__ropes_u10)(NimStringV2 r_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9808)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, lenExpr__cgen_u495)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u503)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(NimStringV2, lenField__cgen_u484)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__cgen_u9539)(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw c_p0, NimStringV2 accessor_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, lengthOrd__types_u1491)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, indexType__ast_u5345)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_u169)(NimStringV2* result_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg value_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt128__int128_u821)(NimStringV2* result_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg value_p1);
static N_INLINE(NimStringV2, parentObj__cgen_u9625)(NimStringV2 accessor_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9637)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__cgen_u9550)(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw c_p0, NimStringV2 accessor_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3);
N_LIB_PRIVATE N_NIMCALL(void, fillObjectFields__cgen_u5401)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(void, addRecordFields__cgen_u5247)(NimStringV2* result_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p3);
N_LIB_PRIVATE N_NIMCALL(void, genRecordFieldsAux__cgen_u5054)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* rectype_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p3, NimStringV2* result_p4, NimStringV2 unionPrefix_p5);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleRecFieldName__cgen_u4042)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleField__cgen_u763)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isKeyword__cgen_u757)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* w_p0);
static N_INLINE(void, fillLoc__cgen_u78)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p0, tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode_p2, NimStringV2 r_p3, tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg s_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elemType__types_u254)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasCppCtor__cgen_u4054)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__cgen_u4125)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA*, X5BX5D___cgen_u4463)(tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(void, addField__cgen_u534)(NimStringV2* obj_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p1, NimStringV2 name_p2, NimStringV2 typ_p3, NIM_BOOL isFlexArray_p4, NimStringV2 initializer_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4851)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0, tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u5386)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u5396)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9574)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genCaseRange__cgen_u9543)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_p1);
N_LIB_PRIVATE N_NIMCALL(void, genLiteral__cgen_u14095)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, genLiteral__cgen_u20138)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(void, intLiteral__cgen_u14092)(NI64 i_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u20104)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, int64Literal__cgen_u20097)(NI64 i_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(void, uint64Literal__cgen_u20109)(NU64 i_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u54)(NU64 xX60gensym9__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u20168)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u20177)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genNilStringLiteral__cgen_u701)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toStrMaxPrecision__cgen_u20199)(NF32 f_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toStrMaxPrecision__astyaml_u674)(NF f_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___nodekinds_u168)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u18066)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyNode__ast_u6736)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u18073)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9596)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9601)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9606)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9620)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9814)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dataField__cgen_u516)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9869)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9875)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9880)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9885)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u9893)(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1051)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u12703)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genArrayInfo__cgen_u9524)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, genSetInfo__cgen_u9506)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9519)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rope__cgen_u9217)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___int128_u36)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0);
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__cgen_u9442)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9474)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9481)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9486)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9491)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9496)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9501)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__cgen_u9350)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(void, genObjectFields__cgen_u9250)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, NimStringV2 expr_p4, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p5);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, discriminatorTableName__cgen_u9198)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* objtype_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* d_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, lookupInRecord__astalgo_u30)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* field_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9212)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9296)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9226)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, plus___int128_u1015)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, NI64 b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getOrdValue__types_u167)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9345)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, openArrayToTuple__cgen_u12207)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3881)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1);
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopyProc__cgen_u9955)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 result_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9959)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u12743)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoV2Impl__cgen_u10311)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10323)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10349)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10356)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10361)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10371)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10395)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10404)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u10409)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, rawConstExpr__cgen_u12894)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u20252)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genBracedInit__cgen_u16526)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* optionalType_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ, toBitSet__nimsets_u73)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, genRawSetData__cgen_u20229)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ cs_p0, NI size_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NU64, bitSetToWord__bitsets_u237)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ s_p0, NI size_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZtimes_u2620)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, genConstSeqV2__cgen_u27543)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, NIM_BOOL isConst_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27454)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27635)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSeqPayloadType__cgen_u3522)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, genConstSeq__cgen_u27436)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, NIM_BOOL isConst_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27442)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27538)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27678)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getClosureType__cgen_u8751)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyEnum_TClosureTypeKind__sY8uWROOfudsYU84nI5xdg kind_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8050)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8055)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genConstSimpleList__cgen_u27385)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(void, getDefaultValue__cgen_u27230)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAuxT__cgen_u20082)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* orig_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constOrNil_p4, NimStringV2* result_p5, NI* count_p6, NIM_BOOL isConst_p7, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p8);
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAux__cgen_u27283)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constOrNil_p3, NimStringV2* result_p4, NI* count_p5, NIM_BOOL isConst_p6, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p7);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3699)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3696)(tySequence__9ahcSjIErJohSBBFLwuF56Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, caseObjDefaultBranch__expanddefaults_u4)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg branch_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isEmptyCaseObjectBranch__cgen_u27275)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___renderer_u2166)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NIM_BOOL, isEmptyTupleType__ast_u5666)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, genConstTuple__cgen_u27412)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tup_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u27758)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genConstObjConstr__cgen_u27374)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralV2Const__cgen_u682)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u689)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u20257)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genAssignment__cgen_u12898)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3);
N_LIB_PRIVATE N_NIMCALL(void, genGenericAsgn__cgen_u20436)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canMove__cgen_u20278)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDeepConstExpr__trees_u153)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NIM_BOOL preventInheritance_p1);
N_LIB_PRIVATE N_NIMCALL(void, optAsgnLoc__cgen_u20366)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2 field_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
static N_INLINE(NI, kidsLen__ast_u5648)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnTuple__cgen_u20374)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u20400)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NI, asgnComplexity__cgen_u20354)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnObject__cgen_u20406)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p4, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p5);
static N_INLINE(NIM_BOOL, reifiedOpenArray__cgen_u14410)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayConv__cgen_u20514)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dataFieldAccessor__cgen_u508)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 sym_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, byRefLoc__cgen_u12841)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isException__types_u4100)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u6287)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p1);
N_LIB_PRIVATE N_NIMCALL(void, addRdLoc__cgen_u477)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA, allPathsAsgnResult__cgen_u28217)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseDisp__cgen_u14148)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaise__ast_u7516)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fn_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseConservative__ast_u7504)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fn_p0);
N_LIB_PRIVATE N_NIMCALL(void, initLocalVar__cgen_u13552)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, NIM_BOOL immediateAsgn_p2);
N_LIB_PRIVATE N_NIMCALL(void, fillResult__cgen_u1887)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* param_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* proctype_p2);
N_LIB_PRIVATE N_NIMCALL(void, assignParam__cgen_u14044)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* retType_p2);
N_LIB_PRIVATE N_NIMCALL(void, scopeMangledParam__cgen_u1246)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p1);
N_LIB_PRIVATE N_NIMCALL(void, resetLoc__cgen_u13360)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* loc_p1);
N_LIB_PRIVATE N_NIMCALL(void, specializeReset__cgen_u13357)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1);
N_LIB_PRIVATE N_NIMCALL(void, specializeResetT__cgen_u13094)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 accessor_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
N_LIB_PRIVATE N_NIMCALL(void, specializeResetN__cgen_u13098)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 accessor_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3);
N_LIB_PRIVATE N_NIMCALL(void, closureSetup__cgen_u28093)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(void, genProcBody__cgen_u28369)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* procBody_p1);
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_u396)(NimStringV2* r_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2);
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_u370)(NimStringV2* r_p0, NI32 fileIdx_p1, NI line_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3);
static N_INLINE(NIM_BOOL, isNoReturn__cgen_u28412)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, initFrame__cgen_u19996)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 procname_p1, NimStringV2 filename_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, quotedFilename__msgs_u1638)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, deinitFrame__cgen_u20066)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u28637)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getProcTypeCast__cgen_u28353)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u28364)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_u2846)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26278)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genVarPrototype__cgen_u14075)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, treatGlobalDifferentlyForHCR__cgen_u13851)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_u366)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(void, declareThreadVar__cgen_u13751)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NIM_BOOL isExtern_p2);
static N_INLINE(NIM_BOOL, emulatedThreadVars__cgen_u452)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u13808)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(NimStringV2*, procSec__cgendata_u464)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26797)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u309)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q e_p0);
N_LIB_PRIVATE N_NIMCALL(void, excl__suggestsymdb_u161)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__cgen_u6258)(tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg* s_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow key_p1);
N_LIB_PRIVATE N_NIMCALL(void, addAbiCheck__cgen_u1860)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2 name_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, colonanonymous___cgen_u1869)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, addTypeHeader__types_u209)(NimStringV2* result_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q prefer_p3, NIM_BOOL getDeclarationPath_p4);
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZprivateZoscommon_u120)(NimStringV2* s_p0, NimStringV2 x_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u1882)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOpenArrayDesc__cgen_u6122)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p2, tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q kind_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u6180)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u7974)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u7979)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u7984)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u7993)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8266)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__int128_u53)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8319)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, scanCppGenericSlot__cgen_u6072)(NimStringV2 pat_p0, NI* cursor_p1, NI* outIdx_p2, NI* outStars_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, resolveStarsInCppType__cgen_u6104)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, NI idx_p1, NI stars_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderTree__renderer_u59)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8645)(NimStringV2 s_p0, NI first_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getRecordDesc__cgen_u5412)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p3);
static N_INLINE(NIM_BOOL, lacksMTypeField__types_u2937)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
N_LIB_PRIVATE N_NIMCALL(void, addField__cgen_u530)(NimStringV2* obj_p0, NimStringV2 name_p1, NimStringV2 typ_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, ptrType__cgen_u553)(NimStringV2 t_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8394)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTupleDesc__cgen_u5748)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8666)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u8671)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(NIM_BOOL, requiresExternC__cgen_u28642)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, putLocIntoDest__cgen_u14088)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw s_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleConst__cgen_u107)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
N_LIB_PRIVATE N_NIMCALL(void, putIntoDest__cgen_u21142)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, NimStringV2 r_p3, tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg s_p4);
N_LIB_PRIVATE N_NIMCALL(void, genConstHeader__cgen_u26784)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* q_p1, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, genConstSetup__cgen_u26767)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26792)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26802)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genComplexConst__cgen_u26529)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, requestConstImpl__cgen_u14078)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, genConstDefinition__cgen_u26816)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* q_p0, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26822)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26835)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__cgen_u16620)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* vn_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p3);
N_LIB_PRIVATE N_NIMCALL(void, genGotoVar__cgen_u16514)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16521)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(NIM_BOOL, isAssignedImmediately__cgen_u15650)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, potentialValueInit__cgen_u16532)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__cgen_u52)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsHiddenPointer__types_u601)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
N_LIB_PRIVATE N_NIMCALL(void, callGlobalVarCppCtor__cgen_u14035)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* vn_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p3, NIM_BOOL* didGenTemp_p4);
N_LIB_PRIVATE N_NIMCALL(void, genGlobalVarDecl__cgen_u13871)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 td_p2, NimStringV2 value_p3, NimStringV2* decl_p4);
N_LIB_PRIVATE N_NIMCALL(void, genCppVarForCtor__cgen_u13914)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_p1, NimStringV2* decl_p2, NIM_BOOL* didGenTemp_p3);
N_LIB_PRIVATE N_NIMCALL(void, assignGlobalVar__cgen_u13919)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 value_p2);
N_LIB_PRIVATE N_NIMCALL(void, varInDynamicLib__cgen_u13848)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u28023)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringV2 s_p0, NimStringV2 prefix_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14026)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, registerTraverseProc__cgen_u15592)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsManagedMemory__types_u573)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTraverseProcForGlobal__cgen_u9927)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(void, accessThreadLocalVar__cgen_u449)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u13733)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9939)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u9945)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__cgen_u418)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, sourceLine__msgs_u1210)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p1);
static N_INLINE(NIM_BOOL, endsWith__pureZstrutils_u1414)(NimStringV2 s_p0, NIM_CHAR suffix_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genPostprocessDir__cgen_u365)(NimStringV2 field1_p0, NimStringV2 field2_p1, NimStringV2 field3_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16719)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16724)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(void, loadInto__cgen_u16153)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p3);
N_LIB_PRIVATE N_NIMCALL(void, genAsgnCall__cgen_u15561)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInactiveDestructorCall__cgen_u15553)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1);
static N_INLINE(NIM_BOOL, notYetAlive__cgen_u15541)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getRoot__trees_u373)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipAddr__trees_u429)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, genClosureCall__cgen_u15095)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3);
N_LIB_PRIVATE N_NIMCALL(void, genParams__cgen_u14860)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(tySequence__shxop0zPIs5Ec3k71aCLuQ, newSeq__cgen_u14881)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipTrivialIndirections__cgen_u14825)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, potentialAlias__cgen_u14809)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q potentialWrites_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_AliasKind__lRVSpyjZSQUjiqOwUaCudg, aliases__aliasanalysis_u67)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* field_p1);
N_LIB_PRIVATE N_NIMCALL(void, getPotentialReads__cgen_u14852)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q* result_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3225)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, getPotentialWrites__cgen_u14828)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NIM_BOOL mutate_p1, tySequence__9ahcSjIErJohSBBFLwuF56Q* result_p2);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg, getMagic__trees_u122)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* op_p0);
N_LIB_PRIVATE N_NIMCALL(void, genArg__cgen_u14693)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_p3, NimStringV2* result_p4, NIM_BOOL needsTmp_p5);
N_LIB_PRIVATE N_NIMCALL(void, openArrayLoc__cgen_u14535)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formalType_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipConv__types_u3715)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__UV3llMMYFckfui8YMBuUZA, genOpenArraySlice__cgen_u14422)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* q_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formalType_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* destType_p3, NIM_BOOL prepareForMutation_p4);
N_LIB_PRIVATE N_NIMCALL(void, genBoundsCheck__cgen_u14404)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw arr_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* arrTyp_p4);
N_LIB_PRIVATE N_NIMCALL(void, raiseInstr__cgen_u457)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(void, intLiteral__cgen_u20135)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg i_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, lastOrd__types_u1298)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rdCharLoc__cgen_u12869)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u12876)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14455)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14462)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14468)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14473)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14478)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14525)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14530)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZprivateZospaths2_u306)(tyTuple__UV3llMMYFckfui8YMBuUZA dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14575)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14580)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14585)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14633)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14638)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14643)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, addAddrLoc__cgen_u12801)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, expressionsNeedsTmp__cgen_u14674)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, exactReplica__ast_u6243)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameBackendTypePickyAliases__types_u2757)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14793)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u14965)(tySequence__shxop0zPIs5Ec3k71aCLuQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, preventNrvo__cgen_u14180)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p3);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ, isPartOf__aliases_u120)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, locationEscapes__cgen_u14186)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, NIM_BOOL inTryStmt_p2);
static N_INLINE(NIM_BOOL, hasNoInit__cgen_u14238)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u15142)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, addComma__cgen_u15100)(NimStringV2 r_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u15147)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExit__cgen_u14106)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
static N_INLINE(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*, X5BX5D___cgen_u17403)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isHarmlessStore__cgen_u14249)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NIM_BOOL canRaise_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u15181)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u15186)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__cgen_u15418)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1837)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p1);
N_LIB_PRIVATE N_NIMCALL(void, genPatternCall__cgen_u15339)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, NimStringV2 pat_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(void, genThisArg__cgen_u15283)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, NI i_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipAddrDeref__cgen_u15266)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_p0);
N_LIB_PRIVATE N_NIMCALL(void, fixupCall__cgen_u14292)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3, NimStringV2 callee_p4, NimStringV2 params_p5);
N_LIB_PRIVATE N_NIMCALL(void, getTempCpp__cgen_u13605)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2 value_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, cleanupTemp__cgen_u14263)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* returnType_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_p2);
N_LIB_PRIVATE N_NIMCALL(void, raiseExitCleanup__cgen_u14108)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 destroy_p1);
N_LIB_PRIVATE N_NIMCALL(void, genNamedParamCall__cgen_u15479)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
static N_INLINE(NIM_BOOL, contains__stdZprivateZospaths2_u383)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1);
static N_INLINE(NI, find__stdZprivateZospaths2_u388)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1);
N_LIB_PRIVATE N_NIMCALL(void, genPrefixCall__cgen_u15075)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3);
N_LIB_PRIVATE N_NIMCALL(void, putDataIntoDest__cgen_u21128)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, NimStringV2 r_p3);
N_LIB_PRIVATE N_NIMCALL(void, genMagicExpr__cgen_u25880)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3);
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__cgen_u22826)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getLabel__cgen_u14059)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u22842)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u22847)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, fixLabel__cgen_u14067)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 labl_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u14070)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6281)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, unaryArith__cgen_u21772)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21788)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21793)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21798)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21479)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, unaryArithOverflow__cgen_u21433)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21474)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21484)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, binaryFloatArith__cgen_u25512)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3);
N_LIB_PRIVATE N_NIMCALL(void, binaryArith__cgen_u21495)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21520)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21525)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21530)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21535)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21540)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21545)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21550)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21555)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21560)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21565)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21570)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21575)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21580)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21585)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21590)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21595)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21600)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21605)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21610)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21615)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21632)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21637)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21654)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21659)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21664)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21693)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genEqProc__cgen_u21704)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21728)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, binaryArithOverflow__cgen_u21248)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21285)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21403)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u21408)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genRepr__cgen_u23976)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, gcUsage__cgen_u22947)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfo__cgen_u24145)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfoV2__cgen_u24150)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isFinal__types_u772)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, rdMType__cgen_u24093)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, NimStringV2* nilCheck_p2, NimStringV2* result_p3, NIM_BOOL enforceV1_p4);
N_LIB_PRIVATE N_NIMCALL(void, genSwap__cgen_u24460)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, cowBracket__cgen_u21960)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, binaryStmt__cgen_u21157)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, NimStringV2 op_p3);
N_LIB_PRIVATE N_NIMCALL(void, genStrConcat__cgen_u22962)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, strLoc__cgen_u22954)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_p1);
N_LIB_PRIVATE N_NIMCALL(void, binaryStmtAddr__cgen_u21181)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, NimStringV2 cpname_p3);
N_LIB_PRIVATE N_NIMCALL(void, genStrAppend__cgen_u23037)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, makeAddr__magicsys_u191)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1);
N_LIB_PRIVATE N_NIMCALL(void, genCall__cgen_u15586)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genSeqElemAppend__cgen_u23129)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, getIntTemp__cgen_u13628)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(void, genStrEquals__cgen_u25452)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genIsNil__cgen_u21737)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genEnumToStr__cgen_u25869)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getToStringProc__modulegraphs_u8679)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyTree__ast_u6891)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, genOf__cgen_u23972)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genOf__cgen_u23911)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3);
N_LIB_PRIVATE N_NIMCALL(void, genOfHelper__cgen_u23853)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p1, NimStringV2 a_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u23886)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u23897)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genNew__cgen_u23348)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1);
N_LIB_PRIVATE N_NIMCALL(void, rawGenNew__cgen_u23197)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p1, NimStringV2 sizeExpr_p2, NIM_BOOL needsInit_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u23214)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u23256)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genNewFinalize__cgen_u23831)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfo__cgen_u12748)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__cgen_u23447)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqAux__cgen_u23353)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, NimStringV2 length_p2, NIM_BOOL lenIsZero_p3);
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqOfCap__cgen_u23475)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26166)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26172)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26193)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genSomeCast__cgen_u25144)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25164)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25193)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25206)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25219)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameBackendType__types_u637)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, genOrd__cgen_u25129)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genArrayLen__cgen_u24171)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24338)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthStr__cgen_u24436)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthSeq__cgen_u24382)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, NIM_BOOL noinit_p3);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, isTrivialTypesToSnippet__cgen_u24371)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, genSetOp__cgen_u24604)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3);
N_LIB_PRIVATE N_NIMCALL(void, rdSetElemLoc__cgen_u20092)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int128_u980)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, NI64 b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24628)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24646)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24664)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24682)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24703)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24721)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24739)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24757)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genInOp__cgen_u24553)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, fewCmps__cgen_u24480)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24580)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24585)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genInExprAux__cgen_u22235)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* b_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24512)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24519)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24526)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24533)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24540)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u24989)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25007)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25105)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genDefault__cgen_u23189)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genEcho__cgen_u22861)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genArrToSeq__cgen_u23736)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genSeqConstr__cgen_u23663)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lhsDoesAlias__cgen_u23654)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, wrapProcForSpawn__spawn_u349)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* spawnExpr_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* retType_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* barrier_p5, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p6);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, liftParallel__semparallel_u1308)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3);
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopy__cgen_u20983)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2);
N_LIB_PRIVATE N_NIMCALL(void, genWasMoved__cgen_u25622)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genMove__cgen_u25627)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
static N_INLINE(NIM_BOOL, isSinkParam__ast_u7466)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, genDestroy__cgen_u25746)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genAccessTypeField__cgen_u24158)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genSlice__cgen_u25833)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u606)(tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg e_p0);
N_LIB_PRIVATE N_NIMCALL(void, genSetNode__cgen_u20239)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__cgen_u26333)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26372)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26378)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u29)(NI64 xX60gensym4__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26384)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26399)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26405)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, exprComplexConst__cgen_u26739)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__cgen_u26510)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, handleConstExpr__cgen_u23535)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genClosure__cgen_u26464)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
static N_INLINE(NIM_BOOL, isConstClosure__cgen_u26453)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NIM_BOOL, isRoutine__ast_u7152)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__cgen_u26410)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u15846)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__cgen_u12890)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3375)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, genFieldObjConstr__cgen_u23551)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_p1, NIM_BOOL useTemp_p2, NIM_BOOL isRef_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nField_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p5, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* check_p6, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p7, NimStringV2 r_p8, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p9);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, lookupFieldAgain__cgen_u22086)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p2, NimStringV2* r_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** resTyp_p4);
N_LIB_PRIVATE N_NIMCALL(void, genFieldCheck__cgen_u22241)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, NimStringV2 obj_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p3);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u707)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toMsgFilename__msgs_u688)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genFieldDefect__astmsgs_u68)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 field_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* disc_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u22329)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genCast__cgen_u25245)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25271)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25308)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genConv__cgen_u25399)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genAddr__cgen_u22001)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
static N_INLINE(NIM_BOOL, isCppRef__cgen_u21817)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u22033)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genBracketExpr__cgen_u22797)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genUncheckedArrayElem__cgen_u22408)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4);
N_LIB_PRIVATE N_NIMCALL(void, genArrayElem__cgen_u22429)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isConstExpr__trees_u129)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int128_u973)(NI64 a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int128_u404)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayElem__cgen_u22621)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4);
N_LIB_PRIVATE N_NIMCALL(void, genSeqElem__cgen_u22707)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4);
N_LIB_PRIVATE N_NIMCALL(void, genCStringElem__cgen_u22516)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4);
N_LIB_PRIVATE N_NIMCALL(void, genTupleElem__cgen_u22054)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u22081)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genDeref__cgen_u21837)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genRecordField__cgen_u22128)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genRecordFieldAux__cgen_u22041)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p3);
N_LIB_PRIVATE N_NIMCALL(void, genCheckedRecordField__cgen_u22380)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genBlock__cgen_u17227)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genStmtListExpr__cgen_u26542)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, initFrameNoDebug__cgen_u20024)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 frame_p1, NimStringV2 procname_p2, NimStringV2 filename_p3, NI line_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u20031)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, deinitFrameNoDebug__cgen_u20049)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 frame_p1);
N_LIB_PRIVATE N_NIMCALL(void, genStmtList__cgen_u26576)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genIf__cgen_u16832)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16869)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16882)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, downConv__cgen_u26695)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isLValue__parampatterns_u491)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u26682)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NI, inheritanceDiff__types_u2785)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* b_p1);
N_LIB_PRIVATE N_NIMCALL(void, upConv__cgen_u26610)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u19)(NI16 xX60gensym2__p0);
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__cgen_u25313)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, sameBackendTypeIgnoreRange__types_u2744)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u25390)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__cgen_u25407)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__cgen_u25421)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__cgen_u17147)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stmtsContainPragma__ccgutils_u37)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw w_p1);
N_LIB_PRIVATE N_NIMCALL(void, genComputedGoto__cgen_u17010)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, flattenStmts__trees_u359)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, enumHasHoles__types_u271)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int128_u959)(NI64 a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17037)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17043)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17054)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17059)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17071)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17106)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__ast_u6769)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__fgQOep3rrztw9aeZI9aS2Ltg kind_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3718)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17187)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(void, assignLabel__cgen_u16174)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* b_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__cgen_u16813)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__cgen_u16780)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1);
N_LIB_PRIVATE N_NIMCALL(void, genClosureVar__cgen_u16800)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1);
N_LIB_PRIVATE N_NIMCALL(void, genVarTuple__cgen_u15769)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lowerTupleUnpacking__lowerings_u56)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u15931)(tySequence__1cgZIGFge8OGY6Zlwa9aRnw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__cgen_u15861)(tySequence__1cgZIGFge8OGY6Zlwa9aRnw* x_p0, tyTuple__IGtaz2jo9ahodpWjWgc5c5A y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdup___ast_u6290)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result);
N_LIB_PRIVATE N_NIMCALL(void, genConstStmt__cgen_u26853)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipPragmaExpr__ast_u4047)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, genCase__cgen_u18222)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genStringCase__cgen_u17761)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg stringKind_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3);
N_LIB_PRIVATE N_NIMCALL(NI, nextPowerOfTwo__pureZmath_u256)(NI x_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__system_u5399)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, genCaseStringBranch__cgen_u17704)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw e_p2, NimStringV2 labl_p3, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg stringKind_p4, NimStringV2* branches_p5, NI branches_p5Len_0);
N_LIB_PRIVATE N_NIMCALL(NI64, hashString__ccgutils_u45)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17842)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17855)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genCaseSecondPass__cgen_u17654)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, NI labId_p3, NI until_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17671)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, exprBlock__cgen_u16234)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genGotoForCase__cgen_u16948)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* caseStmt_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16980)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genOrdinalCase__cgen_u18088)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NI, ifSwitchSplitPoint__cgen_u18029)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, branchHasTooBigRange__cgen_u18021)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16453)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u18204)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u18213)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__cgen_u16900)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, blockLeaveActions__cgen_u16297)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NI howManyTrys_p1, NI howManyExcepts_p2, NIM_BOOL isReturnStmt_p3);
N_LIB_PRIVATE N_NIMCALL(tySequence__olcP618a61wlx6oJIT9b0sA, newSeq__cgen_u16321)(NI len_p0);
static N_INLINE(void, pop__cgen_u16349)(tySequence__olcP618a61wlx6oJIT9b0sA* s_p0, tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u1155)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1108)(tySequence__olcP618a61wlx6oJIT9b0sA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__cgen_u16386)(tySequence__olcP618a61wlx6oJIT9b0sA* x_p0, tyTuple__P9bg2wlfPi4dSSTi3ICCeVA y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdup___cgendata_u1164)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA src_p0, tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1158)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA dest_p0);
static N_INLINE(NIM_BOOL, isClosureIterator__ast_u7426)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1078)(tySequence__olcP618a61wlx6oJIT9b0sA dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16943)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__cgen_u17320)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
static N_INLINE(void, cow__cgen_u21990)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__cgen_u19937)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, NIM_BOOL fastAsgn_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDiscriminantField__astalgo_u3497)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, asgnFieldDiscriminant__cgen_u19926)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1);
N_LIB_PRIVATE N_NIMCALL(void, genDiscriminantCheck__cgen_u19804)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* objtype_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, discriminatorTableDecl__cgen_u9220)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* objtype_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genAsmStmt__cgen_u19725)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw, whichPragma__trees_u218)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, genAsmOrEmitStmt__cgen_u19682)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, NIM_BOOL isAsmStmt_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(void, genTryGoto__cgen_u18931)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u19034)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bodyCanRaise__cgen_u18917)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genTryCpp__cgen_u18373)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(void, genRestoreFrameAfterException__cgen_u18320)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u18494)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__ast_u7333)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__ast_u7302)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(void, genTrySetjmp__cgen_u19232)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
static N_INLINE(NimStringV2, pop__stdZprivateZosdirs_u415)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__system_u5403)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__cgen_u17575)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, finallyActions__cgen_u17512)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0);
static N_INLINE(void, genSimpleBlock__cgen_u16218)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* stmts_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17592)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genTypeSection__cgen_u12758)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genPragma__cgen_u19795)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genEmit__cgen_u19786)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ, determineSection__cgen_u19759)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, processPushBackendOption__pushpoppragmas_u288)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tySequence__bdNIx7Bah2llfuqeoTJEWQ* optionsStack_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* options_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, NI start_p4);
N_LIB_PRIVATE N_NIMCALL(void, popBackendOption__pushpoppragmas_u230)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tySequence__bdNIx7Bah2llfuqeoTJEWQ* optionsStack_p1, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ* options_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, skipGenericOwner__ast_u7111)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, genParForStmt__cgen_u17266)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17286)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17291)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u17297)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genState__cgen_u16254)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, genGotoState__cgen_u16449)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16462)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16470)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16486)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genBreakState__cgen_u16495)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16504)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u16509)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__msgs_u593)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, handleProcGlobals__cgen_u31116)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3693)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, generateLibraryDestroyGlobals__cgen_u31183)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2, NIM_BOOL isDynlib_p3);
static N_INLINE(NIM_BOOL, moduleHasChanged__pipelineutils_u29)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1);
N_LIB_PRIVATE N_NIMCALL(void, generateIfMethodDispatchers__cgmeth_u1019)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__cgen_u31308)(tySequence__fVUhfWxkucMvZhVKGrAHuA* x_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* y_p1);
static N_INLINE(void, nimMarkCyclic)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u715)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u2138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg** dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, genForwardedProcs__cgen_u31328)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, pop__icZic_u3359)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u4732)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, writeModule__cgen_u31161)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NIM_BOOL pending_p1);
N_LIB_PRIVATE N_NIMCALL(void, genInitCode__cgen_u30397)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getInitName__cgen_u29427)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSomeInitName__cgen_u29423)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 suffix_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSomeNameForModule__cgen_u29403)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30326)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30450)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30459)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30464)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30523)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30337)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30537)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getHcrInitName__cgen_u29437)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, hcrGetProcLoadCode__cgen_u29440)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 sym_p1, NimStringV2 prefix_p2, NimStringV2 handle_p3, NimStringV2 getProcFunc_p4);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30387)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30392)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30673)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, genDatInitCode__cgen_u30323)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getDatInitName__cgen_u29434)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30683)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, registerModuleToMain__cgen_u29814)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29819)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29831)(NimStringV2* args_p1, NI args_p1Len_0);
static N_INLINE(NI, rawGet__cgen_u29842)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw t_p0, NI32 key_p1, NI* hc_p2);
static N_INLINE(NI, hash__ast_u624)(NI32 x_p0);
static N_INLINE(NI, hashWangYi1__pureZhashes_u140)(NU64 x_p0);
static N_INLINE(NU64, hiXorLo__pureZhashes_u81)(NU64 a_p0, NU64 b_p1);
static N_INLINE(NU64, hiXorLoFallback64__pureZhashes_u37)(NU64 a_p0, NU64 b_p1);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0);
static N_INLINE(NI, nextTry__pureZcollectionsZtables_u35)(NI h_p0, NI maxHash_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30163)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30168)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30173)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, sigHash__sighashes_u522)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30182)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30187)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30196)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30201)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29745)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30210)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30215)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30220)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30225)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30235)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u30240)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29740)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, finishTypeDescriptions__cgen_u8787)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(void, seqV2ContentType__cgen_u3527)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3333)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, genMainProc__cgen_u29446)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__cgen_u34938)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u34864)(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___cgen_u34876)(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* dest_p0, void* env_p1);
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1);
static N_INLINE(void, add__system_u3018)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3026)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_CLOSURE(NimStringV2, loadLib__cgen_u29449)(NimStringV2 handle_p0, NimStringV2 name_p1, void* ClE_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29476)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29481)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, closeNamespaceNim__cgen_u28091)(NimStringV2* result_p0);
N_LIB_PRIVATE N_NIMCALL(void, openNamespaceNim__cgen_u28088)(NimStringV2 namespace_p0, NimStringV2* result_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u34892)(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, generateThreadVarsSize__cgen_u13832)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u13843)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toObjFile__extccomp_u934)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genModule__cgen_u30700)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getFileHeader__cgen_u29395)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getCopyright__cgen_u29382)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, headerTop__cgen_u29375)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29377)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29390)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getCompileCFileCmd__extccomp_u1228)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p1, NIM_BOOL isMainFile_p2, NIM_BOOL produceOutput_p3);
static N_INLINE(void, addNimDefines__cgen_u29367)(NimStringV2* result_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u29370)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, generateThreadLocalStorage__cgen_u13813)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u13827)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, generateHeaders__cgen_u28062)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u28065)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuReplaceChar)(NimStringV2 s_p0, NIM_CHAR sub_p1, NIM_CHAR by_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u28078)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u28083)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeSingleLineCString__ccgutils_u103)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, postprocessCode__cgen_u30692)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2* r_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringV2 s_p0, NIM_CHAR sub_p1, NI start_p2, NI last_p3);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, nsuSplitChar)(NimStringV2 s_p0, NIM_CHAR sep_p1, NI maxsplit_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, quotedFilename__msgs_u1630)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fi_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldRecompile__cgen_u31152)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 code_p1, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalsFile__ropes_u230)(NimStringV2 r_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, writeRope__ropes_u27)(NimStringV2 head_p0, NimStringV2 filename_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileExists)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nosfileNewer)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void, addFileToCompile__extccomp_u938)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cf_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1619)(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeMapping__extccomp_u3284)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbolMapping_p1);
N_LIB_PRIVATE N_NIMCALL(void, writeHeader__cgen_u31027)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u31030)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u31036)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u31055)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___cgen_u31060)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSomeNameForModule__cgen_u29399)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1);
extern TNimTypeV2 NTIv2__GJ2TTG82D4z6i8QsbkLlYA_;
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2 = { 2 | NIM_STRLIT_FLAG, "TM" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_4 = { 1 | NIM_STRLIT_FLAG, "_" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_5 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_6 = { 2 | NIM_STRLIT_FLAG, ".h" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_7 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_6};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_8 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_9 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_10 = { 22 | NIM_STRLIT_FLAG, "if (nim_hcr_do_init_)\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_11 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_10};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_12 = { 1 | NIM_STRLIT_FLAG, "{" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_13 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_14 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_15 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_16 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_17 = { 2 | NIM_STRLIT_FLAG, "_Z" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_18 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_17};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_19 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_20 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_21 = { 6 | NIM_STRLIT_FLAG, "static" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_22 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_21};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_23 = { 6 | NIM_STRLIT_FLAG, "extern" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_24 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_23};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_25 = { 1 | NIM_STRLIT_FLAG, " " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_26 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_27 = {
0x10, 0x2e, 0x10, 0x00, 0x00, 0x40, 0x80, 0x10,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_28 = {
0x10, 0x2e, 0x10, 0x00, 0x00, 0x60, 0x80, 0x10,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_29 = { 28 | NIM_STRLIT_FLAG, "cannot generate C type for: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_30 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_29};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_32 = { 63 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgtypes.nim" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_33 = { 4 | NIM_STRLIT_FLAG, "void" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_34 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_33};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_35 = { 5 | NIM_STRLIT_FLAG, "void*" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_36 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_35};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_37 = { 13 | NIM_STRLIT_FLAG, "nimStrVersion" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_38 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_37};
static const struct {
  NI cap; NIM_CHAR data[59+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_40 = { 59 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/cgen.nim" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_41 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_42 = { 2 | NIM_STRLIT_FLAG, "||" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_43 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_42};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_44 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_45 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_46 = { 3 | NIM_STRLIT_FLAG, " = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_47 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_48 = { 21 | NIM_STRLIT_FLAG, "system module needs: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_49 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_48};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_51 = { 7 | NIM_STRLIT_FLAG, "_actual" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_52 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_51};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_53 = { 14 | NIM_STRLIT_FLAG, "nimLoadLibrary" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_54 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_53};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_55 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_56 = { 2 | NIM_STRLIT_FLAG, "((" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_57 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_58 = { 13 | NIM_STRLIT_FLAG, "NimStringDesc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_59 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_58};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_60 = { 11 | NIM_STRLIT_FLAG, "*) NIM_NIL)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_61 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_60};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_62 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_63 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_58};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_64 = { 4 | NIM_STRLIT_FLAG, "*) &" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_65 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_64};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_66 = { 11 | NIM_STRLIT_FLAG, "TGenericSeq" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_67 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_66};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_68 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_69 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_70 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_71 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_58};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_72 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_64};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_73 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_74 = { 5 | NIM_STRLIT_FLAG, "const" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_75 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_74};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_76 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_77 = { 13 | NIM_STRLIT_FLAG, "NimStrPayload" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_78 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_77};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_79 = { 11 | NIM_STRLIT_FLAG, "NimStringV2" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_80 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_79};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_81 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_74};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_82 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_83 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_74};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_84 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[55+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_85 = { 55 | NIM_STRLIT_FLAG, "cannot determine how to produce code for string literal" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_86 = {55, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_85};
static const struct {
  NI cap; NIM_CHAR data[66+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_88 = { 66 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgliterals.nim" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_89 = { 6 | NIM_STRLIT_FLAG, "if (!(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_90 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_89};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_91 = { 3 | NIM_STRLIT_FLAG, ")) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_92 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_91};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_93 = { 19 | NIM_STRLIT_FLAG, "nimLoadLibraryError" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_94 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_93};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_95 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_96 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_97 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_98 = { 2 | NIM_STRLIT_FLAG, "(*" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_99 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_98};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_100 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_101 = { 1 | NIM_STRLIT_FLAG, ";" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_102 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_103 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_104 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_89};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_105 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_106 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_53};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_107 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_108 = { 4 | NIM_STRLIT_FLAG, "))) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_109 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_108};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_110 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_93};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_111 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_112 = { 2 | NIM_STRLIT_FLAG, ");" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_113 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_114 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_115 = { 14 | NIM_STRLIT_FLAG, "loadDynamicLib" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_116 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_115};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_118 = { 6 | NIM_STRLIT_FLAG, "Dl_$1_" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_119 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_118};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_120 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_121 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_122 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_123 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_124 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_125 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_126 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_128 = { 13 | NIM_STRLIT_FLAG, "wrong index: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_129 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_128};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_131 = { 1 | NIM_STRLIT_FLAG, "\011" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_132 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_133 = { 4 | NIM_STRLIT_FLAG, " = (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_134 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_133};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_135 = { 2 | NIM_STRLIT_FLAG, ") " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_136 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_137 = { 14 | NIM_STRLIT_FLAG, "nimGetProcAddr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_138 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_139 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_140 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_141 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_142 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_143 = { 8 | NIM_STRLIT_FLAG, ".nim.cpp" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_144 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_143};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_145 = { 6 | NIM_STRLIT_FLAG, ".nim.m" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_146 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_145};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_147 = { 6 | NIM_STRLIT_FLAG, ".nim.c" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_148 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_147};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_149 = { 1 | NIM_STRLIT_FLAG, "/" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_150 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_149};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_151 = { 2 | NIM_STRLIT_FLAG, "#." };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_152 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_151};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_153 = { 3 | NIM_STRLIT_FLAG, "#->" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_154 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_153};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_155 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_156 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_157 = { 13 | NIM_STRLIT_FLAG, "getTypeName: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_158 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_157};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_160 = {
0x10, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_161 = { 5 | NIM_STRLIT_FLAG, "union" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_162 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_161};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_163 = { 6 | NIM_STRLIT_FLAG, "struct" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_164 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_163};
static const struct {
  NI cap; NIM_CHAR data[54+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_165 = { 54 | NIM_STRLIT_FLAG, "ccgtypes.nim(411, 5) `m.forwTypeCache[sig] == result` " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_166 = {54, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_165};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_167 = { 15 | NIM_STRLIT_FLAG, "getTypeForward(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_168 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_167};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_170 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x90, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[41+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_171 = { 41 | NIM_STRLIT_FLAG, "cannot map the empty seq type to a C type" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_172 = {41, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_171};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_174 = { 6 | NIM_STRLIT_FLAG, "struct" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_175 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_174};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_176 = { 8 | NIM_STRLIT_FLAG, "_Content" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_177 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_176};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_178 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_174};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_179 = { 7 | NIM_STRLIT_FLAG, "struct " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_180 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_179};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_181 = { 13 | NIM_STRLIT_FLAG, " {\012  NI len; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_182 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_181};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_183 = { 16 | NIM_STRLIT_FLAG, "_Content* p;\012};\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_184 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_183};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_185 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_186 = { 1 | NIM_STRLIT_FLAG, "*" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_187 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_188 = { 4 | NIM_STRLIT_FLAG, "_PTR" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_189 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_188};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_190 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_191 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_192 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_193 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_194 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_195 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_196 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_197 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_198 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_199 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_200 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__MQdRN7fpbG7rPm4JpVVAhA_201 = {
0x00, 0x3e, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_202 = { 8 | NIM_STRLIT_FLAG, "operator" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_203 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_202};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_204 = { 7 | NIM_STRLIT_FLAG, "static " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_205 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_206 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_207 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_208 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_74};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_209 = { 8 | NIM_STRLIT_FLAG, "override" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_210 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_209};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_211 = { 8 | NIM_STRLIT_FLAG, "virtual " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_212 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_211};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_213 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_211};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_214 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_215 = { 11 | NIM_STRLIT_FLAG, "operator ()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_216 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_215};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_217 = { 1 | NIM_STRLIT_FLAG, ":" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_218 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_217};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_219 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_220 = { 2 | NIM_STRLIT_FLAG, "->" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_221 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_220};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_222 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_223 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_224 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_225 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_226 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[51+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_227 = { 51 | NIM_STRLIT_FLAG, "ccgtypes.nim(192, 5) `typ.isResolvedUserTypeClass` " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_228 = {51, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_227};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_229 = { 39 | NIM_STRLIT_FLAG, "ccgtypes.nim(227, 15) `false` mapType: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_230 = {39, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_229};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_231 = { 39 | NIM_STRLIT_FLAG, "ccgtypes.nim(230, 13) `false` mapType: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_232 = {39, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_231};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_233 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_33};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_234 = { 2 | NIM_STRLIT_FLAG, "\'0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_235 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_234};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_236 = { 2 | NIM_STRLIT_FLAG, "$1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_237 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_236};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_238 = {
0x00, 0x01, 0x80, 0x00, 0x00, 0x80, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_239 = { 4 | NIM_STRLIT_FLAG, "this" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_240 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_239};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_241 = { 7 | NIM_STRLIT_FLAG, "(*this)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_242 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_241};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_243 = { 19 | NIM_STRLIT_FLAG, "genMemberProcParams" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_244 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_243};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_246 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_247 = { 12 | NIM_STRLIT_FLAG, "NIM_NOALIAS " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_248 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_247};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_249 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_250 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[2];
} TM__MQdRN7fpbG7rPm4JpVVAhA_252 = {2 | NIM_STRLIT_FLAG, {39,
35}};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_253 = { 23 | NIM_STRLIT_FLAG, "invalid format string: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_254 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_253};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_255 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_253};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_256 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_257 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_253};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_258 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_253};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_259 = { 2 | NIM_STRLIT_FLAG, "()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_260 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_259};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_261 = { 6 | NIM_STRLIT_FLAG, "(void)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_262 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_261};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_263 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_264 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_265 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_266 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_267 = { 4 | NIM_STRLIT_FLAG, "...)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_268 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_267};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_269 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_270 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_271 = { 6 | NIM_STRLIT_FLAG, " const" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_272 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_271};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_273 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_274 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_211};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_275 = { 9 | NIM_STRLIT_FLAG, " override" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_276 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_275};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_277 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_278 = { 3 | NIM_STRLIT_FLAG, " : " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_279 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_278};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_280 = { 14 | NIM_STRLIT_FLAG, "N_LIB_PRIVATE " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_281 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_280};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_282 = { 9 | NIM_STRLIT_FLAG, "N_NIMCALL" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_283 = { 9 | NIM_STRLIT_FLAG, "N_STDCALL" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_284 = { 7 | NIM_STRLIT_FLAG, "N_CDECL" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_285 = { 10 | NIM_STRLIT_FLAG, "N_SAFECALL" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_286 = { 9 | NIM_STRLIT_FLAG, "N_SYSCALL" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_287 = { 8 | NIM_STRLIT_FLAG, "N_INLINE" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_288 = { 10 | NIM_STRLIT_FLAG, "N_NOINLINE" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_289 = { 10 | NIM_STRLIT_FLAG, "N_FASTCALL" };
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_290 = { 10 | NIM_STRLIT_FLAG, "N_THISCALL" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_291 = { 9 | NIM_STRLIT_FLAG, "N_CLOSURE" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_292 = { 8 | NIM_STRLIT_FLAG, "N_NOCONV" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_293 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_294 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_295 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_296 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_33};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_297 = { 13 | NIM_STRLIT_FLAG, "genProcParams" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_298 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_297};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_300 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_301 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_302 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_303 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_304 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_247};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_305 = {
0x00, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_306 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_307 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_308 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_309 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_310 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_311 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_312 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_313 = { 11 | NIM_STRLIT_FLAG, "void* ClE_0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_314 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_313};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_315 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_316 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_317 = { 3 | NIM_STRLIT_FLAG, "..." };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_318 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_317};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_319 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_320 = { 5 | NIM_STRLIT_FLAG, "void)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_321 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_320};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_322 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_323 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_188};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_324 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_325 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_51};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_326 = { 13 | NIM_STRLIT_FLAG, "N_LIB_IMPORT " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_327 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_326};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_328 = { 13 | NIM_STRLIT_FLAG, "N_LIB_EXPORT " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_329 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_328};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_330 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_331 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_280};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_332 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_98};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_333 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_334 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_335 = { 25 | NIM_STRLIT_FLAG, "proc has no result symbol" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_336 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_335};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_338 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_339 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_340 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_341 = { 7 | NIM_STRLIT_FLAG, "\012#line " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_342 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_341};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_343 = { 31 | NIM_STRLIT_FLAG, " \"generated_not_to_break_here\"\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_344 = {31, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_343};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_345 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_341};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_346 = { 4 | NIM_STRLIT_FLAG, " FX_" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_347 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_346};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_348 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_349 = { 9 | NIM_STRLIT_FLAG, " register" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_350 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_349};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_351 = { 9 | NIM_STRLIT_FLAG, " volatile" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_352 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_351};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_353 = { 12 | NIM_STRLIT_FLAG, " NIM_NOALIAS" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_354 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_353};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_355 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_356 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_357 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_358 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_359 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_360 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_361 = {
0x00, 0x00, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_362 = { 2 | NIM_STRLIT_FLAG, "{}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_363 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_362};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_364 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_365 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_366 = { 1 | NIM_STRLIT_FLAG, "," };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_367 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_366};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_368 = {
0x00, 0x00, 0x65, 0x39, 0x00, 0x00, 0x03, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_369 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_370 = { 16 | NIM_STRLIT_FLAG, "nimToCStringConv" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_371 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_370};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_372 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_373 = { 1 | NIM_STRLIT_FLAG, "T" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_374 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_373};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_375 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_376 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_377 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_378 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_379 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_380 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_381 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_382 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x10,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_383 = { 10 | NIM_STRLIT_FLAG, ".len = 0; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_384 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_383};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_385 = { 13 | NIM_STRLIT_FLAG, ".p = NIM_NIL;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_386 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_385};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_387 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_388 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0xb0, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_389 = { 7 | NIM_STRLIT_FLAG, "NIM_NIL" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_390 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_389};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_391 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_392 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_393 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_394 = { 7 | NIM_STRLIT_FLAG, "asgnRef" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_395 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_394};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_396 = { 10 | NIM_STRLIT_FLAG, "((void**) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_397 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_396};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_398 = { 2 | NIM_STRLIT_FLAG, "(&" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_399 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_400 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_401 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_402 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_403 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_404 = { 13 | NIM_STRLIT_FLAG, "unsureAsgnRef" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_405 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_404};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_406 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_396};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_407 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_408 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_409 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_410 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_133};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_411 = { 3 | NIM_STRLIT_FLAG, ")0;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_412 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_411};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_413 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_414 = { 10 | NIM_STRLIT_FLAG, "nimZeroMem" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_415 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_414};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_416 = { 8 | NIM_STRLIT_FLAG, "((void*)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_417 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_418 = { 9 | NIM_STRLIT_FLAG, ", sizeof(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_419 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_420 = { 3 | NIM_STRLIT_FLAG, "));" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_421 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_422 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_423 = { 4 | NIM_STRLIT_FLAG, ".Sup" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_424 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_423};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_425 = {
0x10, 0x09, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_426 = { 10 | NIM_STRLIT_FLAG, ".m_type = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_427 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_426};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_428 = {
0x10, 0x0e, 0x10, 0x00, 0x00, 0x60, 0xb0, 0x10,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_429 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_430 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_431 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_432 = { 10 | NIM_STRLIT_FLAG, "TNimTypeV2" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_433 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_432};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_434 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_432};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_435 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_436 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_437 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_432};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_438 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_432};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_439 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_440 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_432};
static const struct {
  NI cap; NIM_CHAR data[47+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_441 = { 47 | NIM_STRLIT_FLAG, " needs to have the \'nimcall\' calling convention" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_442 = {47, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_441};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_444 = { 11 | NIM_STRLIT_FLAG, "rttiDestroy" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_445 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_444};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_446 = { 4 | NIM_STRLIT_FLAG, "dest" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_447 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_446};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_448 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_389};
static const struct {
  NI cap; NIM_CHAR data[51+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_449 = { 51 | NIM_STRLIT_FLAG, "request for RTTI generation for incomplete object: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_450 = {51, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_449};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_452 = { 12 | NIM_STRLIT_FLAG, "nimTypeNames" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_453 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_452};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_454 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_455 = { 1 | NIM_STRLIT_FLAG, "." };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_456 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_457 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_458 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_389};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_459 = { 1 | NIM_STRLIT_FLAG, "{" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_460 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_459};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_461 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_462 = { 1 | NIM_STRLIT_FLAG, "}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_463 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_464 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_465 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_466 = { 9 | NIM_STRLIT_FLAG, "(void *) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_467 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_466};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_468 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_469 = {
0x10, 0x2e, 0x10, 0x00, 0x00, 0x60, 0xb0, 0x10,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_470 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_471 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_472 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_473 = { 8 | NIM_STRLIT_FLAG, "TNimType" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_474 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_475 = { 8 | NIM_STRLIT_FLAG, "TNimNode" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_476 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_475};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_477 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_478 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_479 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_480 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_475};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_481 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_482 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_483 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_484 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_475};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_485 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_486 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_487 = { 1 | NIM_STRLIT_FLAG, "0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_488 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_487};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_489 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_98};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_490 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_491 = { 5 | NIM_STRLIT_FLAG, "void*" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_492 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_491};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_493 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_494 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_452};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_495 = { 10 | NIM_STRLIT_FLAG, "ref object" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_496 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_495};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_497 = { 21 | NIM_STRLIT_FLAG, "anon ref object from " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_498 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_497};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_499 = { 11 | NIM_STRLIT_FLAG, "nimTypeRoot" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_500 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_499};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_501 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_487};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_502 = { 14 | NIM_STRLIT_FLAG, "genTypeInfoV1(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_503 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_502};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_506 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_487};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_507 = { 1 | NIM_STRLIT_FLAG, "0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_508 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_509 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_510 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_511 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_512 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_513 = { 7 | NIM_STRLIT_FLAG, "Marker_" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_514 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_513};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_515 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_516 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_51};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_517 = { 2 | NIM_STRLIT_FLAG, "op" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_518 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_517};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_519 = { 4 | NIM_STRLIT_FLAG, ".len" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_520 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_519};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_521 = { 3 | NIM_STRLIT_FLAG, "len" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_522 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_521};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_523 = { 7 | NIM_STRLIT_FLAG, "Sup.len" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_524 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_523};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_525 = { 5 | NIM_STRLIT_FLAG, "for (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_526 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_525};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_527 = { 6 | NIM_STRLIT_FLAG, " = 0; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_528 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_527};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_529 = { 3 | NIM_STRLIT_FLAG, " < " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_530 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_531 = { 2 | NIM_STRLIT_FLAG, "; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_532 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_533 = { 5 | NIM_STRLIT_FLAG, "++) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_534 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_533};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_535 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_536 = { 1 | NIM_STRLIT_FLAG, "[" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_537 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_538 = { 1 | NIM_STRLIT_FLAG, "]" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_539 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_540 = { 15 | NIM_STRLIT_FLAG, "genTraverseProc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_541 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_540};
static const struct {
  NI cap; NIM_CHAR data[62+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_543 = { 62 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgtrav.nim" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_544 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_545 = { 18 | NIM_STRLIT_FLAG, "genRecordFieldsAux" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_546 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_545};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_548 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_549 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_550 = { 2 | NIM_STRLIT_FLAG, "_0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_551 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_550};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_552 = { 18 | NIM_STRLIT_FLAG, "mangleRecFieldName" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_553 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_552};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_555 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_556 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_557 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_558 = { 37 | NIM_STRLIT_FLAG, "struct __attribute__((__packed__)) {\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_559 = {37, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_558};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_560 = { 30 | NIM_STRLIT_FLAG, "#pragma pack(push, 1)\012struct {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_561 = {30, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_560};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_562 = { 9 | NIM_STRLIT_FLAG, "struct {\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_563 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_562};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_564 = { 2 | NIM_STRLIT_FLAG, "} " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_565 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_564};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_566 = { 2 | NIM_STRLIT_FLAG, ";\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_567 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_566};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_568 = { 18 | NIM_STRLIT_FLAG, "#pragma pack(pop)\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_569 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_568};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_570 = { 38 | NIM_STRLIT_FLAG, "genRecordFieldsAux(record case branch)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_571 = {38, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_570};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_573 = { 7 | NIM_STRLIT_FLAG, "union{\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_574 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_573};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_575 = { 3 | NIM_STRLIT_FLAG, "};\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_576 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_575};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_577 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_578 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_579 = { 10 | NIM_STRLIT_FLAG, "NIM_ALIGN(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_580 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_579};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_581 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_582 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_353};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_583 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_584 = { 15 | NIM_STRLIT_FLAG, "[SEQ_DECL_SIZE]" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_585 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_584};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_586 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_217};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_587 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_566};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_588 = { 20 | NIM_STRLIT_FLAG, "genRecordFieldsAux()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_589 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_588};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_591 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_592 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_593 = { 17 | NIM_STRLIT_FLAG, "genTraverseProc()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_594 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_593};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_596 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_597 = { 16 | NIM_STRLIT_FLAG, "(-2147483647 -1)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_598 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_597};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_599 = { 38 | NIM_STRLIT_FLAG, "(IL64(-9223372036854775807) - IL64(1))" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_600 = {38, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_599};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_601 = { 8 | NIM_STRLIT_FLAG, "NIM_TRUE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_602 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_601};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_603 = { 9 | NIM_STRLIT_FLAG, "NIM_FALSE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_604 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_603};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_605 = {38, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_599};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_606 = { 3 | NIM_STRLIT_FLAG, "ULL" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_607 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_606};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_608 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_609 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_610 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_611 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_389};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_612 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0xb0, 0x10,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_613 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_614 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_58};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_615 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_60};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_616 = { 11 | NIM_STRLIT_FLAG, "genLiteral(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_617 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_616};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_619 = { 63 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgexprs.nim" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_620 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_622 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_593};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_624 = { 6 | NIM_STRLIT_FLAG, ".Field" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_625 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_624};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_626 = { 10 | NIM_STRLIT_FLAG, "nimGCvisit" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_627 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_626};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_628 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_629 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_630 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_631 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_632 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_626};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_633 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_634 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_635 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_636 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_637 = { 13 | NIM_STRLIT_FLAG, "nimGCvisitSeq" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_638 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_637};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_639 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_640 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_641 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_642 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_643 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_626};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_644 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_645 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_646 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_647 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_648 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_626};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_649 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_650 = { 6 | NIM_STRLIT_FLAG, ".ClE_0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_651 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_650};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_652 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_653 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_654 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_655 = { 8 | NIM_STRLIT_FLAG, ".p->data" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_656 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_655};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_657 = { 6 | NIM_STRLIT_FLAG, "->data" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_658 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_657};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_659 = { 1 | NIM_STRLIT_FLAG, "a" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_660 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_659};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_661 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_659};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_662 = { 4 | NIM_STRLIT_FLAG, "(*a)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_663 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_662};
extern TNimTypeV2 NTIv2__qtjLoeN4t2OOlLAbQg1W1A_;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_664 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_665 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_666 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_667 = { 3 | NIM_STRLIT_FLAG, ", \012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_668 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_667};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_669 = {51, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_449};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_671 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_672 = {
0x10, 0xa9, 0xe0, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_673 = { 32 | NIM_STRLIT_FLAG, "anonymous obj with discriminator" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_674 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_673};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_676 = { 15 | NIM_STRLIT_FLAG, "genObjectFields" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_677 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_676};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_679 = { 34 | NIM_STRLIT_FLAG, "genObjectFields; nkOfBranch broken" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_680 = {34, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_679};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_682 = { 26 | NIM_STRLIT_FLAG, "genObjectFields(nkRecCase)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_683 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_682};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_685 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_676};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_687 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_676};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_689 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_502};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_691 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_692 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_432};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_693 = { 21 | NIM_STRLIT_FLAG, ".destructor = (void*)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_694 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_693};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_695 = {51, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_449};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_697 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_452};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_698 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_389};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_699 = { 22 | NIM_STRLIT_FLAG, ", .traceImpl = (void*)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_700 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_699};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_701 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_702 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_703 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_704 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_426};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_705 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_706 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_707 = {
0x10, 0xa9, 0x40, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_708 = { 16 | NIM_STRLIT_FLAG, "node has no type" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_709 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_708};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_711 = { 2 | NIM_STRLIT_FLAG, "{\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_712 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_711};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_713 = { 2 | NIM_STRLIT_FLAG, "0x" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_714 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_713};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_715 = { 16 | NIM_STRLIT_FLAG, "0123456789abcdef" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_716 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_715};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_717 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_715};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_718 = { 2 | NIM_STRLIT_FLAG, ",\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_719 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_718};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_720 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_721 = { 2 | NIM_STRLIT_FLAG, "}\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_722 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_721};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_723 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_724 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_723};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_725 = { 3 | NIM_STRLIT_FLAG, ", {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_726 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_725};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_727 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_728 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_729 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_74};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_730 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_731 = { 9 | NIM_STRLIT_FLAG, " struct {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_732 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_731};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_733 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_734 = { 10 | NIM_STRLIT_FLAG, "  NI cap; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_735 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_734};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_736 = { 6 | NIM_STRLIT_FLAG, " data[" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_737 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_736};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_738 = { 2 | NIM_STRLIT_FLAG, "];" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_739 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_738};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_740 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_741 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_564};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_742 = { 4 | NIM_STRLIT_FLAG, " = {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_743 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_742};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_744 = { 18 | NIM_STRLIT_FLAG, " | NIM_STRLIT_FLAG" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_745 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_744};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_746 = { 2 | NIM_STRLIT_FLAG, "};" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_747 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_746};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_748 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_749 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_176};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_750 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_725};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_751 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_752 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_753 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_754 = { 9 | NIM_STRLIT_FLAG, "NIM_CONST" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_755 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_754};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_756 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_757 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_731};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_758 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_759 = { 2 | NIM_STRLIT_FLAG, "  " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_760 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_759};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_761 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_66};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_762 = { 5 | NIM_STRLIT_FLAG, " Sup;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_763 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_762};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_764 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_765 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_759};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_766 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_767 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_738};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_768 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_769 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_564};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_770 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_771 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_772 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_773 = { 17 | NIM_STRLIT_FLAG, "{NIM_NIL,NIM_NIL}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_774 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_773};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_775 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_776 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_777 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_778 = {
0x10, 0xa8, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_779 = { 9 | NIM_STRLIT_FLAG, "NIM_FALSE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_780 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_779};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_781 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_487};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_782 = { 3 | NIM_STRLIT_FLAG, "0.0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_783 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_782};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_784 = { 7 | NIM_STRLIT_FLAG, "NIM_NIL" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_785 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_784};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_786 = { 12 | NIM_STRLIT_FLAG, "{0, NIM_NIL}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_787 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_786};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_788 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_389};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_789 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_389};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_790 = { 18 | NIM_STRLIT_FLAG, "{NIM_NIL, NIM_NIL}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_791 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_790};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_792 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_793 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_794 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_795 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_796 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_797 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_798 = { 2 | NIM_STRLIT_FLAG, "._" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_799 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_798};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_800 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_801 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_742};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_802 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_803 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_804 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_805 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_806 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_807 = { 32 | NIM_STRLIT_FLAG, "cannot create null element for: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_808 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_807};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_810 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_811 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_812 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_813 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_814 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_815 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_816 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_817 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_818 = { 12 | NIM_STRLIT_FLAG, "{NIM_NIL, 0}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_819 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_818};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_820 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_362};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_821 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_822 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_807};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_824 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_718};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_825 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_721};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_826 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_827 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_828 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_718};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_829 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_721};
static const struct {
  NI cap; NIM_CHAR data[55+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_830 = { 55 | NIM_STRLIT_FLAG, "const openArray expression is not an array construction" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_831 = {55, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_830};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_833 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_834 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_74};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_835 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_836 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_837 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_838 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_839 = { 4 | NIM_STRLIT_FLAG, "] = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_840 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_839};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_841 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_842 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_843 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_844 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_721};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_845 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_77};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_846 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_79};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_847 = { 10 | NIM_STRLIT_FLAG, "nimCopyMem" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_848 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_847};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_849 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_850 = { 20 | NIM_STRLIT_FLAG, ", (NIM_CONST void*)&" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_851 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_850};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_852 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_853 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_854 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_855 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_856 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_857 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_858 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0xb0, 0x10,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_859 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_860 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_861 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_862 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_847};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_863 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_864 = { 19 | NIM_STRLIT_FLAG, ", (NIM_CONST void*)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_865 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_864};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_866 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_867 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_868 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_869 = { 20 | NIM_STRLIT_FLAG, "genericShallowAssign" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_870 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_869};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_871 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_872 = { 9 | NIM_STRLIT_FLAG, ", (void*)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_873 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_872};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_874 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_875 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_876 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_877 = { 13 | NIM_STRLIT_FLAG, "genericAssign" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_878 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_877};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_879 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_880 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_872};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_881 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_882 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_883 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_884 = { 16 | NIM_STRLIT_FLAG, "genericSeqAssign" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_885 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_884};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_886 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_887 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_888 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_889 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_890 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_891 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_892 = { 10 | NIM_STRLIT_FLAG, "copyString" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_893 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_892};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_894 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_895 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_896 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_897 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_898 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_899 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_900 = { 13 | NIM_STRLIT_FLAG, "copyStringRC1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_901 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_900};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_902 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_903 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_904 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_905 = { 4 | NIM_STRLIT_FLAG, "if (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_906 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_907 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_908 = { 17 | NIM_STRLIT_FLAG, "nimGCunrefNoCycle" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_909 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_908};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_910 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_911 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_912 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_913 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_404};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_914 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_396};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_915 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_916 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_892};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_917 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_918 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_919 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_920 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_921 = { 5 | NIM_STRLIT_FLAG, "ClE_0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_922 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_921};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_923 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_921};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_924 = { 9 | NIM_STRLIT_FLAG, ".ClP_0 = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_925 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_924};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_926 = { 7 | NIM_STRLIT_FLAG, ".ClP_0;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_927 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_926};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_928 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_929 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_930 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_931 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_932 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_933 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_934 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_935 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_936 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_937 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_939 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_940 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_941 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_942 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_847};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_943 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_944 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_864};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_945 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_946 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_947 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_948 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_949 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_950 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_951 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_952 = { 10 | NIM_STRLIT_FLAG, ".Field0 = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_953 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_952};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_954 = { 9 | NIM_STRLIT_FLAG, ".Field0; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_955 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_954};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_956 = { 10 | NIM_STRLIT_FLAG, ".Field1 = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_957 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_956};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_958 = { 8 | NIM_STRLIT_FLAG, ".Field1;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_959 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_958};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_960 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_961 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_952};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_962 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_954};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_963 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_956};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_964 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_958};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_965 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_966 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_952};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_967 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_968 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_956};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_969 = { 6 | NIM_STRLIT_FLAG, "Len_0;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_970 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_969};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_971 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_972 = { 11 | NIM_STRLIT_FLAG, ".Field0 = (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_973 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_972};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_974 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_975 = { 3 | NIM_STRLIT_FLAG, ").p" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_976 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_975};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_977 = { 5 | NIM_STRLIT_FLAG, ") \? (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_978 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_977};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_979 = { 13 | NIM_STRLIT_FLAG, ") : NIM_NIL; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_980 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_979};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_981 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_956};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_982 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_983 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_984 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_952};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_985 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_986 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_956};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_987 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_988 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_989 = { 23 | NIM_STRLIT_FLAG, "nimPrepareStrMutationV2" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_990 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_989};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_991 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_992 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_993 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_994 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_995 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_996 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_972};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_997 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_977};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_998 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_979};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_999 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_956};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1000 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1001 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1002 = { 14 | NIM_STRLIT_FLAG, "cannot handle " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1003 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1002};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1005 = { 22 | NIM_STRLIT_FLAG, "genericAssignOpenArray" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1006 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1005};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1007 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1008 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_872};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1009 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1010 = { 7 | NIM_STRLIT_FLAG, "Len_0, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1011 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1010};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1012 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1013 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1014 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1015 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1016 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1017 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_847};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1018 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1019 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_864};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1020 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1021 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1022 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1023 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1024 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1025 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1026 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1027 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1028 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1029 = { 15 | NIM_STRLIT_FLAG, "genAssignment: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1030 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1029};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1032 = { 15 | NIM_STRLIT_FLAG, "memTrackerWrite" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1033 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1032};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1034 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1035 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1036 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1037 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1038 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1039 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1040 = { 10 | NIM_STRLIT_FLAG, "objectInit" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1041 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1040};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1042 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1043 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1044 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1045 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1046 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_423};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1047 = { 8 | NIM_STRLIT_FLAG, ".name = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1048 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1047};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1049 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1050 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1051 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1052 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_98};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1053 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1054 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1055 = { 20 | NIM_STRLIT_FLAG, "wrong argument count" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1056 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1055};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1058 = { 63 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgcalls.nim" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1059 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1060 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1061 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1062 = {
0x10, 0xa8, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1063 = { 8 | NIM_STRLIT_FLAG, "\011return " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1064 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1063};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1065 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1066 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1067 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_239};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1068 = { 6 | NIM_STRLIT_FLAG, "Result" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1069 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1068};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1070 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1071 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1072 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1073 = { 11 | NIM_STRLIT_FLAG, "->len = 0; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1074 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1073};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1075 = { 14 | NIM_STRLIT_FLAG, "->p = NIM_NIL;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1076 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1075};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1077 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1078 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_383};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1079 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_385};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1080 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1081 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_389};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1082 = { 5 | NIM_STRLIT_FLAG, " = 0;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1083 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1082};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1084 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1085 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1086 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1087 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1088 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1089 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_533};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1090 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1091 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1092 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1093 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_414};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1094 = { 10 | NIM_STRLIT_FLAG, "((void**)&" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1095 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1094};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1096 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1097 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1098 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1099 = { 16 | NIM_STRLIT_FLAG, "specializeResetN" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1100 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1099};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1102 = { 63 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgreset.nim" };
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1103 = { 18 | NIM_STRLIT_FLAG, "specializeResetN()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1104 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1103};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1106 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1103};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1108 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1103};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1110 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_624};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1111 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_404};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1112 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1094};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1113 = { 11 | NIM_STRLIT_FLAG, ", NIM_NIL);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1114 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1113};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1115 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1116 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_404};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1117 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1094};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1118 = { 17 | NIM_STRLIT_FLAG, ".ClE_0, NIM_NIL);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1119 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1118};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1120 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1121 = { 17 | NIM_STRLIT_FLAG, ".ClP_0 = NIM_NIL;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1122 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1123 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1124 = { 11 | NIM_STRLIT_FLAG, " = NIM_NIL;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1125 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1124};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1126 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1127 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1082};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1128 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1129 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1124};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1130 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1131 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_414};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1132 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1133 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1134 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1135 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1136 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1082};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1137 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1138 = { 24 | NIM_STRLIT_FLAG, "unexpected set type kind" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1139 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1138};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1140 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_847};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1141 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1142 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_864};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1143 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1144 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1145 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1146 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_414};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1147 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1148 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1149 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1150 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1151 = { 25 | NIM_STRLIT_FLAG, "closure generation failed" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1152 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1151};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1154 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_404};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1155 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_396};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1156 = { 3 | NIM_STRLIT_FLAG, ", (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1157 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1156};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1158 = { 9 | NIM_STRLIT_FLAG, ") ClE_0);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1159 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1158};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1160 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1161 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_133};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1162 = { 8 | NIM_STRLIT_FLAG, ") ClE_0;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1163 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1162};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1164 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1165 = { 18 | NIM_STRLIT_FLAG, "NIM_BOOL* nimErr_;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1166 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1165};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1167 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1168 = { 10 | NIM_STRLIT_FLAG, "nimErr_ = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1169 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1168};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1170 = { 12 | NIM_STRLIT_FLAG, "nimErrorFlag" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1171 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1170};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1172 = { 3 | NIM_STRLIT_FLAG, "();" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1173 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1174 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1175 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1176 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_341};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1177 = {31, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_343};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1178 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_341};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1179 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_346};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1180 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1181 = { 21 | NIM_STRLIT_FLAG, "__declspec(noreturn) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1182 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1181};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1183 = { 18 | NIM_STRLIT_FLAG, "__declspec(naked) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1184 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1183};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1185 = { 2 | NIM_STRLIT_FLAG, " {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1186 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1185};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1187 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1188 = { 3 | NIM_STRLIT_FLAG, "}\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1189 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1188};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1190 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1185};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1191 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1192 = { 1 | NIM_STRLIT_FLAG, "#" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1193 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1192};
static const struct {
  NI cap; NIM_CHAR data[115+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1194 = { 115 | NIM_STRLIT_FLAG, "define nimfr_(proc, file) \\\012  TFrame FR_; \\\012  FR_.procname = proc; FR_.filename = file; FR_.line = 0; FR_.len = 0; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1195 = {115, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1194};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1196 = { 8 | NIM_STRLIT_FLAG, "nimFrame" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1197 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1196};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1198 = { 9 | NIM_STRLIT_FLAG, "(&FR_);\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1199 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1198};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1200 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1192};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1201 = { 36 | NIM_STRLIT_FLAG, "define nimln_(n) \\\012  FR_.line = n;\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1202 = {36, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1201};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1203 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1192};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1204 = { 63 | NIM_STRLIT_FLAG, "define nimlf_(n, file) \\\012  FR_.line = n; FR_.filename = file;\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1205 = {63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1206 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1196};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1207 = { 8 | NIM_STRLIT_FLAG, "\011nimfr_(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1208 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1207};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1209 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1210 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1211 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1212 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1213 = { 10 | NIM_STRLIT_FLAG, "nimProfile" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1214 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1213};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1215 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1216 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1217 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1218 = { 16 | NIM_STRLIT_FLAG, "\011}BeforeRet_: ;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1219 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1218};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1220 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1221 = { 8 | NIM_STRLIT_FLAG, "popFrame" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1222 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1221};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1223 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1224 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1225 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_721};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1226 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_51};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1227 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1228 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1229 = { 7 | NIM_STRLIT_FLAG, "extern " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1230 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1229};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1231 = { 17 | NIM_STRLIT_FLAG, "N_LIB_EXPORT_VAR " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1232 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1231};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1233 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_280};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1234 = { 17 | NIM_STRLIT_FLAG, "NIM_THREAD_LOCAL " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1235 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1234};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1236 = { 14 | NIM_STRLIT_FLAG, "NIM_THREADVAR " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1237 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1236};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1238 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1239 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1229};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1240 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1241 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1242 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_349};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1243 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_351};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1244 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_353};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1245 = { 7 | NIM_STRLIT_FLAG, "cgsym: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1246 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1245};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1248 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_48};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1250 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_77};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1251 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_79};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1252 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_79};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1253 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_58};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1254 = { 14 | NIM_STRLIT_FLAG, "NimStringDesc*" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1255 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1254};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1256 = { 8 | NIM_STRLIT_FLAG, "NCSTRING" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1257 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1256};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1258 = { 8 | NIM_STRLIT_FLAG, "NIM_BOOL" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1259 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1258};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1260 = { 8 | NIM_STRLIT_FLAG, "NIM_CHAR" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1261 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1260};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1262 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_35};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1263 = { 2 | NIM_STRLIT_FLAG, "NI" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1264 = { 3 | NIM_STRLIT_FLAG, "NI8" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1265 = { 4 | NIM_STRLIT_FLAG, "NI16" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1266 = { 4 | NIM_STRLIT_FLAG, "NI32" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1267 = { 4 | NIM_STRLIT_FLAG, "NI64" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1268 = { 2 | NIM_STRLIT_FLAG, "NF" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1269 = { 4 | NIM_STRLIT_FLAG, "NF32" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1270 = { 4 | NIM_STRLIT_FLAG, "NF64" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1271 = { 5 | NIM_STRLIT_FLAG, "NF128" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1272 = { 2 | NIM_STRLIT_FLAG, "NU" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1273 = { 3 | NIM_STRLIT_FLAG, "NU8" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1274 = { 4 | NIM_STRLIT_FLAG, "NU16" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1275 = { 4 | NIM_STRLIT_FLAG, "NU32" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1276 = { 4 | NIM_STRLIT_FLAG, "NU64" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1277 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1278 = { 30 | NIM_STRLIT_FLAG, "tyStatic for getSimpleTypeDesc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1279 = {30, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1278};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1281 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1282 = {
0x10, 0x0e, 0x10, 0x00, 0x00, 0x40, 0x80, 0x10,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1283 = { 1 | NIM_STRLIT_FLAG, "&" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1284 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1283};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1285 = { 8 | NIM_STRLIT_FLAG, "checkAbi" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1286 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1285};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1287 = { 36 | NIM_STRLIT_FLAG, "backend & Nim disagree on size for: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1288 = {36, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1287};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1289 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1290 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1283};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1291 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1292 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1293 = { 20 | NIM_STRLIT_FLAG, "getTypeDescAux: enum" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1294 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1293};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1296 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1297 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1298 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_179};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1299 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_278};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1300 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_66};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1301 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1185};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1302 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1303 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_759};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1304 = { 21 | NIM_STRLIT_FLAG, " data[SEQ_DECL_SIZE];" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1305 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1304};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1306 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1307 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_746};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1308 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1309 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_179};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1310 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1185};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1311 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1312 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_759};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1313 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_66};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1314 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_762};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1315 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1316 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_759};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1317 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1304};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1318 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1319 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_746};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1320 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1321 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_66};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1322 = {
0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1323 = { 39 | NIM_STRLIT_FLAG, "invalid apostrophe type parameter index" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1324 = {39, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1323};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1325 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_33};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1327 = { 1 | NIM_STRLIT_FLAG, "<" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1328 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1327};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1329 = { 7 | NIM_STRLIT_FLAG, " COMMA " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1330 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1329};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1331 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_33};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1332 = { 2 | NIM_STRLIT_FLAG, "> " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1333 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1332};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1334 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1335 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1336 = { 28 | NIM_STRLIT_FLAG, " __attribute__((__packed__))" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1337 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1336};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1338 = { 22 | NIM_STRLIT_FLAG, "#pragma pack(push, 1)\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1339 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1338};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1340 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1341 = { 10 | NIM_STRLIT_FLAG, " : public " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1342 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1341};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1343 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1344 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_711};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1345 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1346 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_566};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1347 = { 5 | NIM_STRLIT_FLAG, "dummy" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1348 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1347};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1349 = { 4 | NIM_STRLIT_FLAG, "char" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1350 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1349};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1351 = { 6 | NIM_STRLIT_FLAG, "m_type" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1352 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1351};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1353 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1354 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1355 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1351};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1356 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_432};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1357 = { 3 | NIM_STRLIT_FLAG, "Sup" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1358 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1357};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1359 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1347};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1360 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1349};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1361 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_575};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1362 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_568};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1363 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1364 = { 2 | NIM_STRLIT_FLAG, "TY" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1365 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1364};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1366 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1367 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1336};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1368 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1338};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1369 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1370 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1341};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1371 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1372 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1373 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_711};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1374 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1347};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1375 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1349};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1376 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1351};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1377 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1378 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1351};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1379 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_432};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1380 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1357};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1381 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1382 = { 5 | NIM_STRLIT_FLAG, "Field" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1383 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1382};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1384 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1347};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1385 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1349};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1386 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_575};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1387 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_568};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1388 = { 6 | NIM_STRLIT_FLAG, "tySet_" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1389 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1388};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1390 = { 15 | NIM_STRLIT_FLAG, "getTypeDescAux(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1391 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1390};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1393 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1394 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1395 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1396 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1397 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1181};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1398 = { 11 | NIM_STRLIT_FLAG, "extern \"C\" " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1399 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1398};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1400 = { 23 | NIM_STRLIT_FLAG, " __attribute__((naked))" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1401 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1400};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1402 = { 26 | NIM_STRLIT_FLAG, " __attribute__((noreturn))" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1403 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1402};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1404 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_566};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1405 = { 48 | NIM_STRLIT_FLAG, "request to generate code for .compileTime proc: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1406 = {48, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1405};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1408 = { 20 | NIM_STRLIT_FLAG, "expr: proc not init " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1409 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1408};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1411 = { 6 | NIM_STRLIT_FLAG, "_const" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1412 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1411};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1413 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1414 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_847};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1415 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1416 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_850};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1417 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1418 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1419 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1420 = { 37 | NIM_STRLIT_FLAG, "\'goto\' target must be a literal value" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1421 = {37, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1420};
static const struct {
  NI cap; NIM_CHAR data[63+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1423 = { 63 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/ccgstmts.nim" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1424 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1425 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1426 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1427 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1229};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1428 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1231};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1429 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_280};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1430 = { 10 | NIM_STRLIT_FLAG, "NIM_CONST " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1431 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1430};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1432 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1433 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_349};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1434 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_351};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1435 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_353};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1436 = { 8 | NIM_STRLIT_FLAG, " = $#;$n" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1437 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1436};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1438 = { 3 | NIM_STRLIT_FLAG, ";$n" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1439 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1438};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1440 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1441 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1442 = { 4 | NIM_STRLIT_FLAG, "$#;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1443 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1442};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1444 = { 8 | NIM_STRLIT_FLAG, "$#($#);\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1445 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1444};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1447 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_133};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1448 = { 3 | NIM_STRLIT_FLAG, "*) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1449 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1448};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1450 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1451 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1452 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1453 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1454 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1455 = { 37 | NIM_STRLIT_FLAG, ".dynlib variables cannot have a value" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1456 = {37, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1455};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1458 = { 40 | NIM_STRLIT_FLAG, ".threadvar variables cannot have a value" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1459 = {40, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1458};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1461 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1462 = { 3 | NIM_STRLIT_FLAG, "{{}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1463 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1464 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1465 = { 27 | NIM_STRLIT_FLAG, "\011NimTV_ = (NimThreadVars*) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1466 = {27, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1465};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1467 = { 18 | NIM_STRLIT_FLAG, "GetThreadLocalVars" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1468 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1467};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1469 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1470 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1471 = { 8 | NIM_STRLIT_FLAG, "NimTV_->" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1472 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1471};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1473 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1474 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1475 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1476 = { 28 | NIM_STRLIT_FLAG, "nimRegisterThreadLocalMarker" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1477 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1476};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1478 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1479 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1480 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1481 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1482 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1483 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1484 = { 23 | NIM_STRLIT_FLAG, "nimRegisterGlobalMarker" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1485 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1484};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1486 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1487 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1488 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1489 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1490 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1192};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1491 = { 3 | NIM_STRLIT_FLAG, "// " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1492 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1491};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1493 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1494 = { 5 | NIM_STRLIT_FLAG, "nimln" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1495 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1494};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1496 = { 4 | NIM_STRLIT_FLAG, "NULL" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1497 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1496};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1498 = { 18 | NIM_STRLIT_FLAG, "hcrRegisterGlobal(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1499 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1498};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1500 = { 3 | NIM_STRLIT_FLAG, ", \"" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1501 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1500};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1502 = { 10 | NIM_STRLIT_FLAG, "\", sizeof(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1503 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1502};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1504 = { 3 | NIM_STRLIT_FLAG, "), " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1505 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1504};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1506 = { 11 | NIM_STRLIT_FLAG, ", (void**)&" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1507 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1506};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1508 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1509 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1510 = { 22 | NIM_STRLIT_FLAG, "if (hcrRegisterGlobal(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1511 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1510};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1512 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1500};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1513 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1502};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1514 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1504};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1515 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1506};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1516 = { 3 | NIM_STRLIT_FLAG, "))\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1517 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1516};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1518 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1519 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1520 = { 8 | NIM_STRLIT_FLAG, "=destroy" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1521 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1520};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1522 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1523 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1524 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1525 = { 1 | NIM_STRLIT_FLAG, "-" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1526 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1525};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1527 = { 11 | NIM_STRLIT_FLAG, " != -1 && (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1528 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1527};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1529 = { 8 | NIM_STRLIT_FLAG, " < 0 || " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1530 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1531 = { 4 | NIM_STRLIT_FLAG, " >= " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1532 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1533 = { 11 | NIM_STRLIT_FLAG, ".Field1 || " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1534 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1533};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1535 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1536 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1537 = { 11 | NIM_STRLIT_FLAG, ".Field1)){ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1538 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1537};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1539 = { 16 | NIM_STRLIT_FLAG, "raiseIndexError4" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1540 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1539};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1541 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1542 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1543 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1544 = { 10 | NIM_STRLIT_FLAG, ".Field1); " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1545 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1544};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1546 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1547 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1548 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1549 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1550 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1551 = { 9 | NIM_STRLIT_FLAG, "Len_0 || " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1552 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1551};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1553 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1554 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1555 = { 9 | NIM_STRLIT_FLAG, "Len_0)){ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1556 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1555};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1557 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1539};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1558 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1559 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1560 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1561 = { 8 | NIM_STRLIT_FLAG, "Len_0); " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1562 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1561};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1563 = { 16 | NIM_STRLIT_FLAG, "goto BeforeRet_;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1564 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1563};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1565 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1566 = { 7 | NIM_STRLIT_FLAG, "goto LA" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1567 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1566};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1568 = { 2 | NIM_STRLIT_FLAG, "_;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1569 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1568};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1570 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1571 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1572 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1573 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1574 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1575 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1576 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1577 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1525};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1578 = { 9 | NIM_STRLIT_FLAG, " < -1 || " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1579 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1578};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1580 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1581 = { 4 | NIM_STRLIT_FLAG, " || " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1582 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1583 = { 3 | NIM_STRLIT_FLAG, " > " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1584 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1583};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1585 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1586 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1587 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1588 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1583};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1589 = { 4 | NIM_STRLIT_FLAG, ")){ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1590 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1589};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1591 = { 15 | NIM_STRLIT_FLAG, "raiseIndexError" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1592 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1591};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1593 = { 4 | NIM_STRLIT_FLAG, "(); " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1594 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1595 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1596 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1597 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1598 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1599 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1600 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1601 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1602 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1603 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1604 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1605 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1589};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1606 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1539};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1607 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1608 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1609 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1610 = { 3 | NIM_STRLIT_FLAG, "); " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1611 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1612 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1613 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1614 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_989};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1615 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1616 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1617 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1618 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_989};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1619 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1620 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1621 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1622 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1623 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1624 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1625 = { 14 | NIM_STRLIT_FLAG, "openArrayLoc: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1626 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1625};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1628 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1629 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x10,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1630 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_989};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1631 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1632 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1633 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1634 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1635 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1636 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1625};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1638 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1625};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1640 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1641 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1642 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1643 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1645 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[44+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1646 = { 44 | NIM_STRLIT_FLAG, "if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1647 = {44, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1646};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1648 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1649 = { 35 | NIM_STRLIT_FLAG, "if (NIM_UNLIKELY(*nimErr_)) goto LA" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1650 = {35, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1649};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1651 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1568};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1652 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__MQdRN7fpbG7rPm4JpVVAhA_1654 = {
0x00, 0x00, 0x00, 0x00, 0x88, 0x01, 0x00, 0x00,
0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1655 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1656 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1657 = { 40 | NIM_STRLIT_FLAG, "call expression expected for C++ pattern" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1658 = {40, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1657};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1661 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1662 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_220};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1663 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_220};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1664 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1665 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1666 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_220};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1667 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1668 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_33};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1669 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_566};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1670 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1671 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1672 = { 3 | NIM_STRLIT_FLAG, ");\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1673 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1672};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1674 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1672};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1675 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1676 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_373};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1677 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1678 = { 5 | NIM_STRLIT_FLAG, "auto " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1679 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1678};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1680 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1681 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1682 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1683 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1684 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1685 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1686 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1687 = { 29 | NIM_STRLIT_FLAG, "if (NIM_UNLIKELY(*nimErr_)) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1688 = {29, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1687};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1689 = { 19 | NIM_STRLIT_FLAG, "; goto BeforeRet_;}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1690 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1689};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1691 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1692 = {29, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1687};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1693 = { 9 | NIM_STRLIT_FLAG, "; goto LA" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1694 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1693};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1695 = { 3 | NIM_STRLIT_FLAG, "_;}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1696 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1695};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1697 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1698 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1672};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1699 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1701 = { 2 | NIM_STRLIT_FLAG, ": " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1702 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1701};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1703 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1704 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1701};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1705 = { 31 | NIM_STRLIT_FLAG, "varargs for objective C method\?" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1706 = {31, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1705};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1708 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1709 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1701};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1710 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1711 = { 8 | NIM_STRLIT_FLAG, "Result: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1712 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1711};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1713 = { 3 | NIM_STRLIT_FLAG, "];\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1714 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1713};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1715 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1713};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1716 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1717 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1713};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1718 = { 19 | NIM_STRLIT_FLAG, "expr: var not init " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1719 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1718};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1720 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1722 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1471};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1723 = { 20 | NIM_STRLIT_FLAG, "expr: temp not init " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1724 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1723};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1725 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1727 = { 21 | NIM_STRLIT_FLAG, "expr: param not init " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1728 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1727};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1729 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1731 = { 5 | NIM_STRLIT_FLAG, "expr(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1732 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1731};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1733 = { 17 | NIM_STRLIT_FLAG, "); unknown symbol" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1734 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1733};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1736 = { 2 | NIM_STRLIT_FLAG, "LA" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1737 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1738 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1739 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1740 = { 4 | NIM_STRLIT_FLAG, " == " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1741 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1740};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1742 = { 3 | NIM_STRLIT_FLAG, "){ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1743 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1742};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1744 = { 13 | NIM_STRLIT_FLAG, "raiseOverflow" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1745 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1744};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1746 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1747 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1748 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1749 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1750 = { 2 | NIM_STRLIT_FLAG, ")(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1751 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1750};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1752 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1753 = { 1 | NIM_STRLIT_FLAG, "+" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1754 = { 2 | NIM_STRLIT_FLAG, " (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1755 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1754};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1756 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1750};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1757 = { 2 | NIM_STRLIT_FLAG, "))" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1758 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1757};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1759 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1760 = { 4 | NIM_STRLIT_FLAG, " != " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1761 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1760};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1762 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1742};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1763 = { 19 | NIM_STRLIT_FLAG, "raiseFloatInvalidOp" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1764 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1763};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1765 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1766 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1767 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1768 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1769 = { 11 | NIM_STRLIT_FLAG, " != 0.0 && " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1770 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1769};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1771 = { 8 | NIM_STRLIT_FLAG, "*0.5 == " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1772 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1771};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1773 = { 4 | NIM_STRLIT_FLAG, ") { " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1774 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1773};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1775 = { 18 | NIM_STRLIT_FLAG, "raiseFloatOverflow" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1776 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1775};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1777 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1778 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1779 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1780 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1781 = { 1 | NIM_STRLIT_FLAG, "%" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1782 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1783 = { 8 | NIM_STRLIT_FLAG, " == 0){ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1784 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1783};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1785 = { 14 | NIM_STRLIT_FLAG, "raiseDivByZero" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1786 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1785};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1787 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1788 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1789 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1790 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1263};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1791 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1792 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1793 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1794 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1795 = { 11 | NIM_STRLIT_FLAG, "nimAddInt64" };
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1796 = { 11 | NIM_STRLIT_FLAG, "nimSubInt64" };
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1797 = { 11 | NIM_STRLIT_FLAG, "nimMulInt64" };
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1798 = { 11 | NIM_STRLIT_FLAG, "nimDivInt64" };
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1799 = { 11 | NIM_STRLIT_FLAG, "nimModInt64" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1800 = { 9 | NIM_STRLIT_FLAG, "nimAddInt" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1801 = { 9 | NIM_STRLIT_FLAG, "nimSubInt" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1802 = { 9 | NIM_STRLIT_FLAG, "nimMulInt" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1803 = { 9 | NIM_STRLIT_FLAG, "nimDivInt" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1804 = { 9 | NIM_STRLIT_FLAG, "nimModInt" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1805 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1806 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1807 = { 3 | NIM_STRLIT_FLAG, ", &" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1808 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1807};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1809 = { 5 | NIM_STRLIT_FLAG, ")) { " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1810 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1809};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1811 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1744};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1812 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1813 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_746};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1814 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1815 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1816 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1817 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1818 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1583};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1819 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1742};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1820 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1744};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1821 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1822 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1823 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1824 = { 40 | NIM_STRLIT_FLAG, "\'repr\' is not available for --newruntime" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1825 = {40, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1824};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1827 = { 7 | NIM_STRLIT_FLAG, "reprInt" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1828 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1827};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1829 = { 7 | NIM_STRLIT_FLAG, "((NI64)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1830 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1829};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1831 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1832 = { 9 | NIM_STRLIT_FLAG, "reprFloat" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1833 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1832};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1834 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1835 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1836 = { 8 | NIM_STRLIT_FLAG, "reprBool" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1837 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1836};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1838 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1839 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1840 = { 8 | NIM_STRLIT_FLAG, "reprChar" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1841 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1840};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1842 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1843 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1844 = { 8 | NIM_STRLIT_FLAG, "reprEnum" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1845 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1844};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1846 = { 5 | NIM_STRLIT_FLAG, "((NI)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1847 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1846};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1848 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1849 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1850 = { 7 | NIM_STRLIT_FLAG, "reprStr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1851 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1850};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1852 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1853 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1854 = { 7 | NIM_STRLIT_FLAG, "reprSet" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1855 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1854};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1856 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1857 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1858 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1859 = { 9 | NIM_STRLIT_FLAG, "genRepr()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1860 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1859};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1862 = { 13 | NIM_STRLIT_FLAG, "reprOpenArray" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1863 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1862};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1864 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1865 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1866 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1867 = { 7 | NIM_STRLIT_FLAG, "reprAny" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1868 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1867};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1869 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1870 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1871 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1872 = { 34 | NIM_STRLIT_FLAG, "\'repr\' doesn\'t support \'void\' type" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1873 = {34, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1872};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1875 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1867};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1876 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1877 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1878 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1880 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1881 = { 18 | NIM_STRLIT_FLAG, "getDynamicTypeInfo" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1882 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1881};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1883 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1884 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_423};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1885 = { 7 | NIM_STRLIT_FLAG, ".m_type" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1886 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1885};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1887 = { 12 | NIM_STRLIT_FLAG, "->typeInfoV1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1888 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1887};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1889 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_989};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1890 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1891 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1892 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1893 = {
0x10, 0x28, 0x90, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1894 = { 10 | NIM_STRLIT_FLAG, "binaryStmt" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1895 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1894};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1897 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1898 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1899 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1900 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1901 = { 2 | NIM_STRLIT_FLAG, "+=" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1902 = { 2 | NIM_STRLIT_FLAG, "-=" };
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1903 = {
0x10, 0x28, 0x80, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1904 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1263};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1905 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1906 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1907 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1908 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1909 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1910 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1911 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1807};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1912 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1809};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1913 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1744};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1914 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1915 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_746};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1916 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1917 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1918 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1919 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1920 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1583};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1921 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1742};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1922 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1744};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1923 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1924 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1925 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1926 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1927 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1928 = { 10 | NIM_STRLIT_FLAG, "appendChar" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1929 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1928};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1930 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1931 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1932 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1933 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1934 = { 3 | NIM_STRLIT_FLAG, " + " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1935 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1934};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1936 = { 12 | NIM_STRLIT_FLAG, "appendString" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1937 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1936};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1938 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1939 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1940 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1941 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1942 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1943 = { 12 | NIM_STRLIT_FLAG, "rawNewString" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1944 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1943};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1945 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1946 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1947 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1948 = { 14 | NIM_STRLIT_FLAG, "binaryStmtAddr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1949 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1948};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1951 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1952 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1953 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1954 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1955 = { 12 | NIM_STRLIT_FLAG, "nimAddCharV1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1956 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1955};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1957 = { 7 | NIM_STRLIT_FLAG, "addChar" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1958 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1957};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1959 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1960 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1961 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1962 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1963 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1964 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1928};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1965 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1966 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1967 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1968 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1969 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1934};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1970 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1936};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1971 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1972 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1973 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1974 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1975 = { 10 | NIM_STRLIT_FLAG, "prepareAdd" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1976 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1975};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1977 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1978 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1979 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1980 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1981 = { 12 | NIM_STRLIT_FLAG, "resizeString" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1982 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1981};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1983 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1984 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1985 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_1986 = {
0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1987 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1988 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1989 = { 9 | NIM_STRLIT_FLAG, "incrSeqV3" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1990 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1989};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_1991 = { 16 | NIM_STRLIT_FLAG, "((TGenericSeq*)(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1992 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1991};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1993 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1504};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1994 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1995 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1996 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1997 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1989};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1998 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_1999 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2000 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2001 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_373};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2002 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2003 = { 3 | NIM_STRLIT_FLAG, "NI " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2004 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2003};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2005 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2006 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2007 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2008 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_220};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2009 = { 3 | NIM_STRLIT_FLAG, "++;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2010 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2009};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2011 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2012 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2013 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2014 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2015 = { 6 | NIM_STRLIT_FLAG, " == 0)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2016 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2015};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2017 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2018 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2015};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2019 = { 9 | NIM_STRLIT_FLAG, "eqStrings" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2020 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2019};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2021 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2022 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2023 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2024 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2025 = { 10 | NIM_STRLIT_FLAG, "cmpStrings" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2026 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2025};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2027 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2028 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2029 = { 7 | NIM_STRLIT_FLAG, ") <= 0)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2030 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2029};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2031 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2032 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2025};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2033 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2034 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2035 = { 6 | NIM_STRLIT_FLAG, ") < 0)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2036 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2035};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2037 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2038 = { 12 | NIM_STRLIT_FLAG, ".ClP_0 == 0)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2039 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2038};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2040 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2041 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2015};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2042 = { 12 | NIM_STRLIT_FLAG, "nimBoolToStr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2043 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2042};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2044 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2045 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2046 = { 12 | NIM_STRLIT_FLAG, "nimCharToStr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2047 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2046};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2048 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2049 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2050 = { 12 | NIM_STRLIT_FLAG, "cstrToNimstr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2051 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2050};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2052 = { 12 | NIM_STRLIT_FLAG, "((NCSTRING) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2053 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2052};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2054 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2055 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2050};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2056 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2057 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2058 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2059 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2060 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_98};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2061 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2062 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_423};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2063 = { 43 | NIM_STRLIT_FLAG, "no \'of\' operator available for pure objects" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2064 = {43, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2063};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2066 = { 17 | NIM_STRLIT_FLAG, "isObjDisplayCheck" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2067 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2066};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2068 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2069 = { 9 | NIM_STRLIT_FLAG, ".m_type, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2070 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2069};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2071 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2072 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2073 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2074 = { 17 | NIM_STRLIT_FLAG, "Nim_OfCheck_CACHE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2075 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2074};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2076 = { 14 | NIM_STRLIT_FLAG, "isObjWithCache" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2077 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2076};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2078 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2079 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2069};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2080 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2081 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2082 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2083 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2084 = { 6 | NIM_STRLIT_FLAG, ") && (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2085 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2084};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2086 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1757};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2087 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2088 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2089 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2090 = { 9 | NIM_STRLIT_FLAG, "nimNewObj" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2091 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2090};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2092 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2093 = { 14 | NIM_STRLIT_FLAG, ", NIM_ALIGNOF(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2094 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2093};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2095 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1757};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2096 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2097 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2098 = { 15 | NIM_STRLIT_FLAG, "nimNewObjUninit" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2099 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2098};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2100 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2101 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2093};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2102 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1757};
static const struct {
  NI cap; NIM_CHAR data[93+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2103 = { 93 | NIM_STRLIT_FLAG, "the destructor that is turned into a finalizer needs to have the \'nimcall\' calling convention" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2104 = {93, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2103};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2106 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2107 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1773};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2108 = { 13 | NIM_STRLIT_FLAG, "nimGCunrefRC1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2109 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2108};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2110 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2111 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2112 = { 13 | NIM_STRLIT_FLAG, " = NIM_NIL; }" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2113 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2114 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2115 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2116 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1773};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2117 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_908};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2118 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2119 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2120 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2121 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2122 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2123 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2124 = { 6 | NIM_STRLIT_FLAG, "newObj" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2125 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2124};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2126 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2127 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2128 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2129 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_404};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2130 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_396};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2131 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2132 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2133 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2134 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2135 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2136 = { 9 | NIM_STRLIT_FLAG, "newObjRC1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2137 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2136};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2138 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2139 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2140 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2141 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2142 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2143 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2144 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2145 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2146 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2124};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2147 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2148 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2149 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2150 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2151 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2152 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2153 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2154 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2124};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2155 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2156 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2157 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1757};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2158 = { 7 | NIM_STRLIT_FLAG, ".len = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2159 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2158};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2160 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2161 = { 6 | NIM_STRLIT_FLAG, ".p = (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2162 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2161};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2163 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1448};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2164 = { 13 | NIM_STRLIT_FLAG, "newSeqPayload" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2165 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2164};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2166 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2167 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2168 = { 15 | NIM_STRLIT_FLAG, "), NIM_ALIGNOF(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2169 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2168};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2170 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2171 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2172 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2173 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1773};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2174 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2108};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2175 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2176 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2177 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2178 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2179 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2180 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1773};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2181 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_908};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2182 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2183 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2184 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2185 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2186 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2187 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2188 = { 6 | NIM_STRLIT_FLAG, "newSeq" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2189 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2188};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2190 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2191 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2192 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2193 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_404};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2194 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_396};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2195 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2196 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2197 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2198 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2199 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2200 = { 9 | NIM_STRLIT_FLAG, "newSeqRC1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2201 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2200};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2202 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2203 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2204 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2205 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2206 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2207 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2208 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_784};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2209 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2210 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2211 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2188};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2212 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2213 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2214 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2215 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_383};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2216 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2161};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2217 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1448};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2218 = { 19 | NIM_STRLIT_FLAG, "newSeqPayloadUninit" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2219 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2218};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2220 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2221 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2222 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2168};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2223 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2224 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2225 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2226 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2227 = { 14 | NIM_STRLIT_FLAG, "nimNewSeqOfCap" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2228 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2227};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2229 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2230 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2231 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2232 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2233 = { 11 | NIM_STRLIT_FLAG, "unknown ast" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2234 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2233};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2236 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1382};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2237 = {
0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2238 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0xb0, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2239 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2240 = { 3 | NIM_STRLIT_FLAG, ")-(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2241 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2240};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2242 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1757};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2243 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2244 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2240};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2245 = { 4 | NIM_STRLIT_FLAG, ")+1)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2246 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2245};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2247 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2248 = { 8 | NIM_STRLIT_FLAG, "Len_0-1)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2249 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2248};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2250 = { 5 | NIM_STRLIT_FLAG, "Len_0" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2251 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2250};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2252 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2253 = { 11 | NIM_STRLIT_FLAG, "->Field1-1)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2254 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2253};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2255 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2256 = { 10 | NIM_STRLIT_FLAG, ".Field1-1)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2257 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2256};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2258 = { 8 | NIM_STRLIT_FLAG, "->Field1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2259 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2258};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2260 = { 7 | NIM_STRLIT_FLAG, ".Field1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2261 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2260};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2262 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2263 = { 10 | NIM_STRLIT_FLAG, "nimCStrLen" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2264 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2263};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2265 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2266 = { 4 | NIM_STRLIT_FLAG, ")-1)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2267 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2266};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2268 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2263};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2269 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2270 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2271 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2272 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2273 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2274 = { 13 | NIM_STRLIT_FLAG, "genArrayLen()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2275 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2274};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2277 = { 9 | NIM_STRLIT_FLAG, "unaryStmt" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2278 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2277};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2280 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2281 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1773};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2282 = { 8 | NIM_STRLIT_FLAG, "nimGCref" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2283 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2282};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2284 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2285 = { 4 | NIM_STRLIT_FLAG, "); }" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2286 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2285};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2287 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2288 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2277};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2289 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2290 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1773};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2291 = { 10 | NIM_STRLIT_FLAG, "nimGCunref" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2292 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2291};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2293 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2294 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2285};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2295 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2296 = { 14 | NIM_STRLIT_FLAG, "setLengthStrV2" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2297 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2296};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2298 = { 15 | NIM_STRLIT_FLAG, "genSetLengthStr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2299 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2298};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2301 = { 12 | NIM_STRLIT_FLAG, "setLengthStr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2302 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2301};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2303 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2304 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2305 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2306 = { 18 | NIM_STRLIT_FLAG, "setLengthSeqUninit" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2307 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2306};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2308 = { 14 | NIM_STRLIT_FLAG, "setLengthSeqV2" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2309 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2308};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2310 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2311 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2312 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2313 = { 4 | NIM_STRLIT_FLAG, ")\?&(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2314 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2313};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2315 = { 16 | NIM_STRLIT_FLAG, ")->Sup:NIM_NIL, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2316 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2315};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2317 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2318 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2319 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_779};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2320 = { 8 | NIM_STRLIT_FLAG, "NIM_TRUE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2321 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2320};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2322 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2323 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2324 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2325 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2326 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2327 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2328 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2329 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2330 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2331 = { 3 | NIM_STRLIT_FLAG, " - " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2332 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2331};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2333 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2334 = { 11 | NIM_STRLIT_FLAG, "countBits32" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2335 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2334};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2336 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2337 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2338 = { 11 | NIM_STRLIT_FLAG, "countBits64" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2339 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2338};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2340 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2341 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2342 = { 3 | NIM_STRLIT_FLAG, "(((" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2343 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2342};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2344 = { 5 | NIM_STRLIT_FLAG, " & ~ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2345 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2344};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2346 = { 8 | NIM_STRLIT_FLAG, ")==0)&&(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2347 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2346};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2348 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1760};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2349 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1757};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2350 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2351 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2344};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2352 = { 5 | NIM_STRLIT_FLAG, ")==0)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2353 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2352};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2354 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2355 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1740};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2356 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2357 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2358 = { 3 | NIM_STRLIT_FLAG, " & " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2359 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2358};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2360 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2361 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2362 = { 3 | NIM_STRLIT_FLAG, " | " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2363 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2362};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2364 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2365 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2366 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2344};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2367 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2368 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2369 = { 3 | NIM_STRLIT_FLAG, " ^ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2370 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2369};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2371 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2372 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2373 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2374 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2375 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2376 = { 10 | NIM_STRLIT_FLAG, "genSetOp()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2377 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2376};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2379 = { 7 | NIM_STRLIT_FLAG, "cardSet" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2380 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2379};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2381 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2382 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2383 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2384 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2385 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2386 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2387 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2388 = { 6 | NIM_STRLIT_FLAG, "++) { " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2389 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2388};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2390 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2391 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_759};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2392 = { 5 | NIM_STRLIT_FLAG, " = ((" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2393 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2392};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2394 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2395 = { 6 | NIM_STRLIT_FLAG, "] & ~ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2396 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2395};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2397 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2398 = { 9 | NIM_STRLIT_FLAG, "]) == 0);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2399 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2400 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2401 = { 7 | NIM_STRLIT_FLAG, "  if (!" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2402 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2401};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2403 = { 9 | NIM_STRLIT_FLAG, ") break;}" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2404 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2403};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2405 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2406 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2407 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2408 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_133};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2409 = { 9 | NIM_STRLIT_FLAG, "nimCmpMem" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2410 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2409};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2411 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2412 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2413 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2414 = { 8 | NIM_STRLIT_FLAG, ") != 0);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2415 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2414};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2416 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2417 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2418 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2419 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2420 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2421 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2388};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2422 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2423 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_759};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2424 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2392};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2425 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2426 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2395};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2427 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2428 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2429 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2430 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2401};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2431 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2403};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2432 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2433 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2434 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2409};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2435 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2436 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2437 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2438 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2352};
static const struct {
  NI cap; NIM_CHAR data[88+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2439 = { 88 | NIM_STRLIT_FLAG, "for ($1 = 0; $1 < $2; $1++) { $n  $3 = (($4[$1] & ~ $5[$1]) == 0);$n  if (!$3) break;}$n" };
static const struct {
  NI cap; NIM_CHAR data[133+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2440 = { 133 | NIM_STRLIT_FLAG, "for ($1 = 0; $1 < $2; $1++) { $n  $3 = (($4[$1] & ~ $5[$1]) == 0);$n  if (!$3) break;}$nif ($3) $3 = (#nimCmpMem($4, $5, $2) != 0);$n" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2441 = { 1 | NIM_STRLIT_FLAG, "|" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2442 = { 3 | NIM_STRLIT_FLAG, "& ~" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2443 = { 1 | NIM_STRLIT_FLAG, "^" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2444 = { 8 | NIM_STRLIT_FLAG, "genSetOp" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2445 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2444};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2448 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2449 = { 4 | NIM_STRLIT_FLAG, ", \"\"" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2450 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2449};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2451 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2452 = { 16 | NIM_STRLIT_FLAG, "Genode::Cstring(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2453 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2452};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2454 = { 10 | NIM_STRLIT_FLAG, ".p->data, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2455 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2454};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2456 = { 5 | NIM_STRLIT_FLAG, ".len)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2457 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2456};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2458 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2452};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2459 = { 8 | NIM_STRLIT_FLAG, "->data, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2460 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2459};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2461 = { 6 | NIM_STRLIT_FLAG, "->len)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2462 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2461};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2463 = { 12 | NIM_STRLIT_FLAG, "<base/log.h>" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2464 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2463};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2465 = { 15 | NIM_STRLIT_FLAG, "<util/string.h>" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2466 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2465};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2467 = { 12 | NIM_STRLIT_FLAG, "Genode::log(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2468 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2467};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2469 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2470 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2471 = { 11 | NIM_STRLIT_FLAG, "echoBinSafe" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2472 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2471};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2473 = { 10 | NIM_STRLIT_FLAG, "(NIM_NIL, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2474 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2475 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2476 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2477 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2471};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2478 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2479 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2480 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2481 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2482 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2158};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2483 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2484 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2161};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2485 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1448};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2486 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2164};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2487 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2488 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2489 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2168};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2490 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2491 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2492 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2493 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2494 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2158};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2495 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2496 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2161};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2497 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1448};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2498 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2164};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2499 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2500 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2501 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2168};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2502 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2503 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2504 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2505 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2506 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2507 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2508 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2509 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2510 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2511 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2512 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_533};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2513 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2514 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2515 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2516 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2517 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const struct {
  NI cap; NIM_CHAR data[45+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2518 = { 45 | NIM_STRLIT_FLAG, "\'$1\' can only be used in compile-time context" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2519 = {45, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2518};
static const struct {
  NI cap; NIM_CHAR data[82+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2521 = { 82 | NIM_STRLIT_FLAG, "for --mm:arc|atomicArc|orc \'deepcopy\' support has to be enabled with --deepcopy:on" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2522 = {82, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2521};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2524 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x10,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2525 = { 15 | NIM_STRLIT_FLAG, "genericDeepCopy" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2526 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2527 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2528 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_872};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2529 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2530 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2531 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2532 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2525};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2533 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2534 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_872};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2535 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2536 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2537 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2538 = { 18 | NIM_STRLIT_FLAG, "genericSeqDeepCopy" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2539 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2540 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2541 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2542 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2543 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2544 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2545 = { 24 | NIM_STRLIT_FLAG, "genericDeepCopyOpenArray" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2546 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2545};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2547 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2548 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_872};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2549 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2550 = { 10 | NIM_STRLIT_FLAG, "->Field1, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2551 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2550};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2552 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2553 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2554 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_847};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2555 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_416};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2556 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_864};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2557 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2558 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2559 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2560 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2561 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2562 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2563 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2564 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2565 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2566 = { 13 | NIM_STRLIT_FLAG, "genDeepCopy: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2567 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2566};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2569 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2570 = { 6 | NIM_STRLIT_FLAG, ".p != " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2571 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2570};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2572 = { 5 | NIM_STRLIT_FLAG, ".p) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2573 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2572};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2574 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2575 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2576 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2158};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2577 = { 6 | NIM_STRLIT_FLAG, ".len; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2578 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2577};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2579 = { 5 | NIM_STRLIT_FLAG, ".p = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2580 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2579};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2581 = { 3 | NIM_STRLIT_FLAG, ".p;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2582 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2583 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2584 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2585 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2586 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2587 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2588 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2589 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2590 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2591 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2592 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2593 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2594 = { 8 | NIM_STRLIT_FLAG, ".p && !(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2595 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2594};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2596 = { 29 | NIM_STRLIT_FLAG, ".p->cap & NIM_STRLIT_FLAG)) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2597 = {29, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2596};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2598 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2599 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2600 = { 13 | NIM_STRLIT_FLAG, "deallocShared" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2601 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2600};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2602 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2603 = { 4 | NIM_STRLIT_FLAG, ".p);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2604 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2603};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2605 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2606 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2607 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2608 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2609 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2594};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2610 = {29, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2596};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2611 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2612 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2613 = { 7 | NIM_STRLIT_FLAG, "dealloc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2614 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2613};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2615 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2616 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2603};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2617 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2618 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2619 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2620 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2621 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2594};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2622 = {29, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2596};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2623 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2624 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2625 = { 14 | NIM_STRLIT_FLAG, "alignedDealloc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2626 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2625};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2627 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2628 = { 16 | NIM_STRLIT_FLAG, ".p, NIM_ALIGNOF(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2629 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2628};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2630 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2631 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2632 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2633 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2634 = { 39 | NIM_STRLIT_FLAG, "destructor turned out to be not trivial" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2635 = {39, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2634};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2637 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_650};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2638 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2639 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_952};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2640 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2641 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_956};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2642 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2643 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2644 = { 14 | NIM_STRLIT_FLAG, "genMagicExpr: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2645 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2644};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2647 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_414};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2648 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2649 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_418};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2650 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2651 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2652 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1272};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2653 = { 11 | NIM_STRLIT_FLAG, "CNSTCLOSURE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2654 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2653};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2655 = { 26 | NIM_STRLIT_FLAG, "closure to closure created" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2656 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2655};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2658 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_924};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2659 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2660 = { 9 | NIM_STRLIT_FLAG, ".ClE_0 = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2661 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2660};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2662 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2663 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2664 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2665 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_423};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2666 = { 21 | NIM_STRLIT_FLAG, "genCheckedRecordField" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2667 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2666};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2669 = { 17 | NIM_STRLIT_FLAG, "genFieldObjConstr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2670 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2669};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2672 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2673 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2674 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2675 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2676 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2677 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2678 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2679 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2680 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_135};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2681 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_89};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2682 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_91};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2683 = { 2 | NIM_STRLIT_FLAG, "{ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2684 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2683};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2685 = { 18 | NIM_STRLIT_FLAG, "raiseFieldErrorStr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2686 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2685};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2687 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2688 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2689 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2690 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2683};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2691 = { 16 | NIM_STRLIT_FLAG, "raiseFieldError2" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2692 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2691};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2693 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2694 = { 6 | NIM_STRLIT_FLAG, ", (NI)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2695 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2694};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2696 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2697 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2683};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2698 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2691};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2699 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2700 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2701 = { 16 | NIM_STRLIT_FLAG, "reprDiscriminant" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2702 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2701};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2703 = { 6 | NIM_STRLIT_FLAG, "(((NI)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2704 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2703};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2705 = { 8 | NIM_STRLIT_FLAG, ") + (NI)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2706 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2705};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2707 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2708 = { 4 | NIM_STRLIT_FLAG, ")); " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2709 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2708};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2710 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2711 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2712 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2713 = { 8 | NIM_STRLIT_FLAG, "union { " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2714 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2713};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2715 = { 7 | NIM_STRLIT_FLAG, " dest; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2716 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2715};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2717 = { 14 | NIM_STRLIT_FLAG, " source; } LOC" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2718 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2717};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2719 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2720 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2721 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2722 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_414};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2723 = { 5 | NIM_STRLIT_FLAG, "(&LOC" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2724 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2723};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2725 = { 12 | NIM_STRLIT_FLAG, ", sizeof(LOC" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2726 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2725};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2727 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_420};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2728 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2729 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2713};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2730 = { 9 | NIM_STRLIT_FLAG, " source; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2731 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2730};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2732 = { 12 | NIM_STRLIT_FLAG, " dest; } LOC" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2733 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2732};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2734 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2735 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2736 = {
0x10, 0x08, 0x80, 0x00, 0x00, 0xc0, 0x00, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2737 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1283};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2738 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0xb0, 0x00,
0x00}
;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2739 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2740 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2741 = {
0x10, 0xa9, 0xf0, 0x00, 0x00, 0xe0, 0xb0, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2742 = { 9 | NIM_STRLIT_FLAG, "if ((NU)(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2743 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2742};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2744 = { 9 | NIM_STRLIT_FLAG, ") > (NU)(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2745 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2744};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2746 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1589};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2747 = { 16 | NIM_STRLIT_FLAG, "raiseIndexError2" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2748 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2747};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2749 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2750 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2751 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2752 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2753 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2754 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2755 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2756 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2757 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1583};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2758 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1742};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2759 = { 16 | NIM_STRLIT_FLAG, "raiseIndexError3" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2760 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2759};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2761 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2762 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2763 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2764 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2765 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2766 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2767 = { 43 | NIM_STRLIT_FLAG, "index out of bounds, the container is empty" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2768 = {43, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2767};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2769 = { 6 | NIM_STRLIT_FLAG, "index " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2770 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2769};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2771 = { 8 | NIM_STRLIT_FLAG, " not in " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2772 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2771};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2773 = { 4 | NIM_STRLIT_FLAG, " .. " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2774 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2773};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2776 = { 2 | NIM_STRLIT_FLAG, "[(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2777 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2776};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2778 = { 3 | NIM_STRLIT_FLAG, ")- " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2779 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2778};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2780 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2781 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2782 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2783 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2784 = { 8 | NIM_STRLIT_FLAG, "Len_0){ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2785 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2784};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2786 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2747};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2787 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2788 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_366};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2789 = { 10 | NIM_STRLIT_FLAG, "Len_0-1); " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2790 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2789};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2791 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2792 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2793 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2794 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2795 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2796 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2797 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2798 = { 10 | NIM_STRLIT_FLAG, ".Field1){ " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2799 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2798};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2800 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2747};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2801 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2802 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_366};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2803 = { 12 | NIM_STRLIT_FLAG, ".Field1-1); " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2804 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2803};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2805 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2806 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2807 = { 8 | NIM_STRLIT_FLAG, ".Field0[" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2808 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2807};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2809 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2810 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2811 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1529};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2812 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2813 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1742};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2814 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2747};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2815 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2816 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_366};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2817 = { 5 | NIM_STRLIT_FLAG, "-1); " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2818 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2817};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2819 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2820 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2821 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_98};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2822 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2823 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_989};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2824 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2825 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2826 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2827 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2828 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2829 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2830 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_538};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__MQdRN7fpbG7rPm4JpVVAhA_2831 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0x60, 0xb0, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2832 = { 12 | NIM_STRLIT_FLAG, "genTupleElem" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2833 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2832};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2835 = { 20 | NIM_STRLIT_FLAG, "expr(nkBracketExpr, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2836 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2835};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2838 = { 9 | NIM_STRLIT_FLAG, "genDeref " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2839 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2838};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2841 = { 17 | NIM_STRLIT_FLAG, "genRecordFieldAux" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2842 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2841};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2844 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_624};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2845 = { 17 | NIM_STRLIT_FLAG, "genRecordField 3 " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2846 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2845};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2848 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2849 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2666};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2851 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_455};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2852 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2853 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2854 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2855 = { 2 | NIM_STRLIT_FLAG, "FR" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2856 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2855};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2857 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2858 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1196};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2859 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2860 = { 12 | NIM_STRLIT_FLAG, ".procname = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2861 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2860};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2862 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2863 = { 12 | NIM_STRLIT_FLAG, ".filename = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2864 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2863};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2865 = { 3 | NIM_STRLIT_FLAG, ";  " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2866 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2865};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2867 = { 8 | NIM_STRLIT_FLAG, ".line = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2868 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2867};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2869 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_531};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2870 = { 21 | NIM_STRLIT_FLAG, ".len = -1; nimFrame(&" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2871 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2870};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2872 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2873 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2874 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2875 = { 14 | NIM_STRLIT_FLAG, "popFrameOfAddr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2876 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2875};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2877 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2878 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2879 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2880 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2881 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2855};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2882 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2883 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2884 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2885 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2886 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2887 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2888 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2889 = { 7 | NIM_STRLIT_FLAG, "genIf()" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2890 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2889};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2892 = { 5 | NIM_STRLIT_FLAG, "->Sup" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2893 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2892};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2894 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_423};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2895 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_423};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2896 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1283};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2897 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2898 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2899 = { 5 | NIM_STRLIT_FLAG, " && !" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2900 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2899};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2901 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2066};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2902 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2903 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2904 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2905 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1589};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2906 = { 26 | NIM_STRLIT_FLAG, "raiseObjectConversionError" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2907 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2906};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2908 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2909 = { 5 | NIM_STRLIT_FLAG, "if (!" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2910 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2909};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2911 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2066};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2912 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2913 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2914 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2915 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1589};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2916 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2906};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2917 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2918 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2919 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2899};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2920 = { 5 | NIM_STRLIT_FLAG, "isObj" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2921 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2920};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2922 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2923 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2924 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1589};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2925 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2906};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2926 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2927 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2909};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2928 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2920};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2929 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2930 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2931 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1589};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2932 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2906};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2933 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2934 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2935 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2936 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2937 = { 4 | NIM_STRLIT_FLAG, " > (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2938 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2937};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2939 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1750};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2940 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1589};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2941 = { 21 | NIM_STRLIT_FLAG, "raiseRangeErrorNoArgs" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2942 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2941};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2943 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1593};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2944 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2945 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2946 = { 16 | NIM_STRLIT_FLAG, "raiseRangeErrorU" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2947 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2946};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2948 = { 16 | NIM_STRLIT_FLAG, "raiseRangeErrorF" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2949 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2948};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2950 = { 16 | NIM_STRLIT_FLAG, "raiseRangeErrorI" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2951 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2950};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2952 = { 6 | NIM_STRLIT_FLAG, "(NI64)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2953 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2952};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2954 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2955 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2956 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2957 = { 4 | NIM_STRLIT_FLAG, ") < " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2958 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2957};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2959 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1581};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2960 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2961 = { 4 | NIM_STRLIT_FLAG, ") > " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2962 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2961};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2963 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1742};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2964 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2965 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2966 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2967 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1610};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2968 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2969 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2970 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_370};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2971 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2972 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2973 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2050};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2974 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2052};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2975 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2976 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2050};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2977 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2978 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2979 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1408};
static const struct {
  NI cap; NIM_CHAR data[51+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2981 = { 51 | NIM_STRLIT_FLAG, "case statement must be exhaustive for computed goto" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2982 = {51, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2981};
static const struct {
  NI cap; NIM_CHAR data[64+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2984 = { 64 | NIM_STRLIT_FLAG, "case statement cannot work on enums with holes for computed goto" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2985 = {64, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2984};
static const struct {
  NI cap; NIM_CHAR data[51+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2987 = { 51 | NIM_STRLIT_FLAG, "case statement has too many cases for computed goto" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2988 = {51, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2987};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2990 = { 50 | NIM_STRLIT_FLAG, "case statement has to start at 0 for computed goto" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2991 = {50, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2990};
static const struct {
  NI cap; NIM_CHAR data[41+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2993 = { 41 | NIM_STRLIT_FLAG, "no case statement found for computed goto" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2994 = {41, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2993};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2996 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2997 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_2998 = { 46 | NIM_STRLIT_FLAG, "range notation not available for computed goto" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_2999 = {46, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2998};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3001 = { 11 | NIM_STRLIT_FLAG, "while (1) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3002 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3001};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3003 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3004 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3005 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3006 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3007 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1213};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3008 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3009 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3010 = { 11 | NIM_STRLIT_FLAG, "genVarTuple" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3011 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3010};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3013 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3014 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3015 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3016 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3017 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3018 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3019 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3020 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3010};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3022 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1496};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3023 = { 9 | NIM_STRLIT_FLAG, "NIM_BOOL " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3024 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3023};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3025 = { 13 | NIM_STRLIT_FLAG, " = NIM_FALSE;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3026 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3025};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3027 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3028 = { 22 | NIM_STRLIT_FLAG, " |= hcrRegisterGlobal(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3029 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3028};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3030 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1500};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3031 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1502};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3032 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1504};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3033 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1506};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3034 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1672};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3035 = { 28 | NIM_STRLIT_FLAG, "for statement not eliminated" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3036 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3035};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3038 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3039 = { 10 | NIM_STRLIT_FLAG, "eqCstrings" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3040 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3039};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3041 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3042 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3043 = { 8 | NIM_STRLIT_FLAG, ")) goto " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3044 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3043};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3045 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3046 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3047 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3048 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2019};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3049 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3050 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3051 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3043};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3052 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3053 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3054 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3055 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3056 = { 8 | NIM_STRLIT_FLAG, "switch (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3057 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3056};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3058 = { 11 | NIM_STRLIT_FLAG, "hashCstring" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3059 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3058};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3060 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3061 = { 4 | NIM_STRLIT_FLAG, ") & " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3062 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3061};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3063 = { 3 | NIM_STRLIT_FLAG, ") {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3064 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3063};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3065 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3066 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3056};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3067 = { 10 | NIM_STRLIT_FLAG, "hashString" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3068 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3067};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3069 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3070 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3061};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3071 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3063};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3072 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3073 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3074 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3075 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3076 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3039};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3077 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3078 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3079 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3043};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3080 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3081 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3082 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3083 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3084 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3085 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2019};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3086 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3087 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3088 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3043};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3089 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3090 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3091 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3092 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3093 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3094 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3095 = { 4 | NIM_STRLIT_FLAG, " && " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3096 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3095};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3097 = { 4 | NIM_STRLIT_FLAG, " <= " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3098 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3097};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3099 = { 7 | NIM_STRLIT_FLAG, ") goto " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3100 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3099};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3101 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3102 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3103 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3104 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3105 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3106 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1740};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3107 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3099};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3108 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3109 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3110 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3111 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3112 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3113 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3114 = {46, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2998};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3116 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3117 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1531};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3118 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3095};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3119 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3097};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3120 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3099};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3121 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3122 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3123 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3124 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3125 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3126 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1740};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3127 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3099};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3128 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3129 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3130 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3131 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3132 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3133 = { 12 | NIM_STRLIT_FLAG, "popSafePoint" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3134 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3133};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3135 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3136 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3137 = { 19 | NIM_STRLIT_FLAG, "popCurrentException" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3138 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3139 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3140 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3141 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3142 = { 14 | NIM_STRLIT_FLAG, ".status != 0) " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3143 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3142};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3144 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3145 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3146 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3147 = { 46 | NIM_STRLIT_FLAG, "ccgstmts.nim(733, 13) `sym.loc.k == locOther` " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3148 = {46, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3147};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3149 = { 16 | NIM_STRLIT_FLAG, "no loop to break" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3150 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3149};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3152 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3153 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1229};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3154 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_475};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3155 = { 22 | NIM_STRLIT_FLAG, "FieldDiscriminantCheck" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3156 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3155};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3157 = { 10 | NIM_STRLIT_FLAG, "((NI)(NU)(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3158 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3157};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3159 = { 12 | NIM_STRLIT_FLAG, "), (NI)(NU)(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3160 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3159};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3161 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1504};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3162 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3163 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3164 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3165 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3167 = { 7 | NIM_STRLIT_FLAG, "(void)(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3168 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3167};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3169 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1672};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3170 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3171 = { 3 | NIM_STRLIT_FLAG, "gcc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3172 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3171};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3173 = { 3 | NIM_STRLIT_FLAG, "vcc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3174 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3173};
static const struct {
  NI cap; NIM_CHAR data[61+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3175 = { 61 | NIM_STRLIT_FLAG, "Your compiler does not support the specified inline assembler" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3176 = {61, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3175};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3178 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3179 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3180 = { 1 | NIM_STRLIT_FLAG, "\"" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3181 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3180};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3182 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3180};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3183 = { 2 | NIM_STRLIT_FLAG, "\\\"" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3184 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3183};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3185 = { 4 | NIM_STRLIT_FLAG, "\\n\"\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3186 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3185};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3187 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3188 = {29, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1687};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3189 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3190 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3191 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3192 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3193 = { 3 | NIM_STRLIT_FLAG, "_:;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3194 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3193};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3195 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3196 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3197 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3198 = { 21 | NIM_STRLIT_FLAG, "*nimErr_ = NIM_FALSE;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3199 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3198};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3200 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3201 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_42};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3202 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1351};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3203 = { 10 | NIM_STRLIT_FLAG, "Sup.m_type" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3204 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3203};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3205 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2066};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3206 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3207 = { 25 | NIM_STRLIT_FLAG, "nimBorrowCurrentException" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3208 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3207};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3209 = { 4 | NIM_STRLIT_FLAG, "()->" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3210 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3209};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3211 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3212 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3213 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3214 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2920};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3215 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3216 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3207};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3217 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3209};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3218 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3219 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3220 = { 5 | NIM_STRLIT_FLAG, "else " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3221 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3220};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3222 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3223 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3063};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3224 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3225 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3198};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3226 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3227 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3228 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3229 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3230 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3231 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3193};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3232 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3233 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3234 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3235 = { 21 | NIM_STRLIT_FLAG, "NIM_BOOL oldNimErrFin" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3236 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3235};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3237 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1568};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3238 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3239 = { 12 | NIM_STRLIT_FLAG, "oldNimErrFin" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3240 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3239};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3241 = { 35 | NIM_STRLIT_FLAG, "_ = *nimErr_; *nimErr_ = NIM_FALSE;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3242 = {35, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3241};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3243 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3244 = { 23 | NIM_STRLIT_FLAG, "*nimErr_ = oldNimErrFin" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3245 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3244};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3246 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1568};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3247 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3248 = { 11 | NIM_STRLIT_FLAG, "<exception>" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3249 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3248};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3250 = { 20 | NIM_STRLIT_FLAG, "std::exception_ptr T" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3251 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3250};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3252 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1568};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3253 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3254 = { 5 | NIM_STRLIT_FLAG, "try {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3255 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3254};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3256 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3257 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3258 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3259 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3254};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3260 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3261 = { 7 | NIM_STRLIT_FLAG, "catch (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3262 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3261};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3263 = { 9 | NIM_STRLIT_FLAG, "Exception" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3264 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3263};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3265 = { 3 | NIM_STRLIT_FLAG, "* T" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3266 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3265};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3267 = { 4 | NIM_STRLIT_FLAG, "_) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3268 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3267};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3269 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3270 = { 22 | NIM_STRLIT_FLAG, "\011TFrame* _nimCurFrame;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3271 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3270};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3272 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3273 = { 16 | NIM_STRLIT_FLAG, "\011_nimCurFrame = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3274 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3273};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3275 = { 8 | NIM_STRLIT_FLAG, "getFrame" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3276 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3275};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3277 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3278 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3279 = { 8 | NIM_STRLIT_FLAG, "setFrame" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3280 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3279};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3281 = { 15 | NIM_STRLIT_FLAG, "(_nimCurFrame);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3282 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3281};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3283 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3284 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_373};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3285 = { 29 | NIM_STRLIT_FLAG, "_ = std::current_exception();" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3286 = {29, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3285};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3287 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3288 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3289 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3290 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3291 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3292 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3293 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_42};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3294 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1351};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3295 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3203};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3296 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2066};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3297 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3298 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3207};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3299 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3209};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3300 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3301 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3302 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3303 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2920};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3304 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3305 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3207};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3306 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3209};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3307 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3308 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3309 = { 9 | NIM_STRLIT_FLAG, "else if (" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3310 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3309};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3311 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3063};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3312 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3313 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3314 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3063};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3315 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3316 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3317 = { 4 | NIM_STRLIT_FLAG, " = T" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3318 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3317};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3319 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1568};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3320 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3321 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_373};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3322 = { 12 | NIM_STRLIT_FLAG, "_ = nullptr;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3323 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3322};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3324 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3325 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3326 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3327 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3328 = { 11 | NIM_STRLIT_FLAG, "else throw;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3329 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3328};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3330 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3331 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3332 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3333 = { 13 | NIM_STRLIT_FLAG, "catch (...) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3334 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3333};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3335 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3336 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3261};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3337 = { 2 | NIM_STRLIT_FLAG, "& " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3338 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3337};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3339 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3063};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3340 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3341 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3261};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3342 = { 4 | NIM_STRLIT_FLAG, "&) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3343 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3342};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3344 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3345 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3333};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3346 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3347 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_373};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3348 = {29, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3285};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3349 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3350 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3351 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3352 = { 5 | NIM_STRLIT_FLAG, "if (T" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3353 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3352};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3354 = { 27 | NIM_STRLIT_FLAG, "_) std::rethrow_exception(T" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3355 = {27, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3354};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3356 = { 3 | NIM_STRLIT_FLAG, "_);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3357 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3356};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3358 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3359 = { 10 | NIM_STRLIT_FLAG, "<setjmp.h>" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3360 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3359};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3361 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3263};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3362 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3363 = { 10 | NIM_STRLIT_FLAG, "TSafePoint" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3364 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3363};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3365 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3366 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_101};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3367 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3368 = { 13 | NIM_STRLIT_FLAG, "pushSafePoint" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3369 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3368};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3370 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3371 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3372 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3373 = { 12 | NIM_STRLIT_FLAG, "nimStdSetjmp" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3374 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3373};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3375 = { 17 | NIM_STRLIT_FLAG, ".status = setjmp(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3376 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3375};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3377 = { 10 | NIM_STRLIT_FLAG, ".context);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3378 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3377};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3379 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3380 = { 12 | NIM_STRLIT_FLAG, "nimSigSetjmp" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3381 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3380};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3382 = { 20 | NIM_STRLIT_FLAG, ".status = sigsetjmp(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3383 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3382};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3384 = { 13 | NIM_STRLIT_FLAG, ".context, 0);" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3385 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3384};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3386 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3387 = { 16 | NIM_STRLIT_FLAG, "nimBuiltinSetjmp" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3388 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3387};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3389 = { 27 | NIM_STRLIT_FLAG, ".status = __builtin_setjmp(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3390 = {27, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3389};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3391 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3377};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3392 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3393 = { 12 | NIM_STRLIT_FLAG, "nimRawSetjmp" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3394 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3393};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3395 = { 9 | NIM_STRLIT_FLAG, "mswindows" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3396 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3395};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3397 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3173};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3398 = { 7 | NIM_STRLIT_FLAG, "clangcl" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3399 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3400 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3375};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3401 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3377};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3402 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3403 = { 18 | NIM_STRLIT_FLAG, ".status = _setjmp(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3404 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3403};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3405 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3384};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3406 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3407 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3403};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3408 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3377};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3409 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3410 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3375};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3411 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3377};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3412 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3413 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3414 = { 15 | NIM_STRLIT_FLAG, ".status == 0) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3415 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3414};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3416 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3417 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3133};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3418 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3419 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3420 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_462};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3421 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3422 = { 6 | NIM_STRLIT_FLAG, "else {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3423 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3422};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3424 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3425 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3133};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3426 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3427 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3428 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3429 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3207};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3430 = { 5 | NIM_STRLIT_FLAG, "()) {" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3431 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3430};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3432 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3433 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3434 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3435 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3436 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3437 = { 12 | NIM_STRLIT_FLAG, ".status = 0;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3438 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3437};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3439 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3440 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3441 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3442 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3443 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_42};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3444 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1351};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3445 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3203};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3446 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2066};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3447 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3448 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3207};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3449 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3209};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3450 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3451 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3452 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3453 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2920};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3454 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3455 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3207};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3456 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3209};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3457 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3458 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_68};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3459 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3220};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3460 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3461 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3063};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3462 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3463 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3437};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3464 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3465 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3137};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3466 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3467 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3468 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3469 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3470 = { 15 | NIM_STRLIT_FLAG, "nimLeaveFinally" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3471 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3470};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3472 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3473 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3142};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3474 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3470};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3475 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3476 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3477 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_905};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3478 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3142};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3479 = { 16 | NIM_STRLIT_FLAG, "reraiseException" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3480 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3479};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3481 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3482 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3483 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3484 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3485 = { 16 | NIM_STRLIT_FLAG, "raiseExceptionEx" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3486 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3485};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3487 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_56};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3488 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3263};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3489 = { 2 | NIM_STRLIT_FLAG, "*)" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3490 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3489};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3491 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3492 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3493 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3494 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3495 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3496 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3497 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1124};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3498 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3499 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3479};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3500 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3501 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3502 = { 15 | NIM_STRLIT_FLAG, "/*TYPESECTION*/" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3503 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3502};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3504 = { 14 | NIM_STRLIT_FLAG, "/*VARSECTION*/" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3505 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3504};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3506 = { 18 | NIM_STRLIT_FLAG, "/*INCLUDESECTION*/" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3507 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3506};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3508 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_42};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3509 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_12};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3510 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3512 = { 5 | NIM_STRLIT_FLAG, "STATE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3513 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3512};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3514 = { 3 | NIM_STRLIT_FLAG, ": ;" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3515 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3514};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3516 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3517 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3514};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3518 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3519 = { 5 | NIM_STRLIT_FLAG, "STATE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3520 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3519};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3521 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1731};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3522 = { 20 | NIM_STRLIT_FLAG, "); unknown node kind" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3523 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3522};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3526 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3527 = { 16 | NIM_STRLIT_FLAG, "nimTestErrorFlag" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3528 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3529 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3527};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3530 = { 17 | NIM_STRLIT_FLAG, "NimDestroyGlobals" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3531 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3530};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3532 = { 13 | NIM_STRLIT_FLAG, "programResult" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3533 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3532};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3534 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_53};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3535 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_93};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3536 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_137};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3537 = { 13 | NIM_STRLIT_FLAG, "procAddrError" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3538 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3537};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3539 = { 8 | NIM_STRLIT_FLAG, "rawWrite" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3540 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3539};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3541 = { 19 | NIM_STRLIT_FLAG, "initStackBottomWith" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3542 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3541};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3543 = { 23 | NIM_STRLIT_FLAG, "initThreadVarsEmulation" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3544 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3543};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3545 = { 17 | NIM_STRLIT_FLAG, "still forwarded: " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3546 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3545};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3548 = { 13 | NIM_STRLIT_FLAG, "NimMainModule" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3549 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3548};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3550 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3551 = { 7 | NIM_STRLIT_FLAG, "Init000" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3552 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3551};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3553 = { 12 | NIM_STRLIT_FLAG, "N_LIB_EXPORT" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3554 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3553};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3555 = { 13 | NIM_STRLIT_FLAG, "N_LIB_PRIVATE" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3556 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3555};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3557 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3558 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_475};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3559 = { 2 | NIM_STRLIT_FLAG, "* " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3560 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3559};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3561 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_566};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3562 = { 19 | NIM_STRLIT_FLAG, "\011hcrRegisterGlobal(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3563 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3562};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3564 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1500};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3565 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_4};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3566 = { 22 | NIM_STRLIT_FLAG, "\", sizeof(TNimNode) * " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3567 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3566};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3568 = { 17 | NIM_STRLIT_FLAG, ", NULL, (void**)&" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3569 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3568};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3570 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1672};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3571 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3572 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_475};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3573 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3574 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3575 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_738};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3576 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3577 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_204};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3578 = {8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_473};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3579 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3580 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_536};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3581 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_738};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3582 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3583 = { 26 | NIM_STRLIT_FLAG, "\011TFrame FR_; FR_.len = 0;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3584 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3583};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3585 = { 26 | NIM_STRLIT_FLAG, "\011if (nim_hcr_do_init_) {\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3586 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3585};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3587 = { 24 | NIM_STRLIT_FLAG, "\012\011} // nim_hcr_do_init_\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3588 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3587};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3589 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3585};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3590 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3587};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3591 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3585};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3592 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3587};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3593 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3585};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3594 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3587};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3595 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3583};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3596 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3585};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3597 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3587};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3598 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3585};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3599 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3587};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3600 = { 15 | NIM_STRLIT_FLAG, "\011BeforeRet_: ;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3601 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3600};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3602 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3603 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3604 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3527};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3605 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1172};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3606 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3607 = { 15 | NIM_STRLIT_FLAG, "hcrRegisterProc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3608 = {15, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3607};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3609 = { 10 | NIM_STRLIT_FLAG, "hcrGetProc" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3610 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3609};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3611 = { 17 | NIM_STRLIT_FLAG, "hcrRegisterGlobal" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3612 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3611};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3613 = { 12 | NIM_STRLIT_FLAG, "hcrGetGlobal" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3614 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3613};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3615 = { 10 | NIM_STRLIT_FLAG, "HcrInit000" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3616 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3615};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3617 = { 7 | NIM_STRLIT_FLAG, "hcrInit" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3618 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3617};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3619 = { 12 | NIM_STRLIT_FLAG, "hcrAddModule" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3620 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3619};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3621 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3622 = { 6 | NIM_STRLIT_FLAG, "handle" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3623 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3622};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3624 = { 11 | NIM_STRLIT_FLAG, "getProcAddr" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3625 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3624};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3626 = {12, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3553};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3627 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3555};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3628 = { 10 | NIM_STRLIT_FLAG, "DatInit000" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3629 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3628};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3630 = { 13 | NIM_STRLIT_FLAG, "stdlib_system" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3631 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3630};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3632 = { 9 | NIM_STRLIT_FLAG, "stdlib_os" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3633 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3632};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3634 = { 17 | NIM_STRLIT_FLAG, "\011int* cmd_count;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3635 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3634};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3636 = { 19 | NIM_STRLIT_FLAG, "\011char*** cmd_line;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3637 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3636};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3638 = { 24 | NIM_STRLIT_FLAG, "\011*cmd_count = cmdCount;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3639 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3638};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3640 = { 22 | NIM_STRLIT_FLAG, "\011*cmd_line = cmdLine;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3641 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3640};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3642 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3643 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3543};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3644 = { 4 | NIM_STRLIT_FLAG, "();\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3645 = {4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3644};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3646 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3647 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3541};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3648 = { 18 | NIM_STRLIT_FLAG, "((void *)&inner);\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3649 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3648};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3650 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_179};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3651 = { 19 | NIM_STRLIT_FLAG, "_Content { NI cap; " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3652 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3651};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3653 = { 25 | NIM_STRLIT_FLAG, " data[SEQ_DECL_SIZE]; };\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3654 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3653};
N_LIB_PRIVATE TNimTypeV2 NTIv2__JS0sf27XzZG7UDuztDBfOw_;
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3656 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3657 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3658 = { 7 | NIM_STRLIT_FLAG, "\011if (!(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3659 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3658};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3660 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_46};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3661 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_53};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3662 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3663 = { 6 | NIM_STRLIT_FLAG, ")))\012\011\011" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3664 = {6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3663};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3665 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_93};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3666 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_44};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3667 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1672};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3668 = { 10 | NIM_STRLIT_FLAG, "hcr_handle" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3669 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3668};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3670 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3609};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3672 = { 19 | NIM_STRLIT_FLAG, "\011void* rtl_handle;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3673 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3672};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3674 = { 10 | NIM_STRLIT_FLAG, "rtl_handle" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3675 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3674};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3676 = { 20 | NIM_STRLIT_FLAG, "nimGC_setStackBottom" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3677 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3676};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3679 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3676};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3680 = { 7 | NIM_STRLIT_FLAG, "nimrtl_" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3681 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3680};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3682 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3674};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3683 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_137};
static const struct {
  NI cap; NIM_CHAR data[45+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3684 = { 45 | NIM_STRLIT_FLAG, "\011initStackBottomWith_actual((void *)&inner);\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3685 = {45, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3684};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3686 = { 13 | NIM_STRLIT_FLAG, "\011(*inner)();\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3687 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3686};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3688 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3689 = { 28 | NIM_STRLIT_FLAG, "N_LIB_PRIVATE int cmdCount;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3690 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3689};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3691 = { 30 | NIM_STRLIT_FLAG, "N_LIB_PRIVATE char** cmdLine;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3692 = {30, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3691};
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3693 = { 27 | NIM_STRLIT_FLAG, "N_LIB_PRIVATE char** gEnv;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3694 = {27, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3693};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3695 = { 11 | NIM_STRLIT_FLAG, "<windows.h>" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3696 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3695};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3697 = { 18 | NIM_STRLIT_FLAG, "<libc/component.h>" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3698 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3697};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3699 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3700 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3701 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3541};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3702 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3648};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3703 = { 1 | NIM_STRLIT_FLAG, "1" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3704 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3703};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3705 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_507};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3706 = { 20 | NIM_STRLIT_FLAG, "\012N_LIB_PRIVATE void " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3707 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3706};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3708 = { 21 | NIM_STRLIT_FLAG, "PreMainInner(void) {\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3709 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3708};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3710 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1188};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3711 = { 19 | NIM_STRLIT_FLAG, "N_LIB_PRIVATE void " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3712 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3711};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3713 = { 20 | NIM_STRLIT_FLAG, "PreMain(void) {\012#if " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3714 = {20, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3713};
static const struct {
  NI cap; NIM_CHAR data[41+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3715 = { 41 | NIM_STRLIT_FLAG, "\012\011void (*volatile inner)(void);\012\011inner = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3716 = {41, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3715};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3717 = { 14 | NIM_STRLIT_FLAG, "PreMainInner;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3718 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3717};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3719 = { 19 | NIM_STRLIT_FLAG, "\011(*inner)();\012#else\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3720 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3719};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3721 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3722 = { 26 | NIM_STRLIT_FLAG, "PreMainInner();\012#endif\012}\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3723 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3722};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3724 = { 28 | NIM_STRLIT_FLAG, "N_LIB_PRIVATE N_CDECL(void, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3725 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3724};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3726 = { 22 | NIM_STRLIT_FLAG, "NimMainInner)(void) {\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3727 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3726};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3728 = { 17 | NIM_STRLIT_FLAG, "}\012\012N_CDECL(void, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3729 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3728};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3730 = { 21 | NIM_STRLIT_FLAG, "NimMain)(void) {\012#if " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3731 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3730};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3732 = { 32 | NIM_STRLIT_FLAG, "\012\011void (*volatile inner)(void);\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3733 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3732};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3734 = { 9 | NIM_STRLIT_FLAG, "\011inner = " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3735 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3734};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3736 = { 14 | NIM_STRLIT_FLAG, "NimMainInner;\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3737 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3738 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3719};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3739 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3740 = { 26 | NIM_STRLIT_FLAG, "NimMainInner();\012#endif\012}\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3741 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3740};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3742 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3724};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3743 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3726};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3744 = { 30 | NIM_STRLIT_FLAG, "}\012\012N_LIB_EXPORT N_CDECL(void, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3745 = {30, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3744};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3746 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3730};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3747 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3732};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3748 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3734};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3749 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3750 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3719};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3751 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3752 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3740};
static const struct {
  NI cap; NIM_CHAR data[121+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3753 = { 121 | NIM_STRLIT_FLAG, "extern Genode::Env *nim_runtime_env;\012extern \"C\" void nim_component_construct(Genode::Env*);\012\012N_LIB_PRIVATE N_CDECL(void, " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3754 = {121, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3753};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3755 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3726};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3756 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3728};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3757 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3730};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3758 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3732};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3759 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3734};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3760 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3761 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3719};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3762 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3763 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3740};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3764 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3724};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3765 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3726};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3766 = {30, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3744};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3767 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3730};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3768 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3732};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3769 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3734};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3770 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3771 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3719};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3772 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3773 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3740};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3774 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3724};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3775 = {22, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3726};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3776 = {17, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3728};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3777 = {21, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3730};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3778 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3732};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3779 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3734};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3780 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3736};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3781 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3719};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3782 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_131};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3783 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3740};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3784 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_721};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3785 = { 16 | NIM_STRLIT_FLAG, "using namespace " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3786 = {16, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3785};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3787 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_566};
static const struct {
  NI cap; NIM_CHAR data[157+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3788 = { 157 | NIM_STRLIT_FLAG, "N_STDCALL(int, WinMain)(HINSTANCE hCurInstance, \012                        HINSTANCE hPrevInstance, \012                        LPSTR lpCmdLine, int nCmdShow) {\012\011" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3789 = {157, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3788};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3790 = { 19 | NIM_STRLIT_FLAG, "NimMain();\012\011return " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3791 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3790};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3792 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3793 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3794 = { 23 | NIM_STRLIT_FLAG, "nim_program_result;\012}\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3795 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3794};
static const struct {
  NI cap; NIM_CHAR data[141+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3796 = { 141 | NIM_STRLIT_FLAG, "BOOL WINAPI DllMain(HINSTANCE hinstDLL, DWORD fwdreason, \012                    LPVOID lpvReserved) {\012\011if (fwdreason == DLL_PROCESS_ATTACH) {\012\011" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3797 = {141, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3796};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3798 = { 28 | NIM_STRLIT_FLAG, "NimMain();\012\011}\012\011return 1;\012}\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3799 = {28, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3798};
static const struct {
  NI cap; NIM_CHAR data[185+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3800 = { 185 | NIM_STRLIT_FLAG, "void Libc::Component::construct(Libc::Env &env) {\012\011// Set Env used during runtime initialization\012\011nim_runtime_env = &env;\012\011Libc::with_libc([&] () {\012\011\011// Initialize runtime and globals\012\011" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3801 = {185, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3800};
static const struct {
  NI cap; NIM_CHAR data[83+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3802 = { 83 | NIM_STRLIT_FLAG, "NimMain();\012\011// Call application construct\012\011\011nim_component_construct(&env);\012\011});\012}\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3803 = {83, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3802};
static const struct {
  NI cap; NIM_CHAR data[55+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3804 = { 55 | NIM_STRLIT_FLAG, "N_LIB_PRIVATE void NIM_POSIX_INIT NimMainInit(void) {\012\011" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3805 = {55, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3804};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3806 = { 14 | NIM_STRLIT_FLAG, "NimMain();\012}\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3807 = {14, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3806};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3808 = { 18 | NIM_STRLIT_FLAG, "int main(void) {\012\011" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3809 = {18, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3808};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3810 = { 25 | NIM_STRLIT_FLAG, "NimMain();\012\011return 0;\012}\012\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3811 = {25, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3810};
static const struct {
  NI cap; NIM_CHAR data[95+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3812 = { 95 | NIM_STRLIT_FLAG, "int main(int argc, char** args, char** env) {\012\011cmdLine = args;\012\011cmdCount = argc;\012\011gEnv = env;\012\011" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3813 = {95, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3812};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3814 = {19, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3790};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3815 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3816 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3817 = {23, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3794};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3818 = { 10 | NIM_STRLIT_FLAG, "namespace " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3819 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3818};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3820 = { 3 | NIM_STRLIT_FLAG, " {\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3821 = {3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3820};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3822 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1398};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3823 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3825 = { 6 | NIM_STRLIT_FLAG, "2.2.10" };
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3826 = { 31 | NIM_STRLIT_FLAG, "#define NIM_HOT_CODE_RELOADING\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3827 = {31, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3826};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3828 = { 26 | NIM_STRLIT_FLAG, "#define USE_NIM_NAMESPACE " };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3829 = {26, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3828};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3830 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3831 = { 24 | NIM_STRLIT_FLAG, "nimEmulateOverflowChecks" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3832 = {24, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3831};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3833 = { 34 | NIM_STRLIT_FLAG, "#define NIM_EmulateOverflowChecks\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3834 = {34, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3833};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3835 = { 9 | NIM_STRLIT_FLAG, "nimbase.h" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3836 = {9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3835};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3837 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const struct {
  NI cap; NIM_CHAR data[170+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3838 = { 170 | NIM_STRLIT_FLAG, "#undef LANGUAGE_C\012#undef MIPSEB\012#undef MIPSEL\012#undef PPC\012#undef R3000\012#undef R4000\012#undef i386\012#undef linux\012#undef mips\012#undef near\012#undef far\012#undef powerpc\012#undef unix\012" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3839 = {170, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3838};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3840 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3841 = { 11 | NIM_STRLIT_FLAG, "#define FX_" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3842 = {11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3841};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3843 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_25};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3844 = {1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_14};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3845 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3846 = {0, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_8};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3847 = {5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1494};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3848 = { 7 | NIM_STRLIT_FLAG, "nimln_(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3849 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3848};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3850 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3851 = { 7 | NIM_STRLIT_FLAG, "nimlf_(" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3852 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3851};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3853 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_121};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3854 = {2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_112};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__MQdRN7fpbG7rPm4JpVVAhA_3855 = { 32 | NIM_STRLIT_FLAG, "unexpected postprocess directive" };
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3856 = {32, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3855};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3859 = {13, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_326};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3861 = {10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3628};
static const NimStringV2 TM__MQdRN7fpbG7rPm4JpVVAhA_3862 = {7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3551};
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_31 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)867),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_39 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)837),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_50 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)953),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_87 = {{66, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_88},
((NI)118),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_117 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)870),
((NI)34)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_127 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)902),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_130 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)909),
((NI)19)}
;
extern NIM_CONST tyArray__RQFn3NKTp5P7VzZ9bksPIyA OS__platform_u534;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_159 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)168),
((NI)32)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_169 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)412),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_173 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)430),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_245 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)553),
((NI)42)}
;
static NIM_CONST tySequence__lBgZ7a89beZGYPl8PiANMTA TM__MQdRN7fpbG7rPm4JpVVAhA_251 = {2, (tySequence__lBgZ7a89beZGYPl8PiANMTA_Content*)&TM__MQdRN7fpbG7rPm4JpVVAhA_252};
N_LIB_PRIVATE NIM_CONST tyArray__uE8Y0xae4ilky52M2Sfl4Q CallingConvToStr__cgen_u1465 = {{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_282},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_283},
{7, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_284},
{10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_285},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_286},
{8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_287},
{10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_288},
{10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_289},
{10, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_290},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_291},
{8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_292},
{8, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_292}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_299 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)608),
((NI)42)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_337 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)1216),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_443 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1606),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_451 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1684),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_504 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1891),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_505 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1893),
((NI)4)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_542 = {{62, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_543},
((NI)34),
((NI)42)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_547 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)710),
((NI)40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_554 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)678),
((NI)32)}
;
extern NIM_CONST tyArray__LheWFUTR89bV9bcpnmBZNQig CC__extccomp_u624;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_572 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)728),
((NI)25)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_590 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)761),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_595 = {{62, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_543},
((NI)39),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_618 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)110),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_621 = {{62, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_543},
((NI)56),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_623 = {{62, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_543},
((NI)58),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_670 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1415),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_675 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1324),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_678 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1367),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_681 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1383),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_684 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1397),
((NI)25)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_686 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1405),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_688 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1410),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_690 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1929),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_696 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1731),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_710 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3469),
((NI)21)}
;
extern NIM_CONST tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg Zero__int128_u8;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_809 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3357),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_823 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3292),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_832 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3507),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_938 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)387),
((NI)8)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1004 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)323),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1031 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)425),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1057 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)574),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1101 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1102},
((NI)25),
((NI)42)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1105 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1102},
((NI)29),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1107 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1102},
((NI)47),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1109 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1102},
((NI)49),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1153 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)998),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1247 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)939),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1249 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)946),
((NI)14)}
;
N_LIB_PRIVATE NIM_CONST tyArray__wgmwCG2MY84OFtPmYaVG9bA NumericalTypeToStr__cgen_u1921 = {{2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1263},
{3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1264},
{4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1265},
{4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1266},
{4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1267},
{2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1268},
{4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1269},
{4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1270},
{5, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1271},
{2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1272},
{3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1273},
{4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1274},
{4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1275},
{4, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1276}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1280 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)365),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1295 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)942),
((NI)29)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1326 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1025),
((NI)10)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1392 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_32},
((NI)1094),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1407 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3009),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1410 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3017),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1422 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)278),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1446 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)347),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1457 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)684),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1460 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)692),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1627 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)242),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1637 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)296),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1639 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)297),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1644 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)59),
((NI)13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1653 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)731),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1659 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)695),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1660 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)639),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1700 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)775),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1707 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1058},
((NI)794),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1721 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3044),
((NI)8)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1726 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3063),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1730 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3070),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1735 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3072),
((NI)23)}
;
N_LIB_PRIVATE NIM_CONST tyArray__Seu7uK9aaOSN0BK3EAjjSHw opr__cgen_u25525 = {{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1753},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1525},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_149}}
;
N_LIB_PRIVATE NIM_CONST tyArray__hFPV9bffMpPjoz9bsO9crekNg opr__cgen_u21255 = {{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1753},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1525},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_186},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_149},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1781},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1753},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1525}}
;
N_LIB_PRIVATE NIM_CONST tyArray__hFPV9bffMpPjoz9bsO9crekNg prc64__cgen_u21254 = {{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1795},
{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1796},
{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1797},
{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1798},
{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1799},
{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1795},
{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1796}}
;
N_LIB_PRIVATE NIM_CONST tyArray__hFPV9bffMpPjoz9bsO9crekNg prc__cgen_u21253 = {{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1800},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1801},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1802},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1803},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1804},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1800},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1801}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1826 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1777),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1861 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1812),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1874 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1821),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1879 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1256),
((NI)39)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1896 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)513),
((NI)34)}
;
N_LIB_PRIVATE NIM_CONST tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ opr__cgen_u25885 = {{2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1901},
{2, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1902}}
;
N_LIB_PRIVATE NIM_CONST tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ fun64__cgen_u25886 = {{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1795},
{11, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1796}}
;
N_LIB_PRIVATE NIM_CONST tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ fun__cgen_u25887 = {{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1800},
{9, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1801}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_1950 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)519),
((NI)34)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2065 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1753),
((NI)15)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2105 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1410),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2235 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)2575),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2276 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1935),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2279 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)525),
((NI)34)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2300 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1981),
((NI)36)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2378 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)2134),
((NI)23)}
;
N_LIB_PRIVATE NIM_CONST tyArray__A2YC0h9cZydgH7zGAndH9bLg lookupOpr__cgen_u24609 = {{88, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2439},
{133, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2440},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1283},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2441},
{3, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2442},
{1, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_2443}}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2446 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)2171),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2447 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1223),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2520 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)2629),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2523 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)2644),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2568 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)475),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2636 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)2438),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2646 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)2666),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2657 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)2780),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2668 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)882),
((NI)33)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2671 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1532),
((NI)43)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2775 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1035),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2834 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)864),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2837 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)1146),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2840 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)791),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2843 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)849),
((NI)38)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2847 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)906),
((NI)45)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2850 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)990),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2891 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)502),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2980 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3148),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2983 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)556),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2986 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)560),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2989 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)564),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2992 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)568),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_2995 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)571),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3000 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)594),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3012 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)75),
((NI)40)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3021 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)115),
((NI)44)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3037 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3165),
((NI)29)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3115 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)527),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3151 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)739),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3166 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)1679),
((NI)11)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3177 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)1590),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3511 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)197),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3524 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_619},
((NI)3243),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3525 = {{63, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_1423},
((NI)1711),
((NI)2)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3547 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)2368),
((NI)19)}
;
static NIM_CONST tyArray__YgExxhfgKcesA5EOUj1MOA TM__MQdRN7fpbG7rPm4JpVVAhA_3824 = {{6, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_3825}}
;
extern NIM_CONST tyArray__BJ38CrWfGxMtyd3CSynibg CPU__platform_u740;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3857 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)2228),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3858 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)2236),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__MQdRN7fpbG7rPm4JpVVAhA_3860 = {{59, (NimStrPayload*)&TM__MQdRN7fpbG7rPm4JpVVAhA_40},
((NI)2146),
((NI)14)}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static NIM_CONST NU32 TM__MQdRN7fpbG7rPm4JpVVAhA_3655[2] = {3701606400, 757890816};
N_LIB_PRIVATE TNimTypeV2 NTIv2__JS0sf27XzZG7UDuztDBfOw_ = {.destructor = (void*)rttiDestroy__cgen_u34938, .size = sizeof(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw), .align = (NI16) NIM_ALIGNOF(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw), .depth = 1, .display = TM__MQdRN7fpbG7rPm4JpVVAhA_3655, .traceImpl = (void*)eqtrace___cgen_u34876, .flags = 0};
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initPackedSet__pureZcollectionsZintsets_u37(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NimStringV2, newRopeAppender__ropes_u7)(NI cap_p0) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	result = rawNewString((cap_p0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ, initProcOptions__cgen_u30744)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ result;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ colontmpD_;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ colontmpD__2;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ opts_1;
	nimZeroMem((void*)(&colontmpD_), sizeof(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ));
	nimZeroMem((void*)(&colontmpD__2), sizeof(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ));
	opts_1 = (*(*(*m_p0).g).config).options;
	{
		if (!(((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0)) goto LA3_;
		colontmpD_ = (opts_1 & ~ 131072);
		result = colontmpD_;
	}
	goto LA1_;
LA3_: ;
	{
		colontmpD__2 = opts_1;
		result = colontmpD__2;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTempName__cgen_u462)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	colontmpD_ = rope__ropes_u15(((NI64) ((*m_p0).labels)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = rawNewString((*m_p0).tmpBase.len + colontmpD_.len + 0);
appendString((&T1_), (*m_p0).tmpBase);
appendString((&T1_), colontmpD_);
	result = T1_;
	(*m_p0).labels += ((NI)1);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, rawNewModule__cgen_u30756)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, NimStringV2 filename_p2) {
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* result;
	NimStringV2 colontmpD_;
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* T1_;
	NimStringV2 T2_;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T3_;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ T4_;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA T5_;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA T6_;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA T7_;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA T8_;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA T9_;
	tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA T10_;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* T11_;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T16_;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* T17_;
	tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g T18_;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg T19_;
	NimStringV2 T20_;
	NimStringV2 T21_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) nimNewObj(sizeof(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA), NIM_ALIGNOF(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA));
	(*T1_).Sup.Sup.m_type = (&NTIv2__GJ2TTG82D4z6i8QsbkLlYA_);
	(*T1_).labels = ((NI)0);
	result = T1_;
	eqcopy___cgendata_u2194(&(*result).g, g_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_.len = 0; T2_.p = NIM_NIL;
	nimZeroMem((void*)T3_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	hashOwner__sighashes_u491(module_p1, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = dollar___modulegraphs_u10732(T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = rawNewString(colontmpD_.len + 3);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_3);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_5);
	eqsink___system_u2700((&(*result).tmpBase), T2_);
	T4_.len = 0; T4_.p = NIM_NIL;
	T4_.len = 0; T4_.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	eqsink___system_u5515((&(*result).headerFiles), T4_);
	nimZeroMem((void*)(&T5_), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&T5_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___pureZcollectionsZintsets_u236((&(*result).declaredThings), (&T5_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T6_), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&T6_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___pureZcollectionsZintsets_u236((&(*result).declaredProtos), (&T6_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___system_u2694((&(*result).cfilename), filename_p2);
	eqcopy___system_u2694((&(*result).filename), filename_p2);
	T7_ = initTable__cgen_u30780(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgen_u30801(T7_); goto BeforeRet_;}
	eqsink___cgen_u30810((&(*result).typeCache), T7_);
	T8_ = initTable__cgen_u30780(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgen_u30801(T8_); goto BeforeRet_;}
	eqsink___cgen_u30810((&(*result).forwTypeCache), T8_);
	eqcopy___ast_u4577(&(*result).module, module_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T9_ = initTable__cgen_u30780(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgen_u30801(T9_); goto BeforeRet_;}
	eqsink___cgen_u30810((&(*result).typeInfoMarker), T9_);
	T10_ = initCountTable__cgen_u30860(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgen_u30879(T10_); goto BeforeRet_;}
	eqsink___cgen_u30888((&(*result).sigConflicts), T10_);
	T11_ = NIM_NIL;
	T11_ = newProc__cgendata_u509(((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), result);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgendata_u2071(T11_); goto BeforeRet_;}
	eqsink___cgendata_u2082(&(*result).initProc, T11_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ i_1;
		NI res_1;
		i_1 = (tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0;
		res_1 = ((NI)0);
		{
			while (1) {
				NimStringV2 T15_;
				if (!(res_1 <= ((NI)15))) goto LA14;
				i_1 = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ) (res_1));
				T15_.len = 0; T15_.p = NIM_NIL;
				T15_ = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto BeforeRet_;}
				eqsink___system_u2700((&(*result).s[(i_1)- 0]), T15_);
				res_1 += ((NI)1);
			} LA14: ;
		}
	}
	nimZeroMem((void*)(&T16_), sizeof(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ));
	T16_ = initProcOptions__cgen_u30744(result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*(*result).initProc).options = T16_;
	T17_ = NIM_NIL;
	T17_ = newProc__cgendata_u509(((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), result);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgendata_u2071(T17_); goto BeforeRet_;}
	eqsink___cgendata_u2082(&(*result).preInitProc, T17_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*(*result).preInitProc).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)6))) & 7);
	(*(*result).preInitProc).labels = ((NI)100000);
	T18_ = initNodeTable__ast_u6397(NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6529(T18_); goto BeforeRet_;}
	eqsink___ast_u6538((&(*result).dataCache), T18_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T19_.len = 0; T19_.p = NIM_NIL;
	T19_.len = 0; T19_.p = (tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content*) newSeqPayload(0, sizeof(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*), NIM_ALIGNOF(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*));
	eqsink___ast_u3320((&(*result).typeStack), T19_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T20_.len = 0; T20_.p = NIM_NIL;
	T20_ = getTempName__cgen_u462(result);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T20_); goto BeforeRet_;}
	eqsink___system_u2700((&(*result).typeNodesName), T20_);
	T21_.len = 0; T21_.p = NIM_NIL;
	T21_ = getTempName__cgen_u462(result);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T21_); goto BeforeRet_;}
	eqsink___system_u2700((&(*result).nimTypesName), T21_);
	{
		if (!(((*module_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0)) goto LA24_;
		(*result).flags |= ((NU8)1)<<(((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)0))) & 7);
		(*(*result).preInitProc).options &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17))) & 31));
	}
LA24_: ;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, rawNewModule__cgen_u30931)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2) {
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = toFullPath__msgs_u624(conf_p2, ((NI32) ((*module_p1).position)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = rawNewModule__cgen_u30756(g_p0, module_p1, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, newModule__cgen_u30936)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2) {
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = rawNewModule__cgen_u30931(g_p0, module_p1, conf_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI T3_;
		T3_ = (*g_p0).modules.len;
		if (!(T3_ <= (*module_p1).position)) goto LA4_;
		setLen__cgendata_u1560((&(*g_p0).modules), ((NI)((*module_p1).position + ((NI)1))));
	}
LA4_: ;
	eqcopy___cgendata_u721(&(*g_p0).modules.p->data[(*module_p1).position], result, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, setupCgen__cgen_u30949)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2) {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* result;
	tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_1;
	RootObj* colontmpD_;
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* T7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	g_1 = NIM_NIL;
	{
		tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* T6_;
		if (!((*graph_p0).backend == ((RootObj*) NIM_NIL))) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = newModuleList__cgendata_u2124(graph_p0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgendata_u2191(T6_); goto LA1_;}
		eqsink___ast_u4955(&(*graph_p0).backend, &T6_->Sup);
	}
LA4_: ;
	colontmpD_ = eqdup___ast_u4951((*graph_p0).backend, NIM_TRUE);
	g_1 = (*((tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g**) (&(colontmpD_))));
	T7_ = NIM_NIL;
	T7_ = newModule__cgen_u30936(g_1, module_p1, (*graph_p0).config);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgendata_u718(T7_); goto LA1_;}
	result = &T7_->Sup;
	eqcopy___ast_u3103(&(*result).idgen, idgen_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T10_;
		NimStringV2 f_1;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T15_;
		tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* T21_;
		T10_ = (NIM_BOOL)0;
		T10_ = (((*(*graph_p0).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)29)))&63U)))!=0);
		if (!(T10_)) goto LA11_;
		T10_ = ((*g_1).generatedHeader == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL));
LA11_: ;
		if (!T10_) goto LA12_;
		f_1.len = 0; f_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T15_.len = 0; T15_.p = NIM_NIL;
		{
			NimStringV2 colontmpD__4;
			if (!(((NI)0) < (*(*graph_p0).config).headerFile.len)) goto LA18_;
			colontmpD__4 = eqdup___system_u2697((*(*graph_p0).config).headerFile);
			f_1 = colontmpD__4;
		}
		goto LA16_;
LA18_: ;
		{
			eqcopy___system_u2694((&f_1), (*(*graph_p0).config).projectFull);
		}
LA16_: ;
		colontmpD__2 = completeCfilePath__extccomp_u929((*graph_p0).config, f_1, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__3 = noschangeFileExt(colontmpD__2, TM__MQdRN7fpbG7rPm4JpVVAhA_7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T21_ = NIM_NIL;
		T21_ = rawNewModule__cgen_u30756(g_1, module_p1, colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___cgendata_u718(T21_); goto LA14_;}
		eqsink___cgendata_u729(&(*g_1).generatedHeader, T21_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		(*(*g_1).generatedHeader).flags |= ((NU8)1)<<(((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)3))) & 7);
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(f_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA12_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u2191(g_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, skipCodegen__pipelineutils_u8)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
	result = (((NI)0) < (*config_p0).errorCounter);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__cgen_u49)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hcrOn__options_u629((*(*m_p0).g).config);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, blockBody__cgen_u16177)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* b_p0, NimStringV2* result_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	prepareAdd((&(*result_p1)), (*b_p0).sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0))- 0].len + 0);
appendString((&(*result_p1)), (*b_p0).sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0))- 0]);
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T5_;
		if (!(((NI16)0) < (*b_p0).frameLen)) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD_ = rope__ropes_u15(((NI64) ((*b_p0).frameLen)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T5_[0] = colontmpD_;
		colontmpD__2 = percent___cgen_u16180(T5_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p1)), colontmpD__2.len + 0);
appendString((&(*result_p1)), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA3_: ;
	prepareAdd((&(*result_p1)), (*b_p0).sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1))- 0].len + 0);
appendString((&(*result_p1)), (*b_p0).sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1))- 0]);
	prepareAdd((&(*result_p1)), (*b_p0).sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2))- 0].len + 0);
appendString((&(*result_p1)), (*b_p0).sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2))- 0]);
	}BeforeRet_: ;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)1073741824)) == ((NI)1073741824));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addIndent__cgen_u315)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2* result_p1) {
	NI i_1;
	NI newLen_1;
	NI T1_;
	i_1 = (*result_p1).len;
	T1_ = (*p_p0).blocks.len;
	newLen_1 = (NI)(i_1 + T1_);
	setLengthStrV2((&(*result_p1)), (newLen_1));
	{
		while (1) {
			if (!(i_1 < newLen_1)) goto LA3;
			nimPrepareStrMutationV2((&(*result_p1)));
			(*result_p1).p->data[i_1] = 9;
			i_1 += ((NI)1);
		} LA3: ;
	}
}
static N_INLINE(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw*, X5BX5D___cgendata_u232)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* result;
	result = (&s_p0[(NI)(s_p0Len_0 - i_p1)]);
	return result;
}
static N_INLINE(NimStringV2*, s__cgendata_u228)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g s_p1) {
	NimStringV2* result;
	tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NimStringV2*)0;
	T1_ = (tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw*)0;
	T1_ = X5BX5D___cgendata_u232((((*p_p0).blocks).p) ? ((*p_p0).blocks.p->data) : NIM_NIL, (*p_p0).blocks.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (&(*T1_).sections[(s_p1)- 0]);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, endBlock__cgen_u16185)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 blockEnd_p1) {
	NI topBlock_1;
	NI T1_;
	tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* T2_;
	NimStringV2* T3_;
	NimStringV2* T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (*p_p0).blocks.len;
	topBlock_1 = (NI)(T1_ - ((NI)1));
	T2_ = (tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw*)0;
	T2_ = (&(*p_p0).blocks.p->data[topBlock_1]);
	blockBody__cgen_u16177(T2_, (&(*p_p0).blocks.p->data[(NI)(topBlock_1 - ((NI)1))].sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2))- 0]));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setLen__cgendata_u311((&(*p_p0).blocks), (topBlock_1));
	T3_ = (NimStringV2*)0;
	T3_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	addIndent__cgen_u315(p_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T4_ = (NimStringV2*)0;
	T4_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&(*T4_)), blockEnd_p1.len + 0);
appendString((&(*T4_)), blockEnd_p1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, endBlock__cgen_u15767)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
	NimStringV2 blockEnd_1;
	NI topBlock_1;
	NI T1_;
	NI16 frameLen_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	blockEnd_1.len = 0; blockEnd_1.p = NIM_NIL;
	T1_ = (*p_p0).blocks.len;
	topBlock_1 = (NI)(T1_ - ((NI)1));
	frameLen_1 = (*p_p0).blocks.p->data[topBlock_1].frameLen;
	blockEnd_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_9;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T6_;
		if (!(((NI16)0) < frameLen_1)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD_ = rope__ropes_u15(((NI64) (frameLen_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T6_[0] = colontmpD_;
		colontmpD__2 = percent___cgen_u16204(T6_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&blockEnd_1), colontmpD__2.len + 0);
appendString((&blockEnd_1), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA4_: ;
	{
		NimStringV2 colontmpD__3;
		tyArray__YgExxhfgKcesA5EOUj1MOA T11_;
		if (!!(((*p_p0).blocks.p->data[topBlock_1].label.len == ((NI)0)))) goto LA9_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T11_[0] = (*p_p0).blocks.p->data[topBlock_1].label;
		colontmpD__3 = percent___cgen_u16209(T11_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&blockEnd_1), colontmpD__3.len + 0);
appendString((&blockEnd_1), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
	}
	goto LA7_;
LA9_: ;
	{
		NimStringV2 colontmpD__4;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T13_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__4 = percent___cgen_u9681(T13_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&blockEnd_1), colontmpD__4.len + 0);
appendString((&blockEnd_1), colontmpD__4);
		eqdestroy___system_u2691(colontmpD__4);
	}
LA7_: ;
	endBlock__cgen_u16185(p_p0, blockEnd_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(blockEnd_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, inExceptBlockLen__cgen_u15682)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
	NI result;
	result = ((NI)0);
	{
		tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* x_1;
		NI i_1;
		NI L_1;
		NI T2_;
		x_1 = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
		i_1 = ((NI)0);
		T2_ = (*p_p0).nestedTryStmts.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				x_1 = (&(*p_p0).nestedTryStmts.p->data[i_1]);
				{
					if (!(*x_1).Field1) goto LA7_;
					result += ((NI)1);
				}
LA7_: ;
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, startBlockInternal__cgen_u15729)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
	NI result;
	NI T1_;
	tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw T2_;
	NI T3_;
	NI T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*p_p0).labels += ((NI)1);
	T1_ = (*p_p0).blocks.len;
	result = T1_;
	nimZeroMem((void*)(&T2_), sizeof(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw));
	initBlock__cgendata_u468((&T2_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__cgen_u15740((&(*p_p0).blocks), (&T2_));
	(*p_p0).blocks.p->data[result].id = (*p_p0).labels;
	T3_ = (*p_p0).nestedTryStmts.len;
	(*p_p0).blocks.p->data[result].nestedTryStmts = ((NI16) (T3_));
	T4_ = (NI)0;
	T4_ = inExceptBlockLen__cgen_u15682(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*p_p0).blocks.p->data[result].nestedExceptStmts = ((NI16) (T4_));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_u5502)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0).sons.len;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleProc__cgen_u767)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NIM_BOOL makeUnique_p2) {
	NimStringV2 result;
	NimStringV2 params_1;
	NimStringV2 staticLists_1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	params_1.len = 0; params_1.p = NIM_NIL;
	staticLists_1.len = 0; staticLists_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_18;
	params_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_19;
	staticLists_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_20;
	{
		NI T4_;
		T4_ = (NI)0;
		T4_ = len__ast_u5502((*s_p1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)1) < T4_)) goto LA5_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u5502((*s_p1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)1);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i_1 = i_2;
					{
						NimStringV2 colontmpD__2;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						{
							if (!((*(*s_p1).typ).sons.p->data[i_1] == 0)) goto LA14_;
							eqdestroy___system_u2691(colontmpD__2);
							goto LA10;
						}
LA14_: ;
						colontmpD__2 = encodeType__ccgutils_u228(m_p0, (*(*s_p1).typ).sons.p->data[i_1], (&staticLists_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
						prepareAdd((&params_1), colontmpD__2.len + 0);
appendString((&params_1), colontmpD__2);
						{
							LA11_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__2);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					} LA10: ;
					i_2 += ((NI)1);
				} LA9: ;
			}
		}
	}
LA5_: ;
	colontmpD_ = encodeSym__ccgutils_u221(m_p0, s_p1, makeUnique_p2, staticLists_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
	prepareAdd((&result), params_1.len + 0);
appendString((&result), params_1);
	{
		NIM_BOOL T20_;
		NimStringV2 T23_;
		T20_ = (NIM_BOOL)0;
		T20_ = contains__cgen_u837((*(*m_p0).g).mangledPrcs, result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T20_) goto LA21_;
		T23_.len = 0; T23_.p = NIM_NIL;
		T23_ = mangleProc__cgen_u767(m_p0, s_p1, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T23_); goto LA1_;}
		eqsink___system_u2700((&result), T23_);
	}
	goto LA18_;
LA21_: ;
	{
		incl__options_u2181((&(*(*m_p0).g).mangledPrcs), result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA18_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(staticLists_1);
		eqdestroy___system_u2691(params_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, fillBackendName__cgen_u896)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 result_1;
		if (!((*s_p1).loc.snippet.len == 0)) goto LA3_;
		result_1.len = 0; result_1.p = NIM_NIL;
		{
			NIM_BOOL T8_;
			NIM_BOOL T9_;
			T8_ = (NIM_BOOL)0;
			T9_ = (NIM_BOOL)0;
			T9_ = ((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18));
			if (!(T9_)) goto LA10_;
			T9_ = ((IL64(288230376151711808) & (*(*(*m_p0).g).config).globalOptions) == IL64(288230376151711808));
LA10_: ;
			T8_ = T9_;
			if (!(T8_)) goto LA11_;
			T8_ = ((*(*(*m_p0).g).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0));
LA11_: ;
			if (!T8_) goto LA12_;
			result_1 = mangleProc__cgen_u767(m_p0, s_p1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		goto LA6_;
LA12_: ;
		{
			NimStringV2 colontmpD_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			result_1 = mangle__mangleutils_u4((*(*s_p1).name).s);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			colontmpD_ = mangleProcNameExt__mangleutils_u35((*(*m_p0).g).graph, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			prepareAdd((&result_1), colontmpD_.len + 0);
appendString((&result_1), colontmpD_);
			eqdestroy___system_u2691(colontmpD_);
		}
LA6_: ;
		{
			NIM_BOOL T17_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 T21_;
			T17_ = (NIM_BOOL)0;
			T17_ = hcrOn__cgen_u49(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			if (!T17_) goto LA18_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			nimAddCharV1((&result_1), 95);
			colontmpD__2 = mangle__mangleutils_u4((*(*(*m_p0).module).name).s);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T21_.len = 0; T21_.p = NIM_NIL;
			T21_ = colontmpD__2;
			colontmpD__3 = idOrSig__sighashes_u2002(s_p1, T21_, (&(*m_p0).sigConflicts), (*(*m_p0).g).config);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			prepareAdd((&result_1), colontmpD__3.len + 0);
appendString((&result_1), colontmpD__3);
			{
				LA20_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA18_: ;
		eqsink___system_u2700((&(*s_p1).loc.snippet), result_1);
		eqwasMoved___system_u2688((&result_1));
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(result_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, fillLoc__cgen_u88)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p0, tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode_p2, tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg s_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*a_p0).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA3_;
		(*a_p0).k = k_p1;
		eqcopy___ast_u3255(&(*a_p0).lode, lode_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*a_p0).storage = s_p3;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fillProcLoc__cgen_u14051)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	sym_1 = NIM_NIL;
	eqcopy___ast_u4577(&sym_1, (*n_p1)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*sym_1).loc.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA4_;
		fillBackendName__cgen_u896(m_p0, sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		fillLoc__cgen_u88((&(*sym_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)7), n_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, useHeader__cgen_u123)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 str_1;
		if (!(((*sym_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)5)))&15U)))!=0)) goto LA3_;
		str_1.len = 0; str_1.p = NIM_NIL;
		str_1 = getStr__ast_u7064((*(*sym_p1).annex).path);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		includeHeader__cgendata_u217(m_p0, str_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(str_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_u163)(NimStringV2* result_p0, NimStringV2 value_p1) {
	prepareAdd((&(*result_p0)), value_p1.len + 0);
appendString((&(*result_p0)), value_p1);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isReloadable__cgen_u8812)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = hcrOn__cgen_u49(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	if (!(T1_)) goto LA2_;
	T1_ = !((((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)38)))&63U)))!=0));
LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedCppType__cgen_u1384)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_1;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	x_1 = NIM_NIL;
	x_1 = skipTypes__ast_u5379(t_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_28);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*t_p0).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = (((*(*t_p0).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA4_;
	T5_ = (NIM_BOOL)0;
	T5_ = !(((*x_1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T5_)) goto LA6_;
	T5_ = (((*(*x_1).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA6_: ;
	T1_ = T5_;
LA4_: ;
	result = T1_;
	eqdestroy___ast_u3378(x_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeNameOrLiteral__cgen_u1900)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2 literal_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*t_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = (((*(*t_p1).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0);
LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T3_ = ((*(*t_p1).sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0));
LA6_: ;
		if (!T3_) goto LA7_;
		useHeader__cgen_u123(m_p0, (*t_p1).sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___system_u2694((&result), (*(*t_p1).sym).loc.snippet);
	}
	goto LA1_;
LA7_: ;
	{
		eqcopy___system_u2694((&result), literal_p2);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, detectStrVersion__cgen_u579)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NI result;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* coreX60gensym75__1;
		if (!((*(*m_p0).g).strVersion == ((NI)0))) goto LA3_;
		coreX60gensym75__1 = NIM_NIL;
		coreX60gensym75__1 = getCompilerProc__magicsys_u150((*(*m_p0).g).graph, TM__MQdRN7fpbG7rPm4JpVVAhA_38);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = (coreX60gensym75__1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
			if (T8_) goto LA9_;
			T8_ = !(((*coreX60gensym75__1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10)));
LA9_: ;
			if (!T8_) goto LA10_;
			(*(*m_p0).g).strVersion = ((NI)1);
		}
		goto LA6_;
LA10_: ;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T14_;
			NI T15_;
			colontmpD_ = NIM_NIL;
			colontmpD_ = astdef__ast_u4596(coreX60gensym75__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T14_ = getInt__ast_u7046(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T15_ = (NI)0;
			T15_ = toInt__int128_u257(T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			(*(*m_p0).g).strVersion = T15_;
			{
				LA13_:;
			}
			{
				oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				*nimErr_ = oldNimErrFin13_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA6_: ;
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(coreX60gensym75__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	result = (*(*m_p0).g).strVersion;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isActivated__cgen_u29100)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p0) {
	NIM_BOOL result;
	result = !(((*prc_p0).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addForwardedProc__cgen_u55)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___ast_u4580(prc_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__renderer_u83((&(*(*m_p0).g).forwardedProcs), colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*, findPendingModule__cgen_u62)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NI32 ms_1;
		if (!((*(*(*m_p0).g).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3))) goto LA3_;
		ms_1 = (*s_p1).itemId.module;
		eqcopy___cgendata_u721(&result, (*(*m_p0).g).modules.p->data[ms_1], NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ms_2;
		ms_2 = NIM_NIL;
		ms_2 = getModule__astalgo_u156(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___cgendata_u721(&result, (*(*m_p0).g).modules.p->data[(*ms_2).position], NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(ms_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isGetProcAddr__cgen_u27777)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_p0) {
	NIM_BOOL result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	n_1 = NIM_NIL;
	n_1 = (*lib_p0).path;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*n_1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*n_1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26) || (*(*n_1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA4_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addActualSuffixForHCR__cgen_u15038)(NimStringV2* res_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T5_;
		NIM_BOOL T8_;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1658__1;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1660__1;
		NimStringV2 T12_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = 0;
		T4_ = (((*sym_p2).flags & IL64(274877907008)) == T5_);
		if (!(T4_)) goto LA6_;
		T4_ = ((*sym_p2).loc.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)7));
LA6_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*(*sym_p2).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)5));
		if (T8_) goto LA9_;
		colontmpD_ = owner__ast_u6254(sym_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		xX60gensym1658__1 = (*colontmpD_).itemId;
		xX60gensym1660__1 = (*module_p1).itemId;
		T8_ = ((NI)((NI)((NU32)(((NI) (xX60gensym1658__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym1658__1.item))) == (NI)((NI)((NU32)(((NI) (xX60gensym1660__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym1660__1.item))));
LA9_: ;
		T3_ = T8_;
LA7_: ;
		if (!T3_) goto LA10_;
		T12_.len = 0; T12_.p = NIM_NIL;
		T12_ = rawNewString((*res_p0).len + 7);
appendString((&T12_), (*res_p0));
appendString((&T12_), TM__MQdRN7fpbG7rPm4JpVVAhA_52);
		eqsink___system_u2700((&(*res_p0)), T12_);
	}
LA10_: ;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cgsymValue__cgen_u141)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1) {
	NimStringV2 result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	sym_1 = NIM_NIL;
	sym_1 = getCompilerProc__magicsys_u150((*(*m_p0).g).graph, name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((sym_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA4_;
		cgsymImpl__cgen_u28031(m_p0, sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T8_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rawNewString(name_p1.len + 21);
appendString((&T8_), TM__MQdRN7fpbG7rPm4JpVVAhA_49);
appendString((&T8_), name_p1);
		colontmpD_ = T8_;
		liMessage__msgs_u1227((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), TM__MQdRN7fpbG7rPm4JpVVAhA_50, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	eqcopy___system_u2694((&result), (*sym_1).loc.snippet);
	{
		NIM_BOOL T13_;
		NIM_BOOL T14_;
		T13_ = (NIM_BOOL)0;
		T14_ = (NIM_BOOL)0;
		T14_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T14_)) goto LA15_;
		T14_ = !((sym_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA15_: ;
		T13_ = T14_;
		if (!(T13_)) goto LA16_;
		T13_ = ((*sym_1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) && (*sym_1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15));
LA16_: ;
		if (!T13_) goto LA17_;
		addActualSuffixForHCR__cgen_u15038((&result), (*m_p0).module, sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA17_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralDataOnlyV1__cgen_u605)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 s_p1, NimStringV2* result_p2) {
	NimStringV2 tmp_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_67);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tmp_1 = getTempName__cgen_u462(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*result_p2)), tmp_1.len + 0);
appendString((&(*result_p2)), tmp_1);
	T2_[0] = tmp_1;
	colontmpD_ = makeCString__msgs_u83(s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[1] = colontmpD_;
	colontmpD__2 = rope__ropes_u15(((NI64) (s_p1.len)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[2] = colontmpD__2;
	colontmpD__3 = percent___cgen_u610(T2_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__3.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__3);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tmp_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_u166)(NimStringV2* result_p0, NI64 value_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, value_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralV1__cgen_u615)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		if (!NIM_FALSE) goto LA3_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_57);
		colontmpD_ = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_59);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&res_1), 11);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_61);
		prepareAdd((&(*result_p2)), res_1.len + 0);
appendString((&(*result_p2)), res_1);
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NI id_1;
		id_1 = nodeTableTestOrSet__treetab_u225((&(*m_p0).dataCache), n_p1, (*m_p0).labels);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__2;
			if (!(id_1 == (*m_p0).labels)) goto LA11_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_62);
			colontmpD__2 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_63);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_65);
			prepareAdd((&(*result_p2)), res_2.len + 0);
appendString((&(*result_p2)), res_2);
			genStringLiteralDataOnlyV1__cgen_u605(m_p0, (*n_p1)._kind_3.strVal, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&(*result_p2)), 1);
appendString((&(*result_p2)), TM__MQdRN7fpbG7rPm4JpVVAhA_69);
			{
				LA13_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA9_;
LA11_: ;
		{
			NimStringV2 res_3;
			NimStringV2 colontmpD__3;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_70);
			colontmpD__3 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_71);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_72);
			cgFormatValue__cgen_u163((&res_3), (*m_p0).tmpBase);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			cgFormatValue__cgen_u166((&res_3), ((NI64) (id_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_73);
			prepareAdd((&(*result_p2)), res_3.len + 0);
appendString((&(*result_p2)), res_3);
			{
				LA17_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(res_3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA9_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralDataOnlyV2__cgen_u654)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 s_p1, NimStringV2 result_p2, NIM_BOOL isConst_p3) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	tyArray__Seu7uK9aaOSN0BK3EAjjSHw T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	T1_[0] = result_p2;
	colontmpD_ = rope__ropes_u15(((NI64) (s_p1.len)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[1] = colontmpD_;
	colontmpD__2 = makeCString__msgs_u83(s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[2] = colontmpD__2;
	{
		if (!isConst_p3) goto LA4_;
		colontmpD__3 = TM__MQdRN7fpbG7rPm4JpVVAhA_75;
		T1_[3] = colontmpD__3;
	}
	goto LA2_;
LA4_: ;
	{
		colontmpD__4 = TM__MQdRN7fpbG7rPm4JpVVAhA_76;
		T1_[3] = colontmpD__4;
	}
LA2_: ;
	colontmpD__5 = percent___cgen_u659(T1_, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__5);
	eqdestroy___system_u2691(colontmpD__5);
	eqdestroy___system_u2691(colontmpD__4);
	eqdestroy___system_u2691(colontmpD__3);
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralV2__cgen_u664)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, NimStringV2* result_p3) {
	NI id_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	id_1 = nodeTableTestOrSet__treetab_u225((&(*m_p0).dataCache), n_p1, (*m_p0).labels);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 pureLit_1;
		NimStringV2 tmp_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T6_;
		if (!(id_1 == (*m_p0).labels)) goto LA3_;
		pureLit_1.len = 0; pureLit_1.p = NIM_NIL;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		pureLit_1 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		genStringLiteralDataOnlyV2__cgen_u654(m_p0, (*n_p1)._kind_3.strVal, pureLit_1, isConst_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		tmp_1 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&(*result_p3)), tmp_1.len + 0);
appendString((&(*result_p3)), tmp_1);
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_78);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_80);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_[0] = tmp_1;
		colontmpD_ = rope__ropes_u15(((NI64) ((*n_p1)._kind_3.strVal.len)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_[1] = colontmpD_;
		T6_[2] = pureLit_1;
		{
			if (!isConst_p2) goto LA9_;
			colontmpD__2 = TM__MQdRN7fpbG7rPm4JpVVAhA_81;
			T6_[3] = colontmpD__2;
		}
		goto LA7_;
LA9_: ;
		{
			colontmpD__3 = TM__MQdRN7fpbG7rPm4JpVVAhA_82;
			T6_[3] = colontmpD__3;
		}
LA7_: ;
		colontmpD__4 = percent___cgen_u672(T6_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__4.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__4);
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(tmp_1);
			eqdestroy___system_u2691(pureLit_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 tmp_2;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T15_;
		NimStringV2 T16_;
		tmp_2.len = 0; tmp_2.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		tmp_2 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p3)), tmp_2.len + 0);
appendString((&(*result_p3)), tmp_2);
		T15_[0] = tmp_2;
		colontmpD__5 = rope__ropes_u15(((NI64) ((*n_p1)._kind_3.strVal.len)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T15_[1] = colontmpD__5;
		T16_.len = 0; T16_.p = NIM_NIL;
		colontmpD__6 = rope__ropes_u15(((NI64) (id_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T16_ = rawNewString((*m_p0).tmpBase.len + colontmpD__6.len + 0);
appendString((&T16_), (*m_p0).tmpBase);
appendString((&T16_), colontmpD__6);
		colontmpD__7 = T16_;
		T15_[2] = colontmpD__7;
		{
			if (!isConst_p2) goto LA19_;
			colontmpD__8 = TM__MQdRN7fpbG7rPm4JpVVAhA_83;
			T15_[3] = colontmpD__8;
		}
		goto LA17_;
LA19_: ;
		{
			colontmpD__9 = TM__MQdRN7fpbG7rPm4JpVVAhA_84;
			T15_[3] = colontmpD__9;
		}
LA17_: ;
		colontmpD__10 = percent___cgen_u672(T15_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__10.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__10);
		eqdestroy___system_u2691(colontmpD__10);
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(tmp_2);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteral__cgen_u714)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2) {
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI)0;
	T1_ = detectStrVersion__cgen_u579(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch (T1_) {
	case ((NI)0):
	case ((NI)1):
	{
		genStringLiteralV1__cgen_u615(m_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((NI)2):
	{
		genStringLiteralV2__cgen_u664(m_p0, n_p1, NIM_TRUE, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		liMessage__msgs_u1227((*(*m_p0).g).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_86, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_87, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initLoc__cgen_u72)(tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode_p1, tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg s_p2, tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	(*Result).k = k_p0;
	(*Result).storage = s_p2;
	colontmpD_ = eqdup___ast_u3258(lode_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).lode = colontmpD_;
	(*Result).snippet = TM__MQdRN7fpbG7rPm4JpVVAhA_96;
	(*Result).flags = flags_p3;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rdLoc__cgen_u470)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	{
		NimStringV2 T5_;
		if (!((a_p0.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0)))&15U)))!=0)) goto LA3_;
		T5_.len = 0; T5_.p = NIM_NIL;
		T5_ = rawNewString(a_p0.snippet.len + 3);
appendString((&T5_), TM__MQdRN7fpbG7rPm4JpVVAhA_99);
appendString((&T5_), a_p0.snippet);
appendString((&T5_), TM__MQdRN7fpbG7rPm4JpVVAhA_100);
		result = T5_;
	}
	goto LA1_;
LA3_: ;
	{
		eqcopy___system_u2694((&result), a_p0.snippet);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, loadDynamicLib__cgen_u27793)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_p1) {
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin29_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 tmp_1;
		NimStringV2 colontmpD_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T6_;
		if (!!((*lib_p1).generated)) goto LA3_;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		(*lib_p1).generated = NIM_TRUE;
		tmp_1 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		eqcopy___system_u2694((&(*lib_p1).name), tmp_1);
		T6_[0] = tmp_1;
		colontmpD_ = percent___cgen_u27807(T6_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD_);
		{
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ s_1;
			NimStringV2 loadlib_1;
			NimStringV2 res_1;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* T24_;
			tyArray__TonP9cxJgj8gXu71dWIyNlA T25_;
			if (!((*(*lib_p1).path).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*(*lib_p1).path).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA9_;
			s_1.len = 0; s_1.p = NIM_NIL;
			loadlib_1.len = 0; loadlib_1.p = NIM_NIL;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			s_1.len = 0; s_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
			libCandidates__pureZdynlib_u81((*(*lib_p1).path)._kind_3.strVal, (&s_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			liMessage__msgs_u1227((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)111), (*(*lib_p1).path)._kind_3.strVal, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), TM__MQdRN7fpbG7rPm4JpVVAhA_39, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			loadlib_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_41;
			{
				NI i_1;
				NI colontmp_;
				NI T13_;
				NI res_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				T13_ = (s_1.len-1);
				colontmp_ = T13_;
				res_2 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
						NimStringV2 res_3;
						NimStringV2 colontmpD__4;
						NimStringV2 colontmpD__5;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T21_;
						if (!(res_2 <= colontmp_)) goto LA15;
						n_1 = NIM_NIL;
						res_3.len = 0; res_3.p = NIM_NIL;
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						i_1 = ((NI) (res_2));
						(*m_p0).labels += ((NI)1);
						{
							if (!(((NI)0) < i_1)) goto LA19_;
							prepareAdd((&loadlib_1), 2);
appendString((&loadlib_1), TM__MQdRN7fpbG7rPm4JpVVAhA_43);
						}
LA19_: ;
						n_1 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), s_1.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						(*n_1).info = (*(*lib_p1).path).info;
						res_3 = rawNewString(((NI)80));
						prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_45);
						cgFormatValue__cgen_u163((&res_3), tmp_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_47);
						colontmpD__4 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_54);
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						cgFormatValue__cgen_u163((&res_3), colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_55);
						prepareAdd((&loadlib_1), res_3.len + 0);
appendString((&loadlib_1), res_3);
						genStringLiteral__cgen_u714(m_p0, n_1, (&loadlib_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						colontmpD__5 = percent___cgen_u27845(T21_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						prepareAdd((&loadlib_1), colontmpD__5.len + 0);
appendString((&loadlib_1), colontmpD__5);
						res_2 += ((NI)1);
						{
							LA16_:;
						}
						{
							oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__5);
							eqdestroy___system_u2691(colontmpD__4);
							eqdestroy___system_u2691(res_3);
							eqdestroy___ast_u3252(n_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
							*nimErr_ = oldNimErrFin16_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					} LA15: ;
				}
			}
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_90);
			cgFormatValue__cgen_u163((&res_1), loadlib_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_92);
			colontmpD__2 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_94);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_95);
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_1);
			T24_ = NIM_NIL;
			T24_ = m_p0;
			genStringLiteral__cgen_u714(T24_, (*lib_p1).path, (&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			colontmpD__3 = percent___cgen_u27859(T25_, 0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__3.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__3);
			{
				LA11_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_1);
				eqdestroy___system_u2691(loadlib_1);
				eqdestroy___system_u5506(s_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		goto LA7_;
LA9_: ;
		{
			tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_1;
			NimStringV2 res_4;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 res_5;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T30_;
			NimStringV2 T31_;
			NimStringV2* T36_;
			NimStringV2* T37_;
			NimStringV2* T38_;
			p_1 = NIM_NIL;
			nimZeroMem((void*)(&dest_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			res_5.len = 0; res_5.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			p_1 = newProc__cgendata_u509(((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			(*p_1).options &= ~(((NU32)1) << (((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17))) & 31));
			(*p_1).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)6))) & 7);
			T30_ = 0;
			initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1), (*lib_p1).path, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2), T30_, (&dest_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T31_.len = 0; T31_.p = NIM_NIL;
			T31_ = getTempName__cgen_u462(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T31_); goto LA29_;}
			eqsink___system_u2700((&dest_1.snippet), T31_);
			res_4 = rawNewString(((NI)80));
			colontmpD__6 = getTypeDesc__cgen_u8738(m_p0, (*(*lib_p1).path).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_97);
			colontmpD__7 = rdLoc__cgen_u470(dest_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_102);
			{
				if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA34_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_103);
			}
LA34_: ;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_4.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_4);
			expr__cgen_u14084(p_1, (*lib_p1).path, (&dest_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T36_ = (NimStringV2*)0;
			T36_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), (*T36_).len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), (*T36_));
			T37_ = (NimStringV2*)0;
			T37_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), (*T37_).len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), (*T37_));
			T38_ = (NimStringV2*)0;
			T38_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), (*T38_).len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), (*T38_));
			res_5 = rawNewString(((NI)80));
			prepareAdd((&res_5), 6);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_104);
			cgFormatValue__cgen_u163((&res_5), tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_105);
			colontmpD__8 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_106);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_107);
			colontmpD__9 = rdLoc__cgen_u470(dest_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_109);
			colontmpD__10 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_110);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_111);
			colontmpD__11 = rdLoc__cgen_u470(dest_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_113);
			{
				if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA41_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_114);
			}
LA41_: ;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_5);
			{
				LA29_:;
			}
			{
				oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(res_5);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(res_4);
				eqdestroy___ast_u6284(dest_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				eqdestroy___cgendata_u2071(p_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				*nimErr_ = oldNimErrFin29_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA7_: ;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(tmp_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		if (!((*lib_p1).name.len == 0)) goto LA49_;
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, TM__MQdRN7fpbG7rPm4JpVVAhA_116, TM__MQdRN7fpbG7rPm4JpVVAhA_117);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA49_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleDynLibProc__cgen_u5410)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!(((*sym_p0).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)18)))&63U)))!=0)) goto LA3_;
		eqcopy___system_u2694((&result), (*(*sym_p0).name).s);
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 colontmpD_;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7190__1;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		xX60gensym7190__1 = (*sym_p0).itemId;
		colontmpD_ = dollar___systemZdollars_u9((NI)((NI)((NU32)(((NI) (xX60gensym7190__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7190__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		result = nsuFormatSingleElem(TM__MQdRN7fpbG7rPm4JpVVAhA_119, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocExpr__cgen_u14111)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0), e_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), flags_p2, Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	expr__cgen_u14084(p_p0, e_p1, Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	T1_ = X5BX5D___ast_u5211((((*n_p0)._kind_6.sons).p) ? ((*n_p0)._kind_6.sons.p->data) : NIM_NIL, (*n_p0)._kind_6.sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info_p0) {
	NimStringV2 result;
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_123;
	prepareAdd((&result), info_p0.Field0.len + 0);
appendString((&result), info_p0.Field0);
	{
		if (!(((NI)0) < info_p0.Field1)) goto LA3_;
		prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_124);
		addInt__stdZprivateZdigitsutils_u204((&result), info_p0.Field1);
		{
			if (!(((NI)0) < (NI)(info_p0.Field2 + ((NI)1)))) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_125);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)(info_p0.Field2 + ((NI)1)));
		}
LA7_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_126);
	}
LA3_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, t__cgen_u97)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*a_p0.lode).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA3_;
		eqcopy___ast_u3381(&result, (*(*a_p0.lode)._kind_4.sym).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		eqcopy___ast_u3381(&result, (*a_p0.lode).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLib__cgen_u27914)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_1;
	NimStringV2 extname_1;
	NimStringV2 tmp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NIM_BOOL isCall_1;
NIM_BOOL oldNimErrFin10_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T59_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	lib_1 = NIM_NIL;
	extname_1.len = 0; extname_1.p = NIM_NIL;
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	eqcopy___ast_u6219(&lib_1, (*sym_p1).annex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	isCall_1 = isGetProcAddr__cgen_u27777(lib_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&extname_1), (*sym_p1).loc.snippet);
	{
		if (!!(isCall_1)) goto LA4_;
		loadDynamicLib__cgen_u27793(m_p0, lib_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	tmp_1 = mangleDynLibProc__cgen_u5410(sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&(*sym_p1).loc.snippet), tmp_1);
	eqsink___ast_u4583(&(*(*sym_p1).typ).sym, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*m_p0).labels += ((NI)2);
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		NimStringV2 params_1;
		NimStringV2 colontmpD__4;
		NimStringV2 load_1;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* last_1;
		NimStringV2 idx_1;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T11_;
		NimStringV2 T12_;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T22_;
		if (!isCall_1) goto LA8_;
		n_1 = NIM_NIL;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		params_1.len = 0; params_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		load_1.len = 0; load_1.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		last_1 = NIM_NIL;
		idx_1.len = 0; idx_1.p = NIM_NIL;
		eqcopy___ast_u3255(&n_1, (*lib_1).path);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T11_ = 0;
		initLocExpr__cgen_u14111((*m_p0).initProc, (*n_1)._kind_6.sons.p->data[((NI)0)], T11_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T12_.len = 0; T12_.p = NIM_NIL;
		colontmpD__4 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T12_ = rawNewString(colontmpD__4.len + 1);
appendString((&T12_), colontmpD__4);
appendString((&T12_), TM__MQdRN7fpbG7rPm4JpVVAhA_120);
		params_1 = T12_;
		{
			NI i_1;
			NI colontmp_;
			NI T14_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T14_ = (NI)0;
			T14_ = len__ast_u3190(n_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			colontmp_ = (NI)(T14_ - ((NI)1));
			i_2 = ((NI)1);
			{
				while (1) {
					NimStringV2 colontmpD__7;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T18_;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T19_;
					if (!(i_2 < colontmp_)) goto LA16;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					i_1 = i_2;
					T18_ = 0;
					nimZeroMem((void*)(&T19_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					initLocExpr__cgen_u14111((*m_p0).initProc, (*n_1)._kind_6.sons.p->data[i_1], T18_, (&T19_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					eqsink___ast_u6293((&a_1), T19_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					colontmpD__7 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					prepareAdd((&params_1), colontmpD__7.len + 0);
appendString((&params_1), colontmpD__7);
					prepareAdd((&params_1), 2);
appendString((&params_1), TM__MQdRN7fpbG7rPm4JpVVAhA_122);
					i_2 += ((NI)1);
					{
						LA17_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__7);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				} LA16: ;
			}
		}
		T22_[0] = tmp_1;
		colontmpD__5 = getTypeDesc__cgen_u8738(m_p0, (*sym_p1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T22_[1] = colontmpD__5;
		T22_[2] = params_1;
		colontmpD__6 = makeCString__msgs_u83(extname_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T22_[3] = colontmpD__6;
		load_1 = percent___cgen_u27934(T22_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		last_1 = lastSon__ast_u5208(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			if (!((*last_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58))) goto LA25_;
			eqcopy___ast_u3255(&last_1, (*last_1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA25_: ;
		{
			NimStringV2 argX60gensym7196__1;
			if (!!(((*last_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20)))) goto LA29_;
			argX60gensym7196__1.len = 0; argX60gensym7196__1.p = NIM_NIL;
			argX60gensym7196__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_127);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, argX60gensym7196__1, TM__MQdRN7fpbG7rPm4JpVVAhA_127);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			{
				LA31_:;
			}
			{
				eqdestroy___system_u2691(argX60gensym7196__1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA29_: ;
		eqcopy___system_u2694((&idx_1), (*last_1)._kind_3.strVal);
		{
			NimStringV2* T38_;
			if (!(idx_1.len == ((NI)0))) goto LA36_;
			T38_ = (NimStringV2*)0;
			T38_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			prepareAdd((&(*T38_)), load_1.len + 0);
appendString((&(*T38_)), load_1);
		}
		goto LA34_;
LA36_: ;
		{
			NIM_BOOL T40_;
			T40_ = (NIM_BOOL)0;
			T40_ = (idx_1.len == ((NI)1));
			if (!(T40_)) goto LA41_;
			T40_ = (((NU8)(idx_1.p->data[((NI)0)])) >= ((NU8)(48)) && ((NU8)(idx_1.p->data[((NI)0)])) <= ((NU8)(57)));
LA41_: ;
			if (!T40_) goto LA42_;
			prepareAdd((&(*m_p0).extensionLoaders[(((NU8)(idx_1.p->data[((NI)0)])))- 48]), load_1.len + 0);
appendString((&(*m_p0).extensionLoaders[(((NU8)(idx_1.p->data[((NI)0)])))- 48]), load_1);
		}
		goto LA34_;
LA42_: ;
		{
			NimStringV2 colontmpD__8;
			NimStringV2 T46_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T46_.len = 0; T46_.p = NIM_NIL;
			T46_ = rawNewString(idx_1.len + 13);
appendString((&T46_), TM__MQdRN7fpbG7rPm4JpVVAhA_129);
appendString((&T46_), idx_1);
			colontmpD__8 = T46_;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*sym_p1).info, colontmpD__8, TM__MQdRN7fpbG7rPm4JpVVAhA_130);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			{
				LA45_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__8);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA34_: ;
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(idx_1);
			eqdestroy___ast_u3252(last_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(load_1);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(params_1);
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(n_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA6_;
LA8_: ;
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_132);
		cgFormatValue__cgen_u163((&res_1), tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_134);
		colontmpD__9 = getTypeDesc__cgen_u8738(m_p0, (*sym_p1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_136);
		colontmpD__10 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_138);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_139);
		cgFormatValue__cgen_u163((&res_1), (*lib_1).name);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_140);
		colontmpD__11 = makeCString__msgs_u83(extname_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_141);
		{
			if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA55_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_142);
		}
LA55_: ;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_1);
		{
			LA52_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	T59_[0] = (*sym_p1).loc.snippet;
	colontmpD_ = t__cgen_u97((*sym_p1).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getTypeDesc__cgen_u8738(m_p0, colontmpD_, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T59_[1] = colontmpD__2;
	colontmpD__3 = percent___cgen_u27971(T59_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__3.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__3);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___system_u2691(extname_1);
		eqdestroy___ast_u6216(lib_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getCFile__cgen_u144)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
	NimStringV2 ext_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	ext_1.len = 0; ext_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T5_) goto LA6_;
		T5_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA6_: ;
		if (!T5_) goto LA7_;
		ext_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_144;
	}
	goto LA3_;
LA7_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)4));
		if (T10_) goto LA11_;
		T10_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)33)))&63U)))!=0);
LA11_: ;
		if (!T10_) goto LA12_;
		ext_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_146;
	}
	goto LA3_;
LA12_: ;
	{
		ext_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_148;
	}
LA3_: ;
	colontmpD_ = mangleModuleName__modulepaths_u40((*(*m_p0).g).config, (*m_p0).cfilename);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = completeCfilePath__extccomp_u929((*(*m_p0).g).config, colontmpD_, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = noschangeFileExt(colontmpD__2, ext_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getModuleDllPath__cgen_u146)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tmpTuple_1;
	NimStringV2 colontmpD_;
	NimStringV2 dir_1;
	NimStringV2 name_1;
	NimStringV2 ext_1;
	NimStringV2 filename_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
	NimStringV2 T3_;
	NimStringV2 T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	dir_1.len = 0; dir_1.p = NIM_NIL;
	name_1.len = 0; name_1.p = NIM_NIL;
	ext_1.len = 0; ext_1.p = NIM_NIL;
	filename_1.len = 0; filename_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD_ = getCFile__cgen_u144(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tmpTuple_1 = splitFile__pathutils_u39(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	dir_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u2688((&tmpTuple_1.Field0));
	name_1 = tmpTuple_1.Field1;
	eqwasMoved___system_u2688((&tmpTuple_1.Field1));
	ext_1 = tmpTuple_1.Field2;
	eqwasMoved___system_u2688((&tmpTuple_1.Field2));
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = rawNewString(name_1.len + ext_1.len + 0);
appendString((&T3_), name_1);
appendString((&T3_), ext_1);
	colontmpD__2 = T3_;
	T2_[0] = colontmpD__2;
	filename_1 = nsuFormatOpenArray(OS__platform_u534[((*(*(*m_p0).g).config).target.targetOS)- 1].Field2, T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_.len = 0; T4_.p = NIM_NIL;
	T4_ = rawNewString(dir_1.len + filename_1.len + 1);
appendString((&T4_), dir_1);
appendString((&T4_), TM__MQdRN7fpbG7rPm4JpVVAhA_150);
appendString((&T4_), filename_1);
	colontmpD__3 = T4_;
	result = makeCString__msgs_u83(colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(filename_1);
		eqdestroy___system_u2691(ext_1);
		eqdestroy___system_u2691(name_1);
		eqdestroy___system_u2691(dir_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___pathutils_u73(tmpTuple_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getModuleDllPath__cgen_u158)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = getModuleDllPath__cgen_u146((*(*m_p0).g).modules.p->data[(*s_p1).itemId.module]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, symInDynamicLibPartial__cgen_u28028)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = mangleDynLibProc__cgen_u5410(sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1_); goto BeforeRet_;}
	eqsink___system_u2700((&(*sym_p1).loc.snippet), T1_);
	eqsink___ast_u4583(&(*(*sym_p1).typ).sym, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, returnType__ast_u5354)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, firstParamType__ast_u5363)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cacheGetType__cgen_u1466)(tyObject_Table__0Na0d2dQ8AYACjty2CqMPA tab_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = getOrDefault__cgen_u1536(tab_p0, sig_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipModifier__ast_u5338)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, typeName__cgen_u1266)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, NimStringV2* result_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	typ_2 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	typ_2 = skipTypes__ast_u5379(typ_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_28);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = dollar___ast_u182((*typ_2).kind);
	prepareAdd((&(*result_p1)), colontmpD_.len + 0);
appendString((&(*result_p1)), colontmpD_);
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD__2;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*typ_2).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*typ_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*typ_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14));
LA4_: ;
		if (!T3_) goto LA5_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		prepareAdd((&(*result_p1)), 1);
appendString((&(*result_p1)), TM__MQdRN7fpbG7rPm4JpVVAhA_156);
		colontmpD__2 = mangle__mangleutils_u4((*(*(*typ_2).sym).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p1)), colontmpD__2.len + 0);
appendString((&(*result_p1)), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
	}
LA5_: ;
	eqdestroy___system_u2691(colontmpD_);
	eqdestroy___ast_u3378(typ_2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeName__cgen_u1281)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T17_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	t_1 = NIM_NIL;
	typ_2 = NIM_NIL;
	eqcopy___ast_u3381(&t_1, typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			{
				NIM_BOOL T6_;
				tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T8_;
				T6_ = (NIM_BOOL)0;
				T6_ = !(((*t_1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
				if (!(T6_)) goto LA7_;
				T8_ = 0;
				T6_ = !(((192 & (*(*t_1).sym).flags) == T8_));
LA7_: ;
				if (!T6_) goto LA9_;
				eqcopy___system_u2694((&result), (*(*t_1).sym).loc.snippet);
				eqdestroy___ast_u3378(typ_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u3378(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
LA9_: ;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T15_;
				if (!((TM__MQdRN7fpbG7rPm4JpVVAhA_28[(NU)(((*t_1).kind))>>3] &(1U<<((NU)(((*t_1).kind))&7U)))!=0)) goto LA13_;
				T15_ = NIM_NIL;
				T15_ = skipModifier__ast_u5338(t_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T15_); goto LA1_;}
				eqsink___ast_u3387(&t_1, T15_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA11_;
LA13_: ;
			{
				goto LA2;
			}
LA11_: ;
		}
	} LA2: ;
	T17_ = NIM_NIL;
	{
		if (!((*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4) || (*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46) || (*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45))) goto LA20_;
		typ_2 = elementType__ast_u5331(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA18_;
LA20_: ;
	{
		eqcopy___ast_u3381(&typ_2, typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA18_: ;
	{
		NimStringV2 colontmpD_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T27_;
		if (!((*typ_2).loc.snippet.len == 0)) goto LA25_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T27_ = NIM_NIL;
		T27_ = typ_2;
		typeName__cgen_u1266(T27_, (&(*typ_2).loc.snippet));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD_ = dollar___modulegraphs_u10732(sig_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*typ_2).loc.snippet), colontmpD_.len + 0);
appendString((&(*typ_2).loc.snippet), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA23_;
LA25_: ;
	{
	}
LA23_: ;
	eqcopy___system_u2694((&result), (*typ_2).loc.snippet);
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T34_;
		if (!(result.len == 0)) goto LA31_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T34_.len = 0; T34_.p = NIM_NIL;
		colontmpD__2 = dollar___ast_u182((*typ_2).kind);
		T34_ = rawNewString(colontmpD__2.len + 13);
appendString((&T34_), TM__MQdRN7fpbG7rPm4JpVVAhA_158);
appendString((&T34_), colontmpD__2);
		colontmpD__3 = T34_;
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, colontmpD__3, TM__MQdRN7fpbG7rPm4JpVVAhA_159);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			LA33_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA31_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(typ_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedType__cgen_u1373)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*t_p0).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*t_p0).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0);
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addForwardStructFormat__cgen_u3187)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 structOrUnion_p1, NimStringV2 typename_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T3_) goto LA4_;
		T3_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA4_: ;
		if (!T3_) goto LA5_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T7_[0] = structOrUnion_p1;
		T7_[1] = typename_p2;
		colontmpD_ = percent___cgen_u3199(T7_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)2))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)2))- 0]), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA1_;
LA5_: ;
	{
		NimStringV2 colontmpD__2;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T9_[0] = structOrUnion_p1;
		T9_[1] = typename_p2;
		colontmpD__2 = percent___cgen_u3204(T9_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)2))- 0]), colontmpD__2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)2))- 0]), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, structOrUnion__cgen_u545)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	t_2 = NIM_NIL;
	t_2 = skipTypes__ast_u5379(t_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_160);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		if (!(((*t_2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)1)))&63U)))!=0)) goto LA4_;
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_162;
	}
	goto LA2_;
LA4_: ;
	{
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_164;
	}
LA2_: ;
	eqdestroy___ast_u3378(t_2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushType__cgen_u3159)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = ((*m_p0).typeStack.len-1);
		colontmp_ = T2_;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				{
					if (!((*m_p0).typeStack.p->data[i_1] == typ_p1)) goto LA7_;
					goto BeforeRet_;
				}
LA7_: ;
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	colontmpD_ = eqdup___ast_u3384(typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3891((&(*m_p0).typeStack), colontmpD_);
	}BeforeRet_: ;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1) {
	(*(*dest_p0).p).data[(*dest_p0).len] = c_p1;
	(*dest_p0).len += ((NI)1);
	(*(*dest_p0).p).data[(*dest_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeForward__cgen_u3216)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* concrete_1;
	NimStringV2 T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	concrete_1 = NIM_NIL;
	result = cacheGetType__cgen_u1466((*m_p0).forwTypeCache, sig_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((result.len == 0))) goto LA4_;
		eqdestroy___ast_u3378(concrete_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_.len = 0; T6_.p = NIM_NIL;
	T6_ = getTypePre__cgen_u3178(m_p0, typ_p1, sig_p2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T6_); goto LA1_;}
	eqsink___system_u2700((&result), T6_);
	{
		if (!!((result.len == 0))) goto LA9_;
		eqdestroy___ast_u3378(concrete_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA9_: ;
	concrete_1 = skipTypes__ast_u5379(typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*concrete_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		NimStringV2 colontmpD_;
		NimStringV2 T12_;
		T12_.len = 0; T12_.p = NIM_NIL;
		T12_ = getTypeName__cgen_u1281(m_p0, typ_p1, sig_p2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T12_); goto LA1_;}
		eqsink___system_u2700((&result), T12_);
		colontmpD_ = eqdup___system_u2697(result);
		X5BX5Deq___cgen_u1967((&(*m_p0).forwTypeCache), sig_p2, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T15_;
			NimStringV2 colontmpD__2;
			T15_ = (NIM_BOOL)0;
			T15_ = isImportedType__cgen_u1373(concrete_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T15_)) goto LA16_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = structOrUnion__cgen_u545(typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addForwardStructFormat__cgen_u3187(m_p0, colontmpD__2, result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__2);
		}
		goto LA13_;
LA16_: ;
		{
			pushType__cgen_u3159(m_p0, concrete_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA13_: ;
		{
			NimStringV2* T21_;
			T21_ = (NimStringV2*)0;
			T21_ = X5BX5D___cgen_u3321((&(*m_p0).forwTypeCache), sig_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(eqStrings((*T21_), result))) goto LA22_;
			failedAssertImpl__stdZassertions_u79(TM__MQdRN7fpbG7rPm4JpVVAhA_166);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA22_: ;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T26_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T26_.len = 0; T26_.p = NIM_NIL;
		colontmpD__3 = dollar___ast_u182((*typ_p1).kind);
		T26_ = rawNewString(colontmpD__3.len + 16);
appendString((&T26_), TM__MQdRN7fpbG7rPm4JpVVAhA_168);
appendString((&T26_), colontmpD__3);
appendChar((&T26_), 41);
		colontmpD__4 = T26_;
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, colontmpD__4, TM__MQdRN7fpbG7rPm4JpVVAhA_169);
		if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		{
			LA25_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(concrete_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, seqStar__cgen_u3209)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
	{
		if (!(((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA3_;
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_185;
	}
	goto LA1_;
LA3_: ;
	{
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_187;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeDescWeak__cgen_u3400)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p2, tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q kind_p3) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* etB_1;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	etB_1 = NIM_NIL;
	etB_1 = skipTypes__ast_u5379(t_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*etB_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		{
			NIM_BOOL T5_;
			T5_ = (NIM_BOOL)0;
			T5_ = isImportedCppType__cgen_u1384(etB_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T5_)) goto LA6_;
			T5_ = ((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11));
LA6_: ;
			if (!T5_) goto LA7_;
			result = getTypeDescAux__cgen_u1419(m_p0, t_p1, check_p2, kind_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA3_;
LA7_: ;
		{
			tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T10_;
			nimZeroMem((void*)T10_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
			hashType__sighashes_u411(t_p1, (*(*m_p0).g).config, 2, T10_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			result = getTypeForward__cgen_u3216(m_p0, t_p1, T10_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			pushType__cgen_u3159(m_p0, t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA3_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_1;
		nimZeroMem((void*)sig_1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
		hashType__sighashes_u411(t_p1, (*(*m_p0).g).config, 2, sig_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			NimStringV2 colontmpD__2;
			if (!(((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA14_;
			colontmpD_ = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			{
				colontmpD_ = skipTypes__ast_u5379((*etB_1).sons.p->data[((NI)0)], TM__MQdRN7fpbG7rPm4JpVVAhA_170);
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
				if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)3))) goto LA19_;
				internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, TM__MQdRN7fpbG7rPm4JpVVAhA_172, TM__MQdRN7fpbG7rPm4JpVVAhA_173);
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			}
LA19_: ;
			result = cacheGetType__cgen_u1466((*m_p0).forwTypeCache, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			{
				NimStringV2 T25_;
				if (!(result.len == 0)) goto LA23_;
				T25_.len = 0; T25_.p = NIM_NIL;
				T25_ = getTypeName__cgen_u1281(m_p0, t_p1, sig_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T25_); goto LA16_;}
				eqsink___system_u2700((&result), T25_);
				{
					NIM_BOOL T28_;
					NimStringV2 colontmpD__3;
					NimStringV2 payload_1;
					NimStringV2 T31_;
					T28_ = (NIM_BOOL)0;
					T28_ = isImportedType__cgen_u1373(t_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					if (!!(T28_)) goto LA29_;
					payload_1.len = 0; payload_1.p = NIM_NIL;
					colontmpD__3 = eqdup___system_u2697(result);
					X5BX5Deq___cgen_u1967((&(*m_p0).forwTypeCache), sig_1, colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					addForwardStructFormat__cgen_u3187(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_175, result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					T31_.len = 0; T31_.p = NIM_NIL;
					T31_ = rawNewString(result.len + 8);
appendString((&T31_), result);
appendString((&T31_), TM__MQdRN7fpbG7rPm4JpVVAhA_177);
					payload_1 = T31_;
					addForwardStructFormat__cgen_u3187(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_178, payload_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					eqdestroy___system_u2691(payload_1);
				}
LA29_: ;
			}
LA23_: ;
			{
				NimStringV2 colontmpD__4;
				NimStringV2 res_1;
				colontmpD__2 = cacheGetType__cgen_u1466((*m_p0).typeCache, sig_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
				if (!(colontmpD__2.len == 0)) goto LA34_;
				res_1.len = 0; res_1.p = NIM_NIL;
				colontmpD__4 = eqdup___system_u2697(result);
				X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
				res_1 = rawNewString(((NI)80));
				prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_180);
				cgFormatValue__cgen_u163((&res_1), result);
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
				prepareAdd((&res_1), 13);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_182);
				cgFormatValue__cgen_u163((&res_1), result);
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
				prepareAdd((&res_1), 16);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_184);
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), res_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), res_1);
				pushType__cgen_u3159(m_p0, t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
				eqdestroy___system_u2691(res_1);
			}
LA34_: ;
			{
				LA16_:;
			}
			{
				oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___ast_u3378(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin16_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA12_;
LA14_: ;
		{
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 T40_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			T40_.len = 0; T40_.p = NIM_NIL;
			colontmpD__5 = getTypeForward__cgen_u3216(m_p0, t_p1, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			colontmpD__6 = seqStar__cgen_u3209(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			T40_ = rawNewString(colontmpD__5.len + colontmpD__6.len + 0);
appendString((&T40_), colontmpD__5);
appendString((&T40_), colontmpD__6);
			result = T40_;
			pushType__cgen_u3159(m_p0, t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			{
				LA39_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA12_: ;
	}
	break;
	default:
	{
		result = getTypeDescAux__cgen_u1419(m_p0, t_p1, check_p2, kind_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(etB_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, parseUntil__pureZparseutils_u266)(NIM_CHAR* s_p0, NI s_p0Len_0, NimStringV2* token_p1, NimStringV2 until_p2) {
	NI result;
	NI i_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	i_1 = ((NI)0);
	{
		while (1) {
			if (!(i_1 < s_p0Len_0)) goto LA2;
			{
				NIM_BOOL T5_;
				NI u_1;
				T5_ = (NIM_BOOL)0;
				T5_ = (((NI)0) < until_p2.len);
				if (!(T5_)) goto LA6_;
				T5_ = ((NU8)(s_p0[i_1]) == (NU8)(until_p2.p->data[((NI)0)]));
LA6_: ;
				if (!T5_) goto LA7_;
				u_1 = ((NI)1);
				{
					while (1) {
						NIM_BOOL T11_;
						NIM_BOOL T12_;
						T11_ = (NIM_BOOL)0;
						T12_ = (NIM_BOOL)0;
						T12_ = ((NI)(i_1 + u_1) < s_p0Len_0);
						if (!(T12_)) goto LA13_;
						T12_ = (u_1 < until_p2.len);
LA13_: ;
						T11_ = T12_;
						if (!(T11_)) goto LA14_;
						T11_ = ((NU8)(s_p0[(NI)(i_1 + u_1)]) == (NU8)(until_p2.p->data[u_1]));
LA14_: ;
						if (!T11_) goto LA10;
						u_1 += ((NI)1);
					} LA10: ;
				}
				{
					if (!(until_p2.len <= u_1)) goto LA17_;
					goto LA1;
				}
LA17_: ;
			}
LA7_: ;
			i_1 += ((NI)1);
		} LA2: ;
	} LA1: ;
	result = i_1;
	fastSubstr__pureZparseutils_u225(s_p0, s_p0Len_0, token_p1, result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, parseUntil__pureZparseutils_u966)(NimStringV2 s_p0, NimStringV2* token_p1, NimStringV2 until_p2, NI start_p3) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = parseUntil__pureZparseutils_u266((((s_p0).p) ? ((NIM_CHAR*)s_p0.p->data+(start_p3)) : NIM_NIL), ((s_p0.len-1))-(start_p3)+1, token_p1, until_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, skip__pureZparseutils_u145)(NIM_CHAR* s_p0, NI s_p0Len_0, NIM_CHAR* token_p1, NI token_p1Len_0) {
	NI result;
	result = ((NI)0);
	{
		while (1) {
			NIM_BOOL T3_;
			NIM_BOOL T4_;
			T3_ = (NIM_BOOL)0;
			T4_ = (NIM_BOOL)0;
			T4_ = (result < s_p0Len_0);
			if (!(T4_)) goto LA5_;
			T4_ = (result < token_p1Len_0);
LA5_: ;
			T3_ = T4_;
			if (!(T3_)) goto LA6_;
			T3_ = ((NU8)(s_p0[result]) == (NU8)(token_p1[result]));
LA6_: ;
			if (!T3_) goto LA2;
			result += ((NI)1);
		} LA2: ;
	}
	{
		if (!!((result == token_p1Len_0))) goto LA9_;
		result = ((NI)0);
	}
LA9_: ;
	return result;
}
static N_INLINE(NI, skip__pureZparseutils_u929)(NimStringV2 s_p0, NimStringV2 token_p1, NI start_p2) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = skip__pureZparseutils_u145((((s_p0).p) ? ((NIM_CHAR*)s_p0.p->data+(start_p2)) : NIM_NIL), ((s_p0.len-1))-(start_p2)+1, ((token_p1).p) ? (token_p1.p->data) : NIM_NIL, token_p1.len);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, skipWhitespace__pureZparseutils_u130)(NIM_CHAR* s_p0, NI s_p0Len_0) {
	NI result;
	result = ((NI)0);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = (result < s_p0Len_0);
			if (!(T3_)) goto LA4_;
			T3_ = (((NU8)(s_p0[result])) == ((NU8)(32)) || ((NU8)(s_p0[result])) == ((NU8)(9)) || ((NU8)(s_p0[result])) == ((NU8)(11)) || ((NU8)(s_p0[result])) == ((NU8)(13)) || ((NU8)(s_p0[result])) == ((NU8)(10)) || ((NU8)(s_p0[result])) == ((NU8)(12)));
LA4_: ;
			if (!T3_) goto LA2;
			result += ((NI)1);
		} LA2: ;
	}
	return result;
}
static N_INLINE(NI, skipWhitespace__pureZparseutils_u925)(NimStringV2 s_p0, NI start_p1) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = skipWhitespace__pureZparseutils_u130((((s_p0).p) ? ((NIM_CHAR*)s_p0.p->data+(start_p1)) : NIM_NIL), ((s_p0.len-1))-(start_p1)+1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, parseVFunctionDecl__cgen_u8828)(NimStringV2 val_p0, NimStringV2* name_p1, NimStringV2* params_p2, NimStringV2* retType_p3, NimStringV2* superCall_p4, NIM_BOOL* isFnConst_p5, NIM_BOOL* isOverride_p6, NIM_BOOL* isMemberVirtual_p7, NIM_BOOL* isStatic_p8, NIM_BOOL isCtor_p9, NIM_BOOL isFunctor_p10) {
	NimStringV2 afterParams_1;
	NimStringV2 inp_1;
	NimStringV2 T81_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	afterParams_1.len = 0; afterParams_1.p = NIM_NIL;
	inp_1.len = 0; inp_1.p = NIM_NIL;
	afterParams_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_195;
	{
		NI idx_1;
		NIM_BOOL res_1;
		NI resLen_1;
		NimStringV2 colontmpD_;
		NI T40_;
		NI T41_;
		NI T42_;
		eqcopy___system_u2694((&inp_1), val_p0);
		idx_1 = ((NI)0);
		res_1 = NIM_FALSE;
		resLen_1 = parseUntil__pureZparseutils_u966(inp_1, name_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_196, idx_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NI resLen_2;
			if (!(((NI)0) <= resLen_1)) goto LA6_;
			idx_1 += resLen_1;
			resLen_2 = skip__pureZparseutils_u929(inp_1, TM__MQdRN7fpbG7rPm4JpVVAhA_197, idx_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				NI resLen_3;
				if (!!((resLen_2 == ((NI)0)))) goto LA10_;
				idx_1 += resLen_2;
				resLen_3 = parseUntil__pureZparseutils_u966(inp_1, params_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_198, idx_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NI resLen_4;
					if (!(((NI)0) <= resLen_3)) goto LA14_;
					idx_1 += resLen_3;
					resLen_4 = skip__pureZparseutils_u929(inp_1, TM__MQdRN7fpbG7rPm4JpVVAhA_199, idx_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						NI T20_;
						NI resLen_5;
						if (!!((resLen_4 == ((NI)0)))) goto LA18_;
						idx_1 += resLen_4;
						T20_ = (NI)0;
						T20_ = skipWhitespace__pureZparseutils_u925(inp_1, idx_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						idx_1 += T20_;
						resLen_5 = parseUntil__pureZparseutils_u966(inp_1, (&afterParams_1), TM__MQdRN7fpbG7rPm4JpVVAhA_200, idx_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						{
							if (!(((NI)0) <= resLen_5)) goto LA23_;
							idx_1 += resLen_5;
							res_1 = NIM_TRUE;
						}
LA23_: ;
					}
LA18_: ;
				}
LA14_: ;
			}
LA10_: ;
		}
LA6_: ;
		if (!res_1) goto LA25_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		{
			NIM_BOOL T30_;
			T30_ = (NIM_BOOL)0;
			colontmpD_ = nsuStrip((*name_p1), NIM_TRUE, NIM_TRUE, TM__MQdRN7fpbG7rPm4JpVVAhA_201);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			T30_ = eqStrings(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_203);
			if (!(T30_)) goto LA31_;
			T30_ = ((*params_p2).len == 0);
LA31_: ;
			if (!T30_) goto LA32_;
			parseVFunctionDecl__cgen_u8828(afterParams_1, name_p1, params_p2, retType_p3, superCall_p4, isFnConst_p5, isOverride_p6, isMemberVirtual_p7, isStatic_p8, isCtor_p9, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(inp_1);
			eqdestroy___system_u2691(afterParams_1);
			goto BeforeRet_;
		}
LA32_: ;
		{
			NI T36_;
			NimStringV2 T39_;
			T36_ = (NI)0;
			T36_ = nsuFindStr((*name_p1), TM__MQdRN7fpbG7rPm4JpVVAhA_205, ((NI)0), ((NI)-1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			if (!(((NI)-1) < T36_)) goto LA37_;
			(*isStatic_p8) = NIM_TRUE;
			T39_.len = 0; T39_.p = NIM_NIL;
			T39_ = nsuReplaceStr((*name_p1), TM__MQdRN7fpbG7rPm4JpVVAhA_206, TM__MQdRN7fpbG7rPm4JpVVAhA_207);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T39_); goto LA27_;}
			eqsink___system_u2700((&(*name_p1)), T39_);
		}
LA37_: ;
		T40_ = (NI)0;
		T40_ = nsuFindStr(afterParams_1, TM__MQdRN7fpbG7rPm4JpVVAhA_208, ((NI)0), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		(*isFnConst_p5) = (((NI)-1) < T40_);
		T41_ = (NI)0;
		T41_ = nsuFindStr(afterParams_1, TM__MQdRN7fpbG7rPm4JpVVAhA_210, ((NI)0), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		(*isOverride_p6) = (((NI)-1) < T41_);
		T42_ = (NI)0;
		T42_ = nsuFindStr((*name_p1), TM__MQdRN7fpbG7rPm4JpVVAhA_212, ((NI)0), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		(*isMemberVirtual_p7) = (((NI)-1) < T42_);
		{
			NimStringV2 T47_;
			if (!(*isMemberVirtual_p7)) goto LA45_;
			T47_.len = 0; T47_.p = NIM_NIL;
			T47_ = nsuReplaceStr((*name_p1), TM__MQdRN7fpbG7rPm4JpVVAhA_213, TM__MQdRN7fpbG7rPm4JpVVAhA_214);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T47_); goto LA27_;}
			eqsink___system_u2700((&(*name_p1)), T47_);
		}
LA45_: ;
		{
			if (!isFunctor_p10) goto LA50_;
			eqsink___system_u2700((&(*name_p1)), TM__MQdRN7fpbG7rPm4JpVVAhA_216);
		}
LA50_: ;
		{
			NimStringV2 inp_2;
			NI idx_2;
			NIM_BOOL res_2;
			NI resLen_6;
			if (!isCtor_p9) goto LA54_;
			inp_2.len = 0; inp_2.p = NIM_NIL;
			inp_2 = afterParams_1;
			eqwasMoved___system_u2688((&afterParams_1));
			idx_2 = ((NI)0);
			res_2 = NIM_FALSE;
			resLen_6 = skip__pureZparseutils_u929(inp_2, TM__MQdRN7fpbG7rPm4JpVVAhA_218, idx_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			{
				NI T60_;
				NI resLen_7;
				if (!!((resLen_6 == ((NI)0)))) goto LA58_;
				idx_2 += resLen_6;
				T60_ = (NI)0;
				T60_ = skipWhitespace__pureZparseutils_u925(inp_2, idx_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				idx_2 += T60_;
				resLen_7 = parseUntil__pureZparseutils_u966(inp_2, superCall_p4, TM__MQdRN7fpbG7rPm4JpVVAhA_219, idx_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				{
					if (!(((NI)0) <= resLen_7)) goto LA63_;
					idx_2 += resLen_7;
					res_2 = NIM_TRUE;
				}
LA63_: ;
			}
LA58_: ;
			(void)(res_2);
			eqdestroy___system_u2691(inp_2);
		}
		goto LA52_;
LA54_: ;
		{
			NimStringV2 inp_3;
			NI idx_3;
			NIM_BOOL res_3;
			NI resLen_8;
			inp_3.len = 0; inp_3.p = NIM_NIL;
			inp_3 = afterParams_1;
			eqwasMoved___system_u2688((&afterParams_1));
			idx_3 = ((NI)0);
			res_3 = NIM_FALSE;
			resLen_8 = skip__pureZparseutils_u929(inp_3, TM__MQdRN7fpbG7rPm4JpVVAhA_221, idx_3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			{
				NI T70_;
				NI resLen_9;
				if (!!((resLen_8 == ((NI)0)))) goto LA68_;
				idx_3 += resLen_8;
				T70_ = (NI)0;
				T70_ = skipWhitespace__pureZparseutils_u925(inp_3, idx_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				idx_3 += T70_;
				resLen_9 = parseUntil__pureZparseutils_u966(inp_3, retType_p3, TM__MQdRN7fpbG7rPm4JpVVAhA_222, idx_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				{
					NI resLen_10;
					if (!(((NI)0) <= resLen_9)) goto LA73_;
					idx_3 += resLen_9;
					resLen_10 = skip__pureZparseutils_u929(inp_3, TM__MQdRN7fpbG7rPm4JpVVAhA_223, idx_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					{
						if (!!((resLen_10 == ((NI)0)))) goto LA77_;
						idx_3 += resLen_10;
						res_3 = NIM_TRUE;
					}
LA77_: ;
				}
LA73_: ;
			}
LA68_: ;
			(void)(res_3);
			eqdestroy___system_u2691(inp_3);
		}
LA52_: ;
		{
			LA27_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA25_: ;
	T81_.len = 0; T81_.p = NIM_NIL;
	T81_ = rawNewString((*params_p2).len + 2);
appendString((&T81_), TM__MQdRN7fpbG7rPm4JpVVAhA_224);
appendString((&T81_), (*params_p2));
appendString((&T81_), TM__MQdRN7fpbG7rPm4JpVVAhA_225);
	eqsink___system_u2700((&(*params_p2)), T81_);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(inp_1);
		eqdestroy___system_u2691(afterParams_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA, mapSetType__cgen_u1311)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA result;
	NI64 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI64)0;
	T1_ = getSize__types_u3397(conf_p0, typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch (((NI) (T1_))) {
	case ((NI)1):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)4);
	}
	break;
	case ((NI)2):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)5);
	}
	break;
	case ((NI)4):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)6);
	}
	break;
	case ((NI)8):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)7);
	}
	break;
	default:
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA, mapType__cgen_u1315)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NIM_BOOL isParam_p2) {
	tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA result;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin23_;
NIM_BOOL oldNimErrFin41_;
NIM_BOOL oldNimErrFin45_;
NIM_BOOL oldNimErrFin74_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
	switch ((*typ_p1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)2);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)1);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)20);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		result = mapSetType__cgen_u1311(conf_p0, typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		{
			if (!isParam_p2) goto LA9_;
			result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17);
		}
		goto LA7_;
LA9_: ;
		{
			result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)19);
		}
LA7_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)19);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)52) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)53):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		{
			if (!!((((*typ_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)10)))&63U)))!=0))) goto LA18_;
			failedAssertImpl__stdZassertions_u79(TM__MQdRN7fpbG7rPm4JpVVAhA_228);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		}
LA18_: ;
		colontmpD_ = skipModifier__ast_u5338(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		result = mapType__cgen_u1315(conf_p0, colontmpD_, isParam_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)15):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)55):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = skipModifier__ast_u5338(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		result = mapType__cgen_u1315(conf_p0, colontmpD__2, isParam_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		{
			LA23_:;
		}
		{
			oldNimErrFin23_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin23_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	{
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T29_;
			NIM_BOOL T30_;
			T29_ = firstOrd__types_u1182(conf_p0, typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T30_ = (NIM_BOOL)0;
			T30_ = lt___int128_u933(T29_, IL64(0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T30_) goto LA31_;
			result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)6);
		}
		goto LA27_;
LA31_: ;
		{
			NI64 T34_;
			T34_ = (NI64)0;
			T34_ = getSize__types_u3397(conf_p0, typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			switch (((NI) (T34_))) {
			case ((NI)1):
			{
				result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)13);
			}
			break;
			case ((NI)2):
			{
				result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)14);
			}
			break;
			case ((NI)4):
			{
				result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)6);
			}
			break;
			case ((NI)8):
			{
				result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)7);
			}
			break;
			default:
			{
				result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)6);
			}
			break;
			}
		}
LA27_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		colontmpD__3 = NIM_NIL;
		colontmpD__3 = elementType__ast_u5331(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		result = mapType__cgen_u1315(conf_p0, colontmpD__3, isParam_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		{
			LA41_:;
		}
		{
			oldNimErrFin41_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin41_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* base_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		base_1 = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		colontmpD__4 = elementType__ast_u5331(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		base_1 = skipTypes__ast_u5379(colontmpD__4, TM__MQdRN7fpbG7rPm4JpVVAhA_170);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		switch ((*base_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
		{
			result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)18);
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
		{
			{
				tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T50_;
				T50_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
				T50_ = mapSetType__cgen_u1311(conf_p0, base_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
				if (!(T50_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17))) goto LA51_;
				result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)18);
			}
			goto LA48_;
LA51_: ;
			{
				result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)20);
			}
LA48_: ;
		}
		break;
		default:
		{
			result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)20);
		}
		break;
		}
		{
			LA45_:;
		}
		{
			oldNimErrFin45_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(base_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin45_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)20);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)22);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T60_;
		T60_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		{
			if (!!(((*typ_p1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9)))) goto LA63_;
			result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)23);
		}
		goto LA61_;
LA63_: ;
		{
			result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)19);
		}
LA61_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)21);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)24);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA) ((NI)((NI)((*typ_p1).kind - ((NI)31)) + ((NI)3))));
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
			if (!!(((*typ_p1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA72_;
			colontmpD__5 = NIM_NIL;
			colontmpD__5 = skipModifier__ast_u5338(typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
			result = mapType__cgen_u1315(conf_p0, colontmpD__5, isParam_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
			{
				LA74_:;
			}
			{
				oldNimErrFin74_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin74_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA70_;
LA72_: ;
		{
			result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0);
			{
				NimStringV2 colontmpD__6;
				NimStringV2 colontmpD__7;
				NimStringV2 T82_;
				if (!NIM_TRUE) goto LA80_;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				T82_.len = 0; T82_.p = NIM_NIL;
				colontmpD__6 = dollar___ast_u182((*typ_p1).kind);
				T82_ = rawNewString(colontmpD__6.len + 39);
appendString((&T82_), TM__MQdRN7fpbG7rPm4JpVVAhA_230);
appendString((&T82_), colontmpD__6);
				colontmpD__7 = T82_;
				failedAssertImpl__stdZassertions_u79(colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
			}
LA80_: ;
		}
LA70_: ;
	}
	break;
	default:
	{
		result = ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0);
		{
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 T88_;
			if (!NIM_TRUE) goto LA86_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			T88_.len = 0; T88_.p = NIM_NIL;
			colontmpD__8 = dollar___ast_u182((*typ_p1).kind);
			T88_ = rawNewString(colontmpD__8.len + 39);
appendString((&T88_), TM__MQdRN7fpbG7rPm4JpVVAhA_232);
appendString((&T88_), colontmpD__8);
			colontmpD__9 = T88_;
			failedAssertImpl__stdZassertions_u79(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
		}
LA86_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, baseClass__ast_u5348)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isObjLackingTypeField__types_u2952)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	NIM_BOOL T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*typ_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T4_ = (NIM_BOOL)0;
	T4_ = (((*typ_p0).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)2)))&63U)))!=0);
	if (!(T4_)) goto LA5_;
	colontmpD_ = baseClass__ast_u5348(typ_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T4_ = (colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
LA5_: ;
	T3_ = T4_;
	if (T3_) goto LA6_;
	T3_ = isPureObject__types_u121(typ_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA6_: ;
	T1_ = T3_;
LA2_: ;
	result = T1_;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInvalidReturnType__cgen_u1424)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NIM_BOOL isProc_p2) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* rettype_1;
	NIM_BOOL isAllowedCall_1;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	rettype_1 = NIM_NIL;
	eqcopy___ast_u3381(&rettype_1, typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	isAllowedCall_1 = NIM_TRUE;
	{
		if (!isProc_p2) goto LA4_;
		eqcopy___ast_u3381(&rettype_1, (*rettype_1).sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		isAllowedCall_1 = ((*typ_p1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9) || (*typ_p1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)5) || (*typ_p1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		NIM_BOOL T10_;
		NI64 T12_;
		T8_ = (NIM_BOOL)0;
		T8_ = (rettype_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (T8_) goto LA9_;
		T10_ = (NIM_BOOL)0;
		T10_ = isAllowedCall_1;
		if (!(T10_)) goto LA11_;
		T12_ = (NI64)0;
		T12_ = getSize__types_u3397(conf_p0, rettype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T10_ = (((NI64) ((NI)((*conf_p0).target.floatSize * ((NI)3)))) < T12_);
LA11_: ;
		T8_ = T10_;
LA9_: ;
		if (!T8_) goto LA13_;
		result = NIM_TRUE;
	}
	goto LA6_;
LA13_: ;
	{
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T16_;
		T16_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		T16_ = mapType__cgen_u1315(conf_p0, rettype_1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		switch (T16_) {
		case ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			colontmpD_ = NIM_NIL;
			colontmpD_ = skipTypes__ast_u5379(rettype_1, TM__MQdRN7fpbG7rPm4JpVVAhA_170);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			result = !(((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21)));
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)19):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
			t_1 = NIM_NIL;
			t_1 = skipTypes__ast_u5379(rettype_1, TM__MQdRN7fpbG7rPm4JpVVAhA_170);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			{
				NIM_BOOL T22_;
				NIM_BOOL T23_;
				NIM_BOOL T26_;
				T22_ = (NIM_BOOL)0;
				T23_ = (NIM_BOOL)0;
				T23_ = isImportedCppType__cgen_u1384(rettype_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				if (T23_) goto LA24_;
				T23_ = isImportedCppType__cgen_u1384(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
LA24_: ;
				T22_ = T23_;
				if (T22_) goto LA25_;
				T26_ = (NIM_BOOL)0;
				T26_ = ((*typ_p1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)2));
				if (!(T26_)) goto LA27_;
				T26_ = ((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5));
LA27_: ;
				T22_ = T26_;
LA25_: ;
				if (!T22_) goto LA28_;
				result = NIM_FALSE;
			}
			goto LA20_;
LA28_: ;
			{
				NIM_BOOL T31_;
				NIM_BOOL T32_;
				NIM_BOOL T34_;
				NIM_BOOL T36_;
				NIM_BOOL T38_;
				NI64 T39_;
				NIM_BOOL T41_;
				T31_ = (NIM_BOOL)0;
				T32_ = (NIM_BOOL)0;
				T32_ = containsGarbageCollectedRef__types_u555(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				if (T32_) goto LA33_;
				T34_ = (NIM_BOOL)0;
				T34_ = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
				if (!(T34_)) goto LA35_;
				T36_ = (NIM_BOOL)0;
				T36_ = isObjLackingTypeField__types_u2952(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				T34_ = !(T36_);
LA35_: ;
				T32_ = T34_;
LA33_: ;
				T31_ = T32_;
				if (T31_) goto LA37_;
				T38_ = (NIM_BOOL)0;
				T39_ = (NI64)0;
				T39_ = getSize__types_u3397(conf_p0, rettype_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				T38_ = (T39_ == IL64(-3));
				if (!(T38_)) goto LA40_;
				T41_ = (NIM_BOOL)0;
				T41_ = ((*t_1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
				if (T41_) goto LA42_;
				T41_ = !((((*(*t_1).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0));
LA42_: ;
				T38_ = T41_;
LA40_: ;
				T31_ = T38_;
LA37_: ;
				result = T31_;
			}
LA20_: ;
			{
				LA19_:;
			}
			{
				oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin19_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
LA6_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(rettype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fillParamName__cgen_u916)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		if (!((*s_p1).loc.snippet.len == 0)) goto LA3_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		res_1 = mangle__mangleutils_u4((*(*s_p1).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD_ = mangleParamExt__mangleutils_u32(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_1), colontmpD_.len + 0);
appendString((&res_1), colontmpD_);
		eqsink___system_u2700((&(*s_p1).loc.snippet), res_1);
		eqdestroy___system_u2691(colontmpD_);
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg, paramStorageLoc__cgen_u3542)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p0) {
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	{
		colontmpD_ = skipTypes__ast_u5379((*param_p0).typ, TM__MQdRN7fpbG7rPm4JpVVAhA_238);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48)))) goto LA3_;
		result = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2);
	}
	goto LA1_;
LA3_: ;
	{
		result = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0);
	}
LA1_: ;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2*, X5BX5D___cgen_u3675)(NimStringV2* s_p0, NI s_p0Len_0, NI i_p1) {
	NimStringV2* result;
	result = (&s_p0[(NI)(s_p0Len_0 - i_p1)]);
	return result;
}
static N_INLINE(NI, find__cgen_u3719)(tySequence__lBgZ7a89beZGYPl8PiANMTA a_p0, NIM_CHAR item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NIM_CHAR* i_1;
		NI i_2;
		NI L_1;
		NI T2_;
		i_1 = (NIM_CHAR*)0;
		i_2 = ((NI)0);
		T2_ = a_p0.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA4;
				i_1 = (&a_p0.p->data[i_2]);
				{
					if (!((NU8)((*i_1)) == (NU8)(item_p1))) goto LA7_;
					goto BeforeRet_;
				}
LA7_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, multiFormat__cgen_u3707)(NimStringV2* frmt_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ* args_p2, NI args_p2Len_0) {
	NimStringV2 res_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	res_1.len = 0; res_1.p = NIM_NIL;
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ arg_1;
		NI T3_;
		NI i_1;
		NI num_1;
		arg_1.len = 0; arg_1.p = NIM_NIL;
		res_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_250;
		T3_ = (NI)0;
		T3_ = find__cgen_u3719(TM__MQdRN7fpbG7rPm4JpVVAhA_251, 39);
		arg_1 = args_p2[T3_];
		i_1 = ((NI)0);
		num_1 = ((NI)0);
		{
			while (1) {
				NI start_1;
				if (!(i_1 < (*frmt_p0).len)) goto LA5;
				{
					if (!((NU8)((*frmt_p0).p->data[i_1]) == (NU8)(39))) goto LA8_;
					i_1 += ((NI)1);
					switch (((NU8)((*frmt_p0).p->data[i_1]))) {
					case 39:
					{
						nimAddCharV1((&res_1), 39);
						i_1 += ((NI)1);
					}
					break;
					case 48 ... 57:
					{
						NI j_1;
						j_1 = ((NI)0);
						{
							while (1) {
								j_1 = (NI)((NI)((NI)(j_1 * ((NI)10)) + ((NU8)((*frmt_p0).p->data[i_1]))) - ((NI)48));
								i_1 += ((NI)1);
								{
									NIM_BOOL T16_;
									T16_ = (NIM_BOOL)0;
									T16_ = ((*frmt_p0).len <= i_1);
									if (T16_) goto LA17_;
									T16_ = !((((NU8)((*frmt_p0).p->data[i_1])) >= ((NU8)(48)) && ((NU8)((*frmt_p0).p->data[i_1])) <= ((NU8)(57))));
LA17_: ;
									if (!T16_) goto LA18_;
									goto LA12;
								}
LA18_: ;
							}
						} LA12: ;
						num_1 = j_1;
						{
							NI T22_;
							NimStringV2 colontmpD_;
							NimStringV2 T25_;
							T22_ = (arg_1.len-1);
							if (!((NI)(T22_ + ((NI)1)) < j_1)) goto LA23_;
							colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
							T25_.len = 0; T25_.p = NIM_NIL;
							T25_ = rawNewString((*frmt_p0).len + 23);
appendString((&T25_), TM__MQdRN7fpbG7rPm4JpVVAhA_254);
appendString((&T25_), (*frmt_p0));
							colontmpD_ = T25_;
							raiseAssert__stdZassertions_u15(colontmpD_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___system_u2691(colontmpD_);
						}
						goto LA20_;
LA23_: ;
						{
							prepareAdd((&res_1), arg_1.p->data[(NI)(j_1 - ((NI)1))].len + 0);
appendString((&res_1), arg_1.p->data[(NI)(j_1 - ((NI)1))]);
						}
LA20_: ;
					}
					break;
					default:
					{
						NimStringV2 colontmpD__2;
						NimStringV2 T28_;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						T28_.len = 0; T28_.p = NIM_NIL;
						T28_ = rawNewString((*frmt_p0).len + 23);
appendString((&T28_), TM__MQdRN7fpbG7rPm4JpVVAhA_255);
appendString((&T28_), (*frmt_p0));
						colontmpD__2 = T28_;
						raiseAssert__stdZassertions_u15(colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(colontmpD__2);
					}
					break;
					}
				}
LA8_: ;
				start_1 = i_1;
				{
					while (1) {
						if (!(i_1 < (*frmt_p0).len)) goto LA30;
						{
							if (!!(((NU8)((*frmt_p0).p->data[i_1]) == (NU8)(39)))) goto LA33_;
							i_1 += ((NI)1);
						}
						goto LA31_;
LA33_: ;
						{
							goto LA29;
						}
LA31_: ;
					} LA30: ;
				} LA29: ;
				{
					NimStringV2 colontmpD__3;
					if (!(start_1 <= (NI)(i_1 - ((NI)1)))) goto LA38_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__3 = substr__system_u8632((*frmt_p0), start_1, (NI)(i_1 - ((NI)1)));
					prepareAdd((&res_1), colontmpD__3.len + 0);
appendString((&res_1), colontmpD__3);
					eqdestroy___system_u2691(colontmpD__3);
				}
LA38_: ;
			} LA5: ;
		}
		eqsink___system_u2700((&(*frmt_p0)), res_1);
		eqwasMoved___system_u2688((&res_1));
	}
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ arg_2;
		NI T41_;
		NI i_2;
		NI num_2;
		arg_2.len = 0; arg_2.p = NIM_NIL;
		eqsink___system_u2700((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_256);
		T41_ = (NI)0;
		T41_ = find__cgen_u3719(TM__MQdRN7fpbG7rPm4JpVVAhA_251, 35);
		arg_2 = args_p2[T41_];
		i_2 = ((NI)0);
		num_2 = ((NI)0);
		{
			while (1) {
				NI start_2;
				if (!(i_2 < (*frmt_p0).len)) goto LA43;
				{
					if (!((NU8)((*frmt_p0).p->data[i_2]) == (NU8)(35))) goto LA46_;
					i_2 += ((NI)1);
					switch (((NU8)((*frmt_p0).p->data[i_2]))) {
					case 35:
					{
						nimAddCharV1((&res_1), 35);
						i_2 += ((NI)1);
					}
					break;
					case 48 ... 57:
					{
						NI j_2;
						j_2 = ((NI)0);
						{
							while (1) {
								j_2 = (NI)((NI)((NI)(j_2 * ((NI)10)) + ((NU8)((*frmt_p0).p->data[i_2]))) - ((NI)48));
								i_2 += ((NI)1);
								{
									NIM_BOOL T54_;
									T54_ = (NIM_BOOL)0;
									T54_ = ((*frmt_p0).len <= i_2);
									if (T54_) goto LA55_;
									T54_ = !((((NU8)((*frmt_p0).p->data[i_2])) >= ((NU8)(48)) && ((NU8)((*frmt_p0).p->data[i_2])) <= ((NU8)(57))));
LA55_: ;
									if (!T54_) goto LA56_;
									goto LA50;
								}
LA56_: ;
							}
						} LA50: ;
						num_2 = j_2;
						{
							NI T60_;
							NimStringV2 colontmpD__4;
							NimStringV2 T63_;
							T60_ = (arg_2.len-1);
							if (!((NI)(T60_ + ((NI)1)) < j_2)) goto LA61_;
							colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
							T63_.len = 0; T63_.p = NIM_NIL;
							T63_ = rawNewString((*frmt_p0).len + 23);
appendString((&T63_), TM__MQdRN7fpbG7rPm4JpVVAhA_257);
appendString((&T63_), (*frmt_p0));
							colontmpD__4 = T63_;
							raiseAssert__stdZassertions_u15(colontmpD__4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___system_u2691(colontmpD__4);
						}
						goto LA58_;
LA61_: ;
						{
							prepareAdd((&res_1), arg_2.p->data[(NI)(j_2 - ((NI)1))].len + 0);
appendString((&res_1), arg_2.p->data[(NI)(j_2 - ((NI)1))]);
						}
LA58_: ;
					}
					break;
					default:
					{
						NimStringV2 colontmpD__5;
						NimStringV2 T66_;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						T66_.len = 0; T66_.p = NIM_NIL;
						T66_ = rawNewString((*frmt_p0).len + 23);
appendString((&T66_), TM__MQdRN7fpbG7rPm4JpVVAhA_258);
appendString((&T66_), (*frmt_p0));
						colontmpD__5 = T66_;
						raiseAssert__stdZassertions_u15(colontmpD__5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(colontmpD__5);
					}
					break;
					}
				}
LA46_: ;
				start_2 = i_2;
				{
					while (1) {
						if (!(i_2 < (*frmt_p0).len)) goto LA68;
						{
							if (!!(((NU8)((*frmt_p0).p->data[i_2]) == (NU8)(35)))) goto LA71_;
							i_2 += ((NI)1);
						}
						goto LA69_;
LA71_: ;
						{
							goto LA67;
						}
LA69_: ;
					} LA68: ;
				} LA67: ;
				{
					NimStringV2 colontmpD__6;
					if (!(start_2 <= (NI)(i_2 - ((NI)1)))) goto LA76_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__6 = substr__system_u8632((*frmt_p0), start_2, (NI)(i_2 - ((NI)1)));
					prepareAdd((&res_1), colontmpD__6.len + 0);
appendString((&res_1), colontmpD__6);
					eqdestroy___system_u2691(colontmpD__6);
				}
LA76_: ;
			} LA43: ;
		}
		eqsink___system_u2700((&(*frmt_p0)), res_1);
		eqwasMoved___system_u2688((&res_1));
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, X5BX5Deq___system_u8114)(NimStringV2* s_p0, NI i_p1, NIM_CHAR x_p2) {
	nimPrepareStrMutationV2((&(*s_p0)));
	(*s_p0).p->data[(NI)((*s_p0).len - i_p1)] = x_p2;
}
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1) {
	tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genMemberProcParams__cgen_u3576)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1, NimStringV2* superCall_p2, NimStringV2* rettype_p3, NimStringV2* name_p4, NimStringV2* params_p5, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p6, NIM_BOOL declareEnvironment_p7, NIM_BOOL weakDep_p8) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ types_1;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ names_1;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ args_1;
	NI colontmpD__2;
	NI colontmpD__3;
	NIM_BOOL isCtor_1;
NIM_BOOL oldNimErrFin20_;
NIM_BOOL oldNimErrFin25_;
NIM_BOOL oldNimErrFin34_;
	NI firstParam_1;
NIM_BOOL oldNimErrFin52_;
	tyArray__MELNUjckgdZAqcL9cILBY6A T99_;
	tyArray__MELNUjckgdZAqcL9cILBY6A T100_;
	tyArray__MELNUjckgdZAqcL9cILBY6A T101_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	types_1.len = 0; types_1.p = NIM_NIL;
	names_1.len = 0; names_1.p = NIM_NIL;
	args_1.len = 0; args_1.p = NIM_NIL;
	colontmpD__2 = (NI)0;
	colontmpD__3 = (NI)0;
	eqcopy___ast_u3381(&t_1, (*prc_p1).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	isCtor_1 = (((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29)))&63U)))!=0);
	{
		NIM_BOOL T4_;
		NIM_BOOL T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = isCtor_1;
		if (T4_) goto LA5_;
		T6_ = (NIM_BOOL)0;
		T6_ = ((NU8)((*name_p4).p->data[((NI)0)]) == (NU8)(126));
		if (!(T6_)) goto LA7_;
		T6_ = (((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)52)))&63U)))!=0);
LA7_: ;
		T4_ = T6_;
LA5_: ;
		if (!T4_) goto LA8_;
		eqsink___system_u2700((&(*rettype_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_226);
	}
	goto LA2_;
LA8_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		colontmpD_ = returnType__ast_u5354(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T11_ = (colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (T11_) goto LA12_;
		T11_ = isInvalidReturnType__cgen_u1424((*(*m_p0).g).config, t_1, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA12_: ;
		if (!T11_) goto LA13_;
		eqsink___system_u2700((&(*rettype_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_233);
	}
	goto LA2_;
LA13_: ;
	{
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			NimStringV2 T21_;
			if (!((*rettype_p3).len == 0)) goto LA18_;
			colontmpD__4 = NIM_NIL;
			colontmpD__4 = returnType__ast_u5354(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T21_.len = 0; T21_.p = NIM_NIL;
			T21_ = getTypeDescAux__cgen_u1419(m_p0, colontmpD__4, check_p6, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)5));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T21_); goto LA20_;}
			eqsink___system_u2700((&(*rettype_p3)), T21_);
			{
				LA20_:;
			}
			{
				oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin20_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA16_;
LA18_: ;
		{
			NimStringV2 colontmpD__5;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
			NimStringV2 colontmpD__7;
			tyArray__YgExxhfgKcesA5EOUj1MOA T26_;
			NimStringV2 T27_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6 = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__5 = nsuReplaceStr((*rettype_p3), TM__MQdRN7fpbG7rPm4JpVVAhA_235, TM__MQdRN7fpbG7rPm4JpVVAhA_237);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			colontmpD__6 = returnType__ast_u5354(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			colontmpD__7 = getTypeDescAux__cgen_u1419(m_p0, colontmpD__6, check_p6, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)5));
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			T26_[0] = colontmpD__7;
			T27_.len = 0; T27_.p = NIM_NIL;
			T27_ = runtimeFormat__ropes_u39(colontmpD__5, T26_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T27_); goto LA25_;}
			eqsink___system_u2700((&(*rettype_p3)), T27_);
			{
				LA25_:;
			}
			{
				oldNimErrFin25_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___ast_u3378(colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__5);
				*nimErr_ = oldNimErrFin25_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA16_: ;
	}
LA2_: ;
	types_1.len = 0; types_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	names_1.len = 0; names_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	args_1.len = 0; args_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* this_1;
		NimStringV2 colontmpD__8;
		tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg T35_;
		NimStringV2 T41_;
		if (!!(isCtor_1)) goto LA32_;
		this_1 = NIM_NIL;
		eqcopy___ast_u4577(&this_1, (*(*(*t_1).n)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		fillParamName__cgen_u916(m_p0, this_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		T35_ = (tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0;
		T35_ = paramStorageLoc__cgen_u3542(this_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		fillLoc__cgen_u88((&(*this_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)4), (*(*t_1).n)._kind_6.sons.p->data[((NI)1)], T35_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		{
			if (!((*(*this_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA38_;
			eqsink___system_u2700((&(*this_1).loc.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_240);
		}
		goto LA36_;
LA38_: ;
		{
			eqsink___system_u2700((&(*this_1).loc.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_242);
		}
LA36_: ;
		colontmpD__8 = eqdup___system_u2697((*this_1).loc.snippet);
		add__stdZenumutils_u71((&names_1), colontmpD__8);
		T41_.len = 0; T41_.p = NIM_NIL;
		T41_ = getTypeDescWeak__cgen_u3400(m_p0, (*this_1).typ, check_p6, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T41_); goto LA34_;}
		add__stdZenumutils_u71((&types_1), T41_);
		{
			LA34_:;
		}
		{
			oldNimErrFin34_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(this_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin34_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA32_: ;
	{
		if (!isCtor_1) goto LA46_;
		colontmpD__2 = ((NI)1);
		firstParam_1 = colontmpD__2;
	}
	goto LA44_;
LA46_: ;
	{
		colontmpD__3 = ((NI)2);
		firstParam_1 = colontmpD__3;
	}
LA44_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190((*t_1).n);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = firstParam_1;
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_1;
				NimStringV2 typ_1;
				NimStringV2 name_2;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
				tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q descKind_1;
				tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg T66_;
				NimStringV2 blitTmp_1;
				NimStringV2 blitTmp_2;
				if (!(i_2 < colontmp_)) goto LA51;
				param_1 = NIM_NIL;
				typ_1.len = 0; typ_1.p = NIM_NIL;
				name_2.len = 0; name_2.p = NIM_NIL;
				colontmpD__9 = NIM_NIL;
				i_1 = i_2;
				{
					if (!!(((*(*(*t_1).n)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA55_;
					internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*(*t_1).n).info, TM__MQdRN7fpbG7rPm4JpVVAhA_244, TM__MQdRN7fpbG7rPm4JpVVAhA_245);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				}
LA55_: ;
				eqcopy___ast_u4577(&param_1, (*(*(*t_1).n)._kind_6.sons.p->data[i_1])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				descKind_1 = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0);
				{
					if (!(((*param_1).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)20)))&31U)))!=0)) goto LA59_;
					{
						if (!((*(*param_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11))) goto LA63_;
						descKind_1 = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)2);
					}
					goto LA61_;
LA63_: ;
					{
						descKind_1 = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)1);
					}
LA61_: ;
				}
LA59_: ;
				typ_1.len = 0; typ_1.p = NIM_NIL;
				name_2.len = 0; name_2.p = NIM_NIL;
				fillParamName__cgen_u916(m_p0, param_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				T66_ = (tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0;
				T66_ = paramStorageLoc__cgen_u3542(param_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				fillLoc__cgen_u88((&(*param_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)4), (*(*t_1).n)._kind_6.sons.p->data[i_1], T66_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				{
					NIM_BOOL T69_;
					NimStringV2 colontmpD__10;
					NimStringV2 T74_;
					T69_ = (NIM_BOOL)0;
					colontmpD__9 = returnType__ast_u5354(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					T69_ = ccgIntroducedPtr__ccgutils_u130((*(*m_p0).g).config, param_1, colontmpD__9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					if (!(T69_)) goto LA70_;
					T69_ = (descKind_1 == ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
LA70_: ;
					if (!T69_) goto LA71_;
					colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
					T74_.len = 0; T74_.p = NIM_NIL;
					colontmpD__10 = getTypeDescWeak__cgen_u3400(m_p0, (*param_1).typ, check_p6, descKind_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
					T74_ = rawNewString(colontmpD__10.len + 1);
appendString((&T74_), colontmpD__10);
appendString((&T74_), TM__MQdRN7fpbG7rPm4JpVVAhA_246);
					typ_1 = T74_;
					(*param_1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
					(*param_1).loc.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0);
					{
						LA73_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__10);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				}
				goto LA67_;
LA71_: ;
				{
					if (!weakDep_p8) goto LA78_;
					typ_1 = getTypeDescWeak__cgen_u3400(m_p0, (*param_1).typ, check_p6, descKind_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				}
				goto LA67_;
LA78_: ;
				{
					typ_1 = getTypeDescAux__cgen_u1419(m_p0, (*param_1).typ, check_p6, descKind_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				}
LA67_: ;
				{
					if (!(((*param_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)47)))&63U)))!=0)) goto LA83_;
					prepareAdd((&typ_1), 12);
appendString((&typ_1), TM__MQdRN7fpbG7rPm4JpVVAhA_248);
				}
LA83_: ;
				eqcopy___system_u2694((&name_2), (*param_1).loc.snippet);
				blitTmp_1 = typ_1;
				eqwasMoved___system_u2688((&typ_1));
				add__stdZenumutils_u71((&types_1), blitTmp_1);
				blitTmp_2 = name_2;
				eqwasMoved___system_u2688((&name_2));
				add__stdZenumutils_u71((&names_1), blitTmp_2);
				{
					NimStringV2 T89_;
					NimStringV2* T90_;
					NimStringV2* T91_;
					if (!!((((*param_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)53)))&63U)))!=0))) goto LA87_;
					T89_.len = 0; T89_.p = NIM_NIL;
					T90_ = (NimStringV2*)0;
					T90_ = X5BX5D___cgen_u3675(((types_1).p) ? (types_1.p->data) : NIM_NIL, types_1.len, ((NI)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					T91_ = (NimStringV2*)0;
					T91_ = X5BX5D___cgen_u3675(((names_1).p) ? (names_1.p->data) : NIM_NIL, names_1.len, ((NI)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					T89_ = rawNewString((*T90_).len + (*T91_).len + 1);
appendString((&T89_), (*T90_));
appendString((&T89_), TM__MQdRN7fpbG7rPm4JpVVAhA_249);
appendString((&T89_), (*T91_));
					add__stdZenumutils_u71((&args_1), T89_);
				}
				goto LA85_;
LA87_: ;
				{
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T93_;
					NimStringV2* T94_;
					NimStringV2* T95_;
					NimStringV2 T96_;
					T94_ = (NimStringV2*)0;
					T94_ = X5BX5D___cgen_u3675(((types_1).p) ? (types_1.p->data) : NIM_NIL, types_1.len, ((NI)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					T93_[0] = (*T94_);
					T95_ = (NimStringV2*)0;
					T95_ = X5BX5D___cgen_u3675(((names_1).p) ? (names_1.p->data) : NIM_NIL, names_1.len, ((NI)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					T93_[1] = (*T95_);
					T96_.len = 0; T96_.p = NIM_NIL;
					T96_ = runtimeFormat__ropes_u39((*(*param_1).constraint)._kind_3.strVal, T93_, 2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T96_); goto LA52_;}
					add__stdZenumutils_u71((&args_1), T96_);
				}
LA85_: ;
				i_2 += ((NI)1);
				{
					LA52_:;
				}
				{
					oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(name_2);
					eqdestroy___system_u2691(typ_1);
					eqdestroy___ast_u4574(param_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin52_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA51: ;
		}
	}
	T99_[0] = types_1;
	T99_[1] = names_1;
	multiFormat__cgen_u3707(params_p5, T99_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T100_[0] = types_1;
	T100_[1] = names_1;
	multiFormat__cgen_u3707(superCall_p2, T100_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T101_[0] = types_1;
	T101_[1] = names_1;
	multiFormat__cgen_u3707(name_p4, T101_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!eqStrings((*params_p5), TM__MQdRN7fpbG7rPm4JpVVAhA_260)) goto LA104_;
		{
			NI T108_;
			T108_ = types_1.len;
			if (!(T108_ == ((NI)0))) goto LA109_;
			eqsink___system_u2700((&(*params_p5)), TM__MQdRN7fpbG7rPm4JpVVAhA_262);
		}
		goto LA106_;
LA109_: ;
		{
			NimStringV2 colontmpD__11;
			NimStringV2 T112_;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			T112_.len = 0; T112_.p = NIM_NIL;
			colontmpD__11 = nsuJoinSep(((args_1).p) ? (args_1.p->data) : NIM_NIL, args_1.len, TM__MQdRN7fpbG7rPm4JpVVAhA_264);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T112_ = rawNewString(colontmpD__11.len + 2);
appendString((&T112_), TM__MQdRN7fpbG7rPm4JpVVAhA_263);
appendString((&T112_), colontmpD__11);
appendString((&T112_), TM__MQdRN7fpbG7rPm4JpVVAhA_265);
			eqsink___system_u2700((&(*params_p5)), T112_);
			eqdestroy___system_u2691(colontmpD__11);
		}
LA106_: ;
	}
LA104_: ;
	{
		if (!(((*t_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)0)))&63U)))!=0)) goto LA115_;
		{
			if (!!(eqStrings((*params_p5), TM__MQdRN7fpbG7rPm4JpVVAhA_266))) goto LA119_;
			X5BX5Deq___system_u8114(params_p5, ((NI)1), 44);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA117_;
LA119_: ;
		{
			tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA T122_;
			T122_ = dotdot___stdZstrbasics_u49((NI)((*params_p5).len - ((NI)1)), (NI)((*params_p5).len - ((NI)1)));
			delete__pureZstrutils_u1360(params_p5, T122_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA117_: ;
		prepareAdd((&(*params_p5)), 4);
appendString((&(*params_p5)), TM__MQdRN7fpbG7rPm4JpVVAhA_268);
	}
LA115_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u5506(args_1);
		eqdestroy___system_u5506(names_1);
		eqdestroy___system_u5506(types_1);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMemberProcHeader__cgen_u5241)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1, NimStringV2* result_p2, NIM_BOOL asPtr_p3, NIM_BOOL isFwdDecl_p4) {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA check_1;
	NimStringV2 memberOp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NimStringV2 typDesc_1;
	NimStringV2 asPtrStr_1;
	NimStringV2 name_1;
	NimStringV2 params_1;
	NimStringV2 rettype_1;
	NimStringV2 superCall_1;
	NimStringV2 fnConst_1;
	NimStringV2 override_1;
	NimStringV2 colontmpD_;
	NIM_BOOL isCtor_1;
	NimStringV2 T12_;
	NIM_BOOL isFnConst_1;
	NIM_BOOL isOverride_1;
	NIM_BOOL isMemberVirtual_1;
	NIM_BOOL isStatic_1;
	NIM_BOOL isVirtual_1;
	NIM_BOOL T18_;
	tyArray__hSrJSIaqyFxuH67Wd7apZQ T58_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&check_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	memberOp_1.len = 0; memberOp_1.p = NIM_NIL;
	typ_1 = NIM_NIL;
	typDesc_1.len = 0; typDesc_1.p = NIM_NIL;
	asPtrStr_1.len = 0; asPtrStr_1.p = NIM_NIL;
	name_1.len = 0; name_1.p = NIM_NIL;
	params_1.len = 0; params_1.p = NIM_NIL;
	rettype_1.len = 0; rettype_1.p = NIM_NIL;
	superCall_1.len = 0; superCall_1.p = NIM_NIL;
	fnConst_1.len = 0; fnConst_1.p = NIM_NIL;
	override_1.len = 0; override_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	isCtor_1 = (((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29)))&63U)))!=0);
	initIntSet__pureZcollectionsZintsets_u598((&check_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillBackendName__cgen_u896(m_p0, prc_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillLoc__cgen_u88((&(*prc_p1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)7), (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	memberOp_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_152;
	{
		if (!isCtor_1) goto LA4_;
		typ_1 = returnType__ast_u5354((*prc_p1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		typ_1 = firstParamType__ast_u5363((*prc_p1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T11_;
		if (!((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA9_;
		T11_ = NIM_NIL;
		T11_ = elementType__ast_u5331(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T11_); goto LA1_;}
		eqsink___ast_u3387(&typ_1, T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___system_u2700((&memberOp_1), TM__MQdRN7fpbG7rPm4JpVVAhA_154);
	}
LA9_: ;
	typDesc_1 = getTypeDescWeak__cgen_u3400(m_p0, typ_1, (&check_1), ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_.len = 0; T12_.p = NIM_NIL;
	{
		if (!asPtr_p3) goto LA15_;
		asPtrStr_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_189;
	}
	goto LA13_;
LA15_: ;
	{
		asPtrStr_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_190;
	}
LA13_: ;
	name_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_191;
	params_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_192;
	rettype_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_193;
	superCall_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_194;
	isFnConst_1 = NIM_FALSE;
	isOverride_1 = NIM_FALSE;
	isMemberVirtual_1 = NIM_FALSE;
	isStatic_1 = NIM_FALSE;
	parseVFunctionDecl__cgen_u8828((*(*prc_p1).constraint)._kind_3.strVal, (&name_1), (&params_1), (&rettype_1), (&superCall_1), (&isFnConst_1), (&isOverride_1), (&isMemberVirtual_1), (&isStatic_1), isCtor_1, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genMemberProcParams__cgen_u3576(m_p0, prc_p1, (&superCall_1), (&rettype_1), (&name_1), (&params_1), (&check_1), NIM_TRUE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T18_ = (NIM_BOOL)0;
	T18_ = (((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)50)))&63U)))!=0);
	if (T18_) goto LA19_;
	T18_ = isMemberVirtual_1;
LA19_: ;
	isVirtual_1 = T18_;
	fnConst_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_269;
	override_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_270;
	{
		if (!isCtor_1) goto LA22_;
		eqcopy___system_u2694((&name_1), typDesc_1);
	}
LA22_: ;
	{
		if (!isFnConst_1) goto LA26_;
		fnConst_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_272;
	}
LA26_: ;
	{
		if (!isFwdDecl_p4) goto LA30_;
		{
			if (!isStatic_1) goto LA34_;
			prepareAdd((&(*result_p2)), 7);
appendString((&(*result_p2)), TM__MQdRN7fpbG7rPm4JpVVAhA_273);
		}
LA34_: ;
		{
			NimStringV2 T40_;
			if (!isVirtual_1) goto LA38_;
			T40_.len = 0; T40_.p = NIM_NIL;
			T40_ = rawNewString(rettype_1.len + 8);
appendString((&T40_), TM__MQdRN7fpbG7rPm4JpVVAhA_274);
appendString((&T40_), rettype_1);
			eqsink___system_u2700((&rettype_1), T40_);
			{
				if (!isOverride_1) goto LA43_;
				override_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_276;
			}
LA43_: ;
		}
LA38_: ;
		eqsink___system_u2700((&superCall_1), TM__MQdRN7fpbG7rPm4JpVVAhA_277);
	}
	goto LA28_;
LA30_: ;
	{
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T56_;
		NimStringV2 T57_;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T50_;
			NimStringV2 T51_;
			if (!!(isCtor_1)) goto LA48_;
			T50_[0] = memberOp_1;
			T50_[1] = name_1;
			T51_.len = 0; T51_.p = NIM_NIL;
			T51_ = percent___cgen_u8988(T50_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T51_); goto LA1_;}
			eqsink___system_u2700((&(*prc_p1).loc.snippet), T51_);
		}
		goto LA46_;
LA48_: ;
		{
			NimStringV2 T55_;
			if (!!((superCall_1.len == 0))) goto LA53_;
			T55_.len = 0; T55_.p = NIM_NIL;
			T55_ = rawNewString(superCall_1.len + 3);
appendString((&T55_), TM__MQdRN7fpbG7rPm4JpVVAhA_279);
appendString((&T55_), superCall_1);
			eqsink___system_u2700((&superCall_1), T55_);
		}
		goto LA46_;
LA53_: ;
LA46_: ;
		T56_[0] = typDesc_1;
		T56_[1] = name_1;
		T57_.len = 0; T57_.p = NIM_NIL;
		T57_ = percent___cgen_u8993(T56_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T57_); goto LA1_;}
		eqsink___system_u2700((&name_1), T57_);
	}
LA28_: ;
	prepareAdd((&(*result_p2)), 14);
appendString((&(*result_p2)), TM__MQdRN7fpbG7rPm4JpVVAhA_281);
	T58_[0] = CallingConvToStr__cgen_u1465[((*(*prc_p1).typ).callConv)- 0];
	T58_[1] = asPtrStr_1;
	T58_[2] = rettype_1;
	T58_[3] = name_1;
	T58_[4] = params_1;
	T58_[5] = fnConst_1;
	T58_[6] = override_1;
	T58_[7] = superCall_1;
	colontmpD_ = percent___cgen_u8998(T58_, 8);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*result_p2)), colontmpD_.len + 0);
appendString((&(*result_p2)), colontmpD_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(superCall_1);
		eqdestroy___system_u2691(rettype_1);
		eqdestroy___system_u2691(params_1);
		eqdestroy___system_u2691(name_1);
		eqdestroy___system_u2691(typDesc_1);
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(memberOp_1);
		eqdestroy___pureZcollectionsZintsets_u230((&check_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isCompileTimeOnly__types_u3641)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	result = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA, mapReturnType__cgen_u1369)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
	result = mapType__cgen_u1315(conf_p0, typ_p1, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcParams__cgen_u3939)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2* rettype_p2, NimStringV2* params_p3, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p4, NIM_BOOL declareEnvironment_p5, NIM_BOOL weakDep_p6) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL oldNimErrFin84_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	eqsink___system_u2700((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_295);
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		colontmpD_ = returnType__ast_u5354(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = (colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = isInvalidReturnType__cgen_u1424((*(*m_p0).g).config, t_p1, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
		eqsink___system_u2700((&(*rettype_p2)), TM__MQdRN7fpbG7rPm4JpVVAhA_296);
	}
	goto LA2_;
LA6_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		NimStringV2 T10_;
		colontmpD__3 = NIM_NIL;
		colontmpD__3 = returnType__ast_u5354(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = getTypeDescWeak__cgen_u3400(m_p0, colontmpD__3, check_p4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)5));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA9_;}
		eqsink___system_u2700((&(*rettype_p2)), T10_);
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190((*t_p1).n);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA15;
				i_1 = i_2;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_1;
					NimStringV2 typ_1;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* arr_1;
					tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q descKind_1;
					tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg T42_;
					NI j_1;
					param_1 = NIM_NIL;
					typ_1.len = 0; typ_1.p = NIM_NIL;
					colontmpD__4 = NIM_NIL;
					arr_1 = NIM_NIL;
					{
						if (!!(((*(*(*t_p1).n)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA20_;
						internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*(*t_p1).n).info, TM__MQdRN7fpbG7rPm4JpVVAhA_298, TM__MQdRN7fpbG7rPm4JpVVAhA_299);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					}
LA20_: ;
					eqcopy___ast_u4577(&param_1, (*(*(*t_p1).n)._kind_6.sons.p->data[i_1])._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					descKind_1 = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0);
					{
						NIM_BOOL T24_;
						T24_ = (NIM_BOOL)0;
						T24_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
						if (!(T24_)) goto LA25_;
						T24_ = (((*param_1).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)20)))&31U)))!=0);
LA25_: ;
						if (!T24_) goto LA26_;
						{
							if (!((*(*param_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11))) goto LA30_;
							descKind_1 = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)2);
						}
						goto LA28_;
LA30_: ;
						{
							descKind_1 = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)1);
						}
LA28_: ;
					}
LA26_: ;
					{
						NIM_BOOL T35_;
						T35_ = (NIM_BOOL)0;
						T35_ = isCompileTimeOnly__types_u3641((*param_1).typ);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						if (!T35_) goto LA36_;
						eqdestroy___ast_u3378(arr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(typ_1);
						eqdestroy___ast_u4574(param_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						goto LA16;
					}
LA36_: ;
					{
						if (!!(eqStrings((*params_p3), TM__MQdRN7fpbG7rPm4JpVVAhA_300))) goto LA40_;
						prepareAdd((&(*params_p3)), 2);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_301);
					}
LA40_: ;
					fillParamName__cgen_u916(m_p0, param_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					T42_ = (tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0;
					T42_ = paramStorageLoc__cgen_u3542(param_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					fillLoc__cgen_u88((&(*param_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)4), (*(*t_p1).n)._kind_6.sons.p->data[i_1], T42_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					typ_1.len = 0; typ_1.p = NIM_NIL;
					{
						NIM_BOOL T45_;
						T45_ = (NIM_BOOL)0;
						colontmpD__4 = returnType__ast_u5354(t_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						T45_ = ccgIntroducedPtr__ccgutils_u130((*(*m_p0).g).config, param_1, colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						if (!(T45_)) goto LA46_;
						T45_ = (descKind_1 == ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
LA46_: ;
						if (!T45_) goto LA47_;
						typ_1 = getTypeDescWeak__cgen_u3400(m_p0, (*param_1).typ, check_p4, descKind_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						prepareAdd((&typ_1), 1);
appendString((&typ_1), TM__MQdRN7fpbG7rPm4JpVVAhA_302);
						(*param_1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
						(*param_1).loc.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0);
					}
					goto LA43_;
LA47_: ;
					{
						if (!weakDep_p6) goto LA50_;
						typ_1 = getTypeDescWeak__cgen_u3400(m_p0, (*param_1).typ, check_p4, descKind_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					}
					goto LA43_;
LA50_: ;
					{
						typ_1 = getTypeDescAux__cgen_u1419(m_p0, (*param_1).typ, check_p4, descKind_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					}
LA43_: ;
					prepareAdd((&typ_1), 1);
appendString((&typ_1), TM__MQdRN7fpbG7rPm4JpVVAhA_303);
					{
						if (!(((*param_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)47)))&63U)))!=0)) goto LA55_;
						prepareAdd((&typ_1), 12);
appendString((&typ_1), TM__MQdRN7fpbG7rPm4JpVVAhA_304);
					}
LA55_: ;
					{
						if (!!((((*param_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)53)))&63U)))!=0))) goto LA59_;
						prepareAdd((&(*params_p3)), typ_1.len + 0);
appendString((&(*params_p3)), typ_1);
						prepareAdd((&(*params_p3)), (*param_1).loc.snippet.len + 0);
appendString((&(*params_p3)), (*param_1).loc.snippet);
					}
					goto LA57_;
LA59_: ;
					{
						NimStringV2 colontmpD__5;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T62_;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						T62_[0] = typ_1;
						T62_[1] = (*param_1).loc.snippet;
						colontmpD__5 = runtimeFormat__ropes_u39((*(*param_1).constraint)._kind_3.strVal, T62_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						prepareAdd((&(*params_p3)), colontmpD__5.len + 0);
appendString((&(*params_p3)), colontmpD__5);
						eqdestroy___system_u2691(colontmpD__5);
					}
LA57_: ;
					arr_1 = skipTypes__ast_u5379((*param_1).typ, TM__MQdRN7fpbG7rPm4JpVVAhA_305);
					if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					{
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T67_;
						if (!((*arr_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*arr_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*arr_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46))) goto LA65_;
						T67_ = NIM_NIL;
						T67_ = elementType__ast_u5331(arr_1);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T67_); goto LA17_;}
						eqsink___ast_u3387(&arr_1, T67_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
					}
LA65_: ;
					j_1 = ((NI)0);
					{
						while (1) {
							NimStringV2 colontmpD__6;
							NimStringV2 colontmpD__7;
							tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T74_;
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T75_;
							if (!((*arr_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*arr_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48))) goto LA69;
							colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
							colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
							{
								if (!((*(*param_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*(*param_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47))) goto LA72_;
								(*param_1).loc.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0);
							}
LA72_: ;
							T74_[0] = (*param_1).loc.snippet;
							colontmpD__6 = rope__ropes_u15(((NI64) (j_1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
							T74_[1] = colontmpD__6;
							colontmpD__7 = percent___cgen_u4005(T74_, 2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
							prepareAdd((&(*params_p3)), colontmpD__7.len + 0);
appendString((&(*params_p3)), colontmpD__7);
							j_1 += ((NI)1);
							T75_ = NIM_NIL;
							T75_ = skipTypes__ast_u5379((*arr_1).sons.p->data[((NI)0)], TM__MQdRN7fpbG7rPm4JpVVAhA_306);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T75_); goto LA17_;}
							eqsink___ast_u3387(&arr_1, T75_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
							eqdestroy___system_u2691(colontmpD__7);
							eqdestroy___system_u2691(colontmpD__6);
						} LA69: ;
					}
					{
						LA17_:;
					}
					{
						oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(arr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(typ_1);
						eqdestroy___ast_u4574(param_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin17_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA16: ;
				i_2 += ((NI)1);
			} LA15: ;
		}
	}
	{
		NIM_BOOL T80_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* arr_2;
		NimStringV2 colontmpD__8;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T109_;
		T80_ = (NIM_BOOL)0;
		colontmpD__2 = returnType__ast_u5354(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T80_ = !((colontmpD__2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T80_)) goto LA81_;
		T80_ = isInvalidReturnType__cgen_u1424((*(*m_p0).g).config, t_p1, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA81_: ;
		if (!T80_) goto LA82_;
		arr_2 = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		arr_2 = returnType__ast_u5354(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
		{
			if (!!(eqStrings((*params_p3), TM__MQdRN7fpbG7rPm4JpVVAhA_307))) goto LA87_;
			prepareAdd((&(*params_p3)), 2);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_308);
		}
LA87_: ;
		{
			tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T91_;
			T91_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
			T91_ = mapReturnType__cgen_u1369((*(*m_p0).g).config, arr_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
			if (!!((T91_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17)))) goto LA92_;
			{
				NimStringV2 colontmpD__9;
				if (!(((*m_p0).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)3)))&7U)))!=0)) goto LA96_;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__9 = getTypeDescAux__cgen_u1419(m_p0, arr_2, check_p4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)5));
				if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
				prepareAdd((&(*params_p3)), colontmpD__9.len + 0);
appendString((&(*params_p3)), colontmpD__9);
				prepareAdd((&(*params_p3)), 1);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_309);
				{
					LA98_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
			}
			goto LA94_;
LA96_: ;
			{
				NimStringV2 colontmpD__10;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				colontmpD__10 = getTypeDescWeak__cgen_u3400(m_p0, arr_2, check_p4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)5));
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				prepareAdd((&(*params_p3)), colontmpD__10.len + 0);
appendString((&(*params_p3)), colontmpD__10);
				prepareAdd((&(*params_p3)), 1);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_310);
				{
					LA102_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__10);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
			}
LA94_: ;
		}
		goto LA89_;
LA92_: ;
		{
			NimStringV2 colontmpD__11;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__11 = getTypeDescAux__cgen_u1419(m_p0, arr_2, check_p4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)5));
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			prepareAdd((&(*params_p3)), colontmpD__11.len + 0);
appendString((&(*params_p3)), colontmpD__11);
			{
				LA106_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__11);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
		}
LA89_: ;
		colontmpD__8 = percent___cgen_u4029(T109_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
		prepareAdd((&(*params_p3)), colontmpD__8.len + 0);
appendString((&(*params_p3)), colontmpD__8);
		{
			LA84_:;
		}
		{
			oldNimErrFin84_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___ast_u3378(arr_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin84_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA82_: ;
	{
		NIM_BOOL T114_;
		T114_ = (NIM_BOOL)0;
		T114_ = ((*t_p1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
		if (!(T114_)) goto LA115_;
		T114_ = declareEnvironment_p5;
LA115_: ;
		if (!T114_) goto LA116_;
		{
			if (!!(eqStrings((*params_p3), TM__MQdRN7fpbG7rPm4JpVVAhA_311))) goto LA120_;
			prepareAdd((&(*params_p3)), 2);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_312);
		}
LA120_: ;
		prepareAdd((&(*params_p3)), 11);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_314);
	}
LA116_: ;
	{
		if (!(((*t_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)0)))&63U)))!=0)) goto LA124_;
		{
			if (!!(eqStrings((*params_p3), TM__MQdRN7fpbG7rPm4JpVVAhA_315))) goto LA128_;
			prepareAdd((&(*params_p3)), 2);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_316);
		}
LA128_: ;
		prepareAdd((&(*params_p3)), 3);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_318);
	}
LA124_: ;
	{
		if (!eqStrings((*params_p3), TM__MQdRN7fpbG7rPm4JpVVAhA_319)) goto LA132_;
		prepareAdd((&(*params_p3)), 5);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_321);
	}
	goto LA130_;
LA132_: ;
	{
		prepareAdd((&(*params_p3)), 1);
appendString((&(*params_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_322);
	}
LA130_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isNonReloadable__cgen_u8820)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = hcrOn__cgen_u49(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	if (!(T1_)) goto LA2_;
	T1_ = (((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)38)))&63U)))!=0);
LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcHeader__cgen_u9040)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1, NimStringV2* result_p2, NIM_BOOL asPtr_p3) {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA check_1;
	NimStringV2 rettype_1;
	NimStringV2 params_1;
	NimStringV2 asPtrStr_1;
	NimStringV2 name_1;
	NimStringV2 T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&check_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	rettype_1.len = 0; rettype_1.p = NIM_NIL;
	params_1.len = 0; params_1.p = NIM_NIL;
	asPtrStr_1.len = 0; asPtrStr_1.p = NIM_NIL;
	name_1.len = 0; name_1.p = NIM_NIL;
	initIntSet__pureZcollectionsZintsets_u598((&check_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillBackendName__cgen_u896(m_p0, prc_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillLoc__cgen_u88((&(*prc_p1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)7), (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)], ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rettype_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_293;
	params_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_294;
	genProcParams__cgen_u3939(m_p0, (*prc_p1).typ, (&rettype_1), (&params_1), (&check_1), NIM_TRUE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		if (!asPtr_p3) goto LA5_;
		asPtrStr_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_323;
	}
	goto LA3_;
LA5_: ;
	{
		asPtrStr_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_324;
	}
LA3_: ;
	eqcopy___system_u2694((&name_1), (*prc_p1).loc.snippet);
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = !(asPtr_p3);
		if (!(T10_)) goto LA11_;
		T10_ = isReloadable__cgen_u8812(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA11_: ;
		if (!T10_) goto LA12_;
		prepareAdd((&name_1), 7);
appendString((&name_1), TM__MQdRN7fpbG7rPm4JpVVAhA_325);
	}
LA12_: ;
	{
		NimStringV2 colontmpD_;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T37_;
		if (!!((((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)53)))&63U)))!=0))) goto LA16_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		{
			if (!(((*prc_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)4)))&15U)))!=0)) goto LA20_;
			{
				if (!(((*m_p0).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)3)))&7U)))!=0)) goto LA24_;
				prepareAdd((&(*result_p2)), 13);
appendString((&(*result_p2)), TM__MQdRN7fpbG7rPm4JpVVAhA_327);
			}
			goto LA22_;
LA24_: ;
			{
				prepareAdd((&(*result_p2)), 13);
appendString((&(*result_p2)), TM__MQdRN7fpbG7rPm4JpVVAhA_329);
			}
LA22_: ;
		}
		goto LA18_;
LA20_: ;
		{
			NIM_BOOL T28_;
			NIM_BOOL T29_;
			T28_ = (NIM_BOOL)0;
			T29_ = (NIM_BOOL)0;
			T29_ = ((*(*prc_p1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)5));
			if (T29_) goto LA30_;
			T29_ = asPtr_p3;
LA30_: ;
			T28_ = T29_;
			if (T28_) goto LA31_;
			T28_ = isNonReloadable__cgen_u8820(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA31_: ;
			if (!T28_) goto LA32_;
			prepareAdd((&(*result_p2)), 7);
appendString((&(*result_p2)), TM__MQdRN7fpbG7rPm4JpVVAhA_330);
		}
		goto LA18_;
LA32_: ;
		{
			if (!!((((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0))) goto LA35_;
			prepareAdd((&(*result_p2)), 14);
appendString((&(*result_p2)), TM__MQdRN7fpbG7rPm4JpVVAhA_331);
		}
		goto LA18_;
LA35_: ;
LA18_: ;
		T37_[0] = CallingConvToStr__cgen_u1465[((*(*prc_p1).typ).callConv)- 0];
		T37_[1] = asPtrStr_1;
		T37_[2] = rettype_1;
		T37_[3] = name_1;
		T37_[4] = params_1;
		colontmpD_ = percent___cgen_u9070(T37_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*result_p2)), colontmpD_.len + 0);
appendString((&(*result_p2)), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA14_;
LA16_: ;
	{
		NimStringV2 asPtrStr_2;
		NimStringV2 colontmpD__2;
		NimStringV2 T39_;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T46_;
		asPtrStr_2.len = 0; asPtrStr_2.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T39_.len = 0; T39_.p = NIM_NIL;
		{
			NimStringV2 T44_;
			if (!asPtr_p3) goto LA42_;
			T44_.len = 0; T44_.p = NIM_NIL;
			T44_ = rawNewString(name_1.len + 3);
appendString((&T44_), TM__MQdRN7fpbG7rPm4JpVVAhA_332);
appendString((&T44_), name_1);
appendString((&T44_), TM__MQdRN7fpbG7rPm4JpVVAhA_333);
			asPtrStr_2 = T44_;
		}
		goto LA40_;
LA42_: ;
		{
			asPtrStr_2 = name_1;
			eqwasMoved___system_u2688((&name_1));
		}
LA40_: ;
		T46_[0] = rettype_1;
		T46_[1] = asPtrStr_2;
		T46_[2] = params_1;
		colontmpD__2 = runtimeFormat__ropes_u39((*(*prc_p1).constraint)._kind_3.strVal, T46_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*result_p2)), colontmpD__2.len + 0);
appendString((&(*result_p2)), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(asPtrStr_2);
	}
LA14_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(name_1);
		eqdestroy___system_u2691(params_1);
		eqdestroy___system_u2691(rettype_1);
		eqdestroy___pureZcollectionsZintsets_u230((&check_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, freshLineInfo__cgen_u404)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	NIM_BOOL result;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*p_p0).lastLineInfo.line == info_p1.line));
		if (T3_) goto LA4_;
		T3_ = !(((*p_p0).lastLineInfo.fileIndex == info_p1.fileIndex));
LA4_: ;
		if (!T3_) goto LA5_;
		(*p_p0).lastLineInfo.line = info_p1.line;
		(*p_p0).lastLineInfo.fileIndex = info_p1.fileIndex;
		result = NIM_TRUE;
	}
	goto LA1_;
LA5_: ;
	{
		result = NIM_FALSE;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsResult__cgen_u28141)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	switch ((*n_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)122) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)123):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)109):
	{
		NIM_BOOL T11_;
		NI T12_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i_1 = i_2;
					{
						NIM_BOOL T8_;
						T8_ = (NIM_BOOL)0;
						T8_ = containsResult__cgen_u28141((*n_p0)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T8_) goto LA9_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
LA9_: ;
					i_2 += ((NI)1);
				} LA5: ;
			}
		}
		T11_ = (NIM_BOOL)0;
		T12_ = (NI)0;
		T12_ = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T11_ = (((NI)0) < T12_);
		if (!(T11_)) goto LA13_;
		T11_ = ((*(*n_p0)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
LA13_: ;
		result = T11_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		{
			if (!((*(*n_p0)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11))) goto LA17_;
			result = NIM_TRUE;
		}
LA17_: ;
	}
	break;
	default:
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_4 = ((NI)0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA22;
					i_3 = i_4;
					{
						NIM_BOOL T25_;
						T25_ = (NIM_BOOL)0;
						T25_ = containsResult__cgen_u28141((*n_p0)._kind_6.sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T25_) goto LA26_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
LA26_: ;
					i_4 += ((NI)1);
				} LA22: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, easyResultAsgn__cgen_u28177)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	switch ((*n_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126):
	{
		NI i_1;
		i_1 = ((NI)0);
		{
			while (1) {
				NIM_BOOL T4_;
				NI T5_;
				T4_ = (NIM_BOOL)0;
				T5_ = (NI)0;
				T5_ = len__ast_u3190(n_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T4_ = (i_1 < T5_);
				if (!(T4_)) goto LA6_;
				T4_ = ((*(*n_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) || (*(*n_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76) || (*(*n_p0)._kind_6.sons.p->data[i_1]).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79) && (*(*n_p0)._kind_6.sons.p->data[i_1]).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84) || (*(*n_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98) || (*(*n_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101) || (*(*n_p0)._kind_6.sons.p->data[i_1]).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)122) && (*(*n_p0)._kind_6.sons.p->data[i_1]).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)123) || (*(*n_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125) || (*(*n_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159));
LA6_: ;
				if (!T4_) goto LA3;
				i_1 += ((NI)1);
			} LA3: ;
		}
		{
			NI T9_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T12_;
			T9_ = (NI)0;
			T9_ = len__ast_u3190(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(i_1 < T9_)) goto LA10_;
			T12_ = NIM_NIL;
			T12_ = easyResultAsgn__cgen_u28177((*n_p0)._kind_6.sons.p->data[i_1]);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T12_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T12_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA10_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)74):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149):
	{
		{
			NIM_BOOL T16_;
			NIM_BOOL T17_;
			NIM_BOOL T20_;
			T16_ = (NIM_BOOL)0;
			T17_ = (NIM_BOOL)0;
			T17_ = ((*(*n_p0)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T17_)) goto LA18_;
			T17_ = ((*(*(*n_p0)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11));
LA18_: ;
			T16_ = T17_;
			if (!(T16_)) goto LA19_;
			T20_ = (NIM_BOOL)0;
			T20_ = containsResult__cgen_u28141((*n_p0)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T16_ = !(T20_);
LA19_: ;
			if (!T16_) goto LA21_;
			(*n_p0).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)15))) & 31);
			eqcopy___ast_u3255(&result, (*n_p0)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA21_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)109):
	{
		{
			NI T26_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T29_;
			T26_ = (NI)0;
			T26_ = len__ast_u3190(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(((NI)0) < T26_)) goto LA27_;
			T29_ = NIM_NIL;
			T29_ = easyResultAsgn__cgen_u28177((*n_p0)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T29_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T29_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				if (!!((result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA32_;
				(*n_p0).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)15))) & 31);
			}
LA32_: ;
		}
LA27_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fillLocalName__cgen_u920)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 key_1;
		NimStringV2 result_1;
		NI counter_1;
		if (!((*s_p1).loc.snippet.len == 0)) goto LA3_;
		key_1.len = 0; key_1.p = NIM_NIL;
		result_1.len = 0; result_1.p = NIM_NIL;
		key_1 = mangle__mangleutils_u4((*(*s_p1).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		counter_1 = getOrDefault__cgen_u1001((*p_p0).sigConflicts, key_1, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___system_u2694((&result_1), key_1);
		{
			if (!((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5))) goto LA7_;
			{
				NimStringV2 colontmpD_;
				NimStringV2 colontmpD__2;
				NimStringV2 T13_;
				if (!!((counter_1 == ((NI)0)))) goto LA11_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				T13_.len = 0; T13_.p = NIM_NIL;
				colontmpD_ = rope__ropes_u15(((NI64) ((NI)(counter_1 + ((NI)1)))));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T13_ = rawNewString(colontmpD_.len + 1);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_339);
appendString((&T13_), colontmpD_);
				colontmpD__2 = T13_;
				prepareAdd((&result_1), colontmpD__2.len + 0);
appendString((&result_1), colontmpD__2);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
			}
LA11_: ;
		}
		goto LA5_;
LA7_: ;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 T17_;
			if (!!(((*s_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11)))) goto LA15_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T17_.len = 0; T17_.p = NIM_NIL;
			colontmpD__3 = rope__ropes_u15(((NI64) ((NI)(counter_1 + ((NI)1)))));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T17_ = rawNewString(colontmpD__3.len + 1);
appendString((&T17_), TM__MQdRN7fpbG7rPm4JpVVAhA_340);
appendString((&T17_), colontmpD__3);
			colontmpD__4 = T17_;
			prepareAdd((&result_1), colontmpD__4.len + 0);
appendString((&result_1), colontmpD__4);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		goto LA5_;
LA15_: ;
LA5_: ;
		inc__cgen_u1077((&(*p_p0).sigConflicts), key_1, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqsink___system_u2700((&(*s_p1).loc.snippet), result_1);
		eqdestroy___system_u2691(key_1);
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_u382)(NimStringV2* r_p0, NI32 fileIdx_p1, NI line_p2, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, NI32 lastFileIndex_p5) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*(*(*(*p_p3).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (((NI)0) < line_p2);
LA4_: ;
		if (!T3_) goto LA5_;
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 T11_;
			if (!(fileIdx_p1 == ((NI32)-1))) goto LA9_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T11_.len = 0; T11_.p = NIM_NIL;
			colontmpD_ = dollar___systemZdollars_u9(line_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T11_ = rawNewString(colontmpD_.len + 38);
appendString((&T11_), TM__MQdRN7fpbG7rPm4JpVVAhA_342);
appendString((&T11_), colontmpD_);
appendString((&T11_), TM__MQdRN7fpbG7rPm4JpVVAhA_344);
			colontmpD__2 = T11_;
			prepareAdd((&(*r_p0)), colontmpD__2.len + 0);
appendString((&(*r_p0)), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA7_;
LA9_: ;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 T13_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T13_.len = 0; T13_.p = NIM_NIL;
			colontmpD__3 = dollar___systemZdollars_u9(line_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__4 = dollar___systemZdollars_u24(fileIdx_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T13_ = rawNewString(colontmpD__3.len + colontmpD__4.len + 12);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_345);
appendString((&T13_), colontmpD__3);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_347);
appendString((&T13_), colontmpD__4);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_348);
			colontmpD__5 = T13_;
			prepareAdd((&(*r_p0)), colontmpD__5.len + 0);
appendString((&(*r_p0)), colontmpD__5);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
LA7_: ;
	}
LA5_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, toLinenumber__msgs_u695)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0) {
	NI result;
	result = ((NI) (info_p0.line));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, safeLineNm__cgen_u362)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = toLinenumber__msgs_u695(info_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(result < ((NI)0))) goto LA3_;
		result = ((NI)0);
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_u408)(NimStringV2* r_p0, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI32 lastFileIndex_1;
		if (!(((*conf_p3).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0)) goto LA3_;
		lastFileIndex_1 = (*p_p1).lastLineInfo.fileIndex;
		{
			NIM_BOOL T7_;
			NI T10_;
			T7_ = (NIM_BOOL)0;
			T7_ = freshLineInfo__cgen_u404(p_p1, info_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T7_) goto LA8_;
			T10_ = (NI)0;
			T10_ = safeLineNm__cgen_u362(info_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			genCLineDir__cgen_u382(r_p0, info_p2.fileIndex, T10_, p_p1, info_p2, lastFileIndex_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA8_: ;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, localVarDecl__cgen_u13649)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
	NimStringV2 colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	s_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_338;
	eqcopy___ast_u4577(&s_1, (*n_p1)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*s_1).loc.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA4_;
		fillLocalName__cgen_u920(p_p0, s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		fillLoc__cgen_u88((&(*s_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)2), n_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9))) goto LA8_;
			(*s_1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)1))) & 15);
		}
LA8_: ;
	}
LA4_: ;
	{
		NIM_BOOL T12_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__YgExxhfgKcesA5EOUj1MOA T16_;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21));
		if (!(T12_)) goto LA13_;
		T12_ = (((NI)0) < (*s_1)._kind_2.alignment);
LA13_: ;
		if (!T12_) goto LA14_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__2 = rope__ropes_u15(((NI64) ((*s_1)._kind_2.alignment)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T16_[0] = colontmpD__2;
		colontmpD__3 = percent___cgen_u13670(T16_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
	}
LA14_: ;
	genCLineDir__cgen_u408((&result), p_p0, (*n_p1).info, (*(*(*p_p0).module).g).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, (*s_1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
	{
		if (!!((((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)53)))&63U)))!=0))) goto LA19_;
		{
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)10)))&63U)))!=0)) goto LA23_;
			prepareAdd((&result), 9);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_350);
		}
LA23_: ;
		{
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)9)))&63U)))!=0)) goto LA27_;
			prepareAdd((&result), 9);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_352);
		}
LA27_: ;
		{
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)47)))&63U)))!=0)) goto LA31_;
			prepareAdd((&result), 12);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_354);
		}
LA31_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_355);
		prepareAdd((&result), (*s_1).loc.snippet.len + 0);
appendString((&result), (*s_1).loc.snippet);
	}
	goto LA17_;
LA19_: ;
	{
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T34_;
		NimStringV2 T35_;
		T34_[0] = result;
		T34_[1] = (*s_1).loc.snippet;
		T35_.len = 0; T35_.p = NIM_NIL;
		T35_ = runtimeFormat__ropes_u39((*(*s_1).constraint)._kind_3.strVal, T34_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T35_); goto LA1_;}
		eqsink___system_u2700((&result), T35_);
	}
LA17_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocExprSingleUse__cgen_u14116)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T1_ = 0;
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0), e_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T1_, Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T4_;
		NIM_BOOL T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
		if (!(T4_)) goto LA5_;
		T6_ = (NIM_BOOL)0;
		T6_ = !(((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)));
		if (T6_) goto LA7_;
		T6_ = ((*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0));
LA7_: ;
		T4_ = T6_;
LA5_: ;
		if (!T4_) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T12_)) goto LA13_;
			T12_ = (((*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA13_: ;
			if (!T12_) goto LA14_;
			(*Result).flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)7))) & 15);
		}
LA14_: ;
	}
	goto LA2_;
LA8_: ;
	{
		(*Result).flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)7))) & 15);
	}
LA2_: ;
	expr__cgen_u14084(p_p0, e_p1, Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isOrHasImportedCppType__cgen_u1404)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	colontmpD_ = skipTypes__ast_u5379(typ_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_361);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = searchTypeFor__types_u423(colontmpD_, isImportedCppType__cgen_u1384);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lodeTyp__cgen_u104)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&(*result).typField, t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isComplexValueType__cgen_u13074)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	t_2 = NIM_NIL;
	t_2 = skipTypes__ast_u5379(t_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_388);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*t_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16) || (*t_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19) || (*t_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18) || (*t_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*t_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t_2).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA4_: ;
	T1_ = T3_;
LA2_: ;
	result = T1_;
	eqdestroy___ast_u3378(t_2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, usesWriteBarrier__options_u3582)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NIM_BOOL result;
	result = (((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)9) <= (*conf_p0).selectedGC);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, addrLoc__cgen_u12821)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__2;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__3;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	colontmpD__3 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	{
		NIM_BOOL T4_;
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T6_;
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T12_;
		NimStringV2 T15_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((a_p1.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0)))&15U)))!=0));
		if (!(T4_)) goto LA5_;
		colontmpD_ = t__cgen_u97(a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T6_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			if (!((*a_p1.lode).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA9_;
			colontmpD__2 = (*(*a_p1.lode)._kind_4.sym).kind;
			T6_ = colontmpD__2;
		}
		goto LA7_;
LA9_: ;
		{
			colontmpD__3 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
			T6_ = colontmpD__3;
		}
LA7_: ;
		T12_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		T12_ = mapType__cgen_u1315(conf_p0, colontmpD_, (T6_ == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !((T12_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17)));
LA5_: ;
		if (!T4_) goto LA13_;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = rawNewString(a_p1.snippet.len + 3);
appendString((&T15_), TM__MQdRN7fpbG7rPm4JpVVAhA_399);
appendString((&T15_), a_p1.snippet);
appendString((&T15_), TM__MQdRN7fpbG7rPm4JpVVAhA_400);
		result = T15_;
	}
	goto LA2_;
LA13_: ;
	{
		eqcopy___system_u2694((&result), a_p1.snippet);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genRefAssign__cgen_u13070)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T7_;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2* T10_;
		NimStringV2* T11_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (dest_p1.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2));
		if (!(T4_)) goto LA5_;
		T4_ = !(((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10)));
LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = usesWriteBarrier__options_u3582((*(*(*p_p0).module).g).config);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !(T7_);
LA6_: ;
		if (!T3_) goto LA8_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T10_ = (NimStringV2*)0;
		T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		addIndent__cgen_u315(p_p0, T10_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T11_ = (NimStringV2*)0;
		T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = rdLoc__cgen_u470(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_391);
		colontmpD__2 = rdLoc__cgen_u470(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_392);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA14_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_393);
		}
LA14_: ;
		prepareAdd((&(*T11_)), res_1.len + 0);
appendString((&(*T11_)), res_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
	}
	goto LA1_;
LA8_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2* T20_;
		NimStringV2* T21_;
		if (!(dest_p1.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3))) goto LA17_;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T20_ = (NimStringV2*)0;
		T20_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		addIndent__cgen_u315(p_p0, T20_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		T21_ = (NimStringV2*)0;
		T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		res_2 = rawNewString(((NI)80));
		colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_395);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_397);
		colontmpD__4 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_401);
		colontmpD__5 = rdLoc__cgen_u470(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_402);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA24_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_403);
		}
LA24_: ;
		prepareAdd((&(*T21_)), res_2.len + 0);
appendString((&(*T21_)), res_2);
		{
			LA19_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA17_: ;
	{
		NimStringV2 res_3;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2* T30_;
		NimStringV2* T31_;
		res_3.len = 0; res_3.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		T30_ = (NimStringV2*)0;
		T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		addIndent__cgen_u315(p_p0, T30_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		T31_ = (NimStringV2*)0;
		T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		res_3 = rawNewString(((NI)80));
		colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_405);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		prepareAdd((&res_3), 10);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_406);
		colontmpD__7 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_407);
		colontmpD__8 = rdLoc__cgen_u470(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_408);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA34_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_409);
		}
LA34_: ;
		prepareAdd((&(*T31_)), res_3.len + 0);
appendString((&(*T31_)), res_3);
		{
			LA29_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(res_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q, descKindFromSymKind__cgen_u735)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p0) {
	tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q result;
	tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q T1_;
	T1_ = (tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0;
	switch (kind_p0) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3):
	{
		result = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	{
		result = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19):
	{
		result = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)4);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11):
	{
		result = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)5);
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10):
	{
		result = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)6);
	}
	break;
	default:
	{
		result = ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)7);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasNoInit__cgen_u1407)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	t_2 = NIM_NIL;
	t_2 = skipTypes__ast_u5379(t_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_305);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*t_2).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*t_2).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0);
LA2_: ;
	result = T1_;
	eqdestroy___ast_u3378(t_2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getModuleDllPath__cgen_u154)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NI module_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = getModuleDllPath__cgen_u146((*(*m_p0).g).modules.p->data[module_p1]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, declareNimType__cgen_u9964)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1, NimStringV2 str_p2, NI module_p3) {
	NimStringV2 nr_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nr_1.len = 0; nr_1.p = NIM_NIL;
	nr_1 = name_p1;
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T7_[0] = str_p2;
		T7_[1] = nr_1;
		colontmpD_ = percent___cgen_u9970(T7_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD_);
		T8_[0] = str_p2;
		colontmpD__2 = getModuleDllPath__cgen_u154(m_p0, module_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T8_[1] = colontmpD__2;
		T8_[2] = nr_1;
		colontmpD__3 = percent___cgen_u9975(T8_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), colontmpD__3.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), colontmpD__3);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T12_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T12_[0] = str_p2;
		T12_[1] = nr_1;
		colontmpD__4 = percent___cgen_u9980(T12_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__4.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__4);
		eqdestroy___system_u2691(colontmpD__4);
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, moduleOpenForCodegen__modulegraphs_u14816)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 m_p1) {
	NIM_BOOL result;
	{
		if (!((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0))) goto LA3_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA3_: ;
	{
		result = !(((*g_p0).packed_0.pm.p->data[m_p1].status == ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)0) || (*g_p0).packed_0.pm.p->data[m_p1].status == ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)5) || (*g_p0).packed_0.pm.p->data[m_p1].status == ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)3)));
	}
LA1_: ;
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getBody__modulegraphs_u17880)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3255(&result, (*(*s_p1).ast)._kind_6.sons.p->data[((NI)6)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T7_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T8_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = ((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)2) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)4));
LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = (*g_p0).config;
		T8_ = NIM_NIL;
		T8_ = (*g_p0).cache;
		T9_ = NIM_NIL;
		T9_ = loadProcBody__icZic_u21187(T7_, T8_, (&(*g_p0).packed_0), s_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___ast_u3255(&(*(*s_p1).ast)._kind_6.sons.p->data[((NI)6)], result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isTrivialProc__cgen_u10033)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NIM_BOOL result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NI T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getBody__modulegraphs_u17880(g_p0, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NI)0;
	T2_ = len__ast_u3190(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = (T2_ == ((NI)0));
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newDeref__lowerings_u12)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = elementType__ast_u5331((*n_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65), (*n_p0).info, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3215(result, n_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, generateRttiDestructor__cgen_u10037)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q kind_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p5, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* theProc_p6) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* procname_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* castType_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T2_;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T3_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T4_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T5_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T10_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	procname_1 = NIM_NIL;
	dest_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	n_1 = NIM_NIL;
	body_1 = NIM_NIL;
	castType_1 = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	procname_1 = getIdent__idents_u206((*g_p0).cache, TM__MQdRN7fpbG7rPm4JpVVAhA_445);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = 0;
	result = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12), procname_1, idgen_p5, owner_p2, info_p4, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getIdent__idents_u206((*g_p0).cache, TM__MQdRN7fpbG7rPm4JpVVAhA_447);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	dest_1 = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3), colontmpD_, idgen_p5, result, info_p4, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = NIM_NIL;
	T4_ = getSysType__magicsys_u55(g_p0, info_p4, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T4_); goto LA1_;}
	eqsink___ast_u3387(&(*dest_1).typ, T4_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_ = NIM_NIL;
	T5_ = newProcType__ast_u7492(info_p4, idgen_p5, owner_p2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T5_); goto LA1_;}
	eqsink___ast_u3387(&(*result).typ, T5_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addParam__ast_u7497((*result).typ, dest_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	n_1 = newNodeI__ast_u4095(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79), info_p4, ((NI)7));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
				if (!(i_2 < colontmp_)) goto LA8;
				i_1 = i_2;
				T9_ = NIM_NIL;
				T9_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), info_p4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto LA1_;}
				eqsink___ast_u3261(&(*n_1)._kind_6.sons.p->data[i_1], T9_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				i_2 += ((NI)1);
			} LA8: ;
		}
	}
	T10_ = NIM_NIL;
	T10_ = newSymNode__ast_u5168(result);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T10_); goto LA1_;}
	eqsink___ast_u3261(&(*n_1)._kind_6.sons.p->data[((NI)0)], T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3255(&(*n_1)._kind_6.sons.p->data[((NI)3)], (*(*result).typ).n);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	body_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), info_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	castType_1 = makePtrType__magicsys_u184(typ_p1, idgen_p5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__5;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__6;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__7;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
		tyArray__al2p7ldDMvbBVYNFCuu4Rw T15_;
		tyArray__al2p7ldDMvbBVYNFCuu4Rw T16_;
		colontmpD__2 = firstParamType__ast_u5363((*theProc_p6).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23)))) goto LA13_;
		colontmpD__3 = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__6 = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		colontmpD__8 = NIM_NIL;
		nimZeroMem((void*)T15_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
		colontmpD__3 = newSymNode__ast_u5168(theProc_p6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T15_[0] = colontmpD__3;
		nimZeroMem((void*)T16_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
		colontmpD__4 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4), info_p4, castType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T16_[0] = colontmpD__4;
		colontmpD__5 = newSymNode__ast_u5168(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T16_[1] = colontmpD__5;
		colontmpD__6 = newTreeIT__ast_u4191(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)61), info_p4, castType_1, T16_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__7 = newDeref__lowerings_u12(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T15_[1] = colontmpD__7;
		colontmpD__8 = newTreeI__ast_u4180(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27), info_p4, T15_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		add__ast_u3215(body_1, colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA11_;
LA13_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* addrOf_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__10;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__11;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__12;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__13;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__14;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__15;
		tyArray__al2p7ldDMvbBVYNFCuu4Rw T18_;
		tyArray__al2p7ldDMvbBVYNFCuu4Rw T19_;
		addrOf_1 = NIM_NIL;
		colontmpD__9 = NIM_NIL;
		colontmpD__10 = NIM_NIL;
		colontmpD__11 = NIM_NIL;
		colontmpD__12 = NIM_NIL;
		colontmpD__13 = NIM_NIL;
		colontmpD__14 = NIM_NIL;
		colontmpD__15 = NIM_NIL;
		colontmpD__9 = firstParamType__ast_u5363((*theProc_p6).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addrOf_1 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64), info_p4, colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		nimZeroMem((void*)T18_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
		colontmpD__10 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4), info_p4, castType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T18_[0] = colontmpD__10;
		colontmpD__11 = newSymNode__ast_u5168(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T18_[1] = colontmpD__11;
		colontmpD__12 = newTreeIT__ast_u4191(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)61), info_p4, castType_1, T18_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__13 = newDeref__lowerings_u12(colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		add__ast_u3215(addrOf_1, colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		nimZeroMem((void*)T19_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
		colontmpD__14 = newSymNode__ast_u5168(theProc_p6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T19_[0] = colontmpD__14;
		T19_[1] = addrOf_1;
		colontmpD__15 = newTreeI__ast_u4180(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27), info_p4, T19_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		add__ast_u3215(body_1, colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3378(colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3252(addrOf_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	eqsink___ast_u3261(&(*n_1)._kind_6.sons.p->data[((NI)6)], body_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqwasMoved___ast_u3249(&body_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___ast_u3261(&(*result).ast, n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqwasMoved___ast_u3249(&n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)2))) & 63);
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)39))) & 63);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(castType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(body_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(procname_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genHook__cgen_u10069)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p3, NimStringV2* result_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* theProc_1;
NIM_BOOL oldNimErrFin23_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	theProc_1 = NIM_NIL;
	theProc_1 = getAttachedOp__modulegraphs_u4987((*(*m_p0).g).graph, t_p1, op_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NIM_BOOL T6_;
		T4_ = (NIM_BOOL)0;
		T4_ = !((theProc_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T6_ = (NIM_BOOL)0;
		T6_ = isTrivialProc__cgen_u10033((*(*m_p0).g).graph, theProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !(T6_);
LA5_: ;
		if (!T4_) goto LA7_;
		{
			NIM_BOOL T11_;
			NimStringV2 colontmpD_;
			NimStringV2 T16_;
			T11_ = (NIM_BOOL)0;
			T11_ = ((*theProc_1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
			if (T11_) goto LA12_;
			T11_ = !(((*(*theProc_1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0)));
LA12_: ;
			if (!T11_) goto LA13_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			T16_.len = 0; T16_.p = NIM_NIL;
			T16_ = rawNewString((*(*theProc_1).name).s.len + 47);
appendString((&T16_), (*(*theProc_1).name).s);
appendString((&T16_), TM__MQdRN7fpbG7rPm4JpVVAhA_442);
			colontmpD_ = T16_;
			liMessage__msgs_u1227((*(*m_p0).g).config, info_p2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_443, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			{
				LA15_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA13_: ;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* wrapper_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
			if (!(op_p3 == ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1))) goto LA21_;
			wrapper_1 = NIM_NIL;
			colontmpD__2 = NIM_NIL;
			colontmpD__2 = owner__ast_u6254(theProc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			wrapper_1 = generateRttiDestructor__cgen_u10037((*(*m_p0).g).graph, t_p1, colontmpD__2, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1), (*theProc_1).info, (*m_p0).Sup.idgen, theProc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			genProc__cgen_u454(m_p0, wrapper_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&(*result_p4)), (*wrapper_1).loc.snippet.len + 0);
appendString((&(*result_p4)), (*wrapper_1).loc.snippet);
			{
				LA23_:;
			}
			{
				oldNimErrFin23_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u4574(wrapper_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin23_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA19_;
LA21_: ;
		{
			genProc__cgen_u454(m_p0, theProc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*result_p4)), (*theProc_1).loc.snippet.len + 0);
appendString((&(*result_p4)), (*theProc_1).loc.snippet);
		}
LA19_: ;
	}
	goto LA2_;
LA7_: ;
	{
		prepareAdd((&(*result_p4)), 7);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_448);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(theProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI16, getObjDepth__cgen_u10096)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NI16 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI16)0;
	x_1 = NIM_NIL;
	eqcopy___ast_u3381(&x_1, t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = ((NI16)-1);
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T3_;
			if (!!((x_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA2;
			T3_ = NIM_NIL;
			T3_ = skipTypes__ast_u5379(x_1, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T3_); goto BeforeRet_;}
			eqsink___ast_u3387(&x_1, T3_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqcopy___ast_u3381(&x_1, (*x_1).sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result += ((NI)1);
		} LA2: ;
	}
	eqdestroy___ast_u3378(x_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfo2Name__cgen_u9985)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* it_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T2_;
	NimStringV2 T31_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	it_1 = NIM_NIL;
	eqcopy___ast_u3381(&it_1, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = NIM_NIL;
	T2_ = skipTypes__ast_u5379(it_1, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T2_); goto LA1_;}
	eqsink___ast_u3387(&it_1, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_2;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*it_1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T5_)) goto LA6_;
		T5_ = !((((*it_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)8)))&63U)))!=0));
LA6_: ;
		if (!T5_) goto LA7_;
		m_2 = NIM_NIL;
		m_2 = owner__ast_u6254((*it_1).sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			while (1) {
				NIM_BOOL T11_;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T13_;
				T11_ = (NIM_BOOL)0;
				T11_ = !((m_2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
				if (!(T11_)) goto LA12_;
				T11_ = !(((*m_2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6)));
LA12_: ;
				if (!T11_) goto LA10;
				T13_ = NIM_NIL;
				T13_ = owner__ast_u6254(m_2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T13_); goto LA1_;}
				eqsink___ast_u4583(&m_2, T13_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA10: ;
		}
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = (m_2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
			if (T16_) goto LA17_;
			T16_ = (((*m_2).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0);
LA17_: ;
			if (!T16_) goto LA18_;
			eqcopy___system_u2694((&result), (*(*(*it_1).sym).name).s);
		}
		goto LA14_;
LA18_: ;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* p_1;
			NimStringV2 colontmpD_;
			NimStringV2 T28_;
			p_1 = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			p_1 = owner__ast_u6254(m_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			result = TM__MQdRN7fpbG7rPm4JpVVAhA_454;
			{
				NIM_BOOL T23_;
				NimStringV2 colontmpD__2;
				NimStringV2 T27_;
				T23_ = (NIM_BOOL)0;
				T23_ = !((p_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
				if (!(T23_)) goto LA24_;
				T23_ = ((*p_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)24));
LA24_: ;
				if (!T23_) goto LA25_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				T27_.len = 0; T27_.p = NIM_NIL;
				T27_ = rawNewString((*(*p_1).name).s.len + 1);
appendString((&T27_), (*(*p_1).name).s);
appendString((&T27_), TM__MQdRN7fpbG7rPm4JpVVAhA_456);
				colontmpD__2 = T27_;
				prepareAdd((&result), colontmpD__2.len + 0);
appendString((&result), colontmpD__2);
				eqdestroy___system_u2691(colontmpD__2);
			}
LA25_: ;
			T28_.len = 0; T28_.p = NIM_NIL;
			T28_ = rawNewString((*(*m_2).name).s.len + 1);
appendString((&T28_), (*(*m_2).name).s);
appendString((&T28_), TM__MQdRN7fpbG7rPm4JpVVAhA_457);
			colontmpD_ = T28_;
			prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
			prepareAdd((&result), (*(*(*it_1).sym).name).s.len + 0);
appendString((&result), (*(*(*it_1).sym).name).s);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u4574(p_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA14_: ;
		eqdestroy___ast_u4574(m_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA7_: ;
	{
		tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T30_;
		nimZeroMem((void*)T30_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
		hashType__sighashes_u411(it_1, (*(*m_p0).g).config, 2, T30_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		result = dollar___modulegraphs_u10732(T30_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	T31_.len = 0; T31_.p = NIM_NIL;
	T31_ = makeCString__msgs_u83(result);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T31_); goto LA1_;}
	eqsink___system_u2700((&result), T31_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NU32, genDisplayElem__cgen_u10109)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow d_p0) {
	NU32 result;
	result = ((NU32)0);
	{
		NI i_1;
		NI res_1;
		i_1 = (NI)0;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= ((NI)3))) goto LA3;
				i_1 = ((NI) (res_1));
				result += ((NU32) (d_p0[(i_1)- 0]));
				result = (NU32)((NU32)(result) << (NU32)(((NI)8) & (32 - 1)));
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genDisplay__cgen_u10125)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NI depth_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_1;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ seqs_1;
	NI i_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	x_1 = NIM_NIL;
	seqs_1.len = 0; seqs_1.p = NIM_NIL;
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_460;
	eqcopy___ast_u3381(&x_1, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	seqs_1 = newSeq__stdZsyncio_u571(((NI)(depth_p2 + ((NI)1))));
	i_1 = ((NI)0);
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T4_;
			tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T5_;
			NU32 T6_;
			NimStringV2 T7_;
			if (!!((x_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA3;
			T4_ = NIM_NIL;
			T4_ = skipTypes__ast_u5379(x_1, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T4_); goto LA1_;}
			eqsink___ast_u3387(&x_1, T4_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			nimZeroMem((void*)T5_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
			hashType__sighashes_u411(x_1, (*(*m_p0).g).config, 2, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T6_ = (NU32)0;
			T6_ = genDisplayElem__cgen_u10109(T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T7_.len = 0; T7_.p = NIM_NIL;
			T7_ = dollar___systemZdollars_u49(T6_);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA1_;}
			eqsink___system_u2700((&seqs_1.p->data[i_1]), T7_);
			eqcopy___ast_u3381(&x_1, (*x_1).sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_1 += ((NI)1);
		} LA3: ;
	}
	{
		NI i_2;
		NI res_1;
		i_2 = (NI)0;
		res_1 = depth_p2;
		{
			while (1) {
				NimStringV2 colontmpD_;
				NimStringV2 T11_;
				if (!(((NI)1) <= res_1)) goto LA10;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				i_2 = ((NI) (res_1));
				T11_.len = 0; T11_.p = NIM_NIL;
				T11_ = rawNewString(seqs_1.p->data[i_2].len + 2);
appendString((&T11_), seqs_1.p->data[i_2]);
appendString((&T11_), TM__MQdRN7fpbG7rPm4JpVVAhA_461);
				colontmpD_ = T11_;
				prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
				res_1 -= ((NI)1);
				eqdestroy___system_u2691(colontmpD_);
			} LA10: ;
		}
	}
	prepareAdd((&result), seqs_1.p->data[((NI)0)].len + 0);
appendString((&result), seqs_1.p->data[((NI)0)]);
	prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_463);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u5506(seqs_1);
		eqdestroy___ast_u3378(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genVTable__cgen_u10180)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA seqs_p0) {
	NimStringV2 result;
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_464;
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = seqs_p0.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				NimStringV2 colontmpD_;
				NimStringV2 T9_;
				if (!(i_2 < colontmp_)) goto LA4;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				i_1 = i_2;
				{
					if (!(((NI)0) < i_1)) goto LA7_;
					prepareAdd((&result), 2);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_465);
				}
LA7_: ;
				T9_.len = 0; T9_.p = NIM_NIL;
				T9_ = rawNewString((*seqs_p0.p->data[i_1]).loc.snippet.len + 9);
appendString((&T9_), TM__MQdRN7fpbG7rPm4JpVVAhA_467);
appendString((&T9_), (*seqs_p0.p->data[i_1]).loc.snippet);
				colontmpD_ = T9_;
				prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
				i_2 += ((NI)1);
				eqdestroy___system_u2691(colontmpD_);
			} LA4: ;
		}
	}
	prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_468);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeToC__cgen_u12225)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NimStringV2 result;
	NimStringV2 s_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	s_1.len = 0; s_1.p = NIM_NIL;
	s_1 = typeToString__types_u54(t_p0, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = rawNewString((s_1.len));
	{
		NIM_CHAR c_1;
		NI i_1;
		NI L_1;
		c_1 = (NIM_CHAR)0;
		i_1 = ((NI)0);
		L_1 = s_1.len;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				c_1 = s_1.p->data[i_1];
				switch (((NU8)(c_1))) {
				case 97 ... 122:
				{
					nimAddCharV1((&result), c_1);
				}
				break;
				case 65 ... 90:
				{
					NIM_CHAR T7_;
					T7_ = (NIM_CHAR)0;
					T7_ = nsuToLowerAsciiChar(c_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					nimAddCharV1((&result), T7_);
				}
				break;
				case 32:
				{
				}
				break;
				case 44:
				{
					nimAddCharV1((&result), 95);
				}
				break;
				case 46:
				{
					nimAddCharV1((&result), 79);
				}
				break;
				case 91:
				case 40:
				case 123:
				{
					nimAddCharV1((&result), 76);
				}
				break;
				case 93:
				case 41:
				case 125:
				{
					nimAddCharV1((&result), 84);
				}
				break;
				default:
				{
					addInt__stdZprivateZdigitsutils_u204((&result), ((NU8)(c_1)));
				}
				break;
				}
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(s_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, tiNameForHcr__cgen_u9093)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1) {
	NimStringV2 result;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		NimStringV2 T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T4_) goto LA5_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = rawNewString(name_p1.len + 3);
appendString((&T7_), TM__MQdRN7fpbG7rPm4JpVVAhA_489);
appendString((&T7_), name_p1);
appendString((&T7_), TM__MQdRN7fpbG7rPm4JpVVAhA_490);
		result = T7_;
	}
	goto LA2_;
LA5_: ;
	{
		eqcopy___system_u2694((&result), name_p1);
	}
LA2_: ;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAuxBase__cgen_u9097)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, NimStringV2 base_p4, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p5) {
	NimStringV2 nameHcr_1;
	NimStringV2 size_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NI nimtypeKind_1;
	tyArray__Seu7uK9aaOSN0BK3EAjjSHw T13_;
	NI flags_1;
NIM_BOOL oldNimErrFin47_;
NIM_BOOL oldNimErrFin34_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nameHcr_1.len = 0; nameHcr_1.p = NIM_NIL;
	size_1.len = 0; size_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	nimtypeKind_1 = (NI)0;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isObjLackingTypeField__types_u2952(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		nimtypeKind_1 = ((NI)18);
	}
	goto LA2_;
LA5_: ;
	{
		nimtypeKind_1 = (*typ_p1).kind;
	}
LA2_: ;
	nameHcr_1 = tiNameForHcr__cgen_u9093(m_p0, name_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*typ_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)40)))&63U)))!=0)) goto LA10_;
		size_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_492;
	}
	goto LA8_;
LA10_: ;
	{
		size_1 = getTypeDesc__cgen_u8738(m_p0, origType_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	T13_[0] = nameHcr_1;
	T13_[1] = size_1;
	colontmpD_ = rope__ropes_u15(((NI64) (nimtypeKind_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_[2] = colontmpD_;
	T13_[3] = base_p4;
	colontmpD__2 = percent___cgen_u9117(T13_, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__2);
	flags_1 = ((NI)0);
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = containsGarbageCollectedRef__types_u555(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T16_)) goto LA17_;
		flags_1 = (NI)(flags_1 | ((NI)1));
	}
LA17_: ;
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = canFormAcycle__types_u784((*(*m_p0).g).graph, typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T21_)) goto LA22_;
		flags_1 = (NI)(flags_1 | ((NI)2));
	}
LA22_: ;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T28_;
		if (!!((flags_1 == ((NI)0)))) goto LA26_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T28_[0] = nameHcr_1;
		colontmpD__3 = rope__ropes_u15(((NI64) (flags_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T28_[1] = colontmpD__3;
		colontmpD__4 = percent___cgen_u9123(T28_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__4.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__4);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
	}
LA26_: ;
	cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_493);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T31_;
		NimStringV2 typename_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T35_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T51_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T52_;
		T31_ = (NIM_BOOL)0;
		T31_ = isDefined__options_u959((*(*m_p0).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_494);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T31_) goto LA32_;
		typename_1.len = 0; typename_1.p = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__6 = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		T35_ = NIM_NIL;
		{
			if (!!(((*origType_p2).typeInst == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA38_;
			eqcopy___ast_u3381(&colontmpD__5, (*origType_p2).typeInst);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T35_ = colontmpD__5;
		}
		goto LA36_;
LA38_: ;
		{
			eqcopy___ast_u3381(&colontmpD__6, origType_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T35_ = colontmpD__6;
		}
LA36_: ;
		typename_1 = typeToString__types_u54(T35_, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		{
			NIM_BOOL T43_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 T48_;
			T43_ = (NIM_BOOL)0;
			T43_ = eqStrings(typename_1, TM__MQdRN7fpbG7rPm4JpVVAhA_496);
			if (!(T43_)) goto LA44_;
			colontmpD__7 = skipTypes__ast_u5379(origType_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T43_ = !(((*colontmpD__7).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA44_: ;
			if (!T43_) goto LA45_;
			colontmpD__11 = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			T48_.len = 0; T48_.p = NIM_NIL;
			colontmpD__11 = skipTypes__ast_u5379(origType_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
			colontmpD__12 = dollar___msgs_u714((*(*m_p0).g).config, (*(*colontmpD__11).sym).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
			T48_ = rawNewString(colontmpD__12.len + 21);
appendString((&T48_), TM__MQdRN7fpbG7rPm4JpVVAhA_498);
appendString((&T48_), colontmpD__12);
			eqsink___system_u2700((&typename_1), T48_);
			{
				LA47_:;
			}
			{
				oldNimErrFin47_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___ast_u3378(colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				*nimErr_ = oldNimErrFin47_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		}
LA45_: ;
		T51_[0] = nameHcr_1;
		colontmpD__8 = makeCString__msgs_u83(typename_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		T51_[1] = colontmpD__8;
		colontmpD__9 = percent___cgen_u9137(T51_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__9.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__9);
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_500);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		T52_[0] = nameHcr_1;
		colontmpD__10 = percent___cgen_u9142(T52_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__10.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__10);
		{
			LA34_:;
		}
		{
			oldNimErrFin34_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(typename_1);
			*nimErr_ = oldNimErrFin34_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA32_: ;
	{
		NIM_BOOL T57_;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		tyArray__YgExxhfgKcesA5EOUj1MOA T61_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T62_;
		T57_ = (NIM_BOOL)0;
		T57_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T57_) goto LA58_;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		T61_[0] = name_p3;
		colontmpD__13 = percent___cgen_u9147(T61_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__13.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__13);
		T62_[0] = name_p3;
		colontmpD__14 = getModuleDllPath__cgen_u158(m_p0, (*m_p0).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		T62_[1] = colontmpD__14;
		colontmpD__15 = percent___cgen_u9152(T62_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		prepareAdd((&(*m_p0).hcrCreateTypeInfosProc), colontmpD__15.len + 0);
appendString((&(*m_p0).hcrCreateTypeInfosProc), colontmpD__15);
		{
			LA60_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA55_;
LA58_: ;
	{
		NimStringV2 colontmpD__16;
		tyArray__YgExxhfgKcesA5EOUj1MOA T66_;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		T66_[0] = name_p3;
		colontmpD__16 = percent___cgen_u9157(T66_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__16.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__16);
		eqdestroy___system_u2691(colontmpD__16);
	}
LA55_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(size_1);
		eqdestroy___system_u2691(nameHcr_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, fakeClosureType__cgen_u9529)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* r_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* obj_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	r_1 = NIM_NIL;
	obj_1 = NIM_NIL;
	result = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18), (*m_p0).Sup.idgen, owner_p1, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26), (*m_p0).Sup.idgen, owner_p1, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rawAddSon__ast_u6706(result, colontmpD_, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	r_1 = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22), (*m_p0).Sup.idgen, owner_p1, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	obj_1 = createObj__lowerings_u174((*(*m_p0).g).graph, (*m_p0).Sup.idgen, owner_p1, (*owner_p1).info, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rawAddSon__ast_u6706(r_1, obj_1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rawAddSon__ast_u6706(result, r_1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(obj_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getNimNode__cgen_u9080)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_[0] = (*m_p0).typeNodesName;
	colontmpD_ = rope__ropes_u15(((NI64) ((*m_p0).typeNodes)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[1] = colontmpD_;
	result = percent___cgen_u9083(T1_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*m_p0).typeNodes += ((NI)1);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmptyType__ast_u7234)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (t_p0 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (T1_) goto LA2_;
	T1_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7));
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, validTupleTypeFields__cgen_u9394)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((NI)0);
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_1;
		a_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI T3_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T3_ = (*t_p0).sons.len;
			colontmp_ = T3_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i_1 = i_2;
					eqcopy___ast_u3381(&a_1, (*t_p0).sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						NIM_BOOL T8_;
						T8_ = (NIM_BOOL)0;
						T8_ = isEmptyType__ast_u7234(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!!(T8_)) goto LA9_;
						result += ((NI)1);
					}
LA9_: ;
					i_2 += ((NI)1);
				} LA5: ;
			}
		}
		eqdestroy___ast_u3378(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTNimNodeArray__cgen_u9231)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1, NimStringV2 size_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__YgExxhfgKcesA5EOUj1MOA T7_;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T7_[0] = name_p1;
		colontmpD_ = percent___cgen_u9235(T7_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), colontmpD_);
		T8_[0] = name_p1;
		T8_[1] = size_p2;
		colontmpD__2 = getModuleDllPath__cgen_u158(m_p0, (*m_p0).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T8_[2] = colontmpD__2;
		colontmpD__3 = percent___cgen_u9240(T8_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&(*m_p0).hcrCreateTypeInfosProc), colontmpD__3.len + 0);
appendString((&(*m_p0).hcrCreateTypeInfosProc), colontmpD__3);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T12_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T12_[0] = name_p1;
		T12_[1] = size_p2;
		colontmpD__4 = percent___cgen_u9245(T12_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), colontmpD__4.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), colontmpD__4);
		eqdestroy___system_u2691(colontmpD__4);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleInfo__cgen_u9403)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
	NimStringV2 expr_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NI nonVoidKids_1;
NIM_BOOL oldNimErrFin9_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T32_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	expr_1.len = 0; expr_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	genTypeInfoAuxBase__cgen_u9097(m_p0, typ_p1, typ_p1, name_p3, TM__MQdRN7fpbG7rPm4JpVVAhA_508, info_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	expr_1 = getNimNode__cgen_u9080(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nonVoidKids_1 = validTupleTypeFields__cgen_u9394(typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 tmp_1;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 T7_;
		NI j_1;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T27_;
		if (!(((NI)0) < nonVoidKids_1)) goto LA4_;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T7_.len = 0; T7_.p = NIM_NIL;
		colontmpD__3 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__4 = dollar___systemZdollars_u9(nonVoidKids_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_ = rawNewString(colontmpD__3.len + colontmpD__4.len + 1);
appendString((&T7_), colontmpD__3);
appendString((&T7_), TM__MQdRN7fpbG7rPm4JpVVAhA_509);
appendString((&T7_), colontmpD__4);
		tmp_1 = T7_;
		colontmpD__5 = rope__ropes_u15(((NI64) (nonVoidKids_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		genTNimNodeArray__cgen_u9231(m_p0, tmp_1, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		j_1 = ((NI)0);
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_1;
			NI i_1;
			a_1 = NIM_NIL;
			i_1 = (NI)0;
			{
				NI i_2;
				NI colontmp_;
				NI T11_;
				NI i_3;
				i_2 = (NI)0;
				colontmp_ = (NI)0;
				T11_ = (*typ_p1).sons.len;
				colontmp_ = T11_;
				i_3 = ((NI)0);
				{
					while (1) {
						if (!(i_3 < colontmp_)) goto LA13;
						i_2 = i_3;
						i_1 = i_2;
						eqcopy___ast_u3381(&a_1, (*typ_p1).sons.p->data[i_2]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
						{
							NimStringV2 tmp2_1;
							NimStringV2 colontmpD__8;
							NimStringV2 colontmpD__9;
							NimStringV2 colontmpD__10;
							NimStringV2 colontmpD__11;
							NimStringV2 colontmpD__12;
							NimStringV2 colontmpD__13;
							tyArray__dyW7vpmfeTYw8kX3EXuaJA T21_;
							tyArray__Seu7uK9aaOSN0BK3EAjjSHw T22_;
							tmp2_1.len = 0; tmp2_1.p = NIM_NIL;
							colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
							colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
							colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
							colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
							colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
							colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
							{
								NIM_BOOL T18_;
								T18_ = (NIM_BOOL)0;
								T18_ = isEmptyType__ast_u7234(a_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
								if (!T18_) goto LA19_;
								eqdestroy___system_u2691(colontmpD__13);
								eqdestroy___system_u2691(colontmpD__12);
								eqdestroy___system_u2691(colontmpD__11);
								eqdestroy___system_u2691(colontmpD__10);
								eqdestroy___system_u2691(colontmpD__9);
								eqdestroy___system_u2691(colontmpD__8);
								eqdestroy___system_u2691(tmp2_1);
								goto LA14;
							}
LA19_: ;
							tmp2_1 = getNimNode__cgen_u9080(m_p0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							T21_[0] = tmp_1;
							colontmpD__8 = rope__ropes_u15(((NI64) (j_1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							T21_[1] = colontmpD__8;
							T21_[2] = tmp2_1;
							colontmpD__9 = percent___cgen_u9264(T21_, 3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__9.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__9);
							T22_[0] = tmp2_1;
							colontmpD__10 = getTypeDesc__cgen_u8738(m_p0, origType_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							T22_[1] = colontmpD__10;
							colontmpD__11 = rope__ropes_u15(((NI64) (i_1)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							T22_[2] = colontmpD__11;
							colontmpD__12 = genTypeInfoV1__cgen_u9076(m_p0, a_1, info_p4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							T22_[3] = colontmpD__12;
							colontmpD__13 = percent___cgen_u9420(T22_, 4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__13.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__13);
							j_1 += ((NI)1);
							{
								LA15_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__13);
								eqdestroy___system_u2691(colontmpD__12);
								eqdestroy___system_u2691(colontmpD__11);
								eqdestroy___system_u2691(colontmpD__10);
								eqdestroy___system_u2691(colontmpD__9);
								eqdestroy___system_u2691(colontmpD__8);
								eqdestroy___system_u2691(tmp2_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
						} LA14: ;
						i_3 += ((NI)1);
					} LA13: ;
				}
			}
			{
				LA9_:;
			}
			{
				oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				*nimErr_ = oldNimErrFin9_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
		T27_[0] = expr_1;
		colontmpD__6 = rope__ropes_u15(((NI64) (nonVoidKids_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T27_[1] = colontmpD__6;
		T27_[2] = tmp_1;
		colontmpD__7 = percent___cgen_u9269(T27_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__7.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__7);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(tmp_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD__14;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T31_;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		T31_[0] = expr_1;
		T31_[1] = TM__MQdRN7fpbG7rPm4JpVVAhA_510;
		colontmpD__14 = percent___cgen_u9274(T31_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__14.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__14);
		eqdestroy___system_u2691(colontmpD__14);
	}
LA2_: ;
	colontmpD_ = tiNameForHcr__cgen_u9093(m_p0, name_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T32_[0] = colontmpD_;
	T32_[1] = expr_1;
	colontmpD__2 = percent___cgen_u9380(T32_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__2);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(expr_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, hasElementType__ast_u5660)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NI T1_;
	T1_ = (*t_p0).sons.len;
	result = (((NI)0) < T1_);
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, last__ast_u5278)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoAux__cgen_u9162)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
	NimStringV2 base_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	base_1.len = 0; base_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	{
		NIM_BOOL T4_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_1;
		T4_ = (NIM_BOOL)0;
		T4_ = hasElementType__ast_u5660(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_)) goto LA5_;
		colontmpD_ = last__ast_u5278(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA5_: ;
		if (!T4_) goto LA6_;
		x_1 = NIM_NIL;
		x_1 = last__ast_u5278(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T13_;
			if (!((*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17))) goto LA11_;
			T13_ = NIM_NIL;
			T13_ = skipTypes__ast_u5379(x_1, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T13_); goto LA8_;}
			eqsink___ast_u3387(&x_1, T13_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA11_: ;
		{
			NIM_BOOL T16_;
			NIM_BOOL T17_;
			NIM_BOOL T20_;
			T16_ = (NIM_BOOL)0;
			T17_ = (NIM_BOOL)0;
			T17_ = ((*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
			if (!(T17_)) goto LA18_;
			T17_ = ((*x_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
LA18_: ;
			T16_ = T17_;
			if (!(T16_)) goto LA19_;
			T20_ = (NIM_BOOL)0;
			T20_ = !(((*x_1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
			if (!(T20_)) goto LA21_;
			T20_ = ((1040 & (*(*x_1).sym).flags) == 16);
LA21_: ;
			T16_ = T20_;
LA19_: ;
			if (!T16_) goto LA22_;
			base_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_511;
		}
		goto LA14_;
LA22_: ;
		{
			base_1 = genTypeInfoV1__cgen_u9076(m_p0, x_1, info_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA14_: ;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(x_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		base_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_512;
	}
LA2_: ;
	genTypeInfoAuxBase__cgen_u9097(m_p0, typ_p1, origType_p2, name_p3, base_1, info_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(base_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, freeze__ropes_u10)(NimStringV2 r_p0) {
}
static N_INLINE(NimStringV2, lenField__cgen_u484)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T4_) goto LA5_;
		T4_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA5_: ;
		if (!T4_) goto LA6_;
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_522;
	}
	goto LA2_;
LA6_: ;
	{
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_524;
	}
LA2_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, lenExpr__cgen_u495)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T5_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T5_.len = 0; T5_.p = NIM_NIL;
		colontmpD_ = rdLoc__cgen_u470(a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T5_ = rawNewString(colontmpD_.len + 4);
appendString((&T5_), colontmpD_);
appendString((&T5_), TM__MQdRN7fpbG7rPm4JpVVAhA_520);
		result = T5_;
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__2 = rdLoc__cgen_u470(a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T7_[0] = colontmpD__2;
		colontmpD__3 = lenField__cgen_u484(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T7_[1] = colontmpD__3;
		result = percent___cgen_u503(T7_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, indexType__ast_u5345)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, cgFormatValue__cgen_u169)(NimStringV2* result_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg value_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addInt128__int128_u821(result_p0, value_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NimStringV2, parentObj__cgen_u9625)(NimStringV2 accessor_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*(*m_p1).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T3_) goto LA4_;
		T3_ = (((*(*m_p1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA4_: ;
		if (!!(T3_)) goto LA5_;
		T7_[0] = accessor_p0;
		result = percent___cgen_u9637(T7_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		eqcopy___system_u2694((&result), accessor_p0);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isKeyword__cgen_u757)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* w_p0) {
	NIM_BOOL result;
{	switch ((*w_p0).id) {
	case ((NI)234) ... ((NI)300):
	case ((NI)4) ... ((NI)66):
	case ((NI)148):
	{
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	break;
	default:
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleField__cgen_u763)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = mangle__mangleutils_u4((*name_p1).s);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isKeyword__cgen_u757(name_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		prepareAdd((&result), 2);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_551);
	}
LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mangleRecFieldName__cgen_u4042)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T3_;
		T3_ = 0;
		if (!!(((192 & (*field_p1).flags) == T3_))) goto LA4_;
		eqcopy___system_u2694((&result), (*field_p1).loc.snippet);
	}
	goto LA1_;
LA4_: ;
	{
		result = mangleField__cgen_u763(m_p0, (*field_p1).name);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	{
		if (!(result.len == 0)) goto LA9_;
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*field_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_553, TM__MQdRN7fpbG7rPm4JpVVAhA_554);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA9_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, fillLoc__cgen_u78)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p0, tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode_p2, NimStringV2 r_p3, tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg s_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*a_p0).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA3_;
		(*a_p0).k = k_p1;
		eqcopy___ast_u3255(&(*a_p0).lode, lode_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*a_p0).storage = s_p4;
		{
			if (!((*a_p0).snippet.len == 0)) goto LA7_;
			eqcopy___system_u2694((&(*a_p0).snippet), r_p3);
		}
LA7_: ;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasCppCtor__cgen_u4054)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T5_) goto LA6_;
		T5_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = !((typ_p1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T3_ = contains__cgen_u4125((*(*(*m_p0).g).graph).memberProcsPerType, (*typ_p1).itemId);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA8_: ;
		if (!T3_) goto LA9_;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** prc_1;
			tySequence__ZCZaCk14bTmSb6LMW9aWPVA* colontmp_;
			NI i_1;
			NI L_1;
			NI T12_;
			prc_1 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
			colontmp_ = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA*)0;
			colontmp_ = X5BX5D___cgen_u4463((&(*(*(*m_p0).g).graph).memberProcsPerType), (*typ_p1).itemId);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_1 = ((NI)0);
			T12_ = (*colontmp_).len;
			L_1 = T12_;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA14;
					prc_1 = &(*colontmp_).p->data[i_1];
					{
						if (!(((*(*prc_1)).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29)))&63U)))!=0)) goto LA17_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
LA17_: ;
					i_1 += ((NI)1);
				} LA14: ;
			}
		}
	}
LA9_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addField__cgen_u534)(NimStringV2* obj_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p1, NimStringV2 name_p2, NimStringV2 typ_p3, NIM_BOOL isFlexArray_p4, NimStringV2 initializer_p5) {
	nimAddCharV1((&(*obj_p0)), 9);
	{
		if (!(((NI)0) < (*field_p1)._kind_2.alignment)) goto LA3_;
		prepareAdd((&(*obj_p0)), 10);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_580);
		addInt__stdZprivateZdigitsutils_u204(obj_p0, (*field_p1)._kind_2.alignment);
		prepareAdd((&(*obj_p0)), 2);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_581);
	}
LA3_: ;
	prepareAdd((&(*obj_p0)), typ_p3.len + 0);
appendString((&(*obj_p0)), typ_p3);
	{
		if (!(((*field_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)47)))&63U)))!=0)) goto LA7_;
		prepareAdd((&(*obj_p0)), 12);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_582);
	}
LA7_: ;
	prepareAdd((&(*obj_p0)), 1);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_583);
	prepareAdd((&(*obj_p0)), name_p2.len + 0);
appendString((&(*obj_p0)), name_p2);
	{
		if (!isFlexArray_p4) goto LA11_;
		prepareAdd((&(*obj_p0)), 15);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_585);
	}
LA11_: ;
	{
		if (!!(((*field_p1)._kind_2.bitsize == ((NI)0)))) goto LA15_;
		prepareAdd((&(*obj_p0)), 1);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_586);
		addInt__stdZprivateZdigitsutils_u204(obj_p0, (*field_p1)._kind_2.bitsize);
	}
LA15_: ;
	{
		if (!!((initializer_p5.len == ((NI)0)))) goto LA19_;
		prepareAdd((&(*obj_p0)), initializer_p5.len + 0);
appendString((&(*obj_p0)), initializer_p5);
	}
LA19_: ;
	prepareAdd((&(*obj_p0)), 2);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_587);
}
N_LIB_PRIVATE N_NIMCALL(void, genRecordFieldsAux__cgen_u5054)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* rectype_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p3, NimStringV2* result_p4, NimStringV2 unionPrefix_p5) {
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin72_;
NIM_BOOL oldNimErrFin79_;
NIM_BOOL oldNimErrFin84_;
NIM_BOOL oldNimErrFin67_;
NIM_BOOL oldNimErrFin56_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA4;
					i_1 = i_2;
					genRecordFieldsAux__cgen_u5054(m_p0, (*n_p1)._kind_6.sons.p->data[i_1], rectype_p2, check_p3, result_p4, unionPrefix_p5);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA4: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
	{
		NimStringV2 unionBody_1;
		unionBody_1.len = 0; unionBody_1.p = NIM_NIL;
		{
			if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA9_;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_546, TM__MQdRN7fpbG7rPm4JpVVAhA_547);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA9_: ;
		genRecordFieldsAux__cgen_u5054(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], rectype_p2, check_p3, result_p4, unionPrefix_p5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		unionBody_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_548;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			i_4 = ((NI)1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA13;
					i_3 = i_4;
					switch ((*(*n_p1)._kind_6.sons.p->data[i_3]).kind) {
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85):
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)88):
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* k_1;
						k_1 = NIM_NIL;
						k_1 = lastSon__ast_u5208((*n_p1)._kind_6.sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						{
							NimStringV2 structName_1;
							NimStringV2 colontmpD_;
							NimStringV2 colontmpD__2;
							NimStringV2 a_1;
							NimStringV2 colontmpD__3;
							NimStringV2 T21_;
							NimStringV2 T22_;
							if (!!(((*k_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA18_;
							structName_1.len = 0; structName_1.p = NIM_NIL;
							colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
							colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
							a_1.len = 0; a_1.p = NIM_NIL;
							colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
							T21_.len = 0; T21_.p = NIM_NIL;
							colontmpD_ = mangleRecFieldName__cgen_u4042(m_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
							if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
							colontmpD__2 = dollar___systemZdollars_u9(i_3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
							T21_ = rawNewString(colontmpD_.len + colontmpD__2.len + 2);
appendString((&T21_), TM__MQdRN7fpbG7rPm4JpVVAhA_549);
appendString((&T21_), colontmpD_);
appendString((&T21_), TM__MQdRN7fpbG7rPm4JpVVAhA_555);
appendString((&T21_), colontmpD__2);
							structName_1 = T21_;
							a_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_556;
							T22_.len = 0; T22_.p = NIM_NIL;
							T22_ = rawNewString(unionPrefix_p5.len + structName_1.len + 1);
appendString((&T22_), unionPrefix_p5);
appendString((&T22_), structName_1);
appendString((&T22_), TM__MQdRN7fpbG7rPm4JpVVAhA_557);
							colontmpD__3 = T22_;
							genRecordFieldsAux__cgen_u5054(m_p0, k_1, rectype_p2, check_p3, (&a_1), colontmpD__3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
							{
								if (!!((a_1.len == ((NI)0)))) goto LA25_;
								nimAddCharV1((&unionBody_1), 9);
								{
									if (!(((*rectype_p2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23)))&63U)))!=0)) goto LA29_;
									{
										if (!((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)7)))&15U)))!=0)) goto LA33_;
										prepareAdd((&unionBody_1), 37);
appendString((&unionBody_1), TM__MQdRN7fpbG7rPm4JpVVAhA_559);
									}
									goto LA31_;
LA33_: ;
									{
										prepareAdd((&unionBody_1), 30);
appendString((&unionBody_1), TM__MQdRN7fpbG7rPm4JpVVAhA_561);
									}
LA31_: ;
								}
								goto LA27_;
LA29_: ;
								{
									prepareAdd((&unionBody_1), 9);
appendString((&unionBody_1), TM__MQdRN7fpbG7rPm4JpVVAhA_563);
								}
LA27_: ;
								prepareAdd((&unionBody_1), a_1.len + 0);
appendString((&unionBody_1), a_1);
								prepareAdd((&unionBody_1), 2);
appendString((&unionBody_1), TM__MQdRN7fpbG7rPm4JpVVAhA_565);
								prepareAdd((&unionBody_1), structName_1.len + 0);
appendString((&unionBody_1), structName_1);
								prepareAdd((&unionBody_1), 2);
appendString((&unionBody_1), TM__MQdRN7fpbG7rPm4JpVVAhA_567);
								{
									NIM_BOOL T39_;
									T39_ = (NIM_BOOL)0;
									T39_ = (((*rectype_p2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23)))&63U)))!=0);
									if (!(T39_)) goto LA40_;
									T39_ = !(((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)7)))&15U)))!=0));
LA40_: ;
									if (!T39_) goto LA41_;
									prepareAdd((&(*result_p4)), 18);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_569);
								}
LA41_: ;
							}
LA25_: ;
							{
								LA20_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__3);
								eqdestroy___system_u2691(a_1);
								eqdestroy___system_u2691(colontmpD__2);
								eqdestroy___system_u2691(colontmpD_);
								eqdestroy___system_u2691(structName_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						}
						goto LA16_;
LA18_: ;
						{
							genRecordFieldsAux__cgen_u5054(m_p0, k_1, rectype_p2, check_p3, (&unionBody_1), unionPrefix_p5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						}
LA16_: ;
						{
							LA15_:;
						}
						{
							oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(k_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
							*nimErr_ = oldNimErrFin15_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					}
					break;
					default:
					{
						internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, TM__MQdRN7fpbG7rPm4JpVVAhA_571, TM__MQdRN7fpbG7rPm4JpVVAhA_572);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					}
					break;
					}
					i_4 += ((NI)1);
				} LA13: ;
			}
		}
		{
			if (!!((unionBody_1.len == ((NI)0)))) goto LA51_;
			prepareAdd((&(*result_p4)), 7);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_574);
			prepareAdd((&(*result_p4)), unionBody_1.len + 0);
appendString((&(*result_p4)), unionBody_1);
			prepareAdd((&(*result_p4)), 3);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_576);
		}
LA51_: ;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(unionBody_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		NimStringV2 sname_1;
		NimStringV2 colontmpD__4;
		NimStringV2 T61_;
		field_1 = NIM_NIL;
		sname_1.len = 0; sname_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		eqcopy___ast_u4577(&field_1, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
		{
			if (!((*(*field_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63))) goto LA59_;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(sname_1);
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA59_: ;
		sname_1 = mangleRecFieldName__cgen_u4042(m_p0, field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
		T61_.len = 0; T61_.p = NIM_NIL;
		T61_ = rawNewString(unionPrefix_p5.len + sname_1.len + 0);
appendString((&T61_), unionPrefix_p5);
appendString((&T61_), sname_1);
		colontmpD__4 = T61_;
		fillLoc__cgen_u78((&(*field_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)5), n_p1, colontmpD__4, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
		{
			NIM_BOOL T64_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* fieldType_1;
			NimStringV2 typ_1;
			NimStringV2 initializer_1;
			NIM_BOOL isFlexArray_1;
			T64_ = (NIM_BOOL)0;
			T64_ = isImportedCppType__cgen_u1384(rectype_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			if (!!(T64_)) goto LA65_;
			fieldType_1 = NIM_NIL;
			typ_1.len = 0; typ_1.p = NIM_NIL;
			initializer_1.len = 0; initializer_1.p = NIM_NIL;
			fieldType_1 = skipTypes__ast_u5379((*(*field_1).loc.lode).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			typ_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_577;
			isFlexArray_1 = NIM_FALSE;
			initializer_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_578;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
				NimStringV2 T73_;
				if (!((*fieldType_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49))) goto LA70_;
				colontmpD__5 = NIM_NIL;
				colontmpD__5 = elemType__types_u254(fieldType_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
				T73_.len = 0; T73_.p = NIM_NIL;
				T73_ = getTypeDescAux__cgen_u1419(m_p0, colontmpD__5, check_p3, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)4));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T73_); goto LA72_;}
				eqsink___system_u2700((&typ_1), T73_);
				isFlexArray_1 = NIM_TRUE;
				{
					LA72_:;
				}
				{
					oldNimErrFin72_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
					*nimErr_ = oldNimErrFin72_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			}
			goto LA68_;
LA70_: ;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
				NimStringV2 T80_;
				if (!((*fieldType_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24))) goto LA77_;
				colontmpD__6 = NIM_NIL;
				colontmpD__6 = t__cgen_u97((*field_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
				T80_.len = 0; T80_.p = NIM_NIL;
				T80_ = getTypeDescWeak__cgen_u3400(m_p0, colontmpD__6, check_p3, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)4));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T80_); goto LA79_;}
				eqsink___system_u2700((&typ_1), T80_);
				{
					LA79_:;
				}
				{
					oldNimErrFin79_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
					*nimErr_ = oldNimErrFin79_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			}
			goto LA68_;
LA77_: ;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__8;
				NimStringV2 T85_;
				NIM_BOOL noInit_1;
				NIM_BOOL T86_;
				NIM_BOOL T88_;
				colontmpD__7 = NIM_NIL;
				colontmpD__8 = NIM_NIL;
				colontmpD__7 = t__cgen_u97((*field_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				T85_.len = 0; T85_.p = NIM_NIL;
				T85_ = getTypeDescAux__cgen_u1419(m_p0, colontmpD__7, check_p3, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)4));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T85_); goto LA84_;}
				eqsink___system_u2700((&typ_1), T85_);
				T86_ = (NIM_BOOL)0;
				T86_ = (((*field_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0);
				if (T86_) goto LA87_;
				T88_ = (NIM_BOOL)0;
				T88_ = !(((*(*field_1).typ).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
				if (!(T88_)) goto LA89_;
				T88_ = (((*(*(*field_1).typ).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0);
LA89_: ;
				T86_ = T88_;
LA87_: ;
				noInit_1 = T86_;
				{
					NIM_BOOL T92_;
					NIM_BOOL T94_;
					NIM_BOOL didGenTemp_1;
					NimStringV2 T98_;
					T92_ = (NIM_BOOL)0;
					T92_ = !(noInit_1);
					if (!(T92_)) goto LA93_;
					T94_ = (NIM_BOOL)0;
					T94_ = isOrHasImportedCppType__cgen_u1404(fieldType_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					if (T94_) goto LA95_;
					colontmpD__8 = owner__ast_u6254(field_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					T94_ = hasCppCtor__cgen_u4054(m_p0, (*colontmpD__8).typ);
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
LA95_: ;
					T92_ = T94_;
LA93_: ;
					if (!T92_) goto LA96_;
					didGenTemp_1 = NIM_FALSE;
					T98_.len = 0; T98_.p = NIM_NIL;
					T98_ = genCppInitializer__cgen_u4564(m_p0, ((tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A*) NIM_NIL), fieldType_1, (&didGenTemp_1));
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T98_); goto LA84_;}
					eqsink___system_u2700((&initializer_1), T98_);
				}
LA96_: ;
				{
					LA84_:;
				}
				{
					oldNimErrFin84_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(colontmpD__8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
					eqdestroy___ast_u3378(colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
					*nimErr_ = oldNimErrFin84_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			}
LA68_: ;
			addField__cgen_u534(result_p4, field_1, sname_1, typ_1, isFlexArray_1, initializer_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			{
				LA67_:;
			}
			{
				oldNimErrFin67_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(initializer_1);
				eqdestroy___system_u2691(typ_1);
				eqdestroy___ast_u3378(fieldType_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				*nimErr_ = oldNimErrFin67_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
		}
LA65_: ;
		{
			LA56_:;
		}
		{
			oldNimErrFin56_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(sname_1);
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin56_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_589, TM__MQdRN7fpbG7rPm4JpVVAhA_590);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addRecordFields__cgen_u5247)(NimStringV2* result_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p3) {
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	genRecordFieldsAux__cgen_u5054(m_p1, (*typ_p2).n, typ_p2, check_p3, result_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_591);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		tySequence__ZCZaCk14bTmSb6LMW9aWPVA procs_1;
		tySequence__ZCZaCk14bTmSb6LMW9aWPVA* T7_;
		NIM_BOOL isDefaultCtorGen_1;
		NIM_BOOL isCtorGen_1;
		T3_ = (NIM_BOOL)0;
		T3_ = contains__cgen_u4125((*(*(*m_p1).g).graph).memberProcsPerType, (*typ_p2).itemId);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		procs_1.len = 0; procs_1.p = NIM_NIL;
		T7_ = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA*)0;
		T7_ = X5BX5D___cgen_u4463((&(*(*(*m_p1).g).graph).memberProcsPerType), (*typ_p2).itemId);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		eqcopy___ast_u4851((&procs_1), (*T7_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		isDefaultCtorGen_1 = NIM_FALSE;
		isCtorGen_1 = NIM_FALSE;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** prc_1;
			NI i_1;
			NI L_1;
			NI T9_;
			prc_1 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
			i_1 = ((NI)0);
			T9_ = procs_1.len;
			L_1 = T9_;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA11;
					prc_1 = &procs_1.p->data[i_1];
					{
						NimStringV2 header_1;
						NimStringV2 colontmpD_;
						tyArray__YgExxhfgKcesA5EOUj1MOA T27_;
						header_1.len = 0; header_1.p = NIM_NIL;
						colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
						header_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_592;
						{
							if (!(((*(*prc_1)).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29)))&63U)))!=0)) goto LA16_;
							isCtorGen_1 = NIM_TRUE;
							{
								NI T20_;
								T20_ = (NI)0;
								T20_ = len__ast_u3190((*(*(*prc_1)).typ).n);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								if (!(T20_ == ((NI)1))) goto LA21_;
								isDefaultCtorGen_1 = NIM_TRUE;
							}
LA21_: ;
						}
LA16_: ;
						{
							if (!(((*(*prc_1)).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0)) goto LA25_;
							eqdestroy___system_u2691(colontmpD_);
							eqdestroy___system_u2691(header_1);
							goto LA12;
						}
LA25_: ;
						genMemberProcHeader__cgen_u5241(m_p1, (*prc_1), (&header_1), NIM_FALSE, NIM_TRUE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T27_[0] = header_1;
						colontmpD_ = percent___cgen_u5386(T27_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						prepareAdd((&(*result_p0)), colontmpD_.len + 0);
appendString((&(*result_p0)), colontmpD_);
						{
							LA13_:;
						}
						{
							eqdestroy___system_u2691(colontmpD_);
							eqdestroy___system_u2691(header_1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					} LA12: ;
					i_1 += ((NI)1);
				} LA11: ;
			}
		}
		{
			NIM_BOOL T32_;
			tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA ch_1;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			tyArray__YgExxhfgKcesA5EOUj1MOA T37_;
			T32_ = (NIM_BOOL)0;
			T32_ = isCtorGen_1;
			if (!(T32_)) goto LA33_;
			T32_ = !(isDefaultCtorGen_1);
LA33_: ;
			if (!T32_) goto LA34_;
			nimZeroMem((void*)(&ch_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			nimZeroMem((void*)(&ch_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
			colontmpD__2 = getTypeDescAux__cgen_u1419(m_p1, typ_p2, (&ch_1), ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)7));
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			T37_[0] = colontmpD__2;
			colontmpD__3 = percent___cgen_u5396(T37_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			prepareAdd((&(*result_p0)), colontmpD__3.len + 0);
appendString((&(*result_p0)), colontmpD__3);
			{
				LA36_:;
			}
			{
				oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___pureZcollectionsZintsets_u230((&ch_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				*nimErr_ = oldNimErrFin36_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA34_: ;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4848(procs_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fillObjectFields__cgen_u5401)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA check_1;
	NimStringV2 ignored_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&check_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	ignored_1.len = 0; ignored_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	initIntSet__pureZcollectionsZintsets_u598((&check_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ignored_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_544;
	addRecordFields__cgen_u5247((&ignored_1), m_p0, typ_p1, (&check_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		colontmpD_ = baseClass__ast_u5348(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA4_;
		colontmpD__2 = NIM_NIL;
		colontmpD__3 = NIM_NIL;
		colontmpD__2 = baseClass__ast_u5348(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__3 = skipTypes__ast_u5379(colontmpD__2, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		fillObjectFields__cgen_u5401(m_p0, colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(ignored_1);
		eqdestroy___pureZcollectionsZintsets_u230((&check_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, intLiteral__cgen_u14092)(NI64 i_p0, NimStringV2* result_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = (IL64(-2147483648) < i_p0);
		if (!(T3_)) goto LA4_;
		T3_ = (i_p0 <= IL64(2147483647));
LA4_: ;
		if (!T3_) goto LA5_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = rope__ropes_u15(i_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p1)), colontmpD_.len + 0);
appendString((&(*result_p1)), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA1_;
LA5_: ;
	{
		if (!(i_p0 == IL64(-2147483648))) goto LA8_;
		prepareAdd((&(*result_p1)), 16);
appendString((&(*result_p1)), TM__MQdRN7fpbG7rPm4JpVVAhA_598);
	}
	goto LA1_;
LA8_: ;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__YgExxhfgKcesA5EOUj1MOA T13_;
		if (!((IL64(-9223372036854775807) - IL64(1)) < i_p0)) goto LA11_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__2 = rope__ropes_u15(i_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T13_[0] = colontmpD__2;
		colontmpD__3 = percent___cgen_u20104(T13_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p1)), colontmpD__3.len + 0);
appendString((&(*result_p1)), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
	}
	goto LA1_;
LA11_: ;
	{
		prepareAdd((&(*result_p1)), 38);
appendString((&(*result_p1)), TM__MQdRN7fpbG7rPm4JpVVAhA_600);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, int64Literal__cgen_u20097)(NI64 i_p0, NimStringV2* result_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T5_;
		if (!((IL64(-9223372036854775807) - IL64(1)) < i_p0)) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD_ = rope__ropes_u15(i_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T5_[0] = colontmpD_;
		colontmpD__2 = percent___cgen_u20104(T5_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p1)), colontmpD__2.len + 0);
appendString((&(*result_p1)), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA1_;
LA3_: ;
	{
		prepareAdd((&(*result_p1)), 38);
appendString((&(*result_p1)), TM__MQdRN7fpbG7rPm4JpVVAhA_605);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, uint64Literal__cgen_u20109)(NU64 i_p0, NimStringV2* result_p1) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	colontmpD_ = dollar___systemZdollars_u54(i_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = rawNewString(colontmpD_.len + 3);
appendString((&T1_), colontmpD_);
appendString((&T1_), TM__MQdRN7fpbG7rPm4JpVVAhA_607);
	colontmpD__2 = T1_;
	prepareAdd((&(*result_p1)), colontmpD__2.len + 0);
appendString((&(*result_p1)), colontmpD__2);
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNilStringLiteral__cgen_u701)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2* result_p2) {
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_613);
	colontmpD_ = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_614);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 11);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_615);
	prepareAdd((&(*result_p2)), res_1.len + 0);
appendString((&(*result_p2)), res_1);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genLiteral__cgen_u20138)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_p2, NimStringV2* result_p3) {
NIM_BOOL oldNimErrFin25_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg k_1;
		k_1 = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			if (!!((ty_p2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA4_;
			colontmpD_ = NIM_NIL;
			colontmpD_ = skipTypes__ast_u5379(ty_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			k_1 = (*colontmpD_).kind;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA2_;
LA4_: ;
		{
			switch ((*n_p1).kind) {
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5):
			{
				k_1 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2);
			}
			break;
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
			{
				k_1 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44);
			}
			break;
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)10):
			{
				k_1 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35);
			}
			break;
			default:
			{
				k_1 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5);
			}
			break;
			}
		}
LA2_: ;
		switch (k_1) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
		{
			intLiteral__cgen_u14092((*n_p1)._kind_1.intVal, result_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
		{
			{
				if (!!(((*n_p1)._kind_1.intVal == IL64(0)))) goto LA15_;
				prepareAdd((&(*result_p3)), 8);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_602);
			}
			goto LA13_;
LA15_: ;
			{
				prepareAdd((&(*result_p3)), 9);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_604);
			}
LA13_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		{
			int64Literal__cgen_u20097((*n_p1)._kind_1.intVal, result_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			uint64Literal__cgen_u20109(((NU64) ((*n_p1)._kind_1.intVal)), result_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		default:
		{
			NimStringV2 colontmpD__2;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_608);
			colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, ty_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&(*result_p3)), colontmpD__2.len + 0);
appendString((&(*result_p3)), colontmpD__2);
			prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_609);
			intLiteral__cgen_u14092((*n_p1)._kind_1.intVal, result_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_610);
			{
				LA21_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg colontmpD__3;
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg colontmpD__4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg k_2;
		colontmpD__3 = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
		colontmpD__4 = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
		colontmpD__5 = NIM_NIL;
		{
			if (!(ty_p2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA28_;
			colontmpD__3 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26);
			k_2 = colontmpD__3;
		}
		goto LA26_;
LA28_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
			colontmpD__6 = NIM_NIL;
			colontmpD__6 = skipTypes__ast_u5379(ty_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			colontmpD__4 = (*colontmpD__6).kind;
			eqdestroy___ast_u3378(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			k_2 = colontmpD__4;
		}
LA26_: ;
		{
			NIM_BOOL T33_;
			NimStringV2 tmpName_1;
			NimStringV2 colontmpD__7;
			NI id_1;
			NimStringV2 T38_;
			T33_ = (NIM_BOOL)0;
			T33_ = (k_2 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
			if (!(T33_)) goto LA34_;
			colontmpD__5 = skipTypes__ast_u5379(ty_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			T33_ = ((*colontmpD__5).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA34_: ;
			if (!T33_) goto LA35_;
			tmpName_1.len = 0; tmpName_1.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			id_1 = nodeTableTestOrSet__treetab_u225((&(*(*p_p0).module).dataCache), n_p1, (*(*p_p0).module).labels);
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			T38_.len = 0; T38_.p = NIM_NIL;
			colontmpD__7 = rope__ropes_u15(((NI64) (id_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			T38_ = rawNewString((*(*p_p0).module).tmpBase.len + colontmpD__7.len + 0);
appendString((&T38_), (*(*p_p0).module).tmpBase);
appendString((&T38_), colontmpD__7);
			tmpName_1 = T38_;
			{
				NimStringV2 colontmpD__8;
				NimStringV2 colontmpD__9;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T44_;
				if (!(id_1 == (*(*p_p0).module).labels)) goto LA41_;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				(*(*p_p0).module).labels += ((NI)1);
				colontmpD__8 = getTypeDesc__cgen_u8738((*p_p0).module, ty_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
				T44_[0] = colontmpD__8;
				T44_[1] = tmpName_1;
				colontmpD__9 = percent___cgen_u20168(T44_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
				prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__9.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__9);
				{
					LA43_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			}
LA41_: ;
			prepareAdd((&(*result_p3)), tmpName_1.len + 0);
appendString((&(*result_p3)), tmpName_1);
			{
				LA37_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(tmpName_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		}
		goto LA31_;
LA35_: ;
		{
			if (!(k_2 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26) || k_2 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5) || k_2 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25))) goto LA50_;
			prepareAdd((&(*result_p3)), 7);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_611);
		}
		goto LA31_;
LA50_: ;
		{
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			tyArray__YgExxhfgKcesA5EOUj1MOA T54_;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__10 = getTypeDesc__cgen_u8738((*p_p0).module, ty_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			T54_[0] = colontmpD__10;
			colontmpD__11 = percent___cgen_u20177(T54_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			prepareAdd((&(*result_p3)), colontmpD__11.len + 0);
appendString((&(*result_p3)), colontmpD__11);
			{
				LA53_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		}
LA31_: ;
		{
			LA25_:;
		}
		{
			oldNimErrFin25_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin25_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg colontmpD__12;
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg colontmpD__13;
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg k_3;
		colontmpD__12 = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
		colontmpD__13 = (tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0;
		{
			if (!(ty_p2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA62_;
			colontmpD__12 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28);
			k_3 = colontmpD__12;
		}
		goto LA60_;
LA62_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__14;
			colontmpD__14 = NIM_NIL;
			colontmpD__14 = skipTypes__ast_u5379(ty_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_612);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__13 = (*colontmpD__14).kind;
			eqdestroy___ast_u3378(colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			k_3 = colontmpD__13;
		}
LA60_: ;
		switch (k_3) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
		{
			genNilStringLiteral__cgen_u701((*p_p0).module, (*n_p1).info, result_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
		{
			{
				NIM_BOOL T69_;
				T69_ = (NIM_BOOL)0;
				T69_ = ((*n_p1)._kind_3.strVal.len == ((NI)0));
				if (!(T69_)) goto LA70_;
				T69_ = !((((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0));
LA70_: ;
				if (!T69_) goto LA71_;
				genNilStringLiteral__cgen_u701((*p_p0).module, (*n_p1).info, result_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA67_;
LA71_: ;
			{
				genStringLiteral__cgen_u714((*p_p0).module, n_p1, result_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA67_: ;
		}
		break;
		default:
		{
			NimStringV2 colontmpD__15;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__15 = makeCString__msgs_u83((*n_p1)._kind_3.strVal);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*result_p3)), colontmpD__15.len + 0);
appendString((&(*result_p3)), colontmpD__15);
			eqdestroy___system_u2691(colontmpD__15);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)18):
	{
		{
			NimStringV2 colontmpD__16;
			if (!((*ty_p2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)37))) goto LA78_;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__16 = toStrMaxPrecision__cgen_u20199(((NF32) ((*n_p1)._kind_2.floatVal)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*result_p3)), colontmpD__16.len + 0);
appendString((&(*result_p3)), colontmpD__16);
			eqdestroy___system_u2691(colontmpD__16);
		}
		goto LA76_;
LA78_: ;
		{
			NimStringV2 colontmpD__17;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			colontmpD__17 = toStrMaxPrecision__astyaml_u674((*n_p1)._kind_2.floatVal);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*result_p3)), colontmpD__17.len + 0);
appendString((&(*result_p3)), colontmpD__17);
			eqdestroy___system_u2691(colontmpD__17);
		}
LA76_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)17):
	{
		NimStringV2 colontmpD__18;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__18 = toStrMaxPrecision__cgen_u20199(((NF32) ((*n_p1)._kind_2.floatVal)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p3)), colontmpD__18.len + 0);
appendString((&(*result_p3)), colontmpD__18);
		eqdestroy___system_u2691(colontmpD__18);
	}
	break;
	default:
	{
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		NimStringV2 T84_;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		T84_.len = 0; T84_.p = NIM_NIL;
		colontmpD__19 = dollar___nodekinds_u168((*n_p1).kind);
		T84_ = rawNewString(colontmpD__19.len + 12);
appendString((&T84_), TM__MQdRN7fpbG7rPm4JpVVAhA_617);
appendString((&T84_), colontmpD__19);
appendChar((&T84_), 41);
		colontmpD__20 = T84_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__20, TM__MQdRN7fpbG7rPm4JpVVAhA_618);
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		{
			LA83_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genLiteral__cgen_u14095)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	genLiteral__cgen_u20138(p_p0, n_p1, (*n_p1).typField, result_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCaseRange__cgen_u9543)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_p1) {
NIM_BOOL oldNimErrFin20_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI j_1;
		NI colontmp_;
		NI T2_;
		NI i_1;
		j_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__ast_u3190(branch_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmp_ = (NI)(T2_ - ((NI)1));
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 < colontmp_)) goto LA4;
				j_1 = i_1;
				{
					if (!((*(*branch_p1)._kind_6.sons.p->data[j_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA7_;
					{
						NimStringV2 litA_1;
						NimStringV2 litB_1;
						NimStringV2 colontmpD_;
						NimStringV2* T14_;
						NimStringV2* T15_;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T16_;
						if (!((CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)0)))&15U)))!=0)) goto LA11_;
						litA_1.len = 0; litA_1.p = NIM_NIL;
						litB_1.len = 0; litB_1.p = NIM_NIL;
						colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
						litA_1 = newRopeAppender__ropes_u7(((NI)80));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						litB_1 = newRopeAppender__ropes_u7(((NI)80));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						genLiteral__cgen_u14095(p_p0, (*(*branch_p1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)0)], (&litA_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						genLiteral__cgen_u14095(p_p0, (*(*branch_p1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)1)], (&litB_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T14_ = (NimStringV2*)0;
						T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						addIndent__cgen_u315(p_p0, T14_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T15_ = (NimStringV2*)0;
						T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T16_[0] = litA_1;
						T16_[1] = litB_1;
						colontmpD_ = percent___cgen_u18066(T16_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						prepareAdd((&(*T15_)), colontmpD_.len + 0);
appendString((&(*T15_)), colontmpD_);
						{
							LA13_:;
						}
						{
							eqdestroy___system_u2691(colontmpD_);
							eqdestroy___system_u2691(litB_1);
							eqdestroy___system_u2691(litA_1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
					goto LA9_;
LA11_: ;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* v_1;
						v_1 = NIM_NIL;
						v_1 = copyNode__ast_u6736((*(*branch_p1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)0)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
						{
							while (1) {
								NimStringV2 litA_2;
								NimStringV2 colontmpD__2;
								NimStringV2* T24_;
								NimStringV2* T25_;
								tyArray__YgExxhfgKcesA5EOUj1MOA T26_;
								if (!((*v_1)._kind_1.intVal <= (*(*(*branch_p1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)1)])._kind_1.intVal)) goto LA22;
								litA_2.len = 0; litA_2.p = NIM_NIL;
								colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
								litA_2 = newRopeAppender__ropes_u7(((NI)80));
								if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
								genLiteral__cgen_u14095(p_p0, v_1, (&litA_2));
								if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
								T24_ = (NimStringV2*)0;
								T24_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
								if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
								addIndent__cgen_u315(p_p0, T24_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
								T25_ = (NimStringV2*)0;
								T25_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
								if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
								T26_[0] = litA_2;
								colontmpD__2 = percent___cgen_u18073(T26_, 1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
								prepareAdd((&(*T25_)), colontmpD__2.len + 0);
appendString((&(*T25_)), colontmpD__2);
								(*v_1)._kind_1.intVal += ((NI)1);
								{
									LA23_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__2);
									eqdestroy___system_u2691(litA_2);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
							} LA22: ;
						}
						{
							LA20_:;
						}
						{
							oldNimErrFin20_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(v_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							*nimErr_ = oldNimErrFin20_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA9_: ;
				}
				goto LA5_;
LA7_: ;
				{
					NimStringV2 litA_3;
					NimStringV2 colontmpD__3;
					NimStringV2* T33_;
					NimStringV2* T34_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T35_;
					litA_3.len = 0; litA_3.p = NIM_NIL;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					litA_3 = newRopeAppender__ropes_u7(((NI)80));
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					genLiteral__cgen_u14095(p_p0, (*branch_p1)._kind_6.sons.p->data[j_1], (&litA_3));
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					T33_ = (NimStringV2*)0;
					T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					addIndent__cgen_u315(p_p0, T33_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					T34_ = (NimStringV2*)0;
					T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					T35_[0] = litA_3;
					colontmpD__3 = percent___cgen_u18073(T35_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					prepareAdd((&(*T34_)), colontmpD__3.len + 0);
appendString((&(*T34_)), colontmpD__3);
					{
						LA32_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(litA_3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA5_: ;
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__cgen_u9550)(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw c_p0, NimStringV2 accessor_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3) {
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin49_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(n_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	switch ((*n_p2).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i_1 = i_2;
					genTraverseProc__cgen_u9550(c_p0, accessor_p1, (*n_p2)._kind_6.sons.p->data[i_1], typ_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
	{
		tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* disc_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2* T23_;
		NimStringV2* T24_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T25_;
		NimStringV2* T43_;
		NimStringV2* T44_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T45_;
		p_1 = NIM_NIL;
		disc_1 = NIM_NIL;
		colontmpD_ = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		{
			if (!!(((*(*n_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA13_;
			internalErrorImpl__msgs_u1598((*(*(*c_p0.p).module).g).config, (*n_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_541, TM__MQdRN7fpbG7rPm4JpVVAhA_542);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA13_: ;
		eqcopy___cgendata_u2074(&p_1, c_p0.p, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		eqcopy___ast_u4577(&disc_1, (*(*n_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			if (!((*disc_1).loc.snippet.len == 0)) goto LA17_;
			fillObjectFields__cgen_u5401((*c_p0.p).module, typ_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA17_: ;
		{
			colontmpD_ = t__cgen_u97((*disc_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			if (!(colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA21_;
			internalErrorImpl__msgs_u1598((*(*(*c_p0.p).module).g).config, (*n_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_594, TM__MQdRN7fpbG7rPm4JpVVAhA_595);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA21_: ;
		T23_ = (NimStringV2*)0;
		T23_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		addIndent__cgen_u315(p_1, T23_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T24_ = (NimStringV2*)0;
		T24_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T25_[0] = accessor_p1;
		T25_[1] = (*disc_1).loc.snippet;
		colontmpD__2 = percent___cgen_u9574(T25_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&(*T24_)), colontmpD__2.len + 0);
appendString((&(*T24_)), colontmpD__2);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			i_4 = ((NI)1);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
					NimStringV2 colontmpD__5;
					NimStringV2* T38_;
					NimStringV2* T39_;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T40_;
					if (!(i_4 < colontmp__2)) goto LA28;
					branch_1 = NIM_NIL;
					colontmpD__4 = NIM_NIL;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					i_3 = i_4;
					eqcopy___ast_u3255(&branch_1, (*n_p2)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					{
						if (!((*branch_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA32_;
						genCaseRange__cgen_u9543(c_p0.p, branch_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					}
					goto LA30_;
LA32_: ;
					{
						NimStringV2 colontmpD__6;
						NimStringV2* T35_;
						NimStringV2* T36_;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T37_;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						T35_ = (NimStringV2*)0;
						T35_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						addIndent__cgen_u315(p_1, T35_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						T36_ = (NimStringV2*)0;
						T36_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						colontmpD__6 = percent___cgen_u9596(T37_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						prepareAdd((&(*T36_)), colontmpD__6.len + 0);
appendString((&(*T36_)), colontmpD__6);
						eqdestroy___system_u2691(colontmpD__6);
					}
LA30_: ;
					colontmpD__4 = lastSon__ast_u5208(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					genTraverseProc__cgen_u9550(c_p0, accessor_p1, colontmpD__4, typ_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					T38_ = (NimStringV2*)0;
					T38_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					addIndent__cgen_u315(p_1, T38_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					T39_ = (NimStringV2*)0;
					T39_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					colontmpD__5 = percent___cgen_u9601(T40_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					prepareAdd((&(*T39_)), colontmpD__5.len + 0);
appendString((&(*T39_)), colontmpD__5);
					i_4 += ((NI)1);
					{
						LA29_:;
					}
					{
						oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___ast_u3252(colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						eqdestroy___ast_u3252(branch_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						*nimErr_ = oldNimErrFin29_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				} LA28: ;
			}
		}
		T43_ = (NimStringV2*)0;
		T43_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		addIndent__cgen_u315(p_1, T43_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T44_ = (NimStringV2*)0;
		T44_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		colontmpD__3 = percent___cgen_u9606(T45_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&(*T44_)), colontmpD__3.len + 0);
appendString((&(*T44_)), colontmpD__3);
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(disc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___cgendata_u2071(p_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
		NimStringV2 colontmpD__8;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T62_;
		field_1 = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9 = NIM_NIL;
		eqcopy___ast_u4577(&field_1, (*n_p2)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		{
			if (!((*(*field_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63))) goto LA52_;
			eqdestroy___ast_u3378(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA52_: ;
		{
			if (!((*field_1).loc.snippet.len == 0)) goto LA56_;
			fillObjectFields__cgen_u5401((*c_p0.p).module, typ_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		}
LA56_: ;
		{
			colontmpD__7 = t__cgen_u97((*field_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			if (!(colontmpD__7 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA60_;
			internalErrorImpl__msgs_u1598((*(*(*c_p0.p).module).g).config, (*n_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_620, TM__MQdRN7fpbG7rPm4JpVVAhA_621);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		}
LA60_: ;
		T62_[0] = accessor_p1;
		T62_[1] = (*field_1).loc.snippet;
		colontmpD__8 = percent___cgen_u9620(T62_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		colontmpD__9 = t__cgen_u97((*field_1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		genTraverseProc__cgen_u9539(c_p0, colontmpD__8, colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		{
			LA49_:;
		}
		{
			oldNimErrFin49_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin49_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*(*c_p0.p).module).g).config, (*n_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_622, TM__MQdRN7fpbG7rPm4JpVVAhA_623);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProc__cgen_u9539)(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw c_p0, NimStringV2 accessor_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2) {
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_1;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin33_;
NIM_BOOL oldNimErrFin48_;
NIM_BOOL oldNimErrFin46_;
NIM_BOOL oldNimErrFin71_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	p_1 = NIM_NIL;
	{
		if (!(typ_p2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA4_;
		eqdestroy___cgendata_u2071(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	eqcopy___cgendata_u2074(&p_1, c_p0.p, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*typ_p2).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)55):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = skipModifier__ast_u5338(typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		genTraverseProc__cgen_u9539(c_p0, accessor_p1, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw i_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		NimStringV2 oldCode_1;
		NimStringV2 res_1;
		NimStringV2 res_2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arraySize_1;
		NimStringV2* T12_;
		NimStringV2* T13_;
		NimStringV2* T14_;
		NI oldLen_1;
		NimStringV2* T19_;
		colontmpD__2 = NIM_NIL;
		nimZeroMem((void*)(&i_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__3 = NIM_NIL;
		oldCode_1.len = 0; oldCode_1.p = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		colontmpD__2 = indexType__ast_u5345(typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		arraySize_1 = lengthOrd__types_u1491((*(*(*c_p0.p).module).g).config, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		colontmpD__3 = getSysType__magicsys_u55((*(*(*c_p0.p).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		getTemp__cgen_u9546(p_1, colontmpD__3, NIM_FALSE, (&i_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		T12_ = (NimStringV2*)0;
		T12_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		eqcopy___system_u2694((&oldCode_1), (*T12_));
		freeze__ropes_u10(oldCode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		T13_ = (NimStringV2*)0;
		T13_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		addIndent__cgen_u315(p_1, T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		T14_ = (NimStringV2*)0;
		T14_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_526);
		cgFormatValue__cgen_u163((&res_1), i_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_528);
		cgFormatValue__cgen_u163((&res_1), i_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_530);
		cgFormatValue__cgen_u169((&res_1), arraySize_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_532);
		cgFormatValue__cgen_u163((&res_1), i_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_534);
		{
			if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA17_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_535);
		}
LA17_: ;
		prepareAdd((&(*T14_)), res_1.len + 0);
appendString((&(*T14_)), res_1);
		T19_ = (NimStringV2*)0;
		T19_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		oldLen_1 = (*T19_).len;
		res_2 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_2), accessor_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_537);
		cgFormatValue__cgen_u163((&res_2), i_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_539);
		colontmpD__4 = elementType__ast_u5331(typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		genTraverseProc__cgen_u9539(c_p0, res_2, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		{
			NimStringV2* T22_;
			NimStringV2* T25_;
			T22_ = (NimStringV2*)0;
			T22_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			if (!((*T22_).len == oldLen_1)) goto LA23_;
			T25_ = (NimStringV2*)0;
			T25_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			eqsink___system_u2700((&(*T25_)), oldCode_1);
			eqwasMoved___system_u2688((&oldCode_1));
		}
		goto LA20_;
LA23_: ;
		{
			NimStringV2 colontmpD__5;
			NimStringV2* T27_;
			NimStringV2* T28_;
			tyArray__TonP9cxJgj8gXu71dWIyNlA T29_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T27_ = (NimStringV2*)0;
			T27_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			addIndent__cgen_u315(p_1, T27_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			T28_ = (NimStringV2*)0;
			T28_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			colontmpD__5 = percent___cgen_u9681(T29_, 0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			prepareAdd((&(*T28_)), colontmpD__5.len + 0);
appendString((&(*T28_)), colontmpD__5);
			eqdestroy___system_u2691(colontmpD__5);
		}
LA20_: ;
		{
			LA11_:;
		}
		{
			oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(res_2);
			eqdestroy___system_u2691(res_1);
			eqdestroy___system_u2691(oldCode_1);
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(i_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin11_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_1;
		NimStringV2 colontmpD__6;
		x_1 = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		x_1 = baseClass__ast_u5348(typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T38_;
			if (!!((x_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA36_;
			T38_ = NIM_NIL;
			T38_ = skipTypes__ast_u5379(x_1, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T38_); goto LA33_;}
			eqsink___ast_u3387(&x_1, T38_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
LA36_: ;
		colontmpD__6 = parentObj__cgen_u9625(accessor_p1, (*c_p0.p).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		genTraverseProc__cgen_u9539(c_p0, colontmpD__6, x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			if (!!(((*typ_p2).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA41_;
			genTraverseProc__cgen_u9550(c_p0, accessor_p1, (*typ_p2).n, typ_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
LA41_: ;
		{
			LA33_:;
		}
		{
			oldNimErrFin33_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___ast_u3378(x_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin33_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
		typ_2 = NIM_NIL;
		eqcopy___ast_u3381(&typ_2, typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_1;
			NI i_2;
			a_1 = NIM_NIL;
			i_2 = (NI)0;
			{
				NI i_3;
				NI colontmp_;
				NI T50_;
				NI i_4;
				i_3 = (NI)0;
				colontmp_ = (NI)0;
				T50_ = (*typ_2).sons.len;
				colontmp_ = T50_;
				i_4 = ((NI)0);
				{
					while (1) {
						NimStringV2 res_3;
						if (!(i_4 < colontmp_)) goto LA52;
						res_3.len = 0; res_3.p = NIM_NIL;
						i_3 = i_4;
						i_2 = i_3;
						eqcopy___ast_u3381(&a_1, (*typ_2).sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
						res_3 = rawNewString(((NI)80));
						cgFormatValue__cgen_u163((&res_3), accessor_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
						prepareAdd((&res_3), 6);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_625);
						cgFormatValue__cgen_u166((&res_3), ((NI64) (i_2)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
						genTraverseProc__cgen_u9539(c_p0, res_3, a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
						i_4 += ((NI)1);
						{
							LA53_:;
						}
						{
							eqdestroy___system_u2691(res_3);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
					} LA52: ;
				}
			}
			{
				LA48_:;
			}
			{
				oldNimErrFin48_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
				*nimErr_ = oldNimErrFin48_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		}
		{
			LA46_:;
		}
		{
			oldNimErrFin46_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin46_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	{
		NimStringV2 res_4;
		NimStringV2 colontmpD__7;
		NimStringV2* T62_;
		NimStringV2* T63_;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T62_ = (NimStringV2*)0;
		T62_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		addIndent__cgen_u315(p_1, T62_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		T63_ = (NimStringV2*)0;
		T63_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		res_4 = rawNewString(((NI)80));
		colontmpD__7 = cgsymValue__cgen_u141((*p_1).module, TM__MQdRN7fpbG7rPm4JpVVAhA_627);
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		prepareAdd((&res_4), 8);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_628);
		cgFormatValue__cgen_u163((&res_4), accessor_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_629);
		cgFormatValue__cgen_u163((&res_4), c_p0.visitorFrmt);
		if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_630);
		{
			if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA66_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_631);
		}
LA66_: ;
		prepareAdd((&(*T63_)), res_4.len + 0);
appendString((&(*T63_)), res_4);
		{
			LA61_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(res_4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
		colontmpD__8 = NIM_NIL;
		{
			NimStringV2 res_5;
			NimStringV2 colontmpD__9;
			NimStringV2* T77_;
			NimStringV2* T78_;
			if (!!((((*(*(*(*c_p0.p).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0))) goto LA74_;
			res_5.len = 0; res_5.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			T77_ = (NimStringV2*)0;
			T77_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			addIndent__cgen_u315(p_1, T77_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			T78_ = (NimStringV2*)0;
			T78_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			res_5 = rawNewString(((NI)80));
			colontmpD__9 = cgsymValue__cgen_u141((*p_1).module, TM__MQdRN7fpbG7rPm4JpVVAhA_632);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			prepareAdd((&res_5), 8);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_633);
			cgFormatValue__cgen_u163((&res_5), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_634);
			cgFormatValue__cgen_u163((&res_5), c_p0.visitorFrmt);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_635);
			{
				if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA81_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_636);
			}
LA81_: ;
			prepareAdd((&(*T78_)), res_5.len + 0);
appendString((&(*T78_)), res_5);
			{
				LA76_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(res_5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
		}
		goto LA72_;
LA74_: ;
		{
			NIM_BOOL T86_;
			NimStringV2 res_6;
			NimStringV2 colontmpD__10;
			NimStringV2* T90_;
			NimStringV2* T91_;
			colontmpD__8 = elementType__ast_u5331(typ_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			T86_ = (NIM_BOOL)0;
			T86_ = containsGarbageCollectedRef__types_u555(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			if (!T86_) goto LA87_;
			res_6.len = 0; res_6.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T90_ = (NimStringV2*)0;
			T90_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			addIndent__cgen_u315(p_1, T90_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			T91_ = (NimStringV2*)0;
			T91_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			res_6 = rawNewString(((NI)80));
			colontmpD__10 = cgsymValue__cgen_u141((*p_1).module, TM__MQdRN7fpbG7rPm4JpVVAhA_638);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			prepareAdd((&res_6), 8);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_639);
			cgFormatValue__cgen_u163((&res_6), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_640);
			cgFormatValue__cgen_u163((&res_6), c_p0.visitorFrmt);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_641);
			{
				if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA94_;
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_642);
			}
LA94_: ;
			prepareAdd((&(*T91_)), res_6.len + 0);
appendString((&(*T91_)), res_6);
			{
				LA89_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(res_6);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
		}
		goto LA72_;
LA87_: ;
LA72_: ;
		{
			LA71_:;
		}
		{
			oldNimErrFin71_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin71_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		{
			NimStringV2 res_7;
			NimStringV2 colontmpD__11;
			NimStringV2* T106_;
			NimStringV2* T107_;
			if (!!((((*typ_p2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)31)))&63U)))!=0))) goto LA103_;
			res_7.len = 0; res_7.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			T106_ = (NimStringV2*)0;
			T106_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			addIndent__cgen_u315(p_1, T106_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			T107_ = (NimStringV2*)0;
			T107_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			res_7 = rawNewString(((NI)80));
			colontmpD__11 = cgsymValue__cgen_u141((*p_1).module, TM__MQdRN7fpbG7rPm4JpVVAhA_643);
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			prepareAdd((&res_7), 8);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_644);
			cgFormatValue__cgen_u163((&res_7), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_645);
			cgFormatValue__cgen_u163((&res_7), c_p0.visitorFrmt);
			if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
			prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_646);
			{
				if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA110_;
				prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_647);
			}
LA110_: ;
			prepareAdd((&(*T107_)), res_7.len + 0);
appendString((&(*T107_)), res_7);
			{
				LA105_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(res_7);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA103_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		{
			NimStringV2 res_8;
			NimStringV2 colontmpD__12;
			NimStringV2 res_9;
			NimStringV2* T120_;
			NimStringV2* T121_;
			if (!((*typ_p2).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9))) goto LA117_;
			res_8.len = 0; res_8.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			res_9.len = 0; res_9.p = NIM_NIL;
			T120_ = (NimStringV2*)0;
			T120_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			addIndent__cgen_u315(p_1, T120_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			T121_ = (NimStringV2*)0;
			T121_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			res_8 = rawNewString(((NI)80));
			colontmpD__12 = cgsymValue__cgen_u141((*p_1).module, TM__MQdRN7fpbG7rPm4JpVVAhA_648);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			cgFormatValue__cgen_u163((&res_8), colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			prepareAdd((&res_8), 8);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_649);
			res_9 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_9), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			prepareAdd((&res_9), 6);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_651);
			cgFormatValue__cgen_u163((&res_8), res_9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			prepareAdd((&res_8), 2);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_652);
			cgFormatValue__cgen_u163((&res_8), c_p0.visitorFrmt);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			prepareAdd((&res_8), 2);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_653);
			{
				if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA124_;
				prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_654);
			}
LA124_: ;
			prepareAdd((&(*T121_)), res_8.len + 0);
appendString((&(*T121_)), res_8);
			{
				LA119_:;
			}
			{
				eqdestroy___system_u2691(res_9);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(res_8);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA117_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u2071(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dataField__cgen_u516)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
	NimStringV2 result;
	{
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA3_;
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_656;
	}
	goto LA1_;
LA3_: ;
	{
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_658;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTraverseProcSeq__cgen_u9642)(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw c_p0, NimStringV2 accessor_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2) {
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw i_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 oldCode_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
	NimStringV2* T2_;
	NimStringV2* T3_;
	NimStringV2* T4_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T5_;
	NI oldLen_1;
	NimStringV2* T6_;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	p_1 = NIM_NIL;
	nimZeroMem((void*)(&i_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = NIM_NIL;
	oldCode_1.len = 0; oldCode_1.p = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7 = NIM_NIL;
	eqcopy___cgendata_u2074(&p_1, c_p0.p, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getSysType__magicsys_u55((*(*(*c_p0.p).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	getTemp__cgen_u9546(p_1, colontmpD_, NIM_FALSE, (&i_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NimStringV2*)0;
	T2_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&oldCode_1), (*T2_));
	freeze__ropes_u10(oldCode_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD__2 = eqdup___system_u2697(accessor_p1);
	a_1.snippet = colontmpD__2;
	T3_ = (NimStringV2*)0;
	T3_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_1, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = (NimStringV2*)0;
	T4_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_[0] = i_1.snippet;
	colontmpD__3 = lenExpr__cgen_u495(c_p0.p, a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_[1] = colontmpD__3;
	colontmpD__4 = percent___cgen_u9808(T5_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T4_)), colontmpD__4.len + 0);
appendString((&(*T4_)), colontmpD__4);
	T6_ = (NimStringV2*)0;
	T6_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	oldLen_1 = (*T6_).len;
	T7_[0] = accessor_p1;
	T7_[1] = i_1.snippet;
	colontmpD__5 = dataField__cgen_u516(c_p0.p);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T7_[2] = colontmpD__5;
	colontmpD__6 = percent___cgen_u9814(T7_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__7 = elementType__ast_u5331(typ_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genTraverseProc__cgen_u9539(c_p0, colontmpD__6, colontmpD__7);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2* T10_;
		NimStringV2* T13_;
		T10_ = (NimStringV2*)0;
		T10_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*T10_).len == oldLen_1)) goto LA11_;
		T13_ = (NimStringV2*)0;
		T13_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___system_u2700((&(*T13_)), oldCode_1);
		eqwasMoved___system_u2688((&oldCode_1));
	}
	goto LA8_;
LA11_: ;
	{
		NimStringV2 colontmpD__8;
		NimStringV2* T15_;
		NimStringV2* T16_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T17_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		T15_ = (NimStringV2*)0;
		T15_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_1, T15_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T16_ = (NimStringV2*)0;
		T16_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__8 = percent___cgen_u9681(T17_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*T16_)), colontmpD__8.len + 0);
appendString((&(*T16_)), colontmpD__8);
		eqdestroy___system_u2691(colontmpD__8);
	}
LA8_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(oldCode_1);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(i_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___cgendata_u2071(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) - (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u9893)(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw dest_p0) {
	eqdestroy___system_u2691(dest_p0.visitorFrmt);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0.p, ((TNimTypeV2*) ((&NTIv2__qtjLoeN4t2OOlLAbQg1W1A_))));
		if (!T3_) goto LA4_;
		eqdestroy___cgendata_u1051((&(*dest_p0.p)));
		nimRawDispose(dest_p0.p, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTraverseProc__cgen_u9823)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origTyp_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p2) {
	NimStringV2 result;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_1;
	NimStringV2 colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NimStringV2 markerName_1;
	NimStringV2 header_1;
	NimStringV2 t_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw c_1;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* colontmpD__4;
	NimStringV2 generatedProc_1;
	NimStringV2 colontmpD__5;
	NimStringV2 T2_;
	NIM_BOOL hcrOn_1;
	NimStringV2 T3_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T10_;
	NimStringV2* T11_;
	NimStringV2* T12_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T13_;
	NimStringV2* T14_;
	NimStringV2* T15_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T16_;
NIM_BOOL oldNimErrFin27_;
NIM_BOOL oldNimErrFin31_;
NIM_BOOL oldNimErrFin22_;
	tyArray__Seu7uK9aaOSN0BK3EAjjSHw T36_;
	NimStringV2* T37_;
	NimStringV2* T38_;
	NimStringV2* T39_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T40_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	p_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	typ_1 = NIM_NIL;
	markerName_1.len = 0; markerName_1.p = NIM_NIL;
	header_1.len = 0; header_1.p = NIM_NIL;
	t_1.len = 0; t_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	nimZeroMem((void*)(&c_1), sizeof(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw));
	generatedProc_1.len = 0; generatedProc_1.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	p_1 = newProc__cgendata_u509(((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = getTypeName__cgen_u1281(m_p0, origTyp_p1, sig_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + 7);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_514);
appendString((&T2_), colontmpD_);
	result = T2_;
	hcrOn_1 = hcrOn__cgen_u49(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	typ_1 = skipTypes__ast_u5379(origTyp_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_.len = 0; T3_.p = NIM_NIL;
	{
		NimStringV2 T8_;
		if (!hcrOn_1) goto LA6_;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rawNewString(result.len + 7);
appendString((&T8_), result);
appendString((&T8_), TM__MQdRN7fpbG7rPm4JpVVAhA_516);
		markerName_1 = T8_;
	}
	goto LA4_;
LA6_: ;
	{
		eqcopy___system_u2694((&markerName_1), result);
	}
LA4_: ;
	T10_[0] = markerName_1;
	header_1 = percent___cgen_u9832(T10_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = getTypeDesc__cgen_u8738(m_p0, typ_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_ = (NimStringV2*)0;
	T11_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_1, T11_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_ = (NimStringV2*)0;
	T12_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_[0] = t_1;
	colontmpD__2 = percent___cgen_u9839(T13_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T12_)), colontmpD__2.len + 0);
appendString((&(*T12_)), colontmpD__2);
	T14_ = (NimStringV2*)0;
	T14_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_1, T14_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T15_ = (NimStringV2*)0;
	T15_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T16_[0] = t_1;
	colontmpD__3 = percent___cgen_u9844(T16_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T15_)), colontmpD__3.len + 0);
appendString((&(*T15_)), colontmpD__3);
	colontmpD__4 = eqdup___cgendata_u2078(p_1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	c_1.p = colontmpD__4;
	c_1.visitorFrmt = TM__MQdRN7fpbG7rPm4JpVVAhA_518;
	{
		if (!((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24))) goto LA19_;
		genTraverseProcSeq__cgen_u9642(c_1, TM__MQdRN7fpbG7rPm4JpVVAhA_660, typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA17_;
LA19_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
		colontmpD__6 = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
			colontmpD__6 = elementType__ast_u5331(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			colontmpD__7 = skipTypes__ast_u5379(colontmpD__6, TM__MQdRN7fpbG7rPm4JpVVAhA_170);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			if (!((*colontmpD__7).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16))) goto LA25_;
			colontmpD__8 = NIM_NIL;
			colontmpD__8 = elementType__ast_u5331(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			genTraverseProc__cgen_u9539(c_1, TM__MQdRN7fpbG7rPm4JpVVAhA_661, colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			{
				LA27_:;
			}
			{
				oldNimErrFin27_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				*nimErr_ = oldNimErrFin27_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		}
		goto LA23_;
LA25_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
			colontmpD__9 = NIM_NIL;
			colontmpD__9 = elementType__ast_u5331(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			genTraverseProc__cgen_u9539(c_1, TM__MQdRN7fpbG7rPm4JpVVAhA_663, colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			{
				LA31_:;
			}
			{
				oldNimErrFin31_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				*nimErr_ = oldNimErrFin31_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		}
LA23_: ;
		{
			LA22_:;
		}
		{
			oldNimErrFin22_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin22_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA17_: ;
	T36_[0] = header_1;
	T37_ = (NimStringV2*)0;
	T37_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T36_[1] = (*T37_);
	T38_ = (NimStringV2*)0;
	T38_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T36_[2] = (*T38_);
	T39_ = (NimStringV2*)0;
	T39_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T36_[3] = (*T39_);
	generatedProc_1 = percent___cgen_u9869(T36_, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T40_[0] = header_1;
	colontmpD__5 = percent___cgen_u9875(T40_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD__5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD__5);
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), generatedProc_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), generatedProc_1);
	{
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		tyArray__YgExxhfgKcesA5EOUj1MOA T46_;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T47_;
		if (!hcrOn_1) goto LA43_;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		T46_[0] = result;
		colontmpD__10 = percent___cgen_u9880(T46_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD__10.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD__10);
		T47_[0] = result;
		T47_[1] = markerName_1;
		colontmpD__11 = getModuleDllPath__cgen_u146(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T47_[2] = colontmpD__11;
		colontmpD__12 = percent___cgen_u9885(T47_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__12.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__12);
		{
			LA45_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA43_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(generatedProc_1);
		eqdestroy___cgen_u9893(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(t_1);
		eqdestroy___system_u2691(header_1);
		eqdestroy___system_u2691(markerName_1);
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgendata_u2071(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayInfo__cgen_u9524)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = elementType__ast_u5331(typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = genTypeInfoV1__cgen_u9076(m_p0, colontmpD_, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genTypeInfoAuxBase__cgen_u9097(m_p0, typ_p1, typ_p1, name_p2, colontmpD__2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rope__cgen_u9217)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = dollar___int128_u36(arg_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetInfo__cgen_u9506)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	NimStringV2 tmp_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T2_;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	genTypeInfoAux__cgen_u9162(m_p0, typ_p1, typ_p1, name_p2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tmp_1 = getNimNode__cgen_u9080(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = tmp_1;
	T3_ = firstOrd__types_u1182((*(*m_p0).g).config, typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = rope__cgen_u9217(T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[1] = colontmpD_;
	colontmpD__2 = tiNameForHcr__cgen_u9093(m_p0, name_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[2] = colontmpD__2;
	colontmpD__3 = percent___cgen_u9519(T2_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__3.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__3);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tmp_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEnumInfo__cgen_u9442)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	NimStringV2 nodePtrs_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 enumNames_1;
	NimStringV2 specialCases_1;
	NimStringV2 enumArray_1;
	NimStringV2 counter_1;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	NimStringV2 colontmpD__9;
	NimStringV2 colontmpD__10;
	NimStringV2 colontmpD__11;
	NimStringV2 colontmpD__12;
	NimStringV2 colontmpD__13;
	NimStringV2 T2_;
	NI T3_;
	NI T4_;
	NI firstNimNode_1;
	NIM_BOOL hasHoles_1;
	tyArray__YgExxhfgKcesA5EOUj1MOA T25_;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T26_;
	NI T27_;
	tyArray__A2YC0h9cZydgH7zGAndH9bLg T28_;
	NI T29_;
	tyArray__Seu7uK9aaOSN0BK3EAjjSHw T30_;
	NI T31_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nodePtrs_1.len = 0; nodePtrs_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	enumNames_1.len = 0; enumNames_1.p = NIM_NIL;
	specialCases_1.len = 0; specialCases_1.p = NIM_NIL;
	enumArray_1.len = 0; enumArray_1.p = NIM_NIL;
	counter_1.len = 0; counter_1.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
	colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
	colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
	colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
	colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
	colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
	genTypeInfoAux__cgen_u9162(m_p0, typ_p1, typ_p1, name_p2, info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = getTempName__cgen_u462(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = (NI)0;
	T3_ = len__ast_u3190((*typ_p1).n);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = dollar___systemZdollars_u9(T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + colontmpD__2.len + 1);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_664);
appendString((&T2_), colontmpD__2);
	nodePtrs_1 = T2_;
	T4_ = (NI)0;
	T4_ = len__ast_u3190((*typ_p1).n);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = rope__ropes_u15(((NI64) (T4_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genTNimNodeArray__cgen_u9231(m_p0, nodePtrs_1, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	enumNames_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_665;
	specialCases_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_666;
	firstNimNode_1 = (*m_p0).typeNodes;
	hasHoles_1 = NIM_FALSE;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190((*typ_p1).n);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
				NimStringV2 elemNode_1;
				if (!(i_2 < colontmp_)) goto LA7;
				field_1 = NIM_NIL;
				elemNode_1.len = 0; elemNode_1.p = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u4577(&field_1, (*(*(*typ_p1).n)._kind_6.sons.p->data[i_1])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				elemNode_1 = getNimNode__cgen_u9080(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				{
					NimStringV2 colontmpD__14;
					if (!((*field_1).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA10_;
					colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
					colontmpD__14 = makeCString__msgs_u83((*(*field_1).name).s);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&enumNames_1), colontmpD__14.len + 0);
appendString((&enumNames_1), colontmpD__14);
					eqdestroy___system_u2691(colontmpD__14);
				}
				goto LA8_;
LA10_: ;
				{
					NimStringV2 colontmpD__15;
					colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
					colontmpD__15 = makeCString__msgs_u83((*(*field_1).ast)._kind_3.strVal);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&enumNames_1), colontmpD__15.len + 0);
appendString((&enumNames_1), colontmpD__15);
					eqdestroy___system_u2691(colontmpD__15);
				}
LA8_: ;
				{
					NI T15_;
					T15_ = (NI)0;
					T15_ = len__ast_u3190((*typ_p1).n);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!(i_1 < (NI)(T15_ - ((NI)1)))) goto LA16_;
					prepareAdd((&enumNames_1), 3);
appendString((&enumNames_1), TM__MQdRN7fpbG7rPm4JpVVAhA_668);
				}
LA16_: ;
				{
					NIM_BOOL T20_;
					NimStringV2 colontmpD__16;
					NimStringV2 colontmpD__17;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T24_;
					T20_ = (NIM_BOOL)0;
					T20_ = !(((*field_1).position == i_1));
					if (T20_) goto LA21_;
					T20_ = (((*typ_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)5)))&63U)))!=0);
LA21_: ;
					if (!T20_) goto LA22_;
					colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
					colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
					T24_[0] = elemNode_1;
					colontmpD__16 = rope__ropes_u15(((NI64) ((*field_1).position)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					T24_[1] = colontmpD__16;
					colontmpD__17 = percent___cgen_u9474(T24_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					prepareAdd((&specialCases_1), colontmpD__17.len + 0);
appendString((&specialCases_1), colontmpD__17);
					hasHoles_1 = NIM_TRUE;
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___system_u2691(colontmpD__16);
				}
LA22_: ;
				i_2 += ((NI)1);
				eqdestroy___system_u2691(elemNode_1);
				eqdestroy___ast_u4574(field_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA7: ;
		}
	}
	enumArray_1 = getTempName__cgen_u462(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	counter_1 = getTempName__cgen_u462(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T25_[0] = counter_1;
	colontmpD__4 = percent___cgen_u9481(T25_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), colontmpD__4.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), colontmpD__4);
	T26_[0] = enumArray_1;
	T27_ = (NI)0;
	T27_ = len__ast_u3190((*typ_p1).n);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = rope__ropes_u15(((NI64) (T27_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T26_[1] = colontmpD__5;
	T26_[2] = enumNames_1;
	colontmpD__6 = percent___cgen_u9486(T26_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), colontmpD__6.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), colontmpD__6);
	T28_[0] = counter_1;
	T29_ = (NI)0;
	T29_ = len__ast_u3190((*typ_p1).n);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__7 = rope__ropes_u15(((NI64) (T29_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T28_[1] = colontmpD__7;
	T28_[2] = (*m_p0).typeNodesName;
	colontmpD__8 = rope__ropes_u15(((NI64) (firstNimNode_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T28_[3] = colontmpD__8;
	T28_[4] = enumArray_1;
	T28_[5] = nodePtrs_1;
	colontmpD__9 = percent___cgen_u9491(T28_, 6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__9.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__9);
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), specialCases_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), specialCases_1);
	colontmpD__10 = getNimNode__cgen_u9080(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T30_[0] = colontmpD__10;
	T31_ = (NI)0;
	T31_ = len__ast_u3190((*typ_p1).n);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__11 = rope__ropes_u15(((NI64) (T31_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T30_[1] = colontmpD__11;
	T30_[2] = nodePtrs_1;
	colontmpD__12 = tiNameForHcr__cgen_u9093(m_p0, name_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T30_[3] = colontmpD__12;
	colontmpD__13 = percent___cgen_u9496(T30_, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__13.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__13);
	{
		NimStringV2 colontmpD__18;
		NimStringV2 colontmpD__19;
		tyArray__YgExxhfgKcesA5EOUj1MOA T36_;
		if (!hasHoles_1) goto LA34_;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__18 = tiNameForHcr__cgen_u9093(m_p0, name_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T36_[0] = colontmpD__18;
		colontmpD__19 = percent___cgen_u9501(T36_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__19.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__19);
		eqdestroy___system_u2691(colontmpD__19);
		eqdestroy___system_u2691(colontmpD__18);
	}
LA34_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__13);
		eqdestroy___system_u2691(colontmpD__12);
		eqdestroy___system_u2691(colontmpD__11);
		eqdestroy___system_u2691(colontmpD__10);
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(counter_1);
		eqdestroy___system_u2691(enumArray_1);
		eqdestroy___system_u2691(specialCases_1);
		eqdestroy___system_u2691(enumNames_1);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(nodePtrs_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, discriminatorTableName__cgen_u9198)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* objtype_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* d_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* objtype_2;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T10_;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T11_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	objtype_2 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	objtype_2 = skipTypes__ast_u5379(objtype_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
		colontmpD__3 = NIM_NIL;
		while (1) {
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T4_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T5_;
			T4_ = NIM_NIL;
			T4_ = lookupInRecord__astalgo_u30((*objtype_2).n, (*d_p2).name);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T4_); goto LA1_;}
			eqsink___ast_u4583(&colontmpD__3, T4_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(colontmpD__3 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA3;
			T5_ = NIM_NIL;
			T5_ = skipTypes__ast_u5379((*objtype_2).sons.p->data[((NI)0)], TM__MQdRN7fpbG7rPm4JpVVAhA_672);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T5_); goto LA1_;}
			eqsink___ast_u3387(&objtype_2, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA3: ;
		eqdestroy___ast_u4574(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		if (!((*objtype_2).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA8_;
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*d_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_674, TM__MQdRN7fpbG7rPm4JpVVAhA_675);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	nimZeroMem((void*)T11_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	hashType__sighashes_u411(objtype_2, (*(*m_p0).g).config, 2, T11_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = dollar___modulegraphs_u10732(T11_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[0] = colontmpD_;
	colontmpD__2 = mangle__mangleutils_u4((*(*d_p2).name).s);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[1] = colontmpD__2;
	result = percent___cgen_u9212(T10_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(objtype_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectFields__cgen_u9250)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p3, NimStringV2 expr_p4, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p5) {
NIM_BOOL oldNimErrFin45_;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin86_;
NIM_BOOL oldNimErrFin76_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p3).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		{
			NI T4_;
			T4_ = (NI)0;
			T4_ = len__ast_u3190(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T4_ == ((NI)1))) goto LA5_;
			genObjectFields__cgen_u9250(m_p0, typ_p1, origType_p2, (*n_p3)._kind_6.sons.p->data[((NI)0)], expr_p4, info_p5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA2_;
LA5_: ;
		{
			NI T8_;
			NimStringV2 tmp_1;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 T12_;
			NI T13_;
			NI T14_;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T22_;
			NI T23_;
			T8_ = (NI)0;
			T8_ = len__ast_u3190(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(((NI)0) < T8_)) goto LA9_;
			tmp_1.len = 0; tmp_1.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T12_.len = 0; T12_.p = NIM_NIL;
			colontmpD_ = getTempName__cgen_u462(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			T13_ = (NI)0;
			T13_ = len__ast_u3190(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			colontmpD__2 = dollar___systemZdollars_u9(T13_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			T12_ = rawNewString(colontmpD_.len + colontmpD__2.len + 1);
appendString((&T12_), colontmpD_);
appendString((&T12_), TM__MQdRN7fpbG7rPm4JpVVAhA_671);
appendString((&T12_), colontmpD__2);
			tmp_1 = T12_;
			T14_ = (NI)0;
			T14_ = len__ast_u3190(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			colontmpD__3 = rope__ropes_u15(((NI64) (T14_)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			genTNimNodeArray__cgen_u9231(m_p0, tmp_1, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190(n_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				i_2 = ((NI)0);
				{
					while (1) {
						NimStringV2 tmp2_1;
						NimStringV2 colontmpD__6;
						NimStringV2 colontmpD__7;
						tyArray__dyW7vpmfeTYw8kX3EXuaJA T19_;
						if (!(i_2 < colontmp_)) goto LA17;
						tmp2_1.len = 0; tmp2_1.p = NIM_NIL;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
						i_1 = i_2;
						tmp2_1 = getNimNode__cgen_u9080(m_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						T19_[0] = tmp_1;
						colontmpD__6 = rope__ropes_u15(((NI64) (i_1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						T19_[1] = colontmpD__6;
						T19_[2] = tmp2_1;
						colontmpD__7 = percent___cgen_u9264(T19_, 3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__7.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__7);
						genObjectFields__cgen_u9250(m_p0, typ_p1, origType_p2, (*n_p3)._kind_6.sons.p->data[i_1], tmp2_1, info_p5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						i_2 += ((NI)1);
						{
							LA18_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__7);
							eqdestroy___system_u2691(colontmpD__6);
							eqdestroy___system_u2691(tmp2_1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					} LA17: ;
				}
			}
			T22_[0] = expr_p4;
			T23_ = (NI)0;
			T23_ = len__ast_u3190(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			colontmpD__4 = rope__ropes_u15(((NI64) (T23_)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			T22_[1] = colontmpD__4;
			T22_[2] = tmp_1;
			colontmpD__5 = percent___cgen_u9269(T22_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__5);
			{
				LA11_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u2691(tmp_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA2_;
LA9_: ;
		{
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T27_;
			NI T28_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			T27_[0] = expr_p4;
			T28_ = (NI)0;
			T28_ = len__ast_u3190(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__8 = rope__ropes_u15(((NI64) (T28_)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T27_[1] = colontmpD__8;
			colontmpD__9 = percent___cgen_u9274(T27_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__9.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__9);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
		}
LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		NimStringV2 tmp_2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		NimStringV2 colontmpD__17;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg L_1;
		tyArray__hFPV9bffMpPjoz9bsO9crekNg T39_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T40_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T41_;
		field_1 = NIM_NIL;
		tmp_2.len = 0; tmp_2.p = NIM_NIL;
		colontmpD__10 = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		eqcopy___ast_u4577(&field_1, (*(*n_p3)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		tmp_2 = discriminatorTableName__cgen_u9198(m_p0, typ_p1, field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		L_1 = lengthOrd__types_u1491((*(*m_p0).g).config, (*field_1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		{
			if (!((*field_1).loc.snippet.len == 0)) goto LA33_;
			fillObjectFields__cgen_u5401(m_p0, typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
LA33_: ;
		{
			colontmpD__10 = t__cgen_u97((*field_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			if (!(colontmpD__10 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA37_;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*n_p3).info, TM__MQdRN7fpbG7rPm4JpVVAhA_677, TM__MQdRN7fpbG7rPm4JpVVAhA_678);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
LA37_: ;
		T39_[0] = expr_p4;
		colontmpD__11 = getTypeDesc__cgen_u8738(m_p0, origType_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T39_[1] = colontmpD__11;
		T39_[2] = (*field_1).loc.snippet;
		colontmpD__12 = genTypeInfoV1__cgen_u9076(m_p0, (*field_1).typ, info_p5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T39_[3] = colontmpD__12;
		colontmpD__13 = makeCString__msgs_u83((*(*field_1).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T39_[4] = colontmpD__13;
		T39_[5] = tmp_2;
		colontmpD__14 = rope__cgen_u9217(L_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T39_[6] = colontmpD__14;
		colontmpD__15 = percent___cgen_u9296(T39_, 7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__15.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__15);
		T40_[0] = tmp_2;
		T41_ = plus___int128_u1015(L_1, IL64(1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		colontmpD__16 = rope__cgen_u9217(T41_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T40_[1] = colontmpD__16;
		colontmpD__17 = percent___cgen_u9226(T40_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), colontmpD__17.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), colontmpD__17);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			i_4 = ((NI)1);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
					NimStringV2 tmp2_2;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__18;
					if (!(i_4 < colontmp__2)) goto LA44;
					b_1 = NIM_NIL;
					tmp2_2.len = 0; tmp2_2.p = NIM_NIL;
					colontmpD__18 = NIM_NIL;
					i_3 = i_4;
					eqcopy___ast_u3255(&b_1, (*n_p3)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
					tmp2_2 = getNimNode__cgen_u9080(m_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
					colontmpD__18 = lastSon__ast_u5208(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
					genObjectFields__cgen_u9250(m_p0, typ_p1, origType_p2, colontmpD__18, tmp2_2, info_p5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
					switch ((*b_1).kind) {
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85):
					{
						{
							NI T49_;
							T49_ = (NI)0;
							T49_ = len__ast_u3190(b_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
							if (!(T49_ < ((NI)2))) goto LA50_;
							internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*b_1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_680, TM__MQdRN7fpbG7rPm4JpVVAhA_681);
							if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
						}
LA50_: ;
						{
							NI j_1;
							NI colontmp__3;
							NI T53_;
							NI i_5;
							j_1 = (NI)0;
							colontmp__3 = (NI)0;
							T53_ = (NI)0;
							T53_ = len__ast_u3190(b_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
							colontmp__3 = (NI)(T53_ - ((NI)1));
							i_5 = ((NI)0);
							{
								while (1) {
									if (!(i_5 < colontmp__3)) goto LA55;
									j_1 = i_5;
									{
										NI x_1;
										tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T60_;
										NI y_1;
										tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T61_;
										if (!((*(*b_1)._kind_6.sons.p->data[j_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA58_;
										T60_ = getOrdValue__types_u167((*(*b_1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)0)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
										x_1 = toInt__int128_u257(T60_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
										T61_ = getOrdValue__types_u167((*(*b_1)._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)1)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
										y_1 = toInt__int128_u257(T61_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
										{
											while (1) {
												NimStringV2 colontmpD__19;
												NimStringV2 colontmpD__20;
												tyArray__dyW7vpmfeTYw8kX3EXuaJA T64_;
												if (!(x_1 <= y_1)) goto LA63;
												colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
												colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
												T64_[0] = tmp_2;
												colontmpD__19 = rope__ropes_u15(((NI64) (x_1)));
												if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
												T64_[1] = colontmpD__19;
												T64_[2] = tmp2_2;
												colontmpD__20 = percent___cgen_u9264(T64_, 3);
												if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
												prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__20.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__20);
												x_1 += ((NI)1);
												eqdestroy___system_u2691(colontmpD__20);
												eqdestroy___system_u2691(colontmpD__19);
											} LA63: ;
										}
									}
									goto LA56_;
LA58_: ;
									{
										NimStringV2 colontmpD__21;
										NimStringV2 colontmpD__22;
										tyArray__dyW7vpmfeTYw8kX3EXuaJA T66_;
										tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T67_;
										colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
										colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
										T66_[0] = tmp_2;
										T67_ = getOrdValue__types_u167((*b_1)._kind_6.sons.p->data[j_1]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
										colontmpD__21 = rope__cgen_u9217(T67_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
										T66_[1] = colontmpD__21;
										T66_[2] = tmp2_2;
										colontmpD__22 = percent___cgen_u9264(T66_, 3);
										if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
										prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__22.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__22);
										eqdestroy___system_u2691(colontmpD__22);
										eqdestroy___system_u2691(colontmpD__21);
									}
LA56_: ;
									i_5 += ((NI)1);
								} LA55: ;
							}
						}
					}
					break;
					case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)88):
					{
						NimStringV2 colontmpD__23;
						NimStringV2 colontmpD__24;
						tyArray__dyW7vpmfeTYw8kX3EXuaJA T69_;
						colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
						colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
						T69_[0] = tmp_2;
						colontmpD__23 = rope__cgen_u9217(L_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
						T69_[1] = colontmpD__23;
						T69_[2] = tmp2_2;
						colontmpD__24 = percent___cgen_u9264(T69_, 3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
						prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__24.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__24);
						eqdestroy___system_u2691(colontmpD__24);
						eqdestroy___system_u2691(colontmpD__23);
					}
					break;
					default:
					{
						internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*n_p3).info, TM__MQdRN7fpbG7rPm4JpVVAhA_683, TM__MQdRN7fpbG7rPm4JpVVAhA_684);
						if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
					}
					break;
					}
					i_4 += ((NI)1);
					{
						LA45_:;
					}
					{
						oldNimErrFin45_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__18);
						if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
						eqdestroy___system_u2691(tmp2_2);
						eqdestroy___ast_u3252(b_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
						*nimErr_ = oldNimErrFin45_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				} LA44: ;
			}
		}
		{
			LA30_:;
		}
		{
			oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___ast_u3378(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(tmp_2);
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin30_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_2;
		field_2 = NIM_NIL;
		eqcopy___ast_u4577(&field_2, (*n_p3)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
		{
			NIM_BOOL T79_;
			T79_ = (NIM_BOOL)0;
			T79_ = isEmptyType__ast_u7234((*field_2).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			if (!T79_) goto LA80_;
			eqdestroy___ast_u4574(field_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA80_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__25;
			NimStringV2 colontmpD__26;
			NimStringV2 colontmpD__27;
			NimStringV2 colontmpD__28;
			NimStringV2 colontmpD__29;
			tyArray__awn6UrBeChh9cVy9ccoluuYg T95_;
			if (!((*field_2)._kind_2.bitsize == ((NI)0))) goto LA84_;
			colontmpD__25 = NIM_NIL;
			colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
			colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
			colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
			colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
			{
				if (!((*field_2).loc.snippet.len == 0)) goto LA89_;
				fillObjectFields__cgen_u5401(m_p0, typ_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			}
LA89_: ;
			{
				colontmpD__25 = t__cgen_u97((*field_2).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
				if (!(colontmpD__25 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA93_;
				internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*n_p3).info, TM__MQdRN7fpbG7rPm4JpVVAhA_685, TM__MQdRN7fpbG7rPm4JpVVAhA_686);
				if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			}
LA93_: ;
			T95_[0] = expr_p4;
			colontmpD__26 = getTypeDesc__cgen_u8738(m_p0, origType_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			T95_[1] = colontmpD__26;
			T95_[2] = (*field_2).loc.snippet;
			colontmpD__27 = genTypeInfoV1__cgen_u9076(m_p0, (*field_2).typ, info_p5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			T95_[3] = colontmpD__27;
			colontmpD__28 = makeCString__msgs_u83((*(*field_2).name).s);
			if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			T95_[4] = colontmpD__28;
			colontmpD__29 = percent___cgen_u9345(T95_, 5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__29.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__29);
			{
				LA86_:;
			}
			{
				oldNimErrFin86_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__29);
				eqdestroy___system_u2691(colontmpD__28);
				eqdestroy___system_u2691(colontmpD__27);
				eqdestroy___system_u2691(colontmpD__26);
				eqdestroy___ast_u3378(colontmpD__25);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				*nimErr_ = oldNimErrFin86_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
		}
LA84_: ;
		{
			LA76_:;
		}
		{
			oldNimErrFin76_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(field_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin76_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*n_p3).info, TM__MQdRN7fpbG7rPm4JpVVAhA_687, TM__MQdRN7fpbG7rPm4JpVVAhA_688);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectInfo__cgen_u9350)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
	NimStringV2 tmp_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T19_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	t_1 = NIM_NIL;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T9_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*typ_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = ((1040 & (*(*typ_p1).sym).flags) == 16);
LA5_: ;
		if (!T4_) goto LA6_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T9_.len = 0; T9_.p = NIM_NIL;
		colontmpD__3 = typeToString__types_u54(typ_p1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_ = rawNewString(colontmpD__3.len + 51);
appendString((&T9_), TM__MQdRN7fpbG7rPm4JpVVAhA_669);
appendString((&T9_), colontmpD__3);
		colontmpD__4 = T9_;
		liMessage__msgs_u1227((*(*m_p0).g).config, info_p4, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__4, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_670, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	genTypeInfoAux__cgen_u9162(m_p0, typ_p1, origType_p2, name_p3, info_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tmp_1 = getNimNode__cgen_u9080(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T14_;
		NIM_BOOL T15_;
		T14_ = (NIM_BOOL)0;
		T15_ = (NIM_BOOL)0;
		T15_ = isImportedType__cgen_u1373(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T14_ = !(T15_);
		if (T14_) goto LA16_;
		T14_ = (((*typ_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)41)))&63U)))!=0);
LA16_: ;
		if (!T14_) goto LA17_;
		genObjectFields__cgen_u9250(m_p0, typ_p1, origType_p2, (*typ_p1).n, tmp_1, info_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA17_: ;
	colontmpD_ = tiNameForHcr__cgen_u9093(m_p0, name_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T19_[0] = colontmpD_;
	T19_[1] = tmp_1;
	colontmpD__2 = percent___cgen_u9380(T19_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__2);
	t_1 = baseClass__ast_u5348(typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T22_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T23_;
			if (!!((t_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA21;
			T22_ = NIM_NIL;
			T22_ = skipTypes__ast_u5379(t_1, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T22_); goto LA1_;}
			eqsink___ast_u3387(&t_1, T22_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			(*t_1).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)5))) & 63);
			T23_ = NIM_NIL;
			T23_ = baseClass__ast_u5348(t_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T23_); goto LA1_;}
			eqsink___ast_u3387(&t_1, T23_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA21: ;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tmp_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, openArrayToTuple__cgen_u12207)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* p_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__5;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	p_1 = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	a_1 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	colontmpD__5 = NIM_NIL;
	colontmpD__6 = NIM_NIL;
	colontmpD_ = owner__ast_u6246(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18), (*m_p0).Sup.idgen, colontmpD_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = owner__ast_u6246(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	p_1 = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21), (*m_p0).Sup.idgen, colontmpD__2, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = owner__ast_u6246(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	a_1 = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49), (*m_p0).Sup.idgen, colontmpD__3, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = elementType__ast_u5331(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3881(a_1, colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3881(p_1, a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3881(result, p_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = owner__ast_u6246(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = getSysType__magicsys_u55((*(*m_p0).g).graph, (*colontmpD__5).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3881(result, colontmpD__6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopyProc__cgen_u9955)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NimStringV2 result_p2) {
	NimStringV2 colontmpD_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	genProc__cgen_u454(m_p0, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = result_p2;
	T2_[1] = (*s_p1).loc.snippet;
	colontmpD_ = percent___cgen_u9959(T2_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD_);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfoV1__cgen_u9076)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
	NimStringV2 prefixTI_1;
	tyTuple__w31HlKXGH5QCPFggOmKfbQ marker_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
	NimStringV2 colontmpD__5;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
	NimStringV2 T2_;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T19_;
	NimStringV2 T20_;
	NI32 old_1;
	NI32 owner_1;
	tyTuple__w31HlKXGH5QCPFggOmKfbQ T37_;
NIM_BOOL oldNimErrFin45_;
NIM_BOOL oldNimErrFin55_;
NIM_BOOL oldNimErrFin71_;
NIM_BOOL oldNimErrFin88_;
NIM_BOOL oldNimErrFin99_;
	NimStringV2 T128_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	origType_1 = NIM_NIL;
	t_2 = NIM_NIL;
	prefixTI_1.len = 0; prefixTI_1.p = NIM_NIL;
	nimZeroMem((void*)(&marker_1), sizeof(tyTuple__w31HlKXGH5QCPFggOmKfbQ));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	op_1 = NIM_NIL;
	eqcopy___ast_u3381(&origType_1, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_2 = skipTypes__ast_u5379(origType_1, TM__MQdRN7fpbG7rPm4JpVVAhA_469);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T5_) goto LA6_;
		prefixTI_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_470;
	}
	goto LA3_;
LA6_: ;
	{
		prefixTI_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_471;
	}
LA3_: ;
	nimZeroMem((void*)sig_1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	hashType__sighashes_u411(origType_1, (*(*m_p0).g).config, 2, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = getOrDefault__cgen_u1536((*m_p0).typeInfoMarker, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 T13_;
		if (!!((result.len == 0))) goto LA11_;
		T13_.len = 0; T13_.p = NIM_NIL;
		T13_ = rawNewString(prefixTI_1.len + result.len + 1);
appendString((&T13_), prefixTI_1);
appendString((&T13_), result);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_472);
		result = T13_;
		eqdestroy___ast_u4574(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA11_: ;
	marker_1 = getOrDefault__cgen_u10580((*(*m_p0).g).typeInfoMarker, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD__6;
		NimStringV2 T18_;
		if (!!((marker_1.Field0.len == 0))) goto LA16_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_474);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_476);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		declareNimType__cgen_u9964(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_477, marker_1.Field0, ((NI) (marker_1.Field1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__6 = eqdup___system_u2697(marker_1.Field0);
		X5BX5Deq___cgen_u1967((&(*m_p0).typeInfoMarker), sig_1, colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T18_.len = 0; T18_.p = NIM_NIL;
		T18_ = rawNewString(prefixTI_1.len + marker_1.Field0.len + 1);
appendString((&T18_), prefixTI_1);
appendString((&T18_), marker_1.Field0);
appendString((&T18_), TM__MQdRN7fpbG7rPm4JpVVAhA_478);
		result = T18_;
		eqdestroy___ast_u4574(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA16_: ;
	colontmpD_ = typeToC__cgen_u12225(t_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T19_[0] = colontmpD_;
	colontmpD__2 = dollar___modulegraphs_u10732(sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T19_[1] = colontmpD__2;
	T20_.len = 0; T20_.p = NIM_NIL;
	T20_ = percent___cgen_u12435(T19_, 2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T20_); goto LA1_;}
	eqsink___system_u2700((&result), T20_);
	colontmpD__3 = eqdup___system_u2697(result);
	X5BX5Deq___cgen_u1967((&(*m_p0).typeInfoMarker), sig_1, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	old_1 = getOrDefault__cgen_u12552((*(*(*m_p0).g).graph).emittedTypeInfo, result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 T25_;
		if (!!((old_1 == ((NI32)0)))) goto LA23_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_479);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_480);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		declareNimType__cgen_u9964(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_481, result, ((NI) (old_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T25_.len = 0; T25_.p = NIM_NIL;
		T25_ = rawNewString(prefixTI_1.len + result.len + 1);
appendString((&T25_), prefixTI_1);
appendString((&T25_), result);
appendString((&T25_), TM__MQdRN7fpbG7rPm4JpVVAhA_482);
		result = T25_;
		eqdestroy___ast_u4574(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA23_: ;
	colontmpD__4 = skipTypes__ast_u5379(t_2, TM__MQdRN7fpbG7rPm4JpVVAhA_436);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	owner_1 = (*colontmpD__4).itemId.module;
	{
		NIM_BOOL T28_;
		NimStringV2 colontmpD__7;
		NimStringV2 T33_;
		T28_ = (NIM_BOOL)0;
		T28_ = !((owner_1 == ((NI32) ((*(*m_p0).module).position))));
		if (!(T28_)) goto LA29_;
		T28_ = moduleOpenForCodegen__modulegraphs_u14816((*(*m_p0).g).graph, owner_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA29_: ;
		if (!T28_) goto LA30_;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__7 = genTypeInfoV1__cgen_u9076((*(*m_p0).g).modules.p->data[owner_1], origType_1, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		(void)(colontmpD__7);
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_483);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_484);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		declareNimType__cgen_u9964(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_485, result, ((NI) (owner_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		T33_.len = 0; T33_.p = NIM_NIL;
		T33_ = rawNewString(prefixTI_1.len + result.len + 1);
appendString((&T33_), prefixTI_1);
appendString((&T33_), result);
appendString((&T33_), TM__MQdRN7fpbG7rPm4JpVVAhA_486);
		result = T33_;
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___ast_u4574(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
		{
			LA32_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA26_;
LA30_: ;
	{
		owner_1 = ((NI32) ((*(*m_p0).module).position));
	}
LA26_: ;
	colontmpD__5 = eqdup___system_u2697(result);
	T37_.Field0 = colontmpD__5;
	T37_.Field1 = owner_1;
	X5BX5Deq___cgen_u11067((&(*(*m_p0).g).typeInfoMarker), sig_1, T37_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rememberEmittedTypeInfo__modulegraphs_u14828((*(*m_p0).g).graph, owner_1, result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*t_2).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)3):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63):
	{
		eqsink___system_u2700((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_488);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	{
		genTypeInfoAuxBase__cgen_u9097(m_p0, t_2, t_2, result, TM__MQdRN7fpbG7rPm4JpVVAhA_501, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
			NimStringV2 T46_;
			if (!!(((*t_2).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA43_;
			colontmpD__8 = NIM_NIL;
			colontmpD__8 = skipModifier__ast_u5338(t_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			T46_.len = 0; T46_.p = NIM_NIL;
			T46_ = genTypeInfoV1__cgen_u9076(m_p0, colontmpD__8, info_p2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T46_); goto LA45_;}
			eqsink___system_u2700((&result), T46_);
			{
				LA45_:;
			}
			{
				oldNimErrFin45_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin45_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA41_;
LA43_: ;
		{
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 T51_;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T51_.len = 0; T51_.p = NIM_NIL;
			colontmpD__9 = dollar___ast_u182((*t_2).kind);
			T51_ = rawNewString(colontmpD__9.len + 15);
appendString((&T51_), TM__MQdRN7fpbG7rPm4JpVVAhA_503);
appendString((&T51_), colontmpD__9);
appendChar((&T51_), 41);
			colontmpD__10 = T51_;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, colontmpD__10, TM__MQdRN7fpbG7rPm4JpVVAhA_504);
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			{
				LA50_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA41_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)52) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)53):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
		colontmpD__11 = NIM_NIL;
		{
			NimStringV2 argX60gensym966__1;
			if (!!((((*t_2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)10)))&63U)))!=0))) goto LA58_;
			argX60gensym966__1.len = 0; argX60gensym966__1.p = NIM_NIL;
			argX60gensym966__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_505);
			if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, argX60gensym966__1, TM__MQdRN7fpbG7rPm4JpVVAhA_505);
			if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
			{
				LA60_:;
			}
			{
				eqdestroy___system_u2691(argX60gensym966__1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		}
LA58_: ;
		colontmpD__11 = skipModifier__ast_u5338(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		result = genTypeInfoV1__cgen_u9076(m_p0, colontmpD__11, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		eqdestroy___ast_u3378(colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u4574(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
		{
			LA55_:;
		}
		{
			oldNimErrFin55_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin55_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		{
			if (!!(((*t_2).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9)))) goto LA68_;
			genTypeInfoAuxBase__cgen_u9097(m_p0, t_2, t_2, result, TM__MQdRN7fpbG7rPm4JpVVAhA_506, info_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA66_;
LA68_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__12;
			x_1 = NIM_NIL;
			colontmpD__12 = NIM_NIL;
			colontmpD__12 = owner__ast_u6246(t_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			x_1 = fakeClosureType__cgen_u9529(m_p0, colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			genTupleInfo__cgen_u9403(m_p0, x_1, x_1, result, info_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			{
				LA71_:;
			}
			{
				oldNimErrFin71_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3378(x_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin71_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA66_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		genTypeInfoAux__cgen_u9162(m_p0, t_2, t_2, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 markerProc_1;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T80_;
			if (!((*(*(*m_p0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)7) || (*(*(*m_p0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)9) || (*(*(*m_p0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10))) goto LA77_;
			markerProc_1.len = 0; markerProc_1.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			markerProc_1 = genTraverseProc__cgen_u9823(m_p0, origType_1, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
			colontmpD__13 = tiNameForHcr__cgen_u9093(m_p0, result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
			T80_[0] = colontmpD__13;
			T80_[1] = markerProc_1;
			colontmpD__14 = percent___cgen_u12703(T80_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__14.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__14);
			{
				LA79_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(markerProc_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA77_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	{
		genTypeInfoAux__cgen_u9162(m_p0, t_2, t_2, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 markerProc_2;
			NimStringV2 colontmpD__17;
			NimStringV2 colontmpD__18;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T89_;
			if (!((*(*(*m_p0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)7) || (*(*(*m_p0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)9) || (*(*(*m_p0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10))) goto LA86_;
			colontmpD__15 = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			markerProc_2.len = 0; markerProc_2.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			colontmpD__15 = last__ast_u5278(origType_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			colontmpD__16 = getTypeDesc__cgen_u8738(m_p0, colontmpD__15, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			(void)(colontmpD__16);
			markerProc_2 = genTraverseProc__cgen_u9823(m_p0, origType_1, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			colontmpD__17 = tiNameForHcr__cgen_u9093(m_p0, result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			T89_[0] = colontmpD__17;
			T89_[1] = markerProc_2;
			colontmpD__18 = percent___cgen_u12703(T89_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__18.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__18);
			{
				LA88_:;
			}
			{
				oldNimErrFin88_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__18);
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(markerProc_2);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___ast_u3378(colontmpD__15);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin88_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA86_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
	{
		genTypeInfoAux__cgen_u9162(m_p0, t_2, t_2, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		genArrayInfo__cgen_u9524(m_p0, t_2, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		genSetInfo__cgen_u9506(m_p0, t_2, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	{
		genEnumInfo__cgen_u9442(m_p0, t_2, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		genObjectInfo__cgen_u9350(m_p0, t_2, origType_1, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		genTupleInfo__cgen_u9403(m_p0, t_2, origType_1, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_2;
		x_2 = NIM_NIL;
		x_2 = openArrayToTuple__cgen_u12207(m_p0, t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
		genTupleInfo__cgen_u9403(m_p0, x_2, origType_1, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA99_;
		{
			LA99_:;
		}
		{
			oldNimErrFin99_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(x_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin99_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		NimStringV2 T104_;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		T104_.len = 0; T104_.p = NIM_NIL;
		colontmpD__19 = dollar___ast_u182((*t_2).kind);
		T104_ = rawNewString(colontmpD__19.len + 15);
appendString((&T104_), TM__MQdRN7fpbG7rPm4JpVVAhA_689);
appendString((&T104_), colontmpD__19);
appendChar((&T104_), 41);
		colontmpD__20 = T104_;
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, colontmpD__20, TM__MQdRN7fpbG7rPm4JpVVAhA_690);
		if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
		{
			LA103_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	op_1 = getAttachedOp__modulegraphs_u4987((*(*m_p0).g).graph, t_2, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)6));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T111_;
		if (!(op_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA109_;
		T111_ = NIM_NIL;
		T111_ = getAttachedOp__modulegraphs_u4987((*(*m_p0).g).graph, origType_1, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)6));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T111_); goto LA1_;}
		eqsink___ast_u4583(&op_1, T111_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA109_: ;
	{
		if (!!((op_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA114_;
		genDeepCopyProc__cgen_u9955(m_p0, op_1, result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA114_: ;
	{
		NIM_BOOL T118_;
		NIM_BOOL T119_;
		NimStringV2 v2info_1;
		NimStringV2 colontmpD__21;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T125_;
		T118_ = (NIM_BOOL)0;
		T119_ = (NIM_BOOL)0;
		T119_ = (((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0);
		if (!(T119_)) goto LA120_;
		T119_ = ((*t_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
LA120_: ;
		T118_ = T119_;
		if (!(T118_)) goto LA121_;
		T118_ = !((((*(*t_2).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0));
LA121_: ;
		if (!T118_) goto LA122_;
		v2info_1.len = 0; v2info_1.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		v2info_1 = genTypeInfoV2__cgen_u10426(m_p0, origType_1, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		T125_[0] = v2info_1;
		T125_[1] = result;
		colontmpD__21 = percent___cgen_u12743(T125_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__21.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__21);
		{
			LA124_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(v2info_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA122_: ;
	T128_.len = 0; T128_.p = NIM_NIL;
	T128_ = rawNewString(prefixTI_1.len + result.len + 1);
appendString((&T128_), prefixTI_1);
appendString((&T128_), result);
appendString((&T128_), TM__MQdRN7fpbG7rPm4JpVVAhA_691);
	eqsink___system_u2700((&result), T128_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoV2OldImpl__cgen_u10191)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
	NimStringV2 colontmpD_;
	NimStringV2 typeEntry_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NI16 colontmpD__4;
	NI16 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	NimStringV2 colontmpD__9;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA dispatchMethods_1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA resultX60gensym876__1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
	NI flags_1;
	tyArray__YgExxhfgKcesA5EOUj1MOA T8_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
	NI16 objDepth_1;
	tyArray__Seu7uK9aaOSN0BK3EAjjSHw T41_;
NIM_BOOL oldNimErrFin46_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	typeEntry_1.len = 0; typeEntry_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4 = (NI16)0;
	colontmpD__5 = (NI16)0;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
	colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
	dispatchMethods_1.len = 0; dispatchMethods_1.p = NIM_NIL;
	resultX60gensym876__1.len = 0; resultX60gensym876__1.p = NIM_NIL;
	colontmpD__10 = NIM_NIL;
	cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_440);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = name_p3;
	colontmpD_ = percent___cgen_u10197(T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD_);
	flags_1 = ((NI)0);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = canFormAcycle__types_u784((*(*m_p0).g).graph, t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T5_)) goto LA6_;
		flags_1 = (NI)(flags_1 | ((NI)1));
	}
LA6_: ;
	typeEntry_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_[0] = name_p3;
	colontmpD__2 = percent___cgen_u10204(T8_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&typeEntry_1), colontmpD__2.len + 0);
appendString((&typeEntry_1), colontmpD__2);
	genHook__cgen_u10069(m_p0, t_p1, info_p4, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1), (&typeEntry_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T9_[0] = name_p3;
	colontmpD__3 = percent___cgen_u10209(T9_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&typeEntry_1), colontmpD__3.len + 0);
appendString((&typeEntry_1), colontmpD__3);
	genHook__cgen_u10069(m_p0, t_p1, info_p4, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)5), (&typeEntry_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17))) goto LA12_;
		colontmpD__4 = getObjDepth__cgen_u10096(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		objDepth_1 = colontmpD__4;
	}
	goto LA10_;
LA12_: ;
	{
		colontmpD__5 = ((NI16)-1);
		objDepth_1 = colontmpD__5;
	}
LA10_: ;
	{
		NIM_BOOL T17_;
		NIM_BOOL T19_;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 T24_;
		T17_ = (NIM_BOOL)0;
		T17_ = ((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13));
		if (!(T17_)) goto LA18_;
		T19_ = (NIM_BOOL)0;
		T19_ = !(((*t_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T19_)) goto LA20_;
		T19_ = ((1040 & (*(*t_p1).sym).flags) == 16);
LA20_: ;
		T17_ = T19_;
LA18_: ;
		if (!T17_) goto LA21_;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		T24_.len = 0; T24_.p = NIM_NIL;
		colontmpD__11 = typeToString__types_u54(t_p1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T24_ = rawNewString(colontmpD__11.len + 51);
appendString((&T24_), TM__MQdRN7fpbG7rPm4JpVVAhA_450);
appendString((&T24_), colontmpD__11);
		colontmpD__12 = T24_;
		liMessage__msgs_u1227((*(*m_p0).g).config, info_p4, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__12, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_451, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		{
			LA23_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA21_: ;
	{
		NIM_BOOL T29_;
		NimStringV2 typeName_1;
		NimStringV2 colontmpD__13;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T38_;
		T29_ = (NIM_BOOL)0;
		T29_ = isDefined__options_u959((*(*m_p0).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_453);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T29_) goto LA30_;
		typeName_1.len = 0; typeName_1.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		{
			if (!((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13))) goto LA35_;
			typeName_1 = genTypeInfo2Name__cgen_u9985(m_p0, t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
		goto LA33_;
LA35_: ;
		{
			typeName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_458;
		}
LA33_: ;
		T38_[0] = name_p3;
		T38_[1] = typeName_1;
		colontmpD__13 = percent___cgen_u10240(T38_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		prepareAdd((&typeEntry_1), colontmpD__13.len + 0);
appendString((&typeEntry_1), colontmpD__13);
		{
			LA32_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(typeName_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA30_: ;
	T41_[0] = name_p3;
	colontmpD__6 = getTypeDesc__cgen_u8738(m_p0, t_p1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T41_[1] = colontmpD__6;
	colontmpD__7 = rope__ropes_u15(((NI64) (objDepth_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T41_[2] = colontmpD__7;
	colontmpD__8 = rope__ropes_u15(((NI64) (flags_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T41_[3] = colontmpD__8;
	colontmpD__9 = percent___cgen_u10245(T41_, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&typeEntry_1), colontmpD__9.len + 0);
appendString((&typeEntry_1), colontmpD__9);
	{
		NimStringV2 objDisplay_1;
		NimStringV2 objDisplayStore_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		NimStringV2 colontmpD__17;
		NimStringV2 colontmpD__18;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T47_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T48_;
		if (!(((NI16)0) <= objDepth_1)) goto LA44_;
		objDisplay_1.len = 0; objDisplay_1.p = NIM_NIL;
		objDisplayStore_1.len = 0; objDisplayStore_1.p = NIM_NIL;
		colontmpD__14 = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		objDisplay_1 = genDisplay__cgen_u10125(m_p0, t_p1, ((NI) (objDepth_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		objDisplayStore_1 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		colontmpD__14 = getSysType__magicsys_u55((*(*m_p0).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43));
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		colontmpD__15 = getTypeDesc__cgen_u8738(m_p0, colontmpD__14, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		T47_[0] = colontmpD__15;
		T47_[1] = objDisplayStore_1;
		colontmpD__16 = rope__ropes_u15(((NI64) ((NI16)(objDepth_1 + ((NI16)1)))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		T47_[2] = colontmpD__16;
		T47_[3] = objDisplay_1;
		colontmpD__17 = percent___cgen_u10252(T47_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__17.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__17);
		T48_[0] = name_p3;
		T48_[1] = objDisplayStore_1;
		colontmpD__18 = percent___cgen_u10257(T48_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		prepareAdd((&typeEntry_1), colontmpD__18.len + 0);
appendString((&typeEntry_1), colontmpD__18);
		{
			LA46_:;
		}
		{
			oldNimErrFin46_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___ast_u3378(colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(objDisplayStore_1);
			eqdestroy___system_u2691(objDisplay_1);
			*nimErr_ = oldNimErrFin46_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA44_: ;
	resultX60gensym876__1.len = 0; resultX60gensym876__1.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* xX60gensym876__1;
		xX60gensym876__1 = NIM_NIL;
		{
			NIM_BOOL T55_;
			T55_ = (NIM_BOOL)0;
			T55_ = contains__modulegraphs_u8507((*(*(*m_p0).g).graph).methodsPerType, (*t_p1).itemId);
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			if (!T55_) goto LA56_;
			{
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* it_1;
				NI i_1;
				NI L_1;
				NI T59_;
				tySequence__olFOFaYzOJN9aV5BWqK4b9bA* T60_;
				it_1 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
				i_1 = ((NI)0);
				T60_ = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA*)0;
				T60_ = X5BX5D___modulegraphs_u8590((&(*(*(*m_p0).g).graph).methodsPerType), (*t_p1).itemId);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				T59_ = (*T60_).len;
				L_1 = T59_;
				{
					while (1) {
						tySequence__olFOFaYzOJN9aV5BWqK4b9bA* T63_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T64_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
						if (!(i_1 < L_1)) goto LA62;
						T63_ = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA*)0;
						T63_ = X5BX5D___modulegraphs_u8590((&(*(*(*m_p0).g).graph).methodsPerType), (*t_p1).itemId);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						it_1 = (&(*T63_).p->data[i_1]);
						T64_ = NIM_NIL;
						T64_ = resolveSym__modulegraphs_u3497((*(*m_p0).g).graph, it_1);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T64_); goto LA52_;}
						eqsink___ast_u4583(&xX60gensym876__1, T64_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						blitTmp_1 = xX60gensym876__1;
						eqwasMoved___ast_u4571(&xX60gensym876__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						add__renderer_u83((&resultX60gensym876__1), blitTmp_1);
						i_1 += ((NI)1);
					} LA62: ;
				}
			}
		}
LA56_: ;
		{
			LA52_:;
		}
		{
			oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(xX60gensym876__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin52_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	dispatchMethods_1 = resultX60gensym876__1;
	eqwasMoved___ast_u4845((&resultX60gensym876__1));
	{
		NI T69_;
		NimStringV2 vTablePointerName_1;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		NimStringV2 colontmpD__21;
		NimStringV2 colontmpD__22;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T73_;
		NI T74_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T79_;
		T69_ = dispatchMethods_1.len;
		if (!(((NI)0) < T69_)) goto LA70_;
		vTablePointerName_1.len = 0; vTablePointerName_1.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		vTablePointerName_1 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
		T73_[0] = vTablePointerName_1;
		T74_ = dispatchMethods_1.len;
		colontmpD__19 = rope__ropes_u15(((NI64) (T74_)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
		T73_[1] = colontmpD__19;
		colontmpD__20 = genVTable__cgen_u10180(dispatchMethods_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
		T73_[2] = colontmpD__20;
		colontmpD__21 = percent___cgen_u10285(T73_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__21.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__21);
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** i_2;
			NI i_3;
			NI L_2;
			NI T76_;
			i_2 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
			i_3 = ((NI)0);
			T76_ = dispatchMethods_1.len;
			L_2 = T76_;
			{
				while (1) {
					if (!(i_3 < L_2)) goto LA78;
					i_2 = &dispatchMethods_1.p->data[i_3];
					genProcPrototype__cgen_u523(m_p0, (*i_2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
					i_3 += ((NI)1);
				} LA78: ;
			}
		}
		T79_[0] = name_p3;
		T79_[1] = vTablePointerName_1;
		colontmpD__22 = percent___cgen_u10294(T79_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
		prepareAdd((&typeEntry_1), colontmpD__22.len + 0);
appendString((&typeEntry_1), colontmpD__22);
		{
			LA72_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__22);
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(vTablePointerName_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA70_: ;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), typeEntry_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), typeEntry_1);
	{
		NIM_BOOL T84_;
		NIM_BOOL T85_;
		NimStringV2 colontmpD__23;
		T84_ = (NIM_BOOL)0;
		T85_ = (NIM_BOOL)0;
		T85_ = ((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
		if (!(T85_)) goto LA86_;
		colontmpD__10 = baseClass__ast_u5348(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T85_ = !((colontmpD__10 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA86_: ;
		T84_ = T85_;
		if (!(T84_)) goto LA87_;
		T84_ = (((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)54)))&63U)))!=0);
LA87_: ;
		if (!T84_) goto LA88_;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__23 = genTypeInfoV1__cgen_u9076(m_p0, t_p1, info_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
		(void)(colontmpD__23);
		{
			LA90_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__23);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA88_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4848(resultX60gensym876__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4848(dispatchMethods_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(typeEntry_1);
		eqdestroy___system_u2691(colontmpD_);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeInfoV2Impl__cgen_u10311)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_p2, NimStringV2 name_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4) {
	NimStringV2 colontmpD_;
	NimStringV2 typeEntry_1;
	NimStringV2 colontmpD__2;
	NI16 colontmpD__3;
	NI16 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA dispatchMethods_1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA resultX60gensym900__1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
	NI flags_1;
	tyArray__YgExxhfgKcesA5EOUj1MOA T8_;
	NI16 objDepth_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T26_;
NIM_BOOL oldNimErrFin31_;
NIM_BOOL oldNimErrFin51_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	typeEntry_1.len = 0; typeEntry_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3 = (NI16)0;
	colontmpD__4 = (NI16)0;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	dispatchMethods_1.len = 0; dispatchMethods_1.p = NIM_NIL;
	resultX60gensym900__1.len = 0; resultX60gensym900__1.p = NIM_NIL;
	colontmpD__8 = NIM_NIL;
	cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_692);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = name_p3;
	colontmpD_ = percent___cgen_u10197(T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD_);
	flags_1 = ((NI)0);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = canFormAcycle__types_u784((*(*m_p0).g).graph, t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T5_)) goto LA6_;
		flags_1 = (NI)(flags_1 | ((NI)1));
	}
LA6_: ;
	typeEntry_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_[0] = name_p3;
	colontmpD__2 = percent___cgen_u10323(T8_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&typeEntry_1), colontmpD__2.len + 0);
appendString((&typeEntry_1), colontmpD__2);
	prepareAdd((&typeEntry_1), 21);
appendString((&typeEntry_1), TM__MQdRN7fpbG7rPm4JpVVAhA_694);
	genHook__cgen_u10069(m_p0, t_p1, info_p4, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1), (&typeEntry_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17))) goto LA11_;
		colontmpD__3 = getObjDepth__cgen_u10096(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		objDepth_1 = colontmpD__3;
	}
	goto LA9_;
LA11_: ;
	{
		colontmpD__4 = ((NI16)-1);
		objDepth_1 = colontmpD__4;
	}
LA9_: ;
	{
		NIM_BOOL T16_;
		NIM_BOOL T18_;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 T23_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13));
		if (!(T16_)) goto LA17_;
		T18_ = (NIM_BOOL)0;
		T18_ = !(((*t_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
		if (!(T18_)) goto LA19_;
		T18_ = ((1040 & (*(*t_p1).sym).flags) == 16);
LA19_: ;
		T16_ = T18_;
LA17_: ;
		if (!T16_) goto LA20_;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		T23_.len = 0; T23_.p = NIM_NIL;
		colontmpD__9 = typeToString__types_u54(t_p1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_ = rawNewString(colontmpD__9.len + 51);
appendString((&T23_), TM__MQdRN7fpbG7rPm4JpVVAhA_695);
appendString((&T23_), colontmpD__9);
		colontmpD__10 = T23_;
		liMessage__msgs_u1227((*(*m_p0).g).config, info_p4, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__10, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_696, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		{
			LA22_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA20_: ;
	colontmpD__5 = getTypeDesc__cgen_u8738(m_p0, t_p1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T26_[0] = colontmpD__5;
	colontmpD__6 = rope__ropes_u15(((NI64) (objDepth_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T26_[1] = colontmpD__6;
	colontmpD__7 = percent___cgen_u10349(T26_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&typeEntry_1), colontmpD__7.len + 0);
appendString((&typeEntry_1), colontmpD__7);
	{
		NimStringV2 objDisplay_1;
		NimStringV2 objDisplayStore_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T32_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T33_;
		if (!(((NI16)0) <= objDepth_1)) goto LA29_;
		objDisplay_1.len = 0; objDisplay_1.p = NIM_NIL;
		objDisplayStore_1.len = 0; objDisplayStore_1.p = NIM_NIL;
		colontmpD__11 = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		objDisplay_1 = genDisplay__cgen_u10125(m_p0, t_p1, ((NI) (objDepth_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		objDisplayStore_1 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		colontmpD__11 = getSysType__magicsys_u55((*(*m_p0).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43));
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		colontmpD__12 = getTypeDesc__cgen_u8738(m_p0, colontmpD__11, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		T32_[0] = colontmpD__12;
		T32_[1] = objDisplayStore_1;
		colontmpD__13 = rope__ropes_u15(((NI64) ((NI16)(objDepth_1 + ((NI16)1)))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		T32_[2] = colontmpD__13;
		T32_[3] = objDisplay_1;
		colontmpD__14 = percent___cgen_u10356(T32_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__14.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__14);
		T33_[0] = objDisplayStore_1;
		colontmpD__15 = percent___cgen_u10361(T33_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		prepareAdd((&typeEntry_1), colontmpD__15.len + 0);
appendString((&typeEntry_1), colontmpD__15);
		{
			LA31_:;
		}
		{
			oldNimErrFin31_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___ast_u3378(colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(objDisplayStore_1);
			eqdestroy___system_u2691(objDisplay_1);
			*nimErr_ = oldNimErrFin31_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA29_: ;
	{
		NIM_BOOL T38_;
		NimStringV2 typeName_1;
		NimStringV2 colontmpD__16;
		tyArray__YgExxhfgKcesA5EOUj1MOA T47_;
		T38_ = (NIM_BOOL)0;
		T38_ = isDefined__options_u959((*(*m_p0).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_697);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T38_) goto LA39_;
		typeName_1.len = 0; typeName_1.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		{
			if (!((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13))) goto LA44_;
			typeName_1 = genTypeInfo2Name__cgen_u9985(m_p0, t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		}
		goto LA42_;
LA44_: ;
		{
			typeName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_698;
		}
LA42_: ;
		T47_[0] = typeName_1;
		colontmpD__16 = percent___cgen_u10371(T47_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		prepareAdd((&typeEntry_1), colontmpD__16.len + 0);
appendString((&typeEntry_1), colontmpD__16);
		{
			LA41_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(typeName_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA39_: ;
	prepareAdd((&typeEntry_1), 22);
appendString((&typeEntry_1), TM__MQdRN7fpbG7rPm4JpVVAhA_700);
	genHook__cgen_u10069(m_p0, t_p1, info_p4, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)5), (&typeEntry_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	resultX60gensym900__1.len = 0; resultX60gensym900__1.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* xX60gensym900__1;
		xX60gensym900__1 = NIM_NIL;
		{
			NIM_BOOL T54_;
			T54_ = (NIM_BOOL)0;
			T54_ = contains__modulegraphs_u8507((*(*(*m_p0).g).graph).methodsPerType, (*t_p1).itemId);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			if (!T54_) goto LA55_;
			{
				tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* it_1;
				NI i_1;
				NI L_1;
				NI T58_;
				tySequence__olFOFaYzOJN9aV5BWqK4b9bA* T59_;
				it_1 = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
				i_1 = ((NI)0);
				T59_ = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA*)0;
				T59_ = X5BX5D___modulegraphs_u8590((&(*(*(*m_p0).g).graph).methodsPerType), (*t_p1).itemId);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T58_ = (*T59_).len;
				L_1 = T58_;
				{
					while (1) {
						tySequence__olFOFaYzOJN9aV5BWqK4b9bA* T62_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T63_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
						if (!(i_1 < L_1)) goto LA61;
						T62_ = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA*)0;
						T62_ = X5BX5D___modulegraphs_u8590((&(*(*(*m_p0).g).graph).methodsPerType), (*t_p1).itemId);
						if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
						it_1 = (&(*T62_).p->data[i_1]);
						T63_ = NIM_NIL;
						T63_ = resolveSym__modulegraphs_u3497((*(*m_p0).g).graph, it_1);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T63_); goto LA51_;}
						eqsink___ast_u4583(&xX60gensym900__1, T63_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
						blitTmp_1 = xX60gensym900__1;
						eqwasMoved___ast_u4571(&xX60gensym900__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
						add__renderer_u83((&resultX60gensym900__1), blitTmp_1);
						i_1 += ((NI)1);
					} LA61: ;
				}
			}
		}
LA55_: ;
		{
			LA51_:;
		}
		{
			oldNimErrFin51_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(xX60gensym900__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin51_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	dispatchMethods_1 = resultX60gensym900__1;
	eqwasMoved___ast_u4845((&resultX60gensym900__1));
	{
		NI T68_;
		NimStringV2 colontmpD__17;
		NimStringV2 colontmpD__18;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		tyArray__YgExxhfgKcesA5EOUj1MOA T72_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T77_;
		T68_ = dispatchMethods_1.len;
		if (!(((NI)0) < T68_)) goto LA69_;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__17 = rope__ropes_u15(((NI64) (flags_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
		T72_[0] = colontmpD__17;
		colontmpD__18 = percent___cgen_u10395(T72_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
		prepareAdd((&typeEntry_1), colontmpD__18.len + 0);
appendString((&typeEntry_1), colontmpD__18);
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** i_2;
			NI i_3;
			NI L_2;
			NI T74_;
			i_2 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
			i_3 = ((NI)0);
			T74_ = dispatchMethods_1.len;
			L_2 = T74_;
			{
				while (1) {
					if (!(i_3 < L_2)) goto LA76;
					i_2 = &dispatchMethods_1.p->data[i_3];
					genProcPrototype__cgen_u523(m_p0, (*i_2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
					i_3 += ((NI)1);
				} LA76: ;
			}
		}
		colontmpD__19 = genVTable__cgen_u10180(dispatchMethods_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
		T77_[0] = colontmpD__19;
		colontmpD__20 = percent___cgen_u10404(T77_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
		prepareAdd((&typeEntry_1), colontmpD__20.len + 0);
appendString((&typeEntry_1), colontmpD__20);
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), typeEntry_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), typeEntry_1);
		{
			LA71_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___system_u2691(colontmpD__17);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA66_;
LA69_: ;
	{
		NimStringV2 colontmpD__21;
		NimStringV2 colontmpD__22;
		tyArray__YgExxhfgKcesA5EOUj1MOA T81_;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		colontmpD__21 = rope__ropes_u15(((NI64) (flags_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T81_[0] = colontmpD__21;
		colontmpD__22 = percent___cgen_u10409(T81_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&typeEntry_1), colontmpD__22.len + 0);
appendString((&typeEntry_1), colontmpD__22);
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), typeEntry_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), typeEntry_1);
		eqdestroy___system_u2691(colontmpD__22);
		eqdestroy___system_u2691(colontmpD__21);
	}
LA66_: ;
	{
		NIM_BOOL T84_;
		NIM_BOOL T85_;
		NimStringV2 colontmpD__23;
		T84_ = (NIM_BOOL)0;
		T85_ = (NIM_BOOL)0;
		T85_ = ((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
		if (!(T85_)) goto LA86_;
		colontmpD__8 = baseClass__ast_u5348(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T85_ = !((colontmpD__8 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA86_: ;
		T84_ = T85_;
		if (!(T84_)) goto LA87_;
		T84_ = (((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)54)))&63U)))!=0);
LA87_: ;
		if (!T84_) goto LA88_;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__23 = genTypeInfoV1__cgen_u9076(m_p0, t_p1, info_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
		(void)(colontmpD__23);
		{
			LA90_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__23);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA88_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4848(resultX60gensym900__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4848(dispatchMethods_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(typeEntry_1);
		eqdestroy___system_u2691(colontmpD_);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfoV2__cgen_u10426)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origType_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
	NimStringV2 prefixTI_1;
	tyTuple__w31HlKXGH5QCPFggOmKfbQ marker_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 T2_;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_1;
	tyArray__YgExxhfgKcesA5EOUj1MOA T19_;
	NimStringV2 T20_;
	NI32 owner_1;
	tyTuple__w31HlKXGH5QCPFggOmKfbQ T31_;
	NimStringV2 T41_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	origType_1 = NIM_NIL;
	t_2 = NIM_NIL;
	prefixTI_1.len = 0; prefixTI_1.p = NIM_NIL;
	nimZeroMem((void*)(&marker_1), sizeof(tyTuple__w31HlKXGH5QCPFggOmKfbQ));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	eqcopy___ast_u3381(&origType_1, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_2 = skipTypes__ast_u5379(origType_1, TM__MQdRN7fpbG7rPm4JpVVAhA_428);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T5_) goto LA6_;
		prefixTI_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_429;
	}
	goto LA3_;
LA6_: ;
	{
		prefixTI_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_430;
	}
LA3_: ;
	nimZeroMem((void*)sig_1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	hashType__sighashes_u411(origType_1, (*(*m_p0).g).config, 2, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = getOrDefault__cgen_u1536((*m_p0).typeInfoMarkerV2, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 T13_;
		if (!!((result.len == 0))) goto LA11_;
		T13_.len = 0; T13_.p = NIM_NIL;
		T13_ = rawNewString(prefixTI_1.len + result.len + 1);
appendString((&T13_), prefixTI_1);
appendString((&T13_), result);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_431);
		result = T13_;
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA11_: ;
	marker_1 = getOrDefault__cgen_u10580((*(*m_p0).g).typeInfoMarkerV2, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD__5;
		NimStringV2 T18_;
		if (!!((marker_1.Field0.len == 0))) goto LA16_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_433);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		declareNimType__cgen_u9964(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_434, marker_1.Field0, ((NI) (marker_1.Field1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__5 = eqdup___system_u2697(marker_1.Field0);
		X5BX5Deq___cgen_u1967((&(*m_p0).typeInfoMarkerV2), sig_1, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T18_.len = 0; T18_.p = NIM_NIL;
		T18_ = rawNewString(prefixTI_1.len + marker_1.Field0.len + 1);
appendString((&T18_), prefixTI_1);
appendString((&T18_), marker_1.Field0);
appendString((&T18_), TM__MQdRN7fpbG7rPm4JpVVAhA_435);
		result = T18_;
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA16_: ;
	colontmpD_ = dollar___modulegraphs_u10732(sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T19_[0] = colontmpD_;
	T20_.len = 0; T20_.p = NIM_NIL;
	T20_ = percent___cgen_u10973(T19_, 1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T20_); goto LA1_;}
	eqsink___system_u2700((&result), T20_);
	colontmpD__2 = eqdup___system_u2697(result);
	X5BX5Deq___cgen_u1967((&(*m_p0).typeInfoMarkerV2), sig_1, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = skipTypes__ast_u5379(t_2, TM__MQdRN7fpbG7rPm4JpVVAhA_436);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	owner_1 = (*colontmpD__3).itemId.module;
	{
		NIM_BOOL T23_;
		NimStringV2 colontmpD__6;
		NimStringV2 T28_;
		T23_ = (NIM_BOOL)0;
		T23_ = !((owner_1 == ((NI32) ((*(*m_p0).module).position))));
		if (!(T23_)) goto LA24_;
		T23_ = moduleOpenForCodegen__modulegraphs_u14816((*(*m_p0).g).graph, owner_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA24_: ;
		if (!T23_) goto LA25_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__6 = genTypeInfoV2__cgen_u10426((*(*m_p0).g).modules.p->data[owner_1], origType_1, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		(void)(colontmpD__6);
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_437);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		declareNimType__cgen_u9964(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_438, result, ((NI) (owner_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T28_.len = 0; T28_.p = NIM_NIL;
		T28_ = rawNewString(prefixTI_1.len + result.len + 1);
appendString((&T28_), prefixTI_1);
appendString((&T28_), result);
appendString((&T28_), TM__MQdRN7fpbG7rPm4JpVVAhA_439);
		result = T28_;
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
		{
			LA27_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA25_: ;
	colontmpD__4 = eqdup___system_u2697(result);
	T31_.Field0 = colontmpD__4;
	T31_.Field1 = owner_1;
	X5BX5Deq___cgen_u11067((&(*(*m_p0).g).typeInfoMarkerV2), sig_1, T31_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T34_;
		NIM_BOOL T35_;
		T34_ = (NIM_BOOL)0;
		T35_ = (NIM_BOOL)0;
		T35_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T35_) goto LA36_;
		T35_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA36_: ;
		T34_ = T35_;
		if (T34_) goto LA37_;
		T34_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA37_: ;
		if (!T34_) goto LA38_;
		genTypeInfoV2OldImpl__cgen_u10191(m_p0, t_2, origType_1, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA32_;
LA38_: ;
	{
		genTypeInfoV2Impl__cgen_u10311(m_p0, t_2, origType_1, result, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA32_: ;
	T41_.len = 0; T41_.p = NIM_NIL;
	T41_ = rawNewString(prefixTI_1.len + result.len + 1);
appendString((&T41_), prefixTI_1);
appendString((&T41_), result);
appendString((&T41_), TM__MQdRN7fpbG7rPm4JpVVAhA_701);
	eqsink___system_u2700((&result), T41_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___cgen_u10908(marker_1);
		eqdestroy___ast_u3378(t_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(origType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genRawSetData__cgen_u20229)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ cs_p0, NI size_p1, NimStringV2* result_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 res_1;
		if (!(((NI)8) < size_p1)) goto LA3_;
		res_1.len = 0; res_1.p = NIM_NIL;
		res_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_712;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < size_p1)) goto LA7;
					i_1 = i_2;
					prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_714);
					nimAddCharV1((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_716.p->data[(NU8)((NU8)(cs_p0.p->data[i_1]) / (NU8)(((NU8)16)))]);
					nimAddCharV1((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_717.p->data[(NU8)((NU8)(cs_p0.p->data[i_1]) % (NU8)(((NU8)16)))]);
					{
						if (!(i_1 < (NI)(size_p1 - ((NI)1)))) goto LA10_;
						{
							if (!((NI)(i_1 % ((NI)8)) == ((NI)7))) goto LA14_;
							prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_719);
						}
						goto LA12_;
LA14_: ;
						{
							prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_720);
						}
LA12_: ;
					}
					goto LA8_;
LA10_: ;
					{
						prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_722);
					}
LA8_: ;
					i_2 += ((NI)1);
				} LA7: ;
			}
		}
		prepareAdd((&(*result_p2)), res_1.len + 0);
appendString((&(*result_p2)), res_1);
		eqdestroy___system_u2691(res_1);
	}
	goto LA1_;
LA3_: ;
	{
		NU64 T19_;
		T19_ = (NU64)0;
		T19_ = bitSetToWord__bitsets_u237(cs_p0, size_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		intLiteral__cgen_u14092(((NI64) (T19_)), result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSeqPayloadType__cgen_u3522)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1) {
	NimStringV2 result;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA check_1;
	NimStringV2 colontmpD_;
	NimStringV2 T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)(&check_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	initIntSet__pureZcollectionsZintsets_u598((&check_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = getTypeDescWeak__cgen_u3400(m_p0, t_p1, (&check_1), ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + 8);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_749);
	result = T2_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___pureZcollectionsZintsets_u230((&check_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstSeqV2__cgen_u27543)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, NIM_BOOL isConst_p3, NimStringV2* result_p4) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* base_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 data_1;
	NimStringV2 payload_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 T15_;
	NI T25_;
	NI T30_;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T35_;
	NI T36_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	base_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	data_1.len = 0; data_1.p = NIM_NIL;
	payload_1.len = 0; payload_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD_ = skipTypes__ast_u5379(t_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&base_1, (*colontmpD_).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	data_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_724;
	{
		NI T4_;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)0) < T4_)) goto LA5_;
		prepareAdd((&data_1), 3);
appendString((&data_1), TM__MQdRN7fpbG7rPm4JpVVAhA_726);
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i_1 = i_2;
					{
						NimStringV2 colontmpD__8;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T14_;
						if (!(((NI)0) < i_1)) goto LA12_;
						colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
						colontmpD__8 = percent___cgen_u27454(T14_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						prepareAdd((&data_1), colontmpD__8.len + 0);
appendString((&data_1), colontmpD__8);
						eqdestroy___system_u2691(colontmpD__8);
					}
LA12_: ;
					genBracedInit__cgen_u16526(p_p0, (*n_p1)._kind_6.sons.p->data[i_1], isConst_p3, base_1, (&data_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					i_2 += ((NI)1);
				} LA9: ;
			}
		}
		prepareAdd((&data_1), 1);
appendString((&data_1), TM__MQdRN7fpbG7rPm4JpVVAhA_727);
	}
LA5_: ;
	payload_1 = getTempName__cgen_u462((*p_p0).module);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_728);
	T15_.len = 0; T15_.p = NIM_NIL;
	{
		if (!isConst_p3) goto LA18_;
		colontmpD__2 = TM__MQdRN7fpbG7rPm4JpVVAhA_729;
		T15_ = colontmpD__2;
	}
	goto LA16_;
LA18_: ;
	{
		colontmpD__3 = TM__MQdRN7fpbG7rPm4JpVVAhA_730;
		T15_ = colontmpD__3;
	}
LA16_: ;
	cgFormatValue__cgen_u163((&res_1), T15_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_732);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA23_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_733);
	}
LA23_: ;
	prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_735);
	colontmpD__4 = getTypeDesc__cgen_u8738((*p_p0).module, base_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_737);
	T25_ = (NI)0;
	T25_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u166((&res_1), ((NI64) (T25_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_739);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA28_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_740);
	}
LA28_: ;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_741);
	cgFormatValue__cgen_u163((&res_1), payload_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_743);
	T30_ = (NI)0;
	T30_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u166((&res_1), ((NI64) (T30_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 18);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_745);
	cgFormatValue__cgen_u163((&res_1), data_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_747);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA33_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_748);
	}
LA33_: ;
	prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), res_1.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), res_1);
	T36_ = (NI)0;
	T36_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = rope__ropes_u15(((NI64) (T36_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T35_[0] = colontmpD__5;
	colontmpD__6 = getSeqPayloadType__cgen_u3522((*p_p0).module, t_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T35_[1] = colontmpD__6;
	T35_[2] = payload_1;
	colontmpD__7 = percent___cgen_u27635(T35_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*result_p4)), colontmpD__7.len + 0);
appendString((&(*result_p4)), colontmpD__7);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(payload_1);
		eqdestroy___system_u2691(data_1);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(base_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstSeq__cgen_u27436)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, NIM_BOOL isConst_p3, NimStringV2* result_p4) {
	NimStringV2 data_1;
	NimStringV2 colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* base_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	NimStringV2 tmpName_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
	NI T3_;
	NimStringV2 T17_;
	NI T31_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T40_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	data_1.len = 0; data_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	base_1 = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	tmpName_1.len = 0; tmpName_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
	T3_ = (NI)0;
	T3_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = rope__ropes_u15(((NI64) (T3_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = colontmpD_;
	data_1 = percent___cgen_u27442(T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = skipTypes__ast_u5379(t_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&base_1, (*colontmpD__2).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T6_;
		T6_ = (NI)0;
		T6_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)0) < T6_)) goto LA7_;
		prepareAdd((&data_1), 3);
appendString((&data_1), TM__MQdRN7fpbG7rPm4JpVVAhA_750);
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA11;
					i_1 = i_2;
					{
						NimStringV2 colontmpD__9;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T16_;
						if (!(((NI)0) < i_1)) goto LA14_;
						colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
						colontmpD__9 = percent___cgen_u27454(T16_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						prepareAdd((&data_1), colontmpD__9.len + 0);
appendString((&data_1), colontmpD__9);
						eqdestroy___system_u2691(colontmpD__9);
					}
LA14_: ;
					genBracedInit__cgen_u16526(p_p0, (*n_p1)._kind_6.sons.p->data[i_1], isConst_p3, base_1, (&data_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					i_2 += ((NI)1);
				} LA11: ;
			}
		}
		prepareAdd((&data_1), 1);
appendString((&data_1), TM__MQdRN7fpbG7rPm4JpVVAhA_751);
	}
LA7_: ;
	prepareAdd((&data_1), 1);
appendString((&data_1), TM__MQdRN7fpbG7rPm4JpVVAhA_752);
	tmpName_1 = getTempName__cgen_u462((*p_p0).module);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_753);
	T17_.len = 0; T17_.p = NIM_NIL;
	{
		if (!isConst_p3) goto LA20_;
		colontmpD__3 = TM__MQdRN7fpbG7rPm4JpVVAhA_755;
		T17_ = colontmpD__3;
	}
	goto LA18_;
LA20_: ;
	{
		colontmpD__4 = TM__MQdRN7fpbG7rPm4JpVVAhA_756;
		T17_ = colontmpD__4;
	}
LA18_: ;
	cgFormatValue__cgen_u163((&res_1), T17_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_757);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA25_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_758);
	}
LA25_: ;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_760);
	colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_761);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_763);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA29_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_764);
	}
LA29_: ;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_765);
	colontmpD__6 = getTypeDesc__cgen_u8738((*p_p0).module, base_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_766);
	T31_ = (NI)0;
	T31_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u166((&res_1), ((NI64) (T31_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_767);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA34_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_768);
	}
LA34_: ;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_769);
	cgFormatValue__cgen_u163((&res_1), tmpName_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_770);
	cgFormatValue__cgen_u163((&res_1), data_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_771);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA38_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_772);
	}
LA38_: ;
	prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), res_1.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), res_1);
	colontmpD__7 = getTypeDesc__cgen_u8738((*p_p0).module, t_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T40_[0] = colontmpD__7;
	T40_[1] = tmpName_1;
	colontmpD__8 = percent___cgen_u27538(T40_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*result_p4)), colontmpD__8.len + 0);
appendString((&(*result_p4)), colontmpD__8);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(tmpName_1);
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(base_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(data_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getClosureType__cgen_u8751)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyEnum_TClosureTypeKind__sY8uWROOfudsYU84nI5xdg kind_p2) {
	NimStringV2 result;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA check_1;
	NimStringV2 rettype_1;
	NimStringV2 desc_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)(&check_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	rettype_1.len = 0; rettype_1.p = NIM_NIL;
	desc_1.len = 0; desc_1.p = NIM_NIL;
	initIntSet__pureZcollectionsZintsets_u598((&check_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = getTempName__cgen_u462(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rettype_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_775;
	desc_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_776;
	genProcParams__cgen_u3939(m_p0, t_p1, (&rettype_1), (&desc_1), (&check_1), !((kind_p2 == ((tyEnum_TClosureTypeKind__sY8uWROOfudsYU84nI5xdg)0))), NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isImportedType__cgen_u1373(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		{
			NIM_BOOL T9_;
			NimStringV2 colontmpD_;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T13_;
			T9_ = (NIM_BOOL)0;
			T9_ = !(((*t_p1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9)));
			if (T9_) goto LA10_;
			T9_ = !((kind_p2 == ((tyEnum_TClosureTypeKind__sY8uWROOfudsYU84nI5xdg)2)));
LA10_: ;
			if (!T9_) goto LA11_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			T13_[0] = CallingConvToStr__cgen_u1465[((*t_p1).callConv)- 0];
			T13_[1] = rettype_1;
			T13_[2] = result;
			T13_[3] = desc_1;
			colontmpD_ = percent___cgen_u8050(T13_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD_);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA7_;
LA11_: ;
		{
			NimStringV2 colontmpD__2;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T15_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T15_[0] = result;
			T15_[1] = rettype_1;
			T15_[2] = desc_1;
			colontmpD__2 = percent___cgen_u8055(T15_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
		}
LA7_: ;
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(desc_1);
		eqdestroy___system_u2691(rettype_1);
		eqdestroy___pureZcollectionsZintsets_u230((&check_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isEmptyCaseObjectBranch__cgen_u27275)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
		it_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i_1 = i_2;
					eqcopy___ast_u3255(&it_1, (*n_p0)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					{
						NIM_BOOL T8_;
						NIM_BOOL T10_;
						T8_ = (NIM_BOOL)0;
						T8_ = ((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
						if (!(T8_)) goto LA9_;
						T10_ = (NIM_BOOL)0;
						T10_ = isEmptyType__ast_u7234((*(*it_1)._kind_4.sym).typ);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
						T8_ = !(T10_);
LA9_: ;
						if (!T8_) goto LA11_;
						result = NIM_FALSE;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA11_: ;
					i_2 += ((NI)1);
				} LA5: ;
			}
		}
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAux__cgen_u27283)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constOrNil_p3, NimStringV2* result_p4, NI* count_p5, NIM_BOOL isConst_p6, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p7) {
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin55_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*obj_p2).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		{
			tySequence__9ahcSjIErJohSBBFLwuF56Q colontmp_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** it_1;
			NI i_1;
			NI L_1;
			NI T4_;
			colontmp_.len = 0; colontmp_.p = NIM_NIL;
			it_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
			eqcopy___ast_u3699((&colontmp_), (*obj_p2)._kind_6.sons);
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			i_1 = ((NI)0);
			T4_ = colontmp_.len;
			L_1 = T4_;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA6;
					it_1 = &colontmp_.p->data[i_1];
					getNullValueAux__cgen_u27283(p_p0, t_p1, (*it_1), constOrNil_p3, result_p4, count_p5, isConst_p6, info_p7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					i_1 += ((NI)1);
				} LA6: ;
			}
			{
				LA3_:;
			}
			{
				oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3696(colontmp_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin3_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
	{
		NimStringV2 res_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg branch_1;
		NI selectedBranch_1;
		NI countB_1;
		res_1.len = 0; res_1.p = NIM_NIL;
		b_1 = NIM_NIL;
		getNullValueAux__cgen_u27283(p_p0, t_p1, (*obj_p2)._kind_6.sons.p->data[((NI)0)], constOrNil_p3, result_p4, count_p5, isConst_p6, info_p7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		res_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_795;
		{
			if (!(((NI)0) < (*count_p5))) goto LA13_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_796);
		}
LA13_: ;
		branch_1 = Zero__int128_u8;
		{
			if (!!((constOrNil_p3 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA17_;
			{
				NI i_2;
				NI colontmp__2;
				NI i_3;
				i_2 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_u3190(constOrNil_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				i_3 = ((NI)1);
				{
					while (1) {
						if (!(i_3 < colontmp__2)) goto LA21;
						i_2 = i_3;
						{
							if (!((*(*constOrNil_p3)._kind_6.sons.p->data[i_2]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA24_;
							{
								if (!((*(*(*(*(*constOrNil_p3)._kind_6.sons.p->data[i_2])._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).id == (*(*(*(*obj_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).id)) goto LA28_;
								branch_1 = getOrdValue__types_u167((*(*constOrNil_p3)._kind_6.sons.p->data[i_2])._kind_6.sons.p->data[((NI)1)]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
								goto LA19;
							}
LA28_: ;
						}
						goto LA22_;
LA24_: ;
						{
							if (!(i_2 == (*(*(*obj_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).position)) goto LA31_;
							branch_1 = getOrdValue__types_u167((*constOrNil_p3)._kind_6.sons.p->data[i_2]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
							goto LA19;
						}
						goto LA22_;
LA31_: ;
LA22_: ;
						i_3 += ((NI)1);
					} LA21: ;
				}
			} LA19: ;
		}
LA17_: ;
		selectedBranch_1 = caseObjDefaultBranch__expanddefaults_u4(obj_p2, branch_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_797);
		countB_1 = ((NI)0);
		b_1 = lastSon__ast_u5208((*obj_p2)._kind_6.sons.p->data[selectedBranch_1]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			NIM_BOOL T35_;
			NIM_BOOL T37_;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 T41_;
			T35_ = (NIM_BOOL)0;
			T35_ = ((*b_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138));
			if (!(T35_)) goto LA36_;
			T37_ = (NIM_BOOL)0;
			T37_ = isEmptyCaseObjectBranch__cgen_u27275(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			T35_ = !(T37_);
LA36_: ;
			if (!T35_) goto LA38_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T41_.len = 0; T41_.p = NIM_NIL;
			colontmpD_ = mangleRecFieldName__cgen_u4042((*p_p0).module, (*(*obj_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			colontmpD__2 = dollar___systemZdollars_u9(selectedBranch_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			T41_ = rawNewString(colontmpD_.len + colontmpD__2.len + 7);
appendString((&T41_), TM__MQdRN7fpbG7rPm4JpVVAhA_799);
appendString((&T41_), colontmpD_);
appendString((&T41_), TM__MQdRN7fpbG7rPm4JpVVAhA_800);
appendString((&T41_), colontmpD__2);
appendString((&T41_), TM__MQdRN7fpbG7rPm4JpVVAhA_801);
			colontmpD__3 = T41_;
			prepareAdd((&res_1), colontmpD__3.len + 0);
appendString((&res_1), colontmpD__3);
			getNullValueAux__cgen_u27283(p_p0, t_p1, b_1, constOrNil_p3, (&res_1), (&countB_1), isConst_p6, info_p7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_802);
			{
				LA40_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
		goto LA33_;
LA38_: ;
		{
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 T48_;
			if (!((*b_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA45_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T48_.len = 0; T48_.p = NIM_NIL;
			colontmpD__4 = mangleRecFieldName__cgen_u4042((*p_p0).module, (*b_1)._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
			T48_ = rawNewString(colontmpD__4.len + 4);
appendString((&T48_), TM__MQdRN7fpbG7rPm4JpVVAhA_803);
appendString((&T48_), colontmpD__4);
appendString((&T48_), TM__MQdRN7fpbG7rPm4JpVVAhA_804);
			colontmpD__5 = T48_;
			prepareAdd((&res_1), colontmpD__5.len + 0);
appendString((&res_1), colontmpD__5);
			getNullValueAux__cgen_u27283(p_p0, t_p1, b_1, constOrNil_p3, (&res_1), (&countB_1), isConst_p6, info_p7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
			{
				LA47_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
		goto LA33_;
LA45_: ;
		{
			eqdestroy___ast_u3252(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(res_1);
			goto BeforeRet_;
		}
LA33_: ;
		prepareAdd((&(*result_p4)), res_1.len + 0);
appendString((&(*result_p4)), res_1);
		prepareAdd((&(*result_p4)), 1);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_805);
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(res_1);
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		field_1 = NIM_NIL;
		{
			if (!(((NI)0) < (*count_p5))) goto LA58_;
			prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_806);
		}
LA58_: ;
		(*count_p5) += ((NI)1);
		eqcopy___ast_u4577(&field_1, (*obj_p2)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		{
			if (!!((constOrNil_p3 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA62_;
			{
				NI i_4;
				NI colontmp__3;
				NI i_5;
				i_4 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__ast_u3190(constOrNil_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				i_5 = ((NI)1);
				{
					while (1) {
						if (!(i_5 < colontmp__3)) goto LA66;
						i_4 = i_5;
						{
							if (!((*(*constOrNil_p3)._kind_6.sons.p->data[i_4]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA69_;
							{
								if (!((*(*(*(*(*constOrNil_p3)._kind_6.sons.p->data[i_4])._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).id == (*(*field_1).name).id)) goto LA73_;
								genBracedInit__cgen_u16526(p_p0, (*(*constOrNil_p3)._kind_6.sons.p->data[i_4])._kind_6.sons.p->data[((NI)1)], isConst_p6, (*field_1).typ, result_p4);
								if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
								eqdestroy___ast_u4574(field_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto BeforeRet_;
							}
LA73_: ;
						}
						goto LA67_;
LA69_: ;
						{
							if (!(i_4 == (*field_1).position)) goto LA76_;
							genBracedInit__cgen_u16526(p_p0, (*constOrNil_p3)._kind_6.sons.p->data[i_4], isConst_p6, (*field_1).typ, result_p4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
							eqdestroy___ast_u4574(field_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
						goto LA67_;
LA76_: ;
LA67_: ;
						i_5 += ((NI)1);
					} LA66: ;
				}
			}
		}
LA62_: ;
		getDefaultValue__cgen_u27230(p_p0, (*field_1).typ, info_p7, result_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		{
			LA55_:;
		}
		{
			oldNimErrFin55_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin55_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 T82_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T82_.len = 0; T82_.p = NIM_NIL;
		colontmpD__6 = dollar___renderer_u2166(obj_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		T82_ = rawNewString(colontmpD__6.len + 32);
appendString((&T82_), TM__MQdRN7fpbG7rPm4JpVVAhA_808);
appendString((&T82_), colontmpD__6);
		colontmpD__7 = T82_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, info_p7, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__7, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_809, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		{
			LA81_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getNullValueAuxT__cgen_u20082)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* orig_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constOrNil_p4, NimStringV2* result_p5, NI* count_p6, NIM_BOOL isConst_p7, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p8) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* base_1;
	NimStringV2 oldRes_1;
	NI oldcount_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	base_1 = NIM_NIL;
	oldRes_1.len = 0; oldRes_1.p = NIM_NIL;
	base_1 = baseClass__ast_u5348(t_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&oldRes_1), (*result_p5));
	oldcount_1 = (*count_p6);
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T6_;
		if (!!((base_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA4_;
		prepareAdd((&(*result_p5)), 1);
appendString((&(*result_p5)), TM__MQdRN7fpbG7rPm4JpVVAhA_793);
		T6_ = NIM_NIL;
		T6_ = skipTypes__ast_u5379(base_1, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T6_); goto LA1_;}
		eqsink___ast_u3387(&base_1, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		getNullValueAuxT__cgen_u20082(p_p0, orig_p1, base_1, (*base_1).n, constOrNil_p4, result_p5, count_p6, isConst_p7, info_p8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*result_p5)), 1);
appendString((&(*result_p5)), TM__MQdRN7fpbG7rPm4JpVVAhA_794);
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = isObjLackingTypeField__types_u2952(t_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T8_)) goto LA9_;
		{
			NimStringV2 colontmpD_;
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA13_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD_ = genTypeInfoV2__cgen_u10426((*p_p0).module, orig_p1, (*obj_p3).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&(*result_p5)), colontmpD_.len + 0);
appendString((&(*result_p5)), colontmpD_);
			{
				LA15_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA11_;
LA13_: ;
		{
			NimStringV2 colontmpD__2;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = genTypeInfoV1__cgen_u9076((*p_p0).module, orig_p1, (*obj_p3).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			prepareAdd((&(*result_p5)), colontmpD__2.len + 0);
appendString((&(*result_p5)), colontmpD__2);
			{
				LA19_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA11_: ;
		(*count_p6) += ((NI)1);
	}
	goto LA2_;
LA9_: ;
LA2_: ;
	getNullValueAux__cgen_u27283(p_p0, t_p2, obj_p3, constOrNil_p4, result_p5, count_p6, isConst_p7, info_p8);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(oldcount_1 == (*count_p6))) goto LA24_;
		eqsink___system_u2700((&(*result_p5)), oldRes_1);
		eqwasMoved___system_u2688((&oldRes_1));
	}
LA24_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(oldRes_1);
		eqdestroy___ast_u3378(base_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isEmptyTupleType__ast_u5666)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NI T1_;
	T1_ = (*t_p0).sons.len;
	result = (T1_ == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getDefaultValue__cgen_u27230)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, NimStringV2* result_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL oldNimErrFin48_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379(typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_778);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*t_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		prepareAdd((&(*result_p3)), 9);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_780);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_781);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	{
		prepareAdd((&(*result_p3)), 3);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_783);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)6):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	{
		prepareAdd((&(*result_p3)), 7);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_785);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		{
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA9_;
			prepareAdd((&(*result_p3)), 12);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_787);
		}
		goto LA7_;
LA9_: ;
		{
			prepareAdd((&(*result_p3)), 7);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_788);
		}
LA7_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		{
			if (!!(((*t_1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9)))) goto LA15_;
			prepareAdd((&(*result_p3)), 7);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_789);
		}
		goto LA13_;
LA15_: ;
		{
			prepareAdd((&(*result_p3)), 18);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_791);
		}
LA13_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		NI count_1;
		count_1 = ((NI)0);
		prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_792);
		getNullValueAuxT__cgen_u20082(p_p0, t_1, t_1, (*t_1).n, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL), result_p3, (&count_1), NIM_TRUE, info_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_810);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_811);
		{
			NIM_BOOL T22_;
			NIM_BOOL T23_;
			T22_ = (NIM_BOOL)0;
			T23_ = (NIM_BOOL)0;
			T23_ = ((*(*(*(*p_p0).module).g).config).cCompiler == ((tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA)6));
			if (!(T23_)) goto LA24_;
			T23_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1));
LA24_: ;
			T22_ = T23_;
			if (!(T22_)) goto LA25_;
			T22_ = isEmptyTupleType__ast_u5666(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA25_: ;
			if (!T22_) goto LA26_;
			prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_812);
		}
LA26_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_1;
			NI i_1;
			a_1 = NIM_NIL;
			i_1 = (NI)0;
			{
				NI i_2;
				NI colontmp_;
				NI T31_;
				NI i_3;
				i_2 = (NI)0;
				colontmp_ = (NI)0;
				T31_ = (*t_1).sons.len;
				colontmp_ = T31_;
				i_3 = ((NI)0);
				{
					while (1) {
						if (!(i_3 < colontmp_)) goto LA33;
						i_2 = i_3;
						i_1 = i_2;
						eqcopy___ast_u3381(&a_1, (*t_1).sons.p->data[i_2]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						{
							{
								NIM_BOOL T37_;
								T37_ = (NIM_BOOL)0;
								T37_ = isEmptyType__ast_u7234(a_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
								if (!T37_) goto LA38_;
								goto LA34;
							}
LA38_: ;
							{
								if (!(((NI)0) < i_1)) goto LA42_;
								prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_813);
							}
LA42_: ;
							getDefaultValue__cgen_u27230(p_p0, a_1, info_p2, result_p3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						} LA34: ;
						i_3 += ((NI)1);
					} LA33: ;
				}
			}
			{
				LA29_:;
			}
			{
				oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin29_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_814);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_815);
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			NI i_4;
			NI colontmp__2;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T49_;
			NI i_5;
			colontmpD_ = NIM_NIL;
			i_4 = (NI)0;
			colontmp__2 = (NI)0;
			colontmpD_ = indexType__ast_u5345(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			T49_ = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			colontmp__2 = toInt__int128_u257(T49_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			i_5 = ((NI)0);
			{
				while (1) {
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
					if (!(i_5 < colontmp__2)) goto LA51;
					colontmpD__2 = NIM_NIL;
					i_4 = i_5;
					{
						if (!(((NI)0) < i_4)) goto LA55_;
						prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_816);
					}
LA55_: ;
					colontmpD__2 = elementType__ast_u5331(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					getDefaultValue__cgen_u27230(p_p0, colontmpD__2, info_p2, result_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					i_5 += ((NI)1);
					{
						LA52_:;
					}
					{
						oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
						*nimErr_ = oldNimErrFin52_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				} LA51: ;
			}
			{
				LA48_:;
			}
			{
				oldNimErrFin48_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin48_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_817);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		prepareAdd((&(*result_p3)), 12);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_819);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		{
			tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T65_;
			T65_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
			T65_ = mapSetType__cgen_u1311((*(*(*p_p0).module).g).config, t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T65_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17))) goto LA66_;
			prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_820);
		}
		goto LA63_;
LA66_: ;
		{
			prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_821);
		}
LA63_: ;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T71_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T71_.len = 0; T71_.p = NIM_NIL;
		colontmpD__3 = dollar___ast_u182((*t_1).kind);
		T71_ = rawNewString(colontmpD__3.len + 32);
appendString((&T71_), TM__MQdRN7fpbG7rPm4JpVVAhA_822);
appendString((&T71_), colontmpD__3);
		colontmpD__4 = T71_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, info_p2, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__4, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__MQdRN7fpbG7rPm4JpVVAhA_823, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
		{
			LA70_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstSimpleList__cgen_u27385)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, NimStringV2* result_p3) {
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin18_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_777);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI T8_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*(*(*p_p0).module).g).config).cCompiler == ((tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA)6));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1));
LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T8_ = (NI)0;
		T8_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (T8_ == ((NI)0));
LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA9_;
		T3_ = ((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16));
LA9_: ;
		if (!T3_) goto LA10_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = elementType__ast_u5331((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		getDefaultValue__cgen_u27230(p_p0, colontmpD_, (*n_p1).info, result_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA10_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA17;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				{
					if (!(((NI)0) < i_1)) goto LA21_;
					prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_824);
				}
LA21_: ;
				{
					if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA25_;
					genBracedInit__cgen_u16526(p_p0, (*it_1)._kind_6.sons.p->data[((NI)1)], isConst_p2, (*(*it_1)._kind_6.sons.p->data[((NI)0)]).typField, result_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				}
				goto LA23_;
LA25_: ;
				{
					genBracedInit__cgen_u16526(p_p0, it_1, isConst_p2, (*it_1).typField, result_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				}
LA23_: ;
				i_2 += ((NI)1);
				{
					LA18_:;
				}
				{
					oldNimErrFin18_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin18_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA17: ;
		}
	}
	prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_825);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstTuple__cgen_u27412)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tup_p3, NimStringV2* result_p4) {
NIM_BOOL oldNimErrFin14_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	prepareAdd((&(*result_p4)), 1);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_826);
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T7_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*(*(*p_p0).module).g).config).cCompiler == ((tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA)6));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)1));
LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NI)0;
		T7_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (T7_ == ((NI)0));
LA6_: ;
		if (!T3_) goto LA8_;
		prepareAdd((&(*result_p4)), 1);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_827);
	}
LA8_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA12;
				i_1 = i_2;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
					it_1 = NIM_NIL;
					{
						NIM_BOOL T17_;
						T17_ = (NIM_BOOL)0;
						T17_ = isEmptyType__ast_u7234((*tup_p3).sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						if (!T17_) goto LA18_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto LA13;
					}
LA18_: ;
					eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					{
						if (!(((NI)0) < i_1)) goto LA22_;
						prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_828);
					}
LA22_: ;
					{
						if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA26_;
						genBracedInit__cgen_u16526(p_p0, (*it_1)._kind_6.sons.p->data[((NI)1)], isConst_p2, (*tup_p3).sons.p->data[i_1], result_p4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					}
					goto LA24_;
LA26_: ;
					{
						genBracedInit__cgen_u16526(p_p0, it_1, isConst_p2, (*tup_p3).sons.p->data[i_1], result_p4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					}
LA24_: ;
					{
						LA14_:;
					}
					{
						oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin14_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA13: ;
				i_2 += ((NI)1);
			} LA12: ;
		}
	}
	prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_829);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstObjConstr__cgen_u27374)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, NimStringV2* result_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	NI count_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	count_1 = ((NI)0);
	prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_843);
	{
		if (!((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17))) goto LA4_;
		getNullValueAuxT__cgen_u20082(p_p0, t_1, t_1, (*t_1).n, n_p1, result_p3, (&count_1), isConst_p2, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_844);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringLiteralV2Const__cgen_u682)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, NimStringV2* result_p3) {
	NimStringV2 pureLit_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NI id_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	pureLit_1.len = 0; pureLit_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	id_1 = nodeTableTestOrSet__treetab_u225((&(*m_p0).dataCache), n_p1, (*m_p0).labels);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(id_1 == (*m_p0).labels)) goto LA4_;
		pureLit_1 = getTempName__cgen_u462(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_845);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_846);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		genStringLiteralDataOnlyV2__cgen_u654(m_p0, (*n_p1)._kind_3.strVal, pureLit_1, isConst_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 T7_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T7_.len = 0; T7_.p = NIM_NIL;
		colontmpD__3 = rope__ropes_u15(((NI64) (id_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = rawNewString((*m_p0).tmpBase.len + colontmpD__3.len + 0);
appendString((&T7_), (*m_p0).tmpBase);
appendString((&T7_), colontmpD__3);
		pureLit_1 = T7_;
		eqdestroy___system_u2691(colontmpD__3);
	}
LA2_: ;
	colontmpD_ = rope__ropes_u15(((NI64) ((*n_p1)._kind_3.strVal.len)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_[0] = colontmpD_;
	T8_[1] = pureLit_1;
	colontmpD__2 = percent___cgen_u689(T8_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*result_p3)), colontmpD__2.len + 0);
appendString((&(*result_p3)), colontmpD__2);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(pureLit_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBracedInit__cgen_u16526)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConst_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* optionalType_p3, NimStringV2* result_p4) {
NIM_BOOL oldNimErrFin41_;
NIM_BOOL oldNimErrFin47_;
NIM_BOOL oldNimErrFin54_;
NIM_BOOL oldNimErrFin83_;
NIM_BOOL oldNimErrFin88_;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59):
	{
		genBracedInit__cgen_u16526(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], isConst_p2, (*n_p1).typField, result_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
		tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg ty_1;
		typ_1 = NIM_NIL;
		ty_1 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0);
		typ_1 = ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL);
		{
			if (!(optionalType_p3 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA6_;
			{
				if (!((*n_p1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*n_p1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA10_;
				ty_1 = ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28);
			}
			goto LA8_;
LA10_: ;
			{
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_709, TM__MQdRN7fpbG7rPm4JpVVAhA_710);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			}
LA8_: ;
		}
		goto LA4_;
LA6_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T14_;
			T14_ = NIM_NIL;
			T14_ = skipTypes__ast_u5379(optionalType_p3, TM__MQdRN7fpbG7rPm4JpVVAhA_382);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T14_); goto LA3_;}
			eqsink___ast_u3387(&typ_1, T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			ty_1 = (*typ_1).kind;
		}
LA4_: ;
		switch (ty_1) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
		{
			tySequence__6H5Oh5UUvVCLiakt9aTwtUQ cs_1;
			NI64 T17_;
			cs_1.len = 0; cs_1.p = NIM_NIL;
			cs_1 = toBitSet__nimsets_u73((*(*(*p_p0).module).g).config, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			T17_ = (NI64)0;
			T17_ = getSize__types_u3397((*(*(*p_p0).module).g).config, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			genRawSetData__cgen_u20229(cs_1, ((NI) (T17_)), result_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			{
				LA16_:;
			}
			{
				eqdestroy___pureZtimes_u2620(cs_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
		{
			{
				if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA23_;
				genConstSeqV2__cgen_u27543(p_p0, n_p1, typ_1, isConst_p2, result_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			}
			goto LA21_;
LA23_: ;
			{
				genConstSeq__cgen_u27436(p_p0, n_p1, typ_1, isConst_p2, result_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			}
LA21_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
		{
			{
				NIM_BOOL T29_;
				NIM_BOOL T30_;
				NI T32_;
				T29_ = (NIM_BOOL)0;
				T30_ = (NIM_BOOL)0;
				T30_ = ((*typ_1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
				if (!(T30_)) goto LA31_;
				T32_ = (NI)0;
				T32_ = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				T30_ = (((NI)1) < T32_);
LA31_: ;
				T29_ = T30_;
				if (!(T29_)) goto LA33_;
				T29_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA33_: ;
				if (!T29_) goto LA34_;
				{
					if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA38_;
					prepareAdd((&(*result_p4)), 17);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_774);
				}
				goto LA36_;
LA38_: ;
				{
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_1;
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					NimStringV2 colontmpD__3;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T42_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T43_;
					nimZeroMem((void*)(&d_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					T42_ = 0;
					initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T42_, (&d_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					colontmpD_ = getClosureType__cgen_u8751((*p_p0).module, typ_1, ((tyEnum_TClosureTypeKind__sY8uWROOfudsYU84nI5xdg)1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					T43_[0] = colontmpD_;
					colontmpD__2 = rdLoc__cgen_u470(d_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					T43_[1] = colontmpD__2;
					colontmpD__3 = percent___cgen_u27678(T43_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					prepareAdd((&(*result_p4)), colontmpD__3.len + 0);
appendString((&(*result_p4)), colontmpD__3);
					{
						LA41_:;
					}
					{
						oldNimErrFin41_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___ast_u6284(d_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						*nimErr_ = oldNimErrFin41_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				}
LA36_: ;
			}
			goto LA27_;
LA34_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_2;
				NimStringV2 colontmpD__4;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T48_;
				nimZeroMem((void*)(&d_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				T48_ = 0;
				initLocExpr__cgen_u14111(p_p0, n_p1, T48_, (&d_2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
				colontmpD__4 = rdLoc__cgen_u470(d_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
				prepareAdd((&(*result_p4)), colontmpD__4.len + 0);
appendString((&(*result_p4)), colontmpD__4);
				{
					LA47_:;
				}
				{
					oldNimErrFin47_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___ast_u6284(d_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					*nimErr_ = oldNimErrFin47_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			}
LA27_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
		{
			genConstSimpleList__cgen_u27385(p_p0, n_p1, isConst_p2, result_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
		{
			genConstTuple__cgen_u27412(p_p0, n_p1, isConst_p2, typ_1, result_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
		{
			NimStringV2 data_1;
			NimStringV2 payload_1;
			NimStringV2 ctype_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
			NimStringV2 res_1;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NI arrLen_1;
			NimStringV2 T59_;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T69_;
			data_1.len = 0; data_1.p = NIM_NIL;
			payload_1.len = 0; payload_1.p = NIM_NIL;
			ctype_1.len = 0; ctype_1.p = NIM_NIL;
			colontmpD__5 = NIM_NIL;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			{
				if (!!(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41)))) goto LA57_;
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_831, TM__MQdRN7fpbG7rPm4JpVVAhA_832);
				if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			}
LA57_: ;
			data_1 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			genConstSimpleList__cgen_u27385(p_p0, n_p1, isConst_p2, (&data_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			payload_1 = getTempName__cgen_u462((*p_p0).module);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			colontmpD__5 = elementType__ast_u5331(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			ctype_1 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__5, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			arrLen_1 = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_833);
			T59_.len = 0; T59_.p = NIM_NIL;
			{
				if (!isConst_p2) goto LA62_;
				colontmpD__6 = TM__MQdRN7fpbG7rPm4JpVVAhA_834;
				T59_ = colontmpD__6;
			}
			goto LA60_;
LA62_: ;
			{
				colontmpD__7 = TM__MQdRN7fpbG7rPm4JpVVAhA_835;
				T59_ = colontmpD__7;
			}
LA60_: ;
			cgFormatValue__cgen_u163((&res_1), T59_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_836);
			cgFormatValue__cgen_u163((&res_1), ctype_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_837);
			cgFormatValue__cgen_u163((&res_1), payload_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_838);
			cgFormatValue__cgen_u166((&res_1), ((NI64) (arrLen_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_840);
			cgFormatValue__cgen_u163((&res_1), data_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_841);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA67_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_842);
			}
LA67_: ;
			prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), res_1.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), res_1);
			T69_[0] = ctype_1;
			T69_[1] = payload_1;
			colontmpD__8 = rope__ropes_u15(((NI64) (arrLen_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			T69_[2] = colontmpD__8;
			colontmpD__9 = percent___cgen_u27758(T69_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			prepareAdd((&(*result_p4)), colontmpD__9.len + 0);
appendString((&(*result_p4)), colontmpD__9);
			{
				LA54_:;
			}
			{
				oldNimErrFin54_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(res_1);
				eqdestroy___ast_u3378(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				eqdestroy___system_u2691(ctype_1);
				eqdestroy___system_u2691(payload_1);
				eqdestroy___system_u2691(data_1);
				*nimErr_ = oldNimErrFin54_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
		{
			genConstObjConstr__cgen_u27374(p_p0, n_p1, isConst_p2, result_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
		{
			{
				NIM_BOOL T76_;
				NIM_BOOL T77_;
				T76_ = (NIM_BOOL)0;
				T77_ = (NIM_BOOL)0;
				T77_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
				if (!(T77_)) goto LA78_;
				T77_ = !(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23)));
LA78_: ;
				T76_ = T77_;
				if (!(T76_)) goto LA79_;
				T76_ = (ty_1 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28));
LA79_: ;
				if (!T76_) goto LA80_;
				genStringLiteralV2Const__cgen_u682((*p_p0).module, n_p1, isConst_p2, result_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			}
			goto LA74_;
LA80_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_3;
				NimStringV2 colontmpD__10;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T84_;
				nimZeroMem((void*)(&d_3), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				T84_ = 0;
				initLocExpr__cgen_u14111(p_p0, n_p1, T84_, (&d_3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				colontmpD__10 = rdLoc__cgen_u470(d_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				prepareAdd((&(*result_p4)), colontmpD__10.len + 0);
appendString((&(*result_p4)), colontmpD__10);
				{
					LA83_:;
				}
				{
					oldNimErrFin83_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__10);
					eqdestroy___ast_u6284(d_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					*nimErr_ = oldNimErrFin83_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			}
LA74_: ;
		}
		break;
		default:
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_4;
			NimStringV2 colontmpD__11;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T89_;
			nimZeroMem((void*)(&d_4), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			T89_ = 0;
			initLocExpr__cgen_u14111(p_p0, n_p1, T89_, (&d_4));
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			colontmpD__11 = rdLoc__cgen_u470(d_4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			prepareAdd((&(*result_p4)), colontmpD__11.len + 0);
appendString((&(*result_p4)), colontmpD__11);
			{
				LA88_:;
			}
			{
				oldNimErrFin88_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___ast_u6284(d_4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				*nimErr_ = oldNimErrFin88_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		break;
		}
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rawConstExpr__cgen_u12894)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NI id_1;
	NimStringV2 T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	eqcopy___ast_u3381(&t_1, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	id_1 = nodeTableTestOrSet__treetab_u225((&(*(*p_p0).module).dataCache), n_p1, (*(*p_p0).module).labels);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD__2 = rope__ropes_u15(((NI64) (id_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString((*(*p_p0).module).tmpBase.len + colontmpD__2.len + 0);
appendString((&T2_), (*(*p_p0).module).tmpBase);
appendString((&T2_), colontmpD__2);
	colontmpD__3 = T2_;
	fillLoc__cgen_u78(d_p2, ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)8), n_p1, colontmpD__3, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 data_1;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T9_;
		if (!(id_1 == (*(*p_p0).module).labels)) goto LA5_;
		data_1.len = 0; data_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		(*(*p_p0).module).labels += ((NI)1);
		colontmpD__4 = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_[0] = colontmpD__4;
		T8_[1] = (*d_p2).snippet;
		data_1 = percent___cgen_u20252(T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		genBracedInit__cgen_u16526(p_p0, n_p1, NIM_TRUE, t_1, (&data_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__5 = percent___cgen_u20257(T9_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&data_1), colontmpD__5.len + 0);
appendString((&data_1), colontmpD__5);
		prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), data_1.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), data_1);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(data_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGenericAsgn__cgen_u20436)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin46_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2* T6_;
		NimStringV2* T7_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA4_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T6_ = (NimStringV2*)0;
		T6_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = (NimStringV2*)0;
		T7_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_1 = rawNewString(((NI)80));
		colontmpD__3 = rdLoc__cgen_u470(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_859);
		colontmpD__4 = rdLoc__cgen_u470(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_860);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA10_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_861);
		}
LA10_: ;
		prepareAdd((&(*T7_)), res_1.len + 0);
appendString((&(*T7_)), res_1);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(res_1);
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = !(((flags_p3 &((NU8)1<<((NU)((((tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w)0)))&7U)))!=0));
		if (T13_) goto LA14_;
		colontmpD_ = t__cgen_u97(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__2 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T13_ = (((*colontmpD__2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)6)))&63U)))!=0);
LA14_: ;
		if (!T13_) goto LA15_;
		{
			NIM_BOOL T19_;
			NIM_BOOL T20_;
			NIM_BOOL T23_;
			NimStringV2 res_2;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2* T27_;
			NimStringV2* T28_;
			T19_ = (NIM_BOOL)0;
			T20_ = (NIM_BOOL)0;
			T20_ = (dest_p1.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2));
			if (!(T20_)) goto LA21_;
			T20_ = !(((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10)));
LA21_: ;
			T19_ = T20_;
			if (T19_) goto LA22_;
			T23_ = (NIM_BOOL)0;
			T23_ = usesWriteBarrier__options_u3582((*(*(*p_p0).module).g).config);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T19_ = !(T23_);
LA22_: ;
			if (!T19_) goto LA24_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T27_ = (NimStringV2*)0;
			T27_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			addIndent__cgen_u315(p_p0, T27_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			T28_ = (NimStringV2*)0;
			T28_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			res_2 = rawNewString(((NI)80));
			colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_862);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_863);
			colontmpD__6 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			prepareAdd((&res_2), 19);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_865);
			colontmpD__7 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_866);
			colontmpD__8 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_867);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA31_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_868);
			}
LA31_: ;
			prepareAdd((&(*T28_)), res_2.len + 0);
appendString((&(*T28_)), res_2);
			{
				LA26_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA17_;
LA24_: ;
		{
			NimStringV2 res_3;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2* T37_;
			NimStringV2* T38_;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12 = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			T37_ = (NimStringV2*)0;
			T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			addIndent__cgen_u315(p_p0, T37_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			T38_ = (NimStringV2*)0;
			T38_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			res_3 = rawNewString(((NI)80));
			colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_870);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_871);
			colontmpD__10 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_873);
			colontmpD__11 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_874);
			colontmpD__12 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			colontmpD__13 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__12, (*dest_p1.lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_875);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA41_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_876);
			}
LA41_: ;
			prepareAdd((&(*T38_)), res_3.len + 0);
appendString((&(*T38_)), res_3);
			{
				LA36_:;
			}
			{
				oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___ast_u3378(colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(res_3);
				*nimErr_ = oldNimErrFin36_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA17_: ;
	}
	goto LA2_;
LA15_: ;
	{
		NimStringV2 res_4;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__17;
		NimStringV2 colontmpD__18;
		NimStringV2* T47_;
		NimStringV2* T48_;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__17 = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		T47_ = (NimStringV2*)0;
		T47_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		addIndent__cgen_u315(p_p0, T47_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		T48_ = (NimStringV2*)0;
		T48_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		res_4 = rawNewString(((NI)80));
		colontmpD__14 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_878);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		prepareAdd((&res_4), 8);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_879);
		colontmpD__15 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		prepareAdd((&res_4), 9);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_880);
		colontmpD__16 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__16);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_881);
		colontmpD__17 = t__cgen_u97(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		colontmpD__18 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__17, (*dest_p1.lode).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__18);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_882);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA51_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_883);
		}
LA51_: ;
		prepareAdd((&(*T48_)), res_4.len + 0);
appendString((&(*T48_)), res_4);
		{
			LA46_:;
		}
		{
			oldNimErrFin46_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___ast_u3378(colontmpD__17);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(res_4);
			*nimErr_ = oldNimErrFin46_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canMove__cgen_u20278)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p2) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA3_;
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			NI T10_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = isDeepConstExpr__trees_u153(n_p1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T7_ = !(T8_);
			if (T7_) goto LA9_;
			T10_ = (NI)0;
			T10_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T7_ = (T10_ == ((NI)0));
LA9_: ;
			if (!T7_) goto LA11_;
			colontmpD_ = NIM_NIL;
			{
				colontmpD_ = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24))) goto LA16_;
				result = NIM_TRUE;
				eqdestroy___ast_u3378(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
LA16_: ;
			{
				LA13_:;
			}
			{
				oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin13_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA11_: ;
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = ((*n_p1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*n_p1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22));
		if (!(T21_)) goto LA22_;
		T21_ = ((*n_p1)._kind_3.strVal.len == ((NI)0));
LA22_: ;
		if (!T21_) goto LA23_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA1_;
LA23_: ;
LA1_: ;
	result = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, optAsgnLoc__cgen_u20366)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2 field_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
	NimStringV2 colontmpD_;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T1_;
	NimStringV2 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T1_.k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)5);
	T1_.storage = a_p0.storage;
	T1_.lode = lodeTyp__cgen_u104(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = rdLoc__cgen_u470(a_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = rawNewString(colontmpD_.len + field_p2.len + 1);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_920);
appendString((&T2_), field_p2);
	T1_.snippet = T2_;
	(*Result) = T1_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
static N_INLINE(NI, kidsLen__ast_u5648)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NI result;
	NI T1_;
	T1_ = (*t_p0).sons.len;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnTuple__cgen_u20374)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3) {
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w colontmpD__3;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w colontmpD__4;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w newflags_1;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&colontmpD_), sizeof(tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w));
	colontmpD__2 = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__3), sizeof(tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w));
	nimZeroMem((void*)(&colontmpD__4), sizeof(tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w));
	t_1 = NIM_NIL;
	colontmpD__5 = NIM_NIL;
	{
		if (!(src_p2.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1))) goto LA4_;
		colontmpD_ = (flags_p3 | 1);
		newflags_1 = colontmpD_;
	}
	goto LA2_;
LA4_: ;
	{
		colontmpD__2 = t__cgen_u97(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((*colontmpD__2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)6)))&63U)))!=0)) goto LA7_;
		colontmpD__3 = (flags_p3 & ~ 1);
		newflags_1 = colontmpD__3;
	}
	goto LA2_;
LA7_: ;
	{
		colontmpD__4 = flags_p3;
		newflags_1 = colontmpD__4;
	}
LA2_: ;
	colontmpD__5 = t__cgen_u97(dest_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379(colontmpD__5, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
		NI i_1;
		t_2 = NIM_NIL;
		i_1 = (NI)0;
		{
			NI i_2;
			NI colontmp_;
			NI T13_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			T13_ = (*t_1).sons.len;
			colontmp_ = T13_;
			i_3 = ((NI)0);
			{
				while (1) {
					if (!(i_3 < colontmp_)) goto LA15;
					i_2 = i_3;
					i_1 = i_2;
					eqcopy___ast_u3381(&t_2, (*t_1).sons.p->data[i_2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					{
						NimStringV2 field_1;
						NimStringV2 colontmpD__6;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__7;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__8;
						tyArray__YgExxhfgKcesA5EOUj1MOA T23_;
						field_1.len = 0; field_1.p = NIM_NIL;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						nimZeroMem((void*)(&colontmpD__7), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						nimZeroMem((void*)(&colontmpD__8), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						{
							NIM_BOOL T20_;
							T20_ = (NIM_BOOL)0;
							T20_ = isEmptyType__ast_u7234(t_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
							if (!T20_) goto LA21_;
							eqdestroy___ast_u6284(colontmpD__8);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
							eqdestroy___ast_u6284(colontmpD__7);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
							eqdestroy___system_u2691(colontmpD__6);
							eqdestroy___system_u2691(field_1);
							goto LA16;
						}
LA21_: ;
						colontmpD__6 = rope__ropes_u15(((NI64) (i_1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						T23_[0] = colontmpD__6;
						field_1 = percent___cgen_u20400(T23_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						optAsgnLoc__cgen_u20366(dest_p1, t_2, field_1, (&colontmpD__7));
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						optAsgnLoc__cgen_u20366(src_p2, t_2, field_1, (&colontmpD__8));
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						genAssignment__cgen_u12898(p_p0, colontmpD__7, colontmpD__8, newflags_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
						{
							LA17_:;
						}
						{
							oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u6284(colontmpD__8);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
							eqdestroy___ast_u6284(colontmpD__7);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
							eqdestroy___system_u2691(colontmpD__6);
							eqdestroy___system_u2691(field_1);
							*nimErr_ = oldNimErrFin17_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					} LA16: ;
					i_3 += ((NI)1);
				} LA15: ;
			}
		}
		{
			LA11_:;
		}
		{
			oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(t_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin11_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, asgnComplexity__cgen_u20354)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!((n_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA3_;
		switch ((*n_p0).kind) {
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
		{
			result = ((NI)1);
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
		{
			result = ((NI)100);
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
		{
			result = ((NI)0);
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_1;
				t_1 = NIM_NIL;
				{
					NI i_1;
					NI colontmp_;
					NI i_2;
					i_1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_u3197(n_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 = ((NI)0);
					{
						while (1) {
							NI T12_;
							if (!(i_2 < colontmp_)) goto LA11;
							i_1 = i_2;
							eqcopy___ast_u3255(&t_1, (*n_p0)._kind_6.sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							T12_ = (NI)0;
							T12_ = asgnComplexity__cgen_u20354(t_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							result += T12_;
							i_2 += ((NI)1);
						} LA11: ;
					}
				}
				eqdestroy___ast_u3252(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
		}
		break;
		default:
		{
			result = ((NI)0);
		}
		break;
		}
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NI)0);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOptAsgnObject__cgen_u20406)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p4, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p5) {
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w colontmpD__3;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w colontmpD__4;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w newflags_1;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin26_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&colontmpD_), sizeof(tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w));
	colontmpD__2 = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__3), sizeof(tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w));
	nimZeroMem((void*)(&colontmpD__4), sizeof(tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w));
	{
		if (!(t_p4 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	{
		if (!(src_p2.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1))) goto LA8_;
		colontmpD_ = (flags_p3 | 1);
		newflags_1 = colontmpD_;
	}
	goto LA6_;
LA8_: ;
	{
		colontmpD__2 = t__cgen_u97(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((*colontmpD__2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)6)))&63U)))!=0)) goto LA11_;
		colontmpD__3 = (flags_p3 & ~ 1);
		newflags_1 = colontmpD__3;
	}
	goto LA6_;
LA11_: ;
	{
		colontmpD__4 = flags_p3;
		newflags_1 = colontmpD__4;
	}
LA6_: ;
	switch ((*t_p4).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__5;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__6;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T20_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T21_;
		field_1 = NIM_NIL;
		nimZeroMem((void*)(&colontmpD__5), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&colontmpD__6), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		eqcopy___ast_u4577(&field_1, (*t_p4)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			if (!((*field_1).loc.snippet.len == 0)) goto LA18_;
			fillObjectFields__cgen_u5401((*p_p0).module, typ_p5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		}
LA18_: ;
		nimZeroMem((void*)(&T20_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		optAsgnLoc__cgen_u20366(dest_p1, (*field_1).typ, (*field_1).loc.snippet, (&T20_));
		colontmpD__5 = T20_;
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		nimZeroMem((void*)(&T21_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		optAsgnLoc__cgen_u20366(src_p2, (*field_1).typ, (*field_1).loc.snippet, (&T21_));
		colontmpD__6 = T21_;
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		genAssignment__cgen_u12898(p_p0, colontmpD__5, colontmpD__6, newflags_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6284(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* child_1;
			child_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(t_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA29;
						i_1 = i_2;
						eqcopy___ast_u3255(&child_1, (*t_p4)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						genOptAsgnObject__cgen_u20406(p_p0, dest_p1, src_p2, newflags_1, child_1, typ_p5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						i_2 += ((NI)1);
					} LA29: ;
				}
			}
			{
				LA26_:;
			}
			{
				oldNimErrFin26_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(child_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin26_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
	break;
	default:
	{
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, reifiedOpenArray__cgen_u14410)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	x_1 = NIM_NIL;
	eqcopy___ast_u3255(&x_1, n_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			switch ((*x_1).kind) {
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
			{
				eqcopy___ast_u3255(&x_1, (*x_1)._kind_6.sons.p->data[((NI)0)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
			{
				eqcopy___ast_u3255(&x_1, (*x_1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			default:
			{
				goto LA2;
			}
			break;
			}
		}
	} LA2: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = ((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T9_)) goto LA10_;
		T9_ = ((*(*x_1)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3));
LA10_: ;
		if (!T9_) goto LA11_;
		result = NIM_FALSE;
	}
	goto LA7_;
LA11_: ;
	{
		result = NIM_TRUE;
	}
LA7_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dataFieldAccessor__cgen_u508)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 sym_p1) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	{
		NimStringV2 T5_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA3_;
		T5_.len = 0; T5_.p = NIM_NIL;
		T5_ = rawNewString(sym_p1.len + 4);
appendString((&T5_), TM__MQdRN7fpbG7rPm4JpVVAhA_974);
appendString((&T5_), sym_p1);
appendString((&T5_), TM__MQdRN7fpbG7rPm4JpVVAhA_976);
		result = T5_;
	}
	goto LA1_;
LA3_: ;
	{
		eqcopy___system_u2694((&result), sym_p1);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, byRefLoc__cgen_u12841)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__2;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__3;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	colontmpD__3 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T7_;
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T13_;
		NIM_BOOL T15_;
		NimStringV2 T19_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((a_p1.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0)))&15U)))!=0));
		if (!(T5_)) goto LA6_;
		colontmpD_ = t__cgen_u97(a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			if (!((*a_p1.lode).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA10_;
			colontmpD__2 = (*(*a_p1.lode)._kind_4.sym).kind;
			T7_ = colontmpD__2;
		}
		goto LA8_;
LA10_: ;
		{
			colontmpD__3 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
			T7_ = colontmpD__3;
		}
LA8_: ;
		T13_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		T13_ = mapType__cgen_u1315((*(*(*p_p0).module).g).config, colontmpD_, (T7_ == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T5_ = !((T13_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17)));
LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA14_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T15_) goto LA16_;
		T15_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA16_: ;
		T4_ = !(T15_);
LA14_: ;
		if (!T4_) goto LA17_;
		T19_.len = 0; T19_.p = NIM_NIL;
		T19_ = rawNewString(a_p1.snippet.len + 3);
appendString((&T19_), TM__MQdRN7fpbG7rPm4JpVVAhA_992);
appendString((&T19_), a_p1.snippet);
appendString((&T19_), TM__MQdRN7fpbG7rPm4JpVVAhA_993);
		result = T19_;
	}
	goto LA2_;
LA17_: ;
	{
		eqcopy___system_u2694((&result), a_p1.snippet);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayConv__cgen_u20514)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin49_;
NIM_BOOL oldNimErrFin60_;
NIM_BOOL oldNimErrFin85_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD_ = t__cgen_u97(a_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*colontmpD__2).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		{
			NIM_BOOL T5_;
			T5_ = (NIM_BOOL)0;
			T5_ = reifiedOpenArray__cgen_u14410(a_p2.lode);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T5_) goto LA6_;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
				NimStringV2 res_1;
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				NimStringV2 res_2;
				NimStringV2 colontmpD__6;
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2 colontmpD__9;
				NimStringV2* T13_;
				NimStringV2* T14_;
				NimStringV2* T19_;
				NimStringV2* T20_;
				if (!((flags_p3 &((NU8)1<<((NU)((((tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w)2)))&7U)))!=0)) goto LA10_;
				nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__3 = NIM_NIL;
				res_1.len = 0; res_1.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				res_2.len = 0; res_2.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__3 = t__cgen_u97(a_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				getTemp__cgen_u9546(p_p0, colontmpD__3, NIM_FALSE, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				T13_ = (NimStringV2*)0;
				T13_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				addIndent__cgen_u315(p_p0, T13_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				T14_ = (NimStringV2*)0;
				T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				res_1 = rawNewString(((NI)80));
				colontmpD__4 = rdLoc__cgen_u470(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_949);
				colontmpD__5 = rdLoc__cgen_u470(a_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_950);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA17_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_951);
				}
LA17_: ;
				prepareAdd((&(*T14_)), res_1.len + 0);
appendString((&(*T14_)), res_1);
				T19_ = (NimStringV2*)0;
				T19_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				addIndent__cgen_u315(p_p0, T19_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				T20_ = (NimStringV2*)0;
				T20_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				res_2 = rawNewString(((NI)80));
				colontmpD__6 = rdLoc__cgen_u470(d_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_953);
				colontmpD__7 = rdLoc__cgen_u470(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_955);
				colontmpD__8 = rdLoc__cgen_u470(d_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_957);
				colontmpD__9 = rdLoc__cgen_u470(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_959);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA23_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_960);
				}
LA23_: ;
				prepareAdd((&(*T20_)), res_2.len + 0);
appendString((&(*T20_)), res_2);
				{
					LA12_:;
				}
				{
					oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(res_2);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(res_1);
					eqdestroy___ast_u3378(colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin12_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA8_;
LA10_: ;
			{
				NimStringV2 res_3;
				NimStringV2 colontmpD__10;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				NimStringV2 colontmpD__13;
				NimStringV2* T28_;
				NimStringV2* T29_;
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				T28_ = (NimStringV2*)0;
				T28_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				addIndent__cgen_u315(p_p0, T28_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T29_ = (NimStringV2*)0;
				T29_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				res_3 = rawNewString(((NI)80));
				colontmpD__10 = rdLoc__cgen_u470(d_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&res_3), 10);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_961);
				colontmpD__11 = rdLoc__cgen_u470(a_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_962);
				colontmpD__12 = rdLoc__cgen_u470(d_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&res_3), 10);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_963);
				colontmpD__13 = rdLoc__cgen_u470(a_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_964);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA32_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_965);
				}
LA32_: ;
				prepareAdd((&(*T29_)), res_3.len + 0);
appendString((&(*T29_)), res_3);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(res_3);
			}
LA8_: ;
		}
		goto LA3_;
LA6_: ;
		{
			NimStringV2 res_4;
			NimStringV2 colontmpD__14;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			NimStringV2* T35_;
			NimStringV2* T36_;
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			T35_ = (NimStringV2*)0;
			T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T35_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T36_ = (NimStringV2*)0;
			T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			res_4 = rawNewString(((NI)80));
			colontmpD__14 = rdLoc__cgen_u470(d_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 10);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_966);
			colontmpD__15 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_967);
			colontmpD__16 = rdLoc__cgen_u470(d_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__16);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 10);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_968);
			colontmpD__17 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__17);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 6);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_970);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA39_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_971);
			}
LA39_: ;
			prepareAdd((&(*T36_)), res_4.len + 0);
appendString((&(*T36_)), res_4);
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(res_4);
		}
LA3_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		NimStringV2 res_5;
		NimStringV2 colontmpD__18;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		NimStringV2 colontmpD__21;
		NimStringV2 colontmpD__22;
		NimStringV2 colontmpD__23;
		NimStringV2 colontmpD__24;
		NimStringV2* T42_;
		NimStringV2* T43_;
		res_5.len = 0; res_5.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
		T42_ = (NimStringV2*)0;
		T42_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T42_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T43_ = (NimStringV2*)0;
		T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_5 = rawNewString(((NI)80));
		colontmpD__18 = rdLoc__cgen_u470(d_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__18);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 11);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_973);
		colontmpD__19 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__20 = dataFieldAccessor__cgen_u508(p_p0, colontmpD__19);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__20);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 5);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_978);
		colontmpD__21 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__21);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__22 = dataField__cgen_u516(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__22);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 13);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_980);
		colontmpD__23 = rdLoc__cgen_u470(d_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__23);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 10);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_981);
		colontmpD__24 = lenExpr__cgen_u495(p_p0, a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__24);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_982);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA46_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_983);
		}
LA46_: ;
		prepareAdd((&(*T43_)), res_5.len + 0);
appendString((&(*T43_)), res_5);
		eqdestroy___system_u2691(colontmpD__24);
		eqdestroy___system_u2691(colontmpD__23);
		eqdestroy___system_u2691(colontmpD__22);
		eqdestroy___system_u2691(colontmpD__21);
		eqdestroy___system_u2691(colontmpD__20);
		eqdestroy___system_u2691(colontmpD__19);
		eqdestroy___system_u2691(colontmpD__18);
		eqdestroy___system_u2691(res_5);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		NimStringV2 res_6;
		NimStringV2 colontmpD__25;
		NimStringV2 colontmpD__26;
		NimStringV2 colontmpD__27;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__28;
		NimStringV2 colontmpD__29;
		NimStringV2* T50_;
		NimStringV2* T51_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T52_;
		res_6.len = 0; res_6.p = NIM_NIL;
		colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
		colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
		colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
		colontmpD__28 = NIM_NIL;
		colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
		T50_ = (NimStringV2*)0;
		T50_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		addIndent__cgen_u315(p_p0, T50_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		T51_ = (NimStringV2*)0;
		T51_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		res_6 = rawNewString(((NI)80));
		colontmpD__25 = rdLoc__cgen_u470(d_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__25);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		prepareAdd((&res_6), 10);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_984);
		colontmpD__26 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__26);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_985);
		colontmpD__27 = rdLoc__cgen_u470(d_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__27);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		prepareAdd((&res_6), 10);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_986);
		colontmpD__28 = t__cgen_u97(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		T52_ = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, colontmpD__28);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		colontmpD__29 = rope__cgen_u9217(T52_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__29);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_987);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA55_;
			prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_988);
		}
LA55_: ;
		prepareAdd((&(*T51_)), res_6.len + 0);
appendString((&(*T51_)), res_6);
		{
			LA49_:;
		}
		{
			oldNimErrFin49_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__29);
			eqdestroy___ast_u3378(colontmpD__28);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__27);
			eqdestroy___system_u2691(colontmpD__26);
			eqdestroy___system_u2691(colontmpD__25);
			eqdestroy___system_u2691(res_6);
			*nimErr_ = oldNimErrFin49_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* etyp_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__30;
		NimStringV2 res_7;
		NimStringV2 colontmpD__31;
		NimStringV2 colontmpD__32;
		NimStringV2 colontmpD__33;
		NimStringV2 colontmpD__34;
		NimStringV2 colontmpD__35;
		NimStringV2 colontmpD__36;
		NimStringV2 colontmpD__37;
		NimStringV2* T76_;
		NimStringV2* T77_;
		etyp_1 = NIM_NIL;
		colontmpD__30 = NIM_NIL;
		res_7.len = 0; res_7.p = NIM_NIL;
		colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
		colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
		colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
		colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
		colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
		colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
		colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
		colontmpD__30 = t__cgen_u97(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		etyp_1 = skipTypes__ast_u5379(colontmpD__30, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		{
			NIM_BOOL T63_;
			NimStringV2 res_8;
			NimStringV2 colontmpD__38;
			NimStringV2 colontmpD__39;
			NimStringV2* T68_;
			NimStringV2* T69_;
			T63_ = (NIM_BOOL)0;
			T63_ = ((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
			if (!(T63_)) goto LA64_;
			T63_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
LA64_: ;
			if (!T63_) goto LA65_;
			res_8.len = 0; res_8.p = NIM_NIL;
			colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
			colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
			T68_ = (NimStringV2*)0;
			T68_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			addIndent__cgen_u315(p_p0, T68_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			T69_ = (NimStringV2*)0;
			T69_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			res_8 = rawNewString(((NI)80));
			colontmpD__38 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_990);
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			cgFormatValue__cgen_u163((&res_8), colontmpD__38);
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_991);
			colontmpD__39 = byRefLoc__cgen_u12841(p_p0, a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			cgFormatValue__cgen_u163((&res_8), colontmpD__39);
			if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
			prepareAdd((&res_8), 2);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_994);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA72_;
				prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_995);
			}
LA72_: ;
			prepareAdd((&(*T69_)), res_8.len + 0);
appendString((&(*T69_)), res_8);
			{
				LA67_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__39);
				eqdestroy___system_u2691(colontmpD__38);
				eqdestroy___system_u2691(res_8);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		}
LA65_: ;
		T76_ = (NimStringV2*)0;
		T76_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		addIndent__cgen_u315(p_p0, T76_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		T77_ = (NimStringV2*)0;
		T77_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		res_7 = rawNewString(((NI)80));
		colontmpD__31 = rdLoc__cgen_u470(d_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__31);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		prepareAdd((&res_7), 11);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_996);
		colontmpD__32 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		colontmpD__33 = dataFieldAccessor__cgen_u508(p_p0, colontmpD__32);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__33);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		prepareAdd((&res_7), 5);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_997);
		colontmpD__34 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__34);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		colontmpD__35 = dataField__cgen_u516(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		prepareAdd((&res_7), 13);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_998);
		colontmpD__36 = rdLoc__cgen_u470(d_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__36);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		prepareAdd((&res_7), 10);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_999);
		colontmpD__37 = lenExpr__cgen_u495(p_p0, a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__37);
		if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
		prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1000);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA80_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1001);
		}
LA80_: ;
		prepareAdd((&(*T77_)), res_7.len + 0);
appendString((&(*T77_)), res_7);
		{
			LA60_:;
		}
		{
			oldNimErrFin60_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__37);
			eqdestroy___system_u2691(colontmpD__36);
			eqdestroy___system_u2691(colontmpD__35);
			eqdestroy___system_u2691(colontmpD__34);
			eqdestroy___system_u2691(colontmpD__33);
			eqdestroy___system_u2691(colontmpD__32);
			eqdestroy___system_u2691(colontmpD__31);
			eqdestroy___system_u2691(res_7);
			eqdestroy___ast_u3378(colontmpD__30);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(etyp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin60_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__40;
		NimStringV2 colontmpD__41;
		NimStringV2 colontmpD__42;
		NimStringV2 T86_;
		colontmpD__40 = NIM_NIL;
		colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
		colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
		T86_.len = 0; T86_.p = NIM_NIL;
		colontmpD__40 = t__cgen_u97(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
		colontmpD__41 = dollar___ast_u182((*colontmpD__40).kind);
		T86_ = rawNewString(colontmpD__41.len + 14);
appendString((&T86_), TM__MQdRN7fpbG7rPm4JpVVAhA_1003);
appendString((&T86_), colontmpD__41);
		colontmpD__42 = T86_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*a_p2.lode).info, colontmpD__42, TM__MQdRN7fpbG7rPm4JpVVAhA_1004);
		if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
		{
			LA85_:;
		}
		{
			oldNimErrFin85_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__42);
			eqdestroy___system_u2691(colontmpD__41);
			eqdestroy___ast_u3378(colontmpD__40);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin85_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAssignment__cgen_u12898)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2, tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
NIM_BOOL oldNimErrFin31_;
NIM_BOOL oldNimErrFin75_;
NIM_BOOL oldNimErrFin107_;
NIM_BOOL oldNimErrFin101_;
NIM_BOOL oldNimErrFin134_;
NIM_BOOL oldNimErrFin128_;
NIM_BOOL oldNimErrFin208_;
NIM_BOOL oldNimErrFin200_;
NIM_BOOL oldNimErrFin230_;
NIM_BOOL oldNimErrFin220_;
NIM_BOOL oldNimErrFin254_;
NIM_BOOL oldNimErrFin289_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	ty_1 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	{
		NIM_BOOL T4_;
		NimStringV2 res_1;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2* T9_;
		NimStringV2* T10_;
		T4_ = (NIM_BOOL)0;
		colontmpD_ = t__cgen_u97(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		colontmpD__2 = t__cgen_u97(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = ((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
LA5_: ;
		if (!T4_) goto LA6_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T9_ = (NimStringV2*)0;
		T9_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		addIndent__cgen_u315(p_p0, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T10_ = (NimStringV2*)0;
		T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		res_1 = rawNewString(((NI)80));
		colontmpD__4 = rdLoc__cgen_u470(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_855);
		colontmpD__5 = rdLoc__cgen_u470(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_856);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA13_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_857);
		}
LA13_: ;
		prepareAdd((&(*T10_)), res_1.len + 0);
appendString((&(*T10_)), res_1);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	colontmpD__3 = t__cgen_u97(dest_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ty_1 = skipTypes__ast_u5379(colontmpD__3, TM__MQdRN7fpbG7rPm4JpVVAhA_858);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*ty_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	{
		genRefAssign__cgen_u13070(p_p0, dest_p1, src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		{
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA21_;
			genGenericAsgn__cgen_u20436(p_p0, dest_p1, src_p2, flags_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA19_;
LA21_: ;
		{
			NIM_BOOL T24_;
			NIM_BOOL T25_;
			T24_ = (NIM_BOOL)0;
			T25_ = (NIM_BOOL)0;
			T25_ = !(((flags_p3 &((NU8)1<<((NU)((((tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w)0)))&7U)))!=0));
			if (!(T25_)) goto LA26_;
			T25_ = !((src_p2.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1)));
LA26_: ;
			T24_ = T25_;
			if (T24_) goto LA27_;
			T24_ = canMove__cgen_u20278(p_p0, src_p2.lode, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA27_: ;
			if (!T24_) goto LA28_;
			genRefAssign__cgen_u13070(p_p0, dest_p1, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA19_;
LA28_: ;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2* T32_;
			NimStringV2* T33_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9 = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T32_ = (NimStringV2*)0;
			T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			addIndent__cgen_u315(p_p0, T32_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			T33_ = (NimStringV2*)0;
			T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			res_2 = rawNewString(((NI)80));
			colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_885);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_886);
			colontmpD__7 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_887);
			colontmpD__8 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_888);
			colontmpD__9 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			colontmpD__10 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__9, (*dest_p1.lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_889);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA36_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_890);
			}
LA36_: ;
			prepareAdd((&(*T33_)), res_2.len + 0);
appendString((&(*T33_)), res_2);
			{
				LA31_:;
			}
			{
				oldNimErrFin31_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___ast_u3378(colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(res_2);
				*nimErr_ = oldNimErrFin31_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA19_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		{
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA43_;
			genGenericAsgn__cgen_u20436(p_p0, dest_p1, src_p2, flags_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA41_;
LA43_: ;
		{
			NIM_BOOL T46_;
			NIM_BOOL T47_;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T48_;
			T46_ = (NIM_BOOL)0;
			T47_ = (NIM_BOOL)0;
			T48_ = 0;
			T47_ = ((3 & flags_p3) == T48_);
			if (!(T47_)) goto LA49_;
			T47_ = !((src_p2.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1)));
LA49_: ;
			T46_ = T47_;
			if (T46_) goto LA50_;
			T46_ = canMove__cgen_u20278(p_p0, src_p2.lode, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA50_: ;
			if (!T46_) goto LA51_;
			genRefAssign__cgen_u13070(p_p0, dest_p1, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA41_;
LA51_: ;
		{
			{
				NIM_BOOL T56_;
				NIM_BOOL T57_;
				NIM_BOOL T60_;
				NimStringV2 res_3;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				NimStringV2 colontmpD__13;
				NimStringV2* T64_;
				NimStringV2* T65_;
				T56_ = (NIM_BOOL)0;
				T57_ = (NIM_BOOL)0;
				T57_ = (dest_p1.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2));
				if (!(T57_)) goto LA58_;
				T57_ = !(((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10)));
LA58_: ;
				T56_ = T57_;
				if (T56_) goto LA59_;
				T60_ = (NIM_BOOL)0;
				T60_ = usesWriteBarrier__options_u3582((*(*(*p_p0).module).g).config);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T56_ = !(T60_);
LA59_: ;
				if (!T56_) goto LA61_;
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				T64_ = (NimStringV2*)0;
				T64_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				addIndent__cgen_u315(p_p0, T64_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				T65_ = (NimStringV2*)0;
				T65_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				res_3 = rawNewString(((NI)80));
				colontmpD__11 = rdLoc__cgen_u470(dest_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_891);
				colontmpD__12 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_893);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_894);
				colontmpD__13 = rdLoc__cgen_u470(src_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_895);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA68_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_896);
				}
LA68_: ;
				prepareAdd((&(*T65_)), res_3.len + 0);
appendString((&(*T65_)), res_3);
				{
					LA63_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__13);
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(res_3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA54_;
LA61_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
				NimStringV2 res_4;
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				NimStringV2 colontmpD__16;
				NimStringV2 colontmpD__17;
				NimStringV2 colontmpD__18;
				NimStringV2 res_5;
				NimStringV2 colontmpD__19;
				NimStringV2 colontmpD__20;
				NimStringV2 colontmpD__21;
				NimStringV2* T76_;
				NimStringV2* T77_;
				NimStringV2* T82_;
				NimStringV2* T83_;
				if (!(dest_p1.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3))) goto LA73_;
				nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				res_4.len = 0; res_4.p = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
				colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				res_5.len = 0; res_5.p = NIM_NIL;
				colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				getTemp__cgen_u9546(p_p0, ty_1, NIM_FALSE, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				T76_ = (NimStringV2*)0;
				T76_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				addIndent__cgen_u315(p_p0, T76_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				T77_ = (NimStringV2*)0;
				T77_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				res_4 = rawNewString(((NI)80));
				colontmpD__14 = rdLoc__cgen_u470(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_897);
				colontmpD__15 = rdLoc__cgen_u470(dest_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__15);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_898);
				colontmpD__16 = rdLoc__cgen_u470(dest_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_899);
				colontmpD__17 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_901);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__17);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_902);
				colontmpD__18 = rdLoc__cgen_u470(src_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__18);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_903);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA80_;
					prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_904);
				}
LA80_: ;
				prepareAdd((&(*T77_)), res_4.len + 0);
appendString((&(*T77_)), res_4);
				T82_ = (NimStringV2*)0;
				T82_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				addIndent__cgen_u315(p_p0, T82_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				T83_ = (NimStringV2*)0;
				T83_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				res_5 = rawNewString(((NI)80));
				prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_906);
				colontmpD__19 = rdLoc__cgen_u470(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__19);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_907);
				colontmpD__20 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_909);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__20);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_910);
				colontmpD__21 = rdLoc__cgen_u470(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__21);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_911);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA86_;
					prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_912);
				}
LA86_: ;
				prepareAdd((&(*T83_)), res_5.len + 0);
appendString((&(*T83_)), res_5);
				{
					LA75_:;
				}
				{
					oldNimErrFin75_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__21);
					eqdestroy___system_u2691(colontmpD__20);
					eqdestroy___system_u2691(colontmpD__19);
					eqdestroy___system_u2691(res_5);
					eqdestroy___system_u2691(colontmpD__18);
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___system_u2691(colontmpD__16);
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(res_4);
					eqdestroy___ast_u6284(tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin75_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA54_;
LA73_: ;
			{
				NimStringV2 res_6;
				NimStringV2 colontmpD__22;
				NimStringV2 colontmpD__23;
				NimStringV2 colontmpD__24;
				NimStringV2 colontmpD__25;
				NimStringV2* T92_;
				NimStringV2* T93_;
				res_6.len = 0; res_6.p = NIM_NIL;
				colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
				colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
				T92_ = (NimStringV2*)0;
				T92_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				addIndent__cgen_u315(p_p0, T92_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				T93_ = (NimStringV2*)0;
				T93_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				res_6 = rawNewString(((NI)80));
				colontmpD__22 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_913);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__22);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				prepareAdd((&res_6), 10);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_914);
				colontmpD__23 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__23);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_915);
				colontmpD__24 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_916);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__24);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_917);
				colontmpD__25 = rdLoc__cgen_u470(src_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__25);
				if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
				prepareAdd((&res_6), 3);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_918);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA96_;
					prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_919);
				}
LA96_: ;
				prepareAdd((&(*T93_)), res_6.len + 0);
appendString((&(*T93_)), res_6);
				{
					LA91_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__25);
					eqdestroy___system_u2691(colontmpD__24);
					eqdestroy___system_u2691(colontmpD__23);
					eqdestroy___system_u2691(colontmpD__22);
					eqdestroy___system_u2691(res_6);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA54_: ;
		}
LA41_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__26;
		colontmpD__26 = NIM_NIL;
		{
			NIM_BOOL T104_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__27;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__28;
			NimStringV2 res_7;
			NimStringV2 colontmpD__29;
			NimStringV2 colontmpD__30;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T108_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T109_;
			NimStringV2* T110_;
			NimStringV2* T111_;
			colontmpD__26 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			T104_ = (NIM_BOOL)0;
			T104_ = containsGarbageCollectedRef__types_u555(colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			if (!T104_) goto LA105_;
			nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__27 = NIM_NIL;
			nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__28 = NIM_NIL;
			res_7.len = 0; res_7.p = NIM_NIL;
			colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			colontmpD__27 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			nimZeroMem((void*)(&T108_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			optAsgnLoc__cgen_u20366(dest_p1, colontmpD__27, TM__MQdRN7fpbG7rPm4JpVVAhA_922, (&T108_));
			a_1 = T108_;
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			colontmpD__28 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			nimZeroMem((void*)(&T109_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			optAsgnLoc__cgen_u20366(src_p2, colontmpD__28, TM__MQdRN7fpbG7rPm4JpVVAhA_923, (&T109_));
			b_1 = T109_;
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			genRefAssign__cgen_u13070(p_p0, a_1, b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T110_ = (NimStringV2*)0;
			T110_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			addIndent__cgen_u315(p_p0, T110_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T111_ = (NimStringV2*)0;
			T111_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			res_7 = rawNewString(((NI)80));
			colontmpD__29 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__29);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			prepareAdd((&res_7), 9);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_925);
			colontmpD__30 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__30);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			prepareAdd((&res_7), 7);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_927);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA114_;
				prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_928);
			}
LA114_: ;
			prepareAdd((&(*T111_)), res_7.len + 0);
appendString((&(*T111_)), res_7);
			{
				LA107_:;
			}
			{
				oldNimErrFin107_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__30);
				eqdestroy___system_u2691(colontmpD__29);
				eqdestroy___system_u2691(res_7);
				eqdestroy___ast_u3378(colontmpD__28);
				if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
				eqdestroy___ast_u6284(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
				eqdestroy___ast_u3378(colontmpD__27);
				if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
				eqdestroy___ast_u6284(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
				*nimErr_ = oldNimErrFin107_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
		}
		goto LA102_;
LA105_: ;
		{
			NimStringV2 res_8;
			NimStringV2 colontmpD__31;
			NimStringV2 colontmpD__32;
			NimStringV2* T119_;
			NimStringV2* T120_;
			res_8.len = 0; res_8.p = NIM_NIL;
			colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
			colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
			T119_ = (NimStringV2*)0;
			T119_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			addIndent__cgen_u315(p_p0, T119_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			T120_ = (NimStringV2*)0;
			T120_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			res_8 = rawNewString(((NI)80));
			colontmpD__31 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			cgFormatValue__cgen_u163((&res_8), colontmpD__31);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			prepareAdd((&res_8), 3);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_929);
			colontmpD__32 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			cgFormatValue__cgen_u163((&res_8), colontmpD__32);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_930);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA123_;
				prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_931);
			}
LA123_: ;
			prepareAdd((&(*T120_)), res_8.len + 0);
appendString((&(*T120_)), res_8);
			eqdestroy___system_u2691(colontmpD__32);
			eqdestroy___system_u2691(colontmpD__31);
			eqdestroy___system_u2691(res_8);
		}
LA102_: ;
		{
			LA101_:;
		}
		{
			oldNimErrFin101_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin101_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__33;
		colontmpD__33 = NIM_NIL;
		{
			NIM_BOOL T131_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__34;
			colontmpD__33 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			T131_ = (NIM_BOOL)0;
			T131_ = containsGarbageCollectedRef__types_u555(colontmpD__33);
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			if (!T131_) goto LA132_;
			colontmpD__34 = NIM_NIL;
			{
				NI T137_;
				colontmpD__34 = t__cgen_u97(dest_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				T137_ = (NI)0;
				T137_ = kidsLen__ast_u5648(colontmpD__34);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				if (!(T137_ <= ((NI)4))) goto LA138_;
				genOptAsgnTuple__cgen_u20374(p_p0, dest_p1, src_p2, flags_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
			}
			goto LA135_;
LA138_: ;
			{
				genGenericAsgn__cgen_u20436(p_p0, dest_p1, src_p2, flags_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
			}
LA135_: ;
			{
				LA134_:;
			}
			{
				oldNimErrFin134_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__34);
				if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
				*nimErr_ = oldNimErrFin134_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
		}
		goto LA129_;
LA132_: ;
		{
			NimStringV2 res_9;
			NimStringV2 colontmpD__35;
			NimStringV2 colontmpD__36;
			NimStringV2* T144_;
			NimStringV2* T145_;
			res_9.len = 0; res_9.p = NIM_NIL;
			colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
			colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
			T144_ = (NimStringV2*)0;
			T144_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			addIndent__cgen_u315(p_p0, T144_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			T145_ = (NimStringV2*)0;
			T145_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			res_9 = rawNewString(((NI)80));
			colontmpD__35 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			cgFormatValue__cgen_u163((&res_9), colontmpD__35);
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			prepareAdd((&res_9), 3);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_932);
			colontmpD__36 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			cgFormatValue__cgen_u163((&res_9), colontmpD__36);
			if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_933);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA148_;
				prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_934);
			}
LA148_: ;
			prepareAdd((&(*T145_)), res_9.len + 0);
appendString((&(*T145_)), res_9);
			eqdestroy___system_u2691(colontmpD__36);
			eqdestroy___system_u2691(colontmpD__35);
			eqdestroy___system_u2691(res_9);
		}
LA129_: ;
		{
			LA128_:;
		}
		{
			oldNimErrFin128_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__33);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin128_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		{
			NIM_BOOL T155_;
			NimStringV2 res_10;
			NimStringV2 colontmpD__37;
			NimStringV2 colontmpD__38;
			NimStringV2* T158_;
			NimStringV2* T159_;
			T155_ = (NIM_BOOL)0;
			T155_ = isImportedCppType__cgen_u1384(ty_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T155_) goto LA156_;
			res_10.len = 0; res_10.p = NIM_NIL;
			colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
			colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
			T158_ = (NimStringV2*)0;
			T158_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T158_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T159_ = (NimStringV2*)0;
			T159_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			res_10 = rawNewString(((NI)80));
			colontmpD__37 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_10), colontmpD__37);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_10), 3);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_935);
			colontmpD__38 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_10), colontmpD__38);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_936);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA162_;
				prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_937);
			}
LA162_: ;
			prepareAdd((&(*T159_)), res_10.len + 0);
appendString((&(*T159_)), res_10);
			eqdestroy___system_u2691(colontmpD__38);
			eqdestroy___system_u2691(colontmpD__37);
			eqdestroy___system_u2691(res_10);
		}
		goto LA153_;
LA156_: ;
		{
			NIM_BOOL T165_;
			T165_ = (NIM_BOOL)0;
			T165_ = isObjLackingTypeField__types_u2952(ty_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T165_)) goto LA166_;
			genGenericAsgn__cgen_u20436(p_p0, dest_p1, src_p2, flags_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA153_;
LA166_: ;
		{
			NIM_BOOL T169_;
			T169_ = (NIM_BOOL)0;
			T169_ = containsGarbageCollectedRef__types_u555(ty_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T169_) goto LA170_;
			{
				NIM_BOOL T174_;
				NIM_BOOL T175_;
				NI T177_;
				NimStringV2 colontmpD__39;
				T174_ = (NIM_BOOL)0;
				T175_ = (NIM_BOOL)0;
				T175_ = ((*ty_1).sons.p->data[((NI)0)] == 0);
				if (!(T175_)) goto LA176_;
				T177_ = (NI)0;
				T177_ = asgnComplexity__cgen_u20354((*ty_1).n);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T175_ = (T177_ <= ((NI)4));
LA176_: ;
				T174_ = T175_;
				if (!(T174_)) goto LA178_;
				T174_ = !(((flags_p3 &((NU8)1<<((NU)((((tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w)3)))&7U)))!=0));
LA178_: ;
				if (!T174_) goto LA179_;
				colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
				colontmpD__39 = getTypeDesc__cgen_u8738((*p_p0).module, ty_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA181_;
				(void)(colontmpD__39);
				{
					NimStringV2 argX60gensym4116__1;
					if (!!(!(((*ty_1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))))) goto LA184_;
					argX60gensym4116__1.len = 0; argX60gensym4116__1.p = NIM_NIL;
					argX60gensym4116__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_938);
					if (NIM_UNLIKELY(*nimErr_)) goto LA186_;
					internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, argX60gensym4116__1, TM__MQdRN7fpbG7rPm4JpVVAhA_938);
					if (NIM_UNLIKELY(*nimErr_)) goto LA186_;
					{
						LA186_:;
					}
					{
						eqdestroy___system_u2691(argX60gensym4116__1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA181_;
				}
LA184_: ;
				genOptAsgnObject__cgen_u20406(p_p0, dest_p1, src_p2, flags_p3, (*ty_1).n, ty_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA181_;
				{
					LA181_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__39);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA172_;
LA179_: ;
			{
				genGenericAsgn__cgen_u20436(p_p0, dest_p1, src_p2, flags_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA172_: ;
		}
		goto LA153_;
LA170_: ;
		{
			NimStringV2 res_11;
			NimStringV2 colontmpD__40;
			NimStringV2 colontmpD__41;
			NimStringV2* T193_;
			NimStringV2* T194_;
			res_11.len = 0; res_11.p = NIM_NIL;
			colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
			colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
			T193_ = (NimStringV2*)0;
			T193_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T193_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T194_ = (NimStringV2*)0;
			T194_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			res_11 = rawNewString(((NI)80));
			colontmpD__40 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_11), colontmpD__40);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_11), 3);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_939);
			colontmpD__41 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_11), colontmpD__41);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_940);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA197_;
				prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_941);
			}
LA197_: ;
			prepareAdd((&(*T194_)), res_11.len + 0);
appendString((&(*T194_)), res_11);
			eqdestroy___system_u2691(colontmpD__41);
			eqdestroy___system_u2691(colontmpD__40);
			eqdestroy___system_u2691(res_11);
		}
LA153_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__42;
		colontmpD__42 = NIM_NIL;
		{
			NIM_BOOL T203_;
			T203_ = (NIM_BOOL)0;
			colontmpD__42 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
			T203_ = containsGarbageCollectedRef__types_u555(colontmpD__42);
			if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
			if (!(T203_)) goto LA204_;
			T203_ = !(((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)8)));
LA204_: ;
			if (!T203_) goto LA205_;
			genGenericAsgn__cgen_u20436(p_p0, dest_p1, src_p2, flags_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
		}
		goto LA201_;
LA205_: ;
		{
			NimStringV2 res_12;
			NimStringV2 colontmpD__43;
			NimStringV2 colontmpD__44;
			NimStringV2 colontmpD__45;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__46;
			NimStringV2 colontmpD__47;
			NimStringV2* T209_;
			NimStringV2* T210_;
			res_12.len = 0; res_12.p = NIM_NIL;
			colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
			colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
			colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
			colontmpD__46 = NIM_NIL;
			colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
			T209_ = (NimStringV2*)0;
			T209_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			addIndent__cgen_u315(p_p0, T209_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			T210_ = (NimStringV2*)0;
			T210_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			res_12 = rawNewString(((NI)80));
			colontmpD__43 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_942);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			cgFormatValue__cgen_u163((&res_12), colontmpD__43);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			prepareAdd((&res_12), 8);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_943);
			colontmpD__44 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			cgFormatValue__cgen_u163((&res_12), colontmpD__44);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			prepareAdd((&res_12), 19);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_944);
			colontmpD__45 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			cgFormatValue__cgen_u163((&res_12), colontmpD__45);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			prepareAdd((&res_12), 9);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_945);
			colontmpD__46 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			colontmpD__47 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__46, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			cgFormatValue__cgen_u163((&res_12), colontmpD__47);
			if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
			prepareAdd((&res_12), 3);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_946);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA213_;
				prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_947);
			}
LA213_: ;
			prepareAdd((&(*T210_)), res_12.len + 0);
appendString((&(*T210_)), res_12);
			{
				LA208_:;
			}
			{
				oldNimErrFin208_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__47);
				eqdestroy___ast_u3378(colontmpD__46);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				eqdestroy___system_u2691(colontmpD__45);
				eqdestroy___system_u2691(colontmpD__44);
				eqdestroy___system_u2691(colontmpD__43);
				eqdestroy___system_u2691(res_12);
				*nimErr_ = oldNimErrFin208_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
		}
LA201_: ;
		{
			LA200_:;
		}
		{
			oldNimErrFin200_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__42);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin200_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__48;
		colontmpD__48 = NIM_NIL;
		{
			NIM_BOOL T223_;
			T223_ = (NIM_BOOL)0;
			T223_ = reifiedOpenArray__cgen_u14410(dest_p1.lode);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			if (!T223_) goto LA224_;
			genOpenArrayConv__cgen_u20514(p_p0, dest_p1, src_p2, flags_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
		}
		goto LA221_;
LA224_: ;
		{
			NIM_BOOL T227_;
			NimStringV2 res_13;
			NimStringV2 colontmpD__49;
			NimStringV2 colontmpD__50;
			NimStringV2 colontmpD__51;
			NimStringV2 colontmpD__52;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__53;
			NimStringV2 colontmpD__54;
			NimStringV2* T231_;
			NimStringV2* T232_;
			colontmpD__48 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			T227_ = (NIM_BOOL)0;
			T227_ = containsGarbageCollectedRef__types_u555(colontmpD__48);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			if (!T227_) goto LA228_;
			res_13.len = 0; res_13.p = NIM_NIL;
			colontmpD__49.len = 0; colontmpD__49.p = NIM_NIL;
			colontmpD__50.len = 0; colontmpD__50.p = NIM_NIL;
			colontmpD__51.len = 0; colontmpD__51.p = NIM_NIL;
			colontmpD__52.len = 0; colontmpD__52.p = NIM_NIL;
			colontmpD__53 = NIM_NIL;
			colontmpD__54.len = 0; colontmpD__54.p = NIM_NIL;
			T231_ = (NimStringV2*)0;
			T231_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			addIndent__cgen_u315(p_p0, T231_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			T232_ = (NimStringV2*)0;
			T232_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			res_13 = rawNewString(((NI)80));
			colontmpD__49 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1006);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__49);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			prepareAdd((&res_13), 8);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_1007);
			colontmpD__50 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__50);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			prepareAdd((&res_13), 9);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_1008);
			colontmpD__51 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__51);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			prepareAdd((&res_13), 2);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_1009);
			colontmpD__52 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__52);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			prepareAdd((&res_13), 7);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_1011);
			colontmpD__53 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			colontmpD__54 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__53, (*dest_p1.lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__54);
			if (NIM_UNLIKELY(*nimErr_)) goto LA230_;
			prepareAdd((&res_13), 2);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_1012);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA235_;
				prepareAdd((&res_13), 1);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_1013);
			}
LA235_: ;
			prepareAdd((&(*T232_)), res_13.len + 0);
appendString((&(*T232_)), res_13);
			{
				LA230_:;
			}
			{
				oldNimErrFin230_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__54);
				eqdestroy___ast_u3378(colontmpD__53);
				if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
				eqdestroy___system_u2691(colontmpD__52);
				eqdestroy___system_u2691(colontmpD__51);
				eqdestroy___system_u2691(colontmpD__50);
				eqdestroy___system_u2691(colontmpD__49);
				eqdestroy___system_u2691(res_13);
				*nimErr_ = oldNimErrFin230_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
		}
		goto LA221_;
LA228_: ;
		{
			NimStringV2 res_14;
			NimStringV2 colontmpD__55;
			NimStringV2 colontmpD__56;
			NimStringV2* T240_;
			NimStringV2* T241_;
			res_14.len = 0; res_14.p = NIM_NIL;
			colontmpD__55.len = 0; colontmpD__55.p = NIM_NIL;
			colontmpD__56.len = 0; colontmpD__56.p = NIM_NIL;
			T240_ = (NimStringV2*)0;
			T240_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			addIndent__cgen_u315(p_p0, T240_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			T241_ = (NimStringV2*)0;
			T241_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			res_14 = rawNewString(((NI)80));
			colontmpD__55 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			cgFormatValue__cgen_u163((&res_14), colontmpD__55);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			prepareAdd((&res_14), 3);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_1014);
			colontmpD__56 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			cgFormatValue__cgen_u163((&res_14), colontmpD__56);
			if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
			prepareAdd((&res_14), 1);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_1015);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA244_;
				prepareAdd((&res_14), 1);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_1016);
			}
LA244_: ;
			prepareAdd((&(*T241_)), res_14.len + 0);
appendString((&(*T241_)), res_14);
			eqdestroy___system_u2691(colontmpD__56);
			eqdestroy___system_u2691(colontmpD__55);
			eqdestroy___system_u2691(res_14);
		}
LA221_: ;
		{
			LA220_:;
		}
		{
			oldNimErrFin220_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__48);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin220_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		{
			tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T251_;
			NimStringV2 res_15;
			NimStringV2 colontmpD__57;
			NimStringV2 colontmpD__58;
			NimStringV2 colontmpD__59;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__60;
			NimStringV2* T255_;
			NimStringV2* T256_;
			NI64 T257_;
			T251_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
			T251_ = mapSetType__cgen_u1311((*(*(*p_p0).module).g).config, ty_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T251_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17))) goto LA252_;
			res_15.len = 0; res_15.p = NIM_NIL;
			colontmpD__57.len = 0; colontmpD__57.p = NIM_NIL;
			colontmpD__58.len = 0; colontmpD__58.p = NIM_NIL;
			colontmpD__59.len = 0; colontmpD__59.p = NIM_NIL;
			colontmpD__60 = NIM_NIL;
			T255_ = (NimStringV2*)0;
			T255_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			addIndent__cgen_u315(p_p0, T255_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			T256_ = (NimStringV2*)0;
			T256_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			res_15 = rawNewString(((NI)80));
			colontmpD__57 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1017);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			cgFormatValue__cgen_u163((&res_15), colontmpD__57);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			prepareAdd((&res_15), 8);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_1018);
			colontmpD__58 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			cgFormatValue__cgen_u163((&res_15), colontmpD__58);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			prepareAdd((&res_15), 19);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_1019);
			colontmpD__59 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			cgFormatValue__cgen_u163((&res_15), colontmpD__59);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			prepareAdd((&res_15), 2);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_1020);
			colontmpD__60 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			T257_ = (NI64)0;
			T257_ = getSize__types_u3397((*(*(*p_p0).module).g).config, colontmpD__60);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			cgFormatValue__cgen_u166((&res_15), T257_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			prepareAdd((&res_15), 2);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_1021);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA260_;
				prepareAdd((&res_15), 1);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_1022);
			}
LA260_: ;
			prepareAdd((&(*T256_)), res_15.len + 0);
appendString((&(*T256_)), res_15);
			{
				LA254_:;
			}
			{
				oldNimErrFin254_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__60);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__59);
				eqdestroy___system_u2691(colontmpD__58);
				eqdestroy___system_u2691(colontmpD__57);
				eqdestroy___system_u2691(res_15);
				*nimErr_ = oldNimErrFin254_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA249_;
LA252_: ;
		{
			NimStringV2 res_16;
			NimStringV2 colontmpD__61;
			NimStringV2 colontmpD__62;
			NimStringV2* T265_;
			NimStringV2* T266_;
			res_16.len = 0; res_16.p = NIM_NIL;
			colontmpD__61.len = 0; colontmpD__61.p = NIM_NIL;
			colontmpD__62.len = 0; colontmpD__62.p = NIM_NIL;
			T265_ = (NimStringV2*)0;
			T265_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T265_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T266_ = (NimStringV2*)0;
			T266_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			res_16 = rawNewString(((NI)80));
			colontmpD__61 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_16), colontmpD__61);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_16), 3);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_1023);
			colontmpD__62 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_16), colontmpD__62);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_16), 1);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_1024);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA269_;
				prepareAdd((&res_16), 1);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_1025);
			}
LA269_: ;
			prepareAdd((&(*T266_)), res_16.len + 0);
appendString((&(*T266_)), res_16);
			eqdestroy___system_u2691(colontmpD__62);
			eqdestroy___system_u2691(colontmpD__61);
			eqdestroy___system_u2691(res_16);
		}
LA249_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	{
		NimStringV2 res_17;
		NimStringV2 colontmpD__63;
		NimStringV2 colontmpD__64;
		NimStringV2* T272_;
		NimStringV2* T273_;
		res_17.len = 0; res_17.p = NIM_NIL;
		colontmpD__63.len = 0; colontmpD__63.p = NIM_NIL;
		colontmpD__64.len = 0; colontmpD__64.p = NIM_NIL;
		T272_ = (NimStringV2*)0;
		T272_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T272_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T273_ = (NimStringV2*)0;
		T273_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_17 = rawNewString(((NI)80));
		colontmpD__63 = rdLoc__cgen_u470(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_17), colontmpD__63);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_17), 3);
appendString((&res_17), TM__MQdRN7fpbG7rPm4JpVVAhA_1026);
		colontmpD__64 = rdLoc__cgen_u470(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_17), colontmpD__64);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_17), 1);
appendString((&res_17), TM__MQdRN7fpbG7rPm4JpVVAhA_1027);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA276_;
			prepareAdd((&res_17), 1);
appendString((&res_17), TM__MQdRN7fpbG7rPm4JpVVAhA_1028);
		}
LA276_: ;
		prepareAdd((&(*T273_)), res_17.len + 0);
appendString((&(*T273_)), res_17);
		eqdestroy___system_u2691(colontmpD__64);
		eqdestroy___system_u2691(colontmpD__63);
		eqdestroy___system_u2691(res_17);
	}
	break;
	default:
	{
		NimStringV2 colontmpD__65;
		NimStringV2 colontmpD__66;
		NimStringV2 T280_;
		colontmpD__65.len = 0; colontmpD__65.p = NIM_NIL;
		colontmpD__66.len = 0; colontmpD__66.p = NIM_NIL;
		T280_.len = 0; T280_.p = NIM_NIL;
		colontmpD__65 = dollar___ast_u182((*ty_1).kind);
		T280_ = rawNewString(colontmpD__65.len + 15);
appendString((&T280_), TM__MQdRN7fpbG7rPm4JpVVAhA_1030);
appendString((&T280_), colontmpD__65);
		colontmpD__66 = T280_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, colontmpD__66, TM__MQdRN7fpbG7rPm4JpVVAhA_1031);
		if (NIM_UNLIKELY(*nimErr_)) goto LA279_;
		{
			LA279_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__66);
			eqdestroy___system_u2691(colontmpD__65);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		NIM_BOOL T285_;
		NimStringV2 res_18;
		NimStringV2 colontmpD__67;
		NimStringV2 colontmpD__68;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__69;
		NimStringV2 colontmpD__70;
		NimStringV2 colontmpD__71;
		NimStringV2* T290_;
		NimStringV2* T291_;
		NI64 T292_;
		NI T293_;
		T285_ = (NIM_BOOL)0;
		T285_ = (((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)24)))&31U)))!=0);
		if (!(T285_)) goto LA286_;
		T285_ = (dest_p1.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3) || dest_p1.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
LA286_: ;
		if (!T285_) goto LA287_;
		res_18.len = 0; res_18.p = NIM_NIL;
		colontmpD__67.len = 0; colontmpD__67.p = NIM_NIL;
		colontmpD__68.len = 0; colontmpD__68.p = NIM_NIL;
		colontmpD__69 = NIM_NIL;
		colontmpD__70.len = 0; colontmpD__70.p = NIM_NIL;
		colontmpD__71.len = 0; colontmpD__71.p = NIM_NIL;
		T290_ = (NimStringV2*)0;
		T290_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		addIndent__cgen_u315(p_p0, T290_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		T291_ = (NimStringV2*)0;
		T291_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		res_18 = rawNewString(((NI)80));
		colontmpD__67 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1033);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		cgFormatValue__cgen_u163((&res_18), colontmpD__67);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		prepareAdd((&res_18), 8);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_1034);
		colontmpD__68 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		cgFormatValue__cgen_u163((&res_18), colontmpD__68);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		prepareAdd((&res_18), 2);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_1035);
		colontmpD__69 = t__cgen_u97(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		T292_ = (NI64)0;
		T292_ = getSize__types_u3397((*(*(*p_p0).module).g).config, colontmpD__69);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		cgFormatValue__cgen_u166((&res_18), T292_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		prepareAdd((&res_18), 2);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_1036);
		colontmpD__70 = toFullPath__msgs_u624((*(*(*p_p0).module).g).config, (*p_p0).currLineInfo.fileIndex);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		colontmpD__71 = makeCString__msgs_u83(colontmpD__70);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		cgFormatValue__cgen_u163((&res_18), colontmpD__71);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		prepareAdd((&res_18), 2);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_1037);
		T293_ = (NI)0;
		T293_ = safeLineNm__cgen_u362((*p_p0).currLineInfo);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		cgFormatValue__cgen_u166((&res_18), ((NI64) (T293_)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		prepareAdd((&res_18), 2);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_1038);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA296_;
			prepareAdd((&res_18), 1);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_1039);
		}
LA296_: ;
		prepareAdd((&(*T291_)), res_18.len + 0);
appendString((&(*T291_)), res_18);
		{
			LA289_:;
		}
		{
			oldNimErrFin289_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__71);
			eqdestroy___system_u2691(colontmpD__70);
			eqdestroy___ast_u3378(colontmpD__69);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__68);
			eqdestroy___system_u2691(colontmpD__67);
			eqdestroy___system_u2691(res_18);
			*nimErr_ = oldNimErrFin289_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA287_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjectInit__cgen_u12909)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g section_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p3, tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q mode_p4) {
	tyEnum_TTypeFieldResult__jQSyZUgToorx8YweWMVnag T1_;
NIM_BOOL oldNimErrFin4_;
NIM_BOOL oldNimErrFin57_;
NIM_BOOL oldNimErrFin74_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (tyEnum_TTypeFieldResult__jQSyZUgToorx8YweWMVnag)0;
	T1_ = analyseObjectWithTypeField__types_u528(t_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch (T1_) {
	case ((tyEnum_TTypeFieldResult__jQSyZUgToorx8YweWMVnag)0):
	{
	}
	break;
	case ((tyEnum_TTypeFieldResult__jQSyZUgToorx8YweWMVnag)1):
	{
		NimStringV2 r_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_1;
		r_1.len = 0; r_1.p = NIM_NIL;
		s_1 = NIM_NIL;
		r_1 = rdLoc__cgen_u470((*a_p3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
			NimStringV2 T10_;
			if (!(mode_p4 == ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)1))) goto LA7_;
			T9_[0] = r_1;
			T10_.len = 0; T10_.p = NIM_NIL;
			T10_ = percent___cgen_u12921(T9_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA4_;}
			eqsink___system_u2700((&r_1), T10_);
		}
LA7_: ;
		s_1 = skipTypes__ast_u5379(t_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T13_) goto LA14_;
			T13_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA14_: ;
			if (!!(T13_)) goto LA15_;
			{
				while (1) {
					NIM_BOOL T19_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T21_;
					T19_ = (NIM_BOOL)0;
					T19_ = ((*s_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
					if (!(T19_)) goto LA20_;
					T19_ = !(((*s_1).sons.p->data[((NI)0)] == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA20_: ;
					if (!T19_) goto LA18;
					prepareAdd((&r_1), 4);
appendString((&r_1), TM__MQdRN7fpbG7rPm4JpVVAhA_424);
					T21_ = NIM_NIL;
					T21_ = skipTypes__ast_u5379((*s_1).sons.p->data[((NI)0)], TM__MQdRN7fpbG7rPm4JpVVAhA_425);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T21_); goto LA4_;}
					eqsink___ast_u3387(&s_1, T21_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				} LA18: ;
			}
		}
LA15_: ;
		{
			NimStringV2 res_1;
			NimStringV2 colontmpD_;
			NimStringV2* T27_;
			NimStringV2* T28_;
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA24_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			T27_ = (NimStringV2*)0;
			T27_ = s__cgendata_u228(p_p0, section_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			addIndent__cgen_u315(p_p0, T27_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			T28_ = (NimStringV2*)0;
			T28_ = s__cgendata_u228(p_p0, section_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			res_1 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_1), r_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_427);
			colontmpD_ = genTypeInfoV2__cgen_u10426((*p_p0).module, t_p2, (*(*a_p3).lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			cgFormatValue__cgen_u163((&res_1), colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_702);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA31_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_703);
			}
LA31_: ;
			prepareAdd((&(*T28_)), res_1.len + 0);
appendString((&(*T28_)), res_1);
			{
				LA26_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		}
		goto LA22_;
LA24_: ;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__2;
			NimStringV2* T37_;
			NimStringV2* T38_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T37_ = (NimStringV2*)0;
			T37_ = s__cgendata_u228(p_p0, section_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			addIndent__cgen_u315(p_p0, T37_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			T38_ = (NimStringV2*)0;
			T38_ = s__cgendata_u228(p_p0, section_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			res_2 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_2), r_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_704);
			colontmpD__2 = genTypeInfoV1__cgen_u9076((*p_p0).module, t_p2, (*(*a_p3).lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_705);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA41_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_706);
			}
LA41_: ;
			prepareAdd((&(*T38_)), res_2.len + 0);
appendString((&(*T38_)), res_2);
			{
				LA36_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		}
LA22_: ;
		{
			LA4_:;
		}
		{
			oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(r_1);
			*nimErr_ = oldNimErrFin4_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeFieldResult__jQSyZUgToorx8YweWMVnag)2):
	{
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA50_;
			nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* objType_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
				NimStringV2 res_3;
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__7;
				tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__8;
				NimStringV2 colontmpD__9;
				NimStringV2* T58_;
				NimStringV2* T59_;
				tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T60_;
				tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q T66_;
				if (!(mode_p4 == ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)1))) goto LA55_;
				objType_1 = NIM_NIL;
				colontmpD__3 = NIM_NIL;
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__7 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
				colontmpD__8 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				objType_1 = skipTypes__ast_u5379(t_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_707);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				colontmpD__3 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4), (*(*a_p3).lode).info, objType_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				rawConstExpr__cgen_u12894(p_p0, colontmpD__3, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T58_ = (NimStringV2*)0;
				T58_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				addIndent__cgen_u315(p_p0, T58_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T59_ = (NimStringV2*)0;
				T59_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				res_3 = rawNewString(((NI)80));
				colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_848);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_849);
				colontmpD__5 = rdLoc__cgen_u470((*a_p3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_3), 20);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_851);
				colontmpD__6 = rdLoc__cgen_u470(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_852);
				T60_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
				{
					if (!((*(*a_p3).lode).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA63_;
					colontmpD__7 = (*(*(*a_p3).lode)._kind_4.sym).kind;
					T60_ = colontmpD__7;
				}
				goto LA61_;
LA63_: ;
				{
					colontmpD__8 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
					T60_ = colontmpD__8;
				}
LA61_: ;
				T66_ = (tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0;
				T66_ = descKindFromSymKind__cgen_u735(T60_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				colontmpD__9 = getTypeDesc__cgen_u8738((*p_p0).module, objType_1, T66_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_853);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA69_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_854);
				}
LA69_: ;
				prepareAdd((&(*T59_)), res_3.len + 0);
appendString((&(*T59_)), res_3);
				{
					LA57_:;
				}
				{
					oldNimErrFin57_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(res_3);
					eqdestroy___ast_u3252(colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					eqdestroy___ast_u3378(objType_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					*nimErr_ = oldNimErrFin57_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			}
			goto LA53_;
LA55_: ;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__10;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T75_;
				colontmpD__10 = NIM_NIL;
				colontmpD__10 = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)4), (*(*a_p3).lode).info, t_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				rawConstExpr__cgen_u12894(p_p0, colontmpD__10, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				T75_ = 0;
				genAssignment__cgen_u12898(p_p0, (*a_p3), tmp_1, T75_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				{
					LA74_:;
				}
				{
					oldNimErrFin74_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					*nimErr_ = oldNimErrFin74_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			}
LA53_: ;
			{
				LA52_:;
			}
			{
				oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin52_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA48_;
LA50_: ;
		{
			NimStringV2 r_2;
			NimStringV2 res_4;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 T82_;
			NimStringV2* T88_;
			NimStringV2* T89_;
			r_2.len = 0; r_2.p = NIM_NIL;
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			T82_.len = 0; T82_.p = NIM_NIL;
			{
				if (!(mode_p4 == ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0))) goto LA85_;
				r_2 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*a_p3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			}
			goto LA83_;
LA85_: ;
			{
				r_2 = rdLoc__cgen_u470((*a_p3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			}
LA83_: ;
			T88_ = (NimStringV2*)0;
			T88_ = s__cgendata_u228(p_p0, section_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			addIndent__cgen_u315(p_p0, T88_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			T89_ = (NimStringV2*)0;
			T89_ = s__cgendata_u228(p_p0, section_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			res_4 = rawNewString(((NI)80));
			colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1041);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1042);
			cgFormatValue__cgen_u163((&res_4), r_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1043);
			colontmpD__12 = genTypeInfoV1__cgen_u9076((*p_p0).module, t_p2, (*(*a_p3).lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1044);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA92_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1045);
			}
LA92_: ;
			prepareAdd((&(*T89_)), res_4.len + 0);
appendString((&(*T89_)), res_4);
			{
				LA81_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(res_4);
				eqdestroy___system_u2691(r_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA48_: ;
	}
	break;
	default: __builtin_unreachable();
	}
	{
		NIM_BOOL T98_;
		NimStringV2 r_3;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_2;
		NimStringV2 res_5;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2* T120_;
		NimStringV2* T121_;
		T98_ = (NIM_BOOL)0;
		T98_ = isException__types_u4100(t_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T98_) goto LA99_;
		r_3.len = 0; r_3.p = NIM_NIL;
		s_2 = NIM_NIL;
		res_5.len = 0; res_5.p = NIM_NIL;
		colontmpD__13 = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		r_3 = rdLoc__cgen_u470((*a_p3));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T105_;
			NimStringV2 T106_;
			if (!(mode_p4 == ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)1))) goto LA103_;
			T105_[0] = r_3;
			T106_.len = 0; T106_.p = NIM_NIL;
			T106_ = percent___cgen_u12921(T105_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T106_); goto BeforeRet_;}
			eqsink___system_u2700((&r_3), T106_);
		}
LA103_: ;
		s_2 = skipTypes__ast_u5379(t_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T109_;
			T109_ = (NIM_BOOL)0;
			T109_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T109_) goto LA110_;
			T109_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA110_: ;
			if (!!(T109_)) goto LA111_;
			{
				while (1) {
					NIM_BOOL T115_;
					NIM_BOOL T116_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T119_;
					T115_ = (NIM_BOOL)0;
					T116_ = (NIM_BOOL)0;
					T116_ = ((*s_2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
					if (!(T116_)) goto LA117_;
					T116_ = !(((*s_2).sons.p->data[((NI)0)] == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA117_: ;
					T115_ = T116_;
					if (!(T115_)) goto LA118_;
					T115_ = !(((*(*s_2).sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)269)));
LA118_: ;
					if (!T115_) goto LA114;
					prepareAdd((&r_3), 4);
appendString((&r_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1046);
					T119_ = NIM_NIL;
					T119_ = skipTypes__ast_u5379((*s_2).sons.p->data[((NI)0)], TM__MQdRN7fpbG7rPm4JpVVAhA_425);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T119_); goto BeforeRet_;}
					eqsink___ast_u3387(&s_2, T119_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA114: ;
			}
		}
LA111_: ;
		T120_ = (NimStringV2*)0;
		T120_ = s__cgendata_u228(p_p0, section_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		addIndent__cgen_u315(p_p0, T120_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T121_ = (NimStringV2*)0;
		T121_ = s__cgendata_u228(p_p0, section_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		res_5 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_5), r_3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_5), 8);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1048);
		colontmpD__13 = skipTypes__ast_u5379(t_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__14 = makeCString__msgs_u83((*(*(*colontmpD__13).sym).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1049);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA124_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1050);
		}
LA124_: ;
		prepareAdd((&(*T121_)), res_5.len + 0);
appendString((&(*T121_)), res_5);
		eqdestroy___system_u2691(colontmpD__14);
		eqdestroy___ast_u3378(colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(res_5);
		eqdestroy___ast_u3378(s_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(r_3);
	}
LA99_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, constructLoc__cgen_u13487)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* loc_p1, NIM_BOOL isTemp_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin18_;
NIM_BOOL oldNimErrFin49_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	typ_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	typ_1 = t__cgen_u97((*loc_p1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 res_1;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2* T8_;
		NimStringV2* T9_;
		T4_ = (NIM_BOOL)0;
		T4_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
		if (!(T4_)) goto LA5_;
		colontmpD_ = skipTypes__ast_u5379(typ_1, TM__MQdRN7fpbG7rPm4JpVVAhA_382);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24));
LA5_: ;
		if (!T4_) goto LA6_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T8_ = (NimStringV2*)0;
		T8_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T8_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T9_ = (NimStringV2*)0;
		T9_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_1 = rawNewString(((NI)80));
		colontmpD__2 = rdLoc__cgen_u470((*loc_p1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_384);
		colontmpD__3 = rdLoc__cgen_u470((*loc_p1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_1), 13);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_386);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA12_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_387);
		}
LA12_: ;
		prepareAdd((&(*T9_)), res_1.len + 0);
appendString((&(*T9_)), res_1);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(res_1);
	}
	goto LA2_;
LA6_: ;
	{
		NIM_BOOL T15_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		T15_ = (NIM_BOOL)0;
		T15_ = isComplexValueType__cgen_u13074(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T15_)) goto LA16_;
		colontmpD__4 = NIM_NIL;
		{
			NIM_BOOL T21_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw nilLoc_1;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T25_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T26_;
			colontmpD__4 = t__cgen_u97((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			T21_ = (NIM_BOOL)0;
			T21_ = containsGarbageCollectedRef__types_u555(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			if (!T21_) goto LA22_;
			nimZeroMem((void*)(&nilLoc_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			T25_ = 0;
			nimZeroMem((void*)(&T26_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1), (*loc_p1).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2), T25_, (&T26_));
			nilLoc_1 = T26_;
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			eqsink___system_u2700((&nilLoc_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_390);
			genRefAssign__cgen_u13070(p_p0, (*loc_p1), nilLoc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			{
				LA24_:;
			}
			{
				oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(nilLoc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
				*nimErr_ = oldNimErrFin24_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		}
		goto LA19_;
LA22_: ;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__5;
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__6;
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2* T31_;
			NimStringV2* T32_;
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T33_;
			tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q T39_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			colontmpD__7 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T31_ = (NimStringV2*)0;
			T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			addIndent__cgen_u315(p_p0, T31_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T32_ = (NimStringV2*)0;
			T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			res_2 = rawNewString(((NI)80));
			colontmpD__5 = rdLoc__cgen_u470((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_410);
			T33_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			{
				if (!((*(*loc_p1).lode).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA36_;
				colontmpD__6 = (*(*(*loc_p1).lode)._kind_4.sym).kind;
				T33_ = colontmpD__6;
			}
			goto LA34_;
LA36_: ;
			{
				colontmpD__7 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
				T33_ = colontmpD__7;
			}
LA34_: ;
			T39_ = (tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0;
			T39_ = descKindFromSymKind__cgen_u735(T33_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			colontmpD__8 = getTypeDesc__cgen_u8738((*p_p0).module, typ_1, T39_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_412);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA42_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_413);
			}
LA42_: ;
			prepareAdd((&(*T32_)), res_2.len + 0);
appendString((&(*T32_)), res_2);
			{
				LA30_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		}
LA19_: ;
		{
			LA18_:;
		}
		{
			oldNimErrFin18_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin18_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA16_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
		colontmpD__9 = NIM_NIL;
		colontmpD__10 = NIM_NIL;
		colontmpD__11 = NIM_NIL;
		{
			NIM_BOOL T52_;
			NIM_BOOL T53_;
			NIM_BOOL T56_;
			T52_ = (NIM_BOOL)0;
			T53_ = (NIM_BOOL)0;
			T53_ = !(isTemp_p2);
			if (T53_) goto LA54_;
			colontmpD__9 = t__cgen_u97((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T53_ = containsGarbageCollectedRef__types_u555(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
LA54_: ;
			T52_ = T53_;
			if (!(T52_)) goto LA55_;
			colontmpD__10 = t__cgen_u97((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T56_ = (NIM_BOOL)0;
			T56_ = hasNoInit__cgen_u1407(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T52_ = !(T56_);
LA55_: ;
			if (!T52_) goto LA57_;
			{
				NIM_BOOL T61_;
				NimStringV2 res_3;
				NimStringV2 colontmpD__12;
				NimStringV2 colontmpD__13;
				tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__14;
				tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__15;
				NimStringV2 colontmpD__16;
				NimStringV2* T65_;
				NimStringV2* T66_;
				tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T67_;
				tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q T73_;
				T61_ = (NIM_BOOL)0;
				T61_ = isOrHasImportedCppType__cgen_u1404(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
				if (!!(T61_)) goto LA62_;
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				colontmpD__14 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
				colontmpD__15 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
				colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
				T65_ = (NimStringV2*)0;
				T65_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				addIndent__cgen_u315(p_p0, T65_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				T66_ = (NimStringV2*)0;
				T66_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				res_3 = rawNewString(((NI)80));
				colontmpD__12 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_415);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_417);
				colontmpD__13 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*loc_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_419);
				T67_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
				{
					if (!((*(*loc_p1).lode).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA70_;
					colontmpD__14 = (*(*(*loc_p1).lode)._kind_4.sym).kind;
					T67_ = colontmpD__14;
				}
				goto LA68_;
LA70_: ;
				{
					colontmpD__15 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
					T67_ = colontmpD__15;
				}
LA68_: ;
				T73_ = (tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0;
				T73_ = descKindFromSymKind__cgen_u735(T67_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				colontmpD__16 = getTypeDesc__cgen_u8738((*p_p0).module, typ_1, T73_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_421);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA76_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_422);
				}
LA76_: ;
				prepareAdd((&(*T66_)), res_3.len + 0);
appendString((&(*T66_)), res_3);
				{
					LA64_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__16);
					eqdestroy___system_u2691(colontmpD__13);
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(res_3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			}
LA62_: ;
		}
LA57_: ;
		colontmpD__11 = t__cgen_u97((*loc_p1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		genObjectInit__cgen_u12909(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2), colontmpD__11, loc_p1, ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		{
			LA49_:;
		}
		{
			oldNimErrFin49_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin49_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getTemp__cgen_u9546)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NIM_BOOL needsInit_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
	NimStringV2 colontmpD_;
	NimStringV2 T2_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	(*p_p0).labels += ((NI)1);
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).labels)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + 2);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_374);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_375);
	(*Result).snippet = T2_;
	(*Result).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1);
	T3_ = NIM_NIL;
	T3_ = lodeTyp__cgen_u104(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T3_); goto LA1_;}
	(*Result).lode = T3_;
	(*Result).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2);
	(*Result).flags = 0;
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		NimStringV2 res_1;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NIM_BOOL didGenTemp_1;
		NimStringV2* T13_;
		NimStringV2* T14_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T7_) goto LA8_;
		T7_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA9_;
		T6_ = isOrHasImportedCppType__cgen_u1404(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA9_: ;
		if (!T6_) goto LA10_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		didGenTemp_1 = NIM_FALSE;
		T13_ = (NimStringV2*)0;
		T13_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		addIndent__cgen_u315(p_p0, T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T14_ = (NimStringV2*)0;
		T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		res_1 = rawNewString(((NI)80));
		colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, t_p1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_376);
		cgFormatValue__cgen_u163((&res_1), (*Result).snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		colontmpD__3 = genCppInitializer__cgen_u4564((*p_p0).module, p_p0, t_p1, (&didGenTemp_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_377);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA17_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_378);
		}
LA17_: ;
		prepareAdd((&(*T14_)), res_1.len + 0);
appendString((&(*T14_)), res_1);
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA10_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__4;
		NimStringV2* T23_;
		NimStringV2* T24_;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T23_ = (NimStringV2*)0;
		T23_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		addIndent__cgen_u315(p_p0, T23_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T24_ = (NimStringV2*)0;
		T24_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		res_2 = rawNewString(((NI)80));
		colontmpD__4 = getTypeDesc__cgen_u8738((*p_p0).module, t_p1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_379);
		cgFormatValue__cgen_u163((&res_2), (*Result).snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_380);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA27_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_381);
		}
LA27_: ;
		prepareAdd((&(*T24_)), res_2.len + 0);
appendString((&(*T24_)), res_2);
		{
			LA22_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	constructLoc__cgen_u13487(p_p0, Result, !(needsInit_p2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, withTmpIfNeeded__cgen_u14661)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, NIM_BOOL needsTmp_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NI64 T9_;
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T12_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = needsTmp_p2;
		if (!(T5_)) goto LA6_;
		T5_ = !(((*a_p1.lode).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = ((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5));
LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T9_ = (NI64)0;
		T9_ = getSize__types_u3397((*(*(*p_p0).module).g).config, (*a_p1.lode).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (T9_ < IL64(1024));
LA8_: ;
		if (!T3_) goto LA10_;
		getTemp__cgen_u9546(p_p0, (*a_p1.lode).typField, NIM_FALSE, Result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T12_ = 0;
		genAssignment__cgen_u12898(p_p0, (*Result), a_p1, T12_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA10_: ;
	{
		eqcopy___ast_u6287(Result, a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, genArgStringToCString__cgen_u14678)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2, NIM_BOOL needsTmp_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__2;
	NimStringV2 colontmpD__3;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_371);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_372);
	withTmpIfNeeded__cgen_u14661(p_p0, a_1, needsTmp_p3, (&colontmpD__2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = rdLoc__cgen_u470(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1051);
	prepareAdd((&(*result_p2)), res_1.len + 0);
appendString((&(*result_p2)), res_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___ast_u6284(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addRdLoc__cgen_u477)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0, NimStringV2* result_p1) {
	{
		NimStringV2 colontmpD_;
		NimStringV2 T5_;
		if (!((a_p0.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0)))&15U)))!=0)) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T5_.len = 0; T5_.p = NIM_NIL;
		T5_ = rawNewString(a_p0.snippet.len + 3);
appendString((&T5_), TM__MQdRN7fpbG7rPm4JpVVAhA_1052);
appendString((&T5_), a_p0.snippet);
appendString((&T5_), TM__MQdRN7fpbG7rPm4JpVVAhA_1053);
		colontmpD_ = T5_;
		prepareAdd((&(*result_p1)), colontmpD_.len + 0);
appendString((&(*result_p1)), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA1_;
LA3_: ;
	{
		prepareAdd((&(*result_p1)), a_p0.snippet.len + 0);
appendString((&(*result_p1)), a_p0.snippet);
	}
LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArgNoParam__cgen_u14798)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2, NIM_BOOL needsTmp_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)71))) goto LA4_;
		genArgStringToCString__cgen_u14678(p_p0, n_p1, result_p2, needsTmp_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD_;
		nimZeroMem((void*)(&colontmpD_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		initLocExprSingleUse__cgen_u14116(p_p0, n_p1, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		withTmpIfNeeded__cgen_u14661(p_p0, a_1, needsTmp_p3, (&colontmpD_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		addRdLoc__cgen_u477(colontmpD_, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6284(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOtherArg__cgen_u14099)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, NI i_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, NimStringV2* result_p4, NI* argsCounter_p5) {
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* paramType_1;
		T3_ = (NI)0;
		T3_ = len__ast_u3190((*typ_p3).n);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(i_p2 < T3_)) goto LA4_;
		paramType_1 = NIM_NIL;
		eqcopy___ast_u3255(&paramType_1, (*(*typ_p3).n)._kind_6.sons.p->data[i_p2]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = isCompileTimeOnly__types_u3641((*paramType_1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			if (!T9_) goto LA10_;
		}
		goto LA7_;
LA10_: ;
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = ((*(*paramType_1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
			if (!(T13_)) goto LA14_;
			T13_ = ((*(*ri_p1)._kind_6.sons.p->data[i_p2]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64));
LA14_: ;
			if (!T13_) goto LA15_;
			{
				if (!(((NI)0) < (*argsCounter_p5))) goto LA19_;
				prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_369);
			}
LA19_: ;
			genArgNoParam__cgen_u14798(p_p0, (*(*ri_p1)._kind_6.sons.p->data[i_p2])._kind_6.sons.p->data[((NI)0)], result_p4, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			(*argsCounter_p5) += ((NI)1);
		}
		goto LA7_;
LA15_: ;
		{
			{
				if (!(((NI)0) < (*argsCounter_p5))) goto LA24_;
				prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1054);
			}
LA24_: ;
			genArgNoParam__cgen_u14798(p_p0, (*ri_p1)._kind_6.sons.p->data[i_p2], result_p4, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			(*argsCounter_p5) += ((NI)1);
		}
LA7_: ;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(paramType_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		{
			if (!!((((*typ_p3).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)0)))&63U)))!=0))) goto LA31_;
			liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*ri_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_1056, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1057, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA29_;
LA31_: ;
		{
			{
				if (!(((NI)0) < (*argsCounter_p5))) goto LA36_;
				prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1059);
			}
LA36_: ;
			genArgNoParam__cgen_u14798(p_p0, (*ri_p1)._kind_6.sons.p->data[i_p2], result_p4, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*argsCounter_p5) += ((NI)1);
		}
LA29_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genCppParamsForCtor__cgen_u4560)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_p1, NIM_BOOL* didGenTemp_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NI argsCounter_1;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin21_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	typ_1 = NIM_NIL;
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_365;
	argsCounter_1 = ((NI)0);
	typ_1 = skipTypes__ast_u5379((*(*call_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(call_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				{
					NIM_BOOL T7_;
					NIM_BOOL T8_;
					NimStringV2 colontmpD_;
					T7_ = (NIM_BOOL)0;
					T8_ = (NIM_BOOL)0;
					T8_ = ((*(*call_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27));
					if (!(T8_)) goto LA9_;
					T8_ = ((*(*(*call_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA9_: ;
					T7_ = T8_;
					if (!(T7_)) goto LA10_;
					T7_ = ((*(*(*(*call_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)])._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7));
LA10_: ;
					if (!T7_) goto LA11_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					{
						if (!(((NI)0) < argsCounter_1)) goto LA16_;
						prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_367);
					}
LA16_: ;
					colontmpD_ = genCppInitializer__cgen_u4564((*p_p0).module, p_p0, (*(*(*(*call_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)])._kind_4.sym).typ, didGenTemp_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
					{
						LA13_:;
					}
					{
						eqdestroy___system_u2691(colontmpD_);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA5_;
LA11_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* param_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T22_;
					param_1 = NIM_NIL;
					T22_ = NIM_NIL;
					{
						NIM_BOOL T25_;
						T25_ = (NIM_BOOL)0;
						T25_ = ((*(*typ_1).sons.p->data[i_1]).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
						if (!(T25_)) goto LA26_;
						T25_ = ((*(*call_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64));
LA26_: ;
						if (!T25_) goto LA27_;
						eqcopy___ast_u3255(&param_1, (*(*call_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					}
					goto LA23_;
LA27_: ;
					{
						eqcopy___ast_u3255(&param_1, (*call_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					}
LA23_: ;
					{
						NIM_BOOL T32_;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tempLoc_1;
						NIM_BOOL T37_;
						T32_ = (NIM_BOOL)0;
						T32_ = !(((*param_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42)));
						if (T32_) goto LA33_;
						T32_ = ((TM__MQdRN7fpbG7rPm4JpVVAhA_368[(NU)(((*(*param_1).typField).kind))>>3] &(1U<<((NU)(((*(*param_1).typField).kind))&7U)))!=0);
LA33_: ;
						if (!T32_) goto LA34_;
						nimZeroMem((void*)(&tempLoc_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						initLocExprSingleUse__cgen_u14116(p_p0, param_1, (&tempLoc_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
						T37_ = (NIM_BOOL)0;
						T37_ = (*didGenTemp_p2);
						if (T37_) goto LA38_;
						T37_ = (tempLoc_1.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1));
LA38_: ;
						(*didGenTemp_p2) = T37_;
						{
							LA36_:;
						}
						{
							oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u6284(tempLoc_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
							*nimErr_ = oldNimErrFin36_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					}
LA34_: ;
					genOtherArg__cgen_u14099(p_p0, call_p1, i_1, typ_1, (&result), (&argsCounter_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					{
						LA21_:;
					}
					{
						oldNimErrFin21_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(param_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin21_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA5_: ;
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genCppInitializer__cgen_u4564)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* prc_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, NIM_BOOL* didGenTemp_p3) {
	NimStringV2 result;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_363;
	{
		NIM_BOOL T3_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = contains__cgen_u4625((*(*(*m_p0).g).graph).initializersPerType, (*typ_p2).itemId);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		call_1 = NIM_NIL;
		T7_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
		T7_ = X5BX5D___cgen_u4964((&(*(*(*m_p0).g).graph).initializersPerType), (*typ_p2).itemId);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		eqcopy___ast_u3255(&call_1, (*T7_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_1;
			NimStringV2 colontmpD_;
			NimStringV2 T18_;
			if (!!((call_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA10_;
			p_1 = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			eqcopy___cgendata_u2074(&p_1, prc_p1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			{
				tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* colontmpD__2;
				tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* T17_;
				if (!(p_1 == ((tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A*) NIM_NIL))) goto LA15_;
				T17_ = NIM_NIL;
				T17_ = (tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A*) nimNewObj(sizeof(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A), NIM_ALIGNOF(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A));
				colontmpD__2 = eqdup___cgendata_u725(m_p0, NIM_TRUE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				(*T17_).module = colontmpD__2;
				(*T17_).labels = ((NI)0);
				eqsink___cgendata_u2082(&p_1, T17_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			}
LA15_: ;
			T18_.len = 0; T18_.p = NIM_NIL;
			colontmpD_ = genCppParamsForCtor__cgen_u4560(p_1, call_1, didGenTemp_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			T18_ = rawNewString(colontmpD_.len + 2);
appendString((&T18_), TM__MQdRN7fpbG7rPm4JpVVAhA_364);
appendString((&T18_), colontmpD_);
appendString((&T18_), TM__MQdRN7fpbG7rPm4JpVVAhA_1060);
			eqsink___system_u2700((&result), T18_);
			{
				if (!(prc_p1 == ((tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A*) NIM_NIL))) goto LA21_;
			}
LA21_: ;
			{
				LA12_:;
			}
			{
				oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___cgendata_u2071(p_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				*nimErr_ = oldNimErrFin12_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA10_: ;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(call_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, assignLocalVar__cgen_u13691)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 nl_1;
	NimStringV2 decl_1;
	NimStringV2 colontmpD_;
	NimStringV2 T2_;
	NimStringV2 T19_;
	NimStringV2* T20_;
	NimStringV2* T21_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nl_1.len = 0; nl_1.p = NIM_NIL;
	decl_1.len = 0; decl_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		if (!(((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0)) goto LA5_;
		nl_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_359;
	}
	goto LA3_;
LA5_: ;
	{
		nl_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_360;
	}
LA3_: ;
	decl_1 = localVarDecl__cgen_u13649(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NimStringV2 colontmpD__2;
		NIM_BOOL didGenTemp_1;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T11_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T11_) goto LA12_;
		T11_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA12_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA13_;
		T10_ = isOrHasImportedCppType__cgen_u1404((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA13_: ;
		if (!T10_) goto LA14_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		didGenTemp_1 = NIM_FALSE;
		colontmpD__2 = genCppInitializer__cgen_u4564((*p_p0).module, p_p0, (*n_p1).typField, (&didGenTemp_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		prepareAdd((&decl_1), colontmpD__2.len + 0);
appendString((&decl_1), colontmpD__2);
		{
			LA16_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA14_: ;
	T19_.len = 0; T19_.p = NIM_NIL;
	T19_ = rawNewString(nl_1.len + 1);
appendString((&T19_), TM__MQdRN7fpbG7rPm4JpVVAhA_1061);
appendString((&T19_), nl_1);
	colontmpD_ = T19_;
	prepareAdd((&decl_1), colontmpD_.len + 0);
appendString((&decl_1), colontmpD_);
	T20_ = (NimStringV2*)0;
	T20_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T20_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T21_ = (NimStringV2*)0;
	T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T21_)), decl_1.len + 0);
appendString((&(*T21_)), decl_1);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(decl_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseDisp__cgen_u14148)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	{
		NIM_BOOL T3_;
		tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T3_)) goto LA4_;
		T5_ = 0;
		T3_ = !(((IL64(8796093284416) & (*(*n_p1)._kind_4.sym).flags) == T5_));
LA4_: ;
		if (!T3_) goto LA6_;
		result = NIM_FALSE;
	}
	goto LA1_;
LA6_: ;
	{
		NIM_BOOL T9_;
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		T9_ = (NIM_BOOL)0;
		T9_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)51)))&63U)))!=0);
		if (T9_) goto LA10_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T12_)) goto LA13_;
		colontmpD_ = getModule__astalgo_u156((*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T12_ = (((*colontmpD_).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0);
LA13_: ;
		T11_ = T12_;
		if (!(T11_)) goto LA14_;
		T11_ = !((((*(*n_p1)._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)44)))&63U)))!=0));
LA14_: ;
		T9_ = T11_;
LA10_: ;
		if (!T9_) goto LA15_;
		result = canRaise__ast_u7516(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA15_: ;
	{
		result = canRaiseConservative__ast_u7504(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA, allPathsAsgnResult__cgen_u28217)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA result;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin56_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL oldNimErrFin90_;
NIM_BOOL oldNimErrFin81_;
NIM_BOOL oldNimErrFin134_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
			it_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA6;
						i_1 = i_2;
						eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						result = allPathsAsgnResult__cgen_u28217(p_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						{
							if (!!((result == ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0)))) goto LA9_;
							eqdestroy___ast_u3252(it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
LA9_: ;
						i_2 += ((NI)1);
					} LA6: ;
				}
			}
			{
				LA3_:;
			}
			{
				oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin3_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)74):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149):
	{
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T16_)) goto LA17_;
			T16_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11));
LA17_: ;
			if (!T16_) goto LA18_;
			{
				NIM_BOOL T22_;
				T22_ = (NIM_BOOL)0;
				T22_ = containsResult__cgen_u28141((*n_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!!(T22_)) goto LA23_;
				{
					tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA T27_;
					T27_ = (tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0;
					T27_ = allPathsAsgnResult__cgen_u28217(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!(T27_ == ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2))) goto LA28_;
					result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
				}
				goto LA25_;
LA28_: ;
				{
					result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1);
				}
LA25_: ;
			}
			goto LA20_;
LA23_: ;
			{
				result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
			}
LA20_: ;
		}
		goto LA14_;
LA18_: ;
		{
			NIM_BOOL T33_;
			T33_ = (NIM_BOOL)0;
			T33_ = containsResult__cgen_u28141(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T33_) goto LA34_;
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
		}
		goto LA14_;
LA34_: ;
		{
			result = allPathsAsgnResult__cgen_u28217(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)109):
	{
		{
			NI T40_;
			T40_ = (NI)0;
			T40_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(((NI)0) < T40_)) goto LA41_;
			{
				NIM_BOOL T45_;
				T45_ = (NIM_BOOL)0;
				T45_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
				if (!(T45_)) goto LA46_;
				T45_ = !((result == ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1)));
LA46_: ;
				if (!T45_) goto LA47_;
				result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
			}
			goto LA43_;
LA47_: ;
			{
				result = allPathsAsgnResult__cgen_u28217(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA43_: ;
		}
LA41_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)92):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)48):
	{
		NIM_BOOL exhaustive_1;
		exhaustive_1 = NIM_FALSE;
		result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1);
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_2;
			it_2 = NIM_NIL;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				i_4 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
						tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA aX60gensym7294__1;
						if (!(i_4 < colontmp__2)) goto LA55;
						colontmpD_ = NIM_NIL;
						i_3 = i_4;
						eqcopy___ast_u3255(&it_2, (*n_p1)._kind_6.sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
						{
							NIM_BOOL T59_;
							NI T60_;
							T59_ = (NIM_BOOL)0;
							T60_ = (NI)0;
							T60_ = len__ast_u3190(it_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
							T59_ = (T60_ == ((NI)2));
							if (!(T59_)) goto LA61_;
							T59_ = containsResult__cgen_u28141((*it_2)._kind_6.sons.p->data[((NI)0)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
LA61_: ;
							if (!T59_) goto LA62_;
							result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
							eqdestroy___ast_u3252(colontmpD_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
							eqdestroy___ast_u3252(it_2);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
LA62_: ;
						{
							NI T66_;
							T66_ = (NI)0;
							T66_ = len__ast_u3190(it_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
							if (!(T66_ == ((NI)1))) goto LA67_;
							exhaustive_1 = NIM_TRUE;
						}
LA67_: ;
						colontmpD_ = lastSon__ast_u5208(it_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
						aX60gensym7294__1 = allPathsAsgnResult__cgen_u28217(p_p0, colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
						switch (aX60gensym7294__1) {
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2):
						{
							result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
							eqdestroy___ast_u3252(colontmpD_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
							eqdestroy___ast_u3252(it_2);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
						break;
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1):
						{
						}
						break;
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0):
						{
							result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
						}
						break;
						default: __builtin_unreachable();
						}
						i_4 += ((NI)1);
						{
							LA56_:;
						}
						{
							oldNimErrFin56_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(colontmpD_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
							*nimErr_ = oldNimErrFin56_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					} LA55: ;
				}
			}
			{
				LA52_:;
			}
			{
				oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(it_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin52_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		{
			if (!!(exhaustive_1)) goto LA78_;
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
		}
LA78_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)97):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		NIM_BOOL exhaustive_2;
		colontmpD__2 = NIM_NIL;
		{
			NIM_BOOL T84_;
			T84_ = (NIM_BOOL)0;
			T84_ = containsResult__cgen_u28141((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			if (!T84_) goto LA85_;
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA85_: ;
		result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1);
		colontmpD__2 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1062);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		exhaustive_2 = !(((*colontmpD__2).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*colontmpD__2).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29)));
		{
			NI i_5;
			NI colontmp__3;
			NI i_6;
			i_5 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__3 = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			i_6 = ((NI)1);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_3;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
					tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA aX60gensym7300__1;
					if (!(i_6 < colontmp__3)) goto LA89;
					it_3 = NIM_NIL;
					colontmpD__3 = NIM_NIL;
					i_5 = i_6;
					eqcopy___ast_u3255(&it_3, (*n_p1)._kind_6.sons.p->data[i_5]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
					colontmpD__3 = lastSon__ast_u5208(it_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
					aX60gensym7300__1 = allPathsAsgnResult__cgen_u28217(p_p0, colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
					switch (aX60gensym7300__1) {
					case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2):
					{
						result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
						eqdestroy___ast_u3252(colontmpD__3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						eqdestroy___ast_u3252(it_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						eqdestroy___ast_u3378(colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
					break;
					case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1):
					{
					}
					break;
					case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0):
					{
						result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
					}
					break;
					default: __builtin_unreachable();
					}
					{
						if (!((*it_3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)88))) goto LA96_;
						exhaustive_2 = NIM_TRUE;
					}
LA96_: ;
					i_6 += ((NI)1);
					{
						LA90_:;
					}
					{
						oldNimErrFin90_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						eqdestroy___ast_u3252(it_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						*nimErr_ = oldNimErrFin90_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				} LA89: ;
			}
		}
		{
			if (!!(exhaustive_2)) goto LA102_;
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
		}
LA102_: ;
		{
			LA81_:;
		}
		{
			oldNimErrFin81_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin81_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)96):
	{
		result = allPathsAsgnResult__cgen_u28217(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!(result == ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0))) goto LA109_;
			result = allPathsAsgnResult__cgen_u28217(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				if (!(result == ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1))) goto LA113_;
				result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
			}
LA113_: ;
		}
LA109_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)122) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)123):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
		result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)156):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)158):
	{
		result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		{
			if (!((*(*n_p1)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11))) goto LA120_;
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
		}
LA120_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)106):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)154):
	{
		tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA aX60gensym7303__1;
		result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1);
		aX60gensym7303__1 = allPathsAsgnResult__cgen_u28217(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (aX60gensym7303__1) {
		case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2):
		{
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1):
		{
		}
		break;
		case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0):
		{
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
		}
		break;
		default: __builtin_unreachable();
		}
		{
			NI i_7;
			NI colontmp__4;
			NI i_8;
			i_7 = (NI)0;
			colontmp__4 = (NI)0;
			colontmp__4 = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_8 = ((NI)1);
			{
				while (1) {
					if (!(i_8 < colontmp__4)) goto LA128;
					i_7 = i_8;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
						if (!((*(*n_p1)._kind_6.sons.p->data[i_7]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107))) goto LA131_;
						colontmpD__4 = NIM_NIL;
						colontmpD__4 = lastSon__ast_u5208((*n_p1)._kind_6.sons.p->data[i_7]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						result = allPathsAsgnResult__cgen_u28217(p_p0, colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___ast_u3252(colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
					goto LA129_;
LA131_: ;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__5;
						tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA aX60gensym7307__1;
						colontmpD__5 = NIM_NIL;
						colontmpD__5 = lastSon__ast_u5208((*n_p1)._kind_6.sons.p->data[i_7]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
						aX60gensym7307__1 = allPathsAsgnResult__cgen_u28217(p_p0, colontmpD__5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
						switch (aX60gensym7307__1) {
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2):
						{
							result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
							eqdestroy___ast_u3252(colontmpD__5);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
						break;
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1):
						{
						}
						break;
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0):
						{
							result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
						}
						break;
						default: __builtin_unreachable();
						}
						{
							LA134_:;
						}
						{
							oldNimErrFin134_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(colontmpD__5);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							*nimErr_ = oldNimErrFin134_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA129_: ;
					i_8 += ((NI)1);
				} LA128: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		{
			NIM_BOOL T143_;
			NIM_BOOL T145_;
			T143_ = (NIM_BOOL)0;
			T143_ = canRaiseDisp__cgen_u14148(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (T143_) goto LA144_;
			T145_ = (NIM_BOOL)0;
			T145_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T145_)) goto LA146_;
			T145_ = (((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)16)))&63U)))!=0);
LA146_: ;
			T143_ = T145_;
LA144_: ;
			if (!T143_) goto LA147_;
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
		}
		goto LA141_;
LA147_: ;
		{
			NIM_BOOL T150_;
			NIM_BOOL T151_;
			T150_ = (NIM_BOOL)0;
			T151_ = (NIM_BOOL)0;
			T151_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T151_)) goto LA152_;
			T151_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic >= ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)93) && (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic <= ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)95) || (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic >= ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)46) && (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic <= ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)52));
LA152_: ;
			T150_ = T151_;
			if (!(T150_)) goto LA153_;
			T150_ = (((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0);
LA153_: ;
			if (!T150_) goto LA154_;
			result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
		}
		goto LA141_;
LA154_: ;
		{
			{
				NI i_9;
				NI colontmp__5;
				NI i_10;
				i_9 = (NI)0;
				colontmp__5 = (NI)0;
				colontmp__5 = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_10 = ((NI)0);
				{
					while (1) {
						tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA aX60gensym7318__1;
						if (!(i_10 < colontmp__5)) goto LA159;
						i_9 = i_10;
						aX60gensym7318__1 = allPathsAsgnResult__cgen_u28217(p_p0, (*n_p1)._kind_6.sons.p->data[i_9]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						switch (aX60gensym7318__1) {
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2):
						{
							result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
							goto BeforeRet_;
						}
						break;
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1):
						{
						}
						break;
						case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0):
						{
							result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
						}
						break;
						default: __builtin_unreachable();
						}
						i_10 += ((NI)1);
					} LA159: ;
				}
			}
		}
LA141_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)108):
	{
		result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)68):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)69):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)70):
	{
		result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
	}
	break;
	default:
	{
		{
			NI i_11;
			NI colontmp__6;
			NI i_12;
			i_11 = (NI)0;
			colontmp__6 = (NI)0;
			colontmp__6 = safeLen__ast_u3197(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_12 = ((NI)0);
			{
				while (1) {
					tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA aX60gensym7320__1;
					if (!(i_12 < colontmp__6)) goto LA168;
					i_11 = i_12;
					aX60gensym7320__1 = allPathsAsgnResult__cgen_u28217(p_p0, (*n_p1)._kind_6.sons.p->data[i_11]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					switch (aX60gensym7320__1) {
					case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2):
					{
						result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)2);
						goto BeforeRet_;
					}
					break;
					case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1):
					{
					}
					break;
					case ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0):
					{
						result = ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0);
					}
					break;
					default: __builtin_unreachable();
					}
					i_12 += ((NI)1);
				} LA168: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initLocalVar__cgen_u13552)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, NIM_BOOL immediateAsgn_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!((((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0))) goto LA3_;
		{
			if (!!(immediateAsgn_p2)) goto LA7_;
			constructLoc__cgen_u13487(p_p0, (&(*v_p1).loc), NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, fillResult__cgen_u1887)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* param_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* proctype_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	fillLoc__cgen_u78((&(*(*param_p1)._kind_4.sym).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)4), param_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1069, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3381(&t_1, (*(*param_p1)._kind_4.sym).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T5_;
		T4_ = (NIM_BOOL)0;
		T5_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		T5_ = mapReturnType__cgen_u1369(conf_p0, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !((T5_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17)));
		if (!(T4_)) goto LA6_;
		T4_ = isInvalidReturnType__cgen_u1424(conf_p0, proctype_p2, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA6_: ;
		if (!T4_) goto LA7_;
		(*(*param_p1)._kind_4.sym).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
		(*(*param_p1)._kind_4.sym).loc.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0);
	}
LA7_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, scopeMangledParam__cgen_u1246)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p1) {
	NimStringV2 key_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	key_1.len = 0; key_1.p = NIM_NIL;
	key_1 = mangle__mangleutils_u4((*(*param_p1).name).s);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	inc__cgen_u1077((&(*p_p0).sigConflicts), key_1, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(key_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, assignParam__cgen_u14044)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* retType_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	scopeMangledParam__cgen_u1246(p_p0, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeResetN__cgen_u13098)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 accessor_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3) {
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin50_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(n_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	switch ((*n_p2).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)138):
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i_1 = i_2;
					specializeResetN__cgen_u13098(p_p0, accessor_p1, (*n_p2)._kind_6.sons.p->data[i_1], typ_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA8: ;
			}
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)139):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* disc_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		NimStringV2* T23_;
		NimStringV2* T24_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T25_;
		NimStringV2* T43_;
		NimStringV2* T44_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T45_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T46_;
		disc_1 = NIM_NIL;
		colontmpD_ = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		{
			if (!!(((*(*n_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA13_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1100, TM__MQdRN7fpbG7rPm4JpVVAhA_1101);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA13_: ;
		eqcopy___ast_u4577(&disc_1, (*(*n_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			if (!((*disc_1).loc.snippet.len == 0)) goto LA17_;
			fillObjectFields__cgen_u5401((*p_p0).module, typ_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA17_: ;
		{
			colontmpD_ = t__cgen_u97((*disc_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			if (!(colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA21_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1104, TM__MQdRN7fpbG7rPm4JpVVAhA_1105);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA21_: ;
		T23_ = (NimStringV2*)0;
		T23_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		addIndent__cgen_u315(p_p0, T23_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T24_ = (NimStringV2*)0;
		T24_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T25_[0] = accessor_p1;
		T25_[1] = (*disc_1).loc.snippet;
		colontmpD__2 = percent___cgen_u9574(T25_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&(*T24_)), colontmpD__2.len + 0);
appendString((&(*T24_)), colontmpD__2);
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			i_4 = ((NI)1);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__6;
					NimStringV2 colontmpD__7;
					NimStringV2* T38_;
					NimStringV2* T39_;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T40_;
					if (!(i_4 < colontmp__2)) goto LA28;
					branch_1 = NIM_NIL;
					colontmpD__6 = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					i_3 = i_4;
					eqcopy___ast_u3255(&branch_1, (*n_p2)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					{
						if (!((*branch_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA32_;
						genCaseRange__cgen_u9543(p_p0, branch_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					}
					goto LA30_;
LA32_: ;
					{
						NimStringV2 colontmpD__8;
						NimStringV2* T35_;
						NimStringV2* T36_;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T37_;
						colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
						T35_ = (NimStringV2*)0;
						T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						addIndent__cgen_u315(p_p0, T35_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						T36_ = (NimStringV2*)0;
						T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						colontmpD__8 = percent___cgen_u9596(T37_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						prepareAdd((&(*T36_)), colontmpD__8.len + 0);
appendString((&(*T36_)), colontmpD__8);
						eqdestroy___system_u2691(colontmpD__8);
					}
LA30_: ;
					colontmpD__6 = lastSon__ast_u5208(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					specializeResetN__cgen_u13098(p_p0, accessor_p1, colontmpD__6, typ_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					T38_ = (NimStringV2*)0;
					T38_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					addIndent__cgen_u315(p_p0, T38_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					T39_ = (NimStringV2*)0;
					T39_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					colontmpD__7 = percent___cgen_u9601(T40_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
					prepareAdd((&(*T39_)), colontmpD__7.len + 0);
appendString((&(*T39_)), colontmpD__7);
					i_4 += ((NI)1);
					{
						LA29_:;
					}
					{
						oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___ast_u3252(colontmpD__6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						eqdestroy___ast_u3252(branch_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						*nimErr_ = oldNimErrFin29_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				} LA28: ;
			}
		}
		T43_ = (NimStringV2*)0;
		T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		addIndent__cgen_u315(p_p0, T43_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T44_ = (NimStringV2*)0;
		T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		colontmpD__3 = percent___cgen_u9606(T45_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&(*T44_)), colontmpD__3.len + 0);
appendString((&(*T44_)), colontmpD__3);
		T46_[0] = accessor_p1;
		T46_[1] = (*disc_1).loc.snippet;
		colontmpD__4 = percent___cgen_u9620(T46_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		colontmpD__5 = t__cgen_u97((*disc_1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		specializeResetT__cgen_u13094(p_p0, colontmpD__4, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(disc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
		NimStringV2 colontmpD__10;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T63_;
		field_1 = NIM_NIL;
		colontmpD__9 = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11 = NIM_NIL;
		eqcopy___ast_u4577(&field_1, (*n_p2)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		{
			if (!((*(*field_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63))) goto LA53_;
			eqdestroy___ast_u3378(colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___ast_u3378(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA53_: ;
		{
			if (!((*field_1).loc.snippet.len == 0)) goto LA57_;
			fillObjectFields__cgen_u5401((*p_p0).module, typ_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		}
LA57_: ;
		{
			colontmpD__9 = t__cgen_u97((*field_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			if (!(colontmpD__9 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA61_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1106, TM__MQdRN7fpbG7rPm4JpVVAhA_1107);
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		}
LA61_: ;
		T63_[0] = accessor_p1;
		T63_[1] = (*field_1).loc.snippet;
		colontmpD__10 = percent___cgen_u9620(T63_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		colontmpD__11 = t__cgen_u97((*field_1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		specializeResetT__cgen_u13094(p_p0, colontmpD__10, colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		{
			LA50_:;
		}
		{
			oldNimErrFin50_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___ast_u3378(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin50_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1108, TM__MQdRN7fpbG7rPm4JpVVAhA_1109);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeResetT__cgen_u13094)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 accessor_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2) {
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin23_;
NIM_BOOL oldNimErrFin54_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(typ_p2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	switch ((*typ_p2).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)55):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = skipModifier__ast_u5338(typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		specializeResetT__cgen_u13094(p_p0, accessor_p1, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw i_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		NimStringV2 res_1;
		NimStringV2 res_2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		NimStringV2 colontmpD__5;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arraySize_1;
		NimStringV2* T11_;
		NimStringV2* T12_;
		NimStringV2* T17_;
		NimStringV2* T18_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T19_;
		colontmpD__2 = NIM_NIL;
		nimZeroMem((void*)(&i_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__3 = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__2 = indexType__ast_u5345(typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		arraySize_1 = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		colontmpD__3 = getSysType__magicsys_u55((*(*(*p_p0).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		getTemp__cgen_u9546(p_p0, colontmpD__3, NIM_FALSE, (&i_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T11_ = (NimStringV2*)0;
		T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		addIndent__cgen_u315(p_p0, T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T12_ = (NimStringV2*)0;
		T12_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1085);
		cgFormatValue__cgen_u163((&res_1), i_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1086);
		cgFormatValue__cgen_u163((&res_1), i_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1087);
		cgFormatValue__cgen_u169((&res_1), arraySize_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1088);
		cgFormatValue__cgen_u163((&res_1), i_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1089);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA15_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1090);
		}
LA15_: ;
		prepareAdd((&(*T12_)), res_1.len + 0);
appendString((&(*T12_)), res_1);
		res_2 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_2), accessor_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1091);
		cgFormatValue__cgen_u163((&res_2), i_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1092);
		colontmpD__4 = elementType__ast_u5331(typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		specializeResetT__cgen_u13094(p_p0, res_2, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T17_ = (NimStringV2*)0;
		T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		addIndent__cgen_u315(p_p0, T17_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T18_ = (NimStringV2*)0;
		T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		colontmpD__5 = percent___cgen_u9681(T19_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&(*T18_)), colontmpD__5.len + 0);
appendString((&(*T18_)), colontmpD__5);
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(res_2);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(i_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* x_1;
		NimStringV2 colontmpD__6;
		x_1 = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		x_1 = baseClass__ast_u5348(typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T28_;
			if (!!((x_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA26_;
			T28_ = NIM_NIL;
			T28_ = skipTypes__ast_u5379(x_1, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T28_); goto LA23_;}
			eqsink___ast_u3387(&x_1, T28_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		}
LA26_: ;
		colontmpD__6 = parentObj__cgen_u9625(accessor_p1, (*p_p0).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		specializeResetT__cgen_u13094(p_p0, colontmpD__6, x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		{
			if (!!(((*typ_p2).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA31_;
			{
				NIM_BOOL T35_;
				NimStringV2 res_3;
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2* T40_;
				NimStringV2* T41_;
				T35_ = (NIM_BOOL)0;
				T35_ = !(((*typ_p2).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
				if (!(T35_)) goto LA36_;
				T35_ = (((*(*typ_p2).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0);
LA36_: ;
				if (!T35_) goto LA37_;
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				T40_ = (NimStringV2*)0;
				T40_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				addIndent__cgen_u315(p_p0, T40_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				T41_ = (NimStringV2*)0;
				T41_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				res_3 = rawNewString(((NI)80));
				colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1093);
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				prepareAdd((&res_3), 10);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1095);
				cgFormatValue__cgen_u163((&res_3), accessor_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1096);
				colontmpD__8 = getTypeDesc__cgen_u8738((*p_p0).module, typ_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1097);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA44_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1098);
				}
LA44_: ;
				prepareAdd((&(*T41_)), res_3.len + 0);
appendString((&(*T41_)), res_3);
				{
					LA39_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
					eqdestroy___system_u2691(res_3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			}
			goto LA33_;
LA37_: ;
			{
				specializeResetN__cgen_u13098(p_p0, accessor_p1, (*typ_p2).n, typ_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			}
LA33_: ;
		}
LA31_: ;
		{
			LA23_:;
		}
		{
			oldNimErrFin23_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___ast_u3378(x_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin23_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
		typ_2 = NIM_NIL;
		eqcopy___ast_u3381(&typ_2, typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_1;
			NI i_2;
			a_1 = NIM_NIL;
			i_2 = (NI)0;
			{
				NI i_3;
				NI colontmp_;
				NI T56_;
				NI i_4;
				i_3 = (NI)0;
				colontmp_ = (NI)0;
				T56_ = (*typ_2).sons.len;
				colontmp_ = T56_;
				i_4 = ((NI)0);
				{
					while (1) {
						NimStringV2 res_4;
						if (!(i_4 < colontmp_)) goto LA58;
						res_4.len = 0; res_4.p = NIM_NIL;
						i_3 = i_4;
						i_2 = i_3;
						eqcopy___ast_u3381(&a_1, (*typ_2).sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
						res_4 = rawNewString(((NI)80));
						cgFormatValue__cgen_u163((&res_4), accessor_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
						prepareAdd((&res_4), 6);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1110);
						cgFormatValue__cgen_u166((&res_4), ((NI64) (i_2)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
						specializeResetT__cgen_u13094(p_p0, res_4, a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
						i_4 += ((NI)1);
						{
							LA59_:;
						}
						{
							eqdestroy___system_u2691(res_4);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					} LA58: ;
				}
			}
			{
				LA54_:;
			}
			{
				oldNimErrFin54_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				*nimErr_ = oldNimErrFin54_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		}
		{
			LA52_:;
		}
		{
			oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin52_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		NimStringV2 res_5;
		NimStringV2 colontmpD__9;
		NimStringV2* T68_;
		NimStringV2* T69_;
		res_5.len = 0; res_5.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		T68_ = (NimStringV2*)0;
		T68_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		addIndent__cgen_u315(p_p0, T68_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		T69_ = (NimStringV2*)0;
		T69_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		res_5 = rawNewString(((NI)80));
		colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1111);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		prepareAdd((&res_5), 10);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1112);
		cgFormatValue__cgen_u163((&res_5), accessor_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
		prepareAdd((&res_5), 11);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1114);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA72_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1115);
		}
LA72_: ;
		prepareAdd((&(*T69_)), res_5.len + 0);
appendString((&(*T69_)), res_5);
		{
			LA67_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(res_5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		{
			NimStringV2 res_6;
			NimStringV2 colontmpD__10;
			NimStringV2 res_7;
			NimStringV2* T82_;
			NimStringV2* T83_;
			NimStringV2* T88_;
			NimStringV2* T89_;
			if (!((*typ_p2).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9))) goto LA79_;
			res_6.len = 0; res_6.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			res_7.len = 0; res_7.p = NIM_NIL;
			T82_ = (NimStringV2*)0;
			T82_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			addIndent__cgen_u315(p_p0, T82_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			T83_ = (NimStringV2*)0;
			T83_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			res_6 = rawNewString(((NI)80));
			colontmpD__10 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1116);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			prepareAdd((&res_6), 10);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1117);
			cgFormatValue__cgen_u163((&res_6), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			prepareAdd((&res_6), 17);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1119);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA86_;
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1120);
			}
LA86_: ;
			prepareAdd((&(*T83_)), res_6.len + 0);
appendString((&(*T83_)), res_6);
			T88_ = (NimStringV2*)0;
			T88_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			addIndent__cgen_u315(p_p0, T88_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			T89_ = (NimStringV2*)0;
			T89_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			res_7 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_7), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			prepareAdd((&res_7), 17);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1122);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA92_;
				prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1123);
			}
LA92_: ;
			prepareAdd((&(*T89_)), res_7.len + 0);
appendString((&(*T89_)), res_7);
			{
				LA81_:;
			}
			{
				eqdestroy___system_u2691(res_7);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(res_6);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA77_;
LA79_: ;
		{
			NimStringV2 res_8;
			NimStringV2* T97_;
			NimStringV2* T98_;
			res_8.len = 0; res_8.p = NIM_NIL;
			T97_ = (NimStringV2*)0;
			T97_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			addIndent__cgen_u315(p_p0, T97_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T98_ = (NimStringV2*)0;
			T98_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			res_8 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_8), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&res_8), 11);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1125);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA101_;
				prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1126);
			}
LA101_: ;
			prepareAdd((&(*T98_)), res_8.len + 0);
appendString((&(*T98_)), res_8);
			eqdestroy___system_u2691(res_8);
		}
LA77_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		NimStringV2 res_9;
		NimStringV2* T104_;
		NimStringV2* T105_;
		res_9.len = 0; res_9.p = NIM_NIL;
		T104_ = (NimStringV2*)0;
		T104_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		addIndent__cgen_u315(p_p0, T104_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T105_ = (NimStringV2*)0;
		T105_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		res_9 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_9), accessor_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_9), 5);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_1127);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA108_;
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_1128);
		}
LA108_: ;
		prepareAdd((&(*T105_)), res_9.len + 0);
appendString((&(*T105_)), res_9);
		eqdestroy___system_u2691(res_9);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	{
		NimStringV2 res_10;
		NimStringV2* T111_;
		NimStringV2* T112_;
		res_10.len = 0; res_10.p = NIM_NIL;
		T111_ = (NimStringV2*)0;
		T111_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		addIndent__cgen_u315(p_p0, T111_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T112_ = (NimStringV2*)0;
		T112_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		res_10 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_10), accessor_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_10), 11);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_1129);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA115_;
			prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_1130);
		}
LA115_: ;
		prepareAdd((&(*T112_)), res_10.len + 0);
appendString((&(*T112_)), res_10);
		eqdestroy___system_u2691(res_10);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T118_;
		T118_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		T118_ = mapSetType__cgen_u1311((*(*(*p_p0).module).g).config, typ_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (T118_) {
		case ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17):
		{
			NimStringV2 res_11;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2* T121_;
			NimStringV2* T122_;
			res_11.len = 0; res_11.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			T121_ = (NimStringV2*)0;
			T121_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			addIndent__cgen_u315(p_p0, T121_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			T122_ = (NimStringV2*)0;
			T122_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			res_11 = rawNewString(((NI)80));
			colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1131);
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			cgFormatValue__cgen_u163((&res_11), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_1132);
			cgFormatValue__cgen_u163((&res_11), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			prepareAdd((&res_11), 9);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_1133);
			colontmpD__12 = getTypeDesc__cgen_u8738((*p_p0).module, typ_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			cgFormatValue__cgen_u163((&res_11), colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
			prepareAdd((&res_11), 3);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_1134);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA125_;
				prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_1135);
			}
LA125_: ;
			prepareAdd((&(*T122_)), res_11.len + 0);
appendString((&(*T122_)), res_11);
			{
				LA120_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(res_11);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)4):
		case ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)5):
		case ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)6):
		case ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)7):
		{
			NimStringV2 res_12;
			NimStringV2* T130_;
			NimStringV2* T131_;
			res_12.len = 0; res_12.p = NIM_NIL;
			T130_ = (NimStringV2*)0;
			T130_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			addIndent__cgen_u315(p_p0, T130_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T131_ = (NimStringV2*)0;
			T131_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			res_12 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_12), accessor_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&res_12), 5);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_1136);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA134_;
				prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_1137);
			}
LA134_: ;
			prepareAdd((&(*T131_)), res_12.len + 0);
appendString((&(*T131_)), res_12);
			eqdestroy___system_u2691(res_12);
		}
		break;
		default:
		{
			raiseAssert__stdZassertions_u15(TM__MQdRN7fpbG7rPm4JpVVAhA_1139);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)3):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)6):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)9):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)15):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)30):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)50):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)51):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)52):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)53):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)54):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)56):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)58):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)59):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)61):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)62):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)64):
	{
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, specializeReset__cgen_u13357)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1) {
	NimStringV2 colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD_ = rdLoc__cgen_u470(a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = t__cgen_u97(a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	specializeResetT__cgen_u13094(p_p0, colontmpD_, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, resetLoc__cgen_u13360)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* loc_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	NIM_BOOL containsGcRef_1;
	NIM_BOOL T2_;
NIM_BOOL oldNimErrFin49_;
NIM_BOOL oldNimErrFin68_;
NIM_BOOL oldNimErrFin92_;
NIM_BOOL oldNimErrFin72_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	typ_1 = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	T2_ = (NIM_BOOL)0;
	T2_ = !((((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0));
	if (!(T2_)) goto LA3_;
	colontmpD_ = t__cgen_u97((*loc_p1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = containsGarbageCollectedRef__types_u555(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA3_: ;
	containsGcRef_1 = T2_;
	colontmpD__2 = t__cgen_u97((*loc_p1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	typ_1 = skipTypes__ast_u5379(colontmpD__2, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T6_;
		NimStringV2 res_1;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NIM_BOOL didGenTemp_1;
		NimStringV2* T10_;
		NimStringV2* T11_;
		T6_ = (NIM_BOOL)0;
		T6_ = isImportedCppType__cgen_u1384(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T6_) goto LA7_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		didGenTemp_1 = NIM_FALSE;
		T10_ = (NimStringV2*)0;
		T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		addIndent__cgen_u315(p_p0, T10_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T11_ = (NimStringV2*)0;
		T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		res_1 = rawNewString(((NI)80));
		colontmpD__3 = rdLoc__cgen_u470((*loc_p1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1070);
		colontmpD__4 = genCppInitializer__cgen_u4564((*p_p0).module, p_p0, typ_1, (&didGenTemp_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1071);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA14_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1072);
		}
LA14_: ;
		prepareAdd((&(*T11_)), res_1.len + 0);
appendString((&(*T11_)), res_1);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	{
		NIM_BOOL T20_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* atyp_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		T20_ = (NIM_BOOL)0;
		T20_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
		if (!(T20_)) goto LA21_;
		T20_ = ((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28) || (*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24));
LA21_: ;
		if (!T20_) goto LA22_;
		atyp_1 = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__5 = t__cgen_u97((*loc_p1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		atyp_1 = skipTypes__ast_u5379(colontmpD__5, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2* T28_;
			NimStringV2* T29_;
			if (!((*atyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*atyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47))) goto LA26_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			T28_ = (NimStringV2*)0;
			T28_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T28_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T29_ = (NimStringV2*)0;
			T29_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			res_2 = rawNewString(((NI)80));
			colontmpD__6 = rdLoc__cgen_u470((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_2), 11);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1074);
			colontmpD__7 = rdLoc__cgen_u470((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_2), 14);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1076);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA32_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1077);
			}
LA32_: ;
			prepareAdd((&(*T29_)), res_2.len + 0);
appendString((&(*T29_)), res_2);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(res_2);
		}
		goto LA24_;
LA26_: ;
		{
			NimStringV2 res_3;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2* T35_;
			NimStringV2* T36_;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			T35_ = (NimStringV2*)0;
			T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T35_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T36_ = (NimStringV2*)0;
			T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			res_3 = rawNewString(((NI)80));
			colontmpD__8 = rdLoc__cgen_u470((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 10);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1078);
			colontmpD__9 = rdLoc__cgen_u470((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 13);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1079);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA39_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1080);
			}
LA39_: ;
			prepareAdd((&(*T36_)), res_3.len + 0);
appendString((&(*T36_)), res_3);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(res_3);
		}
LA24_: ;
		eqdestroy___ast_u3378(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3378(atyp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA18_;
LA22_: ;
	{
		NIM_BOOL T42_;
		T42_ = (NIM_BOOL)0;
		T42_ = isComplexValueType__cgen_u13074(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T42_)) goto LA43_;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw nilLoc_1;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T50_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T51_;
			if (!containsGcRef_1) goto LA47_;
			nimZeroMem((void*)(&nilLoc_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			T50_ = 0;
			nimZeroMem((void*)(&T51_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1), (*loc_p1).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2), T50_, (&T51_));
			nilLoc_1 = T51_;
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			eqsink___system_u2700((&nilLoc_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_1081);
			genRefAssign__cgen_u13070(p_p0, (*loc_p1), nilLoc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			{
				LA49_:;
			}
			{
				oldNimErrFin49_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(nilLoc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin49_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA45_;
LA47_: ;
		{
			NimStringV2 res_4;
			NimStringV2 colontmpD__10;
			NimStringV2* T55_;
			NimStringV2* T56_;
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T55_ = (NimStringV2*)0;
			T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T55_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T56_ = (NimStringV2*)0;
			T56_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			res_4 = rawNewString(((NI)80));
			colontmpD__10 = rdLoc__cgen_u470((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 5);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1083);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA59_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1084);
			}
LA59_: ;
			prepareAdd((&(*T56_)), res_4.len + 0);
appendString((&(*T56_)), res_4);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(res_4);
		}
LA45_: ;
	}
	goto LA18_;
LA43_: ;
	{
		{
			NIM_BOOL T64_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
			T64_ = (NIM_BOOL)0;
			T64_ = !(((*loc_p1).storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2)));
			if (!(T64_)) goto LA65_;
			T64_ = containsGcRef_1;
LA65_: ;
			if (!T64_) goto LA66_;
			colontmpD__11 = NIM_NIL;
			specializeReset__cgen_u13357(p_p0, (*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
			colontmpD__11 = t__cgen_u97((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
			genObjectInit__cgen_u12909(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2), colontmpD__11, loc_p1, ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
			{
				LA68_:;
			}
			{
				oldNimErrFin68_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin68_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA62_;
LA66_: ;
		{
			NimStringV2 tyDesc_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__12;
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__13;
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__14;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__15;
			tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T73_;
			tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q T79_;
			tyDesc_1.len = 0; tyDesc_1.p = NIM_NIL;
			colontmpD__12 = NIM_NIL;
			colontmpD__13 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			colontmpD__14 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			colontmpD__15 = NIM_NIL;
			colontmpD__12 = t__cgen_u97((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
			T73_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
			{
				if (!((*(*loc_p1).lode).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA76_;
				colontmpD__13 = (*(*(*loc_p1).lode)._kind_4.sym).kind;
				T73_ = colontmpD__13;
			}
			goto LA74_;
LA76_: ;
			{
				colontmpD__14 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
				T73_ = colontmpD__14;
			}
LA74_: ;
			T79_ = (tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0;
			T79_ = descKindFromSymKind__cgen_u735(T73_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
			tyDesc_1 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__12, T79_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
			{
				NIM_BOOL T82_;
				NIM_BOOL T83_;
				T82_ = (NIM_BOOL)0;
				T83_ = (NIM_BOOL)0;
				T83_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T83_) goto LA84_;
				T83_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA84_: ;
				T82_ = T83_;
				if (!(T82_)) goto LA85_;
				T82_ = isOrHasImportedCppType__cgen_u1404(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
LA85_: ;
				if (!T82_) goto LA86_;
				{
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__16;
					NimStringV2 res_5;
					NimStringV2 colontmpD__17;
					NimStringV2 colontmpD__18;
					NimStringV2 colontmpD__19;
					NimStringV2* T93_;
					NimStringV2* T94_;
					if (!(((*loc_p1).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0)))&15U)))!=0)) goto LA90_;
					nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					colontmpD__16 = NIM_NIL;
					res_5.len = 0; res_5.p = NIM_NIL;
					colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
					colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
					colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
					colontmpD__16 = t__cgen_u97((*loc_p1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					getTemp__cgen_u9546(p_p0, colontmpD__16, NIM_FALSE, (&tmp_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					T93_ = (NimStringV2*)0;
					T93_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					addIndent__cgen_u315(p_p0, T93_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					T94_ = (NimStringV2*)0;
					T94_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					res_5 = rawNewString(((NI)80));
					colontmpD__17 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1140);
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					cgFormatValue__cgen_u163((&res_5), colontmpD__17);
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					prepareAdd((&res_5), 8);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1141);
					colontmpD__18 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*loc_p1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					cgFormatValue__cgen_u163((&res_5), colontmpD__18);
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					prepareAdd((&res_5), 19);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1142);
					colontmpD__19 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					cgFormatValue__cgen_u163((&res_5), colontmpD__19);
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					prepareAdd((&res_5), 9);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1143);
					cgFormatValue__cgen_u163((&res_5), tyDesc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
					prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1144);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA97_;
						prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1145);
					}
LA97_: ;
					prepareAdd((&(*T94_)), res_5.len + 0);
appendString((&(*T94_)), res_5);
					{
						LA92_:;
					}
					{
						oldNimErrFin92_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__19);
						eqdestroy___system_u2691(colontmpD__18);
						eqdestroy___system_u2691(colontmpD__17);
						eqdestroy___system_u2691(res_5);
						eqdestroy___ast_u3378(colontmpD__16);
						if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
						eqdestroy___ast_u6284(tmp_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
						*nimErr_ = oldNimErrFin92_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
				}
LA90_: ;
			}
			goto LA80_;
LA86_: ;
			{
				NimStringV2 res_6;
				NimStringV2 colontmpD__20;
				NimStringV2 colontmpD__21;
				NimStringV2* T103_;
				NimStringV2* T104_;
				res_6.len = 0; res_6.p = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				T103_ = (NimStringV2*)0;
				T103_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				addIndent__cgen_u315(p_p0, T103_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				T104_ = (NimStringV2*)0;
				T104_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				res_6 = rawNewString(((NI)80));
				colontmpD__20 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1146);
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__20);
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				prepareAdd((&res_6), 8);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1147);
				colontmpD__21 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*loc_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__21);
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				prepareAdd((&res_6), 9);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1148);
				cgFormatValue__cgen_u163((&res_6), tyDesc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				prepareAdd((&res_6), 3);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1149);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA107_;
					prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1150);
				}
LA107_: ;
				prepareAdd((&(*T104_)), res_6.len + 0);
appendString((&(*T104_)), res_6);
				{
					LA102_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__21);
					eqdestroy___system_u2691(colontmpD__20);
					eqdestroy___system_u2691(res_6);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
			}
LA80_: ;
			colontmpD__15 = t__cgen_u97((*loc_p1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
			genObjectInit__cgen_u12909(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2), colontmpD__15, loc_p1, ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
			{
				LA72_:;
			}
			{
				oldNimErrFin72_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__15);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3378(colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(tyDesc_1);
				*nimErr_ = oldNimErrFin72_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA62_: ;
	}
LA18_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, closureSetup__cgen_u28093)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ls_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* env_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ls_1 = NIM_NIL;
	env_1 = NIM_NIL;
	{
		if (!!((((*(*prc_p1).typ).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)12)))&63U)))!=0))) goto LA4_;
		eqdestroy___ast_u4574(env_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ls_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	ls_1 = lastSon__ast_u5208((*(*prc_p1).ast)._kind_6.sons.p->data[((NI)3)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!(((*ls_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA8_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*prc_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1152, TM__MQdRN7fpbG7rPm4JpVVAhA_1153);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	eqcopy___ast_u4577(&env_1, (*ls_1)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	assignLocalVar__cgen_u13691(p_p0, ls_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2* T15_;
		NimStringV2* T16_;
		if (!((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10))) goto LA12_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T15_ = (NimStringV2*)0;
		T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		addIndent__cgen_u315(p_p0, T15_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T16_ = (NimStringV2*)0;
		T16_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1154);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1155);
		colontmpD__2 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*env_1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1157);
		colontmpD__3 = getTypeDesc__cgen_u8738((*p_p0).module, (*env_1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1159);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA19_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1160);
		}
LA19_: ;
		prepareAdd((&(*T16_)), res_1.len + 0);
appendString((&(*T16_)), res_1);
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
LA12_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2* T25_;
		NimStringV2* T26_;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T25_ = (NimStringV2*)0;
		T25_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		addIndent__cgen_u315(p_p0, T25_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		T26_ = (NimStringV2*)0;
		T26_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		res_2 = rawNewString(((NI)80));
		colontmpD__4 = rdLoc__cgen_u470((*env_1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1161);
		colontmpD__5 = getTypeDesc__cgen_u8738((*p_p0).module, (*env_1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1163);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA29_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1164);
		}
LA29_: ;
		prepareAdd((&(*T26_)), res_2.len + 0);
appendString((&(*T26_)), res_2);
		{
			LA24_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(env_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ls_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcBody__cgen_u28369)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* procBody_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	genStmts__cgen_u14081(p_p0, procBody_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 res_1;
		NimStringV2 res_2;
		NimStringV2 colontmpD_;
		if (!((112 & (*p_p0).flags) == 16)) goto LA3_;
		res_1.len = 0; res_1.p = NIM_NIL;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)5))) & 7);
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 18);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1166);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA8_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1167);
		}
LA8_: ;
		prepareAdd((&(*p_p0).blocks.p->data[((NI)0)].sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0))- 0]), res_1.len + 0);
appendString((&(*p_p0).blocks.p->data[((NI)0)].sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0))- 0]), res_1);
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1169);
		colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1171);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		cgFormatValue__cgen_u163((&res_2), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1173);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA12_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1174);
		}
LA12_: ;
		prepareAdd((&(*p_p0).blocks.p->data[((NI)0)].sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1))- 0]), res_2.len + 0);
appendString((&(*p_p0).blocks.p->data[((NI)0)].sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1))- 0]), res_2);
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_2);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_u370)(NimStringV2* r_p0, NI32 fileIdx_p1, NI line_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*conf_p3).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = (((NI)0) < line_p2);
LA4_: ;
		if (!T3_) goto LA5_;
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 T11_;
			if (!(fileIdx_p1 == ((NI32)-1))) goto LA9_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T11_.len = 0; T11_.p = NIM_NIL;
			colontmpD_ = dollar___systemZdollars_u9(line_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T11_ = rawNewString(colontmpD_.len + 38);
appendString((&T11_), TM__MQdRN7fpbG7rPm4JpVVAhA_1176);
appendString((&T11_), colontmpD_);
appendString((&T11_), TM__MQdRN7fpbG7rPm4JpVVAhA_1177);
			colontmpD__2 = T11_;
			prepareAdd((&(*r_p0)), colontmpD__2.len + 0);
appendString((&(*r_p0)), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA7_;
LA9_: ;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 T13_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T13_.len = 0; T13_.p = NIM_NIL;
			colontmpD__3 = dollar___systemZdollars_u9(line_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__4 = dollar___systemZdollars_u24(fileIdx_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T13_ = rawNewString(colontmpD__3.len + colontmpD__4.len + 12);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_1178);
appendString((&T13_), colontmpD__3);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_1179);
appendString((&T13_), colontmpD__4);
appendString((&T13_), TM__MQdRN7fpbG7rPm4JpVVAhA_1180);
			colontmpD__5 = T13_;
			prepareAdd((&(*r_p0)), colontmpD__5.len + 0);
appendString((&(*r_p0)), colontmpD__5);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
LA7_: ;
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCLineDir__cgen_u396)(NimStringV2* r_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T5_;
		if (!(((*conf_p2).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0)) goto LA3_;
		T5_ = (NI)0;
		T5_ = safeLineNm__cgen_u362(info_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genCLineDir__cgen_u370(r_p0, info_p1.fileIndex, T5_, conf_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isNoReturn__cgen_u28412)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*s_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)16)))&63U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = !(((*(*(*m_p0).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3)));
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, initFrame__cgen_u19996)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 procname_p1, NimStringV2 filename_p2) {
	NimStringV2 result;
	NimStringV2 res_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD_;
		if (!((*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)1))- 0].len == ((NI)0))) goto LA4_;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		res_2 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1193);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_2), 115);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1195);
		colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1197);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		cgFormatValue__cgen_u163((&res_2), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1199);
		cgFormatValue__cgen_u163((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1200);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_2), 36);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1202);
		cgFormatValue__cgen_u163((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1203);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_2), 63);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1205);
		prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)1))- 0]), res_2.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)1))- 0]), res_2);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	cgsym__cgen_u138((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1206);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 8);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1208);
	cgFormatValue__cgen_u163((&res_1), procname_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1209);
	cgFormatValue__cgen_u163((&res_1), filename_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1210);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA11_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1211);
	}
LA11_: ;
	result = res_1;
	eqwasMoved___system_u2688((&res_1));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, deinitFrame__cgen_u20066)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
	NimStringV2 result;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1220);
	colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1222);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1223);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA4_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1224);
	}
LA4_: ;
	result = res_1;
	eqwasMoved___system_u2688((&res_1));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getProcTypeCast__cgen_u28353)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = t__cgen_u97((*prc_p1).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = getTypeDesc__cgen_u8738(m_p0, colontmpD_, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 rettype_1;
		NimStringV2 params_1;
		tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA check_1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
		NimStringV2 T8_;
		if (!((*(*prc_p1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9))) goto LA4_;
		rettype_1.len = 0; rettype_1.p = NIM_NIL;
		params_1.len = 0; params_1.p = NIM_NIL;
		nimZeroMem((void*)(&check_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
		rettype_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1227;
		params_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1228;
		initIntSet__pureZcollectionsZintsets_u598((&check_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		genProcParams__cgen_u3939(m_p0, (*prc_p1).typ, (&rettype_1), (&params_1), (&check_1), NIM_TRUE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[0] = rettype_1;
		T7_[1] = params_1;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = percent___cgen_u28364(T7_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T8_); goto LA6_;}
		eqsink___system_u2700((&result), T8_);
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZcollectionsZintsets_u230((&check_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(params_1);
			eqdestroy___system_u2691(rettype_1);
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcAux__cgen_u28424)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_1;
	NimStringV2 header_1;
	NimStringV2 returnStmt_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* procBody_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 generatedProc_1;
	NIM_BOOL isCppMember_1;
	NIM_BOOL T2_;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T4_;
	tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA T10_;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tmpInfo_1;
	NIM_BOOL T16_;
NIM_BOOL oldNimErrFin51_;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin78_;
NIM_BOOL oldNimErrFin83_;
NIM_BOOL oldNimErrFin23_;
NIM_BOOL oldNimErrFin105_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	p_1 = NIM_NIL;
	header_1.len = 0; header_1.p = NIM_NIL;
	returnStmt_1.len = 0; returnStmt_1.p = NIM_NIL;
	procBody_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	generatedProc_1.len = 0; generatedProc_1.p = NIM_NIL;
	p_1 = newProc__cgendata_u509(prc_p1, m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	header_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
	if (!(T2_)) goto LA3_;
	T4_ = 0;
	T2_ = !(((IL64(5629500071084032) & (*prc_p1).flags) == T4_));
LA3_: ;
	isCppMember_1 = T2_;
	{
		if (!isCppMember_1) goto LA7_;
		genMemberProcHeader__cgen_u5241(m_p0, prc_p1, (&header_1), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA5_;
LA7_: ;
	{
		genProcHeader__cgen_u9040(m_p0, prc_p1, (&header_1), NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	returnStmt_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_334;
	T10_ = 0;
	procBody_1 = transformBody__transf_u26((*(*m_p0).g).graph, (*m_p0).Sup.idgen, prc_p1, T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T15_;
		if (!(((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)42)))&63U)))!=0)) goto LA13_;
		T15_ = NIM_NIL;
		T15_ = injectDestructorCalls__injectdestructors_u3431((*(*m_p0).g).graph, (*m_p0).Sup.idgen, prc_p1, procBody_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T15_); goto LA1_;}
		eqsink___ast_u3261(&procBody_1, T15_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	tmpInfo_1 = (*prc_p1).info;
	T16_ = (NIM_BOOL)0;
	T16_ = freshLineInfo__cgen_u404(p_1, (*prc_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(T16_);
	{
		NIM_BOOL T19_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* resNode_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* res_1;
		T19_ = (NIM_BOOL)0;
		T19_ = !((((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0));
		if (!(T19_)) goto LA20_;
		colontmpD_ = returnType__ast_u5354((*prc_p1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T19_ = !((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA20_: ;
		if (!T19_) goto LA21_;
		resNode_1 = NIM_NIL;
		res_1 = NIM_NIL;
		{
			NI T26_;
			T26_ = (NI)0;
			T26_ = len__ast_u3190((*prc_p1).ast);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			if (!(T26_ <= ((NI)7))) goto LA27_;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*prc_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_336, TM__MQdRN7fpbG7rPm4JpVVAhA_337);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		}
LA27_: ;
		eqcopy___ast_u3255(&resNode_1, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)7)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		eqcopy___ast_u4577(&res_1, (*resNode_1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		{
			NIM_BOOL T31_;
			NIM_BOOL T32_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_1;
			NimStringV2 res_2;
			NimStringV2 colontmpD__2;
			T31_ = (NIM_BOOL)0;
			T32_ = (NIM_BOOL)0;
			T32_ = isInvalidReturnType__cgen_u1424((*(*m_p0).g).config, (*prc_p1).typ, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T31_ = !(T32_);
			if (!(T31_)) goto LA33_;
			T31_ = !((((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29)))&63U)))!=0));
LA33_: ;
			if (!T31_) goto LA34_;
			val_1 = NIM_NIL;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			{
				if (!(((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA39_;
				(*res_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14))) & 63);
			}
LA39_: ;
			{
				NIM_BOOL T43_;
				NIM_BOOL T44_;
				NIM_BOOL T46_;
				NimStringV2 decl_1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
				NimStringV2 res_3;
				NimStringV2 colontmpD__3;
				NimStringV2* T52_;
				NimStringV2* T53_;
				T43_ = (NIM_BOOL)0;
				T44_ = (NIM_BOOL)0;
				T44_ = (((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0);
				if (!(T44_)) goto LA45_;
				T46_ = (NIM_BOOL)0;
				T46_ = ((*(*(*(*p_1).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T46_) goto LA47_;
				T46_ = (((*(*(*p_1).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA47_: ;
				T44_ = T46_;
LA45_: ;
				T43_ = T44_;
				if (!(T43_)) goto LA48_;
				val_1 = easyResultAsgn__cgen_u28177(procBody_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				T43_ = !((val_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA48_: ;
				if (!T43_) goto LA49_;
				decl_1.len = 0; decl_1.p = NIM_NIL;
				nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				decl_1 = localVarDecl__cgen_u13649(p_1, resNode_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				initLocExprSingleUse__cgen_u14116(p_1, val_1, (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T52_ = (NimStringV2*)0;
				T52_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				addIndent__cgen_u315(p_1, T52_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T53_ = (NimStringV2*)0;
				T53_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				res_3 = rawNewString(((NI)80));
				cgFormatValue__cgen_u163((&res_3), decl_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_356);
				colontmpD__3 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_357);
				{
					if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA56_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_358);
				}
LA56_: ;
				prepareAdd((&(*T53_)), res_3.len + 0);
appendString((&(*T53_)), res_3);
				{
					LA51_:;
				}
				{
					oldNimErrFin51_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(res_3);
					eqdestroy___ast_u6284(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
					eqdestroy___system_u2691(decl_1);
					*nimErr_ = oldNimErrFin51_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			}
			goto LA41_;
LA49_: ;
			{
				assignLocalVar__cgen_u13691(p_1, resNode_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				{
					NIM_BOOL T63_;
					tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA T65_;
					T63_ = (NIM_BOOL)0;
					T63_ = ((*(*(*(*p_1).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*p_1).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*p_1).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5));
					if (!(T63_)) goto LA64_;
					T65_ = (tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0;
					T65_ = allPathsAsgnResult__cgen_u28217(p_1, procBody_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
					T63_ = (T65_ == ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1));
LA64_: ;
					if (!T63_) goto LA66_;
				}
				goto LA61_;
LA66_: ;
				{
					initLocalVar__cgen_u13552(p_1, res_1, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				}
LA61_: ;
			}
LA41_: ;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1064);
			colontmpD__2 = rdLoc__cgen_u470((*res_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1065);
			{
				if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA71_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1066);
			}
LA71_: ;
			eqsink___system_u2700((&returnStmt_1), res_2);
			eqwasMoved___system_u2688((&res_2));
			{
				LA36_:;
			}
			{
				oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_2);
				eqdestroy___ast_u3252(val_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				*nimErr_ = oldNimErrFin36_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		}
		goto LA29_;
LA34_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			NimStringV2 T79_;
			if (!(((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29)))&63U)))!=0)) goto LA76_;
			colontmpD__4 = NIM_NIL;
			(*(*resNode_1)._kind_4.sym).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
			fillLoc__cgen_u78((&(*(*resNode_1)._kind_4.sym).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)4), resNode_1, TM__MQdRN7fpbG7rPm4JpVVAhA_1067, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
			colontmpD__4 = t__cgen_u97((*(*resNode_1)._kind_4.sym).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
			T79_.len = 0; T79_.p = NIM_NIL;
			T79_ = getTypeDesc__cgen_u8738(m_p0, colontmpD__4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T79_); goto LA78_;}
			eqsink___system_u2700((&(*prc_p1).loc.snippet), T79_);
			{
				LA78_:;
			}
			{
				oldNimErrFin78_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				*nimErr_ = oldNimErrFin78_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		}
		goto LA29_;
LA76_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
			colontmpD__5 = NIM_NIL;
			colontmpD__6 = NIM_NIL;
			fillResult__cgen_u1887((*(*(*p_1).module).g).config, resNode_1, (*prc_p1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			colontmpD__5 = returnType__ast_u5354((*prc_p1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			assignParam__cgen_u14044(p_1, res_1, colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			{
				if (!(((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA86_;
			}
			goto LA84_;
LA86_: ;
			{
				tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA T89_;
				T89_ = (tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)0;
				T89_ = allPathsAsgnResult__cgen_u28217(p_1, procBody_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				if (!(T89_ == ((tyEnum_InitResultEnum__zkNt4DlQMXyottRsdxXPQA)1))) goto LA90_;
			}
			goto LA84_;
LA90_: ;
			{
				resetLoc__cgen_u13360(p_1, (&(*res_1).loc));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			}
LA84_: ;
			{
				colontmpD__6 = skipTypes__ast_u5379((*res_1).typ, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				if (!((*colontmpD__6).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16))) goto LA95_;
				(*res_1).loc.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0);
			}
LA95_: ;
			{
				LA83_:;
			}
			{
				oldNimErrFin83_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				eqdestroy___ast_u3378(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				*nimErr_ = oldNimErrFin83_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		}
LA29_: ;
		{
			LA23_:;
		}
		{
			oldNimErrFin23_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(res_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(resNode_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin23_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA21_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190((*(*prc_p1).typ).n);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA103;
				i_1 = i_2;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_1;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
					param_1 = NIM_NIL;
					colontmpD__7 = NIM_NIL;
					eqcopy___ast_u4577(&param_1, (*(*(*(*prc_p1).typ).n)._kind_6.sons.p->data[i_1])._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
					{
						NIM_BOOL T108_;
						T108_ = (NIM_BOOL)0;
						T108_ = isCompileTimeOnly__types_u3641((*param_1).typ);
						if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
						if (!T108_) goto LA109_;
						eqdestroy___ast_u3378(colontmpD__7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u4574(param_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						goto LA104;
					}
LA109_: ;
					colontmpD__7 = returnType__ast_u5354((*prc_p1).typ);
					if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
					assignParam__cgen_u14044(p_1, param_1, colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
					{
						LA105_:;
					}
					{
						oldNimErrFin105_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u4574(param_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin105_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA104: ;
				i_2 += ((NI)1);
			} LA103: ;
		}
	}
	closureSetup__cgen_u28093(p_1, prc_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genProcBody__cgen_u28369(p_1, procBody_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*prc_p1).info = tmpInfo_1;
	generatedProc_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1175;
	genCLineDir__cgen_u396((&generatedProc_1), (*prc_p1).info, (*(*m_p0).g).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T115_;
		T115_ = (NIM_BOOL)0;
		T115_ = isNoReturn__cgen_u28412((*p_1).module, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T115_) goto LA116_;
		{
			NIM_BOOL T120_;
			NimStringV2 T124_;
			T120_ = (NIM_BOOL)0;
			T120_ = ((CC__extccomp_u624[((*(*(*(*p_1).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)6)))&15U)))!=0);
			if (!(T120_)) goto LA121_;
			T120_ = !(isCppMember_1);
LA121_: ;
			if (!T120_) goto LA122_;
			T124_.len = 0; T124_.p = NIM_NIL;
			T124_ = rawNewString(header_1.len + 21);
appendString((&T124_), TM__MQdRN7fpbG7rPm4JpVVAhA_1182);
appendString((&T124_), header_1);
			eqsink___system_u2700((&header_1), T124_);
		}
LA122_: ;
	}
LA116_: ;
	{
		NimStringV2 res_4;
		NimStringV2* T140_;
		NimStringV2* T141_;
		NimStringV2* T142_;
		if (!(((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0)) goto LA127_;
		res_4.len = 0; res_4.p = NIM_NIL;
		{
			NIM_BOOL T131_;
			NimStringV2 T135_;
			T131_ = (NIM_BOOL)0;
			T131_ = ((CC__extccomp_u624[((*(*(*(*p_1).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)6)))&15U)))!=0);
			if (!(T131_)) goto LA132_;
			T131_ = !(isCppMember_1);
LA132_: ;
			if (!T131_) goto LA133_;
			T135_.len = 0; T135_.p = NIM_NIL;
			T135_ = rawNewString(header_1.len + 18);
appendString((&T135_), TM__MQdRN7fpbG7rPm4JpVVAhA_1184);
appendString((&T135_), header_1);
			eqsink___system_u2700((&header_1), T135_);
		}
LA133_: ;
		res_4 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_4), header_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1186);
		{
			if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA138_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1187);
		}
LA138_: ;
		T140_ = (NimStringV2*)0;
		T140_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_4), (*T140_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T141_ = (NimStringV2*)0;
		T141_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_4), (*T141_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T142_ = (NimStringV2*)0;
		T142_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_4), (*T142_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1189);
		prepareAdd((&generatedProc_1), res_4.len + 0);
appendString((&generatedProc_1), res_4);
		eqdestroy___system_u2691(res_4);
	}
	goto LA125_;
LA127_: ;
	{
		NimStringV2 res_5;
		NimStringV2* T182_;
		NimStringV2* T183_;
		res_5.len = 0; res_5.p = NIM_NIL;
		{
			NIM_BOOL T147_;
			NimStringV2 colontmpD__8;
			tyArray__YgExxhfgKcesA5EOUj1MOA T151_;
			T147_ = (NIM_BOOL)0;
			T147_ = hcrOn__cgen_u49(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
			if (!(T147_)) goto LA148_;
			T147_ = isReloadable__cgen_u8812(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
LA148_: ;
			if (!T147_) goto LA149_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T151_[0] = header_1;
			colontmpD__8 = percent___cgen_u9875(T151_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD__8.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD__8);
			eqdestroy___system_u2691(colontmpD__8);
		}
LA149_: ;
		res_5 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_5), header_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
		prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1190);
		{
			if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA154_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1191);
		}
LA154_: ;
		prepareAdd((&generatedProc_1), res_5.len + 0);
appendString((&generatedProc_1), res_5);
		{
			NimStringV2 procname_1;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2* T161_;
			if (!(((*prc_p1).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0)) goto LA158_;
			procname_1.len = 0; procname_1.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T161_ = (NimStringV2*)0;
			T161_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
			prepareAdd((&generatedProc_1), (*T161_).len + 0);
appendString((&generatedProc_1), (*T161_));
			procname_1 = makeCString__msgs_u83((*(*prc_p1).name).s);
			if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
			colontmpD__9 = quotedFilename__msgs_u1638((*(*(*p_1).module).g).config, (*prc_p1).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
			colontmpD__10 = initFrame__cgen_u19996(p_1, procname_1, colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
			prepareAdd((&generatedProc_1), colontmpD__10.len + 0);
appendString((&generatedProc_1), colontmpD__10);
			{
				LA160_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(procname_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
		}
		goto LA156_;
LA158_: ;
		{
			NimStringV2* T165_;
			T165_ = (NimStringV2*)0;
			T165_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
			prepareAdd((&generatedProc_1), (*T165_).len + 0);
appendString((&generatedProc_1), (*T165_));
		}
LA156_: ;
		{
			NimStringV2 res_6;
			NimStringV2 colontmpD__11;
			NimStringV2* T171_;
			if (!(((*prc_p1).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)21)))&31U)))!=0)) goto LA168_;
			res_6.len = 0; res_6.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			T171_ = (NimStringV2*)0;
			T171_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
			res_6 = rawNewString(((NI)80));
			prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1212);
			colontmpD__11 = cgsymValue__cgen_u141((*p_1).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1214);
			if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
			prepareAdd((&res_6), 3);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1215);
			{
				if (!!((((*(*(*(*p_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA174_;
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1216);
			}
LA174_: ;
			prepareAdd((&(*T171_)), res_6.len + 0);
appendString((&(*T171_)), res_6);
			{
				LA170_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(res_6);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
		}
LA168_: ;
		{
			if (!(((*p_1).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)0)))&7U)))!=0)) goto LA180_;
			prepareAdd((&generatedProc_1), 1);
appendString((&generatedProc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1217);
		}
LA180_: ;
		T182_ = (NimStringV2*)0;
		T182_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
		prepareAdd((&generatedProc_1), (*T182_).len + 0);
appendString((&generatedProc_1), (*T182_));
		T183_ = (NimStringV2*)0;
		T183_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
		prepareAdd((&generatedProc_1), (*T183_).len + 0);
appendString((&generatedProc_1), (*T183_));
		{
			if (!(((*p_1).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)0)))&7U)))!=0)) goto LA186_;
			prepareAdd((&generatedProc_1), 16);
appendString((&generatedProc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1219);
		}
LA186_: ;
		{
			NimStringV2 colontmpD__12;
			if (!(((*prc_p1).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0)) goto LA190_;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__12 = deinitFrame__cgen_u20066(p_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA192_;
			prepareAdd((&generatedProc_1), colontmpD__12.len + 0);
appendString((&generatedProc_1), colontmpD__12);
			{
				LA192_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA144_;
		}
LA190_: ;
		prepareAdd((&generatedProc_1), returnStmt_1.len + 0);
appendString((&generatedProc_1), returnStmt_1);
		prepareAdd((&generatedProc_1), 2);
appendString((&generatedProc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1225);
		{
			LA144_:;
		}
		{
			eqdestroy___system_u2691(res_5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA125_: ;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), generatedProc_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), generatedProc_1);
	{
		NIM_BOOL T199_;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T203_;
		NimStringV2 T204_;
		T199_ = (NIM_BOOL)0;
		T199_ = isReloadable__cgen_u8812(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T199_) goto LA200_;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		T203_[0] = (*prc_p1).loc.snippet;
		T204_.len = 0; T204_.p = NIM_NIL;
		T204_ = rawNewString((*prc_p1).loc.snippet.len + 7);
appendString((&T204_), (*prc_p1).loc.snippet);
appendString((&T204_), TM__MQdRN7fpbG7rPm4JpVVAhA_1226);
		colontmpD__13 = T204_;
		T203_[1] = colontmpD__13;
		colontmpD__14 = getProcTypeCast__cgen_u28353(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		T203_[2] = colontmpD__14;
		colontmpD__15 = getModuleDllPath__cgen_u158(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		T203_[3] = colontmpD__15;
		colontmpD__16 = percent___cgen_u28637(T203_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__16.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__16);
		{
			LA202_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA200_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(generatedProc_1);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(procBody_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(returnStmt_1);
		eqdestroy___system_u2691(header_1);
		eqdestroy___cgendata_u2071(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcNoForward__cgen_u28805)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
NIM_BOOL oldNimErrFin25_;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin40_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(((*prc_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)6)))&15U)))!=0)) goto LA3_;
		fillProcLoc__cgen_u14051(m_p0, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		useHeader__cgen_u123(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		cgsym__cgen_u138(m_p0, (*(*prc_p1).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(((*prc_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0)) goto LA7_;
		fillProcLoc__cgen_u14051(m_p0, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genProcPrototype__cgen_u523(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA7_: ;
	{
		tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* q_1;
		if (!(((*prc_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)3)))&15U)))!=0)) goto LA10_;
		q_1 = NIM_NIL;
		q_1 = findPendingModule__cgen_u62(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		fillProcLoc__cgen_u14051(q_1, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		genProcPrototype__cgen_u523(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			NIM_BOOL T15_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7471__1;
			NIM_BOOL T17_;
			T15_ = (NIM_BOOL)0;
			T15_ = !((q_1 == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)));
			if (!(T15_)) goto LA16_;
			xX60gensym7471__1 = (*prc_p1).itemId;
			T17_ = (NIM_BOOL)0;
			T17_ = containsOrIncl__astyaml_u223((&(*q_1).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7471__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7471__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			T15_ = !(T17_);
LA16_: ;
			if (!T15_) goto LA18_;
			symInDynamicLib__cgen_u27914(q_1, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			{
				NIM_BOOL T22_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T26_;
				T22_ = (NIM_BOOL)0;
				T22_ = isReloadable__cgen_u8812(q_1, prc_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				if (!T22_) goto LA23_;
				colontmpD_ = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				T26_[0] = (*prc_p1).loc.snippet;
				colontmpD_ = t__cgen_u97((*prc_p1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
				colontmpD__2 = getTypeDesc__cgen_u8738(q_1, colontmpD_, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
				T26_[1] = colontmpD__2;
				colontmpD__3 = getModuleDllPath__cgen_u158(m_p0, (*q_1).module);
				if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
				T26_[2] = colontmpD__3;
				colontmpD__4 = percent___cgen_u28853(T26_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
				prepareAdd((&(*q_1).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__4.len + 0);
appendString((&(*q_1).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__4);
				{
					LA25_:;
				}
				{
					oldNimErrFin25_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___ast_u3378(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					*nimErr_ = oldNimErrFin25_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			}
LA23_: ;
		}
		goto LA13_;
LA18_: ;
		{
			symInDynamicLibPartial__cgen_u28028(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		}
LA13_: ;
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___cgendata_u718(q_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA10_: ;
	{
		if (!((*(*prc_p1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)5))) goto LA33_;
		{
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7474__1;
			NIM_BOOL T37_;
			tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m2_1;
			tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* T41_;
			xX60gensym7474__1 = (*prc_p1).itemId;
			T37_ = (NIM_BOOL)0;
			T37_ = containsOrIncl__astyaml_u223((&(*m_p0).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7474__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7474__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T37_)) goto LA38_;
			m2_1 = NIM_NIL;
			T41_ = NIM_NIL;
			{
				if (!!(((*(*(*m_p0).g).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA44_;
				eqcopy___cgendata_u721(&m2_1, m_p0, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			}
			goto LA42_;
LA44_: ;
			{
				m2_1 = findPendingModule__cgen_u62(m_p0, prc_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			}
LA42_: ;
			fillProcLoc__cgen_u14051(m2_1, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			genProcPrototype__cgen_u523(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			genProcAux__cgen_u28424(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			{
				LA40_:;
			}
			{
				oldNimErrFin40_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___cgendata_u718(m2_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin40_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA38_: ;
	}
	goto LA5_;
LA33_: ;
	{
		tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* q_2;
		if (!!((((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0))) goto LA50_;
		q_2 = NIM_NIL;
		q_2 = findPendingModule__cgen_u62(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		fillProcLoc__cgen_u14051(q_2, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		{
			NIM_BOOL T55_;
			NIM_BOOL T56_;
			NIM_BOOL T57_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7482__1;
			NIM_BOOL T59_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7486__1;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7488__1;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T65_;
			T55_ = (NIM_BOOL)0;
			T56_ = (NIM_BOOL)0;
			T57_ = (NIM_BOOL)0;
			T57_ = isReloadable__cgen_u8812(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			if (!(T57_)) goto LA58_;
			xX60gensym7482__1 = (*prc_p1).itemId;
			T59_ = (NIM_BOOL)0;
			T59_ = contains__astalgo_u2846((&(*m_p0).declaredProtos), (NI)((NI)((NU32)(((NI) (xX60gensym7482__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7482__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			T57_ = !(T59_);
LA58_: ;
			T56_ = T57_;
			if (!(T56_)) goto LA60_;
			T56_ = !((q_2 == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)));
LA60_: ;
			T55_ = T56_;
			if (!(T55_)) goto LA61_;
			xX60gensym7486__1 = (*(*q_2).module).itemId;
			xX60gensym7488__1 = (*(*m_p0).module).itemId;
			T55_ = !(((NI)((NI)((NU32)(((NI) (xX60gensym7486__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7486__1.item))) == (NI)((NI)((NU32)(((NI) (xX60gensym7488__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7488__1.item)))));
LA61_: ;
			if (!T55_) goto LA62_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			T65_[0] = (*prc_p1).loc.snippet;
			colontmpD__5 = getProcTypeCast__cgen_u28353(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
			T65_[1] = colontmpD__5;
			colontmpD__6 = getModuleDllPath__cgen_u158(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
			T65_[2] = colontmpD__6;
			colontmpD__7 = percent___cgen_u26278(T65_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__7.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__7);
			{
				LA64_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		}
LA62_: ;
		genProcPrototype__cgen_u523(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		{
			NIM_BOOL T70_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7492__1;
			NIM_BOOL T72_;
			T70_ = (NIM_BOOL)0;
			T70_ = !((q_2 == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)));
			if (!(T70_)) goto LA71_;
			xX60gensym7492__1 = (*prc_p1).itemId;
			T72_ = (NIM_BOOL)0;
			T72_ = containsOrIncl__astyaml_u223((&(*q_2).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7492__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7492__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			T70_ = !(T72_);
LA71_: ;
			if (!T70_) goto LA73_;
			{
				NIM_BOOL T77_;
				T77_ = (NIM_BOOL)0;
				T77_ = isReloadable__cgen_u8812(m_p0, prc_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				if (!T77_) goto LA78_;
				genProcPrototype__cgen_u523(q_2, prc_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			}
LA78_: ;
			genProcAux__cgen_u28424(q_2, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
		}
LA73_: ;
		{
			LA52_:;
		}
		{
			oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___cgendata_u718(q_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin52_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA5_;
LA50_: ;
	{
		fillProcLoc__cgen_u14051(m_p0, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		useHeader__cgen_u123(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!!((((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0))) goto LA85_;
			genProcPrototype__cgen_u523(m_p0, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA85_: ;
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genProc__cgen_u454)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)31)))&63U)))!=0);
		if (T3_) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isActivated__cgen_u29100(prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !(T5_);
LA4_: ;
		if (!T3_) goto LA6_;
		goto BeforeRet_;
	}
LA6_: ;
	{
		if (!(((*prc_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4)))&63U)))!=0)) goto LA10_;
		addForwardedProc__cgen_u55(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		fillProcLoc__cgen_u14051(m_p0, (*(*prc_p1).ast)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA8_;
LA10_: ;
	{
		genProcNoForward__cgen_u28805(m_p0, prc_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T15_;
			NIM_BOOL T16_;
			T15_ = (NIM_BOOL)0;
			T16_ = (NIM_BOOL)0;
			T16_ = ((262272 & (*prc_p1).flags) == 128);
			if (!(T16_)) goto LA17_;
			T16_ = !(((*(*m_p0).g).generatedHeader == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)));
LA17_: ;
			T15_ = T16_;
			if (!(T15_)) goto LA18_;
			T15_ = !((((*prc_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0));
LA18_: ;
			if (!T15_) goto LA19_;
			genProcPrototype__cgen_u523((*(*m_p0).g).generatedHeader, prc_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				if (!((*(*prc_p1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)5))) goto LA23_;
				{
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7510__1;
					NIM_BOOL T27_;
					xX60gensym7510__1 = (*prc_p1).itemId;
					T27_ = (NIM_BOOL)0;
					T27_ = containsOrIncl__astyaml_u223((&(*(*(*m_p0).g).generatedHeader).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7510__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7510__1.item))));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!!(T27_)) goto LA28_;
					genProcAux__cgen_u28424((*(*m_p0).g).generatedHeader, prc_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA28_: ;
			}
LA23_: ;
		}
LA19_: ;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, treatGlobalDifferentlyForHCR__cgen_u13851)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = hcrOn__cgen_u49(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	if (!(T2_)) goto LA3_;
	T2_ = ((67108872 & (*s_p1).flags) == 8);
LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T5_ = 0;
	T1_ = ((36 & (*s_p1).loc.flags) == T5_);
LA4_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, emulatedThreadVars__cgen_u452)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NIM_BOOL result;
	result = ((301989888 & ~ (*conf_p0).globalOptions)==0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, declareThreadVar__cgen_u13751)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NIM_BOOL isExtern_p2) {
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = emulatedThreadVars__cgen_u452((*(*m_p0).g).config);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		{
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1401__1;
			NIM_BOOL T8_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T12_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T13_;
			xX60gensym1401__1 = (*s_p1).itemId;
			T8_ = (NIM_BOOL)0;
			T8_ = containsOrIncl__astyaml_u223((&(*(*m_p0).g).nimtvDeclared), (NI)((NI)((NU32)(((NI) (xX60gensym1401__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym1401__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T8_)) goto LA9_;
			colontmpD_ = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T12_ = NIM_NIL;
			T12_ = t__cgen_u97((*s_p1).loc);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T12_); goto LA11_;}
			add__ast_u3891((&(*(*m_p0).g).nimtvDeps), T12_);
			colontmpD_ = t__cgen_u97((*s_p1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			colontmpD__2 = getTypeDesc__cgen_u8738(m_p0, colontmpD_, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			T13_[0] = colontmpD__2;
			T13_[1] = (*s_p1).loc.snippet;
			colontmpD__3 = percent___cgen_u3199(T13_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			prepareAdd((&(*(*m_p0).g).nimtv), colontmpD__3.len + 0);
appendString((&(*(*m_p0).g).nimtv), colontmpD__3);
			{
				LA11_:;
			}
			{
				oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___ast_u3378(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin11_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA9_: ;
	}
	goto LA1_;
LA4_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		tyArray__YgExxhfgKcesA5EOUj1MOA T37_;
		colontmpD__4 = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		{
			if (!isExtern_p2) goto LA20_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 7);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1230);
		}
		goto LA18_;
LA20_: ;
		{
			if (!(((*s_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)4)))&15U)))!=0)) goto LA23_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 17);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1232);
		}
		goto LA18_;
LA23_: ;
		{
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 14);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1233);
		}
LA18_: ;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
			if (!(((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)25)))&63U)))!=0)) goto LA28_;
			sym_1 = NIM_NIL;
			sym_1 = (*(*s_p1).typ).sym;
			{
				NIM_BOOL T32_;
				T32_ = (NIM_BOOL)0;
				T32_ = !((sym_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
				if (!(T32_)) goto LA33_;
				T32_ = (((*sym_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)27)))&63U)))!=0);
LA33_: ;
				if (!T32_) goto LA34_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 17);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1235);
			}
			goto LA30_;
LA34_: ;
			{
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 14);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1237);
			}
LA30_: ;
		}
LA28_: ;
		colontmpD__4 = t__cgen_u97((*s_p1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		colontmpD__5 = getTypeDesc__cgen_u8738(m_p0, colontmpD__4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__5);
		T37_[0] = (*s_p1).loc.snippet;
		colontmpD__6 = percent___cgen_u13808(T37_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__6.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__6);
		{
			LA17_:;
		}
		{
			oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin17_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(NimStringV2*, procSec__cgendata_u464)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g s_p1) {
	NimStringV2* result;
	result = (&(*p_p0).blocks.p->data[((NI)0)].sections[(s_p1)- 0]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarPrototype__cgen_u14075)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL oldNimErrFin64_;
NIM_BOOL oldNimErrFin22_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	sym_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	eqcopy___ast_u4577(&sym_1, (*n_p1)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	useHeader__cgen_u123(m_p0, sym_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillBackendName__cgen_u896(m_p0, sym_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillLoc__cgen_u88((&(*sym_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)3), n_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = treatGlobalDifferentlyForHCR__cgen_u13851(m_p0, sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		(*sym_1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
	}
LA5_: ;
	{
		NIM_BOOL T9_;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7513__1;
		T9_ = (NIM_BOOL)0;
		T9_ = (((*sym_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0);
		if (T9_) goto LA10_;
		xX60gensym7513__1 = (*sym_1).itemId;
		T9_ = contains__astalgo_u2846((&(*m_p0).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7513__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7513__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA10_: ;
		if (!T9_) goto LA11_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA11_: ;
	{
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7516__1;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7518__1;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7523__1;
		colontmpD_ = owner__ast_u6254(sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		xX60gensym7516__1 = (*colontmpD_).itemId;
		xX60gensym7518__1 = (*(*m_p0).module).itemId;
		if (!!(((NI)((NI)((NU32)(((NI) (xX60gensym7516__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7516__1.item))) == (NI)((NI)((NU32)(((NI) (xX60gensym7518__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7518__1.item)))))) goto LA15_;
		xX60gensym7523__1 = (*sym_1).itemId;
		incl__pureZcollectionsZintsets_u366((&(*m_p0).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7523__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7523__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(((*sym_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26)))&63U)))!=0)) goto LA19_;
			declareThreadVar__cgen_u13751(m_p0, sym_1, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA17_;
LA19_: ;
		{
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 T30_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T58_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4 = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			{
				NIM_BOOL T25_;
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				tyArray__YgExxhfgKcesA5EOUj1MOA T29_;
				T25_ = (NIM_BOOL)0;
				T25_ = ((*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9) || (*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19) || (*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21));
				if (!(T25_)) goto LA26_;
				T25_ = (((NI)0) < (*sym_1)._kind_2.alignment);
LA26_: ;
				if (!T25_) goto LA27_;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__7 = rope__ropes_u15(((NI64) ((*sym_1)._kind_2.alignment)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				T29_[0] = colontmpD__7;
				colontmpD__8 = percent___cgen_u13670(T29_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__8.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__8);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
			}
LA27_: ;
			T30_.len = 0; T30_.p = NIM_NIL;
			{
				NIM_BOOL T33_;
				T33_ = (NIM_BOOL)0;
				T33_ = hcrOn__cgen_u49(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				if (!T33_) goto LA34_;
				colontmpD__2 = TM__MQdRN7fpbG7rPm4JpVVAhA_1238;
				T30_ = colontmpD__2;
			}
			goto LA31_;
LA34_: ;
			{
				colontmpD__3 = TM__MQdRN7fpbG7rPm4JpVVAhA_1239;
				T30_ = colontmpD__3;
			}
LA31_: ;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), T30_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), T30_);
			colontmpD__4 = t__cgen_u97((*sym_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			colontmpD__5 = getTypeDesc__cgen_u8738(m_p0, colontmpD__4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__5);
			{
				NIM_BOOL T39_;
				T39_ = (NIM_BOOL)0;
				T39_ = hcrOn__cgen_u49(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				if (!T39_) goto LA40_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 1);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1240);
			}
LA40_: ;
			{
				if (!(((*sym_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)3)))&15U)))!=0)) goto LA44_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 1);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1241);
			}
LA44_: ;
			{
				if (!(((*sym_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)10)))&63U)))!=0)) goto LA48_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 9);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1242);
			}
LA48_: ;
			{
				if (!(((*sym_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)9)))&63U)))!=0)) goto LA52_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 9);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1243);
			}
LA52_: ;
			{
				if (!(((*sym_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)47)))&63U)))!=0)) goto LA56_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), 12);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_1244);
			}
LA56_: ;
			T58_[0] = (*sym_1).loc.snippet;
			colontmpD__6 = percent___cgen_u13808(T58_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__6.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__6);
			{
				NIM_BOOL T61_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
				NimStringV2 colontmpD__10;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				NimStringV2* T65_;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T66_;
				T61_ = (NIM_BOOL)0;
				T61_ = hcrOn__cgen_u49(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
				if (!T61_) goto LA62_;
				colontmpD__9 = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				T65_ = (NimStringV2*)0;
				T65_ = procSec__cgendata_u464((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				T66_[0] = (*sym_1).loc.snippet;
				colontmpD__9 = t__cgen_u97((*sym_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				colontmpD__10 = getTypeDesc__cgen_u8738(m_p0, colontmpD__9, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				T66_[1] = colontmpD__10;
				colontmpD__11 = getModuleDllPath__cgen_u158(m_p0, sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				T66_[2] = colontmpD__11;
				colontmpD__12 = percent___cgen_u26797(T66_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
				prepareAdd((&(*T65_)), colontmpD__12.len + 0);
appendString((&(*T65_)), colontmpD__12);
				{
					LA64_:;
				}
				{
					oldNimErrFin64_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(colontmpD__10);
					eqdestroy___ast_u3378(colontmpD__9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
					*nimErr_ = oldNimErrFin64_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			}
LA62_: ;
			{
				LA22_:;
			}
			{
				oldNimErrFin22_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				*nimErr_ = oldNimErrFin22_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA17_: ;
	}
LA15_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, cgsymImpl__cgen_u28031)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL oldNimErrFin3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*sym_p1).kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15):
	{
		genProc__cgen_u454(m_p0, sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = newSymNode__ast_u5168(sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		genVarPrototype__cgen_u14075(m_p0, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7):
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = getTypeDesc__cgen_u8738(m_p0, (*sym_p1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		(void)(colontmpD__2);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T12_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T12_.len = 0; T12_.p = NIM_NIL;
		colontmpD__3 = dollar___ast_u309((*sym_p1).kind);
		T12_ = rawNewString(colontmpD__3.len + 7);
appendString((&T12_), TM__MQdRN7fpbG7rPm4JpVVAhA_1246);
appendString((&T12_), colontmpD__3);
		colontmpD__4 = T12_;
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, colontmpD__4, TM__MQdRN7fpbG7rPm4JpVVAhA_1247);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		{
			LA11_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cgsym__cgen_u138)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 name_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	sym_1 = NIM_NIL;
	sym_1 = getCompilerProc__magicsys_u150((*(*m_p0).g).graph, name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((sym_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA4_;
		cgsymImpl__cgen_u28031(m_p0, sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T8_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rawNewString(name_p1.len + 21);
appendString((&T8_), TM__MQdRN7fpbG7rPm4JpVVAhA_1248);
appendString((&T8_), name_p1);
		colontmpD_ = T8_;
		liMessage__msgs_u1227((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), TM__MQdRN7fpbG7rPm4JpVVAhA_1249, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSimpleTypeDesc__cgen_u1917)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	NimStringV2 result;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin35_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	switch ((*typ_p1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	{
		result = typeNameOrLiteral__cgen_u1900(m_p0, typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_36);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = detectStrVersion__cgen_u579(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (T3_) {
		case ((NI)2):
		{
			cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1250);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1251);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = typeNameOrLiteral__cgen_u1900(m_p0, typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1252);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		default:
		{
			cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1253);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = typeNameOrLiteral__cgen_u1900(m_p0, typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1255);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	{
		result = typeNameOrLiteral__cgen_u1900(m_p0, typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1257);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		result = typeNameOrLiteral__cgen_u1900(m_p0, typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1259);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		result = typeNameOrLiteral__cgen_u1900(m_p0, typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1261);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	{
		result = typeNameOrLiteral__cgen_u1900(m_p0, typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1262);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		result = typeNameOrLiteral__cgen_u1900(m_p0, typ_p1, NumericalTypeToStr__cgen_u1921[((*typ_p1).kind)- 31]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)15):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = skipModifier__ast_u5338(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		result = getSimpleTypeDesc__cgen_u1917(m_p0, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = skipModifier__ast_u5338(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		result = getSimpleTypeDesc__cgen_u1917(m_p0, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = isImportedType__cgen_u1373(typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			if (!(T19_)) goto LA20_;
			T19_ = !((result.len == 0));
LA20_: ;
			if (!T19_) goto LA21_;
			useHeader__cgen_u123(m_p0, (*typ_p1).sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			eqcopy___system_u2694((&result), (*(*typ_p1).sym).loc.snippet);
		}
LA21_: ;
		{
			LA16_:;
		}
		{
			oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin16_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
			if (!!(((*typ_p1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA28_;
			colontmpD__3 = NIM_NIL;
			colontmpD__3 = skipModifier__ast_u5338(typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			result = getSimpleTypeDesc__cgen_u1917(m_p0, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			{
				LA30_:;
			}
			{
				oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin30_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA26_;
LA28_: ;
		{
			result = TM__MQdRN7fpbG7rPm4JpVVAhA_1277;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, TM__MQdRN7fpbG7rPm4JpVVAhA_1279, TM__MQdRN7fpbG7rPm4JpVVAhA_1280);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA26_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		colontmpD__4 = NIM_NIL;
		colontmpD__4 = skipModifier__ast_u5338(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
		result = getSimpleTypeDesc__cgen_u1917(m_p0, colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
		{
			LA35_:;
		}
		{
			oldNimErrFin35_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin35_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_1281;
	}
	break;
	}
	{
		NIM_BOOL T41_;
		NimStringV2 colontmpD__5;
		tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_1;
		T41_ = (NIM_BOOL)0;
		T41_ = !((result.len == 0));
		if (!(T41_)) goto LA42_;
		T41_ = isImportedType__cgen_u1373(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA42_: ;
		if (!T41_) goto LA43_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		nimZeroMem((void*)sig_1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
		hashType__sighashes_u411(typ_p1, (*(*m_p0).g).config, 2, sig_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		{
			NimStringV2 colontmpD__6;
			colontmpD__5 = cacheGetType__cgen_u1466((*m_p0).typeCache, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
			if (!(colontmpD__5.len == 0)) goto LA48_;
			colontmpD__6 = eqdup___system_u2697(result);
			X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		}
LA48_: ;
		{
			LA45_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA43_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypePre__cgen_u3178)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!(typ_p1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA3_;
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_34;
	}
	goto LA1_;
LA3_: ;
	{
		result = getSimpleTypeDesc__cgen_u1917(m_p0, typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NimStringV2 T10_;
			if (!(result.len == 0)) goto LA8_;
			T10_.len = 0; T10_.p = NIM_NIL;
			T10_ = cacheGetType__cgen_u1466((*m_p0).typeCache, sig_p2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto BeforeRet_;}
			eqsink___system_u2700((&result), T10_);
		}
LA8_: ;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, colonanonymous___cgen_u1869)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	result = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addAbiCheck__cgen_u1860)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2 name_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI64 size_1;
		NIM_BOOL T7_;
		NimStringV2 msg_1;
		NimStringV2 msg2_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T12_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = isDefined__options_u959((*(*m_p0).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_1286);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T4_)) goto LA5_;
		size_1 = getSize__types_u3397((*(*m_p0).g).config, t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = !((size_1 == IL64(-3)));
LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*t_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
		if (!(T7_)) goto LA8_;
		T7_ = searchTypeFor__types_u423(t_p1, colonanonymous___cgen_u1869);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA8_: ;
		T3_ = !(T7_);
LA6_: ;
		if (!T3_) goto LA9_;
		msg_1.len = 0; msg_1.p = NIM_NIL;
		msg2_1.len = 0; msg2_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		msg_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1288;
		addTypeHeader__types_u209((&msg_1), (*(*m_p0).g).config, t_p1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)7), NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		msg2_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1289;
		addQuoted__stdZprivateZoscommon_u120((&msg2_1), msg_1);
		T12_[0] = name_p2;
		colontmpD_ = rope__ropes_u15(size_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		T12_[1] = colontmpD_;
		T12_[2] = msg2_1;
		colontmpD__2 = percent___cgen_u1882(T12_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)5))- 0]), colontmpD__2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)5))- 0]), colontmpD__2);
		{
			LA11_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(msg2_1);
			eqdestroy___system_u2691(msg_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOpenArrayDesc__cgen_u6122)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p2, tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q kind_p3) {
	NimStringV2 result;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_1;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)sig_1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	hashType__sighashes_u411(t_p1, (*(*m_p0).g).config, 2, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T6_;
		if (!(kind_p3 == ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0))) goto LA3_;
		colontmpD_ = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_.len = 0; T6_.p = NIM_NIL;
		colontmpD_ = elementType__ast_u5331(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD__2 = getTypeDescWeak__cgen_u3400(m_p0, colontmpD_, check_p2, kind_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_ = rawNewString(colontmpD__2.len + 1);
appendString((&T6_), colontmpD__2);
appendString((&T6_), TM__MQdRN7fpbG7rPm4JpVVAhA_1292);
		result = T6_;
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = cacheGetType__cgen_u1466((*m_p0).typeCache, sig_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 elemType_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 T15_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T16_;
			if (!(result.len == 0)) goto LA12_;
			elemType_1.len = 0; elemType_1.p = NIM_NIL;
			colontmpD__4 = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T15_.len = 0; T15_.p = NIM_NIL;
			T15_ = getTypeName__cgen_u1281(m_p0, t_p1, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA14_;}
			eqsink___system_u2700((&result), T15_);
			colontmpD__3 = eqdup___system_u2697(result);
			X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			colontmpD__4 = elementType__ast_u5331(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			elemType_1 = getTypeDescWeak__cgen_u3400(m_p0, colontmpD__4, check_p2, kind_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			T16_[0] = result;
			T16_[1] = elemType_1;
			colontmpD__5 = percent___cgen_u6180(T16_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__5);
			{
				LA14_:;
			}
			{
				oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___system_u2691(elemType_1);
				*nimErr_ = oldNimErrFin14_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA12_: ;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, scanCppGenericSlot__cgen_u6072)(NimStringV2 pat_p0, NI* cursor_p1, NI* outIdx_p2, NI* outStars_p3) {
	NIM_BOOL result;
	NI begin_1;
{	(*cursor_p1) += ((NI)1);
	begin_1 = (*cursor_p1);
	{
		while (1) {
			if (!((NU8)(pat_p0.p->data[(*cursor_p1)]) == (NU8)(42))) goto LA2;
			(*cursor_p1) += ((NI)1);
		} LA2: ;
	}
	{
		if (!(((NU8)(pat_p0.p->data[(*cursor_p1)])) >= ((NU8)(48)) && ((NU8)(pat_p0.p->data[(*cursor_p1)])) <= ((NU8)(57)))) goto LA5_;
		(*outIdx_p2) = (NI)(((NU8)(pat_p0.p->data[(*cursor_p1)])) - ((NI)48));
		(*outStars_p3) = (NI)((*cursor_p1) - begin_1);
		(*cursor_p1) += ((NI)1);
		result = NIM_TRUE;
		goto BeforeRet_;
	}
	goto LA3_;
LA5_: ;
	{
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, resolveStarsInCppType__cgen_u6104)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, NI idx_p1, NI stars_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = kidsLen__ast_u5648(typ_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T3_ <= idx_p1)) goto LA4_;
		raiseAssert__stdZassertions_u15(TM__MQdRN7fpbG7rPm4JpVVAhA_1324);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	eqcopy___ast_u3381(&result, (*typ_p0).sons.p->data[idx_p1]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI res_1;
		i_1 = (NI)0;
		res_1 = ((NI)1);
		{
			while (1) {
				if (!(res_1 <= stars_p2)) goto LA8;
				i_1 = ((NI) (res_1));
				{
					NIM_BOOL T11_;
					NI T13_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T16_;
					T11_ = (NIM_BOOL)0;
					T11_ = !((result == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
					if (!(T11_)) goto LA12_;
					T13_ = (NI)0;
					T13_ = kidsLen__ast_u5648(result);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T11_ = (((NI)0) < T13_);
LA12_: ;
					if (!T11_) goto LA14_;
					T16_ = NIM_NIL;
					{
						if (!((*result).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11))) goto LA19_;
						eqcopy___ast_u3381(&result, (*result).sons.p->data[((NI)1)]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
					goto LA17_;
LA19_: ;
					{
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T22_;
						T22_ = NIM_NIL;
						T22_ = elemType__types_u254(result);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T22_); goto BeforeRet_;}
						eqsink___ast_u3387(&result, T22_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA17_: ;
				}
LA14_: ;
				res_1 += ((NI)1);
			} LA8: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, lacksMTypeField__types_u2937)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = !(((*typ_p0).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = (((*(*typ_p0).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0);
LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA4_;
	T1_ = (((*typ_p0).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)2)))&63U)))!=0);
LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addField__cgen_u530)(NimStringV2* obj_p0, NimStringV2 name_p1, NimStringV2 typ_p2) {
	nimAddCharV1((&(*obj_p0)), 9);
	prepareAdd((&(*obj_p0)), typ_p2.len + 0);
appendString((&(*obj_p0)), typ_p2);
	prepareAdd((&(*obj_p0)), 1);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_1345);
	prepareAdd((&(*obj_p0)), name_p1.len + 0);
appendString((&(*obj_p0)), name_p1);
	prepareAdd((&(*obj_p0)), 2);
appendString((&(*obj_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_1346);
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, ptrType__cgen_u553)(NimStringV2 t_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = rawNewString(t_p0.len + 1);
appendString((&T1_), t_p0);
appendString((&T1_), TM__MQdRN7fpbG7rPm4JpVVAhA_1353);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getRecordDesc__cgen_u5412)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p3) {
	NimStringV2 result;
	NimStringV2 baseType_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	baseType_1.len = 0; baseType_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	baseType_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1334;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		NimStringV2 T7_;
		colontmpD_ = baseClass__ast_u5348(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA4_;
		colontmpD__2 = NIM_NIL;
		colontmpD__3 = NIM_NIL;
		colontmpD__2 = baseClass__ast_u5348(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__3 = skipTypes__ast_u5379(colontmpD__2, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = getTypeDescAux__cgen_u1419(m_p0, colontmpD__3, check_p3, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)4));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA6_;}
		eqsink___system_u2700((&baseType_1), T7_);
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		NIM_BOOL T12_;
		tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ baseKindX60gensym381__1;
		NI currLenX60gensym381__1;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*typ_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
		if (T12_) goto LA13_;
		T12_ = !((((*(*typ_p1).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)53)))&63U)))!=0));
LA13_: ;
		if (!T12_) goto LA14_;
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_1335;
		{
			if (!(((*typ_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23)))&63U)))!=0)) goto LA18_;
			{
				NimStringV2 colontmpD__4;
				if (!((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)7)))&15U)))!=0)) goto LA22_;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__4 = structOrUnion__cgen_u545(typ_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&result), colontmpD__4.len + 0);
appendString((&result), colontmpD__4);
				prepareAdd((&result), 28);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1337);
				eqdestroy___system_u2691(colontmpD__4);
			}
			goto LA20_;
LA22_: ;
			{
				NimStringV2 colontmpD__5;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				prepareAdd((&result), 22);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1339);
				colontmpD__5 = structOrUnion__cgen_u545(typ_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&result), colontmpD__5.len + 0);
appendString((&result), colontmpD__5);
				eqdestroy___system_u2691(colontmpD__5);
			}
LA20_: ;
		}
		goto LA16_;
LA18_: ;
		{
			NimStringV2 colontmpD__6;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__6 = structOrUnion__cgen_u545(typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&result), colontmpD__6.len + 0);
appendString((&result), colontmpD__6);
			eqdestroy___system_u2691(colontmpD__6);
		}
LA16_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1340);
		prepareAdd((&result), name_p2.len + 0);
appendString((&result), name_p2);
		baseKindX60gensym381__1 = ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)0);
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
			if (!((*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17))) goto LA28_;
			colontmpD__7 = NIM_NIL;
			{
				colontmpD__7 = baseClass__ast_u5348(typ_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(colontmpD__7 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA32_;
				{
					NIM_BOOL T36_;
					T36_ = (NIM_BOOL)0;
					T36_ = lacksMTypeField__types_u2937(typ_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!T36_) goto LA37_;
					baseKindX60gensym381__1 = ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)0);
				}
				goto LA34_;
LA37_: ;
				{
					if (!(((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA40_;
					baseKindX60gensym381__1 = ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)4);
				}
				goto LA34_;
LA40_: ;
				{
					baseKindX60gensym381__1 = ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)3);
				}
LA34_: ;
			}
			goto LA30_;
LA32_: ;
			{
				NIM_BOOL T44_;
				T44_ = (NIM_BOOL)0;
				T44_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T44_) goto LA45_;
				T44_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA45_: ;
				if (!T44_) goto LA46_;
				baseKindX60gensym381__1 = ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)1);
			}
			goto LA30_;
LA46_: ;
			{
				baseKindX60gensym381__1 = ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)2);
			}
LA30_: ;
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA28_: ;
		{
			if (!(baseKindX60gensym381__1 == ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)1))) goto LA51_;
			prepareAdd((&result), 10);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1342);
			prepareAdd((&result), baseType_1.len + 0);
appendString((&result), baseType_1);
		}
LA51_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1343);
		prepareAdd((&result), 2);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1344);
		currLenX60gensym381__1 = result.len;
		switch (baseKindX60gensym381__1) {
		case ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)0):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
			colontmpD__8 = NIM_NIL;
			{
				NIM_BOOL T56_;
				NIM_BOOL T57_;
				NIM_BOOL T58_;
				NIM_BOOL T59_;
				NIM_BOOL T60_;
				NI T63_;
				T56_ = (NIM_BOOL)0;
				T57_ = (NIM_BOOL)0;
				T58_ = (NIM_BOOL)0;
				T59_ = (NIM_BOOL)0;
				T60_ = (NIM_BOOL)0;
				T60_ = contains__cgen_u4125((*(*(*m_p0).g).graph).memberProcsPerType, (*typ_p1).itemId);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T59_ = !(T60_);
				if (!(T59_)) goto LA61_;
				T59_ = !(((*typ_p1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA61_: ;
				T58_ = T59_;
				if (!(T58_)) goto LA62_;
				T63_ = (NI)0;
				T63_ = len__ast_u3190((*typ_p1).n);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T58_ = (T63_ == ((NI)1));
LA62_: ;
				T57_ = T58_;
				if (!(T57_)) goto LA64_;
				T57_ = ((*(*(*typ_p1).n)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA64_: ;
				T56_ = T57_;
				if (!(T56_)) goto LA65_;
				colontmpD__8 = skipTypes__ast_u5379((*(*(*(*typ_p1).n)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).typ, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T56_ = ((*colontmpD__8).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49));
LA65_: ;
				if (!T56_) goto LA66_;
				addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1348, TM__MQdRN7fpbG7rPm4JpVVAhA_1350);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA66_: ;
			eqdestroy___ast_u3378(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)1):
		{
		}
		break;
		case ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)3):
		{
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__9 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1354);
			if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
			colontmpD__10 = ptrType__cgen_u553(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
			addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1352, colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
			{
				LA70_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)4):
		{
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__11 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1356);
			if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
			colontmpD__12 = ptrType__cgen_u553(colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
			addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1355, colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
			{
				LA74_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)2):
		{
			addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1358, baseType_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default: __builtin_unreachable();
		}
		addRecordFields__cgen_u5247((&result), m_p0, typ_p1, check_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T80_;
			NIM_BOOL T81_;
			NIM_BOOL T84_;
			T80_ = (NIM_BOOL)0;
			T81_ = (NIM_BOOL)0;
			T81_ = (baseKindX60gensym381__1 == ((tyEnum_BaseClassKindX60gensym381___WWPc268R3S8NCJPauSnRsQ)0));
			if (!(T81_)) goto LA82_;
			T81_ = (currLenX60gensym381__1 == result.len);
LA82_: ;
			T80_ = T81_;
			if (!(T80_)) goto LA83_;
			T84_ = (NIM_BOOL)0;
			T84_ = contains__cgen_u4125((*(*(*m_p0).g).graph).memberProcsPerType, (*typ_p1).itemId);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T80_ = !(T84_);
LA83_: ;
			if (!T80_) goto LA85_;
			addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1359, TM__MQdRN7fpbG7rPm4JpVVAhA_1360);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA85_: ;
		prepareAdd((&result), 3);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1361);
		{
			NIM_BOOL T89_;
			T89_ = (NIM_BOOL)0;
			T89_ = (((*typ_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23)))&63U)))!=0);
			if (!(T89_)) goto LA90_;
			T89_ = !(((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)7)))&15U)))!=0));
LA90_: ;
			if (!T89_) goto LA91_;
			prepareAdd((&result), 18);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1362);
		}
LA91_: ;
	}
	goto LA10_;
LA14_: ;
	{
		NimStringV2 desc_1;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T95_;
		desc_1.len = 0; desc_1.p = NIM_NIL;
		desc_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1363;
		addRecordFields__cgen_u5247((&desc_1), m_p0, typ_p1, check_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
		T95_[0] = name_p2;
		T95_[1] = desc_1;
		T95_[2] = baseType_1;
		result = runtimeFormat__ropes_u39((*(*(*typ_p1).sym).constraint)._kind_3.strVal, T95_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
		{
			LA94_:;
		}
		{
			eqdestroy___system_u2691(desc_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(baseType_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTupleDesc__cgen_u5748)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, NimStringV2 name_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p3) {
	NimStringV2 result;
	tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA baseKindX60gensym401__1;
	NI currLenX60gensym401__1;
NIM_BOOL oldNimErrFin64_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_1366;
	{
		if (!(((*typ_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23)))&63U)))!=0)) goto LA3_;
		{
			NimStringV2 colontmpD_;
			if (!((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)7)))&15U)))!=0)) goto LA7_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD_ = structOrUnion__cgen_u545(typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
			prepareAdd((&result), 28);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1367);
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA5_;
LA7_: ;
		{
			NimStringV2 colontmpD__2;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			prepareAdd((&result), 22);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1368);
			colontmpD__2 = structOrUnion__cgen_u545(typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&result), colontmpD__2.len + 0);
appendString((&result), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
		}
LA5_: ;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 colontmpD__3;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__3 = structOrUnion__cgen_u545(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
	}
LA1_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1369);
	prepareAdd((&result), name_p2.len + 0);
appendString((&result), name_p2);
	baseKindX60gensym401__1 = ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)0);
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		if (!((*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17))) goto LA13_;
		colontmpD__4 = NIM_NIL;
		{
			colontmpD__4 = baseClass__ast_u5348(typ_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(colontmpD__4 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA17_;
			{
				NIM_BOOL T21_;
				T21_ = (NIM_BOOL)0;
				T21_ = lacksMTypeField__types_u2937(typ_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!T21_) goto LA22_;
				baseKindX60gensym401__1 = ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)0);
			}
			goto LA19_;
LA22_: ;
			{
				if (!(((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA25_;
				baseKindX60gensym401__1 = ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)4);
			}
			goto LA19_;
LA25_: ;
			{
				baseKindX60gensym401__1 = ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)3);
			}
LA19_: ;
		}
		goto LA15_;
LA17_: ;
		{
			NIM_BOOL T29_;
			T29_ = (NIM_BOOL)0;
			T29_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T29_) goto LA30_;
			T29_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA30_: ;
			if (!T29_) goto LA31_;
			baseKindX60gensym401__1 = ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)1);
		}
		goto LA15_;
LA31_: ;
		{
			baseKindX60gensym401__1 = ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)2);
		}
LA15_: ;
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA13_: ;
	{
		if (!(baseKindX60gensym401__1 == ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)1))) goto LA36_;
		prepareAdd((&result), 10);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1370);
		prepareAdd((&result), 0);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1371);
	}
LA36_: ;
	prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1372);
	prepareAdd((&result), 2);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1373);
	currLenX60gensym401__1 = result.len;
	switch (baseKindX60gensym401__1) {
	case ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)0):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		colontmpD__5 = NIM_NIL;
		{
			NIM_BOOL T41_;
			NIM_BOOL T42_;
			NIM_BOOL T43_;
			NIM_BOOL T44_;
			NIM_BOOL T45_;
			NI T48_;
			T41_ = (NIM_BOOL)0;
			T42_ = (NIM_BOOL)0;
			T43_ = (NIM_BOOL)0;
			T44_ = (NIM_BOOL)0;
			T45_ = (NIM_BOOL)0;
			T45_ = contains__cgen_u4125((*(*(*m_p0).g).graph).memberProcsPerType, (*typ_p1).itemId);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T44_ = !(T45_);
			if (!(T44_)) goto LA46_;
			T44_ = !(((*typ_p1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA46_: ;
			T43_ = T44_;
			if (!(T43_)) goto LA47_;
			T48_ = (NI)0;
			T48_ = len__ast_u3190((*typ_p1).n);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T43_ = (T48_ == ((NI)1));
LA47_: ;
			T42_ = T43_;
			if (!(T42_)) goto LA49_;
			T42_ = ((*(*(*typ_p1).n)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA49_: ;
			T41_ = T42_;
			if (!(T41_)) goto LA50_;
			colontmpD__5 = skipTypes__ast_u5379((*(*(*(*typ_p1).n)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).typ, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T41_ = ((*colontmpD__5).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49));
LA50_: ;
			if (!T41_) goto LA51_;
			addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1374, TM__MQdRN7fpbG7rPm4JpVVAhA_1375);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA51_: ;
		eqdestroy___ast_u3378(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)1):
	{
	}
	break;
	case ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)3):
	{
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__6 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1377);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		colontmpD__7 = ptrType__cgen_u553(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1376, colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		{
			LA55_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)4):
	{
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__8 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1379);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		colontmpD__9 = ptrType__cgen_u553(colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1378, colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		{
			LA59_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)2):
	{
		addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1380, TM__MQdRN7fpbG7rPm4JpVVAhA_1381);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_1;
		NI i_1;
		a_1 = NIM_NIL;
		i_1 = (NI)0;
		{
			NI i_2;
			NI colontmp_;
			NI T66_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			T66_ = (*typ_p1).sons.len;
			colontmp_ = T66_;
			i_3 = ((NI)0);
			{
				while (1) {
					if (!(i_3 < colontmp_)) goto LA68;
					i_2 = i_3;
					i_1 = i_2;
					eqcopy___ast_u3381(&a_1, (*typ_p1).sons.p->data[i_2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
					{
						NimStringV2 colontmpD__10;
						NimStringV2 colontmpD__11;
						NimStringV2 colontmpD__12;
						NimStringV2 T76_;
						colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
						colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
						colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
						{
							NIM_BOOL T73_;
							T73_ = (NIM_BOOL)0;
							T73_ = isEmptyType__ast_u7234(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							if (!T73_) goto LA74_;
							eqdestroy___system_u2691(colontmpD__12);
							eqdestroy___system_u2691(colontmpD__11);
							eqdestroy___system_u2691(colontmpD__10);
							goto LA69;
						}
LA74_: ;
						T76_.len = 0; T76_.p = NIM_NIL;
						colontmpD__10 = dollar___systemZdollars_u9(i_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
						T76_ = rawNewString(colontmpD__10.len + 5);
appendString((&T76_), TM__MQdRN7fpbG7rPm4JpVVAhA_1383);
appendString((&T76_), colontmpD__10);
						colontmpD__11 = T76_;
						colontmpD__12 = getTypeDescAux__cgen_u1419(m_p0, a_1, check_p3, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)4));
						if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
						addField__cgen_u530((&result), colontmpD__11, colontmpD__12);
						if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
						{
							LA70_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__12);
							eqdestroy___system_u2691(colontmpD__11);
							eqdestroy___system_u2691(colontmpD__10);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
					} LA69: ;
					i_3 += ((NI)1);
				} LA68: ;
			}
		}
		{
			LA64_:;
		}
		{
			oldNimErrFin64_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin64_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	{
		NIM_BOOL T83_;
		NIM_BOOL T84_;
		NIM_BOOL T87_;
		T83_ = (NIM_BOOL)0;
		T84_ = (NIM_BOOL)0;
		T84_ = (baseKindX60gensym401__1 == ((tyEnum_BaseClassKindX60gensym401___0rKqfIPWz9cIpfAgSt9ajrOA)0));
		if (!(T84_)) goto LA85_;
		T84_ = (currLenX60gensym401__1 == result.len);
LA85_: ;
		T83_ = T84_;
		if (!(T83_)) goto LA86_;
		T87_ = (NIM_BOOL)0;
		T87_ = contains__cgen_u4125((*(*(*m_p0).g).graph).memberProcsPerType, (*typ_p1).itemId);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T83_ = !(T87_);
LA86_: ;
		if (!T83_) goto LA88_;
		addField__cgen_u530((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1384, TM__MQdRN7fpbG7rPm4JpVVAhA_1385);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA88_: ;
	prepareAdd((&result), 3);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1386);
	{
		NIM_BOOL T92_;
		T92_ = (NIM_BOOL)0;
		T92_ = (((*typ_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23)))&63U)))!=0);
		if (!(T92_)) goto LA93_;
		T92_ = !(((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)7)))&15U)))!=0));
LA93_: ;
		if (!T92_) goto LA94_;
		prepareAdd((&result), 18);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1387);
	}
LA94_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeDescAux__cgen_u1419)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* origTyp_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p2, tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q kind_p3) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_1;
NIM_BOOL oldNimErrFin50_;
NIM_BOOL oldNimErrFin207_;
NIM_BOOL oldNimErrFin223_;
NIM_BOOL oldNimErrFin196_;
NIM_BOOL oldNimErrFin254_;
NIM_BOOL oldNimErrFin270_;
NIM_BOOL oldNimErrFin294_;
NIM_BOOL oldNimErrFin329_;
NIM_BOOL oldNimErrFin275_;
NIM_BOOL oldNimErrFin406_;
NIM_BOOL oldNimErrFin425_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym551__1;
NIM_BOOL oldNimErrFin27_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	t_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	t_1 = skipTypes__ast_u5379(origTyp_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_27);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym427__1;
		NIM_BOOL T4_;
		xX60gensym427__1 = (*t_1).itemId;
		T4_ = (NIM_BOOL)0;
		T4_ = containsOrIncl__astyaml_u223(check_p2, (NI)((NI)((NU32)(((NI) (xX60gensym427__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym427__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		{
			NIM_BOOL T9_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 T14_;
			T9_ = (NIM_BOOL)0;
			T9_ = isImportedCppType__cgen_u1384(origTyp_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (T9_) goto LA10_;
			T9_ = isImportedCppType__cgen_u1384(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA10_: ;
			if (!!(T9_)) goto LA11_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T14_.len = 0; T14_.p = NIM_NIL;
			colontmpD__2 = typeToString__types_u54(origTyp_p1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T14_ = rawNewString(colontmpD__2.len + 28);
appendString((&T14_), TM__MQdRN7fpbG7rPm4JpVVAhA_30);
appendString((&T14_), colontmpD__2);
			colontmpD__3 = T14_;
			internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, colontmpD__3, TM__MQdRN7fpbG7rPm4JpVVAhA_31);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			{
				LA13_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA11_: ;
	}
LA5_: ;
	{
		if (!!(((*t_1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA19_;
		useHeader__cgen_u123(m_p0, (*t_1).sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA19_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = !((t_1 == origTyp_p1));
		if (!(T23_)) goto LA24_;
		T23_ = !(((*origTyp_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA24_: ;
		if (!T23_) goto LA25_;
		useHeader__cgen_u123(m_p0, (*origTyp_p1).sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA25_: ;
	nimZeroMem((void*)sig_1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	hashType__sighashes_u411(origTyp_p1, (*(*m_p0).g).config, 2, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = skipTypes__ast_u5379(origTyp_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1282);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = getTypePre__cgen_u3178(m_p0, colontmpD_, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T30_;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym448__1;
		T30_ = (NIM_BOOL)0;
		T30_ = !((result.len == 0));
		if (!(T30_)) goto LA31_;
		T30_ = !(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27)));
LA31_: ;
		if (!T30_) goto LA32_;
		xX60gensym448__1 = (*t_1).itemId;
		excl__suggestsymdb_u161(check_p2, (NI)((NI)((NU32)(((NI) (xX60gensym448__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym448__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		{
			NIM_BOOL T36_;
			NIM_BOOL T38_;
			T36_ = (NIM_BOOL)0;
			T36_ = (kind_p3 == ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)1));
			if (T36_) goto LA37_;
			T38_ = (NIM_BOOL)0;
			T38_ = (kind_p3 == ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)2));
			if (!(T38_)) goto LA39_;
			T38_ = ((*origTyp_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11));
LA39_: ;
			T36_ = T38_;
LA37_: ;
			if (!T36_) goto LA40_;
			prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1284);
		}
LA40_: ;
		{
			NIM_BOOL T44_;
			NIM_BOOL T46_;
			T44_ = (NIM_BOOL)0;
			T44_ = isImportedType__cgen_u1373(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T44_)) goto LA45_;
			T46_ = (NIM_BOOL)0;
			T46_ = containsOrIncl__cgen_u6258((&(*m_p0).typeABICache), sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T44_ = !(T46_);
LA45_: ;
			if (!T44_) goto LA47_;
			addAbiCheck__cgen_u1860(m_p0, t_1, result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA47_: ;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA32_: ;
	switch ((*t_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	{
		NimStringV2 star_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* et_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* etB_1;
		NimStringV2 T51_;
		star_1.len = 0; star_1.p = NIM_NIL;
		et_1 = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		etB_1 = NIM_NIL;
		T51_.len = 0; T51_.p = NIM_NIL;
		{
			NIM_BOOL T54_;
			NIM_BOOL T55_;
			NIM_BOOL T58_;
			T54_ = (NIM_BOOL)0;
			T55_ = (NIM_BOOL)0;
			T55_ = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
			if (!(T55_)) goto LA56_;
			T55_ = !((((*origTyp_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)20)))&63U)))!=0));
LA56_: ;
			T54_ = T55_;
			if (!(T54_)) goto LA57_;
			T58_ = (NIM_BOOL)0;
			T58_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T58_) goto LA59_;
			T58_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA59_: ;
			T54_ = T58_;
LA57_: ;
			if (!T54_) goto LA60_;
			star_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1290;
		}
		goto LA52_;
LA60_: ;
		{
			star_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1291;
		}
LA52_: ;
		colontmpD__4 = skipTypes__ast_u5379(origTyp_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		et_1 = elementType__ast_u5331(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		etB_1 = skipTypes__ast_u5379(et_1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		{
			NIM_BOOL T65_;
			tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T66_;
			NIM_BOOL T68_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T79_;
			T65_ = (NIM_BOOL)0;
			T66_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
			T66_ = mapType__cgen_u1315((*(*m_p0).g).config, t_1, (kind_p3 == ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			T65_ = (T66_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)18));
			if (!(T65_)) goto LA67_;
			T68_ = (NIM_BOOL)0;
			T68_ = !(((*etB_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27)));
			if (T68_) goto LA69_;
			T68_ = (kind_p3 == ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
LA69_: ;
			T65_ = T68_;
LA67_: ;
			if (!T65_) goto LA70_;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T76_;
				if (!((*etB_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19))) goto LA74_;
				T76_ = NIM_NIL;
				T76_ = getSysType__magicsys_u55((*(*m_p0).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)41));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T76_); goto LA50_;}
				eqsink___ast_u3387(&et_1, T76_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			}
			goto LA72_;
LA74_: ;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T78_;
				T78_ = NIM_NIL;
				T78_ = elemType__types_u254(etB_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T78_); goto LA50_;}
				eqsink___ast_u3387(&et_1, T78_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			}
LA72_: ;
			T79_ = NIM_NIL;
			T79_ = skipTypes__ast_u5379(et_1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T79_); goto LA50_;}
			eqsink___ast_u3387(&etB_1, T79_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			nimPrepareStrMutationV2((&star_1));
			star_1.p->data[((NI)0)] = 42;
		}
LA70_: ;
		switch ((*etB_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
		{
			{
				NIM_BOOL T83_;
				NimStringV2 colontmpD__5;
				NimStringV2 T88_;
				T83_ = (NIM_BOOL)0;
				T83_ = isImportedCppType__cgen_u1384(etB_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				if (!(T83_)) goto LA84_;
				T83_ = ((*et_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11));
LA84_: ;
				if (!T83_) goto LA85_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				T88_.len = 0; T88_.p = NIM_NIL;
				colontmpD__5 = getTypeDescAux__cgen_u1419(m_p0, et_1, check_p2, kind_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
				T88_ = rawNewString(colontmpD__5.len + star_1.len + 0);
appendString((&T88_), colontmpD__5);
appendString((&T88_), star_1);
				eqsink___system_u2700((&result), T88_);
				{
					LA87_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			}
			goto LA81_;
LA85_: ;
			{
				NimStringV2 name_1;
				NimStringV2 colontmpD__6;
				tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T93_;
				NimStringV2 T94_;
				name_1.len = 0; name_1.p = NIM_NIL;
				nimZeroMem((void*)T93_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
				hashType__sighashes_u411(et_1, (*(*m_p0).g).config, 2, T93_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
				name_1 = getTypeForward__cgen_u3216(m_p0, et_1, T93_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
				T94_.len = 0; T94_.p = NIM_NIL;
				T94_ = rawNewString(name_1.len + star_1.len + 0);
appendString((&T94_), name_1);
appendString((&T94_), star_1);
				eqsink___system_u2700((&result), T94_);
				colontmpD__6 = eqdup___system_u2697(result);
				X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
				{
					LA92_:;
				}
				{
					eqdestroy___system_u2691(name_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			}
LA81_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
		{
			{
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2 T103_;
				if (!(((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA100_;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				T103_.len = 0; T103_.p = NIM_NIL;
				colontmpD__7 = getTypeDescWeak__cgen_u3400(m_p0, et_1, check_p2, kind_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				T103_ = rawNewString(colontmpD__7.len + star_1.len + 0);
appendString((&T103_), colontmpD__7);
appendString((&T103_), star_1);
				eqsink___system_u2700((&result), T103_);
				colontmpD__8 = eqdup___system_u2697(result);
				X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				{
					LA102_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__7);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			}
			goto LA98_;
LA100_: ;
			{
				NimStringV2 name_2;
				NimStringV2 colontmpD__9;
				NimStringV2 colontmpD__10;
				tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T108_;
				NimStringV2 T109_;
				name_2.len = 0; name_2.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				nimZeroMem((void*)T108_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
				hashType__sighashes_u411(et_1, (*(*m_p0).g).config, 2, T108_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				name_2 = getTypeForward__cgen_u3216(m_p0, et_1, T108_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T109_.len = 0; T109_.p = NIM_NIL;
				colontmpD__9 = seqStar__cgen_u3209(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T109_ = rawNewString(name_2.len + colontmpD__9.len + star_1.len + 0);
appendString((&T109_), name_2);
appendString((&T109_), colontmpD__9);
appendString((&T109_), star_1);
				eqsink___system_u2700((&result), T109_);
				colontmpD__10 = eqdup___system_u2697(result);
				X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				pushType__cgen_u3159(m_p0, et_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				{
					LA107_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(name_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
			}
LA98_: ;
		}
		break;
		default:
		{
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 T114_;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			T114_.len = 0; T114_.p = NIM_NIL;
			colontmpD__11 = getTypeDescAux__cgen_u1419(m_p0, et_1, check_p2, kind_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			T114_ = rawNewString(colontmpD__11.len + star_1.len + 0);
appendString((&T114_), colontmpD__11);
appendString((&T114_), star_1);
			eqsink___system_u2700((&result), T114_);
			colontmpD__12 = eqdup___system_u2697(result);
			X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			{
				LA113_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__11);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		}
		break;
		}
		{
			LA50_:;
		}
		{
			oldNimErrFin50_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(etB_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			eqdestroy___ast_u3378(et_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			eqdestroy___system_u2691(star_1);
			*nimErr_ = oldNimErrFin50_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		NimStringV2 T120_;
		T120_.len = 0; T120_.p = NIM_NIL;
		T120_ = getOpenArrayDesc__cgen_u6122(m_p0, t_1, check_p2, kind_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T120_); goto LA27_;}
		eqsink___system_u2700((&result), T120_);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	{
		NimStringV2 T122_;
		T122_.len = 0; T122_.p = NIM_NIL;
		T122_ = cacheGetType__cgen_u1466((*m_p0).typeCache, sig_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T122_); goto LA27_;}
		eqsink___system_u2700((&result), T122_);
		{
			NimStringV2 T127_;
			if (!(result.len == 0)) goto LA125_;
			T127_.len = 0; T127_.p = NIM_NIL;
			T127_ = getTypeName__cgen_u1281(m_p0, origTyp_p1, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T127_); goto LA27_;}
			eqsink___system_u2700((&result), T127_);
			{
				NIM_BOOL T130_;
				NIM_BOOL T132_;
				NimStringV2 colontmpD__13;
				NI size_1;
				T130_ = (NIM_BOOL)0;
				T130_ = isImportedCppType__cgen_u1384(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				if (T130_) goto LA131_;
				T132_ = (NIM_BOOL)0;
				T132_ = (((*(*t_1).sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0);
				if (!(T132_)) goto LA133_;
				T132_ = ((*(*t_1).sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0));
LA133_: ;
				T130_ = T132_;
LA131_: ;
				if (!!(T130_)) goto LA134_;
				colontmpD__13 = eqdup___system_u2697(result);
				X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				size_1 = (NI)0;
				{
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T138_;
					NIM_BOOL T139_;
					NimStringV2 colontmpD__14;
					tyArray__YgExxhfgKcesA5EOUj1MOA T142_;
					T138_ = firstOrd__types_u1182((*(*m_p0).g).config, t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					T139_ = (NIM_BOOL)0;
					T139_ = lt___int128_u933(T138_, IL64(0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					if (!T139_) goto LA140_;
					colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
					T142_[0] = result;
					colontmpD__14 = percent___cgen_u7974(T142_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__14.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__14);
					size_1 = ((NI)4);
					eqdestroy___system_u2691(colontmpD__14);
				}
				goto LA136_;
LA140_: ;
				{
					NI64 T144_;
					T144_ = (NI64)0;
					T144_ = getSize__types_u3397((*(*m_p0).g).config, t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					size_1 = ((NI) (T144_));
					switch (size_1) {
					case ((NI)1):
					{
						NimStringV2 colontmpD__15;
						tyArray__YgExxhfgKcesA5EOUj1MOA T146_;
						colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
						T146_[0] = result;
						colontmpD__15 = percent___cgen_u7979(T146_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
						prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__15.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__15);
						eqdestroy___system_u2691(colontmpD__15);
					}
					break;
					case ((NI)2):
					{
						NimStringV2 colontmpD__16;
						tyArray__YgExxhfgKcesA5EOUj1MOA T148_;
						colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
						T148_[0] = result;
						colontmpD__16 = percent___cgen_u7984(T148_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
						prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__16.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__16);
						eqdestroy___system_u2691(colontmpD__16);
					}
					break;
					case ((NI)4):
					{
						NimStringV2 colontmpD__17;
						tyArray__YgExxhfgKcesA5EOUj1MOA T150_;
						colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
						T150_[0] = result;
						colontmpD__17 = percent___cgen_u7974(T150_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
						prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__17.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__17);
						eqdestroy___system_u2691(colontmpD__17);
					}
					break;
					case ((NI)8):
					{
						NimStringV2 colontmpD__18;
						tyArray__YgExxhfgKcesA5EOUj1MOA T152_;
						colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
						T152_[0] = result;
						colontmpD__18 = percent___cgen_u7993(T152_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
						prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__18.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__18);
						eqdestroy___system_u2691(colontmpD__18);
					}
					break;
					default:
					{
						internalErrorImpl__msgs_u1598((*(*m_p0).g).config, (*(*t_1).sym).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1294, TM__MQdRN7fpbG7rPm4JpVVAhA_1295);
						if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
					}
					break;
					}
				}
LA136_: ;
			}
LA134_: ;
		}
LA125_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		NimStringV2 colontmpD__19;
		NimStringV2 rettype_1;
		NimStringV2 desc_1;
		NimStringV2 T156_;
		rettype_1.len = 0; rettype_1.p = NIM_NIL;
		desc_1.len = 0; desc_1.p = NIM_NIL;
		T156_.len = 0; T156_.p = NIM_NIL;
		T156_ = getTypeName__cgen_u1281(m_p0, origTyp_p1, sig_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T156_); goto LA155_;}
		eqsink___system_u2700((&result), T156_);
		colontmpD__19 = eqdup___system_u2697(result);
		X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__19);
		if (NIM_UNLIKELY(*nimErr_)) goto LA155_;
		rettype_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1296;
		desc_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1297;
		genProcParams__cgen_u3939(m_p0, t_1, (&rettype_1), (&desc_1), check_p2, NIM_TRUE, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA155_;
		{
			NIM_BOOL T159_;
			T159_ = (NIM_BOOL)0;
			T159_ = isImportedType__cgen_u1373(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA155_;
			if (!!(T159_)) goto LA160_;
			{
				NimStringV2 colontmpD__20;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T166_;
				if (!!(((*t_1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9)))) goto LA164_;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				T166_[0] = CallingConvToStr__cgen_u1465[((*t_1).callConv)- 0];
				T166_[1] = rettype_1;
				T166_[2] = result;
				T166_[3] = desc_1;
				colontmpD__20 = percent___cgen_u8050(T166_, 4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA155_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__20.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__20);
				eqdestroy___system_u2691(colontmpD__20);
			}
			goto LA162_;
LA164_: ;
			{
				NimStringV2 colontmpD__21;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T168_;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				T168_[0] = result;
				T168_[1] = rettype_1;
				T168_[2] = desc_1;
				colontmpD__21 = percent___cgen_u8055(T168_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA155_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__21.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__21);
				eqdestroy___system_u2691(colontmpD__21);
			}
LA162_: ;
		}
LA160_: ;
		{
			LA155_:;
		}
		{
			eqdestroy___system_u2691(desc_1);
			eqdestroy___system_u2691(rettype_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		{
			NimStringV2 T176_;
			if (!(((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA174_;
			T176_.len = 0; T176_.p = NIM_NIL;
			T176_ = getTypeDescWeak__cgen_u3400(m_p0, t_1, check_p2, kind_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T176_); goto LA27_;}
			eqsink___system_u2700((&result), T176_);
		}
		goto LA172_;
LA174_: ;
		{
			NimStringV2 colontmpD__22;
			NimStringV2 colontmpD__23;
			NimStringV2 T179_;
			NimStringV2 T190_;
			colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
			colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
			T179_.len = 0; T179_.p = NIM_NIL;
			T179_ = cacheGetType__cgen_u1466((*m_p0).forwTypeCache, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T179_); goto LA178_;}
			eqsink___system_u2700((&result), T179_);
			{
				NimStringV2 colontmpD__24;
				NimStringV2 T184_;
				if (!(result.len == 0)) goto LA182_;
				T184_.len = 0; T184_.p = NIM_NIL;
				T184_ = getTypeName__cgen_u1281(m_p0, origTyp_p1, sig_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T184_); goto LA178_;}
				eqsink___system_u2700((&result), T184_);
				{
					NIM_BOOL T187_;
					NimStringV2 colontmpD__25;
					T187_ = (NIM_BOOL)0;
					T187_ = isImportedType__cgen_u1373(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					if (!!(T187_)) goto LA188_;
					colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
					colontmpD__25 = structOrUnion__cgen_u545(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					addForwardStructFormat__cgen_u3187(m_p0, colontmpD__25, result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					eqdestroy___system_u2691(colontmpD__25);
				}
LA188_: ;
				colontmpD__24 = eqdup___system_u2697(result);
				X5BX5Deq___cgen_u1967((&(*m_p0).forwTypeCache), sig_1, colontmpD__24);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
			}
LA182_: ;
			T190_.len = 0; T190_.p = NIM_NIL;
			colontmpD__22 = seqStar__cgen_u3209(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
			T190_ = rawNewString(result.len + colontmpD__22.len + 0);
appendString((&T190_), result);
appendString((&T190_), colontmpD__22);
			X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, T190_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
			{
				NIM_BOOL T193_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__26;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__27;
				T193_ = (NIM_BOOL)0;
				T193_ = isImportedType__cgen_u1373(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				if (!!(T193_)) goto LA194_;
				colontmpD__26 = NIM_NIL;
				colontmpD__27 = NIM_NIL;
				{
					colontmpD__26 = elementType__ast_u5331(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
					colontmpD__27 = skipTypes__ast_u5379(colontmpD__26, TM__MQdRN7fpbG7rPm4JpVVAhA_170);
					if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
					if (!!(((*colontmpD__27).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)3)))) goto LA199_;
					{
						NIM_BOOL T203_;
						NimStringV2 res_1;
						NimStringV2 colontmpD__28;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__29;
						NimStringV2 colontmpD__30;
						T203_ = (NIM_BOOL)0;
						T203_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
						if (T203_) goto LA204_;
						T203_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA204_: ;
						if (!T203_) goto LA205_;
						res_1.len = 0; res_1.p = NIM_NIL;
						colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
						colontmpD__29 = NIM_NIL;
						colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
						res_1 = rawNewString(((NI)80));
						prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1298);
						cgFormatValue__cgen_u163((&res_1), result);
						if (NIM_UNLIKELY(*nimErr_)) goto LA207_;
						prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1299);
						colontmpD__28 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1300);
						if (NIM_UNLIKELY(*nimErr_)) goto LA207_;
						cgFormatValue__cgen_u163((&res_1), colontmpD__28);
						if (NIM_UNLIKELY(*nimErr_)) goto LA207_;
						prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1301);
						{
							if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA210_;
							prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1302);
						}
LA210_: ;
						prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1303);
						colontmpD__29 = elementType__ast_u5331(t_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA207_;
						colontmpD__30 = getTypeDescAux__cgen_u1419(m_p0, colontmpD__29, check_p2, kind_p3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA207_;
						cgFormatValue__cgen_u163((&res_1), colontmpD__30);
						if (NIM_UNLIKELY(*nimErr_)) goto LA207_;
						prepareAdd((&res_1), 21);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1305);
						{
							if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA214_;
							prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1306);
						}
LA214_: ;
						prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1307);
						{
							if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA218_;
							prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1308);
						}
LA218_: ;
						prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)4))- 0]), res_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)4))- 0]), res_1);
						{
							LA207_:;
						}
						{
							oldNimErrFin207_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__30);
							eqdestroy___ast_u3378(colontmpD__29);
							if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
							eqdestroy___system_u2691(colontmpD__28);
							eqdestroy___system_u2691(res_1);
							*nimErr_ = oldNimErrFin207_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
					}
					goto LA201_;
LA205_: ;
					{
						NimStringV2 res_2;
						NimStringV2 colontmpD__31;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__32;
						NimStringV2 colontmpD__33;
						res_2.len = 0; res_2.p = NIM_NIL;
						colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
						colontmpD__32 = NIM_NIL;
						colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
						res_2 = rawNewString(((NI)80));
						prepareAdd((&res_2), 7);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1309);
						cgFormatValue__cgen_u163((&res_2), result);
						if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
						prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1310);
						{
							if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA226_;
							prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1311);
						}
LA226_: ;
						prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1312);
						colontmpD__31 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1313);
						if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
						cgFormatValue__cgen_u163((&res_2), colontmpD__31);
						if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
						prepareAdd((&res_2), 5);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1314);
						{
							if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA230_;
							prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1315);
						}
LA230_: ;
						prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1316);
						colontmpD__32 = elementType__ast_u5331(t_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
						colontmpD__33 = getTypeDescAux__cgen_u1419(m_p0, colontmpD__32, check_p2, kind_p3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
						cgFormatValue__cgen_u163((&res_2), colontmpD__33);
						if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
						prepareAdd((&res_2), 21);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1317);
						{
							if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA234_;
							prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1318);
						}
LA234_: ;
						prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1319);
						{
							if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA238_;
							prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1320);
						}
LA238_: ;
						prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)4))- 0]), res_2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)4))- 0]), res_2);
						{
							LA223_:;
						}
						{
							oldNimErrFin223_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__33);
							eqdestroy___ast_u3378(colontmpD__32);
							if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
							eqdestroy___system_u2691(colontmpD__31);
							eqdestroy___system_u2691(res_2);
							*nimErr_ = oldNimErrFin223_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
					}
LA201_: ;
				}
				goto LA197_;
LA199_: ;
				{
					eqsink___system_u2700((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1321);
				}
LA197_: ;
				{
					LA196_:;
				}
				{
					oldNimErrFin196_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__27);
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					eqdestroy___ast_u3378(colontmpD__26);
					if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
					*nimErr_ = oldNimErrFin196_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
			}
LA194_: ;
			colontmpD__23 = seqStar__cgen_u3209(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
			prepareAdd((&result), colontmpD__23.len + 0);
appendString((&result), colontmpD__23);
			{
				LA178_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__23);
				eqdestroy___system_u2691(colontmpD__22);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		}
LA172_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
	{
		NimStringV2 colontmpD__34;
		NimStringV2 T248_;
		T248_.len = 0; T248_.p = NIM_NIL;
		T248_ = getTypeName__cgen_u1281(m_p0, origTyp_p1, sig_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T248_); goto LA27_;}
		eqsink___system_u2700((&result), T248_);
		colontmpD__34 = eqdup___system_u2697(result);
		X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__34);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		{
			NIM_BOOL T251_;
			NimStringV2 foo_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__35;
			NimStringV2 colontmpD__36;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T255_;
			T251_ = (NIM_BOOL)0;
			T251_ = isImportedType__cgen_u1373(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			if (!!(T251_)) goto LA252_;
			foo_1.len = 0; foo_1.p = NIM_NIL;
			colontmpD__35 = NIM_NIL;
			colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
			colontmpD__35 = elementType__ast_u5331(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			foo_1 = getTypeDescAux__cgen_u1419(m_p0, colontmpD__35, check_p2, kind_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			T255_[0] = foo_1;
			T255_[1] = result;
			colontmpD__36 = percent___cgen_u8266(T255_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA254_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__36.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__36);
			{
				LA254_:;
			}
			{
				oldNimErrFin254_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__36);
				eqdestroy___ast_u3378(colontmpD__35);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				eqdestroy___system_u2691(foo_1);
				*nimErr_ = oldNimErrFin254_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		}
LA252_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		NimStringV2 colontmpD__37;
		NI64 n_1;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T259_;
		NimStringV2 T264_;
		T259_ = lengthOrd__types_u1491((*(*m_p0).g).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		n_1 = toInt64__int128_u53(T259_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		{
			if (!(n_1 <= IL64(0))) goto LA262_;
			n_1 = IL64(1);
		}
LA262_: ;
		T264_.len = 0; T264_.p = NIM_NIL;
		T264_ = getTypeName__cgen_u1281(m_p0, origTyp_p1, sig_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T264_); goto LA27_;}
		eqsink___system_u2700((&result), T264_);
		colontmpD__37 = eqdup___system_u2697(result);
		X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__37);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		{
			NIM_BOOL T267_;
			NimStringV2 e_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__38;
			NimStringV2 colontmpD__39;
			NimStringV2 colontmpD__40;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T271_;
			T267_ = (NIM_BOOL)0;
			T267_ = isImportedType__cgen_u1373(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			if (!!(T267_)) goto LA268_;
			e_1.len = 0; e_1.p = NIM_NIL;
			colontmpD__38 = NIM_NIL;
			colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
			colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
			colontmpD__38 = elementType__ast_u5331(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
			e_1 = getTypeDescAux__cgen_u1419(m_p0, colontmpD__38, check_p2, kind_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
			T271_[0] = e_1;
			T271_[1] = result;
			colontmpD__39 = rope__ropes_u15(n_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
			T271_[2] = colontmpD__39;
			colontmpD__40 = percent___cgen_u8319(T271_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__40.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__40);
			{
				LA270_:;
			}
			{
				oldNimErrFin270_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__40);
				eqdestroy___system_u2691(colontmpD__39);
				eqdestroy___ast_u3378(colontmpD__38);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				eqdestroy___system_u2691(e_1);
				*nimErr_ = oldNimErrFin270_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		}
LA268_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tt_1;
		tt_1 = NIM_NIL;
		tt_1 = skipTypes__ast_u5379(origTyp_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_1322);
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		{
			NIM_BOOL T278_;
			NimStringV2 cppNameAsRope_1;
			NimStringV2 cppName_1;
			NimStringV2 colontmpD__41;
			NimStringV2 typedefName_1;
			NimStringV2 colontmpD__42;
			NimStringV2 colontmpD__43;
			NimStringV2 colontmpD__44;
			NI i_1;
			NI chunkStart_1;
			NimStringV2 T364_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T365_;
			T278_ = (NIM_BOOL)0;
			T278_ = isImportedCppType__cgen_u1384(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
			if (!(T278_)) goto LA279_;
			T278_ = ((*tt_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11));
LA279_: ;
			if (!T278_) goto LA280_;
			cppNameAsRope_1.len = 0; cppNameAsRope_1.p = NIM_NIL;
			cppName_1.len = 0; cppName_1.p = NIM_NIL;
			colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
			typedefName_1.len = 0; typedefName_1.p = NIM_NIL;
			colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
			colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
			cppNameAsRope_1 = getTypeName__cgen_u1281(m_p0, t_1, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
			cppName_1 = cppNameAsRope_1;
			i_1 = ((NI)0);
			chunkStart_1 = ((NI)0);
			{
				while (1) {
					if (!(i_1 < cppName_1.len)) goto LA284;
					{
						NI chunkEnd_1;
						NI idx_1;
						NI stars_1;
						if (!((NU8)(cppName_1.p->data[i_1]) == (NU8)(39))) goto LA287_;
						chunkEnd_1 = (NI)(i_1 - ((NI)1));
						idx_1 = ((NI)0);
						stars_1 = ((NI)0);
						{
							NIM_BOOL T291_;
							NimStringV2 colontmpD__45;
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInSlot_1;
							T291_ = (NIM_BOOL)0;
							T291_ = scanCppGenericSlot__cgen_u6072(cppName_1, (&i_1), (&idx_1), (&stars_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
							if (!T291_) goto LA292_;
							colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
							typeInSlot_1 = NIM_NIL;
							colontmpD__45 = substr__system_u8632(cppName_1, chunkStart_1, chunkEnd_1);
							prepareAdd((&result), colontmpD__45.len + 0);
appendString((&result), colontmpD__45);
							chunkStart_1 = i_1;
							typeInSlot_1 = resolveStarsInCppType__cgen_u6104(tt_1, (NI)(idx_1 + ((NI)1)), stars_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA294_;
							{
								NIM_BOOL T297_;
								T297_ = (NIM_BOOL)0;
								T297_ = (typeInSlot_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
								if (T297_) goto LA298_;
								T297_ = ((*typeInSlot_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63));
LA298_: ;
								if (!T297_) goto LA299_;
								prepareAdd((&result), 4);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1325);
							}
							goto LA295_;
LA299_: ;
							{
								NimStringV2 colontmpD__46;
								tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T312_;
								if (!((*typeInSlot_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60))) goto LA302_;
								colontmpD__46.len = 0; colontmpD__46.p = NIM_NIL;
								{
									NimStringV2 argX60gensym523__1;
									if (!!(!(((*typeInSlot_1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))))) goto LA307_;
									argX60gensym523__1.len = 0; argX60gensym523__1.p = NIM_NIL;
									argX60gensym523__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_1326);
									if (NIM_UNLIKELY(*nimErr_)) goto LA309_;
									internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, argX60gensym523__1, TM__MQdRN7fpbG7rPm4JpVVAhA_1326);
									if (NIM_UNLIKELY(*nimErr_)) goto LA309_;
									{
										LA309_:;
									}
									{
										eqdestroy___system_u2691(argX60gensym523__1);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA304_;
								}
LA307_: ;
								T312_ = 0;
								colontmpD__46 = renderTree__renderer_u59((*typeInSlot_1).n, T312_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA304_;
								prepareAdd((&result), colontmpD__46.len + 0);
appendString((&result), colontmpD__46);
								{
									LA304_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__46);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA294_;
							}
							goto LA295_;
LA302_: ;
							{
								NimStringV2 colontmpD__47;
								colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
								colontmpD__47 = getTypeDescAux__cgen_u1419(m_p0, typeInSlot_1, check_p2, kind_p3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA316_;
								prepareAdd((&result), colontmpD__47.len + 0);
appendString((&result), colontmpD__47);
								{
									LA316_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__47);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA294_;
							}
LA295_: ;
							{
								LA294_:;
							}
							{
								oldNimErrFin294_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3378(typeInSlot_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
								eqdestroy___system_u2691(colontmpD__45);
								*nimErr_ = oldNimErrFin294_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
						}
LA292_: ;
					}
					goto LA285_;
LA287_: ;
					{
						i_1 += ((NI)1);
					}
LA285_: ;
				} LA284: ;
			}
			{
				NimStringV2 colontmpD__48;
				if (!!((chunkStart_1 == ((NI)0)))) goto LA324_;
				colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
				colontmpD__48 = substr__system_u8645(cppName_1, chunkStart_1);
				prepareAdd((&result), colontmpD__48.len + 0);
appendString((&result), colontmpD__48);
				eqdestroy___system_u2691(colontmpD__48);
			}
			goto LA322_;
LA324_: ;
			{
				NimStringV2 T327_;
				T327_.len = 0; T327_.p = NIM_NIL;
				T327_ = rawNewString(cppNameAsRope_1.len + 1);
appendString((&T327_), cppNameAsRope_1);
appendString((&T327_), TM__MQdRN7fpbG7rPm4JpVVAhA_1328);
				eqsink___system_u2700((&result), T327_);
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* a_1;
					NIM_BOOL needsComma_1;
					a_1 = NIM_NIL;
					needsComma_1 = (NIM_BOOL)0;
					{
						NI i_2;
						NI colontmp_;
						NI T331_;
						NI i_3;
						i_2 = (NI)0;
						colontmp_ = (NI)0;
						T331_ = (*tt_1).sons.len;
						colontmp_ = (NI)(T331_ - ((NI)1));
						i_3 = ((NI)1);
						{
							while (1) {
								if (!(i_3 < colontmp_)) goto LA333;
								i_2 = i_3;
								needsComma_1 = !((i_2 == ((NI)1)));
								eqcopy___ast_u3381(&a_1, (*tt_1).sons.p->data[i_2]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA329_;
								{
									if (!needsComma_1) goto LA336_;
									prepareAdd((&result), 7);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1330);
								}
LA336_: ;
								{
									NIM_BOOL T340_;
									T340_ = (NIM_BOOL)0;
									T340_ = (a_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
									if (T340_) goto LA341_;
									T340_ = ((*a_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63));
LA341_: ;
									if (!T340_) goto LA342_;
									prepareAdd((&result), 4);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1331);
								}
								goto LA338_;
LA342_: ;
								{
									NimStringV2 colontmpD__49;
									tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T355_;
									if (!((*a_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60))) goto LA345_;
									colontmpD__49.len = 0; colontmpD__49.p = NIM_NIL;
									{
										NimStringV2 argX60gensym529__1;
										if (!!(!(((*a_1).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))))) goto LA350_;
										argX60gensym529__1.len = 0; argX60gensym529__1.p = NIM_NIL;
										argX60gensym529__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_1326);
										if (NIM_UNLIKELY(*nimErr_)) goto LA352_;
										internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, argX60gensym529__1, TM__MQdRN7fpbG7rPm4JpVVAhA_1326);
										if (NIM_UNLIKELY(*nimErr_)) goto LA352_;
										{
											LA352_:;
										}
										{
											eqdestroy___system_u2691(argX60gensym529__1);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA347_;
									}
LA350_: ;
									T355_ = 0;
									colontmpD__49 = renderTree__renderer_u59((*a_1).n, T355_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA347_;
									prepareAdd((&result), colontmpD__49.len + 0);
appendString((&result), colontmpD__49);
									{
										LA347_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__49);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA329_;
								}
								goto LA338_;
LA345_: ;
								{
									NimStringV2 colontmpD__50;
									colontmpD__50.len = 0; colontmpD__50.p = NIM_NIL;
									colontmpD__50 = getTypeDescAux__cgen_u1419(m_p0, a_1, check_p2, kind_p3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA359_;
									prepareAdd((&result), colontmpD__50.len + 0);
appendString((&result), colontmpD__50);
									{
										LA359_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__50);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA329_;
								}
LA338_: ;
								i_3 += ((NI)1);
							} LA333: ;
						}
					}
					{
						LA329_:;
					}
					{
						oldNimErrFin329_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
						*nimErr_ = oldNimErrFin329_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
				}
				prepareAdd((&result), 2);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1333);
			}
LA322_: ;
			colontmpD__41 = getRecordDesc__cgen_u5412(m_p0, t_1, result, check_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
			(void)(colontmpD__41);
			T364_.len = 0; T364_.p = NIM_NIL;
			colontmpD__42 = dollar___modulegraphs_u10732(sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
			T364_ = rawNewString(colontmpD__42.len + 2);
appendString((&T364_), TM__MQdRN7fpbG7rPm4JpVVAhA_1365);
appendString((&T364_), colontmpD__42);
			typedefName_1 = T364_;
			T365_[0] = result;
			T365_[1] = typedefName_1;
			colontmpD__43 = percent___cgen_u8394(T365_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__43.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__43);
			colontmpD__44 = eqdup___system_u2697(typedefName_1);
			X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__44);
			if (NIM_UNLIKELY(*nimErr_)) goto LA282_;
			eqsink___system_u2700((&result), typedefName_1);
			eqwasMoved___system_u2688((&typedefName_1));
			{
				LA282_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__43);
				eqdestroy___system_u2691(colontmpD__42);
				eqdestroy___system_u2691(typedefName_1);
				eqdestroy___system_u2691(colontmpD__41);
				eqdestroy___system_u2691(cppNameAsRope_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		}
		goto LA276_;
LA280_: ;
		{
			NimStringV2 colontmpD__51;
			NimStringV2 T369_;
			T369_.len = 0; T369_.p = NIM_NIL;
			T369_ = cacheGetType__cgen_u1466((*m_p0).forwTypeCache, sig_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T369_); goto LA275_;}
			eqsink___system_u2700((&result), T369_);
			{
				NimStringV2 colontmpD__52;
				NimStringV2 T374_;
				if (!(result.len == 0)) goto LA372_;
				T374_.len = 0; T374_.p = NIM_NIL;
				T374_ = getTypeName__cgen_u1281(m_p0, origTyp_p1, sig_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T374_); goto LA275_;}
				eqsink___system_u2700((&result), T374_);
				colontmpD__52 = eqdup___system_u2697(result);
				X5BX5Deq___cgen_u1967((&(*m_p0).forwTypeCache), sig_1, colontmpD__52);
				if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
				{
					NIM_BOOL T377_;
					NimStringV2 colontmpD__53;
					T377_ = (NIM_BOOL)0;
					T377_ = isImportedType__cgen_u1373(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
					if (!!(T377_)) goto LA378_;
					colontmpD__53.len = 0; colontmpD__53.p = NIM_NIL;
					colontmpD__53 = structOrUnion__cgen_u545(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
					addForwardStructFormat__cgen_u3187(m_p0, colontmpD__53, result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
					eqdestroy___system_u2691(colontmpD__53);
				}
LA378_: ;
			}
LA372_: ;
			colontmpD__51 = eqdup___system_u2697(result);
			X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__51);
			if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
			{
				NIM_BOOL T382_;
				NimStringV2 recdesc_1;
				NimStringV2 T387_;
				T382_ = (NIM_BOOL)0;
				T382_ = !(((*t_1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
				if (!(T382_)) goto LA383_;
				T382_ = ((1040 & (*(*t_1).sym).flags) == 16);
LA383_: ;
				if (!!(T382_)) goto LA384_;
				recdesc_1.len = 0; recdesc_1.p = NIM_NIL;
				T387_.len = 0; T387_.p = NIM_NIL;
				{
					if (!!(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18)))) goto LA390_;
					recdesc_1 = getRecordDesc__cgen_u5412(m_p0, t_1, result, check_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA386_;
				}
				goto LA388_;
LA390_: ;
				{
					recdesc_1 = getTupleDesc__cgen_u5748(m_p0, t_1, result, check_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA386_;
				}
LA388_: ;
				{
					NIM_BOOL T395_;
					T395_ = (NIM_BOOL)0;
					T395_ = isImportedType__cgen_u1373(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA386_;
					if (!!(T395_)) goto LA396_;
					prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), recdesc_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), recdesc_1);
					addAbiCheck__cgen_u1860(m_p0, t_1, result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA386_;
				}
				goto LA393_;
LA396_: ;
				{
					if (!!((((*t_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)40)))&63U)))!=0))) goto LA399_;
				}
				goto LA393_;
LA399_: ;
LA393_: ;
				{
					LA386_:;
				}
				{
					eqdestroy___system_u2691(recdesc_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
			}
LA384_: ;
		}
LA276_: ;
		{
			LA275_:;
		}
		{
			oldNimErrFin275_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(tt_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			*nimErr_ = oldNimErrFin275_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__54;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__55;
		NimStringV2 colontmpD__56;
		NimStringV2 colontmpD__57;
		tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T407_;
		colontmpD__54 = NIM_NIL;
		colontmpD__55 = NIM_NIL;
		colontmpD__56.len = 0; colontmpD__56.p = NIM_NIL;
		eqsink___system_u2700((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1389);
		colontmpD__54 = elementType__ast_u5331(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
		typeName__cgen_u1266(colontmpD__54, (&result));
		if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
		colontmpD__55 = elementType__ast_u5331(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
		nimZeroMem((void*)T407_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
		hashType__sighashes_u411(colontmpD__55, (*(*m_p0).g).config, 2, T407_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
		colontmpD__56 = dollar___modulegraphs_u10732(T407_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
		prepareAdd((&result), colontmpD__56.len + 0);
appendString((&result), colontmpD__56);
		colontmpD__57 = eqdup___system_u2697(result);
		X5BX5Deq___cgen_u1967((&(*m_p0).typeCache), sig_1, colontmpD__57);
		if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
		{
			NIM_BOOL T410_;
			NI s_1;
			NI64 T413_;
			T410_ = (NIM_BOOL)0;
			T410_ = isImportedType__cgen_u1373(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
			if (!!(T410_)) goto LA411_;
			T413_ = (NI64)0;
			T413_ = getSize__types_u3397((*(*m_p0).g).config, t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
			s_1 = ((NI) (T413_));
			switch (s_1) {
			case ((NI)1):
			case ((NI)2):
			case ((NI)4):
			case ((NI)8):
			{
				NimStringV2 colontmpD__58;
				NimStringV2 colontmpD__59;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T415_;
				colontmpD__58.len = 0; colontmpD__58.p = NIM_NIL;
				colontmpD__59.len = 0; colontmpD__59.p = NIM_NIL;
				T415_[0] = result;
				colontmpD__58 = rope__ropes_u15(((NI64) ((NI)(s_1 * ((NI)8)))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
				T415_[1] = colontmpD__58;
				colontmpD__59 = percent___cgen_u8666(T415_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__59.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__59);
				eqdestroy___system_u2691(colontmpD__59);
				eqdestroy___system_u2691(colontmpD__58);
			}
			break;
			default:
			{
				NimStringV2 colontmpD__60;
				NimStringV2 colontmpD__61;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T418_;
				NI64 T419_;
				colontmpD__60.len = 0; colontmpD__60.p = NIM_NIL;
				colontmpD__61.len = 0; colontmpD__61.p = NIM_NIL;
				T418_[0] = result;
				T419_ = (NI64)0;
				T419_ = getSize__types_u3397((*(*m_p0).g).config, t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA417_;
				colontmpD__60 = rope__ropes_u15(T419_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA417_;
				T418_[1] = colontmpD__60;
				colontmpD__61 = percent___cgen_u8671(T418_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA417_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__61.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), colontmpD__61);
				{
					LA417_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__61);
					eqdestroy___system_u2691(colontmpD__60);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA406_;
			}
			break;
			}
		}
LA411_: ;
		{
			LA406_:;
		}
		{
			oldNimErrFin406_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__56);
			eqdestroy___ast_u3378(colontmpD__55);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			eqdestroy___ast_u3378(colontmpD__54);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			*nimErr_ = oldNimErrFin406_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)15):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)52):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)53):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)55):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__62;
		NimStringV2 T426_;
		colontmpD__62 = NIM_NIL;
		colontmpD__62 = skipModifier__ast_u5338(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA425_;
		T426_.len = 0; T426_.p = NIM_NIL;
		T426_ = getTypeDescAux__cgen_u1419(m_p0, colontmpD__62, check_p2, kind_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T426_); goto LA425_;}
		eqsink___system_u2700((&result), T426_);
		{
			LA425_:;
		}
		{
			oldNimErrFin425_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__62);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			*nimErr_ = oldNimErrFin425_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__63;
		NimStringV2 colontmpD__64;
		NimStringV2 T431_;
		colontmpD__63.len = 0; colontmpD__63.p = NIM_NIL;
		colontmpD__64.len = 0; colontmpD__64.p = NIM_NIL;
		T431_.len = 0; T431_.p = NIM_NIL;
		colontmpD__63 = dollar___ast_u182((*t_1).kind);
		T431_ = rawNewString(colontmpD__63.len + 16);
appendString((&T431_), TM__MQdRN7fpbG7rPm4JpVVAhA_1391);
appendString((&T431_), colontmpD__63);
appendChar((&T431_), 41);
		colontmpD__64 = T431_;
		internalErrorImpl__msgs_u1598((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, colontmpD__64, TM__MQdRN7fpbG7rPm4JpVVAhA_1392);
		if (NIM_UNLIKELY(*nimErr_)) goto LA430_;
		eqsink___system_u2700((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_1393);
		{
			LA430_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__64);
			eqdestroy___system_u2691(colontmpD__63);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
	}
	break;
	}
	xX60gensym551__1 = (*t_1).itemId;
	excl__suggestsymdb_u161(check_p2, (NI)((NI)((NU32)(((NI) (xX60gensym551__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym551__1.item))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
	{
		LA27_:;
	}
	{
		oldNimErrFin27_ = *nimErr_; *nimErr_ = NIM_FALSE;
		{
			NIM_BOOL T438_;
			NIM_BOOL T440_;
			T438_ = (NIM_BOOL)0;
			T438_ = isImportedType__cgen_u1373(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T438_)) goto LA439_;
			T440_ = (NIM_BOOL)0;
			T440_ = containsOrIncl__cgen_u6258((&(*m_p0).typeABICache), sig_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T438_ = !(T440_);
LA439_: ;
			if (!T438_) goto LA441_;
			addAbiCheck__cgen_u1860(m_p0, t_1, result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA441_: ;
		*nimErr_ = oldNimErrFin27_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getTypeDesc__cgen_u8738)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q kind_p2) {
	NimStringV2 result;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA check_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)(&check_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&check_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = getTypeDescAux__cgen_u1419(m_p0, typ_p1, (&check_1), kind_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pureZcollectionsZintsets_u230((&check_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, requiresExternC__cgen_u28642)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	NIM_BOOL T7_;
	NIM_BOOL T8_;
	NIM_BOOL T9_;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T10_;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
	if (!(T3_)) goto LA4_;
	colontmpD_ = getModule__astalgo_u156(sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = !((((*colontmpD_).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0));
LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = !(((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2)));
LA5_: ;
	T1_ = T2_;
	if (T1_) goto LA6_;
	T7_ = (NIM_BOOL)0;
	T8_ = (NIM_BOOL)0;
	T9_ = (NIM_BOOL)0;
	T10_ = 0;
	T9_ = (((*sym_p1).flags & IL64(4295229696)) == T10_);
	if (!(T9_)) goto LA11_;
	T12_ = 0;
	T9_ = !((((*sym_p1).flags & 192) == T12_));
LA11_: ;
	T8_ = T9_;
	if (!(T8_)) goto LA13_;
	T8_ = ((*sym_p1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0));
LA13_: ;
	T7_ = T8_;
	if (!(T7_)) goto LA14_;
	T7_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
LA14_: ;
	T1_ = T7_;
LA6_: ;
	result = T1_;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genProcPrototype__cgen_u523)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	useHeader__cgen_u123(m_p0, sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*sym_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0);
		if (T3_) goto LA4_;
		T5_ = 0;
		T3_ = !(((IL64(5629500071084032) & (*sym_p1).flags) == T5_));
LA4_: ;
		if (!T3_) goto LA6_;
		goto BeforeRet_;
	}
LA6_: ;
	{
		if (!(((*sym_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)3)))&15U)))!=0)) goto LA10_;
		{
			NIM_BOOL T14_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7438__1;
			NIM_BOOL T16_;
			NimStringV2 res_1;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 T20_;
			T14_ = (NIM_BOOL)0;
			T14_ = !(((*sym_p1).itemId.module == ((NI32) ((*(*m_p0).module).position))));
			if (!(T14_)) goto LA15_;
			xX60gensym7438__1 = (*sym_p1).itemId;
			T16_ = (NIM_BOOL)0;
			T16_ = containsOrIncl__astyaml_u223((&(*m_p0).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7438__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7438__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T14_ = !(T16_);
LA15_: ;
			if (!T14_) goto LA17_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3 = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			res_1 = rawNewString(((NI)80));
			T20_.len = 0; T20_.p = NIM_NIL;
			{
				NIM_BOOL T23_;
				T23_ = (NIM_BOOL)0;
				T23_ = isReloadable__cgen_u8812(m_p0, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				if (!T23_) goto LA24_;
				colontmpD_ = TM__MQdRN7fpbG7rPm4JpVVAhA_22;
				T20_ = colontmpD_;
			}
			goto LA21_;
LA24_: ;
			{
				colontmpD__2 = TM__MQdRN7fpbG7rPm4JpVVAhA_24;
				T20_ = colontmpD__2;
			}
LA21_: ;
			cgFormatValue__cgen_u163((&res_1), T20_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_26);
			colontmpD__3 = t__cgen_u97((*sym_p1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			colontmpD__4 = getTypeDesc__cgen_u8738(m_p0, colontmpD__3, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1394);
			colontmpD__5 = mangleDynLibProc__cgen_u5410(sym_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1395);
			{
				if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA29_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1396);
			}
LA29_: ;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), res_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), res_1);
			{
				NIM_BOOL T33_;
				NimStringV2 colontmpD__6;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2 colontmpD__9;
				NimStringV2 colontmpD__10;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T37_;
				T33_ = (NIM_BOOL)0;
				T33_ = isReloadable__cgen_u8812(m_p0, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
				if (!T33_) goto LA34_;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__7 = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				colontmpD__6 = mangleDynLibProc__cgen_u5410(sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				T37_[0] = colontmpD__6;
				colontmpD__7 = t__cgen_u97((*sym_p1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				colontmpD__8 = getTypeDesc__cgen_u8738(m_p0, colontmpD__7, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				T37_[1] = colontmpD__8;
				colontmpD__9 = getModuleDllPath__cgen_u158(m_p0, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				T37_[2] = colontmpD__9;
				colontmpD__10 = percent___cgen_u26278(T37_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__10.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__10);
				{
					LA36_:;
				}
				{
					oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__10);
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___ast_u3378(colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					eqdestroy___system_u2691(colontmpD__6);
					*nimErr_ = oldNimErrFin36_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
			}
LA34_: ;
			{
				LA19_:;
			}
			{
				oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___ast_u3378(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u2691(res_1);
				*nimErr_ = oldNimErrFin19_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA17_: ;
	}
	goto LA8_;
LA10_: ;
	{
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7449__1;
		NIM_BOOL T43_;
		NimStringV2 header_1;
		NimStringV2 res_2;
		NIM_BOOL asPtr_1;
		xX60gensym7449__1 = (*sym_p1).itemId;
		T43_ = (NIM_BOOL)0;
		T43_ = containsOrIncl__astyaml_u223((&(*m_p0).declaredProtos), (NI)((NI)((NU32)(((NI) (xX60gensym7449__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7449__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T43_)) goto LA44_;
		header_1.len = 0; header_1.p = NIM_NIL;
		res_2.len = 0; res_2.p = NIM_NIL;
		asPtr_1 = isReloadable__cgen_u8812(m_p0, sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		header_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		genProcHeader__cgen_u9040(m_p0, sym_p1, (&header_1), asPtr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		{
			if (!!(asPtr_1)) goto LA49_;
			{
				NIM_BOOL T53_;
				NimStringV2 T57_;
				T53_ = (NIM_BOOL)0;
				T53_ = isNoReturn__cgen_u28412(m_p0, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
				if (!(T53_)) goto LA54_;
				T53_ = ((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)6)))&15U)))!=0);
LA54_: ;
				if (!T53_) goto LA55_;
				T57_.len = 0; T57_.p = NIM_NIL;
				T57_ = rawNewString(header_1.len + 21);
appendString((&T57_), TM__MQdRN7fpbG7rPm4JpVVAhA_1397);
appendString((&T57_), header_1);
				eqsink___system_u2700((&header_1), T57_);
			}
LA55_: ;
			{
				NIM_BOOL T60_;
				NimStringV2 T64_;
				T60_ = (NIM_BOOL)0;
				T60_ = !(((*(*sym_p1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)5)));
				if (!(T60_)) goto LA61_;
				T60_ = requiresExternC__cgen_u28642(m_p0, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
LA61_: ;
				if (!T60_) goto LA62_;
				T64_.len = 0; T64_.p = NIM_NIL;
				T64_ = rawNewString(header_1.len + 11);
appendString((&T64_), TM__MQdRN7fpbG7rPm4JpVVAhA_1399);
appendString((&T64_), header_1);
				eqsink___system_u2700((&header_1), T64_);
			}
LA62_: ;
			{
				NIM_BOOL T67_;
				T67_ = (NIM_BOOL)0;
				T67_ = (((*sym_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0);
				if (!(T67_)) goto LA68_;
				T67_ = ((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)7)))&15U)))!=0);
LA68_: ;
				if (!T67_) goto LA69_;
				prepareAdd((&header_1), 23);
appendString((&header_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1401);
			}
LA69_: ;
			{
				NIM_BOOL T73_;
				T73_ = (NIM_BOOL)0;
				T73_ = isNoReturn__cgen_u28412(m_p0, sym_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
				if (!(T73_)) goto LA74_;
				T73_ = ((CC__extccomp_u624[((*(*(*m_p0).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)7)))&15U)))!=0);
LA74_: ;
				if (!T73_) goto LA75_;
				prepareAdd((&header_1), 26);
appendString((&header_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1403);
			}
LA75_: ;
		}
LA49_: ;
		res_2 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_2), header_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1404);
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), res_2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), res_2);
		{
			LA46_:;
		}
		{
			eqdestroy___system_u2691(res_2);
			eqdestroy___system_u2691(header_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA8_;
LA44_: ;
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, putLocIntoDest__cgen_u14088)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw s_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*d_p1).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0)))) goto LA3_;
		{
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T9_;
			if (!(((*d_p1).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)1)))&15U)))!=0)) goto LA7_;
			T9_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p1), s_p2, T9_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA5_;
LA7_: ;
		{
			genAssignment__cgen_u12898(p_p0, (*d_p1), s_p2, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA5_: ;
	}
	goto LA1_;
LA3_: ;
	{
		eqcopy___ast_u6287((&(*d_p1)), s_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isSimpleConst__cgen_u107)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	t_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379(typ_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24)));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t_1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA4_: ;
	T1_ = !(T3_);
LA2_: ;
	result = T1_;
	eqdestroy___ast_u3378(t_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, putIntoDest__cgen_u21142)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, NimStringV2 r_p3, tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg s_p4) {
NIM_BOOL oldNimErrFin5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T6_;
		if (!!(((*d_p1).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0)))) goto LA3_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		T6_ = 0;
		initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), n_p2, s_p4, T6_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		eqcopy___system_u2694((&a_1.snippet), r_p3);
		{
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T11_;
			if (!(((*d_p1).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)1)))&15U)))!=0)) goto LA9_;
			T11_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p1), a_1, T11_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		goto LA7_;
LA9_: ;
		{
			genAssignment__cgen_u12898(p_p0, (*d_p1), a_1, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA7_: ;
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		(*d_p1).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6);
		eqcopy___ast_u3255(&(*d_p1).lode, n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___system_u2694((&(*d_p1).snippet), r_p3);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, genConstSetup__cgen_u26767)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
	NIM_BOOL result;
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_1;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	m_1 = NIM_NIL;
	eqcopy___cgendata_u721(&m_1, (*p_p0).module, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	useHeader__cgen_u123(m_1, sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		if (!((*sym_p1).loc.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA4_;
		colontmpD_ = NIM_NIL;
		fillBackendName__cgen_u896((*p_p0).module, sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD_ = astdef__ast_u4596(sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		fillLoc__cgen_u88((&(*sym_p1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)8), colontmpD_, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = hcrOn__cgen_u49(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T11_) goto LA12_;
		(*sym_p1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
	}
LA12_: ;
	result = !((((*sym_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0));
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u718(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstHeader__cgen_u26784)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* q_p1, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p3) {
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin22_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*sym_p3).loc.snippet.len == 0)) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = genConstSetup__cgen_u26767(p_p2, sym_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T7_)) goto LA8_;
			goto BeforeRet_;
		}
LA8_: ;
	}
LA3_: ;
	{
		NIM_BOOL T12_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T16_;
		NimStringV2* T17_;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T18_;
		T12_ = (NIM_BOOL)0;
		T12_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T12_) goto LA13_;
		colontmpD_ = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD_ = t__cgen_u97((*sym_p3).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		colontmpD__2 = getTypeDesc__cgen_u8738(m_p0, colontmpD_, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T16_[0] = colontmpD__2;
		T16_[1] = (*sym_p3).loc.snippet;
		colontmpD__3 = percent___cgen_u26792(T16_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__3.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__3);
		T17_ = (NimStringV2*)0;
		T17_ = procSec__cgendata_u464((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T18_[0] = (*sym_p3).loc.snippet;
		colontmpD__4 = t__cgen_u97((*sym_p3).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		colontmpD__5 = getTypeDesc__cgen_u8738(m_p0, colontmpD__4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T18_[1] = colontmpD__5;
		colontmpD__6 = getModuleDllPath__cgen_u158(q_p1, sym_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T18_[2] = colontmpD__6;
		colontmpD__7 = percent___cgen_u26797(T18_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		prepareAdd((&(*T17_)), colontmpD__7.len + 0);
appendString((&(*T17_)), colontmpD__7);
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA10_;
LA13_: ;
	{
		NimStringV2 headerDecl_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
		NimStringV2 colontmpD__9;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T23_;
		headerDecl_1.len = 0; headerDecl_1.p = NIM_NIL;
		colontmpD__8 = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__8 = t__cgen_u97((*sym_p3).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		colontmpD__9 = getTypeDesc__cgen_u8738(m_p0, colontmpD__8, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_[0] = colontmpD__9;
		T23_[1] = (*sym_p3).loc.snippet;
		headerDecl_1 = percent___cgen_u26802(T23_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), headerDecl_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), headerDecl_1);
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = (((*sym_p3).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7)))&63U)))!=0);
			if (!(T26_)) goto LA27_;
			T26_ = !(((*(*(*p_p2).module).g).generatedHeader == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)));
LA27_: ;
			if (!T26_) goto LA28_;
			prepareAdd((&(*(*(*(*p_p2).module).g).generatedHeader).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), headerDecl_1.len + 0);
appendString((&(*(*(*(*p_p2).module).g).generatedHeader).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), headerDecl_1);
		}
LA28_: ;
		{
			LA22_:;
		}
		{
			oldNimErrFin22_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___ast_u3378(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(headerDecl_1);
			*nimErr_ = oldNimErrFin22_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA10_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstDefinition__cgen_u26816)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* q_p0, tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
	NimStringV2 actualConstName_1;
	NimStringV2 data_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 T2_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T10_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T11_;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	actualConstName_1.len = 0; actualConstName_1.p = NIM_NIL;
	data_1.len = 0; data_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		NIM_BOOL T5_;
		NimStringV2 T8_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_u49(q_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T5_) goto LA6_;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rawNewString((*sym_p2).loc.snippet.len + 6);
appendString((&T8_), (*sym_p2).loc.snippet);
appendString((&T8_), TM__MQdRN7fpbG7rPm4JpVVAhA_1412);
		actualConstName_1 = T8_;
	}
	goto LA3_;
LA6_: ;
	{
		eqcopy___system_u2694((&actualConstName_1), (*sym_p2).loc.snippet);
	}
LA3_: ;
	data_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getTypeDesc__cgen_u8738(q_p0, (*sym_p2).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[0] = colontmpD_;
	T10_[1] = actualConstName_1;
	colontmpD__2 = percent___cgen_u26822(T10_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&data_1), colontmpD__2.len + 0);
appendString((&data_1), colontmpD__2);
	colontmpD__3 = astdef__ast_u4596(sym_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genBracedInit__cgen_u16526((*q_p0).initProc, colontmpD__3, NIM_TRUE, (*sym_p2).typ, (&data_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = percent___cgen_u20257(T11_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&data_1), colontmpD__4.len + 0);
appendString((&data_1), colontmpD__4);
	prepareAdd((&(*q_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), data_1.len + 0);
appendString((&(*q_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), data_1);
	{
		NIM_BOOL T14_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 res_1;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T18_;
		NimStringV2* T19_;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T20_;
		NimStringV2* T21_;
		T14_ = (NIM_BOOL)0;
		T14_ = hcrOn__cgen_u49(q_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T14_) goto LA15_;
		colontmpD__5 = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__5 = t__cgen_u97((*sym_p2).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		colontmpD__6 = getTypeDesc__cgen_u8738(q_p0, colontmpD__5, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		T18_[0] = colontmpD__6;
		T18_[1] = (*sym_p2).loc.snippet;
		colontmpD__7 = percent___cgen_u26792(T18_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&(*q_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__7.len + 0);
appendString((&(*q_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__7);
		T19_ = (NimStringV2*)0;
		T19_ = procSec__cgendata_u464((*q_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		colontmpD__8 = getModuleDllPath__cgen_u158(q_p0, sym_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		T20_[0] = colontmpD__8;
		T20_[1] = (*sym_p2).loc.snippet;
		colontmpD__9 = rdLoc__cgen_u470((*sym_p2).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		T20_[2] = colontmpD__9;
		colontmpD__10 = percent___cgen_u26835(T20_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&(*T19_)), colontmpD__10.len + 0);
appendString((&(*T19_)), colontmpD__10);
		T21_ = (NimStringV2*)0;
		T21_ = procSec__cgendata_u464((*q_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1413);
		colontmpD__11 = cgsymValue__cgen_u141(q_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1414);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 8);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1415);
		cgFormatValue__cgen_u163((&res_1), (*sym_p2).loc.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 20);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1416);
		cgFormatValue__cgen_u163((&res_1), actualConstName_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1417);
		colontmpD__12 = rdLoc__cgen_u470((*sym_p2).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1418);
		{
			if (!!((((*(*(*q_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA24_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1419);
		}
LA24_: ;
		prepareAdd((&(*T21_)), res_1.len + 0);
appendString((&(*T21_)), res_1);
		{
			LA17_:;
		}
		{
			oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(res_1);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin17_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA15_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___ast_u3252(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(data_1);
		eqdestroy___system_u2691(actualConstName_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, requestConstImpl__cgen_u14078)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_1;
		tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* q_1;
		T3_ = (NIM_BOOL)0;
		T3_ = genConstSetup__cgen_u26767(p_p0, sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		m_1 = NIM_NIL;
		q_1 = NIM_NIL;
		eqcopy___cgendata_u721(&m_1, (*p_p0).module, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		q_1 = findPendingModule__cgen_u62(m_1, sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			NIM_BOOL T9_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7497__1;
			NIM_BOOL T11_;
			T9_ = (NIM_BOOL)0;
			T9_ = !((q_1 == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)));
			if (!(T9_)) goto LA10_;
			xX60gensym7497__1 = (*sym_p1).itemId;
			T11_ = (NIM_BOOL)0;
			T11_ = containsOrIncl__astyaml_u223((&(*q_1).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7497__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7497__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T9_ = !(T11_);
LA10_: ;
			if (!T9_) goto LA12_;
			genConstDefinition__cgen_u26816(q_1, p_p0, sym_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA12_: ;
		{
			NIM_BOOL T16_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7502__1;
			NIM_BOOL T18_;
			T16_ = (NIM_BOOL)0;
			T16_ = !((q_1 == m_1));
			if (!(T16_)) goto LA17_;
			xX60gensym7502__1 = (*sym_p1).itemId;
			T18_ = (NIM_BOOL)0;
			T18_ = containsOrIncl__astyaml_u223((&(*m_1).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7502__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7502__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T16_ = !(T18_);
LA17_: ;
			if (!T16_) goto LA19_;
			genConstHeader__cgen_u26784(m_1, q_1, p_p0, sym_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA19_: ;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___cgendata_u718(q_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___cgendata_u718(m_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genComplexConst__cgen_u26529)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	requestConstImpl__cgen_u14078(p_p0, sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_p1).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoVar__cgen_u16514)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*value_p1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) && (*value_p1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15)))) goto LA3_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*value_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_1421, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1422, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2* T6_;
		NimStringV2* T7_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T8_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_ = (NimStringV2*)0;
		T6_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		addIndent__cgen_u315(p_p0, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T7_ = (NimStringV2*)0;
		T7_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD_ = rope__ropes_u15((*value_p1)._kind_1.intVal);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T8_[0] = colontmpD_;
		colontmpD__2 = percent___cgen_u16521(T8_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*T7_)), colontmpD__2.len + 0);
appendString((&(*T7_)), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isAssignedImmediately__cgen_u15650)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1))) goto LA4_;
		result = NIM_FALSE;
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		NIM_BOOL T9_;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T9_ = (NIM_BOOL)0;
		T9_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
		if (!(T9_)) goto LA10_;
		T9_ = !(((*n_p1)._kind_6.sons.p->data[((NI)0)] == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA10_: ;
		T8_ = T9_;
		if (!(T8_)) goto LA11_;
		T8_ = !(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA11_: ;
		T7_ = T8_;
		if (!(T7_)) goto LA12_;
		colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA12_: ;
		if (!T7_) goto LA13_;
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T17_)) goto LA18_;
			T17_ = (((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29)))&63U)))!=0);
LA18_: ;
			if (!T17_) goto LA19_;
			result = NIM_TRUE;
		}
		goto LA15_;
LA19_: ;
		{
			NIM_BOOL T22_;
			T22_ = (NIM_BOOL)0;
			T22_ = isInvalidReturnType__cgen_u1424(conf_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T22_) goto LA23_;
			result = NIM_FALSE;
		}
		goto LA15_;
LA23_: ;
		{
			result = NIM_TRUE;
		}
LA15_: ;
	}
	goto LA2_;
LA13_: ;
	{
		NIM_BOOL T27_;
		T27_ = (NIM_BOOL)0;
		T27_ = isInvalidReturnType__cgen_u1424(conf_p0, (*n_p1).typField, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T27_) goto LA28_;
		result = NIM_FALSE;
	}
	goto LA2_;
LA28_: ;
	{
		result = NIM_TRUE;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hcrOn__cgen_u52)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = hcrOn__options_u629((*(*(*p_p0).module).g).config);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, potentialValueInit__cgen_u16532)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p2, NimStringV2* result_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = (((*v_p1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)3)))&15U)))!=0);
		if (T4_) goto LA5_;
		T4_ = (((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26)))&63U)))!=0);
LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA6_;
		T3_ = hcrOn__cgen_u52(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA6_: ;
		if (!T3_) goto LA7_;
	}
	goto LA1_;
LA7_: ;
	{
		NIM_BOOL T10_;
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		NIM_BOOL T13_;
		NIM_BOOL T16_;
		NIM_BOOL T20_;
		T10_ = (NIM_BOOL)0;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T13_ = (NIM_BOOL)0;
		T13_ = (((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3)))&63U)))!=0);
		if (!(T13_)) goto LA14_;
		T13_ = !((value_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA14_: ;
		T12_ = T13_;
		if (!(T12_)) goto LA15_;
		T16_ = (NIM_BOOL)0;
		T16_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T16_) goto LA17_;
		T16_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA17_: ;
		T12_ = isDeepConstExpr__trees_u153(value_p2, T16_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA15_: ;
		T11_ = T12_;
		if (!(T11_)) goto LA18_;
		T11_ = ((*p_p0).withinLoop == ((NI)0));
LA18_: ;
		T10_ = T11_;
		if (!(T10_)) goto LA19_;
		T20_ = (NIM_BOOL)0;
		T20_ = containsGarbageCollectedRef__types_u555((*v_p1).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T10_ = !(T20_);
LA19_: ;
		if (!T10_) goto LA21_;
		genBracedInit__cgen_u16526(p_p0, value_p2, NIM_FALSE, (*v_p1).typ, result_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA21_: ;
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGlobalVarDecl__cgen_u13871)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 td_p2, NimStringV2 value_p3, NimStringV2* decl_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1 = NIM_NIL;
	s_1 = (*n_p1)._kind_4.sym;
	{
		if (!!((((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)53)))&63U)))!=0))) goto LA3_;
		{
			NIM_BOOL T7_;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			tyArray__YgExxhfgKcesA5EOUj1MOA T11_;
			T7_ = (NIM_BOOL)0;
			T7_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21));
			if (!(T7_)) goto LA8_;
			T7_ = (((NI)0) < (*s_1)._kind_2.alignment);
LA8_: ;
			if (!T7_) goto LA9_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD_ = rope__ropes_u15(((NI64) ((*s_1)._kind_2.alignment)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T11_[0] = colontmpD_;
			colontmpD__2 = percent___cgen_u13670(T11_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*decl_p4)), colontmpD__2.len + 0);
appendString((&(*decl_p4)), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
LA9_: ;
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = hcrOn__cgen_u52(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA15_;
			prepareAdd((&(*decl_p4)), 7);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1426);
		}
		goto LA12_;
LA15_: ;
		{
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0)) goto LA18_;
			prepareAdd((&(*decl_p4)), 7);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1427);
		}
		goto LA12_;
LA18_: ;
		{
			if (!(((*s_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)4)))&15U)))!=0)) goto LA21_;
			prepareAdd((&(*decl_p4)), 17);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1428);
		}
		goto LA12_;
LA21_: ;
		{
			prepareAdd((&(*decl_p4)), 14);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1429);
		}
LA12_: ;
		{
			NIM_BOOL T26_;
			T26_ = (NIM_BOOL)0;
			T26_ = ((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9));
			if (!(T26_)) goto LA27_;
			T26_ = !((value_p3.len == 0));
LA27_: ;
			if (!T26_) goto LA28_;
			prepareAdd((&(*decl_p4)), 10);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1431);
		}
LA28_: ;
		prepareAdd((&(*decl_p4)), td_p2.len + 0);
appendString((&(*decl_p4)), td_p2);
		{
			NIM_BOOL T32_;
			T32_ = (NIM_BOOL)0;
			T32_ = hcrOn__cgen_u52(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T32_) goto LA33_;
			prepareAdd((&(*decl_p4)), 1);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1432);
		}
LA33_: ;
		{
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)10)))&63U)))!=0)) goto LA37_;
			prepareAdd((&(*decl_p4)), 9);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1433);
		}
LA37_: ;
		{
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)9)))&63U)))!=0)) goto LA41_;
			prepareAdd((&(*decl_p4)), 9);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1434);
		}
LA41_: ;
		{
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)47)))&63U)))!=0)) goto LA45_;
			prepareAdd((&(*decl_p4)), 12);
appendString((&(*decl_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1435);
		}
LA45_: ;
	}
	goto LA1_;
LA3_: ;
	{
		{
			NimStringV2 colontmpD__3;
			NimStringV2 T52_;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T53_;
			NimStringV2 T54_;
			if (!!((value_p3.len == 0))) goto LA50_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T52_.len = 0; T52_.p = NIM_NIL;
			T52_ = rawNewString((*(*s_1).constraint)._kind_3.strVal.len + 8);
appendString((&T52_), (*(*s_1).constraint)._kind_3.strVal);
appendString((&T52_), TM__MQdRN7fpbG7rPm4JpVVAhA_1437);
			colontmpD__3 = T52_;
			T53_[0] = td_p2;
			T53_[1] = (*s_1).loc.snippet;
			T53_[2] = value_p3;
			T54_.len = 0; T54_.p = NIM_NIL;
			T54_ = runtimeFormat__ropes_u39(colontmpD__3, T53_, 3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T54_); goto BeforeRet_;}
			eqsink___system_u2700((&(*decl_p4)), T54_);
			eqdestroy___system_u2691(colontmpD__3);
		}
		goto LA48_;
LA50_: ;
		{
			NimStringV2 colontmpD__4;
			NimStringV2 T56_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T57_;
			NimStringV2 T58_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T56_.len = 0; T56_.p = NIM_NIL;
			T56_ = rawNewString((*(*s_1).constraint)._kind_3.strVal.len + 3);
appendString((&T56_), (*(*s_1).constraint)._kind_3.strVal);
appendString((&T56_), TM__MQdRN7fpbG7rPm4JpVVAhA_1439);
			colontmpD__4 = T56_;
			T57_[0] = td_p2;
			T57_[1] = (*s_1).loc.snippet;
			T58_.len = 0; T58_.p = NIM_NIL;
			T58_ = runtimeFormat__ropes_u39(colontmpD__4, T57_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T58_); goto BeforeRet_;}
			eqsink___system_u2700((&(*decl_p4)), T58_);
			eqdestroy___system_u2691(colontmpD__4);
		}
LA48_: ;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCppVarForCtor__cgen_u13914)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_p1, NimStringV2* decl_p2, NIM_BOOL* didGenTemp_p3) {
	NimStringV2 params_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	params_1.len = 0; params_1.p = NIM_NIL;
	params_1 = genCppParamsForCtor__cgen_u4560(p_p0, call_p1, didGenTemp_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T6_;
		NimStringV2 T7_;
		if (!(params_1.len == ((NI)0))) goto LA4_;
		T6_[0] = (*decl_p2);
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = runtimeFormat__ropes_u39(TM__MQdRN7fpbG7rPm4JpVVAhA_1443, T6_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA1_;}
		eqsink___system_u2700((&(*decl_p2)), T7_);
	}
	goto LA2_;
LA4_: ;
	{
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
		NimStringV2 T10_;
		T9_[0] = (*decl_p2);
		T9_[1] = params_1;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = runtimeFormat__ropes_u39(TM__MQdRN7fpbG7rPm4JpVVAhA_1445, T9_, 2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA1_;}
		eqsink___system_u2700((&(*decl_p2)), T10_);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(params_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, callGlobalVarCppCtor__cgen_u14035)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* vn_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p3, NIM_BOOL* didGenTemp_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
	NimStringV2 decl_1;
	NimStringV2 td_1;
	NimStringV2 colontmpD_;
	NimStringV2 T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1 = NIM_NIL;
	decl_1.len = 0; decl_1.p = NIM_NIL;
	td_1.len = 0; td_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	eqcopy___ast_u4577(&s_1, (*vn_p2)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillBackendName__cgen_u896((*p_p0).module, s_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillLoc__cgen_u88((&(*s_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)3), vn_p2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	decl_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1425;
	td_1 = getTypeDesc__cgen_u8738((*p_p0).module, (*(*vn_p2)._kind_4.sym).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genGlobalVarDecl__cgen_u13871(p_p0, vn_p2, td_1, TM__MQdRN7fpbG7rPm4JpVVAhA_1440, (&decl_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = rawNewString((*s_1).loc.snippet.len + 1);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_1441);
appendString((&T2_), (*s_1).loc.snippet);
	colontmpD_ = T2_;
	prepareAdd((&decl_1), colontmpD_.len + 0);
appendString((&decl_1), colontmpD_);
	genCppVarForCtor__cgen_u13914(p_p0, value_p3, (&decl_1), didGenTemp_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(*didGenTemp_p4)) goto LA5_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(td_1);
		eqdestroy___system_u2691(decl_1);
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA5_: ;
	prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), decl_1.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), decl_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(td_1);
		eqdestroy___system_u2691(decl_1);
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, varInDynamicLib__cgen_u13848)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_1;
	NimStringV2 extname_1;
	NimStringV2 tmp_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	lib_1 = NIM_NIL;
	extname_1.len = 0; extname_1.p = NIM_NIL;
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	eqcopy___ast_u6219(&lib_1, (*sym_p1).annex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&extname_1), (*sym_p1).loc.snippet);
	loadDynamicLib__cgen_u27793(m_p0, lib_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*sym_p1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
	tmp_1 = mangleDynLibProc__cgen_u5410(sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&(*sym_p1).loc.snippet), tmp_1);
	(*m_p0).labels += ((NI)2);
	res_1 = rawNewString(((NI)80));
	cgFormatValue__cgen_u163((&res_1), tmp_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1447);
	colontmpD_ = getTypeDesc__cgen_u8738(m_p0, (*sym_p1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1449);
	colontmpD__2 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_1450);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1451);
	cgFormatValue__cgen_u163((&res_1), (*lib_1).name);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1452);
	colontmpD__3 = makeCString__msgs_u83(extname_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1453);
	{
		if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA4_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1454);
	}
LA4_: ;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), res_1);
	T6_[0] = (*sym_p1).loc.snippet;
	colontmpD__4 = t__cgen_u97((*sym_p1).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = getTypeDesc__cgen_u8738(m_p0, colontmpD__4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_[1] = colontmpD__5;
	colontmpD__6 = percent___cgen_u28023(T6_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__6.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__6);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___system_u2691(extname_1);
		eqdestroy___ast_u6216(lib_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, assignGlobalVar__cgen_u13919)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2 value_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin49_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1 = NIM_NIL;
	eqcopy___ast_u4577(&s_1, (*n_p1)._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*s_1).loc.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA4_;
		fillBackendName__cgen_u896((*p_p0).module, s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		fillLoc__cgen_u88((&(*s_1).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)3), n_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = treatGlobalDifferentlyForHCR__cgen_u13851((*p_p0).module, s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T8_) goto LA9_;
			(*s_1).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
		}
LA9_: ;
	}
LA4_: ;
	{
		tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* q_1;
		if (!(((*s_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)3)))&15U)))!=0)) goto LA13_;
		q_1 = NIM_NIL;
		q_1 = findPendingModule__cgen_u62((*p_p0).module, s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			NIM_BOOL T18_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1434__1;
			NIM_BOOL T20_;
			T18_ = (NIM_BOOL)0;
			T18_ = !((q_1 == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)));
			if (!(T18_)) goto LA19_;
			xX60gensym1434__1 = (*s_1).itemId;
			T20_ = (NIM_BOOL)0;
			T20_ = containsOrIncl__astyaml_u223((&(*q_1).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym1434__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym1434__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T18_ = !(T20_);
LA19_: ;
			if (!T18_) goto LA21_;
			varInDynamicLib__cgen_u13848(q_1, s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		}
		goto LA16_;
LA21_: ;
		{
			NimStringV2 T24_;
			T24_.len = 0; T24_.p = NIM_NIL;
			T24_ = mangleDynLibProc__cgen_u5410(s_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T24_); goto LA15_;}
			eqsink___system_u2700((&(*s_1).loc.snippet), T24_);
		}
LA16_: ;
		{
			if (!!((value_p2.len == 0))) goto LA27_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1456, TM__MQdRN7fpbG7rPm4JpVVAhA_1457);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		}
LA27_: ;
		eqdestroy___cgendata_u718(q_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___cgendata_u718(q_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	useHeader__cgen_u123((*p_p0).module, s_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*s_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0)) goto LA33_;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA33_: ;
	{
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym1441__1;
		NIM_BOOL T37_;
		xX60gensym1441__1 = (*s_1).itemId;
		T37_ = (NIM_BOOL)0;
		T37_ = containsOrIncl__astyaml_u223((&(*(*p_p0).module).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym1441__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym1441__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T37_)) goto LA38_;
		{
			if (!(((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26)))&63U)))!=0)) goto LA42_;
			declareThreadVar__cgen_u13751((*p_p0).module, s_1, (((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6)))&63U)))!=0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				if (!!((value_p2.len == 0))) goto LA46_;
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1459, TM__MQdRN7fpbG7rPm4JpVVAhA_1460);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA46_: ;
		}
		goto LA40_;
LA42_: ;
		{
			NimStringV2 decl_1;
			NimStringV2 td_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			decl_1.len = 0; decl_1.p = NIM_NIL;
			td_1.len = 0; td_1.p = NIM_NIL;
			colontmpD_ = NIM_NIL;
			decl_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1461;
			colontmpD_ = t__cgen_u97((*s_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			td_1 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD_, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			genGlobalVarDecl__cgen_u13871(p_p0, n_p1, td_1, value_p2, (&decl_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			{
				if (!((*s_1).constraint == 0)) goto LA52_;
				{
					if (!!((value_p2.len == 0))) goto LA56_;
					{
						NIM_BOOL T60_;
						NIM_BOOL T61_;
						NimStringV2 colontmpD__2;
						tyArray__YgExxhfgKcesA5EOUj1MOA T66_;
						T60_ = (NIM_BOOL)0;
						T61_ = (NIM_BOOL)0;
						T61_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
						if (T61_) goto LA62_;
						T61_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA62_: ;
						T60_ = T61_;
						if (!(T60_)) goto LA63_;
						T60_ = nsuStartsWith(value_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_1463);
						if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
LA63_: ;
						if (!T60_) goto LA64_;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						T66_[0] = (*s_1).loc.snippet;
						colontmpD__2 = percent___cgen_u13808(T66_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
						prepareAdd((&decl_1), colontmpD__2.len + 0);
appendString((&decl_1), colontmpD__2);
						eqdestroy___system_u2691(colontmpD__2);
					}
					goto LA58_;
LA64_: ;
					{
						NimStringV2 colontmpD__3;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T68_;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						T68_[0] = (*s_1).loc.snippet;
						T68_[1] = value_p2;
						colontmpD__3 = percent___cgen_u14026(T68_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
						prepareAdd((&decl_1), colontmpD__3.len + 0);
appendString((&decl_1), colontmpD__3);
						eqdestroy___system_u2691(colontmpD__3);
					}
LA58_: ;
				}
				goto LA54_;
LA56_: ;
				{
					NimStringV2 colontmpD__4;
					tyArray__YgExxhfgKcesA5EOUj1MOA T70_;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					T70_[0] = (*s_1).loc.snippet;
					colontmpD__4 = percent___cgen_u13808(T70_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
					prepareAdd((&decl_1), colontmpD__4.len + 0);
appendString((&decl_1), colontmpD__4);
					eqdestroy___system_u2691(colontmpD__4);
				}
LA54_: ;
			}
LA52_: ;
			prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), decl_1.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), decl_1);
			{
				LA49_:;
			}
			{
				oldNimErrFin49_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(td_1);
				eqdestroy___system_u2691(decl_1);
				*nimErr_ = oldNimErrFin49_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA40_: ;
	}
LA38_: ;
	{
		NIM_BOOL T75_;
		T75_ = (NIM_BOOL)0;
		T75_ = (((NI)0) < (*p_p0).withinLoop);
		if (!(T75_)) goto LA76_;
		T75_ = (value_p2.len == 0);
LA76_: ;
		if (!T75_) goto LA77_;
		resetLoc__cgen_u13360(p_p0, (&(*s_1).loc));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA77_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, accessThreadLocalVar__cgen_u449)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 colontmpD_;
		NimStringV2 res_1;
		NimStringV2 colontmpD__2;
		NimStringV2* T8_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T9_;
		NimStringV2* T10_;
		T3_ = (NIM_BOOL)0;
		T3_ = emulatedThreadVars__cgen_u452((*(*(*p_p0).module).g).config);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T3_)) goto LA4_;
		T3_ = !((((*p_p0).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)1)))&7U)))!=0));
LA4_: ;
		if (!T3_) goto LA5_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)1))) & 7);
		(*(*p_p0).module).flags |= ((NU8)1)<<(((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)1))) & 7);
		T8_ = (NimStringV2*)0;
		T8_ = procSec__cgendata_u464(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD_ = percent___cgen_u13733(T9_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&(*T8_)), colontmpD_.len + 0);
appendString((&(*T8_)), colontmpD_);
		T10_ = (NimStringV2*)0;
		T10_ = procSec__cgendata_u464(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 27);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1466);
		colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1468);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1469);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA13_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1470);
		}
LA13_: ;
		prepareAdd((&(*T10_)), res_1.len + 0);
appendString((&(*T10_)), res_1);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(res_1);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTraverseProcForGlobal__cgen_u9927)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 colontmpD__2;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_1;
	NimStringV2 sLoc_1;
	tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw c_1;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* colontmpD__3;
	NimStringV2 header_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
	NimStringV2 generatedProc_1;
	NimStringV2 colontmpD__5;
	tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
	tyArray__Seu7uK9aaOSN0BK3EAjjSHw T10_;
	NimStringV2* T11_;
	NimStringV2* T12_;
	NimStringV2* T13_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T14_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	p_1 = NIM_NIL;
	sLoc_1.len = 0; sLoc_1.p = NIM_NIL;
	nimZeroMem((void*)(&c_1), sizeof(tyObject_TTraversalClosure__QE9cf9alXKqg9cYNsaHXukFxw));
	header_1.len = 0; header_1.p = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	generatedProc_1.len = 0; generatedProc_1.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD_ = t__cgen_u97((*s_p1).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = genTypeInfoV1__cgen_u9076(m_p0, colontmpD_, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD__2);
	p_1 = newProc__cgendata_u509(((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	sLoc_1 = rdLoc__cgen_u470((*s_p1).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = getTempName__cgen_u462(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = (((*s_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26)))&63U)))!=0);
		if (!(T4_)) goto LA5_;
		T4_ = emulatedThreadVars__cgen_u452((*(*m_p0).g).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
		accessThreadLocalVar__cgen_u449(p_1, s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rawNewString(sLoc_1.len + 8);
appendString((&T8_), TM__MQdRN7fpbG7rPm4JpVVAhA_1472);
appendString((&T8_), sLoc_1);
		eqsink___system_u2700((&sLoc_1), T8_);
	}
LA6_: ;
	colontmpD__3 = eqdup___cgendata_u2078(p_1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	c_1.p = colontmpD__3;
	c_1.visitorFrmt = TM__MQdRN7fpbG7rPm4JpVVAhA_1473;
	T9_[0] = result;
	header_1 = percent___cgen_u9939(T9_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = t__cgen_u97((*s_p1).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genTraverseProc__cgen_u9539(c_1, sLoc_1, colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[0] = header_1;
	T11_ = (NimStringV2*)0;
	T11_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[1] = (*T11_);
	T12_ = (NimStringV2*)0;
	T12_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[2] = (*T12_);
	T13_ = (NimStringV2*)0;
	T13_ = s__cgendata_u228(p_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_[3] = (*T13_);
	generatedProc_1 = percent___cgen_u9945(T10_, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T14_[0] = header_1;
	colontmpD__5 = percent___cgen_u5386(T14_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD__5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD__5);
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), generatedProc_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), generatedProc_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(generatedProc_1);
		eqdestroy___ast_u3378(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(header_1);
		eqdestroy___cgen_u9893(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(sLoc_1);
		eqdestroy___cgendata_u2071(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerTraverseProc__cgen_u15592)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1) {
	NimStringV2 traverseProc_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	traverseProc_1.len = 0; traverseProc_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	traverseProc_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1464;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NimStringV2 T10_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)7) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)8) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)9));
		if (!(T5_)) goto LA6_;
		T5_ = !((((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)47)))&63U)))!=0));
LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		colontmpD_ = t__cgen_u97((*v_p1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = containsManagedMemory__types_u573(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA7_: ;
		if (!T4_) goto LA8_;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = genTraverseProcForGlobal__cgen_u9927((*p_p0).module, v_p1, (*v_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA1_;}
		eqsink___system_u2700((&traverseProc_1), T10_);
	}
LA8_: ;
	{
		NIM_BOOL T13_;
		NIM_BOOL T15_;
		T13_ = (NIM_BOOL)0;
		T13_ = !((traverseProc_1.len == ((NI)0)));
		if (!(T13_)) goto LA14_;
		T15_ = (NIM_BOOL)0;
		T15_ = hcrOn__cgen_u52(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T13_ = !(T15_);
LA14_: ;
		if (!T13_) goto LA16_;
		{
			NimStringV2 res_1;
			NimStringV2 colontmpD__2;
			NimStringV2* T23_;
			if (!(((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26)))&63U)))!=0)) goto LA20_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T23_ = (NimStringV2*)0;
			T23_ = procSec__cgendata_u464((*(*p_p0).module).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			res_1 = rawNewString(((NI)80));
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA26_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1474);
			}
LA26_: ;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1475);
			colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1477);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1478);
			cgFormatValue__cgen_u163((&res_1), traverseProc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1479);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA30_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1480);
			}
LA30_: ;
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA34_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1481);
			}
LA34_: ;
			prepareAdd((&(*T23_)), res_1.len + 0);
appendString((&(*T23_)), res_1);
			{
				LA22_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA18_;
LA20_: ;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__3;
			NimStringV2* T40_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T40_ = (NimStringV2*)0;
			T40_ = procSec__cgendata_u464((*(*p_p0).module).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			res_2 = rawNewString(((NI)80));
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA43_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1482);
			}
LA43_: ;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1483);
			colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1485);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1486);
			cgFormatValue__cgen_u163((&res_2), traverseProc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1487);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA47_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1488);
			}
LA47_: ;
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA51_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1489);
			}
LA51_: ;
			prepareAdd((&(*T40_)), res_2.len + 0);
appendString((&(*T40_)), res_2);
			{
				LA39_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA18_: ;
	}
LA16_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(traverseProc_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, endsWith__pureZstrutils_u1414)(NimStringV2 s_p0, NIM_CHAR suffix_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (((NI)0) < s_p0.len);
	if (!(T1_)) goto LA2_;
	T1_ = ((NU8)(s_p0.p->data[(s_p0.len-1)]) == (NU8)(suffix_p1));
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genPostprocessDir__cgen_u365)(NimStringV2 field1_p0, NimStringV2 field2_p1, NimStringV2 field3_p2) {
	NimStringV2 result;
	NimStringV2 T1_;
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = rawNewString(field1_p0.len + field2_p1.len + field3_p2.len + 4);
appendChar((&T1_), 1);
appendString((&T1_), field1_p0);
appendChar((&T1_), 31);
appendString((&T1_), field2_p1);
appendChar((&T1_), 31);
appendString((&T1_), field3_p2);
appendChar((&T1_), 23);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genLineDir__cgen_u418)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
	NI line_1;
	NI32 lastFileIndex_1;
	NIM_BOOL freshLine_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(p_p0 == (*(*p_p0).module).preInitProc)) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	line_1 = safeLineNm__cgen_u362((*t_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 code_1;
		NimStringV2 colontmpD_;
		NimStringV2* T14_;
		NimStringV2 T15_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)32)))&63U)))!=0)) goto LA7_;
		code_1.len = 0; code_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		code_1 = sourceLine__msgs_u1210((*(*(*p_p0).module).g).config, (*t_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = endsWith__pureZstrutils_u1414(code_1, 92);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T11_) goto LA12_;
			prepareAdd((&code_1), 1);
appendString((&code_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1490);
		}
LA12_: ;
		T14_ = (NimStringV2*)0;
		T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = rawNewString(code_1.len + 4);
appendString((&T15_), TM__MQdRN7fpbG7rPm4JpVVAhA_1492);
appendString((&T15_), code_1);
appendString((&T15_), TM__MQdRN7fpbG7rPm4JpVVAhA_1493);
		colontmpD_ = T15_;
		prepareAdd((&(*T14_)), colontmpD_.len + 0);
appendString((&(*T14_)), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(code_1);
	}
LA7_: ;
	lastFileIndex_1 = (*p_p0).lastLineInfo.fileIndex;
	freshLine_1 = freshLineInfo__cgen_u404(p_p0, (*t_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2* T20_;
		if (!freshLine_1) goto LA18_;
		T20_ = (NimStringV2*)0;
		T20_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genCLineDir__cgen_u382(T20_, (*t_p1).info.fileIndex, line_1, p_p0, (*t_p1).info, lastFileIndex_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA18_: ;
	{
		NIM_BOOL T23_;
		NIM_BOOL T24_;
		NIM_BOOL T26_;
		T23_ = (NIM_BOOL)0;
		T24_ = (NIM_BOOL)0;
		T24_ = ((655360 & (*p_p0).options) == 655360);
		if (!(T24_)) goto LA25_;
		T26_ = (NIM_BOOL)0;
		T26_ = ((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
		if (T26_) goto LA27_;
		T26_ = !((((*(*p_p0).prc).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0));
LA27_: ;
		T24_ = T26_;
LA25_: ;
		T23_ = T24_;
		if (!(T23_)) goto LA28_;
		T23_ = !(((*t_p1).info.fileIndex == ((NI32)-1)));
LA28_: ;
		if (!T23_) goto LA29_;
		{
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2* T35_;
			NimStringV2* T36_;
			if (!freshLine_1) goto LA33_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T35_ = (NimStringV2*)0;
			T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			addIndent__cgen_u315(p_p0, T35_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T36_ = (NimStringV2*)0;
			T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__2 = dollar___systemZdollars_u9(line_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__3 = dollar___systemZdollars_u24((*t_p1).info.fileIndex);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__4 = genPostprocessDir__cgen_u365(TM__MQdRN7fpbG7rPm4JpVVAhA_1495, colontmpD__2, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*T36_)), colontmpD__4.len + 0);
appendString((&(*T36_)), colontmpD__4);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
LA33_: ;
	}
LA29_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, notYetAlive__cgen_u15541)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* r_1;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	r_1 = NIM_NIL;
	r_1 = getRoot__trees_u373(n_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NIM_BOOL)0;
	T1_ = !((r_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*r_1).loc.lode == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA2_: ;
	result = T1_;
	eqdestroy___ast_u4574(r_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipAddr__trees_u429)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	{
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA4_;
		eqcopy___ast_u3255(&result, (*n_p0)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA4_: ;
	{
		eqcopy___ast_u3255(&result, n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInactiveDestructorCall__cgen_u15553)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1) {
	NIM_BOOL result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	NI T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T4_ = (NI)0;
	T4_ = len__ast_u3190(e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = (T4_ == ((NI)2));
	if (!(T3_)) goto LA5_;
	T3_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA5_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA6_;
	T2_ = eqStrings((*(*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s, TM__MQdRN7fpbG7rPm4JpVVAhA_1521);
LA6_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA7_;
	colontmpD_ = skipAddr__trees_u429((*e_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = notYetAlive__cgen_u15541(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA7_: ;
	result = T1_;
	eqdestroy___ast_u3252(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipTrivialIndirections__cgen_u14825)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3255(&result, n_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)67):
			{
				eqcopy___ast_u3255(&result, (*result)._kind_6.sons.p->data[((NI)0)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59):
			{
				eqcopy___ast_u3255(&result, (*result)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, potentialAlias__cgen_u14809)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q potentialWrites_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** p_1;
		NI i_1;
		NI L_1;
		NI T2_;
		p_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
		i_1 = ((NI)0);
		T2_ = potentialWrites_p1.len;
		L_1 = T2_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA4;
				p_1 = &potentialWrites_p1.p->data[i_1];
				{
					NIM_BOOL T7_;
					tyEnum_AliasKind__lRVSpyjZSQUjiqOwUaCudg T8_;
					tyEnum_AliasKind__lRVSpyjZSQUjiqOwUaCudg T10_;
					T7_ = (NIM_BOOL)0;
					T8_ = (tyEnum_AliasKind__lRVSpyjZSQUjiqOwUaCudg)0;
					T8_ = aliases__aliasanalysis_u67((*p_1), n_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T7_ = !((T8_ == ((tyEnum_AliasKind__lRVSpyjZSQUjiqOwUaCudg)1)));
					if (T7_) goto LA9_;
					T10_ = (tyEnum_AliasKind__lRVSpyjZSQUjiqOwUaCudg)0;
					T10_ = aliases__aliasanalysis_u67(n_p0, (*p_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T7_ = !((T10_ == ((tyEnum_AliasKind__lRVSpyjZSQUjiqOwUaCudg)1)));
LA9_: ;
					if (!T7_) goto LA11_;
					result = NIM_TRUE;
					goto BeforeRet_;
				}
LA11_: ;
				i_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, getPotentialReads__cgen_u14852)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q* result_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		colontmpD_ = eqdup___ast_u3258(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__ast_u3225((&(*result_p1)), colontmpD_);
	}
	break;
	default:
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_1;
			s_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(n_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA7;
						i_1 = i_2;
						eqcopy___ast_u3255(&s_1, (*n_p0)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						getPotentialReads__cgen_u14852(s_1, result_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						i_2 += ((NI)1);
					} LA7: ;
				}
			}
			eqdestroy___ast_u3252(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getPotentialWrites__cgen_u14828)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NIM_BOOL mutate_p1, tySequence__9ahcSjIErJohSBBFLwuF56Q* result_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*n_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
			if (!mutate_p1) goto LA5_;
			colontmpD_ = eqdup___ast_u3258(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			add__ast_u3225((&(*result_p2)), colontmpD_);
		}
LA5_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)74):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149):
	{
		getPotentialWrites__cgen_u14828((*n_p0)._kind_6.sons.p->data[((NI)0)], NIM_TRUE, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		getPotentialWrites__cgen_u14828((*n_p0)._kind_6.sons.p->data[((NI)1)], mutate_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64):
	{
		getPotentialWrites__cgen_u14828((*n_p0)._kind_6.sons.p->data[((NI)0)], NIM_TRUE, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46):
	{
		getPotentialWrites__cgen_u14828((*n_p0)._kind_6.sons.p->data[((NI)0)], mutate_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg T11_;
		T11_ = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
		T11_ = getMagic__trees_u122(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (T11_) {
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)40):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)41):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)29):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)30):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)129):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)130):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)131):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)16):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)32):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)33):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)150):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)152):
		{
			getPotentialWrites__cgen_u14828((*n_p0)._kind_6.sons.p->data[((NI)1)], NIM_TRUE, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190(n_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 = ((NI)2);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA15;
						i_1 = i_2;
						getPotentialWrites__cgen_u14828((*n_p0)._kind_6.sons.p->data[i_1], mutate_p1, result_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						i_2 += ((NI)1);
					} LA15: ;
				}
			}
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)141):
		{
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = len__ast_u3190(n_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_4 = ((NI)1);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA19;
						i_3 = i_4;
						getPotentialWrites__cgen_u14828((*n_p0)._kind_6.sons.p->data[i_3], NIM_TRUE, result_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						i_4 += ((NI)1);
					} LA19: ;
				}
			}
		}
		break;
		default:
		{
			{
				NI i_5;
				NI colontmp__3;
				NI i_6;
				i_5 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__3 = len__ast_u3190(n_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_6 = ((NI)1);
				{
					while (1) {
						if (!(i_6 < colontmp__3)) goto LA23;
						i_5 = i_6;
						getPotentialWrites__cgen_u14828((*n_p0)._kind_6.sons.p->data[i_5], mutate_p1, result_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						i_6 += ((NI)1);
					} LA23: ;
				}
			}
		}
		break;
		}
	}
	break;
	default:
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_1;
			s_1 = NIM_NIL;
			{
				NI i_7;
				NI colontmp__4;
				NI i_8;
				i_7 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__4 = safeLen__ast_u3197(n_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_8 = ((NI)0);
				{
					while (1) {
						if (!(i_8 < colontmp__4)) goto LA28;
						i_7 = i_8;
						eqcopy___ast_u3255(&s_1, (*n_p0)._kind_6.sons.p->data[i_7]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						getPotentialWrites__cgen_u14828(s_1, mutate_p1, result_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						i_8 += ((NI)1);
					} LA28: ;
				}
			}
			eqdestroy___ast_u3252(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, raiseInstr__cgen_u457)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2* result_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI L_1;
		NI T5_;
		if (!((*(*(*(*p_p0).module).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3))) goto LA3_;
		T5_ = (*p_p0).nestedTryStmts.len;
		L_1 = T5_;
		{
			NimStringV2 res_1;
			if (!(L_1 == ((NI)0))) goto LA8_;
			res_1.len = 0; res_1.p = NIM_NIL;
			(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)0))) & 7);
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 16);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1564);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA12_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1565);
			}
LA12_: ;
			prepareAdd((&(*result_p1)), res_1.len + 0);
appendString((&(*result_p1)), res_1);
			eqdestroy___system_u2691(res_1);
		}
		goto LA6_;
LA8_: ;
		{
			NimStringV2 res_2;
			res_2.len = 0; res_2.p = NIM_NIL;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 7);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1567);
			cgFormatValue__cgen_u166((&res_2), ((NI64) ((*p_p0).nestedTryStmts.p->data[(NI)(L_1 - ((NI)1))].Field2)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1569);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA17_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1570);
			}
LA17_: ;
			prepareAdd((&(*result_p1)), res_2.len + 0);
appendString((&(*result_p1)), res_2);
			eqdestroy___system_u2691(res_2);
		}
LA6_: ;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, intLiteral__cgen_u20135)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg i_p0, NimStringV2* result_p1) {
	NI64 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NI64)0;
	T1_ = toInt64__int128_u53(i_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	intLiteral__cgen_u14092(T1_, result_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rdCharLoc__cgen_u12869)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p0) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	result = rdLoc__cgen_u470(a_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T5_;
		NimStringV2 T6_;
		colontmpD_ = t__cgen_u97(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__2 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2))) goto LA3_;
		T5_[0] = result;
		T6_.len = 0; T6_.p = NIM_NIL;
		T6_ = percent___cgen_u12876(T5_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T6_); goto BeforeRet_;}
		eqsink___system_u2700((&result), T6_);
	}
LA3_: ;
	eqdestroy___ast_u3378(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genBoundsCheck__cgen_u14404)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw arr_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* arrTyp_p4) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ty_1 = NIM_NIL;
	eqcopy___ast_u3381(&ty_1, arrTyp_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*ty_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		NimStringV2 res_1;
		NimStringV2* T20_;
		NimStringV2* T21_;
		NimStringV2* T22_;
		res_1.len = 0; res_1.p = NIM_NIL;
		{
			NIM_BOOL T6_;
			NimStringV2 res_2;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2* T10_;
			NimStringV2* T11_;
			T6_ = (NIM_BOOL)0;
			T6_ = reifiedOpenArray__cgen_u14410(arr_p1.lode);
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			if (!T6_) goto LA7_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			T10_ = (NimStringV2*)0;
			T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			addIndent__cgen_u315(p_p0, T10_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			T11_ = (NimStringV2*)0;
			T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1524);
			colontmpD_ = rdLoc__cgen_u470(b_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1526);
			colontmpD__2 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 11);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1528);
			colontmpD__3 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1530);
			colontmpD__4 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1532);
			colontmpD__5 = rdLoc__cgen_u470(arr_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 11);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1534);
			colontmpD__6 = rdLoc__cgen_u470(b_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1535);
			colontmpD__7 = rdLoc__cgen_u470(b_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1536);
			colontmpD__8 = rdLoc__cgen_u470(arr_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 11);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1538);
			colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1540);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1541);
			colontmpD__10 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1542);
			colontmpD__11 = rdLoc__cgen_u470(b_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1543);
			colontmpD__12 = rdLoc__cgen_u470(arr_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1545);
			prepareAdd((&(*T11_)), res_2.len + 0);
appendString((&(*T11_)), res_2);
			{
				LA9_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		goto LA4_;
LA7_: ;
		{
			NimStringV2 res_3;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			NimStringV2 colontmpD__18;
			NimStringV2 colontmpD__19;
			NimStringV2 colontmpD__20;
			NimStringV2 colontmpD__21;
			NimStringV2 colontmpD__22;
			NimStringV2 colontmpD__23;
			NimStringV2 colontmpD__24;
			NimStringV2* T16_;
			NimStringV2* T17_;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
			colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
			colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
			colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
			colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
			colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
			T16_ = (NimStringV2*)0;
			T16_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			addIndent__cgen_u315(p_p0, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T17_ = (NimStringV2*)0;
			T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1546);
			colontmpD__13 = rdLoc__cgen_u470(b_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1547);
			colontmpD__14 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 11);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1548);
			colontmpD__15 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1549);
			colontmpD__16 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__16);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1550);
			colontmpD__17 = rdLoc__cgen_u470(arr_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__17);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1552);
			colontmpD__18 = rdLoc__cgen_u470(b_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__18);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1553);
			colontmpD__19 = rdLoc__cgen_u470(b_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__19);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1554);
			colontmpD__20 = rdLoc__cgen_u470(arr_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__20);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1556);
			colontmpD__21 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1557);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__21);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1558);
			colontmpD__22 = rdLoc__cgen_u470(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__22);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1559);
			colontmpD__23 = rdLoc__cgen_u470(b_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__23);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1560);
			colontmpD__24 = rdLoc__cgen_u470(arr_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__24);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1562);
			prepareAdd((&(*T17_)), res_3.len + 0);
appendString((&(*T17_)), res_3);
			{
				LA15_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__24);
				eqdestroy___system_u2691(colontmpD__23);
				eqdestroy___system_u2691(colontmpD__22);
				eqdestroy___system_u2691(colontmpD__21);
				eqdestroy___system_u2691(colontmpD__20);
				eqdestroy___system_u2691(colontmpD__19);
				eqdestroy___system_u2691(colontmpD__18);
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(res_3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
LA4_: ;
		T20_ = (NimStringV2*)0;
		T20_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		raiseInstr__cgen_u457(p_p0, T20_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		T21_ = (NimStringV2*)0;
		T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		addIndent__cgen_u315(p_p0, T21_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		T22_ = (NimStringV2*)0;
		T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1571);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA25_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1572);
		}
LA25_: ;
		prepareAdd((&(*T22_)), res_1.len + 0);
appendString((&(*T22_)), res_1);
		{
			LA3_:;
		}
		{
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		NimStringV2 first_1;
		NimStringV2 last_1;
		NimStringV2 res_4;
		NimStringV2 colontmpD__25;
		NimStringV2 colontmpD__26;
		NimStringV2 colontmpD__27;
		NimStringV2 colontmpD__28;
		NimStringV2 colontmpD__29;
		NimStringV2 colontmpD__30;
		NimStringV2 colontmpD__31;
		NimStringV2 colontmpD__32;
		NimStringV2 colontmpD__33;
		NimStringV2 res_5;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T31_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T32_;
		NimStringV2* T33_;
		NimStringV2* T34_;
		NimStringV2* T35_;
		NimStringV2* T36_;
		NimStringV2* T37_;
		first_1.len = 0; first_1.p = NIM_NIL;
		last_1.len = 0; last_1.p = NIM_NIL;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
		colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
		colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
		colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
		colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
		colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
		colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
		colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
		colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
		res_5.len = 0; res_5.p = NIM_NIL;
		first_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T31_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		intLiteral__cgen_u20135(T31_, (&first_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		last_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T32_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		intLiteral__cgen_u20135(T32_, (&last_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T33_ = (NimStringV2*)0;
		T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		addIndent__cgen_u315(p_p0, T33_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T34_ = (NimStringV2*)0;
		T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		res_4 = rawNewString(((NI)80));
		prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1573);
		colontmpD__25 = rdCharLoc__cgen_u12869(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__25);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1575);
		colontmpD__26 = rdCharLoc__cgen_u12869(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__26);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 11);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1576);
		colontmpD__27 = rdCharLoc__cgen_u12869(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__27);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1577);
		colontmpD__28 = rdCharLoc__cgen_u12869(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__28);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 9);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1579);
		colontmpD__29 = rdCharLoc__cgen_u12869(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__29);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1580);
		cgFormatValue__cgen_u163((&res_4), first_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1582);
		colontmpD__30 = rdCharLoc__cgen_u12869(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__30);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1584);
		cgFormatValue__cgen_u163((&res_4), last_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1585);
		colontmpD__31 = rdCharLoc__cgen_u12869(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__31);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1586);
		cgFormatValue__cgen_u163((&res_4), first_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1587);
		colontmpD__32 = rdCharLoc__cgen_u12869(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__32);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1588);
		cgFormatValue__cgen_u163((&res_4), last_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1590);
		colontmpD__33 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1592);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__33);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1594);
		prepareAdd((&(*T34_)), res_4.len + 0);
appendString((&(*T34_)), res_4);
		T35_ = (NimStringV2*)0;
		T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		raiseInstr__cgen_u457(p_p0, T35_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T36_ = (NimStringV2*)0;
		T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		addIndent__cgen_u315(p_p0, T36_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		T37_ = (NimStringV2*)0;
		T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		res_5 = rawNewString(((NI)80));
		prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1595);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA40_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1596);
		}
LA40_: ;
		prepareAdd((&(*T37_)), res_5.len + 0);
appendString((&(*T37_)), res_5);
		{
			LA30_:;
		}
		{
			eqdestroy___system_u2691(res_5);
			eqdestroy___system_u2691(colontmpD__33);
			eqdestroy___system_u2691(colontmpD__32);
			eqdestroy___system_u2691(colontmpD__31);
			eqdestroy___system_u2691(colontmpD__30);
			eqdestroy___system_u2691(colontmpD__29);
			eqdestroy___system_u2691(colontmpD__28);
			eqdestroy___system_u2691(colontmpD__27);
			eqdestroy___system_u2691(colontmpD__26);
			eqdestroy___system_u2691(colontmpD__25);
			eqdestroy___system_u2691(res_4);
			eqdestroy___system_u2691(last_1);
			eqdestroy___system_u2691(first_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		NimStringV2 res_6;
		NimStringV2 colontmpD__34;
		NimStringV2 colontmpD__35;
		NimStringV2 colontmpD__36;
		NimStringV2 colontmpD__37;
		NimStringV2 colontmpD__38;
		NimStringV2 colontmpD__39;
		NimStringV2 colontmpD__40;
		NimStringV2 colontmpD__41;
		NimStringV2 colontmpD__42;
		NimStringV2 colontmpD__43;
		NimStringV2 colontmpD__44;
		NimStringV2 colontmpD__45;
		NimStringV2 res_7;
		NimStringV2* T46_;
		NimStringV2* T47_;
		NimStringV2* T48_;
		NimStringV2* T49_;
		NimStringV2* T50_;
		res_6.len = 0; res_6.p = NIM_NIL;
		colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
		colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
		colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
		colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
		colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
		colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
		colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
		colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
		colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
		colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
		colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
		colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
		res_7.len = 0; res_7.p = NIM_NIL;
		T46_ = (NimStringV2*)0;
		T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		addIndent__cgen_u315(p_p0, T46_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T47_ = (NimStringV2*)0;
		T47_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		res_6 = rawNewString(((NI)80));
		prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1597);
		colontmpD__34 = rdLoc__cgen_u470(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__34);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1598);
		colontmpD__35 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 11);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1599);
		colontmpD__36 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__36);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 8);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1600);
		colontmpD__37 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__37);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1601);
		colontmpD__38 = lenExpr__cgen_u495(p_p0, arr_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__38);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1602);
		colontmpD__39 = rdLoc__cgen_u470(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__39);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 8);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1603);
		colontmpD__40 = rdLoc__cgen_u470(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__40);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1604);
		colontmpD__41 = lenExpr__cgen_u495(p_p0, arr_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__41);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1605);
		colontmpD__42 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1606);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__42);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1607);
		colontmpD__43 = rdLoc__cgen_u470(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__43);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1608);
		colontmpD__44 = rdLoc__cgen_u470(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__44);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1609);
		colontmpD__45 = lenExpr__cgen_u495(p_p0, arr_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__45);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 3);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1611);
		prepareAdd((&(*T47_)), res_6.len + 0);
appendString((&(*T47_)), res_6);
		T48_ = (NimStringV2*)0;
		T48_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		raiseInstr__cgen_u457(p_p0, T48_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T49_ = (NimStringV2*)0;
		T49_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		addIndent__cgen_u315(p_p0, T49_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T50_ = (NimStringV2*)0;
		T50_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		res_7 = rawNewString(((NI)80));
		prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1612);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA53_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1613);
		}
LA53_: ;
		prepareAdd((&(*T50_)), res_7.len + 0);
appendString((&(*T50_)), res_7);
		{
			LA45_:;
		}
		{
			eqdestroy___system_u2691(res_7);
			eqdestroy___system_u2691(colontmpD__45);
			eqdestroy___system_u2691(colontmpD__44);
			eqdestroy___system_u2691(colontmpD__43);
			eqdestroy___system_u2691(colontmpD__42);
			eqdestroy___system_u2691(colontmpD__41);
			eqdestroy___system_u2691(colontmpD__40);
			eqdestroy___system_u2691(colontmpD__39);
			eqdestroy___system_u2691(colontmpD__38);
			eqdestroy___system_u2691(colontmpD__37);
			eqdestroy___system_u2691(colontmpD__36);
			eqdestroy___system_u2691(colontmpD__35);
			eqdestroy___system_u2691(colontmpD__34);
			eqdestroy___system_u2691(res_6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyTuple__UV3llMMYFckfui8YMBuUZA, genOpenArraySlice__cgen_u14422)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* q_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formalType_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* destType_p3, NIM_BOOL prepareForMutation_p4) {
	tyTuple__UV3llMMYFckfui8YMBuUZA result;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw c_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 dest_1;
	NimStringV2 lengthExpr_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T4_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T22_;
NIM_BOOL oldNimErrFin44_;
NIM_BOOL oldNimErrFin77_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&c_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	ty_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	dest_1.len = 0; dest_1.p = NIM_NIL;
	lengthExpr_1.len = 0; lengthExpr_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*q_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*q_p1)._kind_6.sons.p->data[((NI)2)], T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*q_p1)._kind_6.sons.p->data[((NI)3)], T4_, (&c_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ty_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_436);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0)) goto LA7_;
		genBoundsCheck__cgen_u14404(p_p0, a_1, b_1, c_1, ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2* T14_;
		NimStringV2* T15_;
		if (!prepareForMutation_p4) goto LA11_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T14_ = (NimStringV2*)0;
		T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		addIndent__cgen_u315(p_p0, T14_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T15_ = (NimStringV2*)0;
		T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		res_1 = rawNewString(((NI)80));
		colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1614);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1615);
		colontmpD__5 = byRefLoc__cgen_u12841(p_p0, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1616);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA18_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1617);
		}
LA18_: ;
		prepareAdd((&(*T15_)), res_1.len + 0);
appendString((&(*T15_)), res_1);
		{
			LA13_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	dest_1 = getTypeDesc__cgen_u8738((*p_p0).module, destType_p3, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = rdLoc__cgen_u470(c_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T22_[0] = colontmpD__2;
	colontmpD__3 = rdLoc__cgen_u470(b_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T22_[1] = colontmpD__3;
	lengthExpr_1 = percent___cgen_u14455(T22_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*ty_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		NI64 first_1;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T24_;
		T24_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		first_1 = toInt64__int128_u53(T24_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NimStringV2 colontmp_;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmp__2;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T29_;
			NimStringV2 blitTmp_1;
			NimStringV2 blitTmp_2;
			if (!(first_1 == IL64(0))) goto LA27_;
			colontmp_.len = 0; colontmp_.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmp__2.len = 0; colontmp__2.p = NIM_NIL;
			colontmpD__6 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T29_[0] = colontmpD__6;
			colontmpD__7 = rdLoc__cgen_u470(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T29_[1] = colontmpD__7;
			T29_[2] = dest_1;
			colontmp_ = percent___cgen_u14462(T29_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmp__2 = lengthExpr_1;
			eqwasMoved___system_u2688((&lengthExpr_1));
			blitTmp_1 = colontmp_;
			result.Field0 = blitTmp_1;
			blitTmp_2 = colontmp__2;
			result.Field1 = blitTmp_2;
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
		}
		goto LA25_;
LA27_: ;
		{
			NimStringV2 lit_1;
			NimStringV2 colontmp__3;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmp__4;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T31_;
			NimStringV2 blitTmp_3;
			NimStringV2 blitTmp_4;
			lit_1.len = 0; lit_1.p = NIM_NIL;
			colontmp__3.len = 0; colontmp__3.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmp__4.len = 0; colontmp__4.p = NIM_NIL;
			lit_1 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			intLiteral__cgen_u14092(first_1, (&lit_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__8 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T31_[0] = colontmpD__8;
			colontmpD__9 = rdLoc__cgen_u470(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T31_[1] = colontmpD__9;
			T31_[2] = lit_1;
			T31_[3] = dest_1;
			colontmp__3 = percent___cgen_u14468(T31_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmp__4 = lengthExpr_1;
			eqwasMoved___system_u2688((&lengthExpr_1));
			blitTmp_3 = colontmp__3;
			result.Field0 = blitTmp_3;
			blitTmp_4 = colontmp__4;
			result.Field1 = blitTmp_4;
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(lit_1);
		}
LA25_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		{
			NIM_BOOL T35_;
			NimStringV2 colontmp__5;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmp__6;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T38_;
			NimStringV2 blitTmp_5;
			NimStringV2 blitTmp_6;
			T35_ = (NIM_BOOL)0;
			T35_ = reifiedOpenArray__cgen_u14410((*q_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T35_) goto LA36_;
			colontmp__5.len = 0; colontmp__5.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmp__6.len = 0; colontmp__6.p = NIM_NIL;
			colontmpD__10 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T38_[0] = colontmpD__10;
			colontmpD__11 = rdLoc__cgen_u470(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T38_[1] = colontmpD__11;
			T38_[2] = dest_1;
			colontmp__5 = percent___cgen_u14473(T38_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmp__6 = lengthExpr_1;
			eqwasMoved___system_u2688((&lengthExpr_1));
			blitTmp_5 = colontmp__5;
			result.Field0 = blitTmp_5;
			blitTmp_6 = colontmp__6;
			result.Field1 = blitTmp_6;
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
		}
		goto LA33_;
LA36_: ;
		{
			NimStringV2 colontmp__7;
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmp__8;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T40_;
			NimStringV2 blitTmp_7;
			NimStringV2 blitTmp_8;
			colontmp__7.len = 0; colontmp__7.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmp__8.len = 0; colontmp__8.p = NIM_NIL;
			colontmpD__12 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T40_[0] = colontmpD__12;
			colontmpD__13 = rdLoc__cgen_u470(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T40_[1] = colontmpD__13;
			T40_[2] = dest_1;
			colontmp__7 = percent___cgen_u14478(T40_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmp__8 = lengthExpr_1;
			eqwasMoved___system_u2688((&lengthExpr_1));
			blitTmp_7 = colontmp__7;
			result.Field0 = blitTmp_7;
			blitTmp_8 = colontmp__8;
			result.Field1 = blitTmp_8;
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
		}
LA33_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	{
		NimStringV2 colontmp__9;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmp__10;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T42_;
		NimStringV2 blitTmp_9;
		NimStringV2 blitTmp_10;
		colontmp__9.len = 0; colontmp__9.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmp__10.len = 0; colontmp__10.p = NIM_NIL;
		colontmpD__14 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T42_[0] = colontmpD__14;
		colontmpD__15 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T42_[1] = colontmpD__15;
		T42_[2] = dest_1;
		colontmp__9 = percent___cgen_u14478(T42_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp__10 = lengthExpr_1;
		eqwasMoved___system_u2688((&lengthExpr_1));
		blitTmp_9 = colontmp__9;
		result.Field0 = blitTmp_9;
		blitTmp_10 = colontmp__10;
		result.Field1 = blitTmp_10;
		eqdestroy___system_u2691(colontmpD__15);
		eqdestroy___system_u2691(colontmpD__14);
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* atyp_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__16;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__17;
		atyp_1 = NIM_NIL;
		colontmpD__16 = NIM_NIL;
		colontmpD__17 = NIM_NIL;
		colontmpD__16 = t__cgen_u97(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
		atyp_1 = skipTypes__ast_u5379(colontmpD__16, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
		{
			NIM_BOOL T47_;
			NIM_BOOL T48_;
			NimStringV2 res_2;
			NimStringV2 colontmpD__18;
			NimStringV2 colontmpD__19;
			NimStringV2* T54_;
			NimStringV2* T55_;
			T47_ = (NIM_BOOL)0;
			T48_ = (NIM_BOOL)0;
			colontmpD__17 = skipTypes__ast_u5379(formalType_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T48_ = ((*colontmpD__17).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
			if (!(T48_)) goto LA49_;
			T48_ = ((*atyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28));
LA49_: ;
			T47_ = T48_;
			if (!(T47_)) goto LA50_;
			T47_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
LA50_: ;
			if (!T47_) goto LA51_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
			T54_ = (NimStringV2*)0;
			T54_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			addIndent__cgen_u315(p_p0, T54_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			T55_ = (NimStringV2*)0;
			T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			res_2 = rawNewString(((NI)80));
			colontmpD__18 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1618);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__18);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1619);
			colontmpD__19 = byRefLoc__cgen_u12841(p_p0, a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__19);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1620);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA58_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1621);
			}
LA58_: ;
			prepareAdd((&(*T55_)), res_2.len + 0);
appendString((&(*T55_)), res_2);
			{
				LA53_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__19);
				eqdestroy___system_u2691(colontmpD__18);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
		}
LA51_: ;
		{
			NIM_BOOL T64_;
			NIM_BOOL T66_;
			NimStringV2 colontmp__11;
			NimStringV2 colontmpD__20;
			NimStringV2 colontmpD__21;
			NimStringV2 colontmpD__22;
			NimStringV2 colontmpD__23;
			NimStringV2 colontmpD__24;
			NimStringV2 colontmpD__25;
			NimStringV2 colontmp__12;
			tyArray__awn6UrBeChh9cVy9ccoluuYg T70_;
			NimStringV2 T71_;
			NimStringV2 blitTmp_11;
			NimStringV2 blitTmp_12;
			T64_ = (NIM_BOOL)0;
			T64_ = ((*atyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
			if (!(T64_)) goto LA65_;
			T66_ = (NIM_BOOL)0;
			T66_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T66_) goto LA67_;
			T66_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA67_: ;
			T64_ = !(T66_);
LA65_: ;
			if (!T64_) goto LA68_;
			colontmp__11.len = 0; colontmp__11.p = NIM_NIL;
			colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
			colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
			colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
			colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
			colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
			colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
			colontmp__12.len = 0; colontmp__12.p = NIM_NIL;
			colontmpD__20 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T70_[0] = colontmpD__20;
			colontmpD__21 = rdLoc__cgen_u470(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T70_[1] = colontmpD__21;
			colontmpD__22 = dataField__cgen_u516(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T70_[2] = colontmpD__22;
			T70_[3] = dest_1;
			T71_.len = 0; T71_.p = NIM_NIL;
			colontmpD__23 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T71_ = rawNewString(colontmpD__23.len + 1);
appendString((&T71_), TM__MQdRN7fpbG7rPm4JpVVAhA_1622);
appendString((&T71_), colontmpD__23);
			colontmpD__24 = T71_;
			colontmpD__25 = dataFieldAccessor__cgen_u508(p_p0, colontmpD__24);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T70_[4] = colontmpD__25;
			colontmp__11 = percent___cgen_u14525(T70_, 5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			colontmp__12 = lengthExpr_1;
			eqwasMoved___system_u2688((&lengthExpr_1));
			blitTmp_11 = colontmp__11;
			result.Field0 = blitTmp_11;
			blitTmp_12 = colontmp__12;
			result.Field1 = blitTmp_12;
			eqdestroy___system_u2691(colontmpD__25);
			eqdestroy___system_u2691(colontmpD__24);
			eqdestroy___system_u2691(colontmpD__23);
			eqdestroy___system_u2691(colontmpD__22);
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(colontmpD__20);
		}
		goto LA62_;
LA68_: ;
		{
			NimStringV2 colontmp__13;
			NimStringV2 colontmpD__26;
			NimStringV2 colontmpD__27;
			NimStringV2 colontmpD__28;
			NimStringV2 colontmpD__29;
			NimStringV2 colontmpD__30;
			NimStringV2 colontmp__14;
			tyArray__awn6UrBeChh9cVy9ccoluuYg T73_;
			NimStringV2 blitTmp_13;
			NimStringV2 blitTmp_14;
			colontmp__13.len = 0; colontmp__13.p = NIM_NIL;
			colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
			colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
			colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
			colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			colontmp__14.len = 0; colontmp__14.p = NIM_NIL;
			colontmpD__26 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T73_[0] = colontmpD__26;
			colontmpD__27 = rdLoc__cgen_u470(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T73_[1] = colontmpD__27;
			colontmpD__28 = dataField__cgen_u516(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T73_[2] = colontmpD__28;
			T73_[3] = dest_1;
			colontmpD__29 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			colontmpD__30 = dataFieldAccessor__cgen_u508(p_p0, colontmpD__29);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T73_[4] = colontmpD__30;
			colontmp__13 = percent___cgen_u14530(T73_, 5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			colontmp__14 = lengthExpr_1;
			eqwasMoved___system_u2688((&lengthExpr_1));
			blitTmp_13 = colontmp__13;
			result.Field0 = blitTmp_13;
			blitTmp_14 = colontmp__14;
			result.Field1 = blitTmp_14;
			eqdestroy___system_u2691(colontmpD__30);
			eqdestroy___system_u2691(colontmpD__29);
			eqdestroy___system_u2691(colontmpD__28);
			eqdestroy___system_u2691(colontmpD__27);
			eqdestroy___system_u2691(colontmpD__26);
		}
LA62_: ;
		{
			LA44_:;
		}
		{
			oldNimErrFin44_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__17);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__16);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(atyp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin44_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 colontmp__15;
		NimStringV2 colontmp__16;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__31;
		NimStringV2 colontmpD__32;
		NimStringV2 colontmpD__33;
		NimStringV2 blitTmp_15;
		NimStringV2 blitTmp_16;
		NimStringV2 T78_;
		colontmp__15.len = 0; colontmp__15.p = NIM_NIL;
		colontmp__16.len = 0; colontmp__16.p = NIM_NIL;
		colontmpD__31 = NIM_NIL;
		colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
		colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
		colontmp__15 = TM__MQdRN7fpbG7rPm4JpVVAhA_1623;
		colontmp__16 = TM__MQdRN7fpbG7rPm4JpVVAhA_1624;
		blitTmp_15 = colontmp__15;
		eqwasMoved___system_u2688((&colontmp__15));
		result.Field0 = blitTmp_15;
		blitTmp_16 = colontmp__16;
		eqwasMoved___system_u2688((&colontmp__16));
		result.Field1 = blitTmp_16;
		T78_.len = 0; T78_.p = NIM_NIL;
		colontmpD__31 = t__cgen_u97(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
		colontmpD__32 = typeToString__types_u54(colontmpD__31, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
		T78_ = rawNewString(colontmpD__32.len + 14);
appendString((&T78_), TM__MQdRN7fpbG7rPm4JpVVAhA_1626);
appendString((&T78_), colontmpD__32);
		colontmpD__33 = T78_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, colontmpD__33, TM__MQdRN7fpbG7rPm4JpVVAhA_1627);
		if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
		{
			LA77_:;
		}
		{
			oldNimErrFin77_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__33);
			eqdestroy___system_u2691(colontmpD__32);
			eqdestroy___ast_u3378(colontmpD__31);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmp__16);
			eqdestroy___system_u2691(colontmp__15);
			*nimErr_ = oldNimErrFin77_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(lengthExpr_1);
		eqdestroy___system_u2691(dest_1);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, openArrayLoc__cgen_u14535)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formalType_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, NimStringV2* result_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* q_1;
	NIM_BOOL skipped_1;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin57_;
NIM_BOOL oldNimErrFin91_;
NIM_BOOL oldNimErrFin103_;
NIM_BOOL oldNimErrFin109_;
NIM_BOOL oldNimErrFin97_;
NIM_BOOL oldNimErrFin116_;
NIM_BOOL oldNimErrFin33_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	q_1 = NIM_NIL;
	q_1 = skipConv__types_u3715(n_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	skipped_1 = NIM_FALSE;
	{
		while (1) {
			NIM_BOOL T4_;
			NI T6_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T7_;
			T4_ = (NIM_BOOL)0;
			T4_ = ((*q_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126));
			if (!(T4_)) goto LA5_;
			T6_ = (NI)0;
			T6_ = len__ast_u3190(q_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T4_ = (((NI)0) < T6_);
LA5_: ;
			if (!T4_) goto LA3;
			skipped_1 = NIM_TRUE;
			T7_ = NIM_NIL;
			T7_ = lastSon__ast_u5208(q_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T7_); goto LA1_;}
			eqsink___ast_u3261(&q_1, T7_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA3: ;
	}
	{
		tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg T10_;
		tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		NimStringV2 x_1;
		NimStringV2 y_1;
		NimStringV2 colontmpD__2;
		NimStringV2 T29_;
		T10_ = (tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0;
		T10_ = getMagic__trees_u122(q_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T10_ == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)124))) goto LA11_;
		nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
		colontmpD_ = NIM_NIL;
		x_1.len = 0; x_1.p = NIM_NIL;
		y_1.len = 0; y_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T18_;
			if (!skipped_1) goto LA16_;
			T18_ = NIM_NIL;
			T18_ = skipConv__types_u3715(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T18_); goto LA13_;}
			eqsink___ast_u3261(&q_1, T18_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			{
				while (1) {
					NIM_BOOL T21_;
					NI T23_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T28_;
					T21_ = (NIM_BOOL)0;
					T21_ = ((*q_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126));
					if (!(T21_)) goto LA22_;
					T23_ = (NI)0;
					T23_ = len__ast_u3190(q_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					T21_ = (((NI)0) < T23_);
LA22_: ;
					if (!T21_) goto LA20;
					{
						NI i_1;
						NI colontmp_;
						NI T25_;
						NI i_2;
						i_1 = (NI)0;
						colontmp_ = (NI)0;
						T25_ = (NI)0;
						T25_ = len__ast_u3190(q_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						colontmp_ = (NI)(T25_ - ((NI)1));
						i_2 = ((NI)0);
						{
							while (1) {
								if (!(i_2 < colontmp_)) goto LA27;
								i_1 = i_2;
								genStmts__cgen_u14081(p_p0, (*q_1)._kind_6.sons.p->data[i_1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								i_2 += ((NI)1);
							} LA27: ;
						}
					}
					T28_ = NIM_NIL;
					T28_ = lastSon__ast_u5208(q_1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T28_); goto LA13_;}
					eqsink___ast_u3261(&q_1, T28_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				} LA20: ;
			}
		}
LA16_: ;
		colontmpD_ = elementType__ast_u5331((*n_p2).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		tmpTuple_1 = genOpenArraySlice__cgen_u14422(p_p0, q_1, formalType_p1, colontmpD_, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		x_1 = tmpTuple_1.Field0;
		eqwasMoved___system_u2688((&tmpTuple_1.Field0));
		y_1 = tmpTuple_1.Field1;
		eqwasMoved___system_u2688((&tmpTuple_1.Field1));
		T29_.len = 0; T29_.p = NIM_NIL;
		T29_ = rawNewString(x_1.len + y_1.len + 2);
appendString((&T29_), x_1);
appendString((&T29_), TM__MQdRN7fpbG7rPm4JpVVAhA_1628);
appendString((&T29_), y_1);
		colontmpD__2 = T29_;
		prepareAdd((&(*result_p3)), colontmpD__2.len + 0);
appendString((&(*result_p3)), colontmpD__2);
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(y_1);
			eqdestroy___system_u2691(x_1);
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___stdZprivateZospaths2_u306(tmpTuple_1);
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA11_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T34_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T40_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__3 = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__6 = NIM_NIL;
		T34_ = NIM_NIL;
		{
			if (!((*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58))) goto LA37_;
			eqcopy___ast_u3255(&colontmpD__3, (*n_p2)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			T34_ = colontmpD__3;
		}
		goto LA35_;
LA37_: ;
		{
			eqcopy___ast_u3255(&colontmpD__4, n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			T34_ = colontmpD__4;
		}
LA35_: ;
		T40_ = 0;
		initLocExpr__cgen_u14111(p_p0, T34_, T40_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		colontmpD__5 = t__cgen_u97(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		colontmpD__6 = skipTypes__ast_u5379(colontmpD__5, TM__MQdRN7fpbG7rPm4JpVVAhA_1629);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		switch ((*colontmpD__6).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
		{
			{
				NIM_BOOL T44_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
				T44_ = (NIM_BOOL)0;
				T44_ = reifiedOpenArray__cgen_u14410(n_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				if (!T44_) goto LA45_;
				colontmpD__7 = NIM_NIL;
				{
					NimStringV2 colontmpD__8;
					NimStringV2 colontmpD__9;
					tyArray__YgExxhfgKcesA5EOUj1MOA T51_;
					colontmpD__7 = t__cgen_u97(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					if (!((*colontmpD__7).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD__7).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47))) goto LA49_;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					colontmpD__8 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					T51_[0] = colontmpD__8;
					colontmpD__9 = percent___cgen_u14575(T51_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					prepareAdd((&(*result_p3)), colontmpD__9.len + 0);
appendString((&(*result_p3)), colontmpD__9);
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
				}
				goto LA47_;
LA49_: ;
				{
					NimStringV2 colontmpD__10;
					NimStringV2 colontmpD__11;
					tyArray__YgExxhfgKcesA5EOUj1MOA T53_;
					colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
					colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
					colontmpD__10 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					T53_[0] = colontmpD__10;
					colontmpD__11 = percent___cgen_u14580(T53_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					prepareAdd((&(*result_p3)), colontmpD__11.len + 0);
appendString((&(*result_p3)), colontmpD__11);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(colontmpD__10);
				}
LA47_: ;
				eqdestroy___ast_u3378(colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			}
			goto LA42_;
LA45_: ;
			{
				NimStringV2 colontmpD__12;
				NimStringV2 colontmpD__13;
				tyArray__YgExxhfgKcesA5EOUj1MOA T55_;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				colontmpD__12 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T55_[0] = colontmpD__12;
				colontmpD__13 = percent___cgen_u14585(T55_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				prepareAdd((&(*result_p3)), colontmpD__13.len + 0);
appendString((&(*result_p3)), colontmpD__13);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
			}
LA42_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ntyp_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__14;
			ntyp_1 = NIM_NIL;
			colontmpD__14 = NIM_NIL;
			ntyp_1 = skipTypes__ast_u5379((*n_p2).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
			if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
			{
				NIM_BOOL T60_;
				NIM_BOOL T61_;
				NimStringV2 res_1;
				NimStringV2 colontmpD__15;
				NimStringV2 colontmpD__16;
				NimStringV2* T67_;
				NimStringV2* T68_;
				T60_ = (NIM_BOOL)0;
				T61_ = (NIM_BOOL)0;
				colontmpD__14 = skipTypes__ast_u5379(formalType_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T61_ = ((*colontmpD__14).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
				if (!(T61_)) goto LA62_;
				T61_ = ((*ntyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28));
LA62_: ;
				T60_ = T61_;
				if (!(T60_)) goto LA63_;
				T60_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
LA63_: ;
				if (!T60_) goto LA64_;
				res_1.len = 0; res_1.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
				T67_ = (NimStringV2*)0;
				T67_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				addIndent__cgen_u315(p_p0, T67_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				T68_ = (NimStringV2*)0;
				T68_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				res_1 = rawNewString(((NI)80));
				colontmpD__15 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1630);
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__15);
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1631);
				colontmpD__16 = byRefLoc__cgen_u12841(p_p0, a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1632);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA71_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1633);
				}
LA71_: ;
				prepareAdd((&(*T68_)), res_1.len + 0);
appendString((&(*T68_)), res_1);
				{
					LA66_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__16);
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(res_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
			}
LA64_: ;
			{
				NIM_BOOL T77_;
				NIM_BOOL T79_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw t_1;
				NimStringV2 colontmpD__17;
				NimStringV2 colontmpD__18;
				NimStringV2 colontmpD__19;
				NimStringV2 colontmpD__20;
				NimStringV2 colontmpD__21;
				NimStringV2 colontmpD__22;
				NimStringV2 colontmpD__23;
				NimStringV2 colontmpD__24;
				tyArray__YgExxhfgKcesA5EOUj1MOA T83_;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T84_;
				NimStringV2 T85_;
				T77_ = (NIM_BOOL)0;
				T77_ = ((*ntyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
				if (!(T77_)) goto LA78_;
				T79_ = (NIM_BOOL)0;
				T79_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T79_) goto LA80_;
				T79_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA80_: ;
				T77_ = !(T79_);
LA78_: ;
				if (!T77_) goto LA81_;
				nimZeroMem((void*)(&t_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
				colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				nimZeroMem((void*)(&t_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__17 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T83_[0] = colontmpD__17;
				t_1.snippet = percent___cgen_u12921(T83_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				colontmpD__18 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T84_[0] = colontmpD__18;
				colontmpD__19 = lenExpr__cgen_u495(p_p0, t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T84_[1] = colontmpD__19;
				colontmpD__20 = dataField__cgen_u516(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T84_[2] = colontmpD__20;
				T85_.len = 0; T85_.p = NIM_NIL;
				colontmpD__21 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T85_ = rawNewString(colontmpD__21.len + 1);
appendString((&T85_), TM__MQdRN7fpbG7rPm4JpVVAhA_1634);
appendString((&T85_), colontmpD__21);
				colontmpD__22 = T85_;
				colontmpD__23 = dataFieldAccessor__cgen_u508(p_p0, colontmpD__22);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T84_[3] = colontmpD__23;
				colontmpD__24 = percent___cgen_u14633(T84_, 4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&(*result_p3)), colontmpD__24.len + 0);
appendString((&(*result_p3)), colontmpD__24);
				eqdestroy___system_u2691(colontmpD__24);
				eqdestroy___system_u2691(colontmpD__23);
				eqdestroy___system_u2691(colontmpD__22);
				eqdestroy___system_u2691(colontmpD__21);
				eqdestroy___system_u2691(colontmpD__20);
				eqdestroy___system_u2691(colontmpD__19);
				eqdestroy___system_u2691(colontmpD__18);
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___ast_u6284(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
			}
			goto LA75_;
LA81_: ;
			{
				NimStringV2 colontmpD__25;
				NimStringV2 colontmpD__26;
				NimStringV2 colontmpD__27;
				NimStringV2 colontmpD__28;
				NimStringV2 colontmpD__29;
				NimStringV2 colontmpD__30;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T87_;
				colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
				colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
				colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
				colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
				colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
				colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
				colontmpD__25 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T87_[0] = colontmpD__25;
				colontmpD__26 = lenExpr__cgen_u495(p_p0, a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T87_[1] = colontmpD__26;
				colontmpD__27 = dataField__cgen_u516(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T87_[2] = colontmpD__27;
				colontmpD__28 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				colontmpD__29 = dataFieldAccessor__cgen_u508(p_p0, colontmpD__28);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T87_[3] = colontmpD__29;
				colontmpD__30 = percent___cgen_u14638(T87_, 4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&(*result_p3)), colontmpD__30.len + 0);
appendString((&(*result_p3)), colontmpD__30);
				eqdestroy___system_u2691(colontmpD__30);
				eqdestroy___system_u2691(colontmpD__29);
				eqdestroy___system_u2691(colontmpD__28);
				eqdestroy___system_u2691(colontmpD__27);
				eqdestroy___system_u2691(colontmpD__26);
				eqdestroy___system_u2691(colontmpD__25);
			}
LA75_: ;
			{
				LA57_:;
			}
			{
				oldNimErrFin57_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				eqdestroy___ast_u3378(ntyp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				*nimErr_ = oldNimErrFin57_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
		{
			NimStringV2 colontmpD__31;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__32;
			NimStringV2 colontmpD__33;
			NimStringV2 colontmpD__34;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T92_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T93_;
			colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
			colontmpD__32 = NIM_NIL;
			colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
			colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
			colontmpD__31 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
			T92_[0] = colontmpD__31;
			colontmpD__32 = t__cgen_u97(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
			T93_ = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, colontmpD__32);
			if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
			colontmpD__33 = rope__cgen_u9217(T93_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
			T92_[1] = colontmpD__33;
			colontmpD__34 = percent___cgen_u14643(T92_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
			prepareAdd((&(*result_p3)), colontmpD__34.len + 0);
appendString((&(*result_p3)), colontmpD__34);
			{
				LA91_:;
			}
			{
				oldNimErrFin91_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__34);
				eqdestroy___system_u2691(colontmpD__33);
				eqdestroy___ast_u3378(colontmpD__32);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				eqdestroy___system_u2691(colontmpD__31);
				*nimErr_ = oldNimErrFin91_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__35;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__36;
			colontmpD__35 = NIM_NIL;
			colontmpD__36 = NIM_NIL;
			colontmpD__35 = t__cgen_u97(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
			colontmpD__36 = elementType__ast_u5331(colontmpD__35);
			if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
			switch ((*colontmpD__36).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw t_2;
				NimStringV2 colontmpD__37;
				NimStringV2 colontmpD__38;
				NimStringV2 colontmpD__39;
				NimStringV2 colontmpD__40;
				NimStringV2 colontmpD__41;
				NimStringV2 colontmpD__42;
				NimStringV2 colontmpD__43;
				NimStringV2 colontmpD__44;
				tyArray__YgExxhfgKcesA5EOUj1MOA T99_;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T100_;
				NimStringV2 T101_;
				nimZeroMem((void*)(&t_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
				colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
				colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
				colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
				colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
				colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
				colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
				colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
				nimZeroMem((void*)(&t_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__37 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				T99_[0] = colontmpD__37;
				t_2.snippet = percent___cgen_u12921(T99_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				colontmpD__38 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				T100_[0] = colontmpD__38;
				colontmpD__39 = lenExpr__cgen_u495(p_p0, t_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				T100_[1] = colontmpD__39;
				colontmpD__40 = dataField__cgen_u516(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				T100_[2] = colontmpD__40;
				T101_.len = 0; T101_.p = NIM_NIL;
				colontmpD__41 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				T101_ = rawNewString(colontmpD__41.len + 1);
appendString((&T101_), TM__MQdRN7fpbG7rPm4JpVVAhA_1635);
appendString((&T101_), colontmpD__41);
				colontmpD__42 = T101_;
				colontmpD__43 = dataFieldAccessor__cgen_u508(p_p0, colontmpD__42);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				T100_[3] = colontmpD__43;
				colontmpD__44 = percent___cgen_u14633(T100_, 4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				prepareAdd((&(*result_p3)), colontmpD__44.len + 0);
appendString((&(*result_p3)), colontmpD__44);
				eqdestroy___system_u2691(colontmpD__44);
				eqdestroy___system_u2691(colontmpD__43);
				eqdestroy___system_u2691(colontmpD__42);
				eqdestroy___system_u2691(colontmpD__41);
				eqdestroy___system_u2691(colontmpD__40);
				eqdestroy___system_u2691(colontmpD__39);
				eqdestroy___system_u2691(colontmpD__38);
				eqdestroy___system_u2691(colontmpD__37);
				eqdestroy___ast_u6284(t_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
			{
				NimStringV2 colontmpD__45;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__46;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__47;
				NimStringV2 colontmpD__48;
				NimStringV2 colontmpD__49;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T104_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T105_;
				colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
				colontmpD__46 = NIM_NIL;
				colontmpD__47 = NIM_NIL;
				colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
				colontmpD__49.len = 0; colontmpD__49.p = NIM_NIL;
				colontmpD__45 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				T104_[0] = colontmpD__45;
				colontmpD__46 = t__cgen_u97(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				colontmpD__47 = elementType__ast_u5331(colontmpD__46);
				if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				T105_ = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, colontmpD__47);
				if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				colontmpD__48 = rope__cgen_u9217(T105_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				T104_[1] = colontmpD__48;
				colontmpD__49 = percent___cgen_u14643(T104_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				prepareAdd((&(*result_p3)), colontmpD__49.len + 0);
appendString((&(*result_p3)), colontmpD__49);
				{
					LA103_:;
				}
				{
					oldNimErrFin103_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__49);
					eqdestroy___system_u2691(colontmpD__48);
					eqdestroy___ast_u3378(colontmpD__47);
					if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
					eqdestroy___ast_u3378(colontmpD__46);
					if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
					eqdestroy___system_u2691(colontmpD__45);
					*nimErr_ = oldNimErrFin103_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
			}
			break;
			default:
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__50;
				NimStringV2 colontmpD__51;
				NimStringV2 colontmpD__52;
				NimStringV2 T110_;
				colontmpD__50 = NIM_NIL;
				colontmpD__51.len = 0; colontmpD__51.p = NIM_NIL;
				colontmpD__52.len = 0; colontmpD__52.p = NIM_NIL;
				T110_.len = 0; T110_.p = NIM_NIL;
				colontmpD__50 = t__cgen_u97(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				colontmpD__51 = typeToString__types_u54(colontmpD__50, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				T110_ = rawNewString(colontmpD__51.len + 14);
appendString((&T110_), TM__MQdRN7fpbG7rPm4JpVVAhA_1636);
appendString((&T110_), colontmpD__51);
				colontmpD__52 = T110_;
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, colontmpD__52, TM__MQdRN7fpbG7rPm4JpVVAhA_1637);
				if (NIM_UNLIKELY(*nimErr_)) goto LA109_;
				{
					LA109_:;
				}
				{
					oldNimErrFin109_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__52);
					eqdestroy___system_u2691(colontmpD__51);
					eqdestroy___ast_u3378(colontmpD__50);
					if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
					*nimErr_ = oldNimErrFin109_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
			}
			break;
			}
			{
				LA97_:;
			}
			{
				oldNimErrFin97_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__36);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				eqdestroy___ast_u3378(colontmpD__35);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				*nimErr_ = oldNimErrFin97_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
		break;
		default:
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__53;
			NimStringV2 colontmpD__54;
			NimStringV2 colontmpD__55;
			NimStringV2 T117_;
			colontmpD__53 = NIM_NIL;
			colontmpD__54.len = 0; colontmpD__54.p = NIM_NIL;
			colontmpD__55.len = 0; colontmpD__55.p = NIM_NIL;
			T117_.len = 0; T117_.p = NIM_NIL;
			colontmpD__53 = t__cgen_u97(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
			colontmpD__54 = typeToString__types_u54(colontmpD__53, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
			T117_ = rawNewString(colontmpD__54.len + 14);
appendString((&T117_), TM__MQdRN7fpbG7rPm4JpVVAhA_1638);
appendString((&T117_), colontmpD__54);
			colontmpD__55 = T117_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, colontmpD__55, TM__MQdRN7fpbG7rPm4JpVVAhA_1639);
			if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
			{
				LA116_:;
			}
			{
				oldNimErrFin116_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__55);
				eqdestroy___system_u2691(colontmpD__54);
				eqdestroy___ast_u3378(colontmpD__53);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				*nimErr_ = oldNimErrFin116_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
		break;
		}
		{
			LA33_:;
		}
		{
			oldNimErrFin33_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3252(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin33_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(q_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addAddrLoc__cgen_u12801)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, NimStringV2* result_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__2;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__3;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	colontmpD__3 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	{
		NIM_BOOL T4_;
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T6_;
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T12_;
		NimStringV2 colontmpD__4;
		NimStringV2 T15_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((a_p1.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0)))&15U)))!=0));
		if (!(T4_)) goto LA5_;
		colontmpD_ = t__cgen_u97(a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T6_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			if (!((*a_p1.lode).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA9_;
			colontmpD__2 = (*(*a_p1.lode)._kind_4.sym).kind;
			T6_ = colontmpD__2;
		}
		goto LA7_;
LA9_: ;
		{
			colontmpD__3 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
			T6_ = colontmpD__3;
		}
LA7_: ;
		T12_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		T12_ = mapType__cgen_u1315(conf_p0, colontmpD_, (T6_ == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !((T12_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17)));
LA5_: ;
		if (!T4_) goto LA13_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = rawNewString(a_p1.snippet.len + 3);
appendString((&T15_), TM__MQdRN7fpbG7rPm4JpVVAhA_1640);
appendString((&T15_), a_p1.snippet);
appendString((&T15_), TM__MQdRN7fpbG7rPm4JpVVAhA_1641);
		colontmpD__4 = T15_;
		prepareAdd((&(*result_p2)), colontmpD__4.len + 0);
appendString((&(*result_p2)), colontmpD__4);
		eqdestroy___system_u2691(colontmpD__4);
	}
	goto LA2_;
LA13_: ;
	{
		prepareAdd((&(*result_p2)), a_p1.snippet.len + 0);
appendString((&(*result_p2)), a_p1.snippet);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, expressionsNeedsTmp__cgen_u14674)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	getTemp__cgen_u9546(p_p0, (*a_p1.lode).typField, NIM_FALSE, Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = 0;
	genAssignment__cgen_u12898(p_p0, (*Result), a_p1, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArg__cgen_u14693)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_p3, NimStringV2* result_p4, NIM_BOOL needsTmp_p5) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin32_;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin83_;
NIM_BOOL oldNimErrFin78_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)71))) goto LA4_;
		genArgStringToCString__cgen_u14678(p_p0, n_p1, result_p4, needsTmp_p5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T10_;
		colontmpD_ = skipTypes__ast_u5379((*param_p2).typ, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48))) goto LA7_;
		n_2 = NIM_NIL;
		T10_ = NIM_NIL;
		{
			if (!!(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64)))) goto LA13_;
			eqcopy___ast_u3255(&n_2, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA11_;
LA13_: ;
		{
			eqcopy___ast_u3255(&n_2, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA11_: ;
		openArrayLoc__cgen_u14535(p_p0, (*param_p2).typ, n_2, result_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(n_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA7_: ;
	{
		NIM_BOOL T19_;
		NIM_BOOL T21_;
		NIM_BOOL T23_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T27_;
		T19_ = (NIM_BOOL)0;
		colontmpD__2 = returnType__ast_u5354((*(*call_p3)._kind_6.sons.p->data[((NI)0)]).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T19_ = ccgIntroducedPtr__ccgutils_u130((*(*(*p_p0).module).g).config, param_p2, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T19_)) goto LA20_;
		T21_ = (NIM_BOOL)0;
		T21_ = !((((*param_p2).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)20)))&31U)))!=0));
		if (T21_) goto LA22_;
		T23_ = (NIM_BOOL)0;
		T23_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T23_) goto LA24_;
		T23_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA24_: ;
		T21_ = !(T23_);
LA22_: ;
		T19_ = T21_;
LA20_: ;
		if (!T19_) goto LA25_;
		T27_ = 0;
		initLocExpr__cgen_u14111(p_p0, n_p1, T27_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__3;
			if (!((*n_p1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) && (*n_p1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA30_;
			nimZeroMem((void*)(&colontmpD__3), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			expressionsNeedsTmp__cgen_u14674(p_p0, a_1, (&colontmpD__3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			addAddrLoc__cgen_u12801((*(*(*p_p0).module).g).config, colontmpD__3, result_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			{
				LA32_:;
			}
			{
				oldNimErrFin32_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin32_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA28_;
LA30_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__4;
			nimZeroMem((void*)(&colontmpD__4), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			withTmpIfNeeded__cgen_u14661(p_p0, a_1, needsTmp_p5, (&colontmpD__4));
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			addAddrLoc__cgen_u12801((*(*(*p_p0).module).g).config, colontmpD__4, result_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			{
				LA36_:;
			}
			{
				oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin36_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA28_: ;
	}
	goto LA2_;
LA25_: ;
	{
		NIM_BOOL T40_;
		NIM_BOOL T41_;
		NIM_BOOL T42_;
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__5;
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__6;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* callee_1;
		NIM_BOOL needsIndirect_1;
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T48_;
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T54_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T60_;
		T40_ = (NIM_BOOL)0;
		T41_ = (NIM_BOOL)0;
		T42_ = (NIM_BOOL)0;
		T42_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T42_) goto LA43_;
		T42_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA43_: ;
		T41_ = T42_;
		if (!(T41_)) goto LA44_;
		T41_ = ((*(*param_p2).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
LA44_: ;
		T40_ = T41_;
		if (!(T40_)) goto LA45_;
		T40_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64));
LA45_: ;
		if (!T40_) goto LA46_;
		colontmpD__5 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		colontmpD__6 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		callee_1 = NIM_NIL;
		T48_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA51_;
			colontmpD__5 = (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).kind;
			T48_ = colontmpD__5;
		}
		goto LA49_;
LA51_: ;
		{
			colontmpD__6 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
			T48_ = colontmpD__6;
		}
LA49_: ;
		T54_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		T54_ = mapType__cgen_u1315((*(*(*p_p0).module).g).config, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, (T48_ == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		needsIndirect_1 = !((T54_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17)));
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T59_;
			if (!needsIndirect_1) goto LA57_;
			T59_ = NIM_NIL;
			T59_ = exactReplica__ast_u6243((*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T59_); goto LA1_;}
			eqsink___ast_u3387(&(*n_p1).typField, T59_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			(*(*n_p1).typField).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)20))) & 63);
		}
LA57_: ;
		initLocExprSingleUse__cgen_u14116(p_p0, n_p1, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		nimZeroMem((void*)(&T60_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		withTmpIfNeeded__cgen_u14661(p_p0, a_1, needsTmp_p5, (&T60_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&a_1), T60_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!needsIndirect_1) goto LA63_;
			a_1.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15);
		}
LA63_: ;
		callee_1 = (*call_p3)._kind_6.sons.p->data[((NI)0)];
		{
			NIM_BOOL T67_;
			NIM_BOOL T68_;
			NIM_BOOL T69_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T72_;
			T67_ = (NIM_BOOL)0;
			T68_ = (NIM_BOOL)0;
			T69_ = (NIM_BOOL)0;
			T69_ = ((*callee_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T69_)) goto LA70_;
			T69_ = ((IL64(4295229504) & (*(*callee_1)._kind_4.sym).flags) == 64);
LA70_: ;
			T68_ = T69_;
			if (!(T68_)) goto LA71_;
			T72_ = 0;
			T68_ = !(((36 & (*(*callee_1)._kind_4.sym).loc.flags) == T72_));
LA71_: ;
			T67_ = T68_;
			if (!(T67_)) goto LA73_;
			T67_ = needsIndirect_1;
LA73_: ;
			if (!T67_) goto LA74_;
			addAddrLoc__cgen_u12801((*(*(*p_p0).module).g).config, a_1, result_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA65_;
LA74_: ;
		{
			addRdLoc__cgen_u477(a_1, result_p4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA65_: ;
	}
	goto LA2_;
LA46_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__7;
		nimZeroMem((void*)(&colontmpD__7), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		initLocExprSingleUse__cgen_u14116(p_p0, n_p1, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
			if (!((*(*param_p2).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*(*param_p2).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*(*param_p2).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*(*param_p2).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46))) goto LA81_;
			typ_1 = NIM_NIL;
			colontmpD__8 = NIM_NIL;
			typ_1 = skipTypes__ast_u5379((*param_p2).typ, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			{
				NIM_BOOL T86_;
				NimStringV2 colontmpD__9;
				NimStringV2 colontmpD__10;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T90_;
				NimStringV2 T91_;
				colontmpD__8 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				T86_ = (NIM_BOOL)0;
				T86_ = sameBackendTypePickyAliases__types_u2757(typ_1, colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				if (!!(T86_)) goto LA87_;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				colontmpD__9 = getTypeDesc__cgen_u8738((*p_p0).module, (*param_p2).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				T90_[0] = colontmpD__9;
				colontmpD__10 = rdCharLoc__cgen_u12869(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				T90_[1] = colontmpD__10;
				T91_.len = 0; T91_.p = NIM_NIL;
				T91_ = percent___cgen_u14793(T90_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T91_); goto LA89_;}
				eqsink___system_u2700((&a_1.snippet), T91_);
				{
					LA89_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__10);
					eqdestroy___system_u2691(colontmpD__9);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			}
LA87_: ;
			{
				LA83_:;
			}
			{
				oldNimErrFin83_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
				eqdestroy___ast_u3378(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
				*nimErr_ = oldNimErrFin83_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		}
LA81_: ;
		withTmpIfNeeded__cgen_u14661(p_p0, a_1, needsTmp_p5, (&colontmpD__7));
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		addRdLoc__cgen_u477(colontmpD__7, result_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		{
			LA78_:;
		}
		{
			oldNimErrFin78_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6284(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin78_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genParams__cgen_u14860)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, NimStringV2* result_p3) {
	tySequence__shxop0zPIs5Ec3k71aCLuQ needTmp_1;
	tySequence__9ahcSjIErJohSBBFLwuF56Q potentialWrites_1;
	NI T2_;
	NI oldLen_1;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	needTmp_1.len = 0; needTmp_1.p = NIM_NIL;
	potentialWrites_1.len = 0; potentialWrites_1.p = NIM_NIL;
	T2_ = (NI)0;
	T2_ = len__ast_u3190(ri_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	needTmp_1 = newSeq__cgen_u14881(((NI)(T2_ - ((NI)1))));
	potentialWrites_1.len = 0; potentialWrites_1.p = (tySequence__9ahcSjIErJohSBBFLwuF56Q_Content*) newSeqPayload(0, sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(ri_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T4_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
				if (!(((NI)1) <= res_1)) goto LA6;
				colontmpD_ = NIM_NIL;
				i_1 = ((NI) (res_1));
				{
					NIM_BOOL T11_;
					colontmpD_ = skipTrivialIndirections__cgen_u14825((*ri_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!((*colontmpD_).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA9_;
					T11_ = (NIM_BOOL)0;
					T11_ = potentialAlias__cgen_u14809((*ri_p1)._kind_6.sons.p->data[i_1], potentialWrites_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					needTmp_1.p->data[(NI)(i_1 - ((NI)1))] = T11_;
				}
				goto LA7_;
LA9_: ;
				{
					tySequence__9ahcSjIErJohSBBFLwuF56Q potentialReads_1;
					potentialReads_1.len = 0; potentialReads_1.p = NIM_NIL;
					potentialReads_1.len = 0; potentialReads_1.p = (tySequence__9ahcSjIErJohSBBFLwuF56Q_Content*) newSeqPayload(0, sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
					getPotentialReads__cgen_u14852((*ri_p1)._kind_6.sons.p->data[i_1], (&potentialReads_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_1;
						NI i_2;
						NI L_1;
						NI T14_;
						n_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
						i_2 = ((NI)0);
						T14_ = potentialReads_1.len;
						L_1 = T14_;
						{
							while (1) {
								if (!(i_2 < L_1)) goto LA16;
								n_1 = &potentialReads_1.p->data[i_2];
								{
									NIM_BOOL T21_;
									if (!!(needTmp_1.p->data[(NI)(i_1 - ((NI)1))])) goto LA19_;
									T21_ = (NIM_BOOL)0;
									T21_ = potentialAlias__cgen_u14809((*n_1), potentialWrites_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									needTmp_1.p->data[(NI)(i_1 - ((NI)1))] = T21_;
								}
LA19_: ;
								i_2 += ((NI)1);
							} LA16: ;
						}
					}
					getPotentialWrites__cgen_u14828((*ri_p1)._kind_6.sons.p->data[i_1], NIM_FALSE, (&potentialWrites_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3696(potentialReads_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA7_: ;
				res_1 -= ((NI)1);
				eqdestroy___ast_u3252(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA6: ;
		}
	}
	oldLen_1 = (*result_p3).len;
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__ast_u3190(ri_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_4 = ((NI)1);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA24;
				i_3 = i_4;
				{
					NI T27_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* paramType_1;
					T27_ = (NI)0;
					T27_ = len__ast_u3190((*typ_p2).n);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!(i_3 < T27_)) goto LA28_;
					paramType_1 = NIM_NIL;
					eqcopy___ast_u3255(&paramType_1, (*(*typ_p2).n)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
					{
						NIM_BOOL T33_;
						T33_ = (NIM_BOOL)0;
						T33_ = isCompileTimeOnly__types_u3641((*paramType_1).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
						if (!!(T33_)) goto LA34_;
						{
							if (!!((oldLen_1 == (*result_p3).len))) goto LA38_;
							prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_1523);
							oldLen_1 = (*result_p3).len;
						}
LA38_: ;
						genArg__cgen_u14693(p_p0, (*ri_p1)._kind_6.sons.p->data[i_3], (*paramType_1)._kind_4.sym, ri_p1, result_p3, needTmp_1.p->data[(NI)(i_3 - ((NI)1))]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
					}
LA34_: ;
					{
						LA30_:;
					}
					{
						oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(paramType_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin30_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA25_;
LA28_: ;
				{
					{
						if (!!((oldLen_1 == (*result_p3).len))) goto LA45_;
						prepareAdd((&(*result_p3)), 2);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_1642);
						oldLen_1 = (*result_p3).len;
					}
LA45_: ;
					genArgNoParam__cgen_u14798(p_p0, (*ri_p1)._kind_6.sons.p->data[i_3], result_p3, needTmp_1.p->data[(NI)(i_3 - ((NI)1))]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA25_: ;
				i_4 += ((NI)1);
			} LA24: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3696(potentialWrites_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___cgen_u14965(needTmp_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, locationEscapes__cgen_u14186)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, NIM_BOOL inTryStmt_p2) {
	NIM_BOOL result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	n_1 = NIM_NIL;
	result = NIM_FALSE;
	eqcopy___ast_u3255(&n_1, le_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			switch ((*n_1).kind) {
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
				colontmpD_ = NIM_NIL;
				{
					colontmpD_ = owner__ast_u6254((*n_1)._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					if (!!((colontmpD_ == (*p_p0).prc))) goto LA8_;
					result = NIM_TRUE;
					eqdestroy___ast_u4574(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(n_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA6_;
LA8_: ;
				{
					NIM_BOOL T11_;
					T11_ = (NIM_BOOL)0;
					T11_ = inTryStmt_p2;
					if (!(T11_)) goto LA12_;
					T11_ = (((*(*n_1)._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)45)))&63U)))!=0);
LA12_: ;
					if (!T11_) goto LA13_;
					result = NIM_TRUE;
					eqdestroy___ast_u4574(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(n_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
				goto LA6_;
LA13_: ;
LA6_: ;
				result = NIM_FALSE;
				eqdestroy___ast_u4574(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3252(n_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
				{
					LA5_:;
				}
				{
					oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin5_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)67):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46):
			{
				eqcopy___ast_u3255(&n_1, (*n_1)._kind_6.sons.p->data[((NI)0)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59):
			case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)60):
			{
				eqcopy___ast_u3255(&n_1, (*n_1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			default:
			{
				result = NIM_TRUE;
				eqdestroy___ast_u3252(n_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
			break;
			}
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, preventNrvo__cgen_u14180)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p3) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin35_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		if (!!((le_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA3_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(ri_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)1);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* r_1;
					if (!(i_2 < colontmp_)) goto LA7;
					r_1 = NIM_NIL;
					i_1 = i_2;
					eqcopy___ast_u3255(&r_1, (*ri_p3)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					{
						tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ T11_;
						T11_ = (tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ)0;
						T11_ = isPartOf__aliases_u120(le_p2, r_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						if (!!((T11_ == ((tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ)0)))) goto LA12_;
						result = NIM_TRUE;
						eqdestroy___ast_u3252(r_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA12_: ;
					i_2 += ((NI)1);
					{
						LA8_:;
					}
					{
						oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(r_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin8_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA7: ;
			}
		}
		{
			NIM_BOOL T18_;
			NI T20_;
			NimStringV2 colontmpD_;
			T18_ = (NIM_BOOL)0;
			T18_ = canRaise__ast_u7516((*ri_p3)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T18_)) goto LA19_;
			T20_ = (*p_p0).nestedTryStmts.len;
			T18_ = locationEscapes__cgen_u14186(p_p0, le_p2, (((NI)0) < T20_));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA19_: ;
			if (!T18_) goto LA21_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD_ = dollar___renderer_u2166(le_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*le_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)63), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1644, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			{
				LA23_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA21_: ;
	}
LA3_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = !((dest_p1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
		if (!(T28_)) goto LA29_;
		T28_ = !((dest_p1 == le_p2));
LA29_: ;
		if (!T28_) goto LA30_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(ri_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_4 = ((NI)1);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* r_2;
					if (!(i_4 < colontmp__2)) goto LA34;
					r_2 = NIM_NIL;
					i_3 = i_4;
					eqcopy___ast_u3255(&r_2, (*ri_p3)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					{
						tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ T38_;
						T38_ = (tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ)0;
						T38_ = isPartOf__aliases_u120(dest_p1, r_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
						if (!!((T38_ == ((tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ)0)))) goto LA39_;
						result = NIM_TRUE;
						eqdestroy___ast_u3252(r_2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA39_: ;
					i_4 += ((NI)1);
					{
						LA35_:;
					}
					{
						oldNimErrFin35_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(r_2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin35_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				} LA34: ;
			}
		}
	}
LA30_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, hasNoInit__cgen_u14238)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*(*call_p0)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
	if (!(T1_)) goto LA2_;
	T1_ = (((*(*(*call_p0)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0);
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, addComma__cgen_u15100)(NimStringV2 r_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
	result.len = 0; result.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		if (!(r_p0.len == ((NI)0))) goto LA4_;
		eqcopy___system_u2694((&result), r_p0);
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 T7_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = rawNewString(r_p0.len + 2);
appendString((&T7_), r_p0);
appendString((&T7_), TM__MQdRN7fpbG7rPm4JpVVAhA_1645);
		result = T7_;
	}
LA2_: ;
	return result;
}
static N_INLINE(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*, X5BX5D___cgen_u17403)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* s_p0, NI s_p0Len_0, NI i_p1) {
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* result;
	result = (&s_p0[(NI)(s_p0Len_0 - i_p1)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, raiseExit__cgen_u14106)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!((((*p_p0).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)6)))&7U)))!=0))) goto LA3_;
		(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)4))) & 7);
		{
			NI T7_;
			NimStringV2 res_1;
			NimStringV2* T10_;
			NimStringV2* T11_;
			T7_ = (*p_p0).nestedTryStmts.len;
			if (!(T7_ == ((NI)0))) goto LA8_;
			res_1.len = 0; res_1.p = NIM_NIL;
			(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)0))) & 7);
			T10_ = (NimStringV2*)0;
			T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			addIndent__cgen_u315(p_p0, T10_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T11_ = (NimStringV2*)0;
			T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 44);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1647);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA14_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1648);
			}
LA14_: ;
			prepareAdd((&(*T11_)), res_1.len + 0);
appendString((&(*T11_)), res_1);
			eqdestroy___system_u2691(res_1);
		}
		goto LA5_;
LA8_: ;
		{
			NimStringV2 res_2;
			NimStringV2* T17_;
			NimStringV2* T18_;
			tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T19_;
			res_2.len = 0; res_2.p = NIM_NIL;
			T17_ = (NimStringV2*)0;
			T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			addIndent__cgen_u315(p_p0, T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T18_ = (NimStringV2*)0;
			T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 35);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1650);
			T19_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
			T19_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			cgFormatValue__cgen_u166((&res_2), ((NI64) ((*T19_).Field2)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1651);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA22_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1652);
			}
LA22_: ;
			prepareAdd((&(*T18_)), res_2.len + 0);
appendString((&(*T18_)), res_2);
			eqdestroy___system_u2691(res_2);
		}
LA5_: ;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isHarmlessStore__cgen_u14249)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NIM_BOOL canRaise_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_p2) {
	NIM_BOOL result;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (d_p2.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1) || d_p2.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
		if (T3_) goto LA4_;
		T3_ = !(canRaise_p1);
LA4_: ;
		if (!T3_) goto LA5_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (d_p2.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)2));
		if (!(T8_)) goto LA9_;
		T8_ = ((*p_p0).withinTryWithExcept == ((NI)0));
LA9_: ;
		if (!T8_) goto LA10_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA10_: ;
	{
		result = NIM_FALSE;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosureCall__cgen_u15095)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw op_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NimStringV2 pl_1;
	NimStringV2 rawProc_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	NIM_BOOL canRaise_1;
	NIM_BOOL T3_;
NIM_BOOL oldNimErrFin31_;
NIM_BOOL oldNimErrFin59_;
NIM_BOOL oldNimErrFin87_;
NIM_BOOL oldNimErrFin82_;
NIM_BOOL oldNimErrFin110_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&op_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	typ_1 = NIM_NIL;
	pl_1.len = 0; pl_1.p = NIM_NIL;
	rawProc_1.len = 0; rawProc_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*ri_p2)._kind_6.sons.p->data[((NI)0)], T2_, (&op_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	typ_1 = skipTypes__ast_u5379((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	pl_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genParams__cgen_u14860(p_p0, ri_p2, typ_1, (&pl_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rawProc_1 = getClosureType__cgen_u8751((*p_p0).module, typ_1, ((tyEnum_TClosureTypeKind__sY8uWROOfudsYU84nI5xdg)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*(*(*p_p0).module).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3));
	if (!(T3_)) goto LA4_;
	T3_ = canRaiseDisp__cgen_u14148(p_p0, (*ri_p2)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA4_: ;
	canRaise_1 = T3_;
	{
		colontmpD_ = returnType__ast_u5354(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA7_;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = isInvalidReturnType__cgen_u1424((*(*(*p_p0).module).g).config, typ_1, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T11_) goto LA12_;
			{
				NI T16_;
				T16_ = (NI)0;
				T16_ = len__ast_u3190(ri_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(((NI)1) < T16_)) goto LA17_;
				prepareAdd((&pl_1), 2);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1643);
			}
LA17_: ;
			{
				NIM_BOOL T21_;
				NIM_BOOL T23_;
				NimStringV2 colontmpD__2;
				T21_ = (NIM_BOOL)0;
				T21_ = ((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1) || (*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
				if (T21_) goto LA22_;
				T23_ = (NIM_BOOL)0;
				T23_ = preventNrvo__cgen_u14180(p_p0, (*d_p3).lode, le_p1, ri_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T21_ = !(T23_);
LA22_: ;
				if (!T21_) goto LA24_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T32_;
					if (!((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA29_;
					colontmpD__3 = NIM_NIL;
					colontmpD__3 = returnType__ast_u5354(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
					nimZeroMem((void*)(&T32_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					getTemp__cgen_u9546(p_p0, colontmpD__3, NIM_TRUE, (&T32_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
					eqsink___ast_u6293((&(*d_p3)), T32_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
					{
						LA31_:;
					}
					{
						oldNimErrFin31_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						*nimErr_ = oldNimErrFin31_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
				}
				goto LA27_;
LA29_: ;
				{
					NIM_BOOL T36_;
					NIM_BOOL T38_;
					T36_ = (NIM_BOOL)0;
					T36_ = !(((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1)));
					if (!(T36_)) goto LA37_;
					T38_ = (NIM_BOOL)0;
					T38_ = hasNoInit__cgen_u14238(ri_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T36_ = !(T38_);
LA37_: ;
					if (!T36_) goto LA39_;
				}
				goto LA27_;
LA39_: ;
LA27_: ;
				colontmpD__2 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*d_p3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
				prepareAdd((&pl_1), colontmpD__2.len + 0);
appendString((&pl_1), colontmpD__2);
				{
					NimStringV2 colontmpD__4;
					NimStringV2 colontmpD__5;
					NimStringV2 colontmpD__6;
					NimStringV2* T45_;
					NimStringV2* T46_;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T47_;
					if (!(((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)15)))&63U)))!=0)) goto LA43_;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					T45_ = (NimStringV2*)0;
					T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					addIndent__cgen_u315(p_p0, T45_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T46_ = (NimStringV2*)0;
					T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					colontmpD__4 = rdLoc__cgen_u470(op_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T47_[0] = colontmpD__4;
					T47_[1] = pl_1;
					colontmpD__5 = addComma__cgen_u15100(pl_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T47_[2] = colontmpD__5;
					T47_[3] = rawProc_1;
					colontmpD__6 = percent___cgen_u15142(T47_, 4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					prepareAdd((&(*T46_)), colontmpD__6.len + 0);
appendString((&(*T46_)), colontmpD__6);
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
				}
				goto LA41_;
LA43_: ;
				{
					NimStringV2 colontmpD__7;
					NimStringV2 colontmpD__8;
					NimStringV2 colontmpD__9;
					NimStringV2* T49_;
					NimStringV2* T50_;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T51_;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					T49_ = (NimStringV2*)0;
					T49_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					addIndent__cgen_u315(p_p0, T49_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T50_ = (NimStringV2*)0;
					T50_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					colontmpD__7 = rdLoc__cgen_u470(op_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T51_[0] = colontmpD__7;
					T51_[1] = pl_1;
					colontmpD__8 = addComma__cgen_u15100(pl_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T51_[2] = colontmpD__8;
					T51_[3] = rawProc_1;
					colontmpD__9 = percent___cgen_u15147(T51_, 4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					prepareAdd((&(*T50_)), colontmpD__9.len + 0);
appendString((&(*T50_)), colontmpD__9);
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
				}
LA41_: ;
				{
					if (!canRaise_1) goto LA54_;
					raiseExit__cgen_u14106(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
				}
LA54_: ;
				{
					LA26_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA19_;
LA24_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
				NimStringV2 colontmpD__11;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T75_;
				nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__10 = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__10 = returnType__ast_u5354(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
				getTemp__cgen_u9546(p_p0, colontmpD__10, NIM_TRUE, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
				colontmpD__11 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
				prepareAdd((&pl_1), colontmpD__11.len + 0);
appendString((&pl_1), colontmpD__11);
				{
					NimStringV2 colontmpD__12;
					NimStringV2 colontmpD__13;
					NimStringV2 colontmpD__14;
					NimStringV2* T64_;
					NimStringV2* T65_;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T66_;
					if (!(((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)15)))&63U)))!=0)) goto LA62_;
					colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
					colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
					colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
					T64_ = (NimStringV2*)0;
					T64_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					addIndent__cgen_u315(p_p0, T64_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T65_ = (NimStringV2*)0;
					T65_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					colontmpD__12 = rdLoc__cgen_u470(op_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T66_[0] = colontmpD__12;
					T66_[1] = pl_1;
					colontmpD__13 = addComma__cgen_u15100(pl_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T66_[2] = colontmpD__13;
					T66_[3] = rawProc_1;
					colontmpD__14 = percent___cgen_u15142(T66_, 4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					prepareAdd((&(*T65_)), colontmpD__14.len + 0);
appendString((&(*T65_)), colontmpD__14);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(colontmpD__13);
					eqdestroy___system_u2691(colontmpD__12);
				}
				goto LA60_;
LA62_: ;
				{
					NimStringV2 colontmpD__15;
					NimStringV2 colontmpD__16;
					NimStringV2 colontmpD__17;
					NimStringV2* T68_;
					NimStringV2* T69_;
					tyArray__Seu7uK9aaOSN0BK3EAjjSHw T70_;
					colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
					colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
					colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
					T68_ = (NimStringV2*)0;
					T68_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					addIndent__cgen_u315(p_p0, T68_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T69_ = (NimStringV2*)0;
					T69_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					colontmpD__15 = rdLoc__cgen_u470(op_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T70_[0] = colontmpD__15;
					T70_[1] = pl_1;
					colontmpD__16 = addComma__cgen_u15100(pl_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T70_[2] = colontmpD__16;
					T70_[3] = rawProc_1;
					colontmpD__17 = percent___cgen_u15147(T70_, 4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					prepareAdd((&(*T69_)), colontmpD__17.len + 0);
appendString((&(*T69_)), colontmpD__17);
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___system_u2691(colontmpD__16);
					eqdestroy___system_u2691(colontmpD__15);
				}
LA60_: ;
				{
					if (!canRaise_1) goto LA73_;
					raiseExit__cgen_u14106(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
				}
LA73_: ;
				T75_ = 0;
				genAssignment__cgen_u12898(p_p0, (*d_p3), tmp_1, T75_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
				{
					LA59_:;
				}
				{
					oldNimErrFin59_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___ast_u3378(colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin59_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA19_: ;
		}
		goto LA9_;
LA12_: ;
		{
			NIM_BOOL T79_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw list_1;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T91_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T92_;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T102_;
			T79_ = (NIM_BOOL)0;
			T79_ = isHarmlessStore__cgen_u14249(p_p0, canRaise_1, (*d_p3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T79_) goto LA80_;
			nimZeroMem((void*)(&list_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__18;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T88_;
				if (!((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA85_;
				colontmpD__18 = NIM_NIL;
				colontmpD__18 = returnType__ast_u5354(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
				nimZeroMem((void*)(&T88_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				getTemp__cgen_u9546(p_p0, colontmpD__18, NIM_FALSE, (&T88_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
				eqsink___ast_u6293((&(*d_p3)), T88_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
				{
					LA87_:;
				}
				{
					oldNimErrFin87_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__18);
					if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
					*nimErr_ = oldNimErrFin87_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
			}
LA85_: ;
			T91_ = 0;
			nimZeroMem((void*)(&T92_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), (*d_p3).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T91_, (&T92_));
			list_1 = T92_;
			if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
			{
				NimStringV2 colontmpD__19;
				NimStringV2 colontmpD__20;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T97_;
				NimStringV2 T98_;
				if (!(((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)15)))&63U)))!=0)) goto LA95_;
				colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__19 = rdLoc__cgen_u470(op_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
				T97_[0] = colontmpD__19;
				T97_[1] = pl_1;
				colontmpD__20 = addComma__cgen_u15100(pl_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
				T97_[2] = colontmpD__20;
				T97_[3] = rawProc_1;
				T98_.len = 0; T98_.p = NIM_NIL;
				T98_ = percent___cgen_u15181(T97_, 4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T98_); goto LA82_;}
				eqsink___system_u2700((&list_1.snippet), T98_);
				eqdestroy___system_u2691(colontmpD__20);
				eqdestroy___system_u2691(colontmpD__19);
			}
			goto LA93_;
LA95_: ;
			{
				NimStringV2 colontmpD__21;
				NimStringV2 colontmpD__22;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T100_;
				NimStringV2 T101_;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
				colontmpD__21 = rdLoc__cgen_u470(op_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
				T100_[0] = colontmpD__21;
				T100_[1] = pl_1;
				colontmpD__22 = addComma__cgen_u15100(pl_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
				T100_[2] = colontmpD__22;
				T100_[3] = rawProc_1;
				T101_.len = 0; T101_.p = NIM_NIL;
				T101_ = percent___cgen_u15186(T100_, 4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T101_); goto LA82_;}
				eqsink___system_u2700((&list_1.snippet), T101_);
				eqdestroy___system_u2691(colontmpD__22);
				eqdestroy___system_u2691(colontmpD__21);
			}
LA93_: ;
			T102_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p3), list_1, T102_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
			{
				if (!canRaise_1) goto LA105_;
				raiseExit__cgen_u14106(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
			}
LA105_: ;
			{
				LA82_:;
			}
			{
				oldNimErrFin82_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(list_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin82_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA9_;
LA80_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_2;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__23;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw list_2;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T111_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T112_;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T122_;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T127_;
			nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__23 = NIM_NIL;
			nimZeroMem((void*)(&list_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__23 = returnType__ast_u5354(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
			getTemp__cgen_u9546(p_p0, colontmpD__23, NIM_FALSE, (&tmp_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
			T111_ = 0;
			nimZeroMem((void*)(&T112_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), (*d_p3).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T111_, (&T112_));
			list_2 = T112_;
			if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
			{
				NimStringV2 colontmpD__24;
				NimStringV2 colontmpD__25;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T117_;
				NimStringV2 T118_;
				if (!(((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)15)))&63U)))!=0)) goto LA115_;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
				colontmpD__24 = rdLoc__cgen_u470(op_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
				T117_[0] = colontmpD__24;
				T117_[1] = pl_1;
				colontmpD__25 = addComma__cgen_u15100(pl_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
				T117_[2] = colontmpD__25;
				T117_[3] = rawProc_1;
				T118_.len = 0; T118_.p = NIM_NIL;
				T118_ = percent___cgen_u15181(T117_, 4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T118_); goto LA110_;}
				eqsink___system_u2700((&list_2.snippet), T118_);
				eqdestroy___system_u2691(colontmpD__25);
				eqdestroy___system_u2691(colontmpD__24);
			}
			goto LA113_;
LA115_: ;
			{
				NimStringV2 colontmpD__26;
				NimStringV2 colontmpD__27;
				tyArray__Seu7uK9aaOSN0BK3EAjjSHw T120_;
				NimStringV2 T121_;
				colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
				colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
				colontmpD__26 = rdLoc__cgen_u470(op_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
				T120_[0] = colontmpD__26;
				T120_[1] = pl_1;
				colontmpD__27 = addComma__cgen_u15100(pl_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
				T120_[2] = colontmpD__27;
				T120_[3] = rawProc_1;
				T121_.len = 0; T121_.p = NIM_NIL;
				T121_ = percent___cgen_u15186(T120_, 4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T121_); goto LA110_;}
				eqsink___system_u2700((&list_2.snippet), T121_);
				eqdestroy___system_u2691(colontmpD__27);
				eqdestroy___system_u2691(colontmpD__26);
			}
LA113_: ;
			T122_ = 0;
			genAssignment__cgen_u12898(p_p0, tmp_2, list_2, T122_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
			{
				if (!canRaise_1) goto LA125_;
				raiseExit__cgen_u14106(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
			}
LA125_: ;
			T127_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p3), tmp_2, T127_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
			{
				LA110_:;
			}
			{
				oldNimErrFin110_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(list_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3378(colontmpD__23);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(tmp_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin110_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA9_: ;
	}
	goto LA5_;
LA7_: ;
	{
		{
			NimStringV2 colontmpD__28;
			NimStringV2 colontmpD__29;
			NimStringV2 colontmpD__30;
			NimStringV2* T135_;
			NimStringV2* T136_;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T137_;
			if (!(((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)15)))&63U)))!=0)) goto LA133_;
			colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
			colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			T135_ = (NimStringV2*)0;
			T135_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T135_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T136_ = (NimStringV2*)0;
			T136_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__28 = rdLoc__cgen_u470(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T137_[0] = colontmpD__28;
			T137_[1] = pl_1;
			colontmpD__29 = addComma__cgen_u15100(pl_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T137_[2] = colontmpD__29;
			T137_[3] = rawProc_1;
			colontmpD__30 = percent___cgen_u15142(T137_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*T136_)), colontmpD__30.len + 0);
appendString((&(*T136_)), colontmpD__30);
			eqdestroy___system_u2691(colontmpD__30);
			eqdestroy___system_u2691(colontmpD__29);
			eqdestroy___system_u2691(colontmpD__28);
		}
		goto LA131_;
LA133_: ;
		{
			NimStringV2 colontmpD__31;
			NimStringV2 colontmpD__32;
			NimStringV2 colontmpD__33;
			NimStringV2* T139_;
			NimStringV2* T140_;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T141_;
			colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
			colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
			colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
			T139_ = (NimStringV2*)0;
			T139_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T139_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T140_ = (NimStringV2*)0;
			T140_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			colontmpD__31 = rdLoc__cgen_u470(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T141_[0] = colontmpD__31;
			T141_[1] = pl_1;
			colontmpD__32 = addComma__cgen_u15100(pl_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T141_[2] = colontmpD__32;
			T141_[3] = rawProc_1;
			colontmpD__33 = percent___cgen_u15147(T141_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*T140_)), colontmpD__33.len + 0);
appendString((&(*T140_)), colontmpD__33);
			eqdestroy___system_u2691(colontmpD__33);
			eqdestroy___system_u2691(colontmpD__32);
			eqdestroy___system_u2691(colontmpD__31);
		}
LA131_: ;
		{
			if (!canRaise_1) goto LA144_;
			raiseExit__cgen_u14106(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA144_: ;
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(rawProc_1);
		eqdestroy___system_u2691(pl_1);
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipAddrDeref__cgen_u15266)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
	NIM_BOOL isAddr_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	n_1 = NIM_NIL;
	n_1 = node_p0;
	isAddr_1 = NIM_FALSE;
	switch ((*n_1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64):
	{
		n_1 = (*n_1)._kind_6.sons.p->data[((NI)0)];
		isAddr_1 = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
	{
		n_1 = (*n_1)._kind_6.sons.p->data[((NI)0)];
	}
	break;
	default:
	{
		eqcopy___ast_u3255(&result, n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
	break;
	}
	{
		if (!((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66))) goto LA6_;
		n_1 = (*n_1)._kind_6.sons.p->data[((NI)0)];
	}
LA6_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = isAddr_1;
		if (!(T10_)) goto LA11_;
		T10_ = ((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65));
LA11_: ;
		if (!T10_) goto LA12_;
		eqcopy___ast_u3255(&result, (*n_1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA8_;
LA12_: ;
	{
		if (!((*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*n_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA15_;
		eqcopy___ast_u3255(&result, (*n_1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA8_;
LA15_: ;
	{
		eqcopy___ast_u3255(&result, node_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genThisArg__cgen_u15283)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, NI i_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, NimStringV2* result_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ri_2 = NIM_NIL;
	t_1 = NIM_NIL;
	{
		NI T4_;
		NimStringV2 argX60gensym1729__1;
		T4_ = (NI)0;
		T4_ = len__ast_u3190((*typ_p3).n);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((i_p2 < T4_))) goto LA5_;
		argX60gensym1729__1.len = 0; argX60gensym1729__1.p = NIM_NIL;
		argX60gensym1729__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_1660);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, argX60gensym1729__1, TM__MQdRN7fpbG7rPm4JpVVAhA_1660);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym1729__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	eqcopy___ast_u3255(&ri_2, (*ri_p1)._kind_6.sons.p->data[i_p2]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66))) goto LA11;
			eqcopy___ast_u3255(&ri_2, (*ri_2)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA11: ;
	}
	t_1 = skipTypes__ast_u5379((*typ_p3).sons.p->data[i_p2], TM__MQdRN7fpbG7rPm4JpVVAhA_1661);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T17_;
		if (!((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23))) goto LA14_;
		x_1 = NIM_NIL;
		T17_ = NIM_NIL;
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA20_;
			eqcopy___ast_u3255(&x_1, (*ri_2)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		}
		goto LA18_;
LA20_: ;
		{
			x_1 = ri_2;
			eqwasMoved___ast_u3249(&ri_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		}
LA18_: ;
		{
			if (!((*(*x_1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA25_;
			genArgNoParam__cgen_u14798(p_p0, x_1, result_p4, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1662);
		}
		goto LA23_;
LA25_: ;
		{
			NIM_BOOL T28_;
			T28_ = (NIM_BOOL)0;
			T28_ = ((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65) || (*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47));
			if (!(T28_)) goto LA29_;
			T28_ = ((*(*(*x_1)._kind_6.sons.p->data[((NI)0)]).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
LA29_: ;
			if (!T28_) goto LA30_;
			genArgNoParam__cgen_u14798(p_p0, (*x_1)._kind_6.sons.p->data[((NI)0)], result_p4, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1663);
		}
		goto LA23_;
LA30_: ;
		{
			genArgNoParam__cgen_u14798(p_p0, x_1, result_p4, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			prepareAdd((&(*result_p4)), 1);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1664);
		}
LA23_: ;
		{
			LA16_:;
		}
		{
			oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(x_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin16_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA12_;
LA14_: ;
	{
		if (!((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA36_;
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA40_;
			genArgNoParam__cgen_u14798(p_p0, (*ri_2)._kind_6.sons.p->data[((NI)0)], result_p4, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*result_p4)), 1);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1665);
		}
		goto LA38_;
LA40_: ;
		{
			genArgNoParam__cgen_u14798(p_p0, ri_2, result_p4, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*result_p4)), 2);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1666);
		}
LA38_: ;
	}
	goto LA12_;
LA36_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T44_;
		T44_ = NIM_NIL;
		T44_ = skipAddrDeref__cgen_u15266(ri_2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T44_); goto LA1_;}
		eqsink___ast_u3261(&ri_2, T44_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!((*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA47_;
			eqcopy___ast_u3255(&ri_2, (*ri_2)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA47_: ;
		genArgNoParam__cgen_u14798(p_p0, ri_2, result_p4, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*result_p4)), 1);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1667);
	}
LA12_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(ri_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPatternCall__cgen_u15339)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, NimStringV2 pat_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p3, NimStringV2* result_p4) {
	NI i_1;
	NI j_1;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin47_;
NIM_BOOL oldNimErrFin59_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	i_1 = ((NI)0);
	j_1 = ((NI)1);
	{
		while (1) {
			if (!(i_1 < pat_p2.len)) goto LA2;
			switch (((NU8)(pat_p2.p->data[i_1]))) {
			case 64:
			{
				NI argsCounter_1;
				argsCounter_1 = ((NI)0);
				{
					NI k_1;
					NI colontmp_;
					NI i_2;
					k_1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = len__ast_u3190(ri_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 = j_1;
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA6;
							k_1 = i_2;
							genOtherArg__cgen_u14099(p_p0, ri_p1, k_1, typ_p3, result_p4, (&argsCounter_1));
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							i_2 += ((NI)1);
						} LA6: ;
					}
				}
				i_1 += ((NI)1);
			}
			break;
			case 35:
			{
				{
					NIM_BOOL T10_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_2;
					T10_ = (NIM_BOOL)0;
					T10_ = ((NI)(i_1 + ((NI)1)) < pat_p2.len);
					if (!(T10_)) goto LA11_;
					T10_ = (((NU8)(pat_p2.p->data[(NI)(i_1 + ((NI)1))])) == ((NU8)(43)) || ((NU8)(pat_p2.p->data[(NI)(i_1 + ((NI)1))])) == ((NU8)(64)));
LA11_: ;
					if (!T10_) goto LA12_;
					ri_2 = NIM_NIL;
					eqcopy___ast_u3255(&ri_2, (*ri_p1)._kind_6.sons.p->data[j_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					{
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
						if (!((*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*ri_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32))) goto LA17_;
						typ_2 = NIM_NIL;
						typ_2 = skipTypes__ast_u5379((*(*ri_2)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
						if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						{
							if (!((NU8)(pat_p2.p->data[(NI)(i_1 + ((NI)1))]) == (NU8)(43))) goto LA22_;
							genArgNoParam__cgen_u14798(p_p0, (*ri_2)._kind_6.sons.p->data[((NI)0)], result_p4, NIM_FALSE);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						}
LA22_: ;
						prepareAdd((&(*result_p4)), 1);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1655);
						{
							NI T26_;
							NI argsCounterB_1;
							T26_ = (NI)0;
							T26_ = len__ast_u3190(ri_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							if (!(((NI)1) < T26_)) goto LA27_;
							argsCounterB_1 = ((NI)0);
							genOtherArg__cgen_u14099(p_p0, ri_2, ((NI)1), typ_2, result_p4, (&argsCounterB_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						}
LA27_: ;
						{
							NI k_2;
							NI colontmp__2;
							NI colontmp__3;
							NI i_3;
							k_2 = (NI)0;
							colontmp__2 = (NI)0;
							colontmp__3 = (NI)0;
							colontmp__2 = (NI)(j_1 + ((NI)1));
							colontmp__3 = len__ast_u3190(ri_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							i_3 = colontmp__2;
							{
								while (1) {
									NI argsCounterB_2;
									if (!(i_3 < colontmp__3)) goto LA31;
									k_2 = i_3;
									argsCounterB_2 = ((NI)0);
									genOtherArg__cgen_u14099(p_p0, ri_2, k_2, typ_2, result_p4, (&argsCounterB_2));
									if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
									i_3 += ((NI)1);
								} LA31: ;
							}
						}
						prepareAdd((&(*result_p4)), 1);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1656);
						{
							LA19_:;
						}
						{
							oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3378(typ_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
							*nimErr_ = oldNimErrFin19_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					}
					goto LA15_;
LA17_: ;
					{
						liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*ri_2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_1658, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1659, NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					}
LA15_: ;
					i_1 += ((NI)1);
					{
						LA14_:;
					}
					{
						oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(ri_2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin14_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
				goto LA8_;
LA12_: ;
				{
					NIM_BOOL T38_;
					T38_ = (NIM_BOOL)0;
					T38_ = ((NI)(i_1 + ((NI)1)) < pat_p2.len);
					if (!(T38_)) goto LA39_;
					T38_ = ((NU8)(pat_p2.p->data[(NI)(i_1 + ((NI)1))]) == (NU8)(46));
LA39_: ;
					if (!T38_) goto LA40_;
					genThisArg__cgen_u15283(p_p0, ri_p1, j_1, typ_p3, result_p4);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_1 += ((NI)1);
				}
				goto LA8_;
LA40_: ;
				{
					NIM_BOOL T43_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg_1;
					T43_ = (NIM_BOOL)0;
					T43_ = ((NI)(i_1 + ((NI)1)) < pat_p2.len);
					if (!(T43_)) goto LA44_;
					T43_ = ((NU8)(pat_p2.p->data[(NI)(i_1 + ((NI)1))]) == (NU8)(91));
LA44_: ;
					if (!T43_) goto LA45_;
					arg_1 = NIM_NIL;
					arg_1 = skipAddrDeref__cgen_u15266((*ri_p1)._kind_6.sons.p->data[j_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
					{
						while (1) {
							if (!((*arg_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*arg_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64) || (*arg_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66))) goto LA49;
							eqcopy___ast_u3255(&arg_1, (*arg_1)._kind_6.sons.p->data[((NI)0)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
						} LA49: ;
					}
					genArgNoParam__cgen_u14798(p_p0, arg_1, result_p4, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
					{
						LA47_:;
					}
					{
						oldNimErrFin47_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(arg_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin47_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
				goto LA8_;
LA45_: ;
				{
					NI argsCounter_2;
					argsCounter_2 = ((NI)0);
					genOtherArg__cgen_u14099(p_p0, ri_p1, j_1, typ_p3, result_p4, (&argsCounter_2));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA8_: ;
				j_1 += ((NI)1);
				i_1 += ((NI)1);
			}
			break;
			case 39:
			{
				NI idx_1;
				NI stars_1;
				idx_1 = ((NI)0);
				stars_1 = ((NI)0);
				{
					NIM_BOOL T56_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
					T56_ = (NIM_BOOL)0;
					T56_ = scanCppGenericSlot__cgen_u6072(pat_p2, (&i_1), (&idx_1), (&stars_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T56_) goto LA57_;
					t_1 = NIM_NIL;
					t_1 = resolveStarsInCppType__cgen_u6104(typ_p3, idx_1, stars_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					{
						if (!(t_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA62_;
						prepareAdd((&(*result_p4)), 4);
appendString((&(*result_p4)), TM__MQdRN7fpbG7rPm4JpVVAhA_1668);
					}
					goto LA60_;
LA62_: ;
					{
						NimStringV2 colontmpD_;
						colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
						colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
						prepareAdd((&(*result_p4)), colontmpD_.len + 0);
appendString((&(*result_p4)), colontmpD_);
						{
							LA65_:;
						}
						{
							eqdestroy___system_u2691(colontmpD_);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					}
LA60_: ;
					{
						LA59_:;
					}
					{
						oldNimErrFin59_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(t_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						*nimErr_ = oldNimErrFin59_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA57_: ;
			}
			break;
			default:
			{
				NI start_1;
				start_1 = i_1;
				{
					while (1) {
						if (!(i_1 < pat_p2.len)) goto LA72;
						{
							if (!!((((NU8)(pat_p2.p->data[i_1])) == ((NU8)(64)) || ((NU8)(pat_p2.p->data[i_1])) == ((NU8)(35)) || ((NU8)(pat_p2.p->data[i_1])) == ((NU8)(39))))) goto LA75_;
							i_1 += ((NI)1);
						}
						goto LA73_;
LA75_: ;
						{
							goto LA71;
						}
LA73_: ;
					} LA72: ;
				} LA71: ;
				{
					NimStringV2 colontmpD__2;
					if (!(start_1 <= (NI)(i_1 - ((NI)1)))) goto LA80_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__2 = substr__system_u8632(pat_p2, start_1, (NI)(i_1 - ((NI)1)));
					prepareAdd((&(*result_p4)), colontmpD__2.len + 0);
appendString((&(*result_p4)), colontmpD__2);
					eqdestroy___system_u2691(colontmpD__2);
				}
LA80_: ;
			}
			break;
			}
		} LA2: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getTempCpp__cgen_u13605)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, NimStringV2 value_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
	NimStringV2 colontmpD_;
	NimStringV2 res_1;
	NimStringV2 T1_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2_;
	NimStringV2* T3_;
	NimStringV2* T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	(*p_p0).labels += ((NI)1);
	T1_.len = 0; T1_.p = NIM_NIL;
	colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).labels)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = rawNewString(colontmpD_.len + 2);
appendString((&T1_), TM__MQdRN7fpbG7rPm4JpVVAhA_1676);
appendString((&T1_), colontmpD_);
appendString((&T1_), TM__MQdRN7fpbG7rPm4JpVVAhA_1677);
	(*Result).snippet = T1_;
	(*Result).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1);
	T2_ = NIM_NIL;
	T2_ = lodeTyp__cgen_u104(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2_); goto BeforeRet_;}
	(*Result).lode = T2_;
	(*Result).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2);
	(*Result).flags = 0;
	T3_ = (NimStringV2*)0;
	T3_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	addIndent__cgen_u315(p_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T4_ = (NimStringV2*)0;
	T4_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1679);
	cgFormatValue__cgen_u163((&res_1), (*Result).snippet);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1680);
	cgFormatValue__cgen_u163((&res_1), value_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1681);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA7_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1682);
	}
LA7_: ;
	prepareAdd((&(*T4_)), res_1.len + 0);
appendString((&(*T4_)), res_1);
	eqdestroy___system_u2691(res_1);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, raiseExitCleanup__cgen_u14108)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 destroy_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!((((*p_p0).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)6)))&7U)))!=0))) goto LA3_;
		(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)4))) & 7);
		{
			NI T7_;
			NimStringV2 res_1;
			NimStringV2* T10_;
			NimStringV2* T11_;
			T7_ = (*p_p0).nestedTryStmts.len;
			if (!(T7_ == ((NI)0))) goto LA8_;
			res_1.len = 0; res_1.p = NIM_NIL;
			(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)0))) & 7);
			T10_ = (NimStringV2*)0;
			T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			addIndent__cgen_u315(p_p0, T10_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T11_ = (NimStringV2*)0;
			T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 29);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1688);
			cgFormatValue__cgen_u163((&res_1), destroy_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&res_1), 19);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1690);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA14_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1691);
			}
LA14_: ;
			prepareAdd((&(*T11_)), res_1.len + 0);
appendString((&(*T11_)), res_1);
			eqdestroy___system_u2691(res_1);
		}
		goto LA5_;
LA8_: ;
		{
			NimStringV2 res_2;
			NimStringV2* T17_;
			NimStringV2* T18_;
			tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T19_;
			res_2.len = 0; res_2.p = NIM_NIL;
			T17_ = (NimStringV2*)0;
			T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			addIndent__cgen_u315(p_p0, T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T18_ = (NimStringV2*)0;
			T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 29);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1692);
			cgFormatValue__cgen_u163((&res_2), destroy_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1694);
			T19_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
			T19_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			cgFormatValue__cgen_u166((&res_2), ((NI64) ((*T19_).Field2)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1696);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA22_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1697);
			}
LA22_: ;
			prepareAdd((&(*T18_)), res_2.len + 0);
appendString((&(*T18_)), res_2);
			eqdestroy___system_u2691(res_2);
		}
LA5_: ;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, cleanupTemp__cgen_u14263)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* returnType_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_p2) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	{
		if (!((*returnType_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*returnType_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47))) goto LA4_;
		result = NIM_FALSE;
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T7_;
		tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A T8_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dtor_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw op_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
		NimStringV2 callee_1;
		NimStringV2 destroy_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T13_;
		NimStringV2 T14_;
		T7_ = (NIM_BOOL)0;
		T8_ = 0;
		T7_ = !(((IL64(2147483664) & (*returnType_p1).flags) == T8_));
		if (!(T7_)) goto LA9_;
		colontmpD_ = getAttachedOp__modulegraphs_u4987((*(*(*p_p0).module).g).graph, returnType_p1, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = !((colontmpD_ == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA9_: ;
		if (!T7_) goto LA10_;
		dtor_1 = NIM_NIL;
		nimZeroMem((void*)(&op_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__2 = NIM_NIL;
		callee_1.len = 0; callee_1.p = NIM_NIL;
		destroy_1.len = 0; destroy_1.p = NIM_NIL;
		colontmpD__3 = NIM_NIL;
		dtor_1 = getAttachedOp__modulegraphs_u4987((*(*(*p_p0).module).g).graph, returnType_p1, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		colontmpD__2 = newSymNode__ast_u5168(dtor_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_ = 0;
		initLocExpr__cgen_u14111(p_p0, colontmpD__2, T13_, (&op_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		callee_1 = rdLoc__cgen_u470(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T14_.len = 0; T14_.p = NIM_NIL;
		{
			NimStringV2 colontmpD__4;
			NimStringV2 T19_;
			colontmpD__3 = firstParamType__ast_u5363((*dtor_1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			if (!((*colontmpD__3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23))) goto LA17_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T19_.len = 0; T19_.p = NIM_NIL;
			colontmpD__4 = rdLoc__cgen_u470(tmp_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			T19_ = rawNewString(callee_1.len + colontmpD__4.len + 3);
appendString((&T19_), callee_1);
appendString((&T19_), TM__MQdRN7fpbG7rPm4JpVVAhA_1683);
appendString((&T19_), colontmpD__4);
appendString((&T19_), TM__MQdRN7fpbG7rPm4JpVVAhA_1684);
			destroy_1 = T19_;
			eqdestroy___system_u2691(colontmpD__4);
		}
		goto LA15_;
LA17_: ;
		{
			NimStringV2 colontmpD__5;
			NimStringV2 T21_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T21_.len = 0; T21_.p = NIM_NIL;
			colontmpD__5 = rdLoc__cgen_u470(tmp_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			T21_ = rawNewString(callee_1.len + colontmpD__5.len + 2);
appendString((&T21_), callee_1);
appendString((&T21_), TM__MQdRN7fpbG7rPm4JpVVAhA_1685);
appendString((&T21_), colontmpD__5);
appendString((&T21_), TM__MQdRN7fpbG7rPm4JpVVAhA_1686);
			destroy_1 = T21_;
			eqdestroy___system_u2691(colontmpD__5);
		}
LA15_: ;
		raiseExitCleanup__cgen_u14108(p_p0, destroy_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		result = NIM_TRUE;
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(destroy_1);
			eqdestroy___system_u2691(callee_1);
			eqdestroy___ast_u3252(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u4574(dtor_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA10_: ;
	{
		result = NIM_FALSE;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixupCall__cgen_u14292)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3, NimStringV2 callee_p4, NimStringV2 params_p5) {
	NimStringV2 pl_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NIM_BOOL canRaise_1;
	NIM_BOOL T2_;
	NimStringV2 T4_;
NIM_BOOL oldNimErrFin35_;
NIM_BOOL oldNimErrFin50_;
NIM_BOOL oldNimErrFin87_;
NIM_BOOL oldNimErrFin82_;
NIM_BOOL oldNimErrFin108_;
NIM_BOOL oldNimErrFin118_;
NIM_BOOL oldNimErrFin103_;
NIM_BOOL oldNimErrFin137_;
NIM_BOOL oldNimErrFin130_;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	pl_1.len = 0; pl_1.p = NIM_NIL;
	typ_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*(*(*(*p_p0).module).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3));
	if (!(T2_)) goto LA3_;
	T2_ = canRaiseDisp__cgen_u14148(p_p0, (*ri_p2)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA3_: ;
	canRaise_1 = T2_;
	genLineDir__cgen_u418(p_p0, ri_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_.len = 0; T4_.p = NIM_NIL;
	T4_ = rawNewString(callee_p4.len + params_p5.len + 1);
appendString((&T4_), callee_p4);
appendString((&T4_), TM__MQdRN7fpbG7rPm4JpVVAhA_1670);
appendString((&T4_), params_p5);
	pl_1 = T4_;
	typ_1 = skipTypes__ast_u5379((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w flags_1;
		colontmpD_ = returnType__ast_u5354(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA7_;
		colontmpD__2 = NIM_NIL;
		flags_1 = 0;
		{
			colontmpD__2 = returnType__ast_u5354(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			if (!((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48))) goto LA12_;
			flags_1 |= ((NU8)1)<<(((((tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w)2))) & 7);
		}
LA12_: ;
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = isInvalidReturnType__cgen_u1424((*(*(*p_p0).module).g).config, typ_1, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			if (!T16_) goto LA17_;
			{
				if (!!((params_p5.len == ((NI)0)))) goto LA21_;
				prepareAdd((&pl_1), 2);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1671);
			}
LA21_: ;
			{
				NIM_BOOL T25_;
				NIM_BOOL T27_;
				NimStringV2 colontmpD__3;
				NimStringV2* T45_;
				NimStringV2* T46_;
				T25_ = (NIM_BOOL)0;
				T25_ = ((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1) || (*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
				if (T25_) goto LA26_;
				T27_ = (NIM_BOOL)0;
				T27_ = preventNrvo__cgen_u14180(p_p0, (*d_p3).lode, le_p1, ri_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				T25_ = !(T27_);
LA26_: ;
				if (!T25_) goto LA28_;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T36_;
					if (!((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA33_;
					colontmpD__4 = NIM_NIL;
					colontmpD__4 = returnType__ast_u5354(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					nimZeroMem((void*)(&T36_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					getTemp__cgen_u9546(p_p0, colontmpD__4, NIM_TRUE, (&T36_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					eqsink___ast_u6293((&(*d_p3)), T36_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					{
						LA35_:;
					}
					{
						oldNimErrFin35_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
						*nimErr_ = oldNimErrFin35_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				}
				goto LA31_;
LA33_: ;
				{
					NIM_BOOL T40_;
					NIM_BOOL T42_;
					T40_ = (NIM_BOOL)0;
					T40_ = !(((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1)));
					if (!(T40_)) goto LA41_;
					T42_ = (NIM_BOOL)0;
					T42_ = hasNoInit__cgen_u14238(ri_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
					T40_ = !(T42_);
LA41_: ;
					if (!T40_) goto LA43_;
				}
				goto LA31_;
LA43_: ;
LA31_: ;
				colontmpD__3 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*d_p3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				prepareAdd((&pl_1), colontmpD__3.len + 0);
appendString((&pl_1), colontmpD__3);
				prepareAdd((&pl_1), 3);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1673);
				T45_ = (NimStringV2*)0;
				T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				addIndent__cgen_u315(p_p0, T45_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				T46_ = (NimStringV2*)0;
				T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				prepareAdd((&(*T46_)), pl_1.len + 0);
appendString((&(*T46_)), pl_1);
				{
					LA30_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
			goto LA23_;
LA28_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
				NimStringV2 colontmpD__6;
				NimStringV2* T51_;
				NimStringV2* T52_;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T53_;
				nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__5 = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__5 = returnType__ast_u5354(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				getTemp__cgen_u9546(p_p0, colontmpD__5, NIM_TRUE, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				colontmpD__6 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				prepareAdd((&pl_1), colontmpD__6.len + 0);
appendString((&pl_1), colontmpD__6);
				prepareAdd((&pl_1), 3);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1674);
				T51_ = (NimStringV2*)0;
				T51_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				addIndent__cgen_u315(p_p0, T51_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				T52_ = (NimStringV2*)0;
				T52_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				prepareAdd((&(*T52_)), pl_1.len + 0);
appendString((&(*T52_)), pl_1);
				T53_ = 0;
				genAssignment__cgen_u12898(p_p0, (*d_p3), tmp_1, T53_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
				{
					LA50_:;
				}
				{
					oldNimErrFin50_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___ast_u3378(colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					eqdestroy___ast_u6284(tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					*nimErr_ = oldNimErrFin50_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
LA23_: ;
			{
				if (!canRaise_1) goto LA58_;
				raiseExit__cgen_u14106(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
LA58_: ;
		}
		goto LA14_;
LA17_: ;
		{
			prepareAdd((&pl_1), 1);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1675);
			{
				NIM_BOOL T63_;
				T63_ = (NIM_BOOL)0;
				T63_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T63_) goto LA64_;
				T63_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA64_: ;
				if (!T63_) goto LA65_;
				{
					if (!(((*d_p3).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)7)))&15U)))!=0)) goto LA69_;
					(*d_p3).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9);
					eqsink___system_u2700((&(*d_p3).snippet), pl_1);
					eqwasMoved___system_u2688((&pl_1));
					(*d_p3).flags &= ~(((NU16)1) << (((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)7))) & 15));
				}
				goto LA67_;
LA69_: ;
				{
					{
						NIM_BOOL T74_;
						NIM_BOOL T75_;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T80_;
						T74_ = (NIM_BOOL)0;
						T75_ = (NIM_BOOL)0;
						T75_ = ((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
						if (!(T75_)) goto LA76_;
						T75_ = ((*p_p0).splitDecls == ((NI)0));
LA76_: ;
						T74_ = T75_;
						if (!(T74_)) goto LA77_;
						T74_ = !(((*(*(*(*p_p0).module).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3)));
LA77_: ;
						if (!T74_) goto LA78_;
						colontmpD__7 = NIM_NIL;
						colontmpD__7 = returnType__ast_u5354(typ_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
						nimZeroMem((void*)(&T80_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						getTempCpp__cgen_u13605(p_p0, colontmpD__7, pl_1, (&T80_));
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
						eqsink___ast_u6293((&(*d_p3)), T80_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
						eqdestroy___ast_u3378(colontmpD__7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					}
					goto LA72_;
LA78_: ;
					{
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw list_1;
						tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T91_;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T92_;
						nimZeroMem((void*)(&list_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						{
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T88_;
							if (!((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA85_;
							colontmpD__8 = NIM_NIL;
							colontmpD__8 = returnType__ast_u5354(typ_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
							nimZeroMem((void*)(&T88_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							getTemp__cgen_u9546(p_p0, colontmpD__8, NIM_FALSE, (&T88_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
							eqsink___ast_u6293((&(*d_p3)), T88_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
							{
								LA87_:;
							}
							{
								oldNimErrFin87_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3378(colontmpD__8);
								if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
								*nimErr_ = oldNimErrFin87_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
						}
LA85_: ;
						T91_ = 0;
						nimZeroMem((void*)(&T92_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), (*d_p3).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T91_, (&T92_));
						list_1 = T92_;
						if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
						eqsink___system_u2700((&list_1.snippet), pl_1);
						eqwasMoved___system_u2688((&pl_1));
						genAssignment__cgen_u12898(p_p0, (*d_p3), list_1, 8);
						if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
						{
							if (!canRaise_1) goto LA95_;
							raiseExit__cgen_u14106(p_p0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
						}
LA95_: ;
						{
							LA82_:;
						}
						{
							oldNimErrFin82_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u6284(list_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
							*nimErr_ = oldNimErrFin82_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					}
LA72_: ;
				}
LA67_: ;
			}
			goto LA61_;
LA65_: ;
			{
				NIM_BOOL T100_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw list_2;
				NIM_BOOL useTemp_1;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T112_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T113_;
				T100_ = (NIM_BOOL)0;
				T100_ = isHarmlessStore__cgen_u14249(p_p0, canRaise_1, (*d_p3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				if (!T100_) goto LA101_;
				nimZeroMem((void*)(&list_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				useTemp_1 = NIM_FALSE;
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T109_;
					if (!((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA106_;
					colontmpD__9 = NIM_NIL;
					useTemp_1 = NIM_TRUE;
					colontmpD__9 = returnType__ast_u5354(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
					nimZeroMem((void*)(&T109_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					getTemp__cgen_u9546(p_p0, colontmpD__9, NIM_FALSE, (&T109_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
					eqsink___ast_u6293((&(*d_p3)), T109_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
					{
						LA108_:;
					}
					{
						oldNimErrFin108_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__9);
						if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
						*nimErr_ = oldNimErrFin108_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				}
LA106_: ;
				T112_ = 0;
				nimZeroMem((void*)(&T113_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), (*d_p3).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T112_, (&T113_));
				list_2 = T113_;
				if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				eqsink___system_u2700((&list_2.snippet), pl_1);
				eqwasMoved___system_u2688((&pl_1));
				genAssignment__cgen_u12898(p_p0, (*d_p3), list_2, (flags_1 | 8));
				if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
					if (!canRaise_1) goto LA116_;
					colontmpD__10 = NIM_NIL;
					{
						NIM_BOOL T121_;
						T121_ = (NIM_BOOL)0;
						T121_ = useTemp_1;
						if (!(T121_)) goto LA122_;
						colontmpD__10 = returnType__ast_u5354(typ_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
						T121_ = cleanupTemp__cgen_u14263(p_p0, colontmpD__10, (*d_p3));
						if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
LA122_: ;
						if (!!(T121_)) goto LA123_;
						raiseExit__cgen_u14106(p_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
					}
LA123_: ;
					{
						LA118_:;
					}
					{
						oldNimErrFin118_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__10);
						if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
						*nimErr_ = oldNimErrFin118_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
				}
LA116_: ;
				{
					LA103_:;
				}
				{
					oldNimErrFin103_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u6284(list_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					*nimErr_ = oldNimErrFin103_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
			goto LA61_;
LA101_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_2;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw list_3;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T131_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T132_;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T145_;
				nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__11 = NIM_NIL;
				nimZeroMem((void*)(&list_3), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__11 = returnType__ast_u5354(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA130_;
				getTemp__cgen_u9546(p_p0, colontmpD__11, NIM_TRUE, (&tmp_2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA130_;
				T131_ = 0;
				nimZeroMem((void*)(&T132_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), (*d_p3).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T131_, (&T132_));
				list_3 = T132_;
				if (NIM_UNLIKELY(*nimErr_)) goto LA130_;
				eqsink___system_u2700((&list_3.snippet), pl_1);
				eqwasMoved___system_u2688((&pl_1));
				genAssignment__cgen_u12898(p_p0, tmp_2, list_3, (flags_1 | 8));
				if (NIM_UNLIKELY(*nimErr_)) goto LA130_;
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__12;
					if (!canRaise_1) goto LA135_;
					colontmpD__12 = NIM_NIL;
					{
						NIM_BOOL T140_;
						colontmpD__12 = returnType__ast_u5354(typ_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
						T140_ = (NIM_BOOL)0;
						T140_ = cleanupTemp__cgen_u14263(p_p0, colontmpD__12, tmp_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
						if (!!(T140_)) goto LA141_;
						raiseExit__cgen_u14106(p_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
					}
LA141_: ;
					{
						LA137_:;
					}
					{
						oldNimErrFin137_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__12);
						if (NIM_UNLIKELY(*nimErr_)) goto LA130_;
						*nimErr_ = oldNimErrFin137_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA130_;
				}
LA135_: ;
				T145_ = 0;
				genAssignment__cgen_u12898(p_p0, (*d_p3), tmp_2, T145_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA130_;
				{
					LA130_:;
				}
				{
					oldNimErrFin130_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u6284(list_3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					eqdestroy___ast_u3378(colontmpD__11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					eqdestroy___ast_u6284(tmp_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					*nimErr_ = oldNimErrFin130_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
LA61_: ;
		}
LA14_: ;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA5_;
LA7_: ;
	{
		NimStringV2* T151_;
		NimStringV2* T152_;
		prepareAdd((&pl_1), 3);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1698);
		T151_ = (NimStringV2*)0;
		T151_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T151_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T152_ = (NimStringV2*)0;
		T152_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*T152_)), pl_1.len + 0);
appendString((&(*T152_)), pl_1);
		{
			if (!canRaise_1) goto LA155_;
			raiseExit__cgen_u14106(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA155_: ;
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(pl_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genInfixCall__cgen_u15418)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw op_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NimStringV2 pat_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin34_;
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&op_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	typ_1 = NIM_NIL;
	pat_1.len = 0; pat_1.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*ri_p2)._kind_6.sons.p->data[((NI)0)], T2_, (&op_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	typ_1 = skipTypes__ast_u5379((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	pat_1 = (*(*(*ri_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).loc.snippet;
	{
		NimStringV2 argX60gensym1770__1;
		if (!!((((NI)0) < pat_1.len))) goto LA5_;
		argX60gensym1770__1.len = 0; argX60gensym1770__1.p = NIM_NIL;
		argX60gensym1770__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_1653);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, argX60gensym1770__1, TM__MQdRN7fpbG7rPm4JpVVAhA_1653);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym1770__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		NIM_BOOL T12_;
		NimStringV2 pl_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		T12_ = (NIM_BOOL)0;
		T12_ = contains__pureZstrutils_u1837(pat_1, TM__MQdRN7fpbG7rPm4JpVVAhA_1654);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T12_) goto LA13_;
		pl_1.len = 0; pl_1.p = NIM_NIL;
		typ_2 = NIM_NIL;
		colontmpD_ = NIM_NIL;
		pl_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		genPatternCall__cgen_u15339(p_p0, ri_p2, pat_1, typ_1, (&pl_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		typ_2 = skipTypes__ast_u5379((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			colontmpD_ = returnType__ast_u5354(typ_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			if (!!((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA18_;
			{
				NIM_BOOL T22_;
				NIM_BOOL T23_;
				T22_ = (NIM_BOOL)0;
				T23_ = (NIM_BOOL)0;
				T23_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T23_) goto LA24_;
				T23_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA24_: ;
				T22_ = T23_;
				if (!(T22_)) goto LA25_;
				T22_ = (((*d_p3).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)7)))&15U)))!=0);
LA25_: ;
				if (!T22_) goto LA26_;
				(*d_p3).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9);
				eqsink___system_u2700((&(*d_p3).snippet), pl_1);
				eqwasMoved___system_u2688((&pl_1));
				(*d_p3).flags &= ~(((NU16)1) << (((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)7))) & 15));
			}
			goto LA20_;
LA26_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw list_1;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T38_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T39_;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T40_;
				nimZeroMem((void*)(&list_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T35_;
					if (!((*d_p3).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA32_;
					colontmpD__2 = NIM_NIL;
					colontmpD__2 = returnType__ast_u5354(typ_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
					nimZeroMem((void*)(&T35_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					getTemp__cgen_u9546(p_p0, colontmpD__2, NIM_FALSE, (&T35_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
					eqsink___ast_u6293((&(*d_p3)), T35_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
					{
						LA34_:;
					}
					{
						oldNimErrFin34_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						*nimErr_ = oldNimErrFin34_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				}
LA32_: ;
				T38_ = 0;
				nimZeroMem((void*)(&T39_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), (*d_p3).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T38_, (&T39_));
				list_1 = T39_;
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				eqsink___system_u2700((&list_1.snippet), pl_1);
				eqwasMoved___system_u2688((&pl_1));
				T40_ = 0;
				genAssignment__cgen_u12898(p_p0, (*d_p3), list_1, T40_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				{
					LA29_:;
				}
				{
					oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u6284(list_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					*nimErr_ = oldNimErrFin29_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			}
LA20_: ;
		}
		goto LA16_;
LA18_: ;
		{
			NimStringV2* T44_;
			NimStringV2* T45_;
			prepareAdd((&pl_1), 2);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1669);
			T44_ = (NimStringV2*)0;
			T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			addIndent__cgen_u315(p_p0, T44_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T45_ = (NimStringV2*)0;
			T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&(*T45_)), pl_1.len + 0);
appendString((&(*T45_)), pl_1);
		}
LA16_: ;
		{
			LA15_:;
		}
		{
			oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(typ_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(pl_1);
			*nimErr_ = oldNimErrFin15_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA10_;
LA13_: ;
	{
		NimStringV2 pl_2;
		NimStringV2 params_1;
		NI argsCounter_1;
		pl_2.len = 0; pl_2.p = NIM_NIL;
		params_1.len = 0; params_1.p = NIM_NIL;
		pl_2 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		argsCounter_1 = ((NI)0);
		{
			NI T52_;
			T52_ = (NI)0;
			T52_ = len__ast_u3190(ri_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			if (!(((NI)1) < T52_)) goto LA53_;
			genThisArg__cgen_u15283(p_p0, ri_p2, ((NI)1), typ_1, (&pl_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		}
LA53_: ;
		prepareAdd((&pl_2), op_1.snippet.len + 0);
appendString((&pl_2), op_1.snippet);
		params_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(ri_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			i_2 = ((NI)2);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA57;
					i_1 = i_2;
					genOtherArg__cgen_u14099(p_p0, ri_p2, i_1, typ_1, (&params_1), (&argsCounter_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
					i_2 += ((NI)1);
				} LA57: ;
			}
		}
		fixupCall__cgen_u14292(p_p0, le_p1, ri_p2, d_p3, pl_2, params_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		{
			LA49_:;
		}
		{
			eqdestroy___system_u2691(params_1);
			eqdestroy___system_u2691(pl_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, find__stdZprivateZospaths2_u388)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1) {
	NI result;
{	result = ((NI)0);
	{
		NIM_CHAR i_1;
		NI i_2;
		i_1 = (NIM_CHAR)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < a_p0Len_0)) goto LA3;
				i_1 = a_p0[i_2];
				{
					if (!((NU8)(i_1) == (NU8)(item_p1))) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				result += ((NI)1);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	result = ((NI)-1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__stdZprivateZospaths2_u383)(NIM_CHAR* a_p0, NI a_p0Len_0, NIM_CHAR item_p1) {
	NIM_BOOL result;
	NI T1_;
{	T1_ = (NI)0;
	T1_ = find__stdZprivateZospaths2_u388(a_p0, a_p0Len_0, item_p1);
	result = (((NI)0) <= T1_);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genNamedParamCall__cgen_u15479)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw op_1;
	NimStringV2 pl_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NimStringV2 pat_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	NI start_1;
NIM_BOOL oldNimErrFin34_;
NIM_BOOL oldNimErrFin65_;
NIM_BOOL oldNimErrFin74_;
NIM_BOOL oldNimErrFin86_;
NIM_BOOL oldNimErrFin81_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&op_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	pl_1.len = 0; pl_1.p = NIM_NIL;
	typ_1 = NIM_NIL;
	pat_1.len = 0; pat_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*ri_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&op_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	pl_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1699;
	typ_1 = skipTypes__ast_u5379((*(*ri_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	pat_1 = (*(*(*ri_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).loc.snippet;
	{
		NimStringV2 argX60gensym1791__1;
		if (!!((((NI)0) < pat_1.len))) goto LA5_;
		argX60gensym1791__1.len = 0; argX60gensym1791__1.p = NIM_NIL;
		argX60gensym1791__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_1700);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, argX60gensym1791__1, TM__MQdRN7fpbG7rPm4JpVVAhA_1700);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym1791__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	start_1 = ((NI)3);
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = contains__stdZprivateZospaths2_u383(((pat_1).p) ? (pat_1.p->data) : NIM_NIL, pat_1.len, 32);
		if (!T12_) goto LA13_;
		start_1 = ((NI)1);
		prepareAdd((&pl_1), op_1.snippet.len + 0);
appendString((&pl_1), op_1.snippet);
		{
			NI T17_;
			T17_ = (NI)0;
			T17_ = len__ast_u3190(ri_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)1) < T17_)) goto LA18_;
			prepareAdd((&pl_1), 2);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1702);
			genArg__cgen_u14693(p_p0, (*ri_p1)._kind_6.sons.p->data[((NI)1)], (*(*(*typ_1).n)._kind_6.sons.p->data[((NI)1)])._kind_4.sym, ri_p1, (&pl_1), NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			start_1 = ((NI)2);
		}
LA18_: ;
	}
	goto LA10_;
LA13_: ;
	{
		{
			NI T23_;
			T23_ = (NI)0;
			T23_ = len__ast_u3190(ri_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)1) < T23_)) goto LA24_;
			genArg__cgen_u14693(p_p0, (*ri_p1)._kind_6.sons.p->data[((NI)1)], (*(*(*typ_1).n)._kind_6.sons.p->data[((NI)1)])._kind_4.sym, ri_p1, (&pl_1), NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&pl_1), 1);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1703);
		}
LA24_: ;
		prepareAdd((&pl_1), op_1.snippet.len + 0);
appendString((&pl_1), op_1.snippet);
		{
			NI T28_;
			T28_ = (NI)0;
			T28_ = len__ast_u3190(ri_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)2) < T28_)) goto LA29_;
			prepareAdd((&pl_1), 2);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1704);
			genArg__cgen_u14693(p_p0, (*ri_p1)._kind_6.sons.p->data[((NI)2)], (*(*(*typ_1).n)._kind_6.sons.p->data[((NI)2)])._kind_4.sym, ri_p1, (&pl_1), NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA29_: ;
	}
LA10_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(ri_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = start_1;
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_1;
				if (!(i_2 < colontmp_)) goto LA33;
				param_1 = NIM_NIL;
				i_1 = i_2;
				{
					NI T37_;
					T37_ = (NI)0;
					T37_ = len__ast_u3190((*typ_1).n);
					if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
					if (!(T37_ <= i_1)) goto LA38_;
					internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*ri_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1706, TM__MQdRN7fpbG7rPm4JpVVAhA_1707);
					if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				}
LA38_: ;
				eqcopy___ast_u4577(&param_1, (*(*(*typ_1).n)._kind_6.sons.p->data[i_1])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				prepareAdd((&pl_1), 1);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1708);
				prepareAdd((&pl_1), (*(*param_1).name).s.len + 0);
appendString((&pl_1), (*(*param_1).name).s);
				prepareAdd((&pl_1), 2);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1709);
				genArg__cgen_u14693(p_p0, (*ri_p1)._kind_6.sons.p->data[i_1], param_1, ri_p1, (&pl_1), NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				i_2 += ((NI)1);
				{
					LA34_:;
				}
				{
					oldNimErrFin34_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(param_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin34_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA33: ;
		}
	}
	{
		colontmpD_ = returnType__ast_u5354(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA44_;
		{
			NIM_BOOL T48_;
			T48_ = (NIM_BOOL)0;
			T48_ = isInvalidReturnType__cgen_u1424((*(*(*p_p0).module).g).config, typ_1, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T48_) goto LA49_;
			{
				NI T53_;
				T53_ = (NI)0;
				T53_ = len__ast_u3190(ri_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(((NI)1) < T53_)) goto LA54_;
				prepareAdd((&pl_1), 1);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1710);
			}
LA54_: ;
			{
				NimStringV2 colontmpD__2;
				NimStringV2* T69_;
				NimStringV2* T70_;
				if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1) || (*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA58_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T66_;
					if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA63_;
					colontmpD__3 = NIM_NIL;
					colontmpD__3 = returnType__ast_u5354(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
					nimZeroMem((void*)(&T66_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					getTemp__cgen_u9546(p_p0, colontmpD__3, NIM_TRUE, (&T66_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
					eqsink___ast_u6293((&(*d_p2)), T66_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
					{
						LA65_:;
					}
					{
						oldNimErrFin65_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
						*nimErr_ = oldNimErrFin65_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
				}
LA63_: ;
				prepareAdd((&pl_1), 8);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1712);
				colontmpD__2 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*d_p2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
				prepareAdd((&pl_1), colontmpD__2.len + 0);
appendString((&pl_1), colontmpD__2);
				prepareAdd((&pl_1), 3);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1714);
				T69_ = (NimStringV2*)0;
				T69_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
				addIndent__cgen_u315(p_p0, T69_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
				T70_ = (NimStringV2*)0;
				T70_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
				prepareAdd((&(*T70_)), pl_1.len + 0);
appendString((&(*T70_)), pl_1);
				{
					LA60_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA56_;
LA58_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
				NimStringV2 colontmpD__5;
				NimStringV2* T75_;
				NimStringV2* T76_;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T77_;
				nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__4 = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__4 = returnType__ast_u5354(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				getTemp__cgen_u9546(p_p0, colontmpD__4, NIM_TRUE, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				colontmpD__5 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				prepareAdd((&pl_1), colontmpD__5.len + 0);
appendString((&pl_1), colontmpD__5);
				prepareAdd((&pl_1), 3);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1715);
				T75_ = (NimStringV2*)0;
				T75_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				addIndent__cgen_u315(p_p0, T75_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				T76_ = (NimStringV2*)0;
				T76_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				prepareAdd((&(*T76_)), pl_1.len + 0);
appendString((&(*T76_)), pl_1);
				T77_ = 0;
				genAssignment__cgen_u12898(p_p0, (*d_p2), tmp_1, T77_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
				{
					LA74_:;
				}
				{
					oldNimErrFin74_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___ast_u3378(colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin74_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA56_: ;
		}
		goto LA46_;
LA49_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw list_1;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T90_;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T91_;
			nimZeroMem((void*)(&list_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			prepareAdd((&pl_1), 1);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1716);
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T87_;
				if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA84_;
				colontmpD__6 = NIM_NIL;
				colontmpD__6 = returnType__ast_u5354(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
				nimZeroMem((void*)(&T87_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				getTemp__cgen_u9546(p_p0, colontmpD__6, NIM_FALSE, (&T87_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
				eqsink___ast_u6293((&(*d_p2)), T87_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
				{
					LA86_:;
				}
				{
					oldNimErrFin86_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
					*nimErr_ = oldNimErrFin86_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			}
LA84_: ;
			T90_ = 0;
			initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), ri_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T90_, (&list_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			eqsink___system_u2700((&list_1.snippet), pl_1);
			eqwasMoved___system_u2688((&pl_1));
			T91_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p2), list_1, T91_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			{
				LA81_:;
			}
			{
				oldNimErrFin81_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(list_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin81_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA46_: ;
	}
	goto LA42_;
LA44_: ;
	{
		NimStringV2* T95_;
		NimStringV2* T96_;
		prepareAdd((&pl_1), 3);
appendString((&pl_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1717);
		T95_ = (NimStringV2*)0;
		T95_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T95_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T96_ = (NimStringV2*)0;
		T96_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*T96_)), pl_1.len + 0);
appendString((&(*T96_)), pl_1);
	}
LA42_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(pl_1);
		eqdestroy___ast_u6284(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPrefixCall__cgen_u15075)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw op_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	NimStringV2 params_1;
	NimStringV2 callee_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&op_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	typ_1 = NIM_NIL;
	params_1.len = 0; params_1.p = NIM_NIL;
	callee_1.len = 0; callee_1.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*ri_p2)._kind_6.sons.p->data[((NI)0)], T2_, (&op_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	typ_1 = skipTypes__ast_u5379((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	params_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genParams__cgen_u14860(p_p0, ri_p2, typ_1, (&params_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	callee_1 = rdLoc__cgen_u470(op_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_u52(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA6_: ;
		if (!T5_) goto LA7_;
		addActualSuffixForHCR__cgen_u15038((&callee_1), (*(*p_p0).module).module, (*(*ri_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	fixupCall__cgen_u14292(p_p0, le_p1, ri_p2, d_p3, callee_1, params_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(callee_1);
		eqdestroy___system_u2691(params_1);
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgnCall__cgen_u15561)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (((NI)0) < (*p_p0).withinBlockLeaveActions);
		if (!(T4_)) goto LA5_;
		T4_ = isInactiveDestructorCall__cgen_u15553(p_p0, ri_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA6_: ;
	{
		colontmpD_ = skipTypes__ast_u5379((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1522);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD_).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9))) goto LA10_;
		genClosureCall__cgen_u15095(p_p0, le_p1, ri_p2, d_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA10_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T13_)) goto LA14_;
		T13_ = (((*(*(*ri_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA14_: ;
		if (!T13_) goto LA15_;
		genInfixCall__cgen_u15418(p_p0, le_p1, ri_p2, d_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA15_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = ((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T18_)) goto LA19_;
		T18_ = (((*(*(*ri_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)33)))&63U)))!=0);
LA19_: ;
		if (!T18_) goto LA20_;
		genNamedParamCall__cgen_u15479(p_p0, ri_p2, d_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA20_: ;
	{
		genPrefixCall__cgen_u15075(p_p0, le_p1, ri_p2, d_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, loadInto__cgen_u16153)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*ri_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*ri_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*ri_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*ri_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*ri_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*ri_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*ri_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*(*ri_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)));
		if (T5_) goto LA6_;
		T5_ = ((*(*(*ri_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0));
LA6_: ;
		T3_ = T5_;
LA4_: ;
		if (!T3_) goto LA7_;
		genAsgnCall__cgen_u15561(p_p0, le_p1, ri_p2, a_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA7_: ;
	{
		(*a_p3).flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)8))) & 15);
		expr__cgen_u14084(p_p0, ri_p2, a_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__cgen_u16620)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* vn_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_p3) {
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* targetProc_1;
	NimStringV2 valueAsRope_1;
	NimStringV2 traverseProc_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	NIM_BOOL imm_1;
	NIM_BOOL isCppCtorCall_1;
	NIM_BOOL T6_;
	NIM_BOOL T7_;
	NIM_BOOL T8_;
	NIM_BOOL T9_;
	NIM_BOOL T10_;
	NIM_BOOL T11_;
NIM_BOOL oldNimErrFin46_;
NIM_BOOL oldNimErrFin55_;
NIM_BOOL oldNimErrFin89_;
	NIM_BOOL forHcr_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	targetProc_1 = NIM_NIL;
	valueAsRope_1.len = 0; valueAsRope_1.p = NIM_NIL;
	traverseProc_1.len = 0; traverseProc_1.p = NIM_NIL;
	colontmpD_ = NIM_NIL;
	{
		if (!(((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)59)))&63U)))!=0)) goto LA4_;
		genGotoVar__cgen_u16514(p_p0, value_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(valueAsRope_1);
		eqdestroy___cgendata_u2071(targetProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	imm_1 = isAssignedImmediately__cgen_u15650((*(*(*p_p0).module).g).config, value_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = (NIM_BOOL)0;
	T7_ = (NIM_BOOL)0;
	T8_ = (NIM_BOOL)0;
	T9_ = (NIM_BOOL)0;
	T10_ = (NIM_BOOL)0;
	T11_ = (NIM_BOOL)0;
	T11_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
	if (T11_) goto LA12_;
	T11_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA12_: ;
	T10_ = T11_;
	if (!(T10_)) goto LA13_;
	T10_ = imm_1;
LA13_: ;
	T9_ = T10_;
	if (!(T9_)) goto LA14_;
	T9_ = ((*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
LA14_: ;
	T8_ = T9_;
	if (!(T8_)) goto LA15_;
	T8_ = ((*(*value_p3)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA15_: ;
	T7_ = T8_;
	if (!(T7_)) goto LA16_;
	T7_ = !(((*(*v_p1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21)));
LA16_: ;
	T6_ = T7_;
	if (!(T6_)) goto LA17_;
	T6_ = (((*(*(*value_p3)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29)))&63U)))!=0);
LA17_: ;
	isCppCtorCall_1 = T6_;
	eqcopy___cgendata_u2074(&targetProc_1, p_p0, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	valueAsRope_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1424;
	potentialValueInit__cgen_u16532(p_p0, v_p1, value_p3, (&valueAsRope_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3)))&63U)))!=0)) goto LA20_;
		{
			NIM_BOOL T24_;
			NIM_BOOL T25_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T28_;
			T24_ = (NIM_BOOL)0;
			T25_ = (NIM_BOOL)0;
			T25_ = (((*v_p1).flags & 192) == 64);
			if (!(T25_)) goto LA26_;
			T25_ = ((*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
LA26_: ;
			T24_ = T25_;
			if (!(T24_)) goto LA27_;
			T28_ = 0;
			T24_ = !((((*v_p1).loc.flags & 36) == T28_));
LA27_: ;
			if (!T24_) goto LA29_;
			eqdestroy___ast_u4574(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(valueAsRope_1);
			eqdestroy___cgendata_u2071(targetProc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA29_: ;
		{
			if (!(((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11)))&63U)))!=0)) goto LA33_;
			eqcopy___cgendata_u2074(&targetProc_1, (*(*p_p0).module).preInitProc, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA33_: ;
		{
			NIM_BOOL T37_;
			NIM_BOOL T39_;
			NIM_BOOL didGenTemp_1;
			T37_ = (NIM_BOOL)0;
			T37_ = isCppCtorCall_1;
			if (!(T37_)) goto LA38_;
			T39_ = (NIM_BOOL)0;
			T39_ = containsHiddenPointer__types_u601((*v_p1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T37_ = !(T39_);
LA38_: ;
			if (!T37_) goto LA40_;
			didGenTemp_1 = NIM_FALSE;
			callGlobalVarCppCtor__cgen_u14035(targetProc_1, v_p1, vn_p2, value_p3, (&didGenTemp_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc_1;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T47_;
				if (!didGenTemp_1) goto LA44_;
				nimZeroMem((void*)(&loc_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*vn_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)86), (*(*(*vn_p2)._kind_4.sym).name).s, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1446, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
				assignGlobalVar__cgen_u13919(targetProc_1, vn_p2, valueAsRope_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
				initLocExprSingleUse__cgen_u14116(targetProc_1, value_p3, (&loc_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
				T47_ = 0;
				genAssignment__cgen_u12898(targetProc_1, (*v_p1).loc, loc_1, T47_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA46_;
				{
					LA46_:;
				}
				{
					oldNimErrFin46_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u6284(loc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin46_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA44_: ;
		}
		goto LA35_;
LA40_: ;
		{
			assignGlobalVar__cgen_u13919(targetProc_1, vn_p2, valueAsRope_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA35_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc_2;
			if (!(valueAsRope_1.len == ((NI)0))) goto LA53_;
			nimZeroMem((void*)(&loc_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			eqcopy___ast_u6287((&loc_2), (*v_p1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
			{
				NIM_BOOL T58_;
				NIM_BOOL T59_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T64_;
				T58_ = (NIM_BOOL)0;
				T59_ = (NIM_BOOL)0;
				T59_ = (((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26)))&63U)))!=0);
				if (!(T59_)) goto LA60_;
				T59_ = emulatedThreadVars__cgen_u452((*(*(*p_p0).module).g).config);
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
LA60_: ;
				T58_ = T59_;
				if (!(T58_)) goto LA61_;
				T58_ = isComplexValueType__cgen_u13074((*v_p1).typ);
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
LA61_: ;
				if (!T58_) goto LA62_;
				nimZeroMem((void*)(&T64_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLocExprSingleUse__cgen_u14116((*(*p_p0).module).preInitProc, vn_p2, (&T64_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				eqsink___ast_u6293((&loc_2), T64_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
			}
LA62_: ;
			genObjectInit__cgen_u12909((*(*p_p0).module).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1), (*v_p1).typ, (&loc_2), ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
			{
				LA55_:;
			}
			{
				oldNimErrFin55_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(loc_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin55_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA53_: ;
		{
			NIM_BOOL T69_;
			T69_ = (NIM_BOOL)0;
			T69_ = (((*v_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7)))&63U)))!=0);
			if (!(T69_)) goto LA70_;
			T69_ = !(((*(*(*p_p0).module).g).generatedHeader == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)));
LA70_: ;
			if (!T69_) goto LA71_;
			genVarPrototype__cgen_u14075((*(*(*p_p0).module).g).generatedHeader, vn_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA71_: ;
		registerTraverseProc__cgen_u15592(p_p0, v_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA18_;
LA20_: ;
	{
		{
			NIM_BOOL T76_;
			NIM_BOOL T77_;
			NIM_BOOL T78_;
			NIM_BOOL T79_;
			NIM_BOOL T81_;
			NIM_BOOL T85_;
			NimStringV2 decl_1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
			T76_ = (NIM_BOOL)0;
			T77_ = (NIM_BOOL)0;
			T78_ = (NIM_BOOL)0;
			T79_ = (NIM_BOOL)0;
			T79_ = imm_1;
			if (!(T79_)) goto LA80_;
			T81_ = (NIM_BOOL)0;
			T81_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T81_) goto LA82_;
			T81_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA82_: ;
			T79_ = T81_;
LA80_: ;
			T78_ = T79_;
			if (!(T78_)) goto LA83_;
			T78_ = ((*p_p0).splitDecls == ((NI)0));
LA83_: ;
			T77_ = T78_;
			if (!(T77_)) goto LA84_;
			T85_ = (NIM_BOOL)0;
			T85_ = containsHiddenPointer__types_u601((*v_p1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T77_ = !(T85_);
LA84_: ;
			T76_ = T77_;
			if (!(T76_)) goto LA86_;
			T76_ = !((((*p_p0).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)4)))&7U)))!=0));
LA86_: ;
			if (!T76_) goto LA87_;
			decl_1.len = 0; decl_1.p = NIM_NIL;
			nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			genLineDir__cgen_u418(p_p0, vn_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			decl_1 = localVarDecl__cgen_u13649(p_p0, vn_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			{
				NIM_BOOL didGenTemp_2;
				NimStringV2* T94_;
				NimStringV2* T95_;
				if (!isCppCtorCall_1) goto LA92_;
				didGenTemp_2 = NIM_FALSE;
				genCppVarForCtor__cgen_u13914(p_p0, value_p3, (&decl_1), (&didGenTemp_2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				T94_ = (NimStringV2*)0;
				T94_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				addIndent__cgen_u315(p_p0, T94_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				T95_ = (NimStringV2*)0;
				T95_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				prepareAdd((&(*T95_)), decl_1.len + 0);
appendString((&(*T95_)), decl_1);
			}
			goto LA90_;
LA92_: ;
			{
				initLocExprSingleUse__cgen_u14116(p_p0, value_p3, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				{
					NimStringV2 colontmpD__2;
					NimStringV2* T101_;
					NimStringV2* T102_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T103_;
					if (!((*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1))) goto LA99_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					T101_ = (NimStringV2*)0;
					T101_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					addIndent__cgen_u315(p_p0, T101_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					T102_ = (NimStringV2*)0;
					T102_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					T103_[0] = decl_1;
					colontmpD__2 = percent___cgen_u16719(T103_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					prepareAdd((&(*T102_)), colontmpD__2.len + 0);
appendString((&(*T102_)), colontmpD__2);
					eqdestroy___system_u2691(colontmpD__2);
				}
				goto LA97_;
LA99_: ;
				{
					NimStringV2 colontmpD__3;
					NimStringV2 colontmpD__4;
					NimStringV2* T105_;
					NimStringV2* T106_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T107_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					T105_ = (NimStringV2*)0;
					T105_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					addIndent__cgen_u315(p_p0, T105_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					T106_ = (NimStringV2*)0;
					T106_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					T107_[0] = decl_1;
					colontmpD__3 = rdLoc__cgen_u470(tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					T107_[1] = colontmpD__3;
					colontmpD__4 = percent___cgen_u16724(T107_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
					prepareAdd((&(*T106_)), colontmpD__4.len + 0);
appendString((&(*T106_)), colontmpD__4);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
				}
LA97_: ;
			}
LA90_: ;
			eqdestroy___ast_u6284(tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(decl_1);
			eqdestroy___ast_u4574(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(valueAsRope_1);
			eqdestroy___cgendata_u2071(targetProc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
			{
				LA89_:;
			}
			{
				oldNimErrFin89_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(decl_1);
				*nimErr_ = oldNimErrFin89_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA87_: ;
		assignLocalVar__cgen_u13691(p_p0, vn_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		initLocalVar__cgen_u13552(p_p0, v_p1, imm_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA18_: ;
	traverseProc_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1497;
	forHcr_1 = treatGlobalDifferentlyForHCR__cgen_u13851((*p_p0).module, v_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T112_;
		NIM_BOOL T113_;
		NI T115_;
		NimStringV2 res_1;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2* T120_;
		NimStringV2* T121_;
		T112_ = (NIM_BOOL)0;
		T113_ = (NIM_BOOL)0;
		T113_ = forHcr_1;
		if (!(T113_)) goto LA114_;
		T115_ = (*targetProc_1).blocks.len;
		T113_ = (((NI)3) < T115_);
LA114_: ;
		T112_ = T113_;
		if (!(T112_)) goto LA116_;
		colontmpD_ = owner__ast_u6254(v_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T112_ = ((*colontmpD_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
LA116_: ;
		if (!T112_) goto LA117_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		T120_ = (NimStringV2*)0;
		T120_ = s__cgendata_u228(targetProc_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		addIndent__cgen_u315(targetProc_1, T120_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		T121_ = (NimStringV2*)0;
		T121_ = s__cgendata_u228(targetProc_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 18);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1499);
		colontmpD__5 = getModuleDllPath__cgen_u158((*p_p0).module, v_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1501);
		cgFormatValue__cgen_u163((&res_1), (*v_p1).loc.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1503);
		colontmpD__6 = rdLoc__cgen_u470((*v_p1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1505);
		cgFormatValue__cgen_u163((&res_1), traverseProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		prepareAdd((&res_1), 11);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1507);
		cgFormatValue__cgen_u163((&res_1), (*v_p1).loc.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1508);
		{
			if (!!((((*(*(*(*targetProc_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA124_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1509);
		}
LA124_: ;
		prepareAdd((&(*T121_)), res_1.len + 0);
appendString((&(*T121_)), res_1);
		forHcr_1 = NIM_FALSE;
		{
			LA119_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA117_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 res_3;
		NimStringV2* T133_;
		NimStringV2* T134_;
		NimStringV2* T135_;
		NimStringV2* T136_;
		NI T141_;
		if (!forHcr_1) goto LA130_;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		res_3.len = 0; res_3.p = NIM_NIL;
		T133_ = (NimStringV2*)0;
		T133_ = s__cgendata_u228(targetProc_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		addIndent__cgen_u315(targetProc_1, T133_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		T134_ = (NimStringV2*)0;
		T134_ = s__cgendata_u228(targetProc_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 22);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1511);
		colontmpD__7 = getModuleDllPath__cgen_u158((*p_p0).module, v_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1512);
		cgFormatValue__cgen_u163((&res_2), (*v_p1).loc.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1513);
		colontmpD__8 = rdLoc__cgen_u470((*v_p1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1514);
		cgFormatValue__cgen_u163((&res_2), traverseProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		prepareAdd((&res_2), 11);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1515);
		cgFormatValue__cgen_u163((&res_2), (*v_p1).loc.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1517);
		prepareAdd((&(*T134_)), res_2.len + 0);
appendString((&(*T134_)), res_2);
		T135_ = (NimStringV2*)0;
		T135_ = s__cgendata_u228(targetProc_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		addIndent__cgen_u315(targetProc_1, T135_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		T136_ = (NimStringV2*)0;
		T136_ = s__cgendata_u228(targetProc_1, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		res_3 = rawNewString(((NI)80));
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1518);
		{
			if (!!((((*(*(*(*targetProc_1).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA139_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1519);
		}
LA139_: ;
		prepareAdd((&(*T136_)), res_3.len + 0);
appendString((&(*T136_)), res_3);
		T141_ = (NI)0;
		T141_ = startBlockInternal__cgen_u15729(targetProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA132_;
		{
			LA132_:;
		}
		{
			eqdestroy___system_u2691(res_3);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA130_: ;
	{
		NIM_BOOL T146_;
		T146_ = (NIM_BOOL)0;
		T146_ = !(((*value_p3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)));
		if (!(T146_)) goto LA147_;
		T146_ = (valueAsRope_1.len == ((NI)0));
LA147_: ;
		if (!T146_) goto LA148_;
		genLineDir__cgen_u418(targetProc_1, vn_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!!(isCppCtorCall_1)) goto LA152_;
			loadInto__cgen_u16153(targetProc_1, vn_p2, value_p3, (&(*v_p1).loc));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA152_: ;
	}
LA148_: ;
	{
		if (!forHcr_1) goto LA156_;
		endBlock__cgen_u15767(targetProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA156_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(valueAsRope_1);
		eqdestroy___cgendata_u2071(targetProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, putDataIntoDest__cgen_u21128)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, NimStringV2 r_p3) {
NIM_BOOL oldNimErrFin5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T6_;
		if (!!(((*d_p1).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0)))) goto LA3_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		T6_ = 0;
		initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)8), n_p2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1), T6_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		eqcopy___system_u2694((&a_1.snippet), r_p3);
		{
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T11_;
			if (!(((*d_p1).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)1)))&15U)))!=0)) goto LA9_;
			T11_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p1), a_1, T11_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		goto LA7_;
LA9_: ;
		{
			genAssignment__cgen_u12898(p_p0, (*d_p1), a_1, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA7_: ;
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		(*d_p1).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)8);
		eqcopy___ast_u3255(&(*d_p1).lode, n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___system_u2694((&(*d_p1).snippet), r_p3);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getLabel__cgen_u14059)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	(*p_p0).labels += ((NI)1);
	T1_.len = 0; T1_.p = NIM_NIL;
	colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).labels)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = rawNewString(colontmpD_.len + 3);
appendString((&T1_), TM__MQdRN7fpbG7rPm4JpVVAhA_1737);
appendString((&T1_), colontmpD_);
appendString((&T1_), TM__MQdRN7fpbG7rPm4JpVVAhA_1738);
	result = T1_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixLabel__cgen_u14067)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 labl_p1) {
	NimStringV2 colontmpD_;
	NimStringV2* T1_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_ = (NimStringV2*)0;
	T1_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_[0] = labl_p1;
	colontmpD_ = percent___cgen_u14070(T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&(*T1_)), colontmpD_.len + 0);
appendString((&(*T1_)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAndOr__cgen_u22826)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3) {
	NimStringV2 L_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	L_1.len = 0; L_1.p = NIM_NIL;
	nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&tmp_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).splitDecls += ((NI)1);
	expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], (&tmp_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	L_1 = getLabel__cgen_u14059(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2* T6_;
		NimStringV2* T7_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		if (!(m_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)107))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_ = (NimStringV2*)0;
		T6_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = (NimStringV2*)0;
		T7_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD_ = rdLoc__cgen_u470(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_[0] = colontmpD_;
		T8_[1] = L_1;
		colontmpD__2 = percent___cgen_u22842(T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*T7_)), colontmpD__2.len + 0);
appendString((&(*T7_)), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2* T10_;
		NimStringV2* T11_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T12_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T10_ = (NimStringV2*)0;
		T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T10_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T11_ = (NimStringV2*)0;
		T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__3 = rdLoc__cgen_u470(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T12_[0] = colontmpD__3;
		T12_[1] = L_1;
		colontmpD__4 = percent___cgen_u22847(T12_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*T11_)), colontmpD__4.len + 0);
appendString((&(*T11_)), colontmpD__4);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
	}
LA2_: ;
	expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], (&tmp_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fixLabel__cgen_u14067(p_p0, L_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA15_;
		eqsink___ast_u6293((&(*d_p2)), tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqwasMoved___ast_u6281((&tmp_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA13_;
LA15_: ;
	{
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T18_;
		T18_ = 0;
		genAssignment__cgen_u12898(p_p0, (*d_p2), tmp_1, T18_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	(*p_p0).splitDecls -= ((NI)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(L_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, unaryArith__cgen_u21772)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch (op_p3) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96):
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T5_;
		NI64 T6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD_ = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		T5_[0] = colontmpD_;
		T6_ = (NI64)0;
		T6_ = getSize__types_u3397((*(*(*p_p0).module).g).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		colontmpD__2 = rope__ropes_u15((NI64)(T6_ * IL64(8)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		T5_[1] = colontmpD__2;
		colontmpD__3 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		T5_[2] = colontmpD__3;
		colontmpD__4 = percent___cgen_u21788(T5_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__4, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		{
			LA4_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)97):
	{
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T11_;
		NI64 T12_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__5 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T11_[0] = colontmpD__5;
		T12_ = (NI64)0;
		T12_ = getSize__types_u3397((*(*(*p_p0).module).g).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		colontmpD__6 = rope__ropes_u15((NI64)(T12_ * IL64(8)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T11_[1] = colontmpD__6;
		colontmpD__7 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T11_[2] = colontmpD__7;
		colontmpD__8 = percent___cgen_u21793(T11_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__8, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			LA10_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)98):
	{
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T17_;
		NI64 T18_;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__9 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		T17_[0] = colontmpD__9;
		T18_ = (NI64)0;
		T18_ = getSize__types_u3397((*(*(*p_p0).module).g).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		colontmpD__10 = rope__ropes_u15((NI64)(T18_ * IL64(8)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		T17_[1] = colontmpD__10;
		colontmpD__11 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		T17_[2] = colontmpD__11;
		colontmpD__12 = percent___cgen_u21798(T17_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__12, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		{
			LA16_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)99):
	{
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T23_;
		NI64 T24_;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__13 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_[0] = colontmpD__13;
		T24_ = (NI64)0;
		T24_ = getSize__types_u3397((*(*(*p_p0).module).g).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		colontmpD__14 = rope__ropes_u15((NI64)(T24_ * IL64(8)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_[1] = colontmpD__14;
		colontmpD__15 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T23_[2] = colontmpD__15;
		colontmpD__16 = percent___cgen_u21793(T23_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__16, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		{
			LA22_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)100):
	{
		NimStringV2 colontmpD__17;
		NimStringV2 colontmpD__18;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T29_;
		NI64 T30_;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__17 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		T29_[0] = colontmpD__17;
		T30_ = (NI64)0;
		T30_ = getSize__types_u3397((*(*(*p_p0).module).g).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		colontmpD__18 = rope__ropes_u15((NI64)(T30_ * IL64(8)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		T29_[1] = colontmpD__18;
		colontmpD__19 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		T29_[2] = colontmpD__19;
		colontmpD__20 = percent___cgen_u21479(T29_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__20, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		{
			LA28_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___system_u2691(colontmpD__17);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, unaryArithOverflow__cgen_u21433)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 first_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 res_2;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T8_;
		NimStringV2* T9_;
		NimStringV2* T10_;
		NimStringV2* T11_;
		NimStringV2* T12_;
		NimStringV2* T13_;
		if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0)) goto LA5_;
		first_1.len = 0; first_1.p = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		res_2.len = 0; res_2.p = NIM_NIL;
		first_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		intLiteral__cgen_u20135(T8_, (&first_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T9_ = (NimStringV2*)0;
		T9_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		addIndent__cgen_u315(p_p0, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T10_ = (NimStringV2*)0;
		T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1739);
		colontmpD_ = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1741);
		cgFormatValue__cgen_u163((&res_1), first_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1743);
		colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1745);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1746);
		prepareAdd((&(*T10_)), res_1.len + 0);
appendString((&(*T10_)), res_1);
		T11_ = (NimStringV2*)0;
		T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		raiseInstr__cgen_u457(p_p0, T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T12_ = (NimStringV2*)0;
		T12_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		addIndent__cgen_u315(p_p0, T12_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T13_ = (NimStringV2*)0;
		T13_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1747);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA16_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1748);
		}
LA16_: ;
		prepareAdd((&(*T13_)), res_2.len + 0);
appendString((&(*T13_)), res_2);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(res_2);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			eqdestroy___system_u2691(first_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	switch (m_p3) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)93):
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T22_;
		NI64 T23_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__3 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		T22_[0] = colontmpD__3;
		T23_ = (NI64)0;
		T23_ = getSize__types_u3397((*(*(*p_p0).module).g).config, t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		colontmpD__4 = rope__ropes_u15((NI64)(T23_ * IL64(8)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		T22_[1] = colontmpD__4;
		colontmpD__5 = percent___cgen_u21474(T22_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__5, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		{
			LA21_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)94):
	{
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tyArray__YgExxhfgKcesA5EOUj1MOA T28_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__6 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T28_[0] = colontmpD__6;
		colontmpD__7 = percent___cgen_u21479(T28_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__7, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		{
			LA27_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)95):
	{
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		tyArray__YgExxhfgKcesA5EOUj1MOA T33_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__8 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		T33_[0] = colontmpD__8;
		colontmpD__9 = percent___cgen_u21484(T33_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__9, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		{
			LA32_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryArith__cgen_u21495)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
	NI64 s_1;
	NI64 k_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
	NI64 T4_;
	NI64 T5_;
	NI64 T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	s_1 = IL64(0);
	k_1 = IL64(0);
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = (NI64)0;
	T4_ = getSize__types_u3397((*(*(*p_p0).module).g).config, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = t__cgen_u97(b_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_ = (NI64)0;
	T5_ = getSize__types_u3397((*(*(*p_p0).module).g).config, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	s_1 = (NI64)(((T4_ >= T5_) ? T4_ : T5_) * IL64(8));
	colontmpD__3 = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = (NI64)0;
	T6_ = getSize__types_u3397((*(*(*p_p0).module).g).config, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	k_1 = (NI64)(T6_ * IL64(8));
	switch (op_p3) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)53):
	{
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T9_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__4 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[0] = colontmpD__4;
		colontmpD__5 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[1] = colontmpD__5;
		colontmpD__6 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[2] = colontmpD__6;
		colontmpD__7 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[3] = colontmpD__7;
		colontmpD__8 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[4] = colontmpD__8;
		colontmpD__9 = percent___cgen_u21520(T9_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__9, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)54):
	{
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T14_;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__10 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[0] = colontmpD__10;
		colontmpD__11 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[1] = colontmpD__11;
		colontmpD__12 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[2] = colontmpD__12;
		colontmpD__13 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[3] = colontmpD__13;
		colontmpD__14 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[4] = colontmpD__14;
		colontmpD__15 = percent___cgen_u21525(T14_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__15, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)55):
	{
		NimStringV2 colontmpD__16;
		NimStringV2 colontmpD__17;
		NimStringV2 colontmpD__18;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		NimStringV2 colontmpD__21;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T19_;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__16 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		T19_[0] = colontmpD__16;
		colontmpD__17 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		T19_[1] = colontmpD__17;
		colontmpD__18 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		T19_[2] = colontmpD__18;
		colontmpD__19 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		T19_[3] = colontmpD__19;
		colontmpD__20 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		T19_[4] = colontmpD__20;
		colontmpD__21 = percent___cgen_u21530(T19_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__21, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		{
			LA18_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___system_u2691(colontmpD__16);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)56):
	{
		NimStringV2 colontmpD__22;
		NimStringV2 colontmpD__23;
		NimStringV2 colontmpD__24;
		NimStringV2 colontmpD__25;
		NimStringV2 colontmpD__26;
		NimStringV2 colontmpD__27;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T24_;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
		colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
		colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
		colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
		colontmpD__22 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T24_[0] = colontmpD__22;
		colontmpD__23 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T24_[1] = colontmpD__23;
		colontmpD__24 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T24_[2] = colontmpD__24;
		colontmpD__25 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T24_[3] = colontmpD__25;
		colontmpD__26 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T24_[4] = colontmpD__26;
		colontmpD__27 = percent___cgen_u21535(T24_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__27, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		{
			LA23_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__27);
			eqdestroy___system_u2691(colontmpD__26);
			eqdestroy___system_u2691(colontmpD__25);
			eqdestroy___system_u2691(colontmpD__24);
			eqdestroy___system_u2691(colontmpD__23);
			eqdestroy___system_u2691(colontmpD__22);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)57):
	{
		NimStringV2 colontmpD__28;
		NimStringV2 colontmpD__29;
		NimStringV2 colontmpD__30;
		NimStringV2 colontmpD__31;
		NimStringV2 colontmpD__32;
		NimStringV2 colontmpD__33;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T29_;
		colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
		colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
		colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
		colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
		colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
		colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
		colontmpD__28 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		T29_[0] = colontmpD__28;
		colontmpD__29 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		T29_[1] = colontmpD__29;
		colontmpD__30 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		T29_[2] = colontmpD__30;
		colontmpD__31 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		T29_[3] = colontmpD__31;
		colontmpD__32 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		T29_[4] = colontmpD__32;
		colontmpD__33 = percent___cgen_u21540(T29_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__33, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		{
			LA28_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__33);
			eqdestroy___system_u2691(colontmpD__32);
			eqdestroy___system_u2691(colontmpD__31);
			eqdestroy___system_u2691(colontmpD__30);
			eqdestroy___system_u2691(colontmpD__29);
			eqdestroy___system_u2691(colontmpD__28);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)58):
	{
		NimStringV2 colontmpD__34;
		NimStringV2 colontmpD__35;
		NimStringV2 colontmpD__36;
		NimStringV2 colontmpD__37;
		NimStringV2 colontmpD__38;
		NimStringV2 colontmpD__39;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T34_;
		colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
		colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
		colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
		colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
		colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
		colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
		colontmpD__34 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		T34_[0] = colontmpD__34;
		colontmpD__35 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		T34_[1] = colontmpD__35;
		colontmpD__36 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		T34_[2] = colontmpD__36;
		colontmpD__37 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		T34_[3] = colontmpD__37;
		colontmpD__38 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		T34_[4] = colontmpD__38;
		colontmpD__39 = percent___cgen_u21545(T34_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__39, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			LA33_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__39);
			eqdestroy___system_u2691(colontmpD__38);
			eqdestroy___system_u2691(colontmpD__37);
			eqdestroy___system_u2691(colontmpD__36);
			eqdestroy___system_u2691(colontmpD__35);
			eqdestroy___system_u2691(colontmpD__34);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)59):
	{
		NimStringV2 colontmpD__40;
		NimStringV2 colontmpD__41;
		NimStringV2 colontmpD__42;
		NimStringV2 colontmpD__43;
		NimStringV2 colontmpD__44;
		NimStringV2 colontmpD__45;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T39_;
		colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
		colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
		colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
		colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
		colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
		colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
		colontmpD__40 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		T39_[0] = colontmpD__40;
		colontmpD__41 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		T39_[1] = colontmpD__41;
		colontmpD__42 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		T39_[2] = colontmpD__42;
		colontmpD__43 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		T39_[3] = colontmpD__43;
		colontmpD__44 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		T39_[4] = colontmpD__44;
		colontmpD__45 = percent___cgen_u21550(T39_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__45, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
		{
			LA38_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__45);
			eqdestroy___system_u2691(colontmpD__44);
			eqdestroy___system_u2691(colontmpD__43);
			eqdestroy___system_u2691(colontmpD__42);
			eqdestroy___system_u2691(colontmpD__41);
			eqdestroy___system_u2691(colontmpD__40);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)60):
	{
		NimStringV2 colontmpD__46;
		NimStringV2 colontmpD__47;
		NimStringV2 colontmpD__48;
		NimStringV2 colontmpD__49;
		NimStringV2 colontmpD__50;
		NimStringV2 colontmpD__51;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T44_;
		colontmpD__46.len = 0; colontmpD__46.p = NIM_NIL;
		colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
		colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
		colontmpD__49.len = 0; colontmpD__49.p = NIM_NIL;
		colontmpD__50.len = 0; colontmpD__50.p = NIM_NIL;
		colontmpD__51.len = 0; colontmpD__51.p = NIM_NIL;
		colontmpD__46 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
		T44_[0] = colontmpD__46;
		colontmpD__47 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
		T44_[1] = colontmpD__47;
		colontmpD__48 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
		T44_[2] = colontmpD__48;
		colontmpD__49 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
		T44_[3] = colontmpD__49;
		colontmpD__50 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
		T44_[4] = colontmpD__50;
		colontmpD__51 = percent___cgen_u21555(T44_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__51, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
		{
			LA43_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__51);
			eqdestroy___system_u2691(colontmpD__50);
			eqdestroy___system_u2691(colontmpD__49);
			eqdestroy___system_u2691(colontmpD__48);
			eqdestroy___system_u2691(colontmpD__47);
			eqdestroy___system_u2691(colontmpD__46);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)61):
	{
		NimStringV2 colontmpD__52;
		NimStringV2 colontmpD__53;
		NimStringV2 colontmpD__54;
		NimStringV2 colontmpD__55;
		NimStringV2 colontmpD__56;
		NimStringV2 colontmpD__57;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T49_;
		colontmpD__52.len = 0; colontmpD__52.p = NIM_NIL;
		colontmpD__53.len = 0; colontmpD__53.p = NIM_NIL;
		colontmpD__54.len = 0; colontmpD__54.p = NIM_NIL;
		colontmpD__55.len = 0; colontmpD__55.p = NIM_NIL;
		colontmpD__56.len = 0; colontmpD__56.p = NIM_NIL;
		colontmpD__57.len = 0; colontmpD__57.p = NIM_NIL;
		colontmpD__52 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		T49_[0] = colontmpD__52;
		colontmpD__53 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		T49_[1] = colontmpD__53;
		colontmpD__54 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		T49_[2] = colontmpD__54;
		colontmpD__55 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		T49_[3] = colontmpD__55;
		colontmpD__56 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		T49_[4] = colontmpD__56;
		colontmpD__57 = percent___cgen_u21560(T49_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__57, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
		{
			LA48_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__57);
			eqdestroy___system_u2691(colontmpD__56);
			eqdestroy___system_u2691(colontmpD__55);
			eqdestroy___system_u2691(colontmpD__54);
			eqdestroy___system_u2691(colontmpD__53);
			eqdestroy___system_u2691(colontmpD__52);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)62):
	{
		NimStringV2 colontmpD__58;
		NimStringV2 colontmpD__59;
		NimStringV2 colontmpD__60;
		NimStringV2 colontmpD__61;
		NimStringV2 colontmpD__62;
		NimStringV2 colontmpD__63;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T54_;
		colontmpD__58.len = 0; colontmpD__58.p = NIM_NIL;
		colontmpD__59.len = 0; colontmpD__59.p = NIM_NIL;
		colontmpD__60.len = 0; colontmpD__60.p = NIM_NIL;
		colontmpD__61.len = 0; colontmpD__61.p = NIM_NIL;
		colontmpD__62.len = 0; colontmpD__62.p = NIM_NIL;
		colontmpD__63.len = 0; colontmpD__63.p = NIM_NIL;
		colontmpD__58 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		T54_[0] = colontmpD__58;
		colontmpD__59 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		T54_[1] = colontmpD__59;
		colontmpD__60 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		T54_[2] = colontmpD__60;
		colontmpD__61 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		T54_[3] = colontmpD__61;
		colontmpD__62 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		T54_[4] = colontmpD__62;
		colontmpD__63 = percent___cgen_u21565(T54_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__63, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		{
			LA53_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__63);
			eqdestroy___system_u2691(colontmpD__62);
			eqdestroy___system_u2691(colontmpD__61);
			eqdestroy___system_u2691(colontmpD__60);
			eqdestroy___system_u2691(colontmpD__59);
			eqdestroy___system_u2691(colontmpD__58);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)63):
	{
		NimStringV2 colontmpD__64;
		NimStringV2 colontmpD__65;
		NimStringV2 colontmpD__66;
		NimStringV2 colontmpD__67;
		NimStringV2 colontmpD__68;
		NimStringV2 colontmpD__69;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T59_;
		colontmpD__64.len = 0; colontmpD__64.p = NIM_NIL;
		colontmpD__65.len = 0; colontmpD__65.p = NIM_NIL;
		colontmpD__66.len = 0; colontmpD__66.p = NIM_NIL;
		colontmpD__67.len = 0; colontmpD__67.p = NIM_NIL;
		colontmpD__68.len = 0; colontmpD__68.p = NIM_NIL;
		colontmpD__69.len = 0; colontmpD__69.p = NIM_NIL;
		colontmpD__64 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		T59_[0] = colontmpD__64;
		colontmpD__65 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		T59_[1] = colontmpD__65;
		colontmpD__66 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		T59_[2] = colontmpD__66;
		colontmpD__67 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		T59_[3] = colontmpD__67;
		colontmpD__68 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		T59_[4] = colontmpD__68;
		colontmpD__69 = percent___cgen_u21570(T59_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__69, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		{
			LA58_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__69);
			eqdestroy___system_u2691(colontmpD__68);
			eqdestroy___system_u2691(colontmpD__67);
			eqdestroy___system_u2691(colontmpD__66);
			eqdestroy___system_u2691(colontmpD__65);
			eqdestroy___system_u2691(colontmpD__64);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)64):
	{
		NimStringV2 colontmpD__70;
		NimStringV2 colontmpD__71;
		NimStringV2 colontmpD__72;
		NimStringV2 colontmpD__73;
		NimStringV2 colontmpD__74;
		NimStringV2 colontmpD__75;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T64_;
		colontmpD__70.len = 0; colontmpD__70.p = NIM_NIL;
		colontmpD__71.len = 0; colontmpD__71.p = NIM_NIL;
		colontmpD__72.len = 0; colontmpD__72.p = NIM_NIL;
		colontmpD__73.len = 0; colontmpD__73.p = NIM_NIL;
		colontmpD__74.len = 0; colontmpD__74.p = NIM_NIL;
		colontmpD__75.len = 0; colontmpD__75.p = NIM_NIL;
		colontmpD__70 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		T64_[0] = colontmpD__70;
		colontmpD__71 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		T64_[1] = colontmpD__71;
		colontmpD__72 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		T64_[2] = colontmpD__72;
		colontmpD__73 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		T64_[3] = colontmpD__73;
		colontmpD__74 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		T64_[4] = colontmpD__74;
		colontmpD__75 = percent___cgen_u21575(T64_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__75, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		{
			LA63_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__75);
			eqdestroy___system_u2691(colontmpD__74);
			eqdestroy___system_u2691(colontmpD__73);
			eqdestroy___system_u2691(colontmpD__72);
			eqdestroy___system_u2691(colontmpD__71);
			eqdestroy___system_u2691(colontmpD__70);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)65):
	{
		NimStringV2 colontmpD__76;
		NimStringV2 colontmpD__77;
		NimStringV2 colontmpD__78;
		NimStringV2 colontmpD__79;
		NimStringV2 colontmpD__80;
		NimStringV2 colontmpD__81;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T69_;
		colontmpD__76.len = 0; colontmpD__76.p = NIM_NIL;
		colontmpD__77.len = 0; colontmpD__77.p = NIM_NIL;
		colontmpD__78.len = 0; colontmpD__78.p = NIM_NIL;
		colontmpD__79.len = 0; colontmpD__79.p = NIM_NIL;
		colontmpD__80.len = 0; colontmpD__80.p = NIM_NIL;
		colontmpD__81.len = 0; colontmpD__81.p = NIM_NIL;
		colontmpD__76 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[0] = colontmpD__76;
		colontmpD__77 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[1] = colontmpD__77;
		colontmpD__78 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[2] = colontmpD__78;
		colontmpD__79 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[3] = colontmpD__79;
		colontmpD__80 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		T69_[4] = colontmpD__80;
		colontmpD__81 = percent___cgen_u21580(T69_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__81, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
		{
			LA68_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__81);
			eqdestroy___system_u2691(colontmpD__80);
			eqdestroy___system_u2691(colontmpD__79);
			eqdestroy___system_u2691(colontmpD__78);
			eqdestroy___system_u2691(colontmpD__77);
			eqdestroy___system_u2691(colontmpD__76);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)66):
	{
		NimStringV2 colontmpD__82;
		NimStringV2 colontmpD__83;
		NimStringV2 colontmpD__84;
		NimStringV2 colontmpD__85;
		NimStringV2 colontmpD__86;
		NimStringV2 colontmpD__87;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T74_;
		colontmpD__82.len = 0; colontmpD__82.p = NIM_NIL;
		colontmpD__83.len = 0; colontmpD__83.p = NIM_NIL;
		colontmpD__84.len = 0; colontmpD__84.p = NIM_NIL;
		colontmpD__85.len = 0; colontmpD__85.p = NIM_NIL;
		colontmpD__86.len = 0; colontmpD__86.p = NIM_NIL;
		colontmpD__87.len = 0; colontmpD__87.p = NIM_NIL;
		colontmpD__82 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T74_[0] = colontmpD__82;
		colontmpD__83 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T74_[1] = colontmpD__83;
		colontmpD__84 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T74_[2] = colontmpD__84;
		colontmpD__85 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T74_[3] = colontmpD__85;
		colontmpD__86 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		T74_[4] = colontmpD__86;
		colontmpD__87 = percent___cgen_u21585(T74_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__87, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		{
			LA73_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__87);
			eqdestroy___system_u2691(colontmpD__86);
			eqdestroy___system_u2691(colontmpD__85);
			eqdestroy___system_u2691(colontmpD__84);
			eqdestroy___system_u2691(colontmpD__83);
			eqdestroy___system_u2691(colontmpD__82);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)67):
	{
		NimStringV2 colontmpD__88;
		NimStringV2 colontmpD__89;
		NimStringV2 colontmpD__90;
		NimStringV2 colontmpD__91;
		NimStringV2 colontmpD__92;
		NimStringV2 colontmpD__93;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T79_;
		colontmpD__88.len = 0; colontmpD__88.p = NIM_NIL;
		colontmpD__89.len = 0; colontmpD__89.p = NIM_NIL;
		colontmpD__90.len = 0; colontmpD__90.p = NIM_NIL;
		colontmpD__91.len = 0; colontmpD__91.p = NIM_NIL;
		colontmpD__92.len = 0; colontmpD__92.p = NIM_NIL;
		colontmpD__93.len = 0; colontmpD__93.p = NIM_NIL;
		colontmpD__88 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		T79_[0] = colontmpD__88;
		colontmpD__89 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		T79_[1] = colontmpD__89;
		colontmpD__90 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		T79_[2] = colontmpD__90;
		colontmpD__91 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		T79_[3] = colontmpD__91;
		colontmpD__92 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		T79_[4] = colontmpD__92;
		colontmpD__93 = percent___cgen_u21590(T79_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__93, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
		{
			LA78_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__93);
			eqdestroy___system_u2691(colontmpD__92);
			eqdestroy___system_u2691(colontmpD__91);
			eqdestroy___system_u2691(colontmpD__90);
			eqdestroy___system_u2691(colontmpD__89);
			eqdestroy___system_u2691(colontmpD__88);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)68):
	{
		NimStringV2 colontmpD__94;
		NimStringV2 colontmpD__95;
		NimStringV2 colontmpD__96;
		NimStringV2 colontmpD__97;
		NimStringV2 colontmpD__98;
		NimStringV2 colontmpD__99;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T84_;
		colontmpD__94.len = 0; colontmpD__94.p = NIM_NIL;
		colontmpD__95.len = 0; colontmpD__95.p = NIM_NIL;
		colontmpD__96.len = 0; colontmpD__96.p = NIM_NIL;
		colontmpD__97.len = 0; colontmpD__97.p = NIM_NIL;
		colontmpD__98.len = 0; colontmpD__98.p = NIM_NIL;
		colontmpD__99.len = 0; colontmpD__99.p = NIM_NIL;
		colontmpD__94 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		T84_[0] = colontmpD__94;
		colontmpD__95 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		T84_[1] = colontmpD__95;
		colontmpD__96 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		T84_[2] = colontmpD__96;
		colontmpD__97 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		T84_[3] = colontmpD__97;
		colontmpD__98 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		T84_[4] = colontmpD__98;
		colontmpD__99 = percent___cgen_u21595(T84_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__99, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
		{
			LA83_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__99);
			eqdestroy___system_u2691(colontmpD__98);
			eqdestroy___system_u2691(colontmpD__97);
			eqdestroy___system_u2691(colontmpD__96);
			eqdestroy___system_u2691(colontmpD__95);
			eqdestroy___system_u2691(colontmpD__94);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)69):
	{
		NimStringV2 colontmpD__100;
		NimStringV2 colontmpD__101;
		NimStringV2 colontmpD__102;
		NimStringV2 colontmpD__103;
		NimStringV2 colontmpD__104;
		NimStringV2 colontmpD__105;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T89_;
		colontmpD__100.len = 0; colontmpD__100.p = NIM_NIL;
		colontmpD__101.len = 0; colontmpD__101.p = NIM_NIL;
		colontmpD__102.len = 0; colontmpD__102.p = NIM_NIL;
		colontmpD__103.len = 0; colontmpD__103.p = NIM_NIL;
		colontmpD__104.len = 0; colontmpD__104.p = NIM_NIL;
		colontmpD__105.len = 0; colontmpD__105.p = NIM_NIL;
		colontmpD__100 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		T89_[0] = colontmpD__100;
		colontmpD__101 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		T89_[1] = colontmpD__101;
		colontmpD__102 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		T89_[2] = colontmpD__102;
		colontmpD__103 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		T89_[3] = colontmpD__103;
		colontmpD__104 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		T89_[4] = colontmpD__104;
		colontmpD__105 = percent___cgen_u21600(T89_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__105, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
		{
			LA88_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__105);
			eqdestroy___system_u2691(colontmpD__104);
			eqdestroy___system_u2691(colontmpD__103);
			eqdestroy___system_u2691(colontmpD__102);
			eqdestroy___system_u2691(colontmpD__101);
			eqdestroy___system_u2691(colontmpD__100);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)70):
	{
		NimStringV2 colontmpD__106;
		NimStringV2 colontmpD__107;
		NimStringV2 colontmpD__108;
		NimStringV2 colontmpD__109;
		NimStringV2 colontmpD__110;
		NimStringV2 colontmpD__111;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T94_;
		colontmpD__106.len = 0; colontmpD__106.p = NIM_NIL;
		colontmpD__107.len = 0; colontmpD__107.p = NIM_NIL;
		colontmpD__108.len = 0; colontmpD__108.p = NIM_NIL;
		colontmpD__109.len = 0; colontmpD__109.p = NIM_NIL;
		colontmpD__110.len = 0; colontmpD__110.p = NIM_NIL;
		colontmpD__111.len = 0; colontmpD__111.p = NIM_NIL;
		colontmpD__106 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		T94_[0] = colontmpD__106;
		colontmpD__107 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		T94_[1] = colontmpD__107;
		colontmpD__108 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		T94_[2] = colontmpD__108;
		colontmpD__109 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		T94_[3] = colontmpD__109;
		colontmpD__110 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		T94_[4] = colontmpD__110;
		colontmpD__111 = percent___cgen_u21605(T94_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__111, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
		{
			LA93_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__111);
			eqdestroy___system_u2691(colontmpD__110);
			eqdestroy___system_u2691(colontmpD__109);
			eqdestroy___system_u2691(colontmpD__108);
			eqdestroy___system_u2691(colontmpD__107);
			eqdestroy___system_u2691(colontmpD__106);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)71):
	{
		NimStringV2 colontmpD__112;
		NimStringV2 colontmpD__113;
		NimStringV2 colontmpD__114;
		NimStringV2 colontmpD__115;
		NimStringV2 colontmpD__116;
		NimStringV2 colontmpD__117;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T99_;
		colontmpD__112.len = 0; colontmpD__112.p = NIM_NIL;
		colontmpD__113.len = 0; colontmpD__113.p = NIM_NIL;
		colontmpD__114.len = 0; colontmpD__114.p = NIM_NIL;
		colontmpD__115.len = 0; colontmpD__115.p = NIM_NIL;
		colontmpD__116.len = 0; colontmpD__116.p = NIM_NIL;
		colontmpD__117.len = 0; colontmpD__117.p = NIM_NIL;
		colontmpD__112 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		T99_[0] = colontmpD__112;
		colontmpD__113 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		T99_[1] = colontmpD__113;
		colontmpD__114 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		T99_[2] = colontmpD__114;
		colontmpD__115 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		T99_[3] = colontmpD__115;
		colontmpD__116 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		T99_[4] = colontmpD__116;
		colontmpD__117 = percent___cgen_u21610(T99_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__117, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
		{
			LA98_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__117);
			eqdestroy___system_u2691(colontmpD__116);
			eqdestroy___system_u2691(colontmpD__115);
			eqdestroy___system_u2691(colontmpD__114);
			eqdestroy___system_u2691(colontmpD__113);
			eqdestroy___system_u2691(colontmpD__112);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)72):
	{
		NimStringV2 colontmpD__118;
		NimStringV2 colontmpD__119;
		NimStringV2 colontmpD__120;
		NimStringV2 colontmpD__121;
		NimStringV2 colontmpD__122;
		NimStringV2 colontmpD__123;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T104_;
		colontmpD__118.len = 0; colontmpD__118.p = NIM_NIL;
		colontmpD__119.len = 0; colontmpD__119.p = NIM_NIL;
		colontmpD__120.len = 0; colontmpD__120.p = NIM_NIL;
		colontmpD__121.len = 0; colontmpD__121.p = NIM_NIL;
		colontmpD__122.len = 0; colontmpD__122.p = NIM_NIL;
		colontmpD__123.len = 0; colontmpD__123.p = NIM_NIL;
		colontmpD__118 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
		T104_[0] = colontmpD__118;
		colontmpD__119 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
		T104_[1] = colontmpD__119;
		colontmpD__120 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
		T104_[2] = colontmpD__120;
		colontmpD__121 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
		T104_[3] = colontmpD__121;
		colontmpD__122 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
		T104_[4] = colontmpD__122;
		colontmpD__123 = percent___cgen_u21615(T104_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__123, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA103_;
		{
			LA103_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__123);
			eqdestroy___system_u2691(colontmpD__122);
			eqdestroy___system_u2691(colontmpD__121);
			eqdestroy___system_u2691(colontmpD__120);
			eqdestroy___system_u2691(colontmpD__119);
			eqdestroy___system_u2691(colontmpD__118);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)73):
	{
		NimStringV2 colontmpD__124;
		NimStringV2 colontmpD__125;
		NimStringV2 colontmpD__126;
		NimStringV2 colontmpD__127;
		NimStringV2 colontmpD__128;
		NimStringV2 colontmpD__129;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T109_;
		colontmpD__124.len = 0; colontmpD__124.p = NIM_NIL;
		colontmpD__125.len = 0; colontmpD__125.p = NIM_NIL;
		colontmpD__126.len = 0; colontmpD__126.p = NIM_NIL;
		colontmpD__127.len = 0; colontmpD__127.p = NIM_NIL;
		colontmpD__128.len = 0; colontmpD__128.p = NIM_NIL;
		colontmpD__129.len = 0; colontmpD__129.p = NIM_NIL;
		colontmpD__124 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
		T109_[0] = colontmpD__124;
		colontmpD__125 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
		T109_[1] = colontmpD__125;
		colontmpD__126 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
		T109_[2] = colontmpD__126;
		colontmpD__127 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
		T109_[3] = colontmpD__127;
		colontmpD__128 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
		T109_[4] = colontmpD__128;
		colontmpD__129 = percent___cgen_u21605(T109_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__129, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
		{
			LA108_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__129);
			eqdestroy___system_u2691(colontmpD__128);
			eqdestroy___system_u2691(colontmpD__127);
			eqdestroy___system_u2691(colontmpD__126);
			eqdestroy___system_u2691(colontmpD__125);
			eqdestroy___system_u2691(colontmpD__124);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)74):
	{
		NimStringV2 colontmpD__130;
		NimStringV2 colontmpD__131;
		NimStringV2 colontmpD__132;
		NimStringV2 colontmpD__133;
		NimStringV2 colontmpD__134;
		NimStringV2 colontmpD__135;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T114_;
		colontmpD__130.len = 0; colontmpD__130.p = NIM_NIL;
		colontmpD__131.len = 0; colontmpD__131.p = NIM_NIL;
		colontmpD__132.len = 0; colontmpD__132.p = NIM_NIL;
		colontmpD__133.len = 0; colontmpD__133.p = NIM_NIL;
		colontmpD__134.len = 0; colontmpD__134.p = NIM_NIL;
		colontmpD__135.len = 0; colontmpD__135.p = NIM_NIL;
		colontmpD__130 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		T114_[0] = colontmpD__130;
		colontmpD__131 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		T114_[1] = colontmpD__131;
		colontmpD__132 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		T114_[2] = colontmpD__132;
		colontmpD__133 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		T114_[3] = colontmpD__133;
		colontmpD__134 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		T114_[4] = colontmpD__134;
		colontmpD__135 = percent___cgen_u21610(T114_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__135, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		{
			LA113_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__135);
			eqdestroy___system_u2691(colontmpD__134);
			eqdestroy___system_u2691(colontmpD__133);
			eqdestroy___system_u2691(colontmpD__132);
			eqdestroy___system_u2691(colontmpD__131);
			eqdestroy___system_u2691(colontmpD__130);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)75):
	{
		NimStringV2 colontmpD__136;
		NimStringV2 colontmpD__137;
		NimStringV2 colontmpD__138;
		NimStringV2 colontmpD__139;
		NimStringV2 colontmpD__140;
		NimStringV2 colontmpD__141;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T119_;
		colontmpD__136.len = 0; colontmpD__136.p = NIM_NIL;
		colontmpD__137.len = 0; colontmpD__137.p = NIM_NIL;
		colontmpD__138.len = 0; colontmpD__138.p = NIM_NIL;
		colontmpD__139.len = 0; colontmpD__139.p = NIM_NIL;
		colontmpD__140.len = 0; colontmpD__140.p = NIM_NIL;
		colontmpD__141.len = 0; colontmpD__141.p = NIM_NIL;
		colontmpD__136 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
		T119_[0] = colontmpD__136;
		colontmpD__137 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
		T119_[1] = colontmpD__137;
		colontmpD__138 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
		T119_[2] = colontmpD__138;
		colontmpD__139 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
		T119_[3] = colontmpD__139;
		colontmpD__140 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
		T119_[4] = colontmpD__140;
		colontmpD__141 = percent___cgen_u21615(T119_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__141, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
		{
			LA118_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__141);
			eqdestroy___system_u2691(colontmpD__140);
			eqdestroy___system_u2691(colontmpD__139);
			eqdestroy___system_u2691(colontmpD__138);
			eqdestroy___system_u2691(colontmpD__137);
			eqdestroy___system_u2691(colontmpD__136);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)76):
	{
		NimStringV2 colontmpD__142;
		NimStringV2 colontmpD__143;
		NimStringV2 colontmpD__144;
		NimStringV2 colontmpD__145;
		NimStringV2 colontmpD__146;
		NimStringV2 colontmpD__147;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T124_;
		colontmpD__142.len = 0; colontmpD__142.p = NIM_NIL;
		colontmpD__143.len = 0; colontmpD__143.p = NIM_NIL;
		colontmpD__144.len = 0; colontmpD__144.p = NIM_NIL;
		colontmpD__145.len = 0; colontmpD__145.p = NIM_NIL;
		colontmpD__146.len = 0; colontmpD__146.p = NIM_NIL;
		colontmpD__147.len = 0; colontmpD__147.p = NIM_NIL;
		colontmpD__142 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
		T124_[0] = colontmpD__142;
		colontmpD__143 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
		T124_[1] = colontmpD__143;
		colontmpD__144 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
		T124_[2] = colontmpD__144;
		colontmpD__145 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
		T124_[3] = colontmpD__145;
		colontmpD__146 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
		T124_[4] = colontmpD__146;
		colontmpD__147 = percent___cgen_u21632(T124_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__147, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
		{
			LA123_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__147);
			eqdestroy___system_u2691(colontmpD__146);
			eqdestroy___system_u2691(colontmpD__145);
			eqdestroy___system_u2691(colontmpD__144);
			eqdestroy___system_u2691(colontmpD__143);
			eqdestroy___system_u2691(colontmpD__142);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)77):
	{
		NimStringV2 colontmpD__148;
		NimStringV2 colontmpD__149;
		NimStringV2 colontmpD__150;
		NimStringV2 colontmpD__151;
		NimStringV2 colontmpD__152;
		NimStringV2 colontmpD__153;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T129_;
		colontmpD__148.len = 0; colontmpD__148.p = NIM_NIL;
		colontmpD__149.len = 0; colontmpD__149.p = NIM_NIL;
		colontmpD__150.len = 0; colontmpD__150.p = NIM_NIL;
		colontmpD__151.len = 0; colontmpD__151.p = NIM_NIL;
		colontmpD__152.len = 0; colontmpD__152.p = NIM_NIL;
		colontmpD__153.len = 0; colontmpD__153.p = NIM_NIL;
		colontmpD__148 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
		T129_[0] = colontmpD__148;
		colontmpD__149 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
		T129_[1] = colontmpD__149;
		colontmpD__150 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
		T129_[2] = colontmpD__150;
		colontmpD__151 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
		T129_[3] = colontmpD__151;
		colontmpD__152 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
		T129_[4] = colontmpD__152;
		colontmpD__153 = percent___cgen_u21637(T129_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__153, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA128_;
		{
			LA128_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__153);
			eqdestroy___system_u2691(colontmpD__152);
			eqdestroy___system_u2691(colontmpD__151);
			eqdestroy___system_u2691(colontmpD__150);
			eqdestroy___system_u2691(colontmpD__149);
			eqdestroy___system_u2691(colontmpD__148);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)78):
	{
		NimStringV2 colontmpD__154;
		NimStringV2 colontmpD__155;
		NimStringV2 colontmpD__156;
		NimStringV2 colontmpD__157;
		NimStringV2 colontmpD__158;
		NimStringV2 colontmpD__159;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T134_;
		colontmpD__154.len = 0; colontmpD__154.p = NIM_NIL;
		colontmpD__155.len = 0; colontmpD__155.p = NIM_NIL;
		colontmpD__156.len = 0; colontmpD__156.p = NIM_NIL;
		colontmpD__157.len = 0; colontmpD__157.p = NIM_NIL;
		colontmpD__158.len = 0; colontmpD__158.p = NIM_NIL;
		colontmpD__159.len = 0; colontmpD__159.p = NIM_NIL;
		colontmpD__154 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
		T134_[0] = colontmpD__154;
		colontmpD__155 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
		T134_[1] = colontmpD__155;
		colontmpD__156 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
		T134_[2] = colontmpD__156;
		colontmpD__157 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
		T134_[3] = colontmpD__157;
		colontmpD__158 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
		T134_[4] = colontmpD__158;
		colontmpD__159 = percent___cgen_u21605(T134_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__159, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA133_;
		{
			LA133_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__159);
			eqdestroy___system_u2691(colontmpD__158);
			eqdestroy___system_u2691(colontmpD__157);
			eqdestroy___system_u2691(colontmpD__156);
			eqdestroy___system_u2691(colontmpD__155);
			eqdestroy___system_u2691(colontmpD__154);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)79):
	{
		NimStringV2 colontmpD__160;
		NimStringV2 colontmpD__161;
		NimStringV2 colontmpD__162;
		NimStringV2 colontmpD__163;
		NimStringV2 colontmpD__164;
		NimStringV2 colontmpD__165;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T139_;
		colontmpD__160.len = 0; colontmpD__160.p = NIM_NIL;
		colontmpD__161.len = 0; colontmpD__161.p = NIM_NIL;
		colontmpD__162.len = 0; colontmpD__162.p = NIM_NIL;
		colontmpD__163.len = 0; colontmpD__163.p = NIM_NIL;
		colontmpD__164.len = 0; colontmpD__164.p = NIM_NIL;
		colontmpD__165.len = 0; colontmpD__165.p = NIM_NIL;
		colontmpD__160 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		T139_[0] = colontmpD__160;
		colontmpD__161 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		T139_[1] = colontmpD__161;
		colontmpD__162 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		T139_[2] = colontmpD__162;
		colontmpD__163 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		T139_[3] = colontmpD__163;
		colontmpD__164 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		T139_[4] = colontmpD__164;
		colontmpD__165 = percent___cgen_u21610(T139_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__165, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
		{
			LA138_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__165);
			eqdestroy___system_u2691(colontmpD__164);
			eqdestroy___system_u2691(colontmpD__163);
			eqdestroy___system_u2691(colontmpD__162);
			eqdestroy___system_u2691(colontmpD__161);
			eqdestroy___system_u2691(colontmpD__160);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)80):
	{
		NimStringV2 colontmpD__166;
		NimStringV2 colontmpD__167;
		NimStringV2 colontmpD__168;
		NimStringV2 colontmpD__169;
		NimStringV2 colontmpD__170;
		NimStringV2 colontmpD__171;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T144_;
		colontmpD__166.len = 0; colontmpD__166.p = NIM_NIL;
		colontmpD__167.len = 0; colontmpD__167.p = NIM_NIL;
		colontmpD__168.len = 0; colontmpD__168.p = NIM_NIL;
		colontmpD__169.len = 0; colontmpD__169.p = NIM_NIL;
		colontmpD__170.len = 0; colontmpD__170.p = NIM_NIL;
		colontmpD__171.len = 0; colontmpD__171.p = NIM_NIL;
		colontmpD__166 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
		T144_[0] = colontmpD__166;
		colontmpD__167 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
		T144_[1] = colontmpD__167;
		colontmpD__168 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
		T144_[2] = colontmpD__168;
		colontmpD__169 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
		T144_[3] = colontmpD__169;
		colontmpD__170 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
		T144_[4] = colontmpD__170;
		colontmpD__171 = percent___cgen_u21615(T144_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__171, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
		{
			LA143_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__171);
			eqdestroy___system_u2691(colontmpD__170);
			eqdestroy___system_u2691(colontmpD__169);
			eqdestroy___system_u2691(colontmpD__168);
			eqdestroy___system_u2691(colontmpD__167);
			eqdestroy___system_u2691(colontmpD__166);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)81):
	{
		NimStringV2 colontmpD__172;
		NimStringV2 colontmpD__173;
		NimStringV2 colontmpD__174;
		NimStringV2 colontmpD__175;
		NimStringV2 colontmpD__176;
		NimStringV2 colontmpD__177;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T149_;
		colontmpD__172.len = 0; colontmpD__172.p = NIM_NIL;
		colontmpD__173.len = 0; colontmpD__173.p = NIM_NIL;
		colontmpD__174.len = 0; colontmpD__174.p = NIM_NIL;
		colontmpD__175.len = 0; colontmpD__175.p = NIM_NIL;
		colontmpD__176.len = 0; colontmpD__176.p = NIM_NIL;
		colontmpD__177.len = 0; colontmpD__177.p = NIM_NIL;
		colontmpD__172 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
		T149_[0] = colontmpD__172;
		colontmpD__173 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
		T149_[1] = colontmpD__173;
		colontmpD__174 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
		T149_[2] = colontmpD__174;
		colontmpD__175 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
		T149_[3] = colontmpD__175;
		colontmpD__176 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
		T149_[4] = colontmpD__176;
		colontmpD__177 = percent___cgen_u21654(T149_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__177, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
		{
			LA148_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__177);
			eqdestroy___system_u2691(colontmpD__176);
			eqdestroy___system_u2691(colontmpD__175);
			eqdestroy___system_u2691(colontmpD__174);
			eqdestroy___system_u2691(colontmpD__173);
			eqdestroy___system_u2691(colontmpD__172);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)82):
	{
		NimStringV2 colontmpD__178;
		NimStringV2 colontmpD__179;
		NimStringV2 colontmpD__180;
		NimStringV2 colontmpD__181;
		NimStringV2 colontmpD__182;
		NimStringV2 colontmpD__183;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T154_;
		colontmpD__178.len = 0; colontmpD__178.p = NIM_NIL;
		colontmpD__179.len = 0; colontmpD__179.p = NIM_NIL;
		colontmpD__180.len = 0; colontmpD__180.p = NIM_NIL;
		colontmpD__181.len = 0; colontmpD__181.p = NIM_NIL;
		colontmpD__182.len = 0; colontmpD__182.p = NIM_NIL;
		colontmpD__183.len = 0; colontmpD__183.p = NIM_NIL;
		colontmpD__178 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
		T154_[0] = colontmpD__178;
		colontmpD__179 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
		T154_[1] = colontmpD__179;
		colontmpD__180 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
		T154_[2] = colontmpD__180;
		colontmpD__181 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
		T154_[3] = colontmpD__181;
		colontmpD__182 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
		T154_[4] = colontmpD__182;
		colontmpD__183 = percent___cgen_u21659(T154_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__183, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
		{
			LA153_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__183);
			eqdestroy___system_u2691(colontmpD__182);
			eqdestroy___system_u2691(colontmpD__181);
			eqdestroy___system_u2691(colontmpD__180);
			eqdestroy___system_u2691(colontmpD__179);
			eqdestroy___system_u2691(colontmpD__178);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)83):
	{
		NimStringV2 colontmpD__184;
		NimStringV2 colontmpD__185;
		NimStringV2 colontmpD__186;
		NimStringV2 colontmpD__187;
		NimStringV2 colontmpD__188;
		NimStringV2 colontmpD__189;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T159_;
		colontmpD__184.len = 0; colontmpD__184.p = NIM_NIL;
		colontmpD__185.len = 0; colontmpD__185.p = NIM_NIL;
		colontmpD__186.len = 0; colontmpD__186.p = NIM_NIL;
		colontmpD__187.len = 0; colontmpD__187.p = NIM_NIL;
		colontmpD__188.len = 0; colontmpD__188.p = NIM_NIL;
		colontmpD__189.len = 0; colontmpD__189.p = NIM_NIL;
		colontmpD__184 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
		T159_[0] = colontmpD__184;
		colontmpD__185 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
		T159_[1] = colontmpD__185;
		colontmpD__186 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
		T159_[2] = colontmpD__186;
		colontmpD__187 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
		T159_[3] = colontmpD__187;
		colontmpD__188 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
		T159_[4] = colontmpD__188;
		colontmpD__189 = percent___cgen_u21664(T159_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__189, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
		{
			LA158_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__189);
			eqdestroy___system_u2691(colontmpD__188);
			eqdestroy___system_u2691(colontmpD__187);
			eqdestroy___system_u2691(colontmpD__186);
			eqdestroy___system_u2691(colontmpD__185);
			eqdestroy___system_u2691(colontmpD__184);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)84):
	{
		NimStringV2 colontmpD__190;
		NimStringV2 colontmpD__191;
		NimStringV2 colontmpD__192;
		NimStringV2 colontmpD__193;
		NimStringV2 colontmpD__194;
		NimStringV2 colontmpD__195;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T164_;
		colontmpD__190.len = 0; colontmpD__190.p = NIM_NIL;
		colontmpD__191.len = 0; colontmpD__191.p = NIM_NIL;
		colontmpD__192.len = 0; colontmpD__192.p = NIM_NIL;
		colontmpD__193.len = 0; colontmpD__193.p = NIM_NIL;
		colontmpD__194.len = 0; colontmpD__194.p = NIM_NIL;
		colontmpD__195.len = 0; colontmpD__195.p = NIM_NIL;
		colontmpD__190 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
		T164_[0] = colontmpD__190;
		colontmpD__191 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
		T164_[1] = colontmpD__191;
		colontmpD__192 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
		T164_[2] = colontmpD__192;
		colontmpD__193 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
		T164_[3] = colontmpD__193;
		colontmpD__194 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
		T164_[4] = colontmpD__194;
		colontmpD__195 = percent___cgen_u21605(T164_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__195, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
		{
			LA163_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__195);
			eqdestroy___system_u2691(colontmpD__194);
			eqdestroy___system_u2691(colontmpD__193);
			eqdestroy___system_u2691(colontmpD__192);
			eqdestroy___system_u2691(colontmpD__191);
			eqdestroy___system_u2691(colontmpD__190);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)85):
	{
		NimStringV2 colontmpD__196;
		NimStringV2 colontmpD__197;
		NimStringV2 colontmpD__198;
		NimStringV2 colontmpD__199;
		NimStringV2 colontmpD__200;
		NimStringV2 colontmpD__201;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T169_;
		colontmpD__196.len = 0; colontmpD__196.p = NIM_NIL;
		colontmpD__197.len = 0; colontmpD__197.p = NIM_NIL;
		colontmpD__198.len = 0; colontmpD__198.p = NIM_NIL;
		colontmpD__199.len = 0; colontmpD__199.p = NIM_NIL;
		colontmpD__200.len = 0; colontmpD__200.p = NIM_NIL;
		colontmpD__201.len = 0; colontmpD__201.p = NIM_NIL;
		colontmpD__196 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
		T169_[0] = colontmpD__196;
		colontmpD__197 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
		T169_[1] = colontmpD__197;
		colontmpD__198 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
		T169_[2] = colontmpD__198;
		colontmpD__199 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
		T169_[3] = colontmpD__199;
		colontmpD__200 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
		T169_[4] = colontmpD__200;
		colontmpD__201 = percent___cgen_u21610(T169_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__201, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
		{
			LA168_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__201);
			eqdestroy___system_u2691(colontmpD__200);
			eqdestroy___system_u2691(colontmpD__199);
			eqdestroy___system_u2691(colontmpD__198);
			eqdestroy___system_u2691(colontmpD__197);
			eqdestroy___system_u2691(colontmpD__196);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)86):
	{
		NimStringV2 colontmpD__202;
		NimStringV2 colontmpD__203;
		NimStringV2 colontmpD__204;
		NimStringV2 colontmpD__205;
		NimStringV2 colontmpD__206;
		NimStringV2 colontmpD__207;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T174_;
		colontmpD__202.len = 0; colontmpD__202.p = NIM_NIL;
		colontmpD__203.len = 0; colontmpD__203.p = NIM_NIL;
		colontmpD__204.len = 0; colontmpD__204.p = NIM_NIL;
		colontmpD__205.len = 0; colontmpD__205.p = NIM_NIL;
		colontmpD__206.len = 0; colontmpD__206.p = NIM_NIL;
		colontmpD__207.len = 0; colontmpD__207.p = NIM_NIL;
		colontmpD__202 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA173_;
		T174_[0] = colontmpD__202;
		colontmpD__203 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA173_;
		T174_[1] = colontmpD__203;
		colontmpD__204 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA173_;
		T174_[2] = colontmpD__204;
		colontmpD__205 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA173_;
		T174_[3] = colontmpD__205;
		colontmpD__206 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA173_;
		T174_[4] = colontmpD__206;
		colontmpD__207 = percent___cgen_u21615(T174_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA173_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__207, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA173_;
		{
			LA173_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__207);
			eqdestroy___system_u2691(colontmpD__206);
			eqdestroy___system_u2691(colontmpD__205);
			eqdestroy___system_u2691(colontmpD__204);
			eqdestroy___system_u2691(colontmpD__203);
			eqdestroy___system_u2691(colontmpD__202);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)87):
	{
		NimStringV2 colontmpD__208;
		NimStringV2 colontmpD__209;
		NimStringV2 colontmpD__210;
		NimStringV2 colontmpD__211;
		NimStringV2 colontmpD__212;
		NimStringV2 colontmpD__213;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T179_;
		colontmpD__208.len = 0; colontmpD__208.p = NIM_NIL;
		colontmpD__209.len = 0; colontmpD__209.p = NIM_NIL;
		colontmpD__210.len = 0; colontmpD__210.p = NIM_NIL;
		colontmpD__211.len = 0; colontmpD__211.p = NIM_NIL;
		colontmpD__212.len = 0; colontmpD__212.p = NIM_NIL;
		colontmpD__213.len = 0; colontmpD__213.p = NIM_NIL;
		colontmpD__208 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
		T179_[0] = colontmpD__208;
		colontmpD__209 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
		T179_[1] = colontmpD__209;
		colontmpD__210 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
		T179_[2] = colontmpD__210;
		colontmpD__211 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
		T179_[3] = colontmpD__211;
		colontmpD__212 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
		T179_[4] = colontmpD__212;
		colontmpD__213 = percent___cgen_u21605(T179_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__213, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
		{
			LA178_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__213);
			eqdestroy___system_u2691(colontmpD__212);
			eqdestroy___system_u2691(colontmpD__211);
			eqdestroy___system_u2691(colontmpD__210);
			eqdestroy___system_u2691(colontmpD__209);
			eqdestroy___system_u2691(colontmpD__208);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)88):
	{
		NimStringV2 colontmpD__214;
		NimStringV2 colontmpD__215;
		NimStringV2 colontmpD__216;
		NimStringV2 colontmpD__217;
		NimStringV2 colontmpD__218;
		NimStringV2 colontmpD__219;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T184_;
		colontmpD__214.len = 0; colontmpD__214.p = NIM_NIL;
		colontmpD__215.len = 0; colontmpD__215.p = NIM_NIL;
		colontmpD__216.len = 0; colontmpD__216.p = NIM_NIL;
		colontmpD__217.len = 0; colontmpD__217.p = NIM_NIL;
		colontmpD__218.len = 0; colontmpD__218.p = NIM_NIL;
		colontmpD__219.len = 0; colontmpD__219.p = NIM_NIL;
		colontmpD__214 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
		T184_[0] = colontmpD__214;
		colontmpD__215 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
		T184_[1] = colontmpD__215;
		colontmpD__216 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
		T184_[2] = colontmpD__216;
		colontmpD__217 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
		T184_[3] = colontmpD__217;
		colontmpD__218 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
		T184_[4] = colontmpD__218;
		colontmpD__219 = percent___cgen_u21610(T184_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__219, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
		{
			LA183_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__219);
			eqdestroy___system_u2691(colontmpD__218);
			eqdestroy___system_u2691(colontmpD__217);
			eqdestroy___system_u2691(colontmpD__216);
			eqdestroy___system_u2691(colontmpD__215);
			eqdestroy___system_u2691(colontmpD__214);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)89):
	{
		NimStringV2 colontmpD__220;
		NimStringV2 colontmpD__221;
		NimStringV2 colontmpD__222;
		NimStringV2 colontmpD__223;
		NimStringV2 colontmpD__224;
		NimStringV2 colontmpD__225;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T189_;
		colontmpD__220.len = 0; colontmpD__220.p = NIM_NIL;
		colontmpD__221.len = 0; colontmpD__221.p = NIM_NIL;
		colontmpD__222.len = 0; colontmpD__222.p = NIM_NIL;
		colontmpD__223.len = 0; colontmpD__223.p = NIM_NIL;
		colontmpD__224.len = 0; colontmpD__224.p = NIM_NIL;
		colontmpD__225.len = 0; colontmpD__225.p = NIM_NIL;
		colontmpD__220 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA188_;
		T189_[0] = colontmpD__220;
		colontmpD__221 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA188_;
		T189_[1] = colontmpD__221;
		colontmpD__222 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA188_;
		T189_[2] = colontmpD__222;
		colontmpD__223 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA188_;
		T189_[3] = colontmpD__223;
		colontmpD__224 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA188_;
		T189_[4] = colontmpD__224;
		colontmpD__225 = percent___cgen_u21615(T189_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA188_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__225, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA188_;
		{
			LA188_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__225);
			eqdestroy___system_u2691(colontmpD__224);
			eqdestroy___system_u2691(colontmpD__223);
			eqdestroy___system_u2691(colontmpD__222);
			eqdestroy___system_u2691(colontmpD__221);
			eqdestroy___system_u2691(colontmpD__220);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)90):
	{
		NimStringV2 colontmpD__226;
		NimStringV2 colontmpD__227;
		NimStringV2 colontmpD__228;
		NimStringV2 colontmpD__229;
		NimStringV2 colontmpD__230;
		NimStringV2 colontmpD__231;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T194_;
		colontmpD__226.len = 0; colontmpD__226.p = NIM_NIL;
		colontmpD__227.len = 0; colontmpD__227.p = NIM_NIL;
		colontmpD__228.len = 0; colontmpD__228.p = NIM_NIL;
		colontmpD__229.len = 0; colontmpD__229.p = NIM_NIL;
		colontmpD__230.len = 0; colontmpD__230.p = NIM_NIL;
		colontmpD__231.len = 0; colontmpD__231.p = NIM_NIL;
		colontmpD__226 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA193_;
		T194_[0] = colontmpD__226;
		colontmpD__227 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA193_;
		T194_[1] = colontmpD__227;
		colontmpD__228 = rope__ropes_u15(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA193_;
		T194_[2] = colontmpD__228;
		colontmpD__229 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA193_;
		T194_[3] = colontmpD__229;
		colontmpD__230 = rope__ropes_u15(k_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA193_;
		T194_[4] = colontmpD__230;
		colontmpD__231 = percent___cgen_u21693(T194_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA193_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__231, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA193_;
		{
			LA193_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__231);
			eqdestroy___system_u2691(colontmpD__230);
			eqdestroy___system_u2691(colontmpD__229);
			eqdestroy___system_u2691(colontmpD__228);
			eqdestroy___system_u2691(colontmpD__227);
			eqdestroy___system_u2691(colontmpD__226);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryFloatArith__cgen_u25512)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3) {
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T3_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T7_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T8_;
		T3_ = 0;
		if (!!(((384 & (*p_p0).options) == T3_))) goto LA4_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T7_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T7_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T8_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T8_, (&b_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1749);
		colontmpD_ = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1751);
		colontmpD__2 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1752);
		cgFormatValue__cgen_u163((&res_1), opr__cgen_u25525[(m_p3)- 53]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1755);
		colontmpD__3 = getSimpleTypeDesc__cgen_u1917((*p_p0).module, (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1756);
		colontmpD__4 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1758);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 res_3;
			NimStringV2* T14_;
			NimStringV2* T15_;
			NimStringV2* T16_;
			NimStringV2* T17_;
			NimStringV2* T18_;
			if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)7)))&31U)))!=0)) goto LA11_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			res_3.len = 0; res_3.p = NIM_NIL;
			T14_ = (NimStringV2*)0;
			T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			addIndent__cgen_u315(p_p0, T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T15_ = (NimStringV2*)0;
			T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1759);
			colontmpD__5 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1761);
			colontmpD__6 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1762);
			colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1764);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1765);
			prepareAdd((&(*T15_)), res_2.len + 0);
appendString((&(*T15_)), res_2);
			T16_ = (NimStringV2*)0;
			T16_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			raiseInstr__cgen_u457(p_p0, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T17_ = (NimStringV2*)0;
			T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			addIndent__cgen_u315(p_p0, T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T18_ = (NimStringV2*)0;
			T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1766);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA21_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1767);
			}
LA21_: ;
			prepareAdd((&(*T18_)), res_3.len + 0);
appendString((&(*T18_)), res_3);
			{
				LA13_:;
			}
			{
				eqdestroy___system_u2691(res_3);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA11_: ;
		{
			NimStringV2 res_4;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 res_5;
			NimStringV2* T30_;
			NimStringV2* T31_;
			NimStringV2* T32_;
			NimStringV2* T33_;
			NimStringV2* T34_;
			if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)8)))&31U)))!=0)) goto LA27_;
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			res_5.len = 0; res_5.p = NIM_NIL;
			T30_ = (NimStringV2*)0;
			T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			addIndent__cgen_u315(p_p0, T30_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T31_ = (NimStringV2*)0;
			T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			res_4 = rawNewString(((NI)80));
			prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1768);
			colontmpD__8 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_4), 11);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1770);
			colontmpD__9 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_4), 8);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1772);
			colontmpD__10 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1774);
			colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1776);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1777);
			colontmpD__12 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1778);
			prepareAdd((&(*T31_)), res_4.len + 0);
appendString((&(*T31_)), res_4);
			T32_ = (NimStringV2*)0;
			T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			raiseInstr__cgen_u457(p_p0, T32_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T33_ = (NimStringV2*)0;
			T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			addIndent__cgen_u315(p_p0, T33_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T34_ = (NimStringV2*)0;
			T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			res_5 = rawNewString(((NI)80));
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1779);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA37_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1780);
			}
LA37_: ;
			prepareAdd((&(*T34_)), res_5.len + 0);
appendString((&(*T34_)), res_5);
			{
				LA29_:;
			}
			{
				eqdestroy___system_u2691(res_5);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(res_4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA27_: ;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u6284(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		binaryArith__cgen_u21495(p_p0, e_p1, d_p2, m_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEqProc__cgen_u21704)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
		colontmpD_ = t__cgen_u97(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__2 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD__2).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9))) goto LA6_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__3 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[0] = colontmpD__3;
		colontmpD__4 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[1] = colontmpD__4;
		colontmpD__5 = percent___cgen_u21728(T9_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__5, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA6_: ;
	{
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T14_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__6 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[0] = colontmpD__6;
		colontmpD__7 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[1] = colontmpD__7;
		colontmpD__8 = percent___cgen_u21605(T14_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__8, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryArithOverflow__cgen_u21248)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	t_1 = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T6_;
		NIM_BOOL T8_;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T13_;
		T6_ = (NIM_BOOL)0;
		T6_ = !((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0));
		if (T6_) goto LA7_;
		T8_ = (NIM_BOOL)0;
		T8_ = (m_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)51) || m_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)52));
		if (!(T8_)) goto LA9_;
		T8_ = ((*t_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*t_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
LA9_: ;
		T6_ = T8_;
LA7_: ;
		if (!T6_) goto LA10_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_[0] = colontmpD_;
		colontmpD__2 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_[1] = colontmpD__2;
		T13_[2] = opr__cgen_u21255[(m_p3)- 46];
		colontmpD__3 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_[3] = colontmpD__3;
		res_1 = percent___cgen_u21285(T13_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA10_: ;
	{
		NIM_BOOL needsOverflowCheck_1;
		needsOverflowCheck_1 = NIM_TRUE;
		{
			NIM_BOOL canBeZero_1;
			if (!(m_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)49) || m_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)50))) goto LA19_;
			canBeZero_1 = NIM_TRUE;
			{
				if (!((*(*e_p1)._kind_6.sons.p->data[((NI)2)]).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6) && (*(*e_p1)._kind_6.sons.p->data[((NI)2)]).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15))) goto LA23_;
				canBeZero_1 = ((*(*e_p1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal == IL64(0));
			}
LA23_: ;
			{
				if (!((*(*e_p1)._kind_6.sons.p->data[((NI)2)]).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6) && (*(*e_p1)._kind_6.sons.p->data[((NI)2)]).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)10))) goto LA27_;
				needsOverflowCheck_1 = ((*(*e_p1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal == IL64(-1));
			}
LA27_: ;
			{
				NimStringV2 res_2;
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				NimStringV2 res_3;
				NimStringV2* T34_;
				NimStringV2* T35_;
				NimStringV2* T36_;
				NimStringV2* T37_;
				NimStringV2* T38_;
				if (!canBeZero_1) goto LA31_;
				res_2.len = 0; res_2.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				res_3.len = 0; res_3.p = NIM_NIL;
				T34_ = (NimStringV2*)0;
				T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				addIndent__cgen_u315(p_p0, T34_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T35_ = (NimStringV2*)0;
				T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				res_2 = rawNewString(((NI)80));
				prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1782);
				colontmpD__4 = rdLoc__cgen_u470(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1784);
				colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1786);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1787);
				prepareAdd((&(*T35_)), res_2.len + 0);
appendString((&(*T35_)), res_2);
				T36_ = (NimStringV2*)0;
				T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				raiseInstr__cgen_u457(p_p0, T36_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T37_ = (NimStringV2*)0;
				T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				addIndent__cgen_u315(p_p0, T37_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T38_ = (NimStringV2*)0;
				T38_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				res_3 = rawNewString(((NI)80));
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1788);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA41_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1789);
				}
LA41_: ;
				prepareAdd((&(*T38_)), res_3.len + 0);
appendString((&(*T38_)), res_3);
				{
					LA33_:;
				}
				{
					eqdestroy___system_u2691(res_3);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(res_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA31_: ;
		}
LA19_: ;
		{
			NimStringV2 res_4;
			NimStringV2 storageX60gensym4365__1;
			NimStringV2 resultX60gensym4365__1;
			NimStringV2 res_5;
			NimStringV2 res_6;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 res_7;
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NI64 sizeX60gensym4365__1;
			NimStringV2 T50_;
			NimStringV2* T56_;
			NimStringV2* T57_;
			NimStringV2* T62_;
			NimStringV2* T63_;
			NimStringV2 T64_;
			NimStringV2* T70_;
			NimStringV2* T71_;
			NimStringV2* T72_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T97_;
			if (!needsOverflowCheck_1) goto LA47_;
			res_4.len = 0; res_4.p = NIM_NIL;
			storageX60gensym4365__1.len = 0; storageX60gensym4365__1.p = NIM_NIL;
			resultX60gensym4365__1.len = 0; resultX60gensym4365__1.p = NIM_NIL;
			res_5.len = 0; res_5.p = NIM_NIL;
			res_6.len = 0; res_6.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			res_7.len = 0; res_7.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			sizeX60gensym4365__1 = getSize__types_u3397((*(*(*p_p0).module).g).config, t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T50_.len = 0; T50_.p = NIM_NIL;
			{
				if (!(sizeX60gensym4365__1 < ((NI64) ((*(*(*(*p_p0).module).g).config).target.intSize)))) goto LA53_;
				storageX60gensym4365__1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1790;
			}
			goto LA51_;
LA53_: ;
			{
				storageX60gensym4365__1 = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			}
LA51_: ;
			resultX60gensym4365__1 = getTempName__cgen_u462((*p_p0).module);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T56_ = (NimStringV2*)0;
			T56_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			addIndent__cgen_u315(p_p0, T56_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T57_ = (NimStringV2*)0;
			T57_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			res_5 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_5), storageX60gensym4365__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1791);
			cgFormatValue__cgen_u163((&res_5), resultX60gensym4365__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1792);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA60_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1793);
			}
LA60_: ;
			prepareAdd((&(*T57_)), res_5.len + 0);
appendString((&(*T57_)), res_5);
			T62_ = (NimStringV2*)0;
			T62_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			addIndent__cgen_u315(p_p0, T62_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T63_ = (NimStringV2*)0;
			T63_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			res_6 = rawNewString(((NI)80));
			prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1794);
			T64_.len = 0; T64_.p = NIM_NIL;
			{
				if (!((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35))) goto LA67_;
				eqcopy___system_u2694((&colontmpD__6), prc64__cgen_u21254[(m_p3)- 46]);
				T64_ = colontmpD__6;
			}
			goto LA65_;
LA67_: ;
			{
				eqcopy___system_u2694((&colontmpD__7), prc__cgen_u21253[(m_p3)- 46]);
				T64_ = colontmpD__7;
			}
LA65_: ;
			colontmpD__8 = cgsymValue__cgen_u141((*p_p0).module, T64_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1805);
			colontmpD__9 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1806);
			colontmpD__10 = rdCharLoc__cgen_u12869(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			prepareAdd((&res_6), 3);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1808);
			cgFormatValue__cgen_u163((&res_6), resultX60gensym4365__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			prepareAdd((&res_6), 5);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1810);
			colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1811);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1812);
			prepareAdd((&(*T63_)), res_6.len + 0);
appendString((&(*T63_)), res_6);
			T70_ = (NimStringV2*)0;
			T70_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			raiseInstr__cgen_u457(p_p0, T70_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T71_ = (NimStringV2*)0;
			T71_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			addIndent__cgen_u315(p_p0, T71_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T72_ = (NimStringV2*)0;
			T72_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			res_7 = rawNewString(((NI)80));
			prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1813);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA75_;
				prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1814);
			}
LA75_: ;
			prepareAdd((&(*T72_)), res_7.len + 0);
appendString((&(*T72_)), res_7);
			{
				NIM_BOOL T79_;
				NimStringV2 firstX60gensym4365__1;
				NimStringV2 lastX60gensym4365__1;
				NimStringV2 res_8;
				NimStringV2 colontmpD__14;
				NimStringV2 res_9;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T84_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T85_;
				NimStringV2* T86_;
				NimStringV2* T87_;
				NimStringV2* T88_;
				NimStringV2* T89_;
				NimStringV2* T90_;
				T79_ = (NIM_BOOL)0;
				T79_ = (sizeX60gensym4365__1 < ((NI64) ((*(*(*(*p_p0).module).g).config).target.intSize)));
				if (T79_) goto LA80_;
				T79_ = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14));
LA80_: ;
				if (!T79_) goto LA81_;
				firstX60gensym4365__1.len = 0; firstX60gensym4365__1.p = NIM_NIL;
				lastX60gensym4365__1.len = 0; lastX60gensym4365__1.p = NIM_NIL;
				res_8.len = 0; res_8.p = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				res_9.len = 0; res_9.p = NIM_NIL;
				firstX60gensym4365__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				T84_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				intLiteral__cgen_u20135(T84_, (&firstX60gensym4365__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				lastX60gensym4365__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				T85_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				intLiteral__cgen_u20135(T85_, (&lastX60gensym4365__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				T86_ = (NimStringV2*)0;
				T86_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				addIndent__cgen_u315(p_p0, T86_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				T87_ = (NimStringV2*)0;
				T87_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				res_8 = rawNewString(((NI)80));
				prepareAdd((&res_8), 4);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1815);
				cgFormatValue__cgen_u163((&res_8), resultX60gensym4365__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				prepareAdd((&res_8), 3);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1816);
				cgFormatValue__cgen_u163((&res_8), firstX60gensym4365__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				prepareAdd((&res_8), 4);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1817);
				cgFormatValue__cgen_u163((&res_8), resultX60gensym4365__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				prepareAdd((&res_8), 3);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1818);
				cgFormatValue__cgen_u163((&res_8), lastX60gensym4365__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				prepareAdd((&res_8), 3);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1819);
				colontmpD__14 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1820);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				cgFormatValue__cgen_u163((&res_8), colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				prepareAdd((&res_8), 4);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1821);
				prepareAdd((&(*T87_)), res_8.len + 0);
appendString((&(*T87_)), res_8);
				T88_ = (NimStringV2*)0;
				T88_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				raiseInstr__cgen_u457(p_p0, T88_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				T89_ = (NimStringV2*)0;
				T89_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				addIndent__cgen_u315(p_p0, T89_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				T90_ = (NimStringV2*)0;
				T90_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				res_9 = rawNewString(((NI)80));
				prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_1822);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA93_;
					prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_1823);
				}
LA93_: ;
				prepareAdd((&(*T90_)), res_9.len + 0);
appendString((&(*T90_)), res_9);
				{
					LA83_:;
				}
				{
					eqdestroy___system_u2691(res_9);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(res_8);
					eqdestroy___system_u2691(lastX60gensym4365__1);
					eqdestroy___system_u2691(firstX60gensym4365__1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			}
LA81_: ;
			res_4 = resultX60gensym4365__1;
			eqwasMoved___system_u2688((&resultX60gensym4365__1));
			colontmpD__12 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T97_[0] = colontmpD__12;
			T97_[1] = res_4;
			colontmpD__13 = percent___cgen_u21403(T97_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__13, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			{
				LA49_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(res_7);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(res_6);
				eqdestroy___system_u2691(res_5);
				eqdestroy___system_u2691(resultX60gensym4365__1);
				eqdestroy___system_u2691(storageX60gensym4365__1);
				eqdestroy___system_u2691(res_4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA45_;
LA47_: ;
		{
			NimStringV2 res_10;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T102_;
			res_10.len = 0; res_10.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			colontmpD__15 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			T102_[0] = colontmpD__15;
			colontmpD__16 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			T102_[1] = colontmpD__16;
			T102_[2] = opr__cgen_u21255[(m_p3)- 46];
			colontmpD__17 = rdLoc__cgen_u470(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			T102_[3] = colontmpD__17;
			res_10 = percent___cgen_u21408(T102_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_10, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			{
				LA101_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(res_10);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA45_: ;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, gcUsage__cgen_u22947)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T6_;
		if (!((*conf_p0).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)1))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T6_ = 0;
		colontmpD_ = renderTree__renderer_u59(n_p1, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		liMessage__msgs_u1227(conf_p0, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)56), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1879, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRepr__cgen_u23976)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T6_;
NIM_BOOL oldNimErrFin48_;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	t_1 = NIM_NIL;
	{
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA4_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*e_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_1825, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1826, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	T6_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T6_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*t_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1828);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1830);
		colontmpD__2 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1831);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_1, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		res_2 = rawNewString(((NI)80));
		colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1833);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1834);
		colontmpD__4 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1835);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_2, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		NimStringV2 res_3;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		res_3.len = 0; res_3.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		res_3 = rawNewString(((NI)80));
		colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1837);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1838);
		colontmpD__6 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1839);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_3, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		{
			LA16_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(res_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		NimStringV2 res_4;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		res_4 = rawNewString(((NI)80));
		colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1841);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1842);
		colontmpD__8 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1843);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_4, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		{
			LA20_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(res_4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)15):
	{
		NimStringV2 res_5;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		res_5.len = 0; res_5.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		res_5 = rawNewString(((NI)80));
		colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1845);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		prepareAdd((&res_5), 5);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1847);
		colontmpD__10 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1848);
		colontmpD__11 = genTypeInfoV1__cgen_u9076((*p_p0).module, t_1, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1849);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_5, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		{
			LA24_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(res_5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		NimStringV2 res_6;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		res_6.len = 0; res_6.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		res_6 = rawNewString(((NI)80));
		colontmpD__12 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1851);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1852);
		colontmpD__13 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1853);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_6, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
		{
			LA28_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(res_6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		NimStringV2 res_7;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		res_7.len = 0; res_7.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		res_7 = rawNewString(((NI)80));
		colontmpD__14 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1855);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1856);
		colontmpD__15 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1857);
		colontmpD__16 = genTypeInfoV1__cgen_u9076((*p_p0).module, t_1, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__16);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1858);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_7, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		{
			LA32_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(res_7);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__17;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__18;
		NimStringV2 res_8;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__21;
		NimStringV2 colontmpD__22;
		nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__17 = NIM_NIL;
		colontmpD__18 = NIM_NIL;
		res_8.len = 0; res_8.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__21 = NIM_NIL;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__17 = t__cgen_u97(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		colontmpD__18 = skipTypes__ast_u5379(colontmpD__17, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		switch ((*colontmpD__18).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
		{
			NimStringV2 colontmpD__23;
			NimStringV2 colontmpD__24;
			tyArray__YgExxhfgKcesA5EOUj1MOA T39_;
			colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
			colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
			colontmpD__23 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			T39_[0] = colontmpD__23;
			colontmpD__24 = percent___cgen_u14585(T39_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			putIntoDest__cgen_u21142(p_p0, (&b_1), e_p1, colontmpD__24, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			{
				LA38_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__24);
				eqdestroy___system_u2691(colontmpD__23);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
		{
			NimStringV2 colontmpD__25;
			NimStringV2 colontmpD__26;
			NimStringV2 colontmpD__27;
			NimStringV2 colontmpD__28;
			NimStringV2 colontmpD__29;
			NimStringV2 colontmpD__30;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T44_;
			colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
			colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
			colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
			colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
			colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			colontmpD__25 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			T44_[0] = colontmpD__25;
			colontmpD__26 = lenExpr__cgen_u495(p_p0, a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			T44_[1] = colontmpD__26;
			colontmpD__27 = dataField__cgen_u516(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			T44_[2] = colontmpD__27;
			colontmpD__28 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			colontmpD__29 = dataFieldAccessor__cgen_u508(p_p0, colontmpD__28);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			T44_[3] = colontmpD__29;
			colontmpD__30 = percent___cgen_u14638(T44_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			putIntoDest__cgen_u21142(p_p0, (&b_1), e_p1, colontmpD__30, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
			{
				LA43_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__30);
				eqdestroy___system_u2691(colontmpD__29);
				eqdestroy___system_u2691(colontmpD__28);
				eqdestroy___system_u2691(colontmpD__27);
				eqdestroy___system_u2691(colontmpD__26);
				eqdestroy___system_u2691(colontmpD__25);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
		{
			NimStringV2 colontmpD__31;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__32;
			NimStringV2 colontmpD__33;
			NimStringV2 colontmpD__34;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T49_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T50_;
			colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
			colontmpD__32 = NIM_NIL;
			colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
			colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
			colontmpD__31 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			T49_[0] = colontmpD__31;
			colontmpD__32 = t__cgen_u97(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			T50_ = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, colontmpD__32);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			colontmpD__33 = rope__cgen_u9217(T50_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			T49_[1] = colontmpD__33;
			colontmpD__34 = percent___cgen_u14643(T49_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			putIntoDest__cgen_u21142(p_p0, (&b_1), e_p1, colontmpD__34, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
			{
				LA48_:;
			}
			{
				oldNimErrFin48_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__34);
				eqdestroy___system_u2691(colontmpD__33);
				eqdestroy___ast_u3378(colontmpD__32);
				if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
				eqdestroy___system_u2691(colontmpD__31);
				*nimErr_ = oldNimErrFin48_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		}
		break;
		default:
		{
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*(*e_p1)._kind_6.sons.p->data[((NI)0)]).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1860, TM__MQdRN7fpbG7rPm4JpVVAhA_1861);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		}
		break;
		}
		res_8 = rawNewString(((NI)80));
		colontmpD__19 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1863);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		cgFormatValue__cgen_u163((&res_8), colontmpD__19);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1864);
		colontmpD__20 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		cgFormatValue__cgen_u163((&res_8), colontmpD__20);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		prepareAdd((&res_8), 2);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1865);
		colontmpD__21 = elemType__types_u254(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		colontmpD__22 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__21, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		cgFormatValue__cgen_u163((&res_8), colontmpD__22);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_1866);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_8, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
		{
			LA36_:;
		}
		{
			oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__22);
			eqdestroy___ast_u3378(colontmpD__21);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(res_8);
			eqdestroy___ast_u3378(colontmpD__18);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__17);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin36_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		NimStringV2 res_9;
		NimStringV2 colontmpD__35;
		NimStringV2 colontmpD__36;
		NimStringV2 colontmpD__37;
		res_9.len = 0; res_9.p = NIM_NIL;
		colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
		colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
		colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
		res_9 = rawNewString(((NI)80));
		colontmpD__35 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1868);
		if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
		cgFormatValue__cgen_u163((&res_9), colontmpD__35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
		prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_1869);
		colontmpD__36 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
		cgFormatValue__cgen_u163((&res_9), colontmpD__36);
		if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
		prepareAdd((&res_9), 2);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_1870);
		colontmpD__37 = genTypeInfoV1__cgen_u9076((*p_p0).module, t_1, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
		cgFormatValue__cgen_u163((&res_9), colontmpD__37);
		if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
		prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_1871);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_9, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
		{
			LA57_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__37);
			eqdestroy___system_u2691(colontmpD__36);
			eqdestroy___system_u2691(colontmpD__35);
			eqdestroy___system_u2691(res_9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)3):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63):
	{
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*e_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_1873, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1874, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 res_10;
		NimStringV2 colontmpD__38;
		NimStringV2 colontmpD__39;
		NimStringV2 colontmpD__40;
		res_10.len = 0; res_10.p = NIM_NIL;
		colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
		colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
		colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
		res_10 = rawNewString(((NI)80));
		colontmpD__38 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1875);
		if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
		cgFormatValue__cgen_u163((&res_10), colontmpD__38);
		if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
		prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_1876);
		colontmpD__39 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
		cgFormatValue__cgen_u163((&res_10), colontmpD__39);
		if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
		prepareAdd((&res_10), 2);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_1877);
		colontmpD__40 = genTypeInfoV1__cgen_u9076((*p_p0).module, t_1, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
		cgFormatValue__cgen_u163((&res_10), colontmpD__40);
		if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
		prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_1878);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_10, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
		{
			LA62_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__40);
			eqdestroy___system_u2691(colontmpD__39);
			eqdestroy___system_u2691(colontmpD__38);
			eqdestroy___system_u2691(res_10);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfo__cgen_u24145)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	cgsym__cgen_u138((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1880);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField;
	colontmpD_ = genTypeInfoV1__cgen_u9076((*p_p0).module, t_1, (*e_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD_, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rdMType__cgen_u24093)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, NimStringV2* nilCheck_p2, NimStringV2* result_p3, NIM_BOOL enforceV1_p4) {
	NimStringV2 derefs_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	derefs_1.len = 0; derefs_1.p = NIM_NIL;
	t_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	derefs_1 = rdLoc__cgen_u470(a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T18_;
			if (!((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22))) goto LA3;
			colontmpD__3 = NIM_NIL;
			{
				if (!!(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47)))) goto LA6_;
				eqcopy___system_u2694((&(*nilCheck_p2)), derefs_1);
			}
LA6_: ;
			{
				NIM_BOOL T10_;
				NIM_BOOL T12_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T16_;
				NimStringV2 T17_;
				T10_ = (NIM_BOOL)0;
				T10_ = !(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47)));
				if (T10_) goto LA11_;
				T12_ = (NIM_BOOL)0;
				T12_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T12_) goto LA13_;
				T12_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA13_: ;
				T10_ = !(T12_);
LA11_: ;
				if (!T10_) goto LA14_;
				T16_[0] = derefs_1;
				T17_.len = 0; T17_.p = NIM_NIL;
				T17_ = percent___cgen_u12921(T16_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T17_); goto LA1_;}
				eqsink___system_u2700((&derefs_1), T17_);
			}
LA14_: ;
			colontmpD__3 = elementType__ast_u5331(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T18_ = NIM_NIL;
			T18_ = skipTypes__ast_u5379(colontmpD__3, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T18_); goto LA1_;}
			eqsink___ast_u3387(&t_1, T18_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA3: ;
	}
	prepareAdd((&(*result_p3)), derefs_1.len + 0);
appendString((&(*result_p3)), derefs_1);
	colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD__2);
	{
		NIM_BOOL T21_;
		T21_ = (NIM_BOOL)0;
		T21_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T21_) goto LA22_;
		T21_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA22_: ;
		if (!!(T21_)) goto LA23_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			colontmpD__4 = NIM_NIL;
			while (1) {
				NIM_BOOL T27_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T29_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T30_;
				T27_ = (NIM_BOOL)0;
				T27_ = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
				if (!(T27_)) goto LA28_;
				T29_ = NIM_NIL;
				T29_ = baseClass__ast_u5348(t_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T29_); goto LA1_;}
				eqsink___ast_u3387(&colontmpD__4, T29_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T27_ = !((colontmpD__4 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA28_: ;
				if (!T27_) goto LA26;
				colontmpD__5 = NIM_NIL;
				prepareAdd((&(*result_p3)), 4);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_1884);
				colontmpD__5 = baseClass__ast_u5348(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T30_ = NIM_NIL;
				T30_ = skipTypes__ast_u5379(colontmpD__5, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T30_); goto LA1_;}
				eqsink___ast_u3387(&t_1, T30_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3378(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA26: ;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
LA23_: ;
	prepareAdd((&(*result_p3)), 7);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_1886);
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0);
		if (!(T33_)) goto LA34_;
		T33_ = enforceV1_p4;
LA34_: ;
		if (!T33_) goto LA35_;
		prepareAdd((&(*result_p3)), 12);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_1888);
	}
LA35_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(derefs_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGetTypeInfoV2__cgen_u24150)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	eqcopy___ast_u3381(&t_1, (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 colontmpD_;
		T4_ = (NIM_BOOL)0;
		T4_ = isFinal__types_u772(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (T4_) goto LA5_;
		T4_ = !(eqStrings((*(*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s, TM__MQdRN7fpbG7rPm4JpVVAhA_1882));
LA5_: ;
		if (!T4_) goto LA6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = genTypeInfoV2__cgen_u10426((*p_p0).module, t_1, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD_, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		NimStringV2 nilCheck_1;
		NimStringV2 rt_1;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T13_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nilCheck_1.len = 0; nilCheck_1.p = NIM_NIL;
		rt_1.len = 0; rt_1.p = NIM_NIL;
		T13_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T13_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		nilCheck_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1883;
		rt_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		rdMType__cgen_u24093(p_p0, a_1, (&nilCheck_1), (&rt_1), NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, rt_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(rt_1);
			eqdestroy___system_u2691(nilCheck_1);
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cowBracket__cgen_u21960)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* strCandidate_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42));
		if (!(T3_)) goto LA4_;
		T3_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
LA4_: ;
		if (!T3_) goto LA5_;
		strCandidate_1 = NIM_NIL;
		colontmpD_ = NIM_NIL;
		eqcopy___ast_u3255(&strCandidate_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
			NimStringV2 res_1;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T13_;
			NimStringV2* T14_;
			NimStringV2* T15_;
			colontmpD_ = skipTypes__ast_u5379((*strCandidate_1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28))) goto LA10_;
			nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T13_ = 0;
			initLocExpr__cgen_u14111(p_p0, strCandidate_1, T13_, (&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			T14_ = (NimStringV2*)0;
			T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			addIndent__cgen_u315(p_p0, T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			T15_ = (NimStringV2*)0;
			T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			res_1 = rawNewString(((NI)80));
			colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1889);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1890);
			colontmpD__3 = byRefLoc__cgen_u12841(p_p0, a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1891);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA18_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1892);
			}
LA18_: ;
			prepareAdd((&(*T15_)), res_1.len + 0);
appendString((&(*T15_)), res_1);
			{
				LA12_:;
			}
			{
				oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_1);
				eqdestroy___ast_u6284(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				*nimErr_ = oldNimErrFin12_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA10_: ;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(strCandidate_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSwap__cgen_u24460)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T4_;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T5_;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	cowBracket__cgen_u21960(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cowBracket__cgen_u21960(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	getTemp__cgen_u9546(p_p0, colontmpD_, NIM_FALSE, (&tmp_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = 0;
	genAssignment__cgen_u12898(p_p0, tmp_1, a_1, T4_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_ = 0;
	genAssignment__cgen_u12898(p_p0, a_1, b_1, T5_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = 0;
	genAssignment__cgen_u12898(p_p0, b_1, tmp_1, T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryStmt__cgen_u21157)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, NimStringV2 op_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T6_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T7_;
	NimStringV2* T8_;
	NimStringV2* T9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	{
		if (!!(((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0)))) goto LA4_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1895, TM__MQdRN7fpbG7rPm4JpVVAhA_1896);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	T6_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T6_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T7_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T7_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_ = (NimStringV2*)0;
	T8_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T8_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T9_ = (NimStringV2*)0;
	T9_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	colontmpD_ = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1897);
	cgFormatValue__cgen_u163((&res_1), op_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1898);
	colontmpD__2 = rdLoc__cgen_u470(b_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1899);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA12_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1900);
	}
LA12_: ;
	prepareAdd((&(*T9_)), res_1.len + 0);
appendString((&(*T9_)), res_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, strLoc__cgen_u22954)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw d_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA3_;
		result = byRefLoc__cgen_u12841(p_p0, d_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = rdLoc__cgen_u470(d_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStrConcat__cgen_u22962)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
	NimStringV2 appends_1;
	NimStringV2 lens_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NI L_1;
NIM_BOOL oldNimErrFin6_;
	NimStringV2* T35_;
	NimStringV2* T36_;
	NimStringV2* T41_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	appends_1.len = 0; appends_1.p = NIM_NIL;
	lens_1.len = 0; lens_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&tmp_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	L_1 = ((NI)0);
	appends_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1926;
	lens_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1927;
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__ast_u3190(e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T3_ - ((NI)1));
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T7_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T8_;
				if (!(i_2 < colontmp_)) goto LA5;
				colontmpD__2 = NIM_NIL;
				i_1 = i_2;
				T7_ = 0;
				nimZeroMem((void*)(&T8_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)1))], T7_, (&T8_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				eqsink___ast_u6293((&a_1), T8_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				{
					NimStringV2 res_2;
					NimStringV2 colontmpD__3;
					NimStringV2 colontmpD__4;
					NimStringV2 colontmpD__5;
					colontmpD__2 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)1))]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					if (!((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2))) goto LA11_;
					res_2.len = 0; res_2.p = NIM_NIL;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					L_1 += ((NI)1);
					res_2 = rawNewString(((NI)80));
					colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1929);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1930);
					colontmpD__4 = strLoc__cgen_u22954(p_p0, tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1931);
					colontmpD__5 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1932);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA16_;
						prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1933);
					}
LA16_: ;
					prepareAdd((&appends_1), res_2.len + 0);
appendString((&appends_1), res_2);
					{
						LA13_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(res_2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				}
				goto LA9_;
LA11_: ;
				{
					NimStringV2 res_3;
					NimStringV2 colontmpD__6;
					NimStringV2 colontmpD__7;
					NimStringV2 colontmpD__8;
					res_3.len = 0; res_3.p = NIM_NIL;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					{
						if (!((*(*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)1))]).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*(*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)1))]).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA24_;
						L_1 += (*(*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)1))])._kind_3.strVal.len;
					}
					goto LA22_;
LA24_: ;
					{
						NimStringV2 colontmpD__9;
						colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
						colontmpD__9 = lenExpr__cgen_u495(p_p0, a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						prepareAdd((&lens_1), colontmpD__9.len + 0);
appendString((&lens_1), colontmpD__9);
						prepareAdd((&lens_1), 3);
appendString((&lens_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1935);
						eqdestroy___system_u2691(colontmpD__9);
					}
LA22_: ;
					res_3 = rawNewString(((NI)80));
					colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1937);
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					cgFormatValue__cgen_u163((&res_3), colontmpD__6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1938);
					colontmpD__7 = strLoc__cgen_u22954(p_p0, tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					cgFormatValue__cgen_u163((&res_3), colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1939);
					colontmpD__8 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					cgFormatValue__cgen_u163((&res_3), colontmpD__8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1940);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA29_;
						prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1941);
					}
LA29_: ;
					prepareAdd((&appends_1), res_3.len + 0);
appendString((&appends_1), res_3);
					{
						LA21_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(res_3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				}
LA9_: ;
				i_2 += ((NI)1);
				{
					LA6_:;
				}
				{
					oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin6_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA5: ;
		}
	}
	T35_ = (NimStringV2*)0;
	T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T35_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T36_ = (NimStringV2*)0;
	T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	cgFormatValue__cgen_u163((&res_1), tmp_1.snippet);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1942);
	colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1944);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1945);
	cgFormatValue__cgen_u163((&res_1), lens_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u166((&res_1), ((NI64) (L_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1946);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA39_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1947);
	}
LA39_: ;
	prepareAdd((&(*T36_)), res_1.len + 0);
appendString((&(*T36_)), res_1);
	T41_ = (NimStringV2*)0;
	T41_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T41_)), appends_1.len + 0);
appendString((&(*T41_)), appends_1);
	{
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA44_;
		eqsink___ast_u6293((&(*d_p2)), tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqwasMoved___ast_u6281((&tmp_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA42_;
LA44_: ;
	{
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T47_;
		T47_ = 0;
		genAssignment__cgen_u12898(p_p0, (*d_p2), tmp_1, T47_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA42_: ;
	gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(lens_1);
		eqdestroy___system_u2691(appends_1);
		eqdestroy___ast_u6284(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, binaryStmtAddr__cgen_u21181)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, NimStringV2 cpname_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T6_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T7_;
	NimStringV2* T8_;
	NimStringV2* T9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	{
		if (!!(((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0)))) goto LA4_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_1949, TM__MQdRN7fpbG7rPm4JpVVAhA_1950);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	T6_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T6_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T7_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T7_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_ = (NimStringV2*)0;
	T8_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T8_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T9_ = (NimStringV2*)0;
	T9_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, cpname_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1951);
	colontmpD__2 = byRefLoc__cgen_u12841(p_p0, a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1952);
	colontmpD__3 = rdLoc__cgen_u470(b_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1953);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA12_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1954);
	}
LA12_: ;
	prepareAdd((&(*T9_)), res_1.len + 0);
appendString((&(*T9_)), res_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStrAppend__cgen_u23037)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw call_1;
	NimStringV2 appends_1;
	NimStringV2 lens_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_1;
	NI L_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin7_;
	NimStringV2* T55_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&call_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	appends_1.len = 0; appends_1.p = NIM_NIL;
	lens_1.len = 0; lens_1.p = NIM_NIL;
	nimZeroMem((void*)(&dest_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	appends_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1962;
	lens_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1963;
	L_1 = ((NI)0);
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&dest_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T4_ - ((NI)2));
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T8_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T9_;
				if (!(i_2 < colontmp_)) goto LA6;
				colontmpD_ = NIM_NIL;
				i_1 = i_2;
				T8_ = 0;
				nimZeroMem((void*)(&T9_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)2))], T8_, (&T9_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				eqsink___ast_u6293((&a_1), T9_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				{
					NimStringV2 res_1;
					NimStringV2 colontmpD__2;
					NimStringV2 colontmpD__3;
					NimStringV2 colontmpD__4;
					colontmpD_ = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)2))]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2))) goto LA12_;
					res_1.len = 0; res_1.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					L_1 += ((NI)1);
					res_1 = rawNewString(((NI)80));
					colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1964);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					cgFormatValue__cgen_u163((&res_1), colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1965);
					colontmpD__3 = strLoc__cgen_u22954(p_p0, dest_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					cgFormatValue__cgen_u163((&res_1), colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1966);
					colontmpD__4 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					cgFormatValue__cgen_u163((&res_1), colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1967);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA17_;
						prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1968);
					}
LA17_: ;
					prepareAdd((&appends_1), res_1.len + 0);
appendString((&appends_1), res_1);
					{
						LA14_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(res_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				}
				goto LA10_;
LA12_: ;
				{
					NimStringV2 res_2;
					NimStringV2 colontmpD__5;
					NimStringV2 colontmpD__6;
					NimStringV2 colontmpD__7;
					res_2.len = 0; res_2.p = NIM_NIL;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					{
						if (!((*(*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)2))]).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*(*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)2))]).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA25_;
						L_1 += (*(*e_p1)._kind_6.sons.p->data[(NI)(i_1 + ((NI)2))])._kind_3.strVal.len;
					}
					goto LA23_;
LA25_: ;
					{
						NimStringV2 colontmpD__8;
						colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
						colontmpD__8 = lenExpr__cgen_u495(p_p0, a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
						prepareAdd((&lens_1), colontmpD__8.len + 0);
appendString((&lens_1), colontmpD__8);
						prepareAdd((&lens_1), 3);
appendString((&lens_1), TM__MQdRN7fpbG7rPm4JpVVAhA_1969);
						eqdestroy___system_u2691(colontmpD__8);
					}
LA23_: ;
					res_2 = rawNewString(((NI)80));
					colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1970);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1971);
					colontmpD__6 = strLoc__cgen_u22954(p_p0, dest_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
					prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1972);
					colontmpD__7 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
					prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1973);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA30_;
						prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1974);
					}
LA30_: ;
					prepareAdd((&appends_1), res_2.len + 0);
appendString((&appends_1), res_2);
					{
						LA22_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___system_u2691(res_2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				}
LA10_: ;
				i_2 += ((NI)1);
				{
					LA7_:;
				}
				{
					oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin7_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA6: ;
		}
	}
	{
		NimStringV2 res_3;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2* T41_;
		NimStringV2* T42_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA38_;
		res_3.len = 0; res_3.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		T41_ = (NimStringV2*)0;
		T41_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		addIndent__cgen_u315(p_p0, T41_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		T42_ = (NimStringV2*)0;
		T42_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		res_3 = rawNewString(((NI)80));
		colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1976);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1977);
		colontmpD__10 = byRefLoc__cgen_u12841(p_p0, dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1978);
		cgFormatValue__cgen_u163((&res_3), lens_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		cgFormatValue__cgen_u166((&res_3), ((NI64) (L_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1979);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA45_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1980);
		}
LA45_: ;
		prepareAdd((&(*T42_)), res_3.len + 0);
appendString((&(*T42_)), res_3);
		{
			LA40_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(res_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA36_;
LA38_: ;
	{
		NimStringV2 res_4;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T51_;
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T52_;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		T51_ = 0;
		initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), e_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T51_, (&call_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		res_4 = rawNewString(((NI)80));
		colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1982);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1983);
		colontmpD__12 = rdLoc__cgen_u470(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1984);
		cgFormatValue__cgen_u163((&res_4), lens_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		cgFormatValue__cgen_u166((&res_4), ((NI64) (L_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1985);
		eqsink___system_u2700((&call_1.snippet), res_4);
		eqwasMoved___system_u2688((&res_4));
		T52_ = 0;
		genAssignment__cgen_u12898(p_p0, dest_1, call_1, T52_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		{
			LA50_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(res_4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA36_: ;
	T55_ = (NimStringV2*)0;
	T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T55_)), appends_1.len + 0);
appendString((&(*T55_)), appends_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(lens_1);
		eqdestroy___system_u2691(appends_1);
		eqdestroy___ast_u6284(call_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCall__cgen_u15586)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	genAsgnCall__cgen_u15561(p_p0, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL), e_p1, d_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, getIntTemp__cgen_u13628)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
	NimStringV2 colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	NimStringV2 res_1;
	NimStringV2 T2_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T3_;
	NimStringV2* T4_;
	NimStringV2* T5_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	(*p_p0).labels += ((NI)1);
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).labels)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + 2);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_2001);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__MQdRN7fpbG7rPm4JpVVAhA_2002);
	(*Result).snippet = T2_;
	(*Result).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1);
	(*Result).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2);
	colontmpD__2 = getSysType__magicsys_u55((*(*(*p_p0).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = NIM_NIL;
	T3_ = lodeTyp__cgen_u104(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T3_); goto LA1_;}
	(*Result).lode = T3_;
	(*Result).flags = 0;
	T4_ = (NimStringV2*)0;
	T4_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T4_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_ = (NimStringV2*)0;
	T5_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2004);
	cgFormatValue__cgen_u163((&res_1), (*Result).snippet);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2005);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA8_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2006);
	}
LA8_: ;
	prepareAdd((&(*T5_)), res_1.len + 0);
appendString((&(*T5_)), res_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqElemAppend__cgen_u23129)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* seqType_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw call_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmpL_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 res_2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T4_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T18_;
	NimStringV2* T19_;
	NimStringV2* T20_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	seqType_1 = NIM_NIL;
	nimZeroMem((void*)(&call_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&dest_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&tmpL_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	res_2.len = 0; res_2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	seqType_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1986);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = 0;
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), e_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T4_, (&call_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T7_;
		NimStringV2 res_3;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T7_) goto LA8_;
		T7_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA8_: ;
		if (!!(T7_)) goto LA9_;
		res_3.len = 0; res_3.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		res_3 = rawNewString(((NI)80));
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1987);
		colontmpD__5 = getTypeDesc__cgen_u8738((*p_p0).module, (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1988);
		colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1990);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_3), 16);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1992);
		colontmpD__7 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1993);
		colontmpD__8 = genTypeInfoV1__cgen_u9076((*p_p0).module, seqType_1, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1994);
		eqsink___system_u2700((&call_1.snippet), res_3);
		eqwasMoved___system_u2688((&res_3));
		{
			LA11_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(res_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA5_;
LA9_: ;
	{
		NimStringV2 res_4;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		res_4 = rawNewString(((NI)80));
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1995);
		colontmpD__9 = getTypeDesc__cgen_u8738((*p_p0).module, (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1996);
		colontmpD__10 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1997);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1998);
		colontmpD__11 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1999);
		colontmpD__12 = genTypeInfoV1__cgen_u9076((*p_p0).module, seqType_1, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2000);
		eqsink___system_u2700((&call_1.snippet), res_4);
		eqwasMoved___system_u2688((&res_4));
		{
			LA15_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(res_4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	genRefAssign__cgen_u13070(p_p0, a_1, call_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T18_ = 0;
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), (*e_p1)._kind_6.sons.p->data[((NI)2)], ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T18_, (&dest_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	getIntTemp__cgen_u13628(p_p0, (&tmpL_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T19_ = (NimStringV2*)0;
	T19_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T19_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T20_ = (NimStringV2*)0;
	T20_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	cgFormatValue__cgen_u163((&res_1), tmpL_1.snippet);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2007);
	colontmpD_ = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2008);
	colontmpD__2 = lenField__cgen_u484(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2010);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA23_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2011);
	}
LA23_: ;
	prepareAdd((&(*T20_)), res_1.len + 0);
appendString((&(*T20_)), res_1);
	res_2 = rawNewString(((NI)80));
	colontmpD__3 = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_2), colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = dataField__cgen_u516(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_2), colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2012);
	cgFormatValue__cgen_u163((&res_2), tmpL_1.snippet);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2013);
	eqsink___system_u2700((&dest_1.snippet), res_2);
	eqwasMoved___system_u2688((&res_2));
	genAssignment__cgen_u12898(p_p0, dest_1, b_1, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(res_2);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(tmpL_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(call_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(seqType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStrEquals__cgen_u25452)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw x_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
NIM_BOOL oldNimErrFin22_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	a_1 = NIM_NIL;
	b_1 = NIM_NIL;
	a_1 = (*e_p1)._kind_6.sons.p->data[((NI)1)];
	eqcopy___ast_u3255(&b_1, (*e_p1)._kind_6.sons.p->data[((NI)2)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T9_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*a_1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*a_1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22));
		if (!(T4_)) goto LA5_;
		T4_ = ((*a_1)._kind_3.strVal.len == 0);
LA5_: ;
		if (!T4_) goto LA6_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T9_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T9_, (&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2014);
		colontmpD_ = lenExpr__cgen_u495(p_p0, x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2016);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		NIM_BOOL T13_;
		NimStringV2 res_2;
		NimStringV2 colontmpD__2;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T18_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*b_1).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*b_1).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22));
		if (!(T13_)) goto LA14_;
		T13_ = ((*b_1)._kind_3.strVal.len == 0);
LA14_: ;
		if (!T13_) goto LA15_;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T18_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T18_, (&x_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2017);
		colontmpD__2 = lenExpr__cgen_u495(p_p0, x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_2), 6);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2018);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		{
			LA17_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA15_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6249__1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym6249__1;
		NimStringV2 res_3;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T23_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T24_;
		nimZeroMem((void*)(&aX60gensym6249__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&bX60gensym6249__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_3.len = 0; res_3.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T23_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T23_, (&aX60gensym6249__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		T24_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T24_, (&bX60gensym6249__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		res_3 = rawNewString(((NI)80));
		colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2020);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2021);
		colontmpD__4 = rdLoc__cgen_u470(aX60gensym6249__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2022);
		colontmpD__5 = rdLoc__cgen_u470(bX60gensym6249__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2023);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_3, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		{
			LA22_:;
		}
		{
			oldNimErrFin22_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(res_3);
			eqdestroy___ast_u6284(bX60gensym6249__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(aX60gensym6249__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin22_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genIsNil__cgen_u21737)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym4549__1;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T9_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
		if (!(T4_)) goto LA5_;
		T4_ = ((*t_1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA5_: ;
		if (!T4_) goto LA6_;
		nimZeroMem((void*)(&aX60gensym4549__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T9_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T9_, (&aX60gensym4549__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2037);
		colontmpD_ = rdLoc__cgen_u470(aX60gensym4549__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 12);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2039);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u6284(aX60gensym4549__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym4556__1;
		NimStringV2 res_2;
		NimStringV2 colontmpD__2;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T14_;
		nimZeroMem((void*)(&aX60gensym4556__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T14_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T14_, (&aX60gensym4556__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2040);
		colontmpD__2 = rdLoc__cgen_u470(aX60gensym4556__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 6);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2041);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(res_2);
			eqdestroy___ast_u6284(aX60gensym4556__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEnumToStr__cgen_u25869)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* toStrProc_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	toStrProc_1 = NIM_NIL;
	n_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2058);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	toStrProc_1 = getToStringProc__modulegraphs_u8679((*(*(*p_p0).module).g).graph, t_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	n_1 = copyTree__ast_u6891(e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = NIM_NIL;
	T2_ = newSymNode__ast_u5168(toStrProc_1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T2_); goto LA1_;}
	eqsink___ast_u3261(&(*n_1)._kind_6.sons.p->data[((NI)0)], T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	expr__cgen_u14084(p_p0, n_1, d_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(toStrProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOfHelper__cgen_u23853)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p1, NimStringV2 a_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, NimStringV2* result_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 token_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T6_;
		NU32 T7_;
		NI16 T8_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA3_;
		token_1.len = 0; token_1.p = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)T6_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
		hashType__sighashes_u411(dest_p1, (*(*(*p_p0).module).g).config, 2, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T7_ = (NU32)0;
		T7_ = genDisplayElem__cgen_u10109(T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		token_1 = dollar___systemZdollars_u49(T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2067);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2068);
		cgFormatValue__cgen_u163((&res_1), a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2070);
		T8_ = (NI16)0;
		T8_ = getObjDepth__cgen_u10096(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		cgFormatValue__cgen_u166((&res_1), ((NI64) (T8_)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2071);
		cgFormatValue__cgen_u163((&res_1), token_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2072);
		prepareAdd((&(*result_p4)), res_1.len + 0);
appendString((&(*result_p4)), res_1);
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			eqdestroy___system_u2691(token_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 ti_1;
		ti_1.len = 0; ti_1.p = NIM_NIL;
		ti_1 = genTypeInfoV1__cgen_u9076((*p_p0).module, dest_p1, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			NIM_BOOL T15_;
			NIM_BOOL T17_;
			NimStringV2 colontmpD__2;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T21_;
			T15_ = (NIM_BOOL)0;
			T15_ = (((*dest_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)2)))&63U)))!=0);
			if (T15_) goto LA16_;
			T17_ = (NIM_BOOL)0;
			T17_ = (((*(*p_p0).module).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)5)))&7U)))!=0);
			if (!(T17_)) goto LA18_;
			T17_ = !((((*dest_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)5)))&63U)))!=0));
LA18_: ;
			T15_ = T17_;
LA16_: ;
			if (!T15_) goto LA19_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T21_[0] = a_p2;
			T21_[1] = ti_1;
			colontmpD__2 = percent___cgen_u23886(T21_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			prepareAdd((&(*result_p4)), colontmpD__2.len + 0);
appendString((&(*result_p4)), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
		}
		goto LA13_;
LA19_: ;
		{
			NimStringV2 cache_1;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 res_2;
			NimStringV2 colontmpD__5;
			NimStringV2 T24_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T25_;
			cache_1.len = 0; cache_1.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			cgsym__cgen_u138((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2073);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			(*(*p_p0).module).labels += ((NI)1);
			T24_.len = 0; T24_.p = NIM_NIL;
			colontmpD__3 = rope__ropes_u15(((NI64) ((*(*p_p0).module).labels)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T24_ = rawNewString(colontmpD__3.len + 17);
appendString((&T24_), TM__MQdRN7fpbG7rPm4JpVVAhA_2075);
appendString((&T24_), colontmpD__3);
			cache_1 = T24_;
			T25_[0] = cache_1;
			colontmpD__4 = percent___cgen_u23897(T25_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__4.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__4);
			res_2 = rawNewString(((NI)80));
			colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2077);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2078);
			cgFormatValue__cgen_u163((&res_2), a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2079);
			cgFormatValue__cgen_u163((&res_2), ti_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2080);
			cgFormatValue__cgen_u163((&res_2), cache_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2081);
			prepareAdd((&(*result_p4)), res_2.len + 0);
appendString((&(*result_p4)), res_2);
			{
				LA23_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(res_2);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(cache_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		}
LA13_: ;
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(ti_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOf__cgen_u23911)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_1;
	NimStringV2 r_1;
	NimStringV2 nilCheck_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 ro_1;
	NimStringV2 ofExpr_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	dest_1 = NIM_NIL;
	r_1.len = 0; r_1.p = NIM_NIL;
	nilCheck_1.len = 0; nilCheck_1.p = NIM_NIL;
	t_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	ro_1.len = 0; ro_1.p = NIM_NIL;
	ofExpr_1.len = 0; ofExpr_1.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, x_p1, T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	dest_1 = skipTypes__ast_u5379(typ_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_436);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	r_1 = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nilCheck_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2059;
	colontmpD_ = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T17_;
			if (!((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22))) goto LA4;
			colontmpD__3 = NIM_NIL;
			{
				if (!!(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47)))) goto LA7_;
				eqcopy___system_u2694((&nilCheck_1), r_1);
			}
LA7_: ;
			{
				NIM_BOOL T11_;
				NIM_BOOL T13_;
				NimStringV2 res_1;
				T11_ = (NIM_BOOL)0;
				T11_ = !(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47)));
				if (T11_) goto LA12_;
				T13_ = (NIM_BOOL)0;
				T13_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T13_) goto LA14_;
				T13_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA14_: ;
				T11_ = !(T13_);
LA12_: ;
				if (!T11_) goto LA15_;
				res_1.len = 0; res_1.p = NIM_NIL;
				res_1 = rawNewString(((NI)80));
				prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2060);
				cgFormatValue__cgen_u163((&res_1), r_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2061);
				eqsink___system_u2700((&r_1), res_1);
			}
LA15_: ;
			colontmpD__3 = elementType__ast_u5331(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T17_ = NIM_NIL;
			T17_ = skipTypes__ast_u5379(colontmpD__3, TM__MQdRN7fpbG7rPm4JpVVAhA_170);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T17_); goto LA1_;}
			eqsink___ast_u3387(&t_1, T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA4: ;
	}
	colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD__2);
	{
		NIM_BOOL T20_;
		T20_ = (NIM_BOOL)0;
		T20_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T20_) goto LA21_;
		T20_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA21_: ;
		if (!!(T20_)) goto LA22_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			colontmpD__4 = NIM_NIL;
			while (1) {
				NIM_BOOL T26_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T28_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T29_;
				T26_ = (NIM_BOOL)0;
				T26_ = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
				if (!(T26_)) goto LA27_;
				T28_ = NIM_NIL;
				T28_ = baseClass__ast_u5348(t_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T28_); goto LA1_;}
				eqsink___ast_u3387(&colontmpD__4, T28_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T26_ = !((colontmpD__4 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA27_: ;
				if (!T26_) goto LA25;
				colontmpD__5 = NIM_NIL;
				prepareAdd((&r_1), 4);
appendString((&r_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2062);
				colontmpD__5 = baseClass__ast_u5348(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T29_ = NIM_NIL;
				T29_ = skipTypes__ast_u5379(colontmpD__5, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T29_); goto LA1_;}
				eqsink___ast_u3387(&t_1, T29_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3378(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA25: ;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
LA22_: ;
	{
		NIM_BOOL T32_;
		T32_ = (NIM_BOOL)0;
		T32_ = isObjLackingTypeField__types_u2952(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T32_) goto LA33_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*x_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2064, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__MQdRN7fpbG7rPm4JpVVAhA_2065, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA33_: ;
	ro_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genOfHelper__cgen_u23853(p_p0, dest_1, r_1, (*x_p1).info, (&ro_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ofExpr_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&ofExpr_1), 1);
appendString((&ofExpr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2082);
	{
		if (!!((nilCheck_1.len == 0))) goto LA37_;
		prepareAdd((&ofExpr_1), 1);
appendString((&ofExpr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2083);
		prepareAdd((&ofExpr_1), nilCheck_1.len + 0);
appendString((&ofExpr_1), nilCheck_1);
		prepareAdd((&ofExpr_1), 6);
appendString((&ofExpr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2085);
		prepareAdd((&ofExpr_1), ro_1.len + 0);
appendString((&ofExpr_1), ro_1);
		prepareAdd((&ofExpr_1), 2);
appendString((&ofExpr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2086);
	}
	goto LA35_;
LA37_: ;
	{
		prepareAdd((&ofExpr_1), ro_1.len + 0);
appendString((&ofExpr_1), ro_1);
		prepareAdd((&ofExpr_1), 1);
appendString((&ofExpr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2087);
	}
LA35_: ;
	putIntoDest__cgen_u21142(p_p0, d_p3, x_p1, ofExpr_1, a_1.storage);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(ofExpr_1);
		eqdestroy___system_u2691(ro_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(nilCheck_1);
		eqdestroy___system_u2691(r_1);
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOf__cgen_u23972)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	genOf__cgen_u23911(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], (*(*n_p1)._kind_6.sons.p->data[((NI)2)]).typField, d_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rawGenNew__cgen_u23197)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p1, NimStringV2 sizeExpr_p2, NIM_BOOL needsInit_p3) {
	NimStringV2 sizeExpr_2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* refType_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* bt_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T3_;
NIM_BOOL oldNimErrFin38_;
NIM_BOOL oldNimErrFin55_;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	sizeExpr_2.len = 0; sizeExpr_2.p = NIM_NIL;
	typ_1 = NIM_NIL;
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	refType_1 = NIM_NIL;
	bt_1 = NIM_NIL;
	eqcopy___system_u2694((&sizeExpr_2), sizeExpr_p2);
	typ_1 = t__cgen_u97((*a_p1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = 0;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), (*a_p1).lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T2_, (&T3_));
	b_1 = T3_;
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	refType_1 = skipTypes__ast_u5379(typ_1, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	bt_1 = elementType__ast_u5331(refType_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
		NimStringV2 T10_;
		if (!(sizeExpr_2.len == 0)) goto LA6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, bt_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[0] = colontmpD_;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = percent___cgen_u23214(T9_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA8_;}
		eqsink___system_u2700((&sizeExpr_2), T10_);
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	{
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T28_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA15_;
		{
			NimStringV2 res_1;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			if (!needsInit_p3) goto LA19_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2088);
			colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, typ_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2089);
			colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2091);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2092);
			cgFormatValue__cgen_u163((&res_1), sizeExpr_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_1), 14);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2094);
			colontmpD__4 = getTypeDesc__cgen_u8738((*p_p0).module, bt_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2095);
			eqsink___system_u2700((&b_1.snippet), res_1);
			eqwasMoved___system_u2688((&res_1));
			{
				LA21_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA17_;
LA19_: ;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2096);
			colontmpD__5 = getTypeDesc__cgen_u8738((*p_p0).module, typ_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2097);
			colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2099);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2100);
			cgFormatValue__cgen_u163((&res_2), sizeExpr_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			prepareAdd((&res_2), 14);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2101);
			colontmpD__7 = getTypeDesc__cgen_u8738((*p_p0).module, bt_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2102);
			eqsink___system_u2700((&b_1.snippet), res_2);
			eqwasMoved___system_u2688((&res_2));
			{
				LA25_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA17_: ;
		T28_ = 0;
		genAssignment__cgen_u12898(p_p0, (*a_p1), b_1, T28_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA13_;
LA15_: ;
	{
		NimStringV2 ti_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
		ti_1.len = 0; ti_1.p = NIM_NIL;
		op_1 = NIM_NIL;
		ti_1 = genTypeInfoV1__cgen_u9076((*p_p0).module, typ_1, (*(*a_p1).lode).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		op_1 = getAttachedOp__modulegraphs_u4987((*(*(*p_p0).module).g).graph, bt_1, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		{
			NIM_BOOL T33_;
			NIM_BOOL T35_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw f_1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T45_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T46_;
			T33_ = (NIM_BOOL)0;
			T33_ = !((op_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
			if (!(T33_)) goto LA34_;
			T35_ = (NIM_BOOL)0;
			T35_ = isTrivialProc__cgen_u10033((*(*(*p_p0).module).g).graph, op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T33_ = !(T35_);
LA34_: ;
			if (!T33_) goto LA36_;
			nimZeroMem((void*)(&f_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__8 = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			{
				NIM_BOOL T41_;
				T41_ = (NIM_BOOL)0;
				T41_ = ((*op_1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
				if (T41_) goto LA42_;
				T41_ = !(((*(*op_1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0)));
LA42_: ;
				if (!T41_) goto LA43_;
				liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*(*a_p1).lode).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2104, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2105, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			}
LA43_: ;
			colontmpD__8 = newSymNode__ast_u5168(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			T45_ = 0;
			initLocExpr__cgen_u14111(p_p0, colontmpD__8, T45_, (&f_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			T46_[0] = ti_1;
			colontmpD__9 = rdLoc__cgen_u470(f_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			T46_[1] = colontmpD__9;
			colontmpD__10 = percent___cgen_u23256(T46_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__10.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__10);
			{
				LA38_:;
			}
			{
				oldNimErrFin38_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___ast_u3252(colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				eqdestroy___ast_u6284(f_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				*nimErr_ = oldNimErrFin38_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
LA36_: ;
		{
			NIM_BOOL T51_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
			T51_ = (NIM_BOOL)0;
			T51_ = ((*a_p1).storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3));
			if (!(T51_)) goto LA52_;
			T51_ = usesWriteBarrier__options_u3582((*(*(*p_p0).module).g).config);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
LA52_: ;
			if (!T51_) goto LA53_;
			colontmpD__11 = NIM_NIL;
			{
				NIM_BOOL T58_;
				NimStringV2 res_3;
				NimStringV2 colontmpD__12;
				NimStringV2 colontmpD__13;
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				NimStringV2* T62_;
				NimStringV2* T63_;
				colontmpD__11 = t__cgen_u97((*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				T58_ = (NIM_BOOL)0;
				T58_ = canFormAcycle__types_u784((*(*(*p_p0).module).g).graph, colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				if (!T58_) goto LA59_;
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				T62_ = (NimStringV2*)0;
				T62_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				addIndent__cgen_u315(p_p0, T62_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				T63_ = (NimStringV2*)0;
				T63_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				res_3 = rawNewString(((NI)80));
				prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2106);
				colontmpD__12 = rdLoc__cgen_u470((*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2107);
				colontmpD__13 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2109);
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2110);
				colontmpD__14 = rdLoc__cgen_u470((*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2111);
				colontmpD__15 = rdLoc__cgen_u470((*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__15);
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
				prepareAdd((&res_3), 13);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2113);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA66_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2114);
				}
LA66_: ;
				prepareAdd((&(*T63_)), res_3.len + 0);
appendString((&(*T63_)), res_3);
				{
					LA61_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(colontmpD__13);
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(res_3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
			}
			goto LA56_;
LA59_: ;
			{
				NimStringV2 res_4;
				NimStringV2 colontmpD__16;
				NimStringV2 colontmpD__17;
				NimStringV2 colontmpD__18;
				NimStringV2 colontmpD__19;
				NimStringV2* T72_;
				NimStringV2* T73_;
				res_4.len = 0; res_4.p = NIM_NIL;
				colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
				colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
				T72_ = (NimStringV2*)0;
				T72_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				addIndent__cgen_u315(p_p0, T72_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				T73_ = (NimStringV2*)0;
				T73_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				res_4 = rawNewString(((NI)80));
				prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2115);
				colontmpD__16 = rdLoc__cgen_u470((*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2116);
				colontmpD__17 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2117);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__17);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2118);
				colontmpD__18 = rdLoc__cgen_u470((*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__18);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2119);
				colontmpD__19 = rdLoc__cgen_u470((*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__19);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				prepareAdd((&res_4), 13);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2120);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA76_;
					prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2121);
				}
LA76_: ;
				prepareAdd((&(*T73_)), res_4.len + 0);
appendString((&(*T73_)), res_4);
				{
					LA71_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__19);
					eqdestroy___system_u2691(colontmpD__18);
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___system_u2691(colontmpD__16);
					eqdestroy___system_u2691(res_4);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
			}
LA56_: ;
			{
				NimStringV2 res_5;
				NimStringV2 colontmpD__20;
				NimStringV2 colontmpD__21;
				NimStringV2 res_6;
				NimStringV2 colontmpD__22;
				NimStringV2 colontmpD__23;
				NimStringV2 colontmpD__24;
				NimStringV2* T85_;
				NimStringV2* T86_;
				if (!((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10))) goto LA82_;
				res_5.len = 0; res_5.p = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				res_6.len = 0; res_6.p = NIM_NIL;
				colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
				colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				res_5 = rawNewString(((NI)80));
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2122);
				colontmpD__20 = getTypeDesc__cgen_u8738((*p_p0).module, typ_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__20);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2123);
				colontmpD__21 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2125);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__21);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2126);
				cgFormatValue__cgen_u163((&res_5), ti_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2127);
				cgFormatValue__cgen_u163((&res_5), sizeExpr_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2128);
				eqsink___system_u2700((&b_1.snippet), res_5);
				eqwasMoved___system_u2688((&res_5));
				T85_ = (NimStringV2*)0;
				T85_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				addIndent__cgen_u315(p_p0, T85_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				T86_ = (NimStringV2*)0;
				T86_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				res_6 = rawNewString(((NI)80));
				colontmpD__22 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2129);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__22);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				prepareAdd((&res_6), 10);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2130);
				colontmpD__23 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, (*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__23);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2131);
				colontmpD__24 = rdLoc__cgen_u470(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__24);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2132);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA89_;
					prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2133);
				}
LA89_: ;
				prepareAdd((&(*T86_)), res_6.len + 0);
appendString((&(*T86_)), res_6);
				{
					LA84_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__24);
					eqdestroy___system_u2691(colontmpD__23);
					eqdestroy___system_u2691(colontmpD__22);
					eqdestroy___system_u2691(res_6);
					eqdestroy___system_u2691(colontmpD__21);
					eqdestroy___system_u2691(colontmpD__20);
					eqdestroy___system_u2691(res_5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
			}
			goto LA80_;
LA82_: ;
			{
				NimStringV2 res_7;
				NimStringV2 colontmpD__25;
				NimStringV2 colontmpD__26;
				NimStringV2 res_8;
				NimStringV2 colontmpD__27;
				NimStringV2 colontmpD__28;
				NimStringV2* T95_;
				NimStringV2* T96_;
				res_7.len = 0; res_7.p = NIM_NIL;
				colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
				colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
				res_8.len = 0; res_8.p = NIM_NIL;
				colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
				colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
				res_7 = rawNewString(((NI)80));
				prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2134);
				colontmpD__25 = getTypeDesc__cgen_u8738((*p_p0).module, typ_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				cgFormatValue__cgen_u163((&res_7), colontmpD__25);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2135);
				colontmpD__26 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2137);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				cgFormatValue__cgen_u163((&res_7), colontmpD__26);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2138);
				cgFormatValue__cgen_u163((&res_7), ti_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2139);
				cgFormatValue__cgen_u163((&res_7), sizeExpr_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2140);
				eqsink___system_u2700((&b_1.snippet), res_7);
				eqwasMoved___system_u2688((&res_7));
				T95_ = (NimStringV2*)0;
				T95_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				addIndent__cgen_u315(p_p0, T95_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				T96_ = (NimStringV2*)0;
				T96_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				res_8 = rawNewString(((NI)80));
				colontmpD__27 = rdLoc__cgen_u470((*a_p1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				cgFormatValue__cgen_u163((&res_8), colontmpD__27);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				prepareAdd((&res_8), 3);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2141);
				colontmpD__28 = rdLoc__cgen_u470(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				cgFormatValue__cgen_u163((&res_8), colontmpD__28);
				if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
				prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2142);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA99_;
					prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2143);
				}
LA99_: ;
				prepareAdd((&(*T96_)), res_8.len + 0);
appendString((&(*T96_)), res_8);
				{
					LA94_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__28);
					eqdestroy___system_u2691(colontmpD__27);
					eqdestroy___system_u2691(res_8);
					eqdestroy___system_u2691(colontmpD__26);
					eqdestroy___system_u2691(colontmpD__25);
					eqdestroy___system_u2691(res_7);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
			}
LA80_: ;
			{
				LA55_:;
			}
			{
				oldNimErrFin55_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				*nimErr_ = oldNimErrFin55_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
		goto LA49_;
LA53_: ;
		{
			NimStringV2 res_9;
			NimStringV2 colontmpD__29;
			NimStringV2 colontmpD__30;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T107_;
			res_9.len = 0; res_9.p = NIM_NIL;
			colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			res_9 = rawNewString(((NI)80));
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2144);
			colontmpD__29 = getTypeDesc__cgen_u8738((*p_p0).module, typ_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			cgFormatValue__cgen_u163((&res_9), colontmpD__29);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			prepareAdd((&res_9), 2);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2145);
			colontmpD__30 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2146);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			cgFormatValue__cgen_u163((&res_9), colontmpD__30);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2147);
			cgFormatValue__cgen_u163((&res_9), ti_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			prepareAdd((&res_9), 2);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2148);
			cgFormatValue__cgen_u163((&res_9), sizeExpr_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2149);
			eqsink___system_u2700((&b_1.snippet), res_9);
			eqwasMoved___system_u2688((&res_9));
			T107_ = 0;
			genAssignment__cgen_u12898(p_p0, (*a_p1), b_1, T107_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			{
				LA106_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__30);
				eqdestroy___system_u2691(colontmpD__29);
				eqdestroy___system_u2691(res_9);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		}
LA49_: ;
		{
			LA30_:;
		}
		{
			oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(ti_1);
			*nimErr_ = oldNimErrFin30_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	genObjectInit__cgen_u12909(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2), bt_1, a_p1, ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(bt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(refType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(sizeExpr_2);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNew__cgen_u23348)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T5_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw se_1;
		NimStringV2 colontmpD_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T9_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T5_ == ((NI)3))) goto LA6_;
		nimZeroMem((void*)(&se_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T9_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T9_, (&se_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		colontmpD_ = rdLoc__cgen_u470(se_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		rawGenNew__cgen_u23197(p_p0, (&a_1), colontmpD_, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u6284(se_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA6_: ;
	{
		rawGenNew__cgen_u23197(p_p0, (&a_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2150, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genTypeInfo__cgen_u12748)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!(((*config_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA3_;
		result = genTypeInfoV2__cgen_u10426(m_p1, t_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = genTypeInfoV1__cgen_u9076(m_p1, t_p2, info_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewFinalize__cgen_u23831)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* refType_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* bt_1;
	NimStringV2 ti_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw f_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 res_1;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
	NimStringV2 colontmpD__7;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T4_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T5_;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	refType_1 = NIM_NIL;
	bt_1 = NIM_NIL;
	ti_1.len = 0; ti_1.p = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&f_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5 = NIM_NIL;
	colontmpD__6 = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8 = NIM_NIL;
	refType_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T3_, (&f_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = 0;
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), a_1.lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T4_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ti_1 = genTypeInfo__cgen_u12748((*(*(*p_p0).module).g).config, (*p_p0).module, refType_1, (*e_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_[0] = ti_1;
	colontmpD_ = rdLoc__cgen_u470(f_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_[1] = colontmpD_;
	colontmpD__2 = percent___cgen_u23256(T5_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__2.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)14))- 0]), colontmpD__2);
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2152);
	colontmpD__3 = getTypeDesc__cgen_u8738((*p_p0).module, refType_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2153);
	colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2154);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2155);
	cgFormatValue__cgen_u163((&res_1), ti_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2156);
	colontmpD__5 = elementType__ast_u5331(refType_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = skipTypes__ast_u5379(colontmpD__5, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__7 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__6, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__7);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2157);
	eqsink___system_u2700((&b_1.snippet), res_1);
	eqwasMoved___system_u2688((&res_1));
	T6_ = 0;
	genAssignment__cgen_u12898(p_p0, a_1, b_1, T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__8 = elementType__ast_u5331(refType_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	bt_1 = skipTypes__ast_u5379(colontmpD__8, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genObjectInit__cgen_u12909(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2), bt_1, (&a_1), ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___ast_u3378(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u6284(f_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(ti_1);
		eqdestroy___ast_u3378(bt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(refType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqAux__cgen_u23353)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, NimStringV2 length_p2, NIM_BOOL lenIsZero_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* seqtype_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw call_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	seqtype_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&call_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = t__cgen_u97(dest_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	seqtype_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = 0;
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), dest_p1.lode, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T2_, (&call_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		T5_ = (NIM_BOOL)0;
		T5_ = (dest_p1.storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3));
		if (!(T5_)) goto LA6_;
		T5_ = usesWriteBarrier__options_u3582((*(*(*p_p0).module).g).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA6_: ;
		if (!T5_) goto LA7_;
		colontmpD__2 = NIM_NIL;
		{
			NIM_BOOL T12_;
			NimStringV2 res_1;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2* T16_;
			NimStringV2* T17_;
			colontmpD__2 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			T12_ = (NIM_BOOL)0;
			T12_ = canFormAcycle__types_u784((*(*(*p_p0).module).g).graph, colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			if (!T12_) goto LA13_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			T16_ = (NimStringV2*)0;
			T16_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			addIndent__cgen_u315(p_p0, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T17_ = (NimStringV2*)0;
			T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2172);
			colontmpD__3 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2173);
			colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2174);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2175);
			colontmpD__5 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2176);
			colontmpD__6 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 13);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2177);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA20_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2178);
			}
LA20_: ;
			prepareAdd((&(*T17_)), res_1.len + 0);
appendString((&(*T17_)), res_1);
			{
				LA15_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA10_;
LA13_: ;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2* T26_;
			NimStringV2* T27_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T26_ = (NimStringV2*)0;
			T26_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			addIndent__cgen_u315(p_p0, T26_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			T27_ = (NimStringV2*)0;
			T27_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2179);
			colontmpD__7 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2180);
			colontmpD__8 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2181);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2182);
			colontmpD__9 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2183);
			colontmpD__10 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
			prepareAdd((&res_2), 13);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2184);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA30_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2185);
			}
LA30_: ;
			prepareAdd((&(*T27_)), res_2.len + 0);
appendString((&(*T27_)), res_2);
			{
				LA25_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA10_: ;
		{
			if (!!(lenIsZero_p3)) goto LA36_;
			{
				NimStringV2 res_3;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				NimStringV2 colontmpD__13;
				NimStringV2 res_4;
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				NimStringV2 colontmpD__16;
				NimStringV2* T43_;
				NimStringV2* T44_;
				if (!((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)10))) goto LA40_;
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				res_4.len = 0; res_4.p = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
				res_3 = rawNewString(((NI)80));
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2186);
				colontmpD__11 = getTypeDesc__cgen_u8738((*p_p0).module, seqtype_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2187);
				colontmpD__12 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2189);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2190);
				colontmpD__13 = genTypeInfoV1__cgen_u9076((*p_p0).module, seqtype_1, (*dest_p1.lode).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2191);
				cgFormatValue__cgen_u163((&res_3), length_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2192);
				eqsink___system_u2700((&call_1.snippet), res_3);
				eqwasMoved___system_u2688((&res_3));
				T43_ = (NimStringV2*)0;
				T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				addIndent__cgen_u315(p_p0, T43_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				T44_ = (NimStringV2*)0;
				T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				res_4 = rawNewString(((NI)80));
				colontmpD__14 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2193);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_4), 10);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2194);
				colontmpD__15 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__15);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2195);
				colontmpD__16 = rdLoc__cgen_u470(call_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2196);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA47_;
					prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2197);
				}
LA47_: ;
				prepareAdd((&(*T44_)), res_4.len + 0);
appendString((&(*T44_)), res_4);
				{
					LA42_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__16);
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(res_4);
					eqdestroy___system_u2691(colontmpD__13);
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(res_3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
			goto LA38_;
LA40_: ;
			{
				NimStringV2 res_5;
				NimStringV2 colontmpD__17;
				NimStringV2 colontmpD__18;
				NimStringV2 colontmpD__19;
				NimStringV2 res_6;
				NimStringV2 colontmpD__20;
				NimStringV2 colontmpD__21;
				NimStringV2* T53_;
				NimStringV2* T54_;
				res_5.len = 0; res_5.p = NIM_NIL;
				colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
				res_6.len = 0; res_6.p = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				res_5 = rawNewString(((NI)80));
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2198);
				colontmpD__17 = getTypeDesc__cgen_u8738((*p_p0).module, seqtype_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__17);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2199);
				colontmpD__18 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2201);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__18);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2202);
				colontmpD__19 = genTypeInfoV1__cgen_u9076((*p_p0).module, seqtype_1, (*dest_p1.lode).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__19);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2203);
				cgFormatValue__cgen_u163((&res_5), length_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2204);
				eqsink___system_u2700((&call_1.snippet), res_5);
				eqwasMoved___system_u2688((&res_5));
				T53_ = (NimStringV2*)0;
				T53_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				addIndent__cgen_u315(p_p0, T53_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				T54_ = (NimStringV2*)0;
				T54_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				res_6 = rawNewString(((NI)80));
				colontmpD__20 = rdLoc__cgen_u470(dest_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__20);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				prepareAdd((&res_6), 3);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2205);
				colontmpD__21 = rdLoc__cgen_u470(call_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				cgFormatValue__cgen_u163((&res_6), colontmpD__21);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2206);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA57_;
					prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2207);
				}
LA57_: ;
				prepareAdd((&(*T54_)), res_6.len + 0);
appendString((&(*T54_)), res_6);
				{
					LA52_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__21);
					eqdestroy___system_u2691(colontmpD__20);
					eqdestroy___system_u2691(res_6);
					eqdestroy___system_u2691(colontmpD__19);
					eqdestroy___system_u2691(colontmpD__18);
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___system_u2691(res_5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
			}
LA38_: ;
		}
LA36_: ;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA7_: ;
	{
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T72_;
		{
			if (!lenIsZero_p3) goto LA66_;
			eqsink___system_u2700((&call_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_2208);
		}
		goto LA64_;
LA66_: ;
		{
			NimStringV2 res_7;
			NimStringV2 colontmpD__22;
			NimStringV2 colontmpD__23;
			NimStringV2 colontmpD__24;
			res_7.len = 0; res_7.p = NIM_NIL;
			colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
			colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
			colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
			res_7 = rawNewString(((NI)80));
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2209);
			colontmpD__22 = getTypeDesc__cgen_u8738((*p_p0).module, seqtype_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__22);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2210);
			colontmpD__23 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2211);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__23);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2212);
			colontmpD__24 = genTypeInfoV1__cgen_u9076((*p_p0).module, seqtype_1, (*dest_p1.lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__24);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2213);
			cgFormatValue__cgen_u163((&res_7), length_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2214);
			eqsink___system_u2700((&call_1.snippet), res_7);
			eqwasMoved___system_u2688((&res_7));
			{
				LA69_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__24);
				eqdestroy___system_u2691(colontmpD__23);
				eqdestroy___system_u2691(colontmpD__22);
				eqdestroy___system_u2691(res_7);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA64_: ;
		T72_ = 0;
		genAssignment__cgen_u12898(p_p0, dest_p1, call_1, T72_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(call_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeq__cgen_u23447)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* seqtype_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
		NimStringV2 colontmpD__8;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2* T9_;
		NimStringV2* T10_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA6_;
		seqtype_1 = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9 = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		seqtype_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_ = (NimStringV2*)0;
		T9_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		addIndent__cgen_u315(p_p0, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T10_ = (NimStringV2*)0;
		T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2159);
		colontmpD__2 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2160);
		colontmpD__3 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2162);
		colontmpD__4 = getSeqPayloadType__cgen_u3522((*p_p0).module, seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2163);
		colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2165);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2166);
		colontmpD__6 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2167);
		colontmpD__7 = elementType__ast_u5331(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		colontmpD__8 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__7, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 15);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2169);
		colontmpD__9 = elementType__ast_u5331(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		colontmpD__10 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__9, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2170);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA13_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2171);
		}
LA13_: ;
		prepareAdd((&(*T10_)), res_1.len + 0);
appendString((&(*T10_)), res_1);
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___ast_u3378(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u3378(seqtype_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA6_: ;
	{
		NimStringV2 colontmpD__11;
		NIM_BOOL lenIsZero_1;
		NIM_BOOL T19_;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		T19_ = (NIM_BOOL)0;
		T19_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
		if (!(T19_)) goto LA20_;
		T19_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)2)])._kind_1.intVal == IL64(0));
LA20_: ;
		lenIsZero_1 = T19_;
		colontmpD__11 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		genNewSeqAux__cgen_u23353(p_p0, a_1, colontmpD__11, lenIsZero_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		{
			LA18_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genNewSeqOfCap__cgen_u23475)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* seqtype_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	seqtype_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	seqtype_1 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
		NimStringV2 colontmpD__7;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2* T13_;
		NimStringV2* T14_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA5_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6 = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8 = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T12_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA10_;
			nimZeroMem((void*)(&T12_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&T12_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqsink___ast_u6293((&(*d_p2)), T12_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA10_: ;
		T13_ = (NimStringV2*)0;
		T13_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		addIndent__cgen_u315(p_p0, T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T14_ = (NimStringV2*)0;
		T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = rdLoc__cgen_u470((*d_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2215);
		colontmpD__2 = rdLoc__cgen_u470((*d_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2216);
		colontmpD__3 = getSeqPayloadType__cgen_u3522((*p_p0).module, seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2217);
		colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2219);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2220);
		colontmpD__5 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2221);
		colontmpD__6 = elementType__ast_u5331(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__7 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__6, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 15);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2222);
		colontmpD__8 = elementType__ast_u5331(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__9 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__8, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2223);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA17_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2224);
		}
LA17_: ;
		prepareAdd((&(*T14_)), res_1.len + 0);
appendString((&(*T14_)), res_1);
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___ast_u3378(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___ast_u3378(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T27_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA25_;
			nimZeroMem((void*)(&T27_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&T27_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			eqsink___ast_u6293((&(*d_p2)), T27_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		}
LA25_: ;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2225);
		colontmpD__10 = getTypeDesc__cgen_u8738((*p_p0).module, seqtype_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2226);
		colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2228);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2229);
		colontmpD__12 = genTypeInfoV1__cgen_u9076((*p_p0).module, seqtype_1, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2230);
		colontmpD__13 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2231);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		{
			LA22_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSomeCast__cgen_u25144)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* etyp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srcTyp_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin66_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	etyp_1 = NIM_NIL;
	srcTyp_1 = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	etyp_1 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2058);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	srcTyp_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T10_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49));
		if (!(T5_)) goto LA6_;
		T5_ = !(((a_1.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0)))&15U)))!=0));
LA6_: ;
		if (!T5_) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T10_[0] = colontmpD_;
		colontmpD__2 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T10_[1] = colontmpD__2;
		colontmpD__3 = percent___cgen_u25164(T10_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__3, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA7_: ;
	{
		NIM_BOOL T14_;
		NIM_BOOL T15_;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T21_;
		T14_ = (NIM_BOOL)0;
		T15_ = (NIM_BOOL)0;
		T15_ = ((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
		if (!(T15_)) goto LA16_;
		T15_ = ((*etyp_1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA16_: ;
		T14_ = T15_;
		if (!(T14_)) goto LA17_;
		T14_ = !(((*srcTyp_1).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9)));
LA17_: ;
		if (!T14_) goto LA18_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__4 = getClosureType__cgen_u8751((*p_p0).module, etyp_1, ((tyEnum_TClosureTypeKind__sY8uWROOfudsYU84nI5xdg)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		T21_[0] = colontmpD__4;
		colontmpD__5 = rdCharLoc__cgen_u12869(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		T21_[1] = colontmpD__5;
		colontmpD__6 = percent___cgen_u14793(T21_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__6, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		{
			LA20_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA18_: ;
	{
		{
			NIM_BOOL T27_;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T32_;
			T27_ = (NIM_BOOL)0;
			T27_ = ((*srcTyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*srcTyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26));
			if (!(T27_)) goto LA28_;
			T27_ = ((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14) || (*etyp_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) && (*etyp_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*etyp_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*etyp_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39) || (*etyp_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*etyp_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
LA28_: ;
			if (!T27_) goto LA29_;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__7 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			T32_[0] = colontmpD__7;
			colontmpD__8 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			T32_[1] = colontmpD__8;
			colontmpD__9 = percent___cgen_u25193(T32_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__9, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
			{
				LA31_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA25_;
LA29_: ;
		{
			NIM_BOOL T36_;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T41_;
			T36_ = (NIM_BOOL)0;
			T36_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
			if (!(T36_)) goto LA37_;
			T36_ = ((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24) || (*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28));
LA37_: ;
			if (!T36_) goto LA38_;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__10 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			T41_[0] = colontmpD__10;
			colontmpD__11 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			T41_[1] = colontmpD__11;
			colontmpD__12 = percent___cgen_u25206(T41_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__12, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			{
				LA40_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA25_;
LA38_: ;
		{
			NIM_BOOL T45_;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			tyArray__YgExxhfgKcesA5EOUj1MOA T50_;
			T45_ = (NIM_BOOL)0;
			T45_ = ((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1));
			if (!(T45_)) goto LA46_;
			T45_ = ((*srcTyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1) || (*srcTyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2) || (*srcTyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14) || (*srcTyp_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) && (*srcTyp_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35) || (*srcTyp_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*srcTyp_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39) || (*srcTyp_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*srcTyp_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
LA46_: ;
			if (!T45_) goto LA47_;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__13 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T50_[0] = colontmpD__13;
			colontmpD__14 = percent___cgen_u25219(T50_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__14, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			{
				LA49_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA25_;
LA47_: ;
		{
			NIM_BOOL T54_;
			NIM_BOOL T55_;
			T54_ = (NIM_BOOL)0;
			T55_ = (NIM_BOOL)0;
			T55_ = ((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
			if (!(T55_)) goto LA56_;
			T55_ = ((*srcTyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA56_: ;
			T54_ = T55_;
			if (!(T54_)) goto LA57_;
			T54_ = sameBackendType__types_u637(etyp_1, srcTyp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA57_: ;
			if (!T54_) goto LA58_;
			expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA25_;
LA58_: ;
		{
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T76_;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* internalType_1;
				if (!((*etyp_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA64_;
				internalType_1 = NIM_NIL;
				internalType_1 = skipTypes__ast_u5379(etyp_1, TM__MQdRN7fpbG7rPm4JpVVAhA_2237);
				if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				{
					NimStringV2 colontmpD__18;
					if (!((*internalType_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17))) goto LA69_;
					colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
					colontmpD__18 = getTypeDesc__cgen_u8738((*p_p0).module, internalType_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
					(void)(colontmpD__18);
					{
						LA71_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__18);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
				}
LA69_: ;
				{
					LA66_:;
				}
				{
					oldNimErrFin66_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(internalType_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
					*nimErr_ = oldNimErrFin66_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			}
LA64_: ;
			colontmpD__15 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			T76_[0] = colontmpD__15;
			colontmpD__16 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			T76_[1] = colontmpD__16;
			colontmpD__17 = percent___cgen_u14793(T76_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__17, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			{
				LA61_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA25_: ;
	}
LA3_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(srcTyp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(etyp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOrd__cgen_u25129)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6098__1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&aX60gensym6098__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&aX60gensym6098__1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	colontmpD_ = rdCharLoc__cgen_u12869(aX60gensym6098__1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(aX60gensym6098__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayLen__cgen_u24171)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
NIM_BOOL oldNimErrFin23_;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin49_;
NIM_BOOL oldNimErrFin54_;
NIM_BOOL oldNimErrFin67_;
NIM_BOOL oldNimErrFin72_;
NIM_BOOL oldNimErrFin81_;
NIM_BOOL oldNimErrFin86_;
NIM_BOOL oldNimErrFin95_;
NIM_BOOL oldNimErrFin100_;
NIM_BOOL oldNimErrFin105_;
NIM_BOOL oldNimErrFin116_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	a_1 = NIM_NIL;
	typ_1 = NIM_NIL;
	eqcopy___ast_u3255(&a_1, (*e_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA4_;
		eqcopy___ast_u3255(&a_1, (*a_1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	typ_1 = skipTypes__ast_u5379((*a_1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2238);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*typ_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		{
			NIM_BOOL T9_;
			NIM_BOOL T10_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw m_1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw c_1;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T16_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T17_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T18_;
			T9_ = (NIM_BOOL)0;
			T10_ = (NIM_BOOL)0;
			T10_ = ((*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
			if (!(T10_)) goto LA11_;
			T10_ = ((*(*a_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA11_: ;
			T9_ = T10_;
			if (!(T9_)) goto LA12_;
			T9_ = ((*(*(*a_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)124));
LA12_: ;
			if (!T9_) goto LA13_;
			nimZeroMem((void*)(&m_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&c_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			T16_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*a_1)._kind_6.sons.p->data[((NI)1)], T16_, (&m_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T17_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*a_1)._kind_6.sons.p->data[((NI)2)], T17_, (&b_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T18_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*a_1)._kind_6.sons.p->data[((NI)3)], T18_, (&c_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
				if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0)) goto LA21_;
				colontmpD_ = NIM_NIL;
				colontmpD__2 = NIM_NIL;
				colontmpD_ = t__cgen_u97(m_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				colontmpD__2 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				genBoundsCheck__cgen_u14404(p_p0, m_1, b_1, c_1, colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				{
					LA23_:;
				}
				{
					oldNimErrFin23_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					eqdestroy___ast_u3378(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					*nimErr_ = oldNimErrFin23_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			}
LA21_: ;
			{
				NimStringV2 res_1;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				if (!(op_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9))) goto LA28_;
				res_1.len = 0; res_1.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				res_1 = rawNewString(((NI)80));
				prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2239);
				colontmpD__3 = rdLoc__cgen_u470(c_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2241);
				colontmpD__4 = rdLoc__cgen_u470(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2242);
				putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				{
					LA30_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(res_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			}
			goto LA26_;
LA28_: ;
			{
				NimStringV2 res_2;
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				res_2.len = 0; res_2.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				res_2 = rawNewString(((NI)80));
				prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2243);
				colontmpD__5 = rdLoc__cgen_u470(c_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2244);
				colontmpD__6 = rdLoc__cgen_u470(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2246);
				putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				{
					LA34_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(res_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			}
LA26_: ;
			{
				LA15_:;
			}
			{
				oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(c_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(m_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin15_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA7_;
LA13_: ;
		{
			{
				NIM_BOOL T42_;
				T42_ = (NIM_BOOL)0;
				T42_ = reifiedOpenArray__cgen_u14410(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!!(T42_)) goto LA43_;
				{
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5635__1;
					NimStringV2 res_3;
					NimStringV2 colontmpD__7;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T50_;
					if (!(op_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9))) goto LA47_;
					nimZeroMem((void*)(&aX60gensym5635__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					res_3.len = 0; res_3.p = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					T50_ = 0;
					initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T50_, (&aX60gensym5635__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
					res_3 = rawNewString(((NI)80));
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2247);
					colontmpD__7 = rdLoc__cgen_u470(aX60gensym5635__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
					cgFormatValue__cgen_u163((&res_3), colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
					prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2249);
					putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_3, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
					{
						LA49_:;
					}
					{
						oldNimErrFin49_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___system_u2691(res_3);
						eqdestroy___ast_u6284(aX60gensym5635__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin49_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA45_;
LA47_: ;
				{
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5642__1;
					NimStringV2 res_4;
					NimStringV2 colontmpD__8;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T55_;
					nimZeroMem((void*)(&aX60gensym5642__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					res_4.len = 0; res_4.p = NIM_NIL;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					T55_ = 0;
					initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T55_, (&aX60gensym5642__1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					res_4 = rawNewString(((NI)80));
					colontmpD__8 = rdLoc__cgen_u470(aX60gensym5642__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					cgFormatValue__cgen_u163((&res_4), colontmpD__8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					prepareAdd((&res_4), 5);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2251);
					putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_4, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					{
						LA54_:;
					}
					{
						oldNimErrFin54_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(res_4);
						eqdestroy___ast_u6284(aX60gensym5642__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin54_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA45_: ;
			}
			goto LA40_;
LA43_: ;
			{
				NIM_BOOL isDeref_1;
				isDeref_1 = ((*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65) || (*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47));
				{
					if (!(op_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9))) goto LA61_;
					{
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5650__1;
						NimStringV2 res_5;
						NimStringV2 colontmpD__9;
						tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T68_;
						if (!isDeref_1) goto LA65_;
						nimZeroMem((void*)(&aX60gensym5650__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						res_5.len = 0; res_5.p = NIM_NIL;
						colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
						T68_ = 0;
						initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T68_, (&aX60gensym5650__1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
						res_5 = rawNewString(((NI)80));
						prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2252);
						colontmpD__9 = rdLoc__cgen_u470(aX60gensym5650__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
						cgFormatValue__cgen_u163((&res_5), colontmpD__9);
						if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
						prepareAdd((&res_5), 11);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2254);
						putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_5, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA67_;
						{
							LA67_:;
						}
						{
							oldNimErrFin67_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__9);
							eqdestroy___system_u2691(res_5);
							eqdestroy___ast_u6284(aX60gensym5650__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							*nimErr_ = oldNimErrFin67_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA63_;
LA65_: ;
					{
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5657__1;
						NimStringV2 res_6;
						NimStringV2 colontmpD__10;
						tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T73_;
						nimZeroMem((void*)(&aX60gensym5657__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						res_6.len = 0; res_6.p = NIM_NIL;
						colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
						T73_ = 0;
						initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T73_, (&aX60gensym5657__1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
						res_6 = rawNewString(((NI)80));
						prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2255);
						colontmpD__10 = rdLoc__cgen_u470(aX60gensym5657__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
						cgFormatValue__cgen_u163((&res_6), colontmpD__10);
						if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
						prepareAdd((&res_6), 10);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2257);
						putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_6, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA72_;
						{
							LA72_:;
						}
						{
							oldNimErrFin72_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__10);
							eqdestroy___system_u2691(res_6);
							eqdestroy___ast_u6284(aX60gensym5657__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							*nimErr_ = oldNimErrFin72_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA63_: ;
				}
				goto LA59_;
LA61_: ;
				{
					{
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5664__1;
						NimStringV2 res_7;
						NimStringV2 colontmpD__11;
						tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T82_;
						if (!isDeref_1) goto LA79_;
						nimZeroMem((void*)(&aX60gensym5664__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						res_7.len = 0; res_7.p = NIM_NIL;
						colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
						T82_ = 0;
						initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T82_, (&aX60gensym5664__1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						res_7 = rawNewString(((NI)80));
						colontmpD__11 = rdLoc__cgen_u470(aX60gensym5664__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						cgFormatValue__cgen_u163((&res_7), colontmpD__11);
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						prepareAdd((&res_7), 8);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2259);
						putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_7, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						{
							LA81_:;
						}
						{
							oldNimErrFin81_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__11);
							eqdestroy___system_u2691(res_7);
							eqdestroy___ast_u6284(aX60gensym5664__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							*nimErr_ = oldNimErrFin81_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA77_;
LA79_: ;
					{
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5671__1;
						NimStringV2 res_8;
						NimStringV2 colontmpD__12;
						tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T87_;
						nimZeroMem((void*)(&aX60gensym5671__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						res_8.len = 0; res_8.p = NIM_NIL;
						colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
						T87_ = 0;
						initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T87_, (&aX60gensym5671__1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
						res_8 = rawNewString(((NI)80));
						colontmpD__12 = rdLoc__cgen_u470(aX60gensym5671__1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
						cgFormatValue__cgen_u163((&res_8), colontmpD__12);
						if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
						prepareAdd((&res_8), 7);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2261);
						putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_8, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
						{
							LA86_:;
						}
						{
							oldNimErrFin86_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__12);
							eqdestroy___system_u2691(res_8);
							eqdestroy___ast_u6284(aX60gensym5671__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							*nimErr_ = oldNimErrFin86_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA77_: ;
				}
LA59_: ;
			}
LA40_: ;
		}
LA7_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	{
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5678__1;
			NimStringV2 res_9;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T96_;
			if (!(op_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9))) goto LA93_;
			nimZeroMem((void*)(&aX60gensym5678__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_9.len = 0; res_9.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			T96_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T96_, (&aX60gensym5678__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			res_9 = rawNewString(((NI)80));
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2262);
			colontmpD__13 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2264);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			cgFormatValue__cgen_u163((&res_9), colontmpD__13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2265);
			colontmpD__14 = rdLoc__cgen_u470(aX60gensym5678__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			cgFormatValue__cgen_u163((&res_9), colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			prepareAdd((&res_9), 4);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2267);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_9, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			{
				LA95_:;
			}
			{
				oldNimErrFin95_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(res_9);
				eqdestroy___ast_u6284(aX60gensym5678__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin95_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA91_;
LA93_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5685__1;
			NimStringV2 res_10;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T101_;
			nimZeroMem((void*)(&aX60gensym5685__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_10.len = 0; res_10.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			T101_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T101_, (&aX60gensym5685__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
			res_10 = rawNewString(((NI)80));
			colontmpD__15 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2268);
			if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
			cgFormatValue__cgen_u163((&res_10), colontmpD__15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
			prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_2269);
			colontmpD__16 = rdLoc__cgen_u470(aX60gensym5685__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
			cgFormatValue__cgen_u163((&res_10), colontmpD__16);
			if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
			prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_2270);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_10, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
			{
				LA100_:;
			}
			{
				oldNimErrFin100_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(res_10);
				eqdestroy___ast_u6284(aX60gensym5685__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin100_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA91_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
		NimStringV2 x_1;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T106_;
		nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		x_1.len = 0; x_1.p = NIM_NIL;
		T106_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T106_, (&a_2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
		x_1 = lenExpr__cgen_u495(p_p0, a_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T111_;
			NimStringV2 T112_;
			if (!(op_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9))) goto LA109_;
			T111_[0] = x_1;
			T112_.len = 0; T112_.p = NIM_NIL;
			T112_ = percent___cgen_u24338(T111_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T112_); goto LA105_;}
			eqsink___system_u2700((&x_1), T112_);
		}
LA109_: ;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, x_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA105_;
		{
			LA105_:;
		}
		{
			oldNimErrFin105_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(x_1);
			eqdestroy___ast_u6284(a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin105_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_3;
		NimStringV2 x_2;
		NimStringV2 res_11;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T117_;
		NimStringV2* T124_;
		NimStringV2* T125_;
		nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		x_2.len = 0; x_2.p = NIM_NIL;
		res_11.len = 0; res_11.p = NIM_NIL;
		getIntTemp__cgen_u13628(p_p0, (&tmp_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		T117_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T117_, (&a_3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		x_2 = lenExpr__cgen_u495(p_p0, a_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T122_;
			NimStringV2 T123_;
			if (!(op_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9))) goto LA120_;
			T122_[0] = x_2;
			T123_.len = 0; T123_.p = NIM_NIL;
			T123_ = percent___cgen_u24338(T122_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T123_); goto LA116_;}
			eqsink___system_u2700((&x_2), T123_);
		}
LA120_: ;
		T124_ = (NimStringV2*)0;
		T124_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		addIndent__cgen_u315(p_p0, T124_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		T125_ = (NimStringV2*)0;
		T125_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		res_11 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_11), tmp_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		prepareAdd((&res_11), 3);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2271);
		cgFormatValue__cgen_u163((&res_11), x_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2272);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA128_;
			prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2273);
		}
LA128_: ;
		prepareAdd((&(*T125_)), res_11.len + 0);
appendString((&(*T125_)), res_11);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, tmp_1.snippet, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
		{
			LA116_:;
		}
		{
			oldNimErrFin116_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(res_11);
			eqdestroy___system_u2691(x_2);
			eqdestroy___ast_u6284(a_3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin116_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		{
			NimStringV2 colontmpD__17;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T138_;
			if (!(op_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9))) goto LA135_;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			T138_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
			colontmpD__17 = rope__cgen_u9217(T138_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__17, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
			{
				LA137_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__17);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA133_;
LA135_: ;
		{
			NimStringV2 colontmpD__18;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T143_;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			T143_ = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
			colontmpD__18 = rope__cgen_u9217(T143_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__18, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
			{
				LA142_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__18);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA133_: ;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2275, TM__MQdRN7fpbG7rPm4JpVVAhA_2276);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(typ_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthStr__cgen_u24436)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA3_;
		binaryStmtAddr__cgen_u21181(p_p0, e_p1, d_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_2297);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw call_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T11_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T12_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T13_;
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T14_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&call_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		{
			if (!!(((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0)))) goto LA9_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2299, TM__MQdRN7fpbG7rPm4JpVVAhA_2300);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA9_: ;
		T11_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T11_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T12_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T12_, (&b_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T13_ = 0;
		initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), e_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T13_, (&call_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2302);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2303);
		colontmpD__2 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2304);
		colontmpD__3 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2305);
		eqsink___system_u2700((&call_1.snippet), res_1);
		eqwasMoved___system_u2688((&res_1));
		T14_ = 0;
		genAssignment__cgen_u12898(p_p0, a_1, call_1, T14_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u6284(call_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, isTrivialTypesToSnippet__cgen_u24371)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = containsGarbageCollectedRef__types_u555(t_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (T3_) goto LA4_;
		T5_ = 0;
		T3_ = !(((IL64(2147483664) & (*t_p0).flags) == T5_));
LA4_: ;
		if (!T3_) goto LA6_;
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_2319;
	}
	goto LA1_;
LA6_: ;
	{
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_2321;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetLengthSeq__cgen_u24382)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, NIM_BOOL noinit_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw call_1;
	NimStringV2 name_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T11_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T12_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T13_;
	NimStringV2 T14_;
NIM_BOOL oldNimErrFin26_;
NIM_BOOL oldNimErrFin30_;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T33_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	x_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	t_1 = NIM_NIL;
	nimZeroMem((void*)(&call_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	name_1.len = 0; name_1.p = NIM_NIL;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T6_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = makeAddr__magicsys_u191((*e_p1)._kind_6.sons.p->data[((NI)1)], (*(*p_p0).module).Sup.idgen);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T6_); goto LA1_;}
		eqsink___ast_u3261(&(*e_p1)._kind_6.sons.p->data[((NI)1)], T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		genCall__cgen_u15586(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u6284(call_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	x_1 = (*e_p1)._kind_6.sons.p->data[((NI)1)];
	{
		if (!((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA9_;
		x_1 = (*x_1)._kind_6.sons.p->data[((NI)0)];
	}
LA9_: ;
	T11_ = 0;
	initLocExpr__cgen_u14111(p_p0, x_1, T11_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T12_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1986);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_ = 0;
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), e_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T13_, (&call_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T14_.len = 0; T14_.p = NIM_NIL;
	{
		if (!noinit_p3) goto LA17_;
		name_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2307;
	}
	goto LA15_;
LA17_: ;
	{
		name_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2309;
	}
LA15_: ;
	{
		NIM_BOOL T22_;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
		NimStringV2 colontmpD__9;
		T22_ = (NIM_BOOL)0;
		T22_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T22_) goto LA23_;
		T22_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA23_: ;
		if (!!(T22_)) goto LA24_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8 = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2310);
		colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2311);
		colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, name_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2312);
		colontmpD__3 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2314);
		colontmpD__4 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		prepareAdd((&res_1), 16);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2316);
		colontmpD__5 = skipTypes__ast_u5379(t_1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		colontmpD__6 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__5, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2317);
		colontmpD__7 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2318);
		colontmpD__8 = skipTypes__ast_u5379(t_1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		colontmpD__9 = isTrivialTypesToSnippet__cgen_u24371((*colontmpD__8).sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2322);
		eqsink___system_u2700((&call_1.snippet), res_1);
		eqwasMoved___system_u2688((&res_1));
		{
			LA26_:;
		}
		{
			oldNimErrFin26_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___ast_u3378(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			*nimErr_ = oldNimErrFin26_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA20_;
LA24_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__16;
		NimStringV2 colontmpD__17;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13 = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16 = NIM_NIL;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2323);
		colontmpD__10 = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2324);
		colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, name_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2325);
		colontmpD__12 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2326);
		colontmpD__13 = skipTypes__ast_u5379(t_1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		colontmpD__14 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__13, (*e_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2327);
		colontmpD__15 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2328);
		colontmpD__16 = skipTypes__ast_u5379(t_1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		colontmpD__17 = isTrivialTypesToSnippet__cgen_u24371((*colontmpD__16).sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__17);
		if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2329);
		eqsink___system_u2700((&call_1.snippet), res_2);
		eqwasMoved___system_u2688((&res_2));
		{
			LA30_:;
		}
		{
			oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___ast_u3378(colontmpD__16);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___ast_u3378(colontmpD__13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(res_2);
			*nimErr_ = oldNimErrFin30_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA20_: ;
	T33_ = 0;
	genAssignment__cgen_u12898(p_p0, a_1, call_1, T33_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(call_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rdSetElemLoc__cgen_u20092)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, NimStringV2* result_p3) {
	NimStringV2 colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* setType_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	setType_1 = NIM_NIL;
	prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_2330);
	colontmpD_ = rdCharLoc__cgen_u12869(a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*result_p3)), colontmpD_.len + 0);
appendString((&(*result_p3)), colontmpD_);
	setType_1 = skipTypes__ast_u5379(typ_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T4_;
		NIM_BOOL T5_;
		NimStringV2 colontmpD__2;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T9_;
		T4_ = firstOrd__types_u1182(conf_p0, setType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T5_ = (NIM_BOOL)0;
		T5_ = eqeq___int128_u980(T4_, IL64(0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T5_)) goto LA6_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		prepareAdd((&(*result_p3)), 3);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_2332);
		T9_ = firstOrd__types_u1182(conf_p0, setType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		colontmpD__2 = rope__cgen_u9217(T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&(*result_p3)), colontmpD__2.len + 0);
appendString((&(*result_p3)), colontmpD__2);
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_2333);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(setType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, fewCmps__cgen_u24480)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_p1) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	{
		if (!!(((*s_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39)))) goto LA4_;
		result = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		NI64 T9_;
		T8_ = (NIM_BOOL)0;
		T9_ = (NI64)0;
		T9_ = getSize__types_u3397(conf_p0, (*s_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_ = (T9_ <= ((NI64) ((*conf_p0).target.intSize)));
		if (!(T8_)) goto LA10_;
		T8_ = (((*s_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)4)))&31U)))!=0);
LA10_: ;
		if (!T8_) goto LA11_;
		result = NIM_FALSE;
	}
	goto LA6_;
LA11_: ;
	{
		colontmpD_ = elemType__types_u254((*s_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) || (*colontmpD_).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33) && (*colontmpD_).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35))) goto LA14_;
		result = NIM_TRUE;
	}
	goto LA6_;
LA14_: ;
	{
		NI T17_;
		T17_ = (NI)0;
		T17_ = len__ast_u3190(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		result = (T17_ <= ((NI)8));
	}
LA6_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genInExprAux__cgen_u22235)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* b_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NI64 T2_;
NIM_BOOL oldNimErrFin4_;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD_ = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NI64)0;
	T2_ = getSize__types_u3397((*(*(*p_p0).module).g).config, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch (((NI) (T2_))) {
	case ((NI)1):
	{
		NimStringV2 elemX60gensym5771__1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T5_;
		elemX60gensym5771__1.len = 0; elemX60gensym5771__1.p = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		elemX60gensym5771__1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		colontmpD__2 = t__cgen_u97((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, (*b_p3), colontmpD__2, (&elemX60gensym5771__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		colontmpD__3 = rdLoc__cgen_u470((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		T5_[0] = colontmpD__3;
		T5_[1] = elemX60gensym5771__1;
		colontmpD__4 = percent___cgen_u24512(T5_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		putIntoDest__cgen_u21142(p_p0, d_p4, e_p1, colontmpD__4, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		{
			LA4_:;
		}
		{
			oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(elemX60gensym5771__1);
			*nimErr_ = oldNimErrFin4_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((NI)2):
	{
		NimStringV2 elemX60gensym5773__1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T10_;
		elemX60gensym5773__1.len = 0; elemX60gensym5773__1.p = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		elemX60gensym5773__1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		colontmpD__5 = t__cgen_u97((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, (*b_p3), colontmpD__5, (&elemX60gensym5773__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		colontmpD__6 = rdLoc__cgen_u470((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T10_[0] = colontmpD__6;
		T10_[1] = elemX60gensym5773__1;
		colontmpD__7 = percent___cgen_u24519(T10_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		putIntoDest__cgen_u21142(p_p0, d_p4, e_p1, colontmpD__7, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(elemX60gensym5773__1);
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((NI)4):
	{
		NimStringV2 elemX60gensym5775__1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T15_;
		elemX60gensym5775__1.len = 0; elemX60gensym5775__1.p = NIM_NIL;
		colontmpD__8 = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		elemX60gensym5775__1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__8 = t__cgen_u97((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, (*b_p3), colontmpD__8, (&elemX60gensym5775__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__9 = rdLoc__cgen_u470((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T15_[0] = colontmpD__9;
		T15_[1] = elemX60gensym5775__1;
		colontmpD__10 = percent___cgen_u24526(T15_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		putIntoDest__cgen_u21142(p_p0, d_p4, e_p1, colontmpD__10, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			LA14_:;
		}
		{
			oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___ast_u3378(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(elemX60gensym5775__1);
			*nimErr_ = oldNimErrFin14_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((NI)8):
	{
		NimStringV2 elemX60gensym5777__1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T20_;
		elemX60gensym5777__1.len = 0; elemX60gensym5777__1.p = NIM_NIL;
		colontmpD__11 = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		elemX60gensym5777__1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		colontmpD__11 = t__cgen_u97((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, (*b_p3), colontmpD__11, (&elemX60gensym5777__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		colontmpD__12 = rdLoc__cgen_u470((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		T20_[0] = colontmpD__12;
		T20_[1] = elemX60gensym5777__1;
		colontmpD__13 = percent___cgen_u24533(T20_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		putIntoDest__cgen_u21142(p_p0, d_p4, e_p1, colontmpD__13, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		{
			LA19_:;
		}
		{
			oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___ast_u3378(colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(elemX60gensym5777__1);
			*nimErr_ = oldNimErrFin19_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 elemX60gensym5779__1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T25_;
		elemX60gensym5779__1.len = 0; elemX60gensym5779__1.p = NIM_NIL;
		colontmpD__14 = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		elemX60gensym5779__1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		colontmpD__14 = t__cgen_u97((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, (*b_p3), colontmpD__14, (&elemX60gensym5779__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		colontmpD__15 = rdLoc__cgen_u470((*a_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		T25_[0] = colontmpD__15;
		T25_[1] = elemX60gensym5779__1;
		colontmpD__16 = percent___cgen_u24540(T25_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		putIntoDest__cgen_u21142(p_p0, d_p4, e_p1, colontmpD__16, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		{
			LA24_:;
		}
		{
			oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___ast_u3378(colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(elemX60gensym5779__1);
			*nimErr_ = oldNimErrFin24_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genInOp__cgen_u24553)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw x_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw y_1;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&y_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		NIM_BOOL T4_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ea_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T8_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T14_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T15_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39));
		if (!(T4_)) goto LA5_;
		T4_ = fewCmps__cgen_u24480((*(*(*p_p0).module).g).config, (*e_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
		ea_1 = NIM_NIL;
		T8_ = NIM_NIL;
		{
			if (!((*(*e_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)70) || (*(*e_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)69))) goto LA11_;
			ea_1 = (*(*e_p1)._kind_6.sons.p->data[((NI)2)])._kind_6.sons.p->data[((NI)0)];
		}
		goto LA9_;
LA11_: ;
		{
			ea_1 = (*e_p1)._kind_6.sons.p->data[((NI)2)];
		}
LA9_: ;
		T14_ = 0;
		initLocExpr__cgen_u14111(p_p0, ea_1, T14_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T15_ = 0;
		initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), e_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T15_, (&b_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NI T18_;
			T18_ = (NI)0;
			T18_ = len__ast_u3190((*e_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)0) < T18_)) goto LA19_;
			eqsink___system_u2700((&b_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_2372);
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190((*e_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				i_2 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
						if (!(i_2 < colontmp_)) goto LA23;
						it_1 = NIM_NIL;
						i_1 = i_2;
						eqcopy___ast_u3255(&it_1, (*(*e_p1)._kind_6.sons.p->data[((NI)1)])._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
						{
							NimStringV2 colontmpD_;
							NimStringV2 colontmpD__2;
							NimStringV2 colontmpD__3;
							NimStringV2 colontmpD__4;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T30_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T31_;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T32_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T33_;
							tyArray__dyW7vpmfeTYw8kX3EXuaJA T34_;
							if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA27_;
							colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
							colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
							colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
							colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
							T30_ = 0;
							nimZeroMem((void*)(&T31_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, (*it_1)._kind_6.sons.p->data[((NI)0)], T30_, (&T31_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							eqsink___ast_u6293((&x_1), T31_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							T32_ = 0;
							nimZeroMem((void*)(&T33_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, (*it_1)._kind_6.sons.p->data[((NI)1)], T32_, (&T33_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							eqsink___ast_u6293((&y_1), T33_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							colontmpD_ = rdCharLoc__cgen_u12869(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							T34_[0] = colontmpD_;
							colontmpD__2 = rdCharLoc__cgen_u12869(x_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							T34_[1] = colontmpD__2;
							colontmpD__3 = rdCharLoc__cgen_u12869(y_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							T34_[2] = colontmpD__3;
							colontmpD__4 = percent___cgen_u24580(T34_, 3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
							prepareAdd((&b_1.snippet), colontmpD__4.len + 0);
appendString((&b_1.snippet), colontmpD__4);
							{
								LA29_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__4);
								eqdestroy___system_u2691(colontmpD__3);
								eqdestroy___system_u2691(colontmpD__2);
								eqdestroy___system_u2691(colontmpD_);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
						}
						goto LA25_;
LA27_: ;
						{
							NimStringV2 colontmpD__5;
							NimStringV2 colontmpD__6;
							NimStringV2 colontmpD__7;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T39_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T40_;
							tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T41_;
							colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
							colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
							colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
							T39_ = 0;
							nimZeroMem((void*)(&T40_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, it_1, T39_, (&T40_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
							eqsink___ast_u6293((&x_1), T40_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
							colontmpD__5 = rdCharLoc__cgen_u12869(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
							T41_[0] = colontmpD__5;
							colontmpD__6 = rdCharLoc__cgen_u12869(x_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
							T41_[1] = colontmpD__6;
							colontmpD__7 = percent___cgen_u24585(T41_, 2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
							prepareAdd((&b_1.snippet), colontmpD__7.len + 0);
appendString((&b_1.snippet), colontmpD__7);
							{
								LA38_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__7);
								eqdestroy___system_u2691(colontmpD__6);
								eqdestroy___system_u2691(colontmpD__5);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
						}
LA25_: ;
						{
							NI T46_;
							T46_ = (NI)0;
							T46_ = len__ast_u3190((*e_p1)._kind_6.sons.p->data[((NI)1)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
							if (!(i_1 < (NI)(T46_ - ((NI)1)))) goto LA47_;
							prepareAdd((&b_1.snippet), 4);
appendString((&b_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_2373);
						}
LA47_: ;
						i_2 += ((NI)1);
						{
							LA24_:;
						}
						{
							oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							*nimErr_ = oldNimErrFin24_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					} LA23: ;
				}
			}
			prepareAdd((&b_1.snippet), 1);
appendString((&b_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_2374);
		}
		goto LA16_;
LA19_: ;
		{
			eqsink___system_u2700((&b_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_2375);
		}
LA16_: ;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, b_1.snippet, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T53_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T54_;
		T53_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T53_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T54_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T54_, (&b_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		genInExprAux__cgen_u22235(p_p0, e_p1, (&a_1), (&b_1), d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(y_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetOp__cgen_u24604)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw i_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* setType_1;
	NI size_1;
	NI64 T2_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin33_;
NIM_BOOL oldNimErrFin44_;
NIM_BOOL oldNimErrFin53_;
NIM_BOOL oldNimErrFin62_;
NIM_BOOL oldNimErrFin71_;
NIM_BOOL oldNimErrFin85_;
NIM_BOOL oldNimErrFin90_;
NIM_BOOL oldNimErrFin95_;
NIM_BOOL oldNimErrFin101_;
NIM_BOOL oldNimErrFin107_;
NIM_BOOL oldNimErrFin113_;
NIM_BOOL oldNimErrFin119_;
NIM_BOOL oldNimErrFin125_;
NIM_BOOL oldNimErrFin131_;
NIM_BOOL oldNimErrFin140_;
NIM_BOOL oldNimErrFin149_;
NIM_BOOL oldNimErrFin158_;
NIM_BOOL oldNimErrFin170_;
NIM_BOOL oldNimErrFin163_;
NIM_BOOL oldNimErrFin217_;
NIM_BOOL oldNimErrFin223_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&i_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	setType_1 = NIM_NIL;
	setType_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NI64)0;
	T2_ = getSize__types_u3397((*(*(*p_p0).module).g).config, setType_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	size_1 = ((NI) (T2_));
	switch (size_1) {
	case ((NI)1):
	case ((NI)2):
	case ((NI)4):
	case ((NI)8):
	{
		switch (op_p3) {
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)40):
		{
			switch (size_1) {
			case ((NI)1):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5816__1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5816__1;
				NimStringV2 elemX60gensym5816__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T7_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T8_;
				NimStringV2* T9_;
				NimStringV2* T10_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T11_;
				nimZeroMem((void*)(&aX60gensym5816__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				nimZeroMem((void*)(&bX60gensym5816__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				elemX60gensym5816__1.len = 0; elemX60gensym5816__1.p = NIM_NIL;
				colontmpD_ = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				T7_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T7_, (&aX60gensym5816__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T8_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T8_, (&bX60gensym5816__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				elemX60gensym5816__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				colontmpD_ = t__cgen_u97(aX60gensym5816__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym5816__1, colontmpD_, (&elemX60gensym5816__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T9_ = (NimStringV2*)0;
				T9_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				addIndent__cgen_u315(p_p0, T9_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T10_ = (NimStringV2*)0;
				T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				colontmpD__2 = rdLoc__cgen_u470(aX60gensym5816__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T11_[0] = colontmpD__2;
				T11_[1] = elemX60gensym5816__1;
				colontmpD__3 = percent___cgen_u24628(T11_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				prepareAdd((&(*T10_)), colontmpD__3.len + 0);
appendString((&(*T10_)), colontmpD__3);
				{
					LA6_:;
				}
				{
					oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___ast_u3378(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(elemX60gensym5816__1);
					eqdestroy___ast_u6284(bX60gensym5816__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(aX60gensym5816__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin6_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((NI)2):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5823__1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5823__1;
				NimStringV2 elemX60gensym5823__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T16_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T17_;
				NimStringV2* T18_;
				NimStringV2* T19_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T20_;
				nimZeroMem((void*)(&aX60gensym5823__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				nimZeroMem((void*)(&bX60gensym5823__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				elemX60gensym5823__1.len = 0; elemX60gensym5823__1.p = NIM_NIL;
				colontmpD__4 = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				T16_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T16_, (&aX60gensym5823__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				T17_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T17_, (&bX60gensym5823__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				elemX60gensym5823__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				colontmpD__4 = t__cgen_u97(aX60gensym5823__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym5823__1, colontmpD__4, (&elemX60gensym5823__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				T18_ = (NimStringV2*)0;
				T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				addIndent__cgen_u315(p_p0, T18_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				T19_ = (NimStringV2*)0;
				T19_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				colontmpD__5 = rdLoc__cgen_u470(aX60gensym5823__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				T20_[0] = colontmpD__5;
				T20_[1] = elemX60gensym5823__1;
				colontmpD__6 = percent___cgen_u24646(T20_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
				prepareAdd((&(*T19_)), colontmpD__6.len + 0);
appendString((&(*T19_)), colontmpD__6);
				{
					LA15_:;
				}
				{
					oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___ast_u3378(colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(elemX60gensym5823__1);
					eqdestroy___ast_u6284(bX60gensym5823__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(aX60gensym5823__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin15_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((NI)4):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5830__1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5830__1;
				NimStringV2 elemX60gensym5830__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2 colontmpD__9;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T25_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T26_;
				NimStringV2* T27_;
				NimStringV2* T28_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T29_;
				nimZeroMem((void*)(&aX60gensym5830__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				nimZeroMem((void*)(&bX60gensym5830__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				elemX60gensym5830__1.len = 0; elemX60gensym5830__1.p = NIM_NIL;
				colontmpD__7 = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				T25_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T25_, (&aX60gensym5830__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				T26_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T26_, (&bX60gensym5830__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				elemX60gensym5830__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				colontmpD__7 = t__cgen_u97(aX60gensym5830__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym5830__1, colontmpD__7, (&elemX60gensym5830__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				T27_ = (NimStringV2*)0;
				T27_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				addIndent__cgen_u315(p_p0, T27_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				T28_ = (NimStringV2*)0;
				T28_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				colontmpD__8 = rdLoc__cgen_u470(aX60gensym5830__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				T29_[0] = colontmpD__8;
				T29_[1] = elemX60gensym5830__1;
				colontmpD__9 = percent___cgen_u24664(T29_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				prepareAdd((&(*T28_)), colontmpD__9.len + 0);
appendString((&(*T28_)), colontmpD__9);
				{
					LA24_:;
				}
				{
					oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___ast_u3378(colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(elemX60gensym5830__1);
					eqdestroy___ast_u6284(bX60gensym5830__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(aX60gensym5830__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin24_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((NI)8):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5837__1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5837__1;
				NimStringV2 elemX60gensym5837__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T34_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T35_;
				NimStringV2* T36_;
				NimStringV2* T37_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T38_;
				nimZeroMem((void*)(&aX60gensym5837__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				nimZeroMem((void*)(&bX60gensym5837__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				elemX60gensym5837__1.len = 0; elemX60gensym5837__1.p = NIM_NIL;
				colontmpD__10 = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				T34_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T34_, (&aX60gensym5837__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T35_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T35_, (&bX60gensym5837__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				elemX60gensym5837__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				colontmpD__10 = t__cgen_u97(aX60gensym5837__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym5837__1, colontmpD__10, (&elemX60gensym5837__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T36_ = (NimStringV2*)0;
				T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				addIndent__cgen_u315(p_p0, T36_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T37_ = (NimStringV2*)0;
				T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				colontmpD__11 = rdLoc__cgen_u470(aX60gensym5837__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				T38_[0] = colontmpD__11;
				T38_[1] = elemX60gensym5837__1;
				colontmpD__12 = percent___cgen_u24682(T38_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				prepareAdd((&(*T37_)), colontmpD__12.len + 0);
appendString((&(*T37_)), colontmpD__12);
				{
					LA33_:;
				}
				{
					oldNimErrFin33_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___ast_u3378(colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(elemX60gensym5837__1);
					eqdestroy___ast_u6284(bX60gensym5837__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(aX60gensym5837__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin33_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			default:
			{
			}
			break;
			}
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)41):
		{
			switch (size_1) {
			case ((NI)1):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5846__1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5846__1;
				NimStringV2 elemX60gensym5846__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__13;
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T45_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T46_;
				NimStringV2* T47_;
				NimStringV2* T48_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T49_;
				nimZeroMem((void*)(&aX60gensym5846__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				nimZeroMem((void*)(&bX60gensym5846__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				elemX60gensym5846__1.len = 0; elemX60gensym5846__1.p = NIM_NIL;
				colontmpD__13 = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				T45_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T45_, (&aX60gensym5846__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				T46_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T46_, (&bX60gensym5846__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				elemX60gensym5846__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				colontmpD__13 = t__cgen_u97(aX60gensym5846__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym5846__1, colontmpD__13, (&elemX60gensym5846__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				T47_ = (NimStringV2*)0;
				T47_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				addIndent__cgen_u315(p_p0, T47_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				T48_ = (NimStringV2*)0;
				T48_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				colontmpD__14 = rdLoc__cgen_u470(aX60gensym5846__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				T49_[0] = colontmpD__14;
				T49_[1] = elemX60gensym5846__1;
				colontmpD__15 = percent___cgen_u24703(T49_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				prepareAdd((&(*T48_)), colontmpD__15.len + 0);
appendString((&(*T48_)), colontmpD__15);
				{
					LA44_:;
				}
				{
					oldNimErrFin44_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___ast_u3378(colontmpD__13);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(elemX60gensym5846__1);
					eqdestroy___ast_u6284(bX60gensym5846__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(aX60gensym5846__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin44_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((NI)2):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5853__1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5853__1;
				NimStringV2 elemX60gensym5853__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__16;
				NimStringV2 colontmpD__17;
				NimStringV2 colontmpD__18;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T54_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T55_;
				NimStringV2* T56_;
				NimStringV2* T57_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T58_;
				nimZeroMem((void*)(&aX60gensym5853__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				nimZeroMem((void*)(&bX60gensym5853__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				elemX60gensym5853__1.len = 0; elemX60gensym5853__1.p = NIM_NIL;
				colontmpD__16 = NIM_NIL;
				colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				T54_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T54_, (&aX60gensym5853__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				T55_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T55_, (&bX60gensym5853__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				elemX60gensym5853__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				colontmpD__16 = t__cgen_u97(aX60gensym5853__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym5853__1, colontmpD__16, (&elemX60gensym5853__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				T56_ = (NimStringV2*)0;
				T56_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				addIndent__cgen_u315(p_p0, T56_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				T57_ = (NimStringV2*)0;
				T57_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				colontmpD__17 = rdLoc__cgen_u470(aX60gensym5853__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				T58_[0] = colontmpD__17;
				T58_[1] = elemX60gensym5853__1;
				colontmpD__18 = percent___cgen_u24721(T58_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
				prepareAdd((&(*T57_)), colontmpD__18.len + 0);
appendString((&(*T57_)), colontmpD__18);
				{
					LA53_:;
				}
				{
					oldNimErrFin53_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__18);
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___ast_u3378(colontmpD__16);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(elemX60gensym5853__1);
					eqdestroy___ast_u6284(bX60gensym5853__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(aX60gensym5853__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin53_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((NI)4):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5860__1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5860__1;
				NimStringV2 elemX60gensym5860__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__19;
				NimStringV2 colontmpD__20;
				NimStringV2 colontmpD__21;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T63_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T64_;
				NimStringV2* T65_;
				NimStringV2* T66_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T67_;
				nimZeroMem((void*)(&aX60gensym5860__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				nimZeroMem((void*)(&bX60gensym5860__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				elemX60gensym5860__1.len = 0; elemX60gensym5860__1.p = NIM_NIL;
				colontmpD__19 = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				T63_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T63_, (&aX60gensym5860__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				T64_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T64_, (&bX60gensym5860__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				elemX60gensym5860__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				colontmpD__19 = t__cgen_u97(aX60gensym5860__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym5860__1, colontmpD__19, (&elemX60gensym5860__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				T65_ = (NimStringV2*)0;
				T65_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				addIndent__cgen_u315(p_p0, T65_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				T66_ = (NimStringV2*)0;
				T66_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				colontmpD__20 = rdLoc__cgen_u470(aX60gensym5860__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				T67_[0] = colontmpD__20;
				T67_[1] = elemX60gensym5860__1;
				colontmpD__21 = percent___cgen_u24739(T67_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				prepareAdd((&(*T66_)), colontmpD__21.len + 0);
appendString((&(*T66_)), colontmpD__21);
				{
					LA62_:;
				}
				{
					oldNimErrFin62_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__21);
					eqdestroy___system_u2691(colontmpD__20);
					eqdestroy___ast_u3378(colontmpD__19);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(elemX60gensym5860__1);
					eqdestroy___ast_u6284(bX60gensym5860__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(aX60gensym5860__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin62_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			case ((NI)8):
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5867__1;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5867__1;
				NimStringV2 elemX60gensym5867__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__22;
				NimStringV2 colontmpD__23;
				NimStringV2 colontmpD__24;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T72_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T73_;
				NimStringV2* T74_;
				NimStringV2* T75_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T76_;
				nimZeroMem((void*)(&aX60gensym5867__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				nimZeroMem((void*)(&bX60gensym5867__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				elemX60gensym5867__1.len = 0; elemX60gensym5867__1.p = NIM_NIL;
				colontmpD__22 = NIM_NIL;
				colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				T72_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T72_, (&aX60gensym5867__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				T73_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T73_, (&bX60gensym5867__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				elemX60gensym5867__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				colontmpD__22 = t__cgen_u97(aX60gensym5867__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym5867__1, colontmpD__22, (&elemX60gensym5867__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				T74_ = (NimStringV2*)0;
				T74_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				addIndent__cgen_u315(p_p0, T74_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				T75_ = (NimStringV2*)0;
				T75_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				colontmpD__23 = rdLoc__cgen_u470(aX60gensym5867__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				T76_[0] = colontmpD__23;
				T76_[1] = elemX60gensym5867__1;
				colontmpD__24 = percent___cgen_u24757(T76_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
				prepareAdd((&(*T75_)), colontmpD__24.len + 0);
appendString((&(*T75_)), colontmpD__24);
				{
					LA71_:;
				}
				{
					oldNimErrFin71_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__24);
					eqdestroy___system_u2691(colontmpD__23);
					eqdestroy___ast_u3378(colontmpD__22);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(elemX60gensym5867__1);
					eqdestroy___ast_u6284(bX60gensym5867__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(aX60gensym5867__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin71_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			break;
			default:
			{
			}
			break;
			}
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)42):
		{
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5876__1;
				NimStringV2 res_1;
				NimStringV2 colontmpD__25;
				NimStringV2 colontmpD__26;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T86_;
				if (!(size_1 <= ((NI)4))) goto LA83_;
				nimZeroMem((void*)(&aX60gensym5876__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				res_1.len = 0; res_1.p = NIM_NIL;
				colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
				colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
				T86_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T86_, (&aX60gensym5876__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				res_1 = rawNewString(((NI)80));
				colontmpD__25 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2335);
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__25);
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2336);
				colontmpD__26 = rdCharLoc__cgen_u12869(aX60gensym5876__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__26);
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2337);
				putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
				{
					LA85_:;
				}
				{
					oldNimErrFin85_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__26);
					eqdestroy___system_u2691(colontmpD__25);
					eqdestroy___system_u2691(res_1);
					eqdestroy___ast_u6284(aX60gensym5876__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin85_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA81_;
LA83_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5883__1;
				NimStringV2 res_2;
				NimStringV2 colontmpD__27;
				NimStringV2 colontmpD__28;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T91_;
				nimZeroMem((void*)(&aX60gensym5883__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				res_2.len = 0; res_2.p = NIM_NIL;
				colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
				colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
				T91_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T91_, (&aX60gensym5883__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
				res_2 = rawNewString(((NI)80));
				colontmpD__27 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2339);
				if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__27);
				if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2340);
				colontmpD__28 = rdCharLoc__cgen_u12869(aX60gensym5883__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__28);
				if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2341);
				putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA90_;
				{
					LA90_:;
				}
				{
					oldNimErrFin90_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__28);
					eqdestroy___system_u2691(colontmpD__27);
					eqdestroy___system_u2691(res_2);
					eqdestroy___ast_u6284(aX60gensym5883__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin90_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA81_: ;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)118):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5890__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5890__1;
			NimStringV2 res_3;
			NimStringV2 colontmpD__29;
			NimStringV2 colontmpD__30;
			NimStringV2 colontmpD__31;
			NimStringV2 colontmpD__32;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T96_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T97_;
			nimZeroMem((void*)(&aX60gensym5890__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym5890__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
			colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
			T96_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T96_, (&aX60gensym5890__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			T97_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T97_, (&bX60gensym5890__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2343);
			colontmpD__29 = rdCharLoc__cgen_u12869(aX60gensym5890__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__29);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			prepareAdd((&res_3), 5);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2345);
			colontmpD__30 = rdCharLoc__cgen_u12869(bX60gensym5890__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__30);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2347);
			colontmpD__31 = rdCharLoc__cgen_u12869(aX60gensym5890__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__31);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2348);
			colontmpD__32 = rdCharLoc__cgen_u12869(bX60gensym5890__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__32);
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2349);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_3, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
			{
				LA95_:;
			}
			{
				oldNimErrFin95_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__32);
				eqdestroy___system_u2691(colontmpD__31);
				eqdestroy___system_u2691(colontmpD__30);
				eqdestroy___system_u2691(colontmpD__29);
				eqdestroy___system_u2691(res_3);
				eqdestroy___ast_u6284(bX60gensym5890__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym5890__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin95_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)117):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5908__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5908__1;
			NimStringV2 res_4;
			NimStringV2 colontmpD__33;
			NimStringV2 colontmpD__34;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T102_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T103_;
			nimZeroMem((void*)(&aX60gensym5908__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym5908__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
			colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
			T102_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T102_, (&aX60gensym5908__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			T103_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T103_, (&bX60gensym5908__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			res_4 = rawNewString(((NI)80));
			prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2350);
			colontmpD__33 = rdCharLoc__cgen_u12869(aX60gensym5908__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__33);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			prepareAdd((&res_4), 5);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2351);
			colontmpD__34 = rdCharLoc__cgen_u12869(bX60gensym5908__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__34);
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			prepareAdd((&res_4), 5);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2353);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_4, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA101_;
			{
				LA101_:;
			}
			{
				oldNimErrFin101_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__34);
				eqdestroy___system_u2691(colontmpD__33);
				eqdestroy___system_u2691(res_4);
				eqdestroy___ast_u6284(bX60gensym5908__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym5908__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin101_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)116):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5926__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5926__1;
			NimStringV2 res_5;
			NimStringV2 colontmpD__35;
			NimStringV2 colontmpD__36;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T108_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T109_;
			nimZeroMem((void*)(&aX60gensym5926__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym5926__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_5.len = 0; res_5.p = NIM_NIL;
			colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
			colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
			T108_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T108_, (&aX60gensym5926__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T109_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T109_, (&bX60gensym5926__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			res_5 = rawNewString(((NI)80));
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2354);
			colontmpD__35 = rdLoc__cgen_u470(aX60gensym5926__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__35);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2355);
			colontmpD__36 = rdLoc__cgen_u470(bX60gensym5926__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__36);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2356);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_5, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			{
				LA107_:;
			}
			{
				oldNimErrFin107_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__36);
				eqdestroy___system_u2691(colontmpD__35);
				eqdestroy___system_u2691(res_5);
				eqdestroy___ast_u6284(bX60gensym5926__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym5926__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin107_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)119):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5944__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5944__1;
			NimStringV2 res_6;
			NimStringV2 colontmpD__37;
			NimStringV2 colontmpD__38;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T114_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T115_;
			nimZeroMem((void*)(&aX60gensym5944__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym5944__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_6.len = 0; res_6.p = NIM_NIL;
			colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
			colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
			T114_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T114_, (&aX60gensym5944__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			T115_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T115_, (&bX60gensym5944__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			res_6 = rawNewString(((NI)80));
			prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2357);
			colontmpD__37 = rdLoc__cgen_u470(aX60gensym5944__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__37);
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			prepareAdd((&res_6), 3);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2359);
			colontmpD__38 = rdLoc__cgen_u470(bX60gensym5944__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__38);
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2360);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_6, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			{
				LA113_:;
			}
			{
				oldNimErrFin113_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__38);
				eqdestroy___system_u2691(colontmpD__37);
				eqdestroy___system_u2691(res_6);
				eqdestroy___ast_u6284(bX60gensym5944__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym5944__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin113_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)120):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5962__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5962__1;
			NimStringV2 res_7;
			NimStringV2 colontmpD__39;
			NimStringV2 colontmpD__40;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T120_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T121_;
			nimZeroMem((void*)(&aX60gensym5962__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym5962__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_7.len = 0; res_7.p = NIM_NIL;
			colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
			colontmpD__40.len = 0; colontmpD__40.p = NIM_NIL;
			T120_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T120_, (&aX60gensym5962__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			T121_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T121_, (&bX60gensym5962__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			res_7 = rawNewString(((NI)80));
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2361);
			colontmpD__39 = rdLoc__cgen_u470(aX60gensym5962__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__39);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			prepareAdd((&res_7), 3);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2363);
			colontmpD__40 = rdLoc__cgen_u470(bX60gensym5962__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__40);
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2364);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_7, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA119_;
			{
				LA119_:;
			}
			{
				oldNimErrFin119_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__40);
				eqdestroy___system_u2691(colontmpD__39);
				eqdestroy___system_u2691(res_7);
				eqdestroy___ast_u6284(bX60gensym5962__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym5962__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin119_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)121):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5980__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5980__1;
			NimStringV2 res_8;
			NimStringV2 colontmpD__41;
			NimStringV2 colontmpD__42;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T126_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T127_;
			nimZeroMem((void*)(&aX60gensym5980__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym5980__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_8.len = 0; res_8.p = NIM_NIL;
			colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
			colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
			T126_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T126_, (&aX60gensym5980__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			T127_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T127_, (&bX60gensym5980__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			res_8 = rawNewString(((NI)80));
			prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2365);
			colontmpD__41 = rdLoc__cgen_u470(aX60gensym5980__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			cgFormatValue__cgen_u163((&res_8), colontmpD__41);
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			prepareAdd((&res_8), 5);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2366);
			colontmpD__42 = rdLoc__cgen_u470(bX60gensym5980__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			cgFormatValue__cgen_u163((&res_8), colontmpD__42);
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2367);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_8, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			{
				LA125_:;
			}
			{
				oldNimErrFin125_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__42);
				eqdestroy___system_u2691(colontmpD__41);
				eqdestroy___system_u2691(res_8);
				eqdestroy___ast_u6284(bX60gensym5980__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym5980__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin125_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)122):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym5998__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym5998__1;
			NimStringV2 res_9;
			NimStringV2 colontmpD__43;
			NimStringV2 colontmpD__44;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T132_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T133_;
			nimZeroMem((void*)(&aX60gensym5998__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym5998__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_9.len = 0; res_9.p = NIM_NIL;
			colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
			colontmpD__44.len = 0; colontmpD__44.p = NIM_NIL;
			T132_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T132_, (&aX60gensym5998__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
			T133_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T133_, (&bX60gensym5998__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
			res_9 = rawNewString(((NI)80));
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2368);
			colontmpD__43 = rdLoc__cgen_u470(aX60gensym5998__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
			cgFormatValue__cgen_u163((&res_9), colontmpD__43);
			if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
			prepareAdd((&res_9), 3);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2370);
			colontmpD__44 = rdLoc__cgen_u470(bX60gensym5998__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
			cgFormatValue__cgen_u163((&res_9), colontmpD__44);
			if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
			prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2371);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_9, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
			{
				LA131_:;
			}
			{
				oldNimErrFin131_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__44);
				eqdestroy___system_u2691(colontmpD__43);
				eqdestroy___system_u2691(res_9);
				eqdestroy___ast_u6284(bX60gensym5998__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym5998__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin131_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)132):
		{
			genInOp__cgen_u24553(p_p0, e_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2377, TM__MQdRN7fpbG7rPm4JpVVAhA_2378);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		}
	}
	break;
	default:
	{
		switch (op_p3) {
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)40):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6019__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym6019__1;
			NimStringV2 elemX60gensym6019__1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__45;
			NimStringV2 colontmpD__46;
			NimStringV2 colontmpD__47;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T141_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T142_;
			NimStringV2* T143_;
			NimStringV2* T144_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T145_;
			nimZeroMem((void*)(&aX60gensym6019__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym6019__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			elemX60gensym6019__1.len = 0; elemX60gensym6019__1.p = NIM_NIL;
			colontmpD__45 = NIM_NIL;
			colontmpD__46.len = 0; colontmpD__46.p = NIM_NIL;
			colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
			T141_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T141_, (&aX60gensym6019__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			T142_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T142_, (&bX60gensym6019__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			elemX60gensym6019__1 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			colontmpD__45 = t__cgen_u97(aX60gensym6019__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym6019__1, colontmpD__45, (&elemX60gensym6019__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			T143_ = (NimStringV2*)0;
			T143_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			addIndent__cgen_u315(p_p0, T143_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			T144_ = (NimStringV2*)0;
			T144_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			colontmpD__46 = rdLoc__cgen_u470(aX60gensym6019__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			T145_[0] = colontmpD__46;
			T145_[1] = elemX60gensym6019__1;
			colontmpD__47 = percent___cgen_u24989(T145_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA140_;
			prepareAdd((&(*T144_)), colontmpD__47.len + 0);
appendString((&(*T144_)), colontmpD__47);
			{
				LA140_:;
			}
			{
				oldNimErrFin140_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__47);
				eqdestroy___system_u2691(colontmpD__46);
				eqdestroy___ast_u3378(colontmpD__45);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(elemX60gensym6019__1);
				eqdestroy___ast_u6284(bX60gensym6019__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym6019__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin140_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)41):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6026__1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym6026__1;
			NimStringV2 elemX60gensym6026__1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__48;
			NimStringV2 colontmpD__49;
			NimStringV2 colontmpD__50;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T150_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T151_;
			NimStringV2* T152_;
			NimStringV2* T153_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T154_;
			nimZeroMem((void*)(&aX60gensym6026__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&bX60gensym6026__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			elemX60gensym6026__1.len = 0; elemX60gensym6026__1.p = NIM_NIL;
			colontmpD__48 = NIM_NIL;
			colontmpD__49.len = 0; colontmpD__49.p = NIM_NIL;
			colontmpD__50.len = 0; colontmpD__50.p = NIM_NIL;
			T150_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T150_, (&aX60gensym6026__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			T151_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T151_, (&bX60gensym6026__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			elemX60gensym6026__1 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			colontmpD__48 = t__cgen_u97(aX60gensym6026__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, bX60gensym6026__1, colontmpD__48, (&elemX60gensym6026__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			T152_ = (NimStringV2*)0;
			T152_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			addIndent__cgen_u315(p_p0, T152_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			T153_ = (NimStringV2*)0;
			T153_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			colontmpD__49 = rdLoc__cgen_u470(aX60gensym6026__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			T154_[0] = colontmpD__49;
			T154_[1] = elemX60gensym6026__1;
			colontmpD__50 = percent___cgen_u25007(T154_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			prepareAdd((&(*T153_)), colontmpD__50.len + 0);
appendString((&(*T153_)), colontmpD__50);
			{
				LA149_:;
			}
			{
				oldNimErrFin149_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__50);
				eqdestroy___system_u2691(colontmpD__49);
				eqdestroy___ast_u3378(colontmpD__48);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(elemX60gensym6026__1);
				eqdestroy___ast_u6284(bX60gensym6026__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(aX60gensym6026__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin149_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)42):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
			NimStringV2 res_10;
			NimStringV2 colontmpD__51;
			NimStringV2 colontmpD__52;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T159_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_10.len = 0; res_10.p = NIM_NIL;
			colontmpD__51.len = 0; colontmpD__51.p = NIM_NIL;
			colontmpD__52.len = 0; colontmpD__52.p = NIM_NIL;
			T159_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T159_, (&a_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
			res_10 = rawNewString(((NI)80));
			colontmpD__51 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2380);
			if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
			cgFormatValue__cgen_u163((&res_10), colontmpD__51);
			if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
			prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_2381);
			colontmpD__52 = rdCharLoc__cgen_u12869(a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
			cgFormatValue__cgen_u163((&res_10), colontmpD__52);
			if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
			prepareAdd((&res_10), 2);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_2382);
			cgFormatValue__cgen_u166((&res_10), ((NI64) (size_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
			prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_2383);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_10, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA158_;
			{
				LA158_:;
			}
			{
				oldNimErrFin158_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__52);
				eqdestroy___system_u2691(colontmpD__51);
				eqdestroy___system_u2691(res_10);
				eqdestroy___ast_u6284(a_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin158_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)118):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)117):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__53;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T164_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T165_;
			colontmpD__53 = NIM_NIL;
			colontmpD__53 = getSysType__magicsys_u55((*(*(*p_p0).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
			if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
			getTemp__cgen_u9546(p_p0, colontmpD__53, NIM_FALSE, (&i_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
			T164_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T164_, (&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
			T165_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T165_, (&b_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__54;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T171_;
				if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA168_;
				colontmpD__54 = NIM_NIL;
				colontmpD__54 = getSysType__magicsys_u55((*(*(*p_p0).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
				nimZeroMem((void*)(&T171_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				getTemp__cgen_u9546(p_p0, colontmpD__54, NIM_FALSE, (&T171_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
				eqsink___ast_u6293((&(*d_p2)), T171_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
				{
					LA170_:;
				}
				{
					oldNimErrFin170_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__54);
					if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
					*nimErr_ = oldNimErrFin170_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
			}
LA168_: ;
			{
				NimStringV2 res_11;
				NimStringV2 colontmpD__55;
				NimStringV2 colontmpD__56;
				NimStringV2 colontmpD__57;
				NimStringV2 colontmpD__58;
				NimStringV2 colontmpD__59;
				NimStringV2 colontmpD__60;
				NimStringV2 colontmpD__61;
				NimStringV2 colontmpD__62;
				NimStringV2 colontmpD__63;
				NimStringV2 colontmpD__64;
				NimStringV2 colontmpD__65;
				NimStringV2 colontmpD__66;
				NimStringV2 colontmpD__67;
				NimStringV2 colontmpD__68;
				NimStringV2* T179_;
				NimStringV2* T180_;
				if (!(op_p3 == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)118))) goto LA176_;
				res_11.len = 0; res_11.p = NIM_NIL;
				colontmpD__55.len = 0; colontmpD__55.p = NIM_NIL;
				colontmpD__56.len = 0; colontmpD__56.p = NIM_NIL;
				colontmpD__57.len = 0; colontmpD__57.p = NIM_NIL;
				colontmpD__58.len = 0; colontmpD__58.p = NIM_NIL;
				colontmpD__59.len = 0; colontmpD__59.p = NIM_NIL;
				colontmpD__60.len = 0; colontmpD__60.p = NIM_NIL;
				colontmpD__61.len = 0; colontmpD__61.p = NIM_NIL;
				colontmpD__62.len = 0; colontmpD__62.p = NIM_NIL;
				colontmpD__63.len = 0; colontmpD__63.p = NIM_NIL;
				colontmpD__64.len = 0; colontmpD__64.p = NIM_NIL;
				colontmpD__65.len = 0; colontmpD__65.p = NIM_NIL;
				colontmpD__66.len = 0; colontmpD__66.p = NIM_NIL;
				colontmpD__67.len = 0; colontmpD__67.p = NIM_NIL;
				colontmpD__68.len = 0; colontmpD__68.p = NIM_NIL;
				T179_ = (NimStringV2*)0;
				T179_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				addIndent__cgen_u315(p_p0, T179_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				T180_ = (NimStringV2*)0;
				T180_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				res_11 = rawNewString(((NI)80));
				prepareAdd((&res_11), 5);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2384);
				colontmpD__55 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__55);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 6);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2385);
				colontmpD__56 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__56);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 3);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2386);
				cgFormatValue__cgen_u166((&res_11), ((NI64) (size_1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 2);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2387);
				colontmpD__57 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__57);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 6);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2389);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA183_;
					prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2390);
				}
LA183_: ;
				prepareAdd((&res_11), 2);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2391);
				colontmpD__58 = rdLoc__cgen_u470((*d_p2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__58);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 5);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2393);
				colontmpD__59 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__59);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2394);
				colontmpD__60 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__60);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 6);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2396);
				colontmpD__61 = rdLoc__cgen_u470(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__61);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2397);
				colontmpD__62 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__62);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 9);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2399);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA187_;
					prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2400);
				}
LA187_: ;
				prepareAdd((&res_11), 7);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2402);
				colontmpD__63 = rdLoc__cgen_u470((*d_p2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__63);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 9);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2404);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA191_;
					prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2405);
				}
LA191_: ;
				prepareAdd((&res_11), 4);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2406);
				colontmpD__64 = rdLoc__cgen_u470((*d_p2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__64);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 2);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2407);
				colontmpD__65 = rdLoc__cgen_u470((*d_p2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__65);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 4);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2408);
				colontmpD__66 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2410);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__66);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2411);
				colontmpD__67 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__67);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 2);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2412);
				colontmpD__68 = rdLoc__cgen_u470(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				cgFormatValue__cgen_u163((&res_11), colontmpD__68);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 2);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2413);
				cgFormatValue__cgen_u166((&res_11), ((NI64) (size_1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				prepareAdd((&res_11), 8);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2415);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA195_;
					prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2416);
				}
LA195_: ;
				prepareAdd((&(*T180_)), res_11.len + 0);
appendString((&(*T180_)), res_11);
				{
					LA178_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__68);
					eqdestroy___system_u2691(colontmpD__67);
					eqdestroy___system_u2691(colontmpD__66);
					eqdestroy___system_u2691(colontmpD__65);
					eqdestroy___system_u2691(colontmpD__64);
					eqdestroy___system_u2691(colontmpD__63);
					eqdestroy___system_u2691(colontmpD__62);
					eqdestroy___system_u2691(colontmpD__61);
					eqdestroy___system_u2691(colontmpD__60);
					eqdestroy___system_u2691(colontmpD__59);
					eqdestroy___system_u2691(colontmpD__58);
					eqdestroy___system_u2691(colontmpD__57);
					eqdestroy___system_u2691(colontmpD__56);
					eqdestroy___system_u2691(colontmpD__55);
					eqdestroy___system_u2691(res_11);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
			}
			goto LA174_;
LA176_: ;
			{
				NimStringV2 res_12;
				NimStringV2 colontmpD__69;
				NimStringV2 colontmpD__70;
				NimStringV2 colontmpD__71;
				NimStringV2 colontmpD__72;
				NimStringV2 colontmpD__73;
				NimStringV2 colontmpD__74;
				NimStringV2 colontmpD__75;
				NimStringV2 colontmpD__76;
				NimStringV2 colontmpD__77;
				NimStringV2* T200_;
				NimStringV2* T201_;
				res_12.len = 0; res_12.p = NIM_NIL;
				colontmpD__69.len = 0; colontmpD__69.p = NIM_NIL;
				colontmpD__70.len = 0; colontmpD__70.p = NIM_NIL;
				colontmpD__71.len = 0; colontmpD__71.p = NIM_NIL;
				colontmpD__72.len = 0; colontmpD__72.p = NIM_NIL;
				colontmpD__73.len = 0; colontmpD__73.p = NIM_NIL;
				colontmpD__74.len = 0; colontmpD__74.p = NIM_NIL;
				colontmpD__75.len = 0; colontmpD__75.p = NIM_NIL;
				colontmpD__76.len = 0; colontmpD__76.p = NIM_NIL;
				colontmpD__77.len = 0; colontmpD__77.p = NIM_NIL;
				T200_ = (NimStringV2*)0;
				T200_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				addIndent__cgen_u315(p_p0, T200_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				T201_ = (NimStringV2*)0;
				T201_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				res_12 = rawNewString(((NI)80));
				prepareAdd((&res_12), 5);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2417);
				colontmpD__69 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__69);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 6);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2418);
				colontmpD__70 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__70);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 3);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2419);
				cgFormatValue__cgen_u166((&res_12), ((NI64) (size_1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 2);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2420);
				colontmpD__71 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__71);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 6);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2421);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA204_;
					prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2422);
				}
LA204_: ;
				prepareAdd((&res_12), 2);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2423);
				colontmpD__72 = rdLoc__cgen_u470((*d_p2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__72);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 5);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2424);
				colontmpD__73 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__73);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2425);
				colontmpD__74 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__74);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 6);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2426);
				colontmpD__75 = rdLoc__cgen_u470(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__75);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2427);
				colontmpD__76 = rdLoc__cgen_u470(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__76);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 9);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2428);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA208_;
					prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2429);
				}
LA208_: ;
				prepareAdd((&res_12), 7);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2430);
				colontmpD__77 = rdLoc__cgen_u470((*d_p2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				cgFormatValue__cgen_u163((&res_12), colontmpD__77);
				if (NIM_UNLIKELY(*nimErr_)) goto LA163_;
				prepareAdd((&res_12), 9);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2431);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA212_;
					prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2432);
				}
LA212_: ;
				prepareAdd((&(*T201_)), res_12.len + 0);
appendString((&(*T201_)), res_12);
				eqdestroy___system_u2691(colontmpD__77);
				eqdestroy___system_u2691(colontmpD__76);
				eqdestroy___system_u2691(colontmpD__75);
				eqdestroy___system_u2691(colontmpD__74);
				eqdestroy___system_u2691(colontmpD__73);
				eqdestroy___system_u2691(colontmpD__72);
				eqdestroy___system_u2691(colontmpD__71);
				eqdestroy___system_u2691(colontmpD__70);
				eqdestroy___system_u2691(colontmpD__69);
				eqdestroy___system_u2691(res_12);
			}
LA174_: ;
			{
				LA163_:;
			}
			{
				oldNimErrFin163_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__53);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin163_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)116):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_3;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_2;
			NimStringV2 res_13;
			NimStringV2 colontmpD__78;
			NimStringV2 colontmpD__79;
			NimStringV2 colontmpD__80;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T218_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T219_;
			nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&b_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_13.len = 0; res_13.p = NIM_NIL;
			colontmpD__78.len = 0; colontmpD__78.p = NIM_NIL;
			colontmpD__79.len = 0; colontmpD__79.p = NIM_NIL;
			colontmpD__80.len = 0; colontmpD__80.p = NIM_NIL;
			T218_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T218_, (&a_3));
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			T219_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T219_, (&b_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			res_13 = rawNewString(((NI)80));
			prepareAdd((&res_13), 1);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_2433);
			colontmpD__78 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2434);
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__78);
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			prepareAdd((&res_13), 1);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_2435);
			colontmpD__79 = rdCharLoc__cgen_u12869(a_3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__79);
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			prepareAdd((&res_13), 2);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_2436);
			colontmpD__80 = rdCharLoc__cgen_u12869(b_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__80);
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			prepareAdd((&res_13), 2);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_2437);
			cgFormatValue__cgen_u166((&res_13), ((NI64) (size_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			prepareAdd((&res_13), 5);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_2438);
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_13, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
			{
				LA217_:;
			}
			{
				oldNimErrFin217_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__80);
				eqdestroy___system_u2691(colontmpD__79);
				eqdestroy___system_u2691(colontmpD__78);
				eqdestroy___system_u2691(res_13);
				eqdestroy___ast_u6284(b_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u6284(a_3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin217_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)119):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)120):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)121):
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)122):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__81;
			NimStringV2 colontmpD__82;
			NimStringV2 colontmpD__83;
			NimStringV2 colontmpD__84;
			NimStringV2 colontmpD__85;
			NimStringV2 colontmpD__86;
			NimStringV2 colontmpD__87;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T224_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T225_;
			NimStringV2* T231_;
			NimStringV2* T232_;
			tyArray__A2YC0h9cZydgH7zGAndH9bLg T233_;
			colontmpD__81 = NIM_NIL;
			colontmpD__82.len = 0; colontmpD__82.p = NIM_NIL;
			colontmpD__83.len = 0; colontmpD__83.p = NIM_NIL;
			colontmpD__84.len = 0; colontmpD__84.p = NIM_NIL;
			colontmpD__85.len = 0; colontmpD__85.p = NIM_NIL;
			colontmpD__86.len = 0; colontmpD__86.p = NIM_NIL;
			colontmpD__87.len = 0; colontmpD__87.p = NIM_NIL;
			colontmpD__81 = getSysType__magicsys_u55((*(*(*p_p0).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			getTemp__cgen_u9546(p_p0, colontmpD__81, NIM_FALSE, (&i_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			T224_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T224_, (&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			T225_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T225_, (&b_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T230_;
				if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA228_;
				nimZeroMem((void*)(&T230_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				getTemp__cgen_u9546(p_p0, setType_1, NIM_FALSE, (&T230_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
				eqsink___ast_u6293((&(*d_p2)), T230_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			}
LA228_: ;
			T231_ = (NimStringV2*)0;
			T231_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			addIndent__cgen_u315(p_p0, T231_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			T232_ = (NimStringV2*)0;
			T232_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			colontmpD__82 = rdLoc__cgen_u470(i_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			T233_[0] = colontmpD__82;
			colontmpD__83 = rope__ropes_u15(((NI64) (size_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			T233_[1] = colontmpD__83;
			colontmpD__84 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			T233_[2] = colontmpD__84;
			colontmpD__85 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			T233_[3] = colontmpD__85;
			colontmpD__86 = rdLoc__cgen_u470(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			T233_[4] = colontmpD__86;
			T233_[5] = lookupOpr__cgen_u24609[(op_p3)- 117];
			colontmpD__87 = percent___cgen_u25105(T233_, 6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA223_;
			prepareAdd((&(*T232_)), colontmpD__87.len + 0);
appendString((&(*T232_)), colontmpD__87);
			{
				LA223_:;
			}
			{
				oldNimErrFin223_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__87);
				eqdestroy___system_u2691(colontmpD__86);
				eqdestroy___system_u2691(colontmpD__85);
				eqdestroy___system_u2691(colontmpD__84);
				eqdestroy___system_u2691(colontmpD__83);
				eqdestroy___system_u2691(colontmpD__82);
				eqdestroy___ast_u3378(colontmpD__81);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin223_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)132):
		{
			genInOp__cgen_u24553(p_p0, e_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2445, TM__MQdRN7fpbG7rPm4JpVVAhA_2446);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		}
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(setType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(i_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDefault__cgen_u23189)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T5_;
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA3_;
		nimZeroMem((void*)(&T5_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_TRUE, (&T5_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqsink___ast_u6293((&(*d_p2)), T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		resetLoc__cgen_u13360(p_p0, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genEcho__cgen_u22861)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin18_;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin65_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 argX60gensym5027__1;
		if (!!(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41)))) goto LA3_;
		argX60gensym5027__1.len = 0; argX60gensym5027__1.p = NIM_NIL;
		argX60gensym5027__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_2447);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, argX60gensym5027__1, TM__MQdRN7fpbG7rPm4JpVVAhA_2447);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym5027__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		NimStringV2 args_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		NimStringV2 res_1;
		NimStringV2* T40_;
		NimStringV2* T41_;
		if (!((*(*(*(*p_p0).module).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)26))) goto LA10_;
		args_1.len = 0; args_1.p = NIM_NIL;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_1.len = 0; res_1.p = NIM_NIL;
		args_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2448;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
			tySequence__9ahcSjIErJohSBBFLwuF56Q colontmp_;
			NI i_1;
			NI i_2;
			NI L_1;
			NI T15_;
			it_1 = NIM_NIL;
			colontmp_.len = 0; colontmp_.p = NIM_NIL;
			i_1 = (NI)0;
			eqcopy___ast_u3699((&colontmp_), (*n_p1)._kind_6.sons);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			i_2 = ((NI)0);
			T15_ = colontmp_.len;
			L_1 = T15_;
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
					if (!(i_2 < L_1)) goto LA17;
					colontmpD_ = NIM_NIL;
					i_1 = i_2;
					eqcopy___ast_u3255(&it_1, colontmp_.p->data[i_2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					{
						colontmpD_ = skipConv__types_u3715(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						if (!((*colontmpD_).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA21_;
						prepareAdd((&args_1), 4);
appendString((&args_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2450);
					}
					goto LA19_;
LA21_: ;
					{
						NI T24_;
						tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T27_;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T28_;
						NI T33_;
						T24_ = (NI)0;
						T24_ = len__ast_u3190(n_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						if (!!((T24_ == ((NI)0)))) goto LA25_;
						T27_ = 0;
						nimZeroMem((void*)(&T28_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						initLocExpr__cgen_u14111(p_p0, it_1, T27_, (&T28_));
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						eqsink___ast_u6293((&a_1), T28_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						{
							if (!(((NI)0) < i_1)) goto LA31_;
							prepareAdd((&args_1), 2);
appendString((&args_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2451);
						}
LA31_: ;
						T33_ = (NI)0;
						T33_ = detectStrVersion__cgen_u579((*p_p0).module);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						switch (T33_) {
						case ((NI)2):
						{
							NimStringV2 res_2;
							NimStringV2 colontmpD__2;
							NimStringV2 colontmpD__3;
							res_2.len = 0; res_2.p = NIM_NIL;
							colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
							colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
							res_2 = rawNewString(((NI)80));
							prepareAdd((&res_2), 16);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2453);
							colontmpD__2 = rdLoc__cgen_u470(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							cgFormatValue__cgen_u163((&res_2), colontmpD__2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2455);
							colontmpD__3 = rdLoc__cgen_u470(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							cgFormatValue__cgen_u163((&res_2), colontmpD__3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							prepareAdd((&res_2), 5);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2457);
							prepareAdd((&args_1), res_2.len + 0);
appendString((&args_1), res_2);
							eqdestroy___system_u2691(colontmpD__3);
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___system_u2691(res_2);
						}
						break;
						default:
						{
							NimStringV2 res_3;
							NimStringV2 colontmpD__4;
							NimStringV2 colontmpD__5;
							res_3.len = 0; res_3.p = NIM_NIL;
							colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
							colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
							res_3 = rawNewString(((NI)80));
							prepareAdd((&res_3), 16);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2458);
							colontmpD__4 = rdLoc__cgen_u470(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							cgFormatValue__cgen_u163((&res_3), colontmpD__4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2460);
							colontmpD__5 = rdLoc__cgen_u470(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							cgFormatValue__cgen_u163((&res_3), colontmpD__5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
							prepareAdd((&res_3), 6);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2462);
							prepareAdd((&args_1), res_3.len + 0);
appendString((&args_1), res_3);
							eqdestroy___system_u2691(colontmpD__5);
							eqdestroy___system_u2691(colontmpD__4);
							eqdestroy___system_u2691(res_3);
						}
						break;
						}
					}
					goto LA19_;
LA25_: ;
LA19_: ;
					i_2 += ((NI)1);
					{
						LA18_:;
					}
					{
						oldNimErrFin18_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						*nimErr_ = oldNimErrFin18_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
				} LA17: ;
			}
			{
				LA14_:;
			}
			{
				oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3696(colontmp_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				eqdestroy___ast_u3252(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				*nimErr_ = oldNimErrFin14_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		}
		includeHeader__cgendata_u217((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2464);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		includeHeader__cgendata_u217((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2466);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T40_ = (NimStringV2*)0;
		T40_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		addIndent__cgen_u315(p_p0, T40_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T41_ = (NimStringV2*)0;
		T41_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 12);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2468);
		cgFormatValue__cgen_u163((&res_1), args_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2469);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA44_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2470);
		}
LA44_: ;
		prepareAdd((&(*T41_)), res_1.len + 0);
appendString((&(*T41_)), res_1);
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(args_1);
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA8_;
LA10_: ;
	{
		{
			NI T51_;
			NimStringV2 res_4;
			NimStringV2 colontmpD__6;
			NimStringV2* T55_;
			NimStringV2* T56_;
			NI T57_;
			T51_ = (NI)0;
			T51_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T51_ == ((NI)0))) goto LA52_;
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			T55_ = (NimStringV2*)0;
			T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			addIndent__cgen_u315(p_p0, T55_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			T56_ = (NimStringV2*)0;
			T56_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			res_4 = rawNewString(((NI)80));
			colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2472);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			prepareAdd((&res_4), 10);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2474);
			T57_ = (NI)0;
			T57_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			cgFormatValue__cgen_u166((&res_4), ((NI64) (T57_)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
			prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2475);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA60_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2476);
			}
LA60_: ;
			prepareAdd((&(*T56_)), res_4.len + 0);
appendString((&(*T56_)), res_4);
			{
				LA54_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(res_4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA49_;
LA52_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
			NimStringV2 res_5;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T66_;
			NimStringV2* T67_;
			NimStringV2* T68_;
			NI T69_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_5.len = 0; res_5.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T66_ = 0;
			initLocExpr__cgen_u14111(p_p0, n_p1, T66_, (&a_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			T67_ = (NimStringV2*)0;
			T67_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			addIndent__cgen_u315(p_p0, T67_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			T68_ = (NimStringV2*)0;
			T68_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			res_5 = rawNewString(((NI)80));
			colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2477);
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2478);
			colontmpD__8 = rdLoc__cgen_u470(a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2479);
			T69_ = (NI)0;
			T69_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			cgFormatValue__cgen_u166((&res_5), ((NI64) (T69_)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
			prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2480);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA72_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2481);
			}
LA72_: ;
			prepareAdd((&(*T68_)), res_5.len + 0);
appendString((&(*T68_)), res_5);
			{
				LA65_:;
			}
			{
				oldNimErrFin65_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(res_5);
				eqdestroy___ast_u6284(a_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin65_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA49_: ;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lhsDoesAlias__cgen_u23654)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_1;
		y_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(b_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i_1 = i_2;
					eqcopy___ast_u3255(&y_1, (*b_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					{
						tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ T8_;
						T8_ = (tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ)0;
						T8_ = isPartOf__aliases_u120(a_p0, y_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
						if (!!((T8_ == ((tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ)0)))) goto LA9_;
						result = NIM_TRUE;
						eqdestroy___ast_u3252(y_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA9_: ;
					i_2 += ((NI)1);
				} LA5: ;
			}
		}
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(y_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqConstr__cgen_u23663)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw arr_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* colontmpD_;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* colontmpD__2;
	NimStringV2 lit_1;
	NIM_BOOL doesAlias_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_1;
	NI T16_;
NIM_BOOL oldNimErrFin21_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&arr_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = (tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw*)0;
	colontmpD__2 = (tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw*)0;
	lit_1.len = 0; lit_1.p = NIM_NIL;
	nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	doesAlias_1 = lhsDoesAlias__cgen_u23654((*d_p2).lode, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!doesAlias_1) goto LA4_;
		colontmpD_ = (&tmp_1);
		dest_1 = colontmpD_;
	}
	goto LA2_;
LA4_: ;
	{
		colontmpD__2 = d_p2;
		dest_1 = colontmpD__2;
	}
LA2_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T11_;
		if (!doesAlias_1) goto LA9_;
		nimZeroMem((void*)(&T11_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T11_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&tmp_1), T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA7_;
LA9_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T15_;
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA13_;
		nimZeroMem((void*)(&T15_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T15_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&(*d_p2)), T15_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA7_;
LA13_: ;
LA7_: ;
	lit_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T16_ = (NI)0;
	T16_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	intLiteral__cgen_u14092(((NI64) (T16_)), (&lit_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* seqtype_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
		NimStringV2 colontmpD__8;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2* T22_;
		NimStringV2* T23_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA19_;
		seqtype_1 = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9 = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		eqcopy___ast_u3381(&seqtype_1, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		T22_ = (NimStringV2*)0;
		T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		addIndent__cgen_u315(p_p0, T22_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		T23_ = (NimStringV2*)0;
		T23_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		res_1 = rawNewString(((NI)80));
		colontmpD__3 = rdLoc__cgen_u470((*dest_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2482);
		cgFormatValue__cgen_u163((&res_1), lit_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2483);
		colontmpD__4 = rdLoc__cgen_u470((*dest_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2484);
		colontmpD__5 = getSeqPayloadType__cgen_u3522((*p_p0).module, seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2485);
		colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2486);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2487);
		cgFormatValue__cgen_u163((&res_1), lit_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2488);
		colontmpD__7 = elementType__ast_u5331(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		colontmpD__8 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__7, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&res_1), 15);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2489);
		colontmpD__9 = elementType__ast_u5331(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		colontmpD__10 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__9, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2490);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA26_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2491);
		}
LA26_: ;
		prepareAdd((&(*T23_)), res_1.len + 0);
appendString((&(*T23_)), res_1);
		{
			LA21_:;
		}
		{
			oldNimErrFin21_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___ast_u3378(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u3378(seqtype_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin21_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA17_;
LA19_: ;
	{
		NI T31_;
		T31_ = (NI)0;
		T31_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		genNewSeqAux__cgen_u23353(p_p0, (*dest_1), lit_1, (T31_ == ((NI)0)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA17_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				NimStringV2 lit_2;
				NimStringV2 res_2;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T36_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T37_;
				if (!(i_2 < colontmp_)) goto LA34;
				lit_2.len = 0; lit_2.p = NIM_NIL;
				res_2.len = 0; res_2.p = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				i_1 = i_2;
				T36_ = 0;
				nimZeroMem((void*)(&T37_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), (*n_p1)._kind_6.sons.p->data[i_1], ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T36_, (&T37_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				eqsink___ast_u6293((&arr_1), T37_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				lit_2 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				intLiteral__cgen_u14092(((NI64) (i_1)), (&lit_2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				res_2 = rawNewString(((NI)80));
				colontmpD__11 = rdLoc__cgen_u470((*dest_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				colontmpD__12 = dataField__cgen_u516(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2492);
				cgFormatValue__cgen_u163((&res_2), lit_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2493);
				eqsink___system_u2700((&arr_1.snippet), res_2);
				eqwasMoved___system_u2688((&res_2));
				arr_1.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3);
				expr__cgen_u14084(p_p0, (*n_p1)._kind_6.sons.p->data[i_1], (&arr_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
				i_2 += ((NI)1);
				{
					LA35_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(res_2);
					eqdestroy___system_u2691(lit_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA34: ;
		}
	}
	gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!doesAlias_1) goto LA42_;
		{
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA46_;
			eqsink___ast_u6293((&(*d_p2)), tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqwasMoved___ast_u6281((&tmp_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA44_;
LA46_: ;
		{
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T49_;
			T49_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p2), tmp_1, T49_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA44_: ;
	}
LA42_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(lit_1);
		eqdestroy___ast_u6284(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(arr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrToSeq__cgen_u23736)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw elem_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw arr_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T11_;
	NI L_1;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T12_;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL oldNimErrFin37_;
NIM_BOOL oldNimErrFin45_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&elem_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&arr_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		if (!((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA4_;
		eqcopy___ast_u3381(&(*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		genSeqConstr__cgen_u23663(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(arr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(elem_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T10_;
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA8_;
		nimZeroMem((void*)(&T10_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T10_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&(*d_p2)), T10_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	T11_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], T11_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_ = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	L_1 = toInt__int128_u257(T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* seqtype_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		NimStringV2 colontmpD__6;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2* T18_;
		NimStringV2* T19_;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA15_;
		seqtype_1 = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5 = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7 = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		eqcopy___ast_u3381(&seqtype_1, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		T18_ = (NimStringV2*)0;
		T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		addIndent__cgen_u315(p_p0, T18_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		T19_ = (NimStringV2*)0;
		T19_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = rdLoc__cgen_u470((*d_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2494);
		cgFormatValue__cgen_u166((&res_1), ((NI64) (L_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2495);
		colontmpD__2 = rdLoc__cgen_u470((*d_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2496);
		colontmpD__3 = getSeqPayloadType__cgen_u3522((*p_p0).module, seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2497);
		colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2498);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2499);
		cgFormatValue__cgen_u166((&res_1), ((NI64) (L_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2500);
		colontmpD__5 = elementType__ast_u5331(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		colontmpD__6 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__5, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 15);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2501);
		colontmpD__7 = elementType__ast_u5331(seqtype_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		colontmpD__8 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__7, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2502);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA22_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2503);
		}
LA22_: ;
		prepareAdd((&(*T19_)), res_1.len + 0);
appendString((&(*T19_)), res_1);
		{
			LA17_:;
		}
		{
			oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u3378(seqtype_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin17_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA13_;
LA15_: ;
	{
		NimStringV2 lit_1;
		lit_1.len = 0; lit_1.p = NIM_NIL;
		lit_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		intLiteral__cgen_u14092(((NI64) (L_1)), (&lit_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		genNewSeqAux__cgen_u23353(p_p0, (*d_p2), lit_1, (L_1 == ((NI)0)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		{
			LA27_:;
		}
		{
			eqdestroy___system_u2691(lit_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA13_: ;
	{
		if (!(L_1 < ((NI)10))) goto LA32_;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__11;
					NimStringV2 lit_2;
					NimStringV2 res_2;
					NimStringV2 colontmpD__12;
					NimStringV2 colontmpD__13;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__14;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__15;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__16;
					NimStringV2 res_3;
					NimStringV2 colontmpD__17;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T38_;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T39_;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T40_;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T41_;
					if (!(i_2 < L_1)) goto LA36;
					colontmpD__9 = NIM_NIL;
					colontmpD__10 = NIM_NIL;
					colontmpD__11 = NIM_NIL;
					lit_2.len = 0; lit_2.p = NIM_NIL;
					res_2.len = 0; res_2.p = NIM_NIL;
					colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
					colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
					colontmpD__14 = NIM_NIL;
					colontmpD__15 = NIM_NIL;
					colontmpD__16 = NIM_NIL;
					res_3.len = 0; res_3.p = NIM_NIL;
					colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
					i_1 = i_2;
					colontmpD__9 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					colontmpD__10 = elemType__types_u254(colontmpD__9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					colontmpD__11 = lodeTyp__cgen_u104(colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					T38_ = 0;
					nimZeroMem((void*)(&T39_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), colontmpD__11, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T38_, (&T39_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					eqsink___ast_u6293((&elem_1), T39_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					lit_2 = newRopeAppender__ropes_u7(((NI)80));
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					intLiteral__cgen_u14092(((NI64) (i_1)), (&lit_2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					res_2 = rawNewString(((NI)80));
					colontmpD__12 = rdLoc__cgen_u470((*d_p2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__12);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					colontmpD__13 = dataField__cgen_u516(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__13);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2504);
					cgFormatValue__cgen_u163((&res_2), lit_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2505);
					eqsink___system_u2700((&elem_1.snippet), res_2);
					eqwasMoved___system_u2688((&res_2));
					elem_1.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3);
					colontmpD__14 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					colontmpD__15 = elemType__types_u254(colontmpD__14);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					colontmpD__16 = lodeTyp__cgen_u104(colontmpD__15);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					T40_ = 0;
					nimZeroMem((void*)(&T41_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), colontmpD__16, a_1.storage, T40_, (&T41_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					eqsink___ast_u6293((&arr_1), T41_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					res_3 = rawNewString(((NI)80));
					colontmpD__17 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					cgFormatValue__cgen_u163((&res_3), colontmpD__17);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2506);
					cgFormatValue__cgen_u163((&res_3), lit_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2507);
					eqsink___system_u2700((&arr_1.snippet), res_3);
					eqwasMoved___system_u2688((&res_3));
					genAssignment__cgen_u12898(p_p0, elem_1, arr_1, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
					i_2 += ((NI)1);
					{
						LA37_:;
					}
					{
						oldNimErrFin37_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__17);
						eqdestroy___system_u2691(res_3);
						eqdestroy___ast_u3252(colontmpD__16);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(colontmpD__15);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(colontmpD__14);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(colontmpD__13);
						eqdestroy___system_u2691(colontmpD__12);
						eqdestroy___system_u2691(res_2);
						eqdestroy___system_u2691(lit_2);
						eqdestroy___ast_u3252(colontmpD__11);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(colontmpD__10);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(colontmpD__9);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin37_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA36: ;
			}
		}
	}
	goto LA30_;
LA32_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw i_3;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__18;
		NimStringV2 res_4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__19;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__20;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__21;
		NimStringV2 res_5;
		NimStringV2 colontmpD__22;
		NimStringV2 colontmpD__23;
		NimStringV2 colontmpD__24;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__25;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__26;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__27;
		NimStringV2 res_6;
		NimStringV2 colontmpD__28;
		NimStringV2 colontmpD__29;
		NimStringV2 colontmpD__30;
		NimStringV2* T46_;
		NimStringV2* T47_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T52_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T53_;
		NimStringV2* T54_;
		NimStringV2* T55_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T56_;
		nimZeroMem((void*)(&i_3), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__18 = NIM_NIL;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__19 = NIM_NIL;
		colontmpD__20 = NIM_NIL;
		colontmpD__21 = NIM_NIL;
		res_5.len = 0; res_5.p = NIM_NIL;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
		colontmpD__25 = NIM_NIL;
		colontmpD__26 = NIM_NIL;
		colontmpD__27 = NIM_NIL;
		res_6.len = 0; res_6.p = NIM_NIL;
		colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
		colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
		colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
		colontmpD__18 = getSysType__magicsys_u55((*(*(*p_p0).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		getTemp__cgen_u9546(p_p0, colontmpD__18, NIM_FALSE, (&i_3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T46_ = (NimStringV2*)0;
		T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		addIndent__cgen_u315(p_p0, T46_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T47_ = (NimStringV2*)0;
		T47_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		res_4 = rawNewString(((NI)80));
		prepareAdd((&res_4), 5);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2508);
		cgFormatValue__cgen_u163((&res_4), i_3.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_4), 6);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2509);
		cgFormatValue__cgen_u163((&res_4), i_3.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2510);
		cgFormatValue__cgen_u166((&res_4), ((NI64) (L_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2511);
		cgFormatValue__cgen_u163((&res_4), i_3.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_4), 5);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2512);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA50_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2513);
		}
LA50_: ;
		prepareAdd((&(*T47_)), res_4.len + 0);
appendString((&(*T47_)), res_4);
		colontmpD__19 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		colontmpD__20 = elemType__types_u254(colontmpD__19);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		colontmpD__21 = lodeTyp__cgen_u104(colontmpD__20);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T52_ = 0;
		initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), colontmpD__21, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T52_, (&elem_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		res_5 = rawNewString(((NI)80));
		colontmpD__22 = rdLoc__cgen_u470((*d_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__22);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		colontmpD__23 = dataField__cgen_u516(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__23);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2514);
		colontmpD__24 = rdLoc__cgen_u470(i_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__24);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2515);
		eqsink___system_u2700((&elem_1.snippet), res_5);
		eqwasMoved___system_u2688((&res_5));
		elem_1.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3);
		colontmpD__25 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		colontmpD__26 = elemType__types_u254(colontmpD__25);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		colontmpD__27 = lodeTyp__cgen_u104(colontmpD__26);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T53_ = 0;
		initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), colontmpD__27, a_1.storage, T53_, (&arr_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		res_6 = rawNewString(((NI)80));
		colontmpD__28 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__28);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2516);
		colontmpD__29 = rdLoc__cgen_u470(i_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		cgFormatValue__cgen_u163((&res_6), colontmpD__29);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2517);
		eqsink___system_u2700((&arr_1.snippet), res_6);
		eqwasMoved___system_u2688((&res_6));
		genAssignment__cgen_u12898(p_p0, elem_1, arr_1, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T54_ = (NimStringV2*)0;
		T54_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		addIndent__cgen_u315(p_p0, T54_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T55_ = (NimStringV2*)0;
		T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		colontmpD__30 = percent___cgen_u9681(T56_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&(*T55_)), colontmpD__30.len + 0);
appendString((&(*T55_)), colontmpD__30);
		{
			LA45_:;
		}
		{
			oldNimErrFin45_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__30);
			eqdestroy___system_u2691(colontmpD__29);
			eqdestroy___system_u2691(colontmpD__28);
			eqdestroy___system_u2691(res_6);
			eqdestroy___ast_u3252(colontmpD__27);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__25);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__24);
			eqdestroy___system_u2691(colontmpD__23);
			eqdestroy___system_u2691(colontmpD__22);
			eqdestroy___system_u2691(res_5);
			eqdestroy___ast_u3252(colontmpD__21);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__20);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(colontmpD__19);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(res_4);
			eqdestroy___ast_u3378(colontmpD__18);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(i_3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin45_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA30_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(arr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(elem_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDeepCopy__cgen_u20983)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin38_;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin53_;
NIM_BOOL oldNimErrFin69_;
NIM_BOOL oldNimErrFin63_;
NIM_BOOL oldNimErrFin88_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ty_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = t__cgen_u97(dest_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ty_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_2524);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*ty_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2* T4_;
		NimStringV2* T5_;
		NimStringV2 T6_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6 = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T4_ = (NimStringV2*)0;
		T4_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		addIndent__cgen_u315(p_p0, T4_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		T5_ = (NimStringV2*)0;
		T5_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		res_1 = rawNewString(((NI)80));
		colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2526);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		prepareAdd((&res_1), 8);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2527);
		colontmpD__3 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2528);
		T6_.len = 0; T6_.p = NIM_NIL;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmpX60gensym4213__1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T12_;
			if (!(src_p2.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6))) goto LA9_;
			nimZeroMem((void*)(&tmpX60gensym4213__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__8 = NIM_NIL;
			colontmpD__8 = t__cgen_u97(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			getTemp__cgen_u9546(p_p0, colontmpD__8, NIM_FALSE, (&tmpX60gensym4213__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			T12_ = 0;
			genAssignment__cgen_u12898(p_p0, tmpX60gensym4213__1, src_p2, T12_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			colontmpD__4 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, tmpX60gensym4213__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			T6_ = colontmpD__4;
			{
				LA11_:;
			}
			{
				oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				eqdestroy___ast_u6284(tmpX60gensym4213__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				*nimErr_ = oldNimErrFin11_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		goto LA7_;
LA9_: ;
		{
			colontmpD__5 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			T6_ = colontmpD__5;
			{
				LA16_:;
			}
			{
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
LA7_: ;
		cgFormatValue__cgen_u163((&res_1), T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2529);
		colontmpD__6 = t__cgen_u97(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		colontmpD__7 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__6, (*dest_p1.lode).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2530);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA21_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2531);
		}
LA21_: ;
		prepareAdd((&(*T5_)), res_1.len + 0);
appendString((&(*T5_)), res_1);
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___ast_u3378(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(res_1);
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__13;
			NimStringV2 colontmpD__14;
			NimStringV2* T31_;
			NimStringV2* T32_;
			NimStringV2 T33_;
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA28_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13 = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			T31_ = (NimStringV2*)0;
			T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			addIndent__cgen_u315(p_p0, T31_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T32_ = (NimStringV2*)0;
			T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			res_2 = rawNewString(((NI)80));
			colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2532);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2533);
			colontmpD__10 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2534);
			T33_.len = 0; T33_.p = NIM_NIL;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmpX60gensym4228__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__15;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T39_;
				if (!(src_p2.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6))) goto LA36_;
				nimZeroMem((void*)(&tmpX60gensym4228__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__15 = NIM_NIL;
				colontmpD__15 = t__cgen_u97(src_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
				getTemp__cgen_u9546(p_p0, colontmpD__15, NIM_FALSE, (&tmpX60gensym4228__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
				T39_ = 0;
				genAssignment__cgen_u12898(p_p0, tmpX60gensym4228__1, src_p2, T39_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
				colontmpD__11 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, tmpX60gensym4228__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
				T33_ = colontmpD__11;
				{
					LA38_:;
				}
				{
					oldNimErrFin38_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__15);
					if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
					eqdestroy___ast_u6284(tmpX60gensym4228__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
					*nimErr_ = oldNimErrFin38_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			}
			goto LA34_;
LA36_: ;
			{
				colontmpD__12 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, src_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
				T33_ = colontmpD__12;
				{
					LA43_:;
				}
				{
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			}
LA34_: ;
			cgFormatValue__cgen_u163((&res_2), T33_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2535);
			colontmpD__13 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			colontmpD__14 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__13, (*dest_p1.lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2536);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA48_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2537);
			}
LA48_: ;
			prepareAdd((&(*T32_)), res_2.len + 0);
appendString((&(*T32_)), res_2);
			{
				LA30_:;
			}
			{
				oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___ast_u3378(colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(res_2);
				*nimErr_ = oldNimErrFin30_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA26_;
LA28_: ;
		{
			NimStringV2 res_3;
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			NimStringV2 colontmpD__18;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__19;
			NimStringV2 colontmpD__20;
			NimStringV2* T54_;
			NimStringV2* T55_;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			colontmpD__19 = NIM_NIL;
			colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
			T54_ = (NimStringV2*)0;
			T54_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			addIndent__cgen_u315(p_p0, T54_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			T55_ = (NimStringV2*)0;
			T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			res_3 = rawNewString(((NI)80));
			colontmpD__16 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2539);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__16);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2540);
			colontmpD__17 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__17);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2541);
			colontmpD__18 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__18);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2542);
			colontmpD__19 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			colontmpD__20 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__19, (*dest_p1.lode).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__20);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2543);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA58_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2544);
			}
LA58_: ;
			prepareAdd((&(*T55_)), res_3.len + 0);
appendString((&(*T55_)), res_3);
			{
				LA53_:;
			}
			{
				oldNimErrFin53_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__20);
				eqdestroy___ast_u3378(colontmpD__19);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__18);
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(res_3);
				*nimErr_ = oldNimErrFin53_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA26_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		NimStringV2 source_1;
		NimStringV2 res_4;
		NimStringV2 colontmpD__21;
		NimStringV2 colontmpD__22;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__23;
		NimStringV2 colontmpD__24;
		NimStringV2 T64_;
		NimStringV2* T74_;
		NimStringV2* T75_;
		source_1.len = 0; source_1.p = NIM_NIL;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		colontmpD__23 = NIM_NIL;
		colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
		T64_.len = 0; T64_.p = NIM_NIL;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmpX60gensym4244__1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__25;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T70_;
			if (!(src_p2.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6))) goto LA67_;
			nimZeroMem((void*)(&tmpX60gensym4244__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__25 = NIM_NIL;
			colontmpD__25 = t__cgen_u97(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			getTemp__cgen_u9546(p_p0, colontmpD__25, NIM_FALSE, (&tmpX60gensym4244__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			T70_ = 0;
			genAssignment__cgen_u12898(p_p0, tmpX60gensym4244__1, src_p2, T70_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			source_1 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, tmpX60gensym4244__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			{
				LA69_:;
			}
			{
				oldNimErrFin69_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__25);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				eqdestroy___ast_u6284(tmpX60gensym4244__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				*nimErr_ = oldNimErrFin69_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		}
		goto LA65_;
LA67_: ;
		{
			source_1 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		}
LA65_: ;
		T74_ = (NimStringV2*)0;
		T74_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		addIndent__cgen_u315(p_p0, T74_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		T75_ = (NimStringV2*)0;
		T75_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		res_4 = rawNewString(((NI)80));
		colontmpD__21 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2546);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__21);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		prepareAdd((&res_4), 8);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2547);
		colontmpD__22 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__22);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		prepareAdd((&res_4), 9);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2548);
		cgFormatValue__cgen_u163((&res_4), source_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2549);
		cgFormatValue__cgen_u163((&res_4), source_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		prepareAdd((&res_4), 10);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2551);
		colontmpD__23 = t__cgen_u97(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		colontmpD__24 = genTypeInfoV1__cgen_u9076((*p_p0).module, colontmpD__23, (*dest_p1.lode).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__24);
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2552);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA78_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2553);
		}
LA78_: ;
		prepareAdd((&(*T75_)), res_4.len + 0);
appendString((&(*T75_)), res_4);
		{
			LA63_:;
		}
		{
			oldNimErrFin63_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__24);
			eqdestroy___ast_u3378(colontmpD__23);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD__22);
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(res_4);
			eqdestroy___system_u2691(source_1);
			*nimErr_ = oldNimErrFin63_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		{
			tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T85_;
			NimStringV2 res_5;
			NimStringV2 colontmpD__26;
			NimStringV2 colontmpD__27;
			NimStringV2 colontmpD__28;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__29;
			NimStringV2* T89_;
			NimStringV2* T90_;
			NI64 T91_;
			T85_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
			T85_ = mapSetType__cgen_u1311((*(*(*p_p0).module).g).config, ty_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T85_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17))) goto LA86_;
			res_5.len = 0; res_5.p = NIM_NIL;
			colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
			colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
			colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
			colontmpD__29 = NIM_NIL;
			T89_ = (NimStringV2*)0;
			T89_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			addIndent__cgen_u315(p_p0, T89_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			T90_ = (NimStringV2*)0;
			T90_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			res_5 = rawNewString(((NI)80));
			colontmpD__26 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2554);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			prepareAdd((&res_5), 8);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2555);
			colontmpD__27 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__27);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			prepareAdd((&res_5), 19);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2556);
			colontmpD__28 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__28);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2557);
			colontmpD__29 = t__cgen_u97(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			T91_ = (NI64)0;
			T91_ = getSize__types_u3397((*(*(*p_p0).module).g).config, colontmpD__29);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			cgFormatValue__cgen_u166((&res_5), T91_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
			prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2558);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA94_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2559);
			}
LA94_: ;
			prepareAdd((&(*T90_)), res_5.len + 0);
appendString((&(*T90_)), res_5);
			{
				LA88_:;
			}
			{
				oldNimErrFin88_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__29);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___system_u2691(colontmpD__28);
				eqdestroy___system_u2691(colontmpD__27);
				eqdestroy___system_u2691(colontmpD__26);
				eqdestroy___system_u2691(res_5);
				*nimErr_ = oldNimErrFin88_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA83_;
LA86_: ;
		{
			NimStringV2 res_6;
			NimStringV2 colontmpD__30;
			NimStringV2 colontmpD__31;
			NimStringV2* T99_;
			NimStringV2* T100_;
			res_6.len = 0; res_6.p = NIM_NIL;
			colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
			colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
			T99_ = (NimStringV2*)0;
			T99_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			addIndent__cgen_u315(p_p0, T99_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T100_ = (NimStringV2*)0;
			T100_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			res_6 = rawNewString(((NI)80));
			colontmpD__30 = rdLoc__cgen_u470(dest_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__30);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_6), 3);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2560);
			colontmpD__31 = rdLoc__cgen_u470(src_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_6), colontmpD__31);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2561);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA103_;
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2562);
			}
LA103_: ;
			prepareAdd((&(*T100_)), res_6.len + 0);
appendString((&(*T100_)), res_6);
			eqdestroy___system_u2691(colontmpD__31);
			eqdestroy___system_u2691(colontmpD__30);
			eqdestroy___system_u2691(res_6);
		}
LA83_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	{
		NimStringV2 res_7;
		NimStringV2 colontmpD__32;
		NimStringV2 colontmpD__33;
		NimStringV2* T106_;
		NimStringV2* T107_;
		res_7.len = 0; res_7.p = NIM_NIL;
		colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
		colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
		T106_ = (NimStringV2*)0;
		T106_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T106_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T107_ = (NimStringV2*)0;
		T107_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_7 = rawNewString(((NI)80));
		colontmpD__32 = rdLoc__cgen_u470(dest_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__32);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 3);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2563);
		colontmpD__33 = rdLoc__cgen_u470(src_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_7), colontmpD__33);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2564);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA110_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_2565);
		}
LA110_: ;
		prepareAdd((&(*T107_)), res_7.len + 0);
appendString((&(*T107_)), res_7);
		eqdestroy___system_u2691(colontmpD__33);
		eqdestroy___system_u2691(colontmpD__32);
		eqdestroy___system_u2691(res_7);
	}
	break;
	default:
	{
		NimStringV2 colontmpD__34;
		NimStringV2 colontmpD__35;
		NimStringV2 T114_;
		colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
		colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
		T114_.len = 0; T114_.p = NIM_NIL;
		colontmpD__34 = dollar___ast_u182((*ty_1).kind);
		T114_ = rawNewString(colontmpD__34.len + 13);
appendString((&T114_), TM__MQdRN7fpbG7rPm4JpVVAhA_2567);
appendString((&T114_), colontmpD__34);
		colontmpD__35 = T114_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, colontmpD__35, TM__MQdRN7fpbG7rPm4JpVVAhA_2568);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		{
			LA113_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__35);
			eqdestroy___system_u2691(colontmpD__34);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genWasMoved__cgen_u25622)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n1_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	n1_1 = NIM_NIL;
	n1_1 = skipAddr__trees_u429((*n_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (((NI)0) < (*p_p0).withinBlockLeaveActions);
		if (!(T4_)) goto LA5_;
		T4_ = notYetAlive__cgen_u15541(n1_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA5_: ;
		if (!T4_) goto LA6_;
	}
	goto LA2_;
LA6_: ;
	{
		initLocExpr__cgen_u14111(p_p0, n1_1, 256, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		resetLoc__cgen_u13360(p_p0, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n1_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isSinkParam__ast_u7466)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3));
	if (!(T1_)) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*s_p0).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46));
	if (T3_) goto LA4_;
	T3_ = (((*(*s_p0).typ).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)4)))&63U)))!=0);
LA4_: ;
	T1_ = T3_;
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genMove__cgen_u25627)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin40_;
NIM_BOOL oldNimErrFin33_;
NIM_BOOL oldNimErrFin97_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = NIM_NIL;
	colontmpD_ = skipAddr__trees_u429((*n_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	initLocExpr__cgen_u14111(p_p0, colontmpD_, 256, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T4_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 res_2;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T8_;
		NimStringV2* T9_;
		NimStringV2* T10_;
		NimStringV2* T11_;
		NimStringV2* T12_;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_ == ((NI)4))) goto LA5_;
		nimZeroMem((void*)(&src_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T8_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], T8_, (&src_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T9_ = (NimStringV2*)0;
		T9_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		addIndent__cgen_u315(p_p0, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T10_ = (NimStringV2*)0;
		T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2569);
		colontmpD__2 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2571);
		colontmpD__3 = rdLoc__cgen_u470(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2573);
		prepareAdd((&(*T10_)), res_1.len + 0);
appendString((&(*T10_)), res_1);
		genStmts__cgen_u14081(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)3)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T11_ = (NimStringV2*)0;
		T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		addIndent__cgen_u315(p_p0, T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T12_ = (NimStringV2*)0;
		T12_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2574);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA15_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2575);
		}
LA15_: ;
		colontmpD__4 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_2), 7);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2576);
		colontmpD__5 = rdLoc__cgen_u470(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_2), 6);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2578);
		colontmpD__6 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_2), 5);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2580);
		colontmpD__7 = rdLoc__cgen_u470(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2582);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA19_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2583);
		}
LA19_: ;
		prepareAdd((&(*T12_)), res_2.len + 0);
appendString((&(*T12_)), res_2);
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(res_2);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u6284(src_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA5_: ;
	{
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T28_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA26_;
			nimZeroMem((void*)(&T28_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T28_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqsink___ast_u6293((&(*d_p2)), T28_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA26_: ;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T34_;
			if (!((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5))) goto LA31_;
			op_1 = NIM_NIL;
			T34_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p2), a_1, T34_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			op_1 = getAttachedOp__modulegraphs_u4987((*(*(*p_p0).module).g).graph, (*n_p1).typField, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			{
				if (!(op_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA37_;
				resetLoc__cgen_u13360(p_p0, (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			}
			goto LA35_;
LA37_: ;
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T41_;
				nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__8 = NIM_NIL;
				colontmpD__9 = NIM_NIL;
				colontmpD__10 = NIM_NIL;
				colontmpD__8 = newSymNode__ast_u5168(op_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
				T41_ = 0;
				initLocExpr__cgen_u14111(p_p0, colontmpD__8, T41_, (&b_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
				colontmpD__9 = t__cgen_u97(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
				colontmpD__10 = skipTypes__ast_u5379(colontmpD__9, TM__MQdRN7fpbG7rPm4JpVVAhA_1629);
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
				switch ((*colontmpD__10).kind) {
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
				case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
				{
					NimStringV2 s_1;
					NimStringV2 res_3;
					NimStringV2 colontmpD__11;
					NimStringV2* T57_;
					NimStringV2* T58_;
					s_1.len = 0; s_1.p = NIM_NIL;
					res_3.len = 0; res_3.p = NIM_NIL;
					colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
					{
						NIM_BOOL T45_;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__12;
						T45_ = (NIM_BOOL)0;
						T45_ = reifiedOpenArray__cgen_u14410(a_1.lode);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						if (!T45_) goto LA46_;
						colontmpD__12 = NIM_NIL;
						{
							NimStringV2 colontmpD__13;
							tyArray__YgExxhfgKcesA5EOUj1MOA T52_;
							colontmpD__12 = t__cgen_u97(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							if (!((*colontmpD__12).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD__12).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47))) goto LA50_;
							colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
							colontmpD__13 = rdLoc__cgen_u470(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							T52_[0] = colontmpD__13;
							s_1 = percent___cgen_u14575(T52_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							eqdestroy___system_u2691(colontmpD__13);
						}
						goto LA48_;
LA50_: ;
						{
							NimStringV2 colontmpD__14;
							tyArray__YgExxhfgKcesA5EOUj1MOA T54_;
							colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
							colontmpD__14 = rdLoc__cgen_u470(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							T54_[0] = colontmpD__14;
							s_1 = percent___cgen_u14580(T54_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
							eqdestroy___system_u2691(colontmpD__14);
						}
LA48_: ;
						eqdestroy___ast_u3378(colontmpD__12);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					}
					goto LA43_;
LA46_: ;
					{
						NimStringV2 colontmpD__15;
						tyArray__YgExxhfgKcesA5EOUj1MOA T56_;
						colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
						colontmpD__15 = rdLoc__cgen_u470(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						T56_[0] = colontmpD__15;
						s_1 = percent___cgen_u14585(T56_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						eqdestroy___system_u2691(colontmpD__15);
					}
LA43_: ;
					T57_ = (NimStringV2*)0;
					T57_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					addIndent__cgen_u315(p_p0, T57_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					T58_ = (NimStringV2*)0;
					T58_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					res_3 = rawNewString(((NI)80));
					colontmpD__11 = rdLoc__cgen_u470(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					cgFormatValue__cgen_u163((&res_3), colontmpD__11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2584);
					cgFormatValue__cgen_u163((&res_3), s_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2585);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA61_;
						prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2586);
					}
LA61_: ;
					prepareAdd((&(*T58_)), res_3.len + 0);
appendString((&(*T58_)), res_3);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(res_3);
					eqdestroy___system_u2691(s_1);
				}
				break;
				default:
				{
					{
						NIM_BOOL T66_;
						NimStringV2 res_4;
						NimStringV2 colontmpD__16;
						NimStringV2 colontmpD__17;
						NimStringV2* T70_;
						NimStringV2* T71_;
						T66_ = (NIM_BOOL)0;
						T66_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
						if (T66_) goto LA67_;
						T66_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA67_: ;
						if (!T66_) goto LA68_;
						res_4.len = 0; res_4.p = NIM_NIL;
						colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
						colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
						T70_ = (NimStringV2*)0;
						T70_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						addIndent__cgen_u315(p_p0, T70_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						T71_ = (NimStringV2*)0;
						T71_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						res_4 = rawNewString(((NI)80));
						colontmpD__16 = rdLoc__cgen_u470(b_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						cgFormatValue__cgen_u163((&res_4), colontmpD__16);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2587);
						colontmpD__17 = rdLoc__cgen_u470(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						cgFormatValue__cgen_u163((&res_4), colontmpD__17);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2588);
						{
							if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA74_;
							prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2589);
						}
LA74_: ;
						prepareAdd((&(*T71_)), res_4.len + 0);
appendString((&(*T71_)), res_4);
						eqdestroy___system_u2691(colontmpD__17);
						eqdestroy___system_u2691(colontmpD__16);
						eqdestroy___system_u2691(res_4);
					}
					goto LA64_;
LA68_: ;
					{
						NimStringV2 res_5;
						NimStringV2 colontmpD__18;
						NimStringV2 colontmpD__19;
						NimStringV2* T78_;
						NimStringV2* T79_;
						res_5.len = 0; res_5.p = NIM_NIL;
						colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
						colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
						T78_ = (NimStringV2*)0;
						T78_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
						addIndent__cgen_u315(p_p0, T78_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
						T79_ = (NimStringV2*)0;
						T79_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
						res_5 = rawNewString(((NI)80));
						colontmpD__18 = rdLoc__cgen_u470(b_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
						cgFormatValue__cgen_u163((&res_5), colontmpD__18);
						if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
						prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2590);
						colontmpD__19 = byRefLoc__cgen_u12841(p_p0, a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
						cgFormatValue__cgen_u163((&res_5), colontmpD__19);
						if (NIM_UNLIKELY(*nimErr_)) goto LA77_;
						prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2591);
						{
							if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA82_;
							prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2592);
						}
LA82_: ;
						prepareAdd((&(*T79_)), res_5.len + 0);
appendString((&(*T79_)), res_5);
						{
							LA77_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__19);
							eqdestroy___system_u2691(colontmpD__18);
							eqdestroy___system_u2691(res_5);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					}
LA64_: ;
				}
				break;
				}
				{
					LA40_:;
				}
				{
					oldNimErrFin40_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					eqdestroy___ast_u3378(colontmpD__9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					eqdestroy___ast_u3252(colontmpD__8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					eqdestroy___ast_u6284(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					*nimErr_ = oldNimErrFin40_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			}
LA35_: ;
			{
				LA33_:;
			}
			{
				oldNimErrFin33_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(op_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin33_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA29_;
LA31_: ;
		{
			{
				NIM_BOOL T93_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__20;
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T98_;
				T93_ = (NIM_BOOL)0;
				T93_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
				if (!(T93_)) goto LA94_;
				T93_ = isSinkParam__ast_u7466((*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA94_: ;
				if (!T93_) goto LA95_;
				nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__20 = NIM_NIL;
				colontmpD__20 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_306);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				getTemp__cgen_u9546(p_p0, colontmpD__20, NIM_FALSE, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				genAssignment__cgen_u12898(p_p0, tmp_1, a_1, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				T98_ = 0;
				genAssignment__cgen_u12898(p_p0, (*d_p2), tmp_1, T98_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				resetLoc__cgen_u13360(p_p0, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				{
					LA97_:;
				}
				{
					oldNimErrFin97_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__20);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u6284(tmp_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin97_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA91_;
LA95_: ;
			{
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T102_;
				T102_ = 0;
				genAssignment__cgen_u12898(p_p0, (*d_p2), a_1, T102_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA91_: ;
			resetLoc__cgen_u13360(p_p0, (&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA29_: ;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDestroy__cgen_u25746)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin51_;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin73_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
		if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA3_;
		arg_1 = NIM_NIL;
		t_1 = NIM_NIL;
		arg_1 = skipAddr__trees_u429((*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		t_1 = skipTypes__ast_u5379((*arg_1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		switch ((*t_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T8_;
			nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			T8_ = 0;
			initLocExpr__cgen_u14111(p_p0, arg_1, T8_, (&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			{
				NimStringV2 res_1;
				NimStringV2 colontmpD_;
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				NimStringV2* T14_;
				NimStringV2* T15_;
				if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)25)))&63U)))!=0)) goto LA11_;
				res_1.len = 0; res_1.p = NIM_NIL;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				T14_ = (NimStringV2*)0;
				T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				addIndent__cgen_u315(p_p0, T14_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				T15_ = (NimStringV2*)0;
				T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				res_1 = rawNewString(((NI)80));
				prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2593);
				colontmpD_ = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				cgFormatValue__cgen_u163((&res_1), colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				prepareAdd((&res_1), 8);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2595);
				colontmpD__2 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				prepareAdd((&res_1), 29);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2597);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA18_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2598);
				}
LA18_: ;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2599);
				colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2601);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2602);
				colontmpD__4 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				cgFormatValue__cgen_u163((&res_1), colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2604);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA22_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2605);
				}
LA22_: ;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2606);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA26_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2607);
				}
LA26_: ;
				prepareAdd((&(*T15_)), res_1.len + 0);
appendString((&(*T15_)), res_1);
				{
					LA13_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
					eqdestroy___system_u2691(res_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			}
			goto LA9_;
LA11_: ;
			{
				NimStringV2 res_2;
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2* T32_;
				NimStringV2* T33_;
				res_2.len = 0; res_2.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				T32_ = (NimStringV2*)0;
				T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				addIndent__cgen_u315(p_p0, T32_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				T33_ = (NimStringV2*)0;
				T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				res_2 = rawNewString(((NI)80));
				prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2608);
				colontmpD__5 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2609);
				colontmpD__6 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				prepareAdd((&res_2), 29);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2610);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA36_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2611);
				}
LA36_: ;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2612);
				colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2614);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2615);
				colontmpD__8 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
				prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2616);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA40_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2617);
				}
LA40_: ;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2618);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA44_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2619);
				}
LA44_: ;
				prepareAdd((&(*T33_)), res_2.len + 0);
appendString((&(*T33_)), res_2);
				{
					LA31_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(res_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			}
LA9_: ;
			{
				LA7_:;
			}
			{
				oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				*nimErr_ = oldNimErrFin7_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
			NimStringV2 res_3;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__13;
			NimStringV2 colontmpD__14;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T52_;
			NimStringV2* T53_;
			NimStringV2* T54_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13 = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			T52_ = 0;
			initLocExpr__cgen_u14111(p_p0, arg_1, T52_, (&a_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			T53_ = (NimStringV2*)0;
			T53_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			addIndent__cgen_u315(p_p0, T53_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			T54_ = (NimStringV2*)0;
			T54_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2620);
			colontmpD__9 = rdLoc__cgen_u470(a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			prepareAdd((&res_3), 8);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2621);
			colontmpD__10 = rdLoc__cgen_u470(a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			prepareAdd((&res_3), 29);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2622);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA57_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2623);
			}
LA57_: ;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2624);
			colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2626);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2627);
			colontmpD__12 = rdLoc__cgen_u470(a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			prepareAdd((&res_3), 16);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2629);
			colontmpD__13 = elementType__ast_u5331(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			colontmpD__14 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__13, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
			prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2630);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA61_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2631);
			}
LA61_: ;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2632);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA65_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2633);
			}
LA65_: ;
			prepareAdd((&(*T54_)), res_3.len + 0);
appendString((&(*T54_)), res_3);
			{
				LA51_:;
			}
			{
				oldNimErrFin51_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___ast_u3378(colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(res_3);
				eqdestroy___ast_u6284(a_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				*nimErr_ = oldNimErrFin51_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		break;
		default:
		{
		}
		break;
		}
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(arg_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__15;
		t_2 = NIM_NIL;
		op_1 = NIM_NIL;
		colontmpD__15 = NIM_NIL;
		t_2 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		op_1 = getAttachedOp__modulegraphs_u4987((*(*(*p_p0).module).g).graph, t_2, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		{
			NIM_BOOL T76_;
			NI T78_;
			T76_ = (NIM_BOOL)0;
			T76_ = !((op_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
			if (!(T76_)) goto LA77_;
			colontmpD__15 = getBody__modulegraphs_u17880((*(*(*p_p0).module).g).graph, op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
			T78_ = (NI)0;
			T78_ = len__ast_u3190(colontmpD__15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
			T76_ = !((T78_ == ((NI)0)));
LA77_: ;
			if (!T76_) goto LA79_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2635, TM__MQdRN7fpbG7rPm4JpVVAhA_2636);
			if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
		}
LA79_: ;
		{
			LA73_:;
		}
		{
			oldNimErrFin73_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__15);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin73_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAccessTypeField__cgen_u24158)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 nilCheck_1;
	NimStringV2 rt_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nilCheck_1.len = 0; nilCheck_1.p = NIM_NIL;
	rt_1.len = 0; rt_1.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	nilCheck_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2638;
	rt_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rdMType__cgen_u24093(p_p0, a_1, (&nilCheck_1), (&rt_1), NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, rt_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(rt_1);
		eqdestroy___system_u2691(nilCheck_1);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSlice__cgen_u25833)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyTuple__UV3llMMYFckfui8YMBuUZA tmpTuple_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	NimStringV2 x_1;
	NimStringV2 y_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	NimStringV2* T11_;
	NimStringV2* T12_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	x_1.len = 0; x_1.p = NIM_NIL;
	y_1.len = 0; y_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD_ = elementType__ast_u5331((*e_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65));
	if (!(T3_)) goto LA4_;
	colontmpD__2 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = ((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28));
LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = ((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5));
LA5_: ;
	tmpTuple_1 = genOpenArraySlice__cgen_u14422(p_p0, e_p1, (*e_p1).typField, colontmpD_, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	x_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u2688((&tmpTuple_1.Field0));
	y_1 = tmpTuple_1.Field1;
	eqwasMoved___system_u2688((&tmpTuple_1.Field1));
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T10_;
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA8_;
		nimZeroMem((void*)(&T10_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&T10_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&(*d_p2)), T10_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	T11_ = (NimStringV2*)0;
	T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T11_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_ = (NimStringV2*)0;
	T12_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	colontmpD__3 = rdLoc__cgen_u470((*d_p2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2639);
	cgFormatValue__cgen_u163((&res_1), x_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2640);
	colontmpD__4 = rdLoc__cgen_u470((*d_p2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2641);
	cgFormatValue__cgen_u163((&res_1), y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2642);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA15_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2643);
	}
LA15_: ;
	prepareAdd((&(*T12_)), res_1.len + 0);
appendString((&(*T12_)), res_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(y_1);
		eqdestroy___system_u2691(x_1);
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___stdZprivateZospaths2_u306(tmpTuple_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMagicExpr__cgen_u25880)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg op_p3) {
NIM_BOOL oldNimErrFin21_;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin83_;
NIM_BOOL oldNimErrFin100_;
NIM_BOOL oldNimErrFin106_;
NIM_BOOL oldNimErrFin113_;
NIM_BOOL oldNimErrFin124_;
NIM_BOOL oldNimErrFin141_;
NIM_BOOL oldNimErrFin152_;
NIM_BOOL oldNimErrFin177_;
NIM_BOOL oldNimErrFin191_;
NIM_BOOL oldNimErrFin196_;
NIM_BOOL oldNimErrFin201_;
NIM_BOOL oldNimErrFin224_;
NIM_BOOL oldNimErrFin239_;
NIM_BOOL oldNimErrFin270_;
NIM_BOOL oldNimErrFin263_;
NIM_BOOL oldNimErrFin258_;
NIM_BOOL oldNimErrFin280_;
NIM_BOOL oldNimErrFin289_;
NIM_BOOL oldNimErrFin293_;
NIM_BOOL oldNimErrFin297_;
NIM_BOOL oldNimErrFin319_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch (op_p3) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)107):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)106):
	{
		genAndOr__cgen_u22826(p_p0, e_p1, d_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)100):
	{
		unaryArith__cgen_u21772(p_p0, e_p1, d_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)93) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)95):
	{
		unaryArithOverflow__cgen_u21433(p_p0, e_p1, d_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)53) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)56):
	{
		binaryFloatArith__cgen_u25512(p_p0, e_p1, d_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)57) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)90):
	{
		binaryArith__cgen_u21495(p_p0, e_p1, d_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)92):
	{
		genEqProc__cgen_u21704(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)46) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)52):
	{
		binaryArithOverflow__cgen_u21248(p_p0, e_p1, d_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)133):
	{
		genRepr__cgen_u23976(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)261):
	{
		genGetTypeInfo__cgen_u24145(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)262):
	{
		genGetTypeInfoV2__cgen_u24150(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)141):
	{
		genSwap__cgen_u24460(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)29):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)30):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* underlying_1;
		underlying_1 = NIM_NIL;
		underlying_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1893);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = !((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)5)))&31U)))!=0));
			if (T16_) goto LA17_;
			T16_ = ((*underlying_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*underlying_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
LA17_: ;
			if (!T16_) goto LA18_;
			binaryStmt__cgen_u21157(p_p0, e_p1, d_p2, opr__cgen_u25885[(op_p3)- 29]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
		goto LA14_;
LA18_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ranged_1;
			NimStringV2 res_1;
			NimStringV2 storageX60gensym6479__1;
			NimStringV2 resultX60gensym6479__1;
			NimStringV2 res_2;
			NimStringV2 res_3;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 res_4;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T22_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T23_;
			NI64 sizeX60gensym6479__1;
			NimStringV2 T24_;
			NimStringV2* T30_;
			NimStringV2* T31_;
			NimStringV2* T36_;
			NimStringV2* T37_;
			NimStringV2 T38_;
			NimStringV2* T44_;
			NimStringV2* T45_;
			NimStringV2* T46_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T71_;
			nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			ranged_1 = NIM_NIL;
			res_1.len = 0; res_1.p = NIM_NIL;
			storageX60gensym6479__1.len = 0; storageX60gensym6479__1.p = NIM_NIL;
			resultX60gensym6479__1.len = 0; resultX60gensym6479__1.p = NIM_NIL;
			res_2.len = 0; res_2.p = NIM_NIL;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T22_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T22_, (&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T23_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T23_, (&b_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			ranged_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1903);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			sizeX60gensym6479__1 = getSize__types_u3397((*(*(*p_p0).module).g).config, ranged_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T24_.len = 0; T24_.p = NIM_NIL;
			{
				if (!(sizeX60gensym6479__1 < ((NI64) ((*(*(*(*p_p0).module).g).config).target.intSize)))) goto LA27_;
				storageX60gensym6479__1 = TM__MQdRN7fpbG7rPm4JpVVAhA_1904;
			}
			goto LA25_;
LA27_: ;
			{
				storageX60gensym6479__1 = getTypeDesc__cgen_u8738((*p_p0).module, ranged_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			}
LA25_: ;
			resultX60gensym6479__1 = getTempName__cgen_u462((*p_p0).module);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T30_ = (NimStringV2*)0;
			T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			addIndent__cgen_u315(p_p0, T30_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T31_ = (NimStringV2*)0;
			T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			res_2 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_2), storageX60gensym6479__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1905);
			cgFormatValue__cgen_u163((&res_2), resultX60gensym6479__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1906);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA34_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_1907);
			}
LA34_: ;
			prepareAdd((&(*T31_)), res_2.len + 0);
appendString((&(*T31_)), res_2);
			T36_ = (NimStringV2*)0;
			T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			addIndent__cgen_u315(p_p0, T36_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T37_ = (NimStringV2*)0;
			T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1908);
			T38_.len = 0; T38_.p = NIM_NIL;
			{
				if (!((*underlying_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35))) goto LA41_;
				eqcopy___system_u2694((&colontmpD_), fun64__cgen_u25886[(op_p3)- 29]);
				T38_ = colontmpD_;
			}
			goto LA39_;
LA41_: ;
			{
				eqcopy___system_u2694((&colontmpD__2), fun__cgen_u25887[(op_p3)- 29]);
				T38_ = colontmpD__2;
			}
LA39_: ;
			colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, T38_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1909);
			colontmpD__4 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1910);
			colontmpD__5 = rdCharLoc__cgen_u12869(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1911);
			cgFormatValue__cgen_u163((&res_3), resultX60gensym6479__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_3), 5);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1912);
			colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1913);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_1914);
			prepareAdd((&(*T37_)), res_3.len + 0);
appendString((&(*T37_)), res_3);
			T44_ = (NimStringV2*)0;
			T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			raiseInstr__cgen_u457(p_p0, T44_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T45_ = (NimStringV2*)0;
			T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			addIndent__cgen_u315(p_p0, T45_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T46_ = (NimStringV2*)0;
			T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			res_4 = rawNewString(((NI)80));
			prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1915);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA49_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_1916);
			}
LA49_: ;
			prepareAdd((&(*T46_)), res_4.len + 0);
appendString((&(*T46_)), res_4);
			{
				NIM_BOOL T53_;
				NimStringV2 firstX60gensym6479__1;
				NimStringV2 lastX60gensym6479__1;
				NimStringV2 res_5;
				NimStringV2 colontmpD__9;
				NimStringV2 res_6;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T58_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T59_;
				NimStringV2* T60_;
				NimStringV2* T61_;
				NimStringV2* T62_;
				NimStringV2* T63_;
				NimStringV2* T64_;
				T53_ = (NIM_BOOL)0;
				T53_ = (sizeX60gensym6479__1 < ((NI64) ((*(*(*(*p_p0).module).g).config).target.intSize)));
				if (T53_) goto LA54_;
				T53_ = ((*ranged_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20) || (*ranged_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14));
LA54_: ;
				if (!T53_) goto LA55_;
				firstX60gensym6479__1.len = 0; firstX60gensym6479__1.p = NIM_NIL;
				lastX60gensym6479__1.len = 0; lastX60gensym6479__1.p = NIM_NIL;
				res_5.len = 0; res_5.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				res_6.len = 0; res_6.p = NIM_NIL;
				firstX60gensym6479__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T58_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ranged_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				intLiteral__cgen_u20135(T58_, (&firstX60gensym6479__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				lastX60gensym6479__1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T59_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ranged_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				intLiteral__cgen_u20135(T59_, (&lastX60gensym6479__1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T60_ = (NimStringV2*)0;
				T60_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				addIndent__cgen_u315(p_p0, T60_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T61_ = (NimStringV2*)0;
				T61_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				res_5 = rawNewString(((NI)80));
				prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1917);
				cgFormatValue__cgen_u163((&res_5), resultX60gensym6479__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1918);
				cgFormatValue__cgen_u163((&res_5), firstX60gensym6479__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1919);
				cgFormatValue__cgen_u163((&res_5), resultX60gensym6479__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1920);
				cgFormatValue__cgen_u163((&res_5), lastX60gensym6479__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1921);
				colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1922);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_1923);
				prepareAdd((&(*T61_)), res_5.len + 0);
appendString((&(*T61_)), res_5);
				T62_ = (NimStringV2*)0;
				T62_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				raiseInstr__cgen_u457(p_p0, T62_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T63_ = (NimStringV2*)0;
				T63_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				addIndent__cgen_u315(p_p0, T63_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				T64_ = (NimStringV2*)0;
				T64_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
				res_6 = rawNewString(((NI)80));
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1924);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA67_;
					prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_1925);
				}
LA67_: ;
				prepareAdd((&(*T64_)), res_6.len + 0);
appendString((&(*T64_)), res_6);
				{
					LA57_:;
				}
				{
					eqdestroy___system_u2691(res_6);
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(res_5);
					eqdestroy___system_u2691(lastX60gensym6479__1);
					eqdestroy___system_u2691(firstX60gensym6479__1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			}
LA55_: ;
			res_1 = resultX60gensym6479__1;
			eqwasMoved___system_u2688((&resultX60gensym6479__1));
			colontmpD__7 = getTypeDesc__cgen_u8738((*p_p0).module, ranged_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T71_[0] = colontmpD__7;
			T71_[1] = res_1;
			colontmpD__8 = percent___cgen_u21403(T71_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			putIntoDest__cgen_u21142(p_p0, (&a_1), (*e_p1)._kind_6.sons.p->data[((NI)1)], colontmpD__8, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			{
				LA21_:;
			}
			{
				oldNimErrFin21_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(res_4);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u2691(res_3);
				eqdestroy___system_u2691(res_2);
				eqdestroy___system_u2691(resultX60gensym6479__1);
				eqdestroy___system_u2691(storageX60gensym6479__1);
				eqdestroy___system_u2691(res_1);
				eqdestroy___ast_u3378(ranged_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				eqdestroy___ast_u6284(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				eqdestroy___ast_u6284(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				*nimErr_ = oldNimErrFin21_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
LA14_: ;
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(underlying_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)123):
	{
		genStrConcat__cgen_u22962(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)129):
	{
		{
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA80_;
			binaryStmtAddr__cgen_u21181(p_p0, e_p1, d_p2, TM__MQdRN7fpbG7rPm4JpVVAhA_1956);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA78_;
LA80_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw call_1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_2;
			NimStringV2 res_7;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T84_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T85_;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T86_;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T87_;
			nimZeroMem((void*)(&call_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&dest_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&b_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_7.len = 0; res_7.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			T84_ = 0;
			initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)9), e_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3), T84_, (&call_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			T85_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T85_, (&dest_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			T86_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T86_, (&b_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			res_7 = rawNewString(((NI)80));
			colontmpD__10 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_1958);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1959);
			colontmpD__11 = rdLoc__cgen_u470(dest_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			prepareAdd((&res_7), 2);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1960);
			colontmpD__12 = rdLoc__cgen_u470(b_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			cgFormatValue__cgen_u163((&res_7), colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_1961);
			eqsink___system_u2700((&call_1.snippet), res_7);
			eqwasMoved___system_u2688((&res_7));
			T87_ = 0;
			genAssignment__cgen_u12898(p_p0, dest_1, call_1, T87_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			{
				LA83_:;
			}
			{
				oldNimErrFin83_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(res_7);
				eqdestroy___ast_u6284(b_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u6284(dest_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u6284(call_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin83_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA78_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)130):
	{
		genStrAppend__cgen_u23037(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)131):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T96_;
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA94_;
			T96_ = NIM_NIL;
			T96_ = makeAddr__magicsys_u191((*e_p1)._kind_6.sons.p->data[((NI)1)], (*(*p_p0).module).Sup.idgen);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T96_); goto BeforeRet_;}
			eqsink___ast_u3261(&(*e_p1)._kind_6.sons.p->data[((NI)1)], T96_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			genCall__cgen_u15586(p_p0, e_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA92_;
LA94_: ;
		{
			genSeqElemAppend__cgen_u23129(p_p0, e_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA92_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)113):
	{
		genStrEquals__cgen_u25452(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)114):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6540__1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym6540__1;
		NimStringV2 res_8;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T101_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T102_;
		nimZeroMem((void*)(&aX60gensym6540__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&bX60gensym6540__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_8.len = 0; res_8.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		T101_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T101_, (&aX60gensym6540__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		T102_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T102_, (&bX60gensym6540__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		res_8 = rawNewString(((NI)80));
		prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2024);
		colontmpD__13 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2026);
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		cgFormatValue__cgen_u163((&res_8), colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2027);
		colontmpD__14 = rdLoc__cgen_u470(aX60gensym6540__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		cgFormatValue__cgen_u163((&res_8), colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		prepareAdd((&res_8), 2);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2028);
		colontmpD__15 = rdLoc__cgen_u470(bX60gensym6540__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		cgFormatValue__cgen_u163((&res_8), colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		prepareAdd((&res_8), 7);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_2030);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_8, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
		{
			LA100_:;
		}
		{
			oldNimErrFin100_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(res_8);
			eqdestroy___ast_u6284(bX60gensym6540__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(aX60gensym6540__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin100_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)115):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6558__1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw bX60gensym6558__1;
		NimStringV2 res_9;
		NimStringV2 colontmpD__16;
		NimStringV2 colontmpD__17;
		NimStringV2 colontmpD__18;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T107_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T108_;
		nimZeroMem((void*)(&aX60gensym6558__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&bX60gensym6558__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_9.len = 0; res_9.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		T107_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T107_, (&aX60gensym6558__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		T108_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T108_, (&bX60gensym6558__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		res_9 = rawNewString(((NI)80));
		prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2031);
		colontmpD__16 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2032);
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		cgFormatValue__cgen_u163((&res_9), colontmpD__16);
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2033);
		colontmpD__17 = rdLoc__cgen_u470(aX60gensym6558__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		cgFormatValue__cgen_u163((&res_9), colontmpD__17);
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		prepareAdd((&res_9), 2);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2034);
		colontmpD__18 = rdLoc__cgen_u470(bX60gensym6558__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		cgFormatValue__cgen_u163((&res_9), colontmpD__18);
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		prepareAdd((&res_9), 6);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_2036);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_9, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
		{
			LA106_:;
		}
		{
			oldNimErrFin106_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(res_9);
			eqdestroy___ast_u6284(bX60gensym6558__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(aX60gensym6558__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin106_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)142):
	{
		genIsNil__cgen_u21737(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)102):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6576__1;
		NimStringV2 res_10;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T114_;
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T120_;
		nimZeroMem((void*)(&aX60gensym6576__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_10.len = 0; res_10.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		T114_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T114_, (&aX60gensym6576__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		res_10 = rawNewString(((NI)80));
		colontmpD__19 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2043);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		cgFormatValue__cgen_u163((&res_10), colontmpD__19);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_2044);
		colontmpD__20 = rdLoc__cgen_u470(aX60gensym6576__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		cgFormatValue__cgen_u163((&res_10), colontmpD__20);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_2045);
		eqsink___system_u2700((&aX60gensym6576__1.snippet), res_10);
		eqwasMoved___system_u2688((&res_10));
		aX60gensym6576__1.flags &= ~(((NU16)1) << (((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15));
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T119_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA117_;
			nimZeroMem((void*)(&T119_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&T119_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
			eqsink___ast_u6293((&(*d_p2)), T119_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		}
LA117_: ;
		T120_ = 0;
		genAssignment__cgen_u12898(p_p0, (*d_p2), aX60gensym6576__1, T120_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
		{
			LA113_:;
		}
		{
			oldNimErrFin113_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(res_10);
			eqdestroy___ast_u6284(aX60gensym6576__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin113_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)101):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6585__1;
		NimStringV2 res_11;
		NimStringV2 colontmpD__21;
		NimStringV2 colontmpD__22;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T125_;
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T131_;
		nimZeroMem((void*)(&aX60gensym6585__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_11.len = 0; res_11.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		T125_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T125_, (&aX60gensym6585__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		res_11 = rawNewString(((NI)80));
		colontmpD__21 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2047);
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		cgFormatValue__cgen_u163((&res_11), colontmpD__21);
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2048);
		colontmpD__22 = rdLoc__cgen_u470(aX60gensym6585__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		cgFormatValue__cgen_u163((&res_11), colontmpD__22);
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_2049);
		eqsink___system_u2700((&aX60gensym6585__1.snippet), res_11);
		eqwasMoved___system_u2688((&res_11));
		aX60gensym6585__1.flags &= ~(((NU16)1) << (((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15));
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T130_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA128_;
			nimZeroMem((void*)(&T130_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&T130_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
			eqsink___ast_u6293((&(*d_p2)), T130_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		}
LA128_: ;
		T131_ = 0;
		genAssignment__cgen_u12898(p_p0, (*d_p2), aX60gensym6585__1, T131_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA124_;
		{
			LA124_:;
		}
		{
			oldNimErrFin124_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__22);
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(res_11);
			eqdestroy___ast_u6284(aX60gensym6585__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin124_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)103):
	{
		{
			NIM_BOOL T137_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6597__1;
			NimStringV2 res_12;
			NimStringV2 colontmpD__23;
			NimStringV2 colontmpD__24;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T142_;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T148_;
			T137_ = (NIM_BOOL)0;
			T137_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T137_) goto LA138_;
			T137_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA138_: ;
			if (!T137_) goto LA139_;
			nimZeroMem((void*)(&aX60gensym6597__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_12.len = 0; res_12.p = NIM_NIL;
			colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
			colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
			T142_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T142_, (&aX60gensym6597__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			res_12 = rawNewString(((NI)80));
			colontmpD__23 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2051);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			cgFormatValue__cgen_u163((&res_12), colontmpD__23);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			prepareAdd((&res_12), 12);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2053);
			colontmpD__24 = rdLoc__cgen_u470(aX60gensym6597__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			cgFormatValue__cgen_u163((&res_12), colontmpD__24);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_2054);
			eqsink___system_u2700((&aX60gensym6597__1.snippet), res_12);
			eqwasMoved___system_u2688((&res_12));
			aX60gensym6597__1.flags &= ~(((NU16)1) << (((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15));
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T147_;
				if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA145_;
				nimZeroMem((void*)(&T147_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&T147_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
				eqsink___ast_u6293((&(*d_p2)), T147_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			}
LA145_: ;
			T148_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p2), aX60gensym6597__1, T148_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
			{
				LA141_:;
			}
			{
				oldNimErrFin141_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__24);
				eqdestroy___system_u2691(colontmpD__23);
				eqdestroy___system_u2691(res_12);
				eqdestroy___ast_u6284(aX60gensym6597__1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin141_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA135_;
LA139_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6606__1;
			NimStringV2 res_13;
			NimStringV2 colontmpD__25;
			NimStringV2 colontmpD__26;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T153_;
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T159_;
			nimZeroMem((void*)(&aX60gensym6606__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			res_13.len = 0; res_13.p = NIM_NIL;
			colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
			colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
			T153_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T153_, (&aX60gensym6606__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
			res_13 = rawNewString(((NI)80));
			colontmpD__25 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2055);
			if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__25);
			if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
			prepareAdd((&res_13), 1);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_2056);
			colontmpD__26 = rdLoc__cgen_u470(aX60gensym6606__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
			cgFormatValue__cgen_u163((&res_13), colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
			prepareAdd((&res_13), 1);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_2057);
			eqsink___system_u2700((&aX60gensym6606__1.snippet), res_13);
			eqwasMoved___system_u2688((&res_13));
			aX60gensym6606__1.flags &= ~(((NU16)1) << (((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)0))) & 15));
			{
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T158_;
				if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA156_;
				nimZeroMem((void*)(&T158_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&T158_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
				eqsink___ast_u6293((&(*d_p2)), T158_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
			}
LA156_: ;
			T159_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p2), aX60gensym6606__1, T159_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
			gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA152_;
			{
				LA152_:;
			}
			{
				oldNimErrFin152_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__26);
				eqdestroy___system_u2691(colontmpD__25);
				eqdestroy___system_u2691(res_13);
				eqdestroy___ast_u6284(aX60gensym6606__1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin152_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA135_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)104):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)155):
	{
		expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)144):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)156) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)157):
	{
		genCall__cgen_u15586(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)105):
	{
		{
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA167_;
			genEnumToStr__cgen_u25869(p_p0, e_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA165_;
LA167_: ;
		{
			genRepr__cgen_u23976(p_p0, e_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA165_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)15):
	{
		genOf__cgen_u23972(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)32):
	{
		genNew__cgen_u23348(p_p0, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)33):
	{
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T178_;
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA175_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			T178_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T178_, (&a_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA177_;
			rawGenNew__cgen_u23197(p_p0, (&a_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2151, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA177_;
			gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA177_;
			{
				LA177_:;
			}
			{
				oldNimErrFin177_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(a_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin177_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA173_;
LA175_: ;
		{
			genNewFinalize__cgen_u23831(p_p0, e_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA173_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)34):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T187_;
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0)) goto LA185_;
			T187_ = NIM_NIL;
			T187_ = makeAddr__magicsys_u191((*e_p1)._kind_6.sons.p->data[((NI)1)], (*(*p_p0).module).Sup.idgen);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T187_); goto BeforeRet_;}
			eqsink___ast_u3261(&(*e_p1)._kind_6.sons.p->data[((NI)1)], T187_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			genCall__cgen_u15586(p_p0, e_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA183_;
LA185_: ;
		{
			genNewSeq__cgen_u23447(p_p0, e_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA183_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)35):
	{
		genNewSeqOfCap__cgen_u23475(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)10):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
		NimStringV2 colontmpD__27;
		NimStringV2 colontmpD__28;
		tyArray__YgExxhfgKcesA5EOUj1MOA T192_;
		t_1 = NIM_NIL;
		colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
		colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
		t_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2232);
		if (NIM_UNLIKELY(*nimErr_)) goto LA191_;
		colontmpD__27 = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA191_;
		T192_[0] = colontmpD__27;
		colontmpD__28 = percent___cgen_u26166(T192_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA191_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__28, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA191_;
		{
			LA191_:;
		}
		{
			oldNimErrFin191_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__28);
			eqdestroy___system_u2691(colontmpD__27);
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin191_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)11):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
		NimStringV2 colontmpD__29;
		NimStringV2 colontmpD__30;
		tyArray__YgExxhfgKcesA5EOUj1MOA T197_;
		t_2 = NIM_NIL;
		colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
		colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
		t_2 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2232);
		if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
		colontmpD__29 = getTypeDesc__cgen_u8738((*p_p0).module, t_2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
		T197_[0] = colontmpD__29;
		colontmpD__30 = percent___cgen_u26172(T197_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__30, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA196_;
		{
			LA196_:;
		}
		{
			oldNimErrFin196_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__30);
			eqdestroy___system_u2691(colontmpD__29);
			eqdestroy___ast_u3378(t_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin196_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)12):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dotExpr_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_3;
		NimStringV2 tname_1;
		NimStringV2 member_1;
		NimStringV2 colontmpD__31;
		NimStringV2 T210_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T217_;
		dotExpr_1 = NIM_NIL;
		t_3 = NIM_NIL;
		tname_1.len = 0; tname_1.p = NIM_NIL;
		member_1.len = 0; member_1.p = NIM_NIL;
		colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
		{
			if (!((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45))) goto LA204_;
			eqcopy___ast_u3255(&dotExpr_1, (*e_p1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA201_;
		}
		goto LA202_;
LA204_: ;
		{
			if (!((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46))) goto LA207_;
			eqcopy___ast_u3255(&dotExpr_1, (*(*e_p1)._kind_6.sons.p->data[((NI)1)])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA201_;
		}
		goto LA202_;
LA207_: ;
		{
			dotExpr_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2234, TM__MQdRN7fpbG7rPm4JpVVAhA_2235);
			if (NIM_UNLIKELY(*nimErr_)) goto LA201_;
		}
LA202_: ;
		t_3 = skipTypes__ast_u5379((*(*dotExpr_1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2232);
		if (NIM_UNLIKELY(*nimErr_)) goto LA201_;
		tname_1 = getTypeDesc__cgen_u8738((*p_p0).module, t_3, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA201_;
		T210_.len = 0; T210_.p = NIM_NIL;
		{
			NimStringV2 colontmpD__32;
			NimStringV2 T215_;
			if (!((*t_3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18))) goto LA213_;
			colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
			T215_.len = 0; T215_.p = NIM_NIL;
			colontmpD__32 = rope__ropes_u15(((NI64) ((*(*(*dotExpr_1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym).position)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA201_;
			T215_ = rawNewString(colontmpD__32.len + 5);
appendString((&T215_), TM__MQdRN7fpbG7rPm4JpVVAhA_2236);
appendString((&T215_), colontmpD__32);
			member_1 = T215_;
			eqdestroy___system_u2691(colontmpD__32);
		}
		goto LA211_;
LA213_: ;
		{
			eqcopy___system_u2694((&member_1), (*(*(*dotExpr_1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym).loc.snippet);
		}
LA211_: ;
		T217_[0] = tname_1;
		T217_[1] = member_1;
		colontmpD__31 = percent___cgen_u26193(T217_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA201_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__31, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA201_;
		{
			LA201_:;
		}
		{
			oldNimErrFin201_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__31);
			eqdestroy___system_u2691(member_1);
			eqdestroy___system_u2691(tname_1);
			eqdestroy___ast_u3378(t_3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(dotExpr_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin201_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)43):
	{
		genSomeCast__cgen_u25144(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)31):
	{
		genOrd__cgen_u25129(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)38):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)37):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)39):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)36):
	{
		genArrayLen__cgen_u24171(p_p0, e_p1, d_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)44):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6642__1;
		NimStringV2 res_14;
		NimStringV2 colontmpD__33;
		NimStringV2 colontmpD__34;
		NimStringV2 colontmpD__35;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T229_;
		NimStringV2* T230_;
		NimStringV2* T231_;
		nimZeroMem((void*)(&aX60gensym6642__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_14.len = 0; res_14.p = NIM_NIL;
		colontmpD__33.len = 0; colontmpD__33.p = NIM_NIL;
		colontmpD__34.len = 0; colontmpD__34.p = NIM_NIL;
		colontmpD__35.len = 0; colontmpD__35.p = NIM_NIL;
		{
			if (!!(((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0)))) goto LA227_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2278, TM__MQdRN7fpbG7rPm4JpVVAhA_2279);
			if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		}
LA227_: ;
		T229_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T229_, (&aX60gensym6642__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		T230_ = (NimStringV2*)0;
		T230_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		addIndent__cgen_u315(p_p0, T230_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		T231_ = (NimStringV2*)0;
		T231_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		res_14 = rawNewString(((NI)80));
		prepareAdd((&res_14), 4);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_2280);
		colontmpD__33 = rdLoc__cgen_u470(aX60gensym6642__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		cgFormatValue__cgen_u163((&res_14), colontmpD__33);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		prepareAdd((&res_14), 4);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_2281);
		colontmpD__34 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2283);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		cgFormatValue__cgen_u163((&res_14), colontmpD__34);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		prepareAdd((&res_14), 1);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_2284);
		colontmpD__35 = rdLoc__cgen_u470(aX60gensym6642__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		cgFormatValue__cgen_u163((&res_14), colontmpD__35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA224_;
		prepareAdd((&res_14), 4);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_2286);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA234_;
			prepareAdd((&res_14), 1);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_2287);
		}
LA234_: ;
		prepareAdd((&(*T231_)), res_14.len + 0);
appendString((&(*T231_)), res_14);
		{
			LA224_:;
		}
		{
			oldNimErrFin224_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__35);
			eqdestroy___system_u2691(colontmpD__34);
			eqdestroy___system_u2691(colontmpD__33);
			eqdestroy___system_u2691(res_14);
			eqdestroy___ast_u6284(aX60gensym6642__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin224_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)45):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6657__1;
		NimStringV2 res_15;
		NimStringV2 colontmpD__36;
		NimStringV2 colontmpD__37;
		NimStringV2 colontmpD__38;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T244_;
		NimStringV2* T245_;
		NimStringV2* T246_;
		nimZeroMem((void*)(&aX60gensym6657__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_15.len = 0; res_15.p = NIM_NIL;
		colontmpD__36.len = 0; colontmpD__36.p = NIM_NIL;
		colontmpD__37.len = 0; colontmpD__37.p = NIM_NIL;
		colontmpD__38.len = 0; colontmpD__38.p = NIM_NIL;
		{
			if (!!(((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0)))) goto LA242_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2288, TM__MQdRN7fpbG7rPm4JpVVAhA_2279);
			if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		}
LA242_: ;
		T244_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T244_, (&aX60gensym6657__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		T245_ = (NimStringV2*)0;
		T245_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		addIndent__cgen_u315(p_p0, T245_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		T246_ = (NimStringV2*)0;
		T246_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		res_15 = rawNewString(((NI)80));
		prepareAdd((&res_15), 4);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_2289);
		colontmpD__36 = rdLoc__cgen_u470(aX60gensym6657__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		cgFormatValue__cgen_u163((&res_15), colontmpD__36);
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		prepareAdd((&res_15), 4);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_2290);
		colontmpD__37 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2292);
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		cgFormatValue__cgen_u163((&res_15), colontmpD__37);
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		prepareAdd((&res_15), 1);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_2293);
		colontmpD__38 = rdLoc__cgen_u470(aX60gensym6657__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		cgFormatValue__cgen_u163((&res_15), colontmpD__38);
		if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
		prepareAdd((&res_15), 4);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_2294);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA249_;
			prepareAdd((&res_15), 1);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_2295);
		}
LA249_: ;
		prepareAdd((&(*T246_)), res_15.len + 0);
appendString((&(*T246_)), res_15);
		{
			LA239_:;
		}
		{
			oldNimErrFin239_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__38);
			eqdestroy___system_u2691(colontmpD__37);
			eqdestroy___system_u2691(colontmpD__36);
			eqdestroy___system_u2691(res_15);
			eqdestroy___ast_u6284(aX60gensym6657__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin239_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)135):
	{
		genSetLengthStr__cgen_u24436(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)136):
	{
		genSetLengthSeq__cgen_u24382(p_p0, e_p1, d_p2, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)137):
	{
		genSetLengthSeq__cgen_u24382(p_p0, e_p1, d_p2, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)40):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)41):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)42):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)118):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)117):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)116):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)119):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)120):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)121):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)132):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)122):
	{
		genSetOp__cgen_u24604(p_p0, e_p1, d_p2, op_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)145):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)146):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)134):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)147):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opr_1;
		opr_1 = NIM_NIL;
		eqcopy___ast_u4577(&opr_1, (*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_1;
			NIM_BOOL wasDeclared_1;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym6678__1;
			if (!!((((*opr_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)2)))&15U)))!=0))) goto LA261_;
			prc_1 = NIM_NIL;
			prc_1 = getCompilerProc__magicsys_u150((*(*(*p_p0).module).g).graph, (*opr_1).loc.snippet);
			if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
			xX60gensym6678__1 = (*prc_1).itemId;
			wasDeclared_1 = containsOrIncl__astyaml_u223((&(*(*p_p0).module).declaredProtos), (NI)((NI)((NU32)(((NI) (xX60gensym6678__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym6678__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
			cgsym__cgen_u138((*p_p0).module, (*opr_1).loc.snippet);
			if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
			{
				NIM_BOOL T266_;
				NimStringV2 colontmpD__39;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__40;
				NimStringV2 colontmpD__41;
				NimStringV2 colontmpD__42;
				NimStringV2 colontmpD__43;
				tyArray__dyW7vpmfeTYw8kX3EXuaJA T271_;
				T266_ = (NIM_BOOL)0;
				T266_ = !(wasDeclared_1);
				if (!(T266_)) goto LA267_;
				T266_ = hcrOn__cgen_u52(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
LA267_: ;
				if (!T266_) goto LA268_;
				colontmpD__39.len = 0; colontmpD__39.p = NIM_NIL;
				colontmpD__40 = NIM_NIL;
				colontmpD__41.len = 0; colontmpD__41.p = NIM_NIL;
				colontmpD__42.len = 0; colontmpD__42.p = NIM_NIL;
				colontmpD__43.len = 0; colontmpD__43.p = NIM_NIL;
				colontmpD__39 = mangleDynLibProc__cgen_u5410(prc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
				T271_[0] = colontmpD__39;
				colontmpD__40 = t__cgen_u97((*prc_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
				colontmpD__41 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__40, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
				T271_[1] = colontmpD__41;
				colontmpD__42 = getModuleDllPath__cgen_u158((*p_p0).module, prc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
				T271_[2] = colontmpD__42;
				colontmpD__43 = percent___cgen_u26278(T271_, 3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA270_;
				prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__43.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)15))- 0]), colontmpD__43);
				{
					LA270_:;
				}
				{
					oldNimErrFin270_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__43);
					eqdestroy___system_u2691(colontmpD__42);
					eqdestroy___system_u2691(colontmpD__41);
					eqdestroy___ast_u3378(colontmpD__40);
					if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
					eqdestroy___system_u2691(colontmpD__39);
					*nimErr_ = oldNimErrFin270_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
			}
LA268_: ;
			{
				LA263_:;
			}
			{
				oldNimErrFin263_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(prc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
				*nimErr_ = oldNimErrFin263_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
		}
LA261_: ;
		genCall__cgen_u15586(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA258_;
		{
			LA258_:;
		}
		{
			oldNimErrFin258_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(opr_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin258_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)154):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)277):
	{
		genDefault__cgen_u23189(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)20):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__44;
		colontmpD__44 = NIM_NIL;
		colontmpD__44 = skipConv__types_u3715((*e_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA280_;
		genEcho__cgen_u22861(p_p0, colontmpD__44);
		if (NIM_UNLIKELY(*nimErr_)) goto LA280_;
		{
			LA280_:;
		}
		{
			oldNimErrFin280_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__44);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin280_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)143):
	{
		genArrToSeq__cgen_u23736(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)213) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)259):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)22) ... ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)28):
	{
		NimStringV2 colontmpD__45;
		colontmpD__45.len = 0; colontmpD__45.p = NIM_NIL;
		colontmpD__45 = nsuFormatSingleElem(TM__MQdRN7fpbG7rPm4JpVVAhA_2519, (*(*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto LA285_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*e_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__45, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2520, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA285_;
		{
			LA285_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__45);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)199):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
		n_1 = NIM_NIL;
		n_1 = wrapProcForSpawn__spawn_u349((*(*(*p_p0).module).g).graph, (*(*p_p0).module).Sup.idgen, (*(*p_p0).module).module, e_p1, (*e_p1).typField, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL), ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		expr__cgen_u14084(p_p0, n_1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
		{
			LA289_:;
		}
		{
			oldNimErrFin289_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(n_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin289_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)140):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
		n_2 = NIM_NIL;
		n_2 = liftParallel__semparallel_u1308((*(*(*p_p0).module).g).graph, (*(*p_p0).module).Sup.idgen, (*(*p_p0).module).module, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		expr__cgen_u14084(p_p0, n_2, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA293_;
		{
			LA293_:;
		}
		{
			oldNimErrFin293_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(n_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin293_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)200):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_3;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_3;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T304_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T310_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T311_;
		x_1 = NIM_NIL;
		nimZeroMem((void*)(&a_3), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&b_3), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		{
			NIM_BOOL T300_;
			T300_ = (NIM_BOOL)0;
			T300_ = ((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5));
			if (!(T300_)) goto LA301_;
			T300_ = !((((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)54)))&63U)))!=0));
LA301_: ;
			if (!T300_) goto LA302_;
			liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*e_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2522, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2523, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA297_;
		}
LA302_: ;
		T304_ = NIM_NIL;
		{
			if (!((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA307_;
			x_1 = (*(*e_p1)._kind_6.sons.p->data[((NI)1)])._kind_6.sons.p->data[((NI)0)];
		}
		goto LA305_;
LA307_: ;
		{
			x_1 = (*e_p1)._kind_6.sons.p->data[((NI)1)];
		}
LA305_: ;
		T310_ = 0;
		initLocExpr__cgen_u14111(p_p0, x_1, T310_, (&a_3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA297_;
		T311_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)2)], T311_, (&b_3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA297_;
		genDeepCopy__cgen_u20983(p_p0, a_3, b_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA297_;
		{
			LA297_:;
		}
		{
			oldNimErrFin297_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6284(b_3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(a_3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin297_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)125):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)91):
	{
		genCall__cgen_u15586(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)150):
	{
		genWasMoved__cgen_u25622(p_p0, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)148):
	{
		genMove__cgen_u25627(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)152):
	{
		genDestroy__cgen_u25746(p_p0, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)158):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym6699__1;
		NimStringV2 res_16;
		NimStringV2 colontmpD__46;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T320_;
		nimZeroMem((void*)(&aX60gensym6699__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		res_16.len = 0; res_16.p = NIM_NIL;
		colontmpD__46.len = 0; colontmpD__46.p = NIM_NIL;
		T320_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], T320_, (&aX60gensym6699__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA319_;
		res_16 = rawNewString(((NI)80));
		colontmpD__46 = rdLoc__cgen_u470(aX60gensym6699__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA319_;
		cgFormatValue__cgen_u163((&res_16), colontmpD__46);
		if (NIM_UNLIKELY(*nimErr_)) goto LA319_;
		prepareAdd((&res_16), 6);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_2637);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, res_16, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA319_;
		{
			LA319_:;
		}
		{
			oldNimErrFin319_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__46);
			eqdestroy___system_u2691(res_16);
			eqdestroy___ast_u6284(aX60gensym6699__1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin319_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)159):
	{
		genAccessTypeField__cgen_u24158(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)124):
	{
		genSlice__cgen_u25833(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)153):
	{
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)149):
	{
		expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)151):
	{
		expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__47;
		NimStringV2 colontmpD__48;
		NimStringV2 T330_;
		colontmpD__47.len = 0; colontmpD__47.p = NIM_NIL;
		colontmpD__48.len = 0; colontmpD__48.p = NIM_NIL;
		T330_.len = 0; T330_.p = NIM_NIL;
		colontmpD__47 = dollar___ast_u606(op_p3);
		T330_ = rawNewString(colontmpD__47.len + 14);
appendString((&T330_), TM__MQdRN7fpbG7rPm4JpVVAhA_2645);
appendString((&T330_), colontmpD__47);
		colontmpD__48 = T330_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, colontmpD__48, TM__MQdRN7fpbG7rPm4JpVVAhA_2646);
		if (NIM_UNLIKELY(*nimErr_)) goto LA329_;
		{
			LA329_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__48);
			eqdestroy___system_u2691(colontmpD__47);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetNode__cgen_u20239)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NimStringV2* result_p2) {
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ cs_1;
	NI size_1;
	NI64 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	cs_1.len = 0; cs_1.p = NIM_NIL;
	T2_ = (NI64)0;
	T2_ = getSize__types_u3397((*(*(*p_p0).module).g).config, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	size_1 = ((NI) (T2_));
	cs_1 = toBitSet__nimsets_u73((*(*(*p_p0).module).g).config, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 tmpName_1;
		NimStringV2 colontmpD_;
		NI id_1;
		NimStringV2 T8_;
		if (!(((NI)8) < size_1)) goto LA5_;
		tmpName_1.len = 0; tmpName_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		id_1 = nodeTableTestOrSet__treetab_u225((&(*(*p_p0).module).dataCache), n_p1, (*(*p_p0).module).labels);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_.len = 0; T8_.p = NIM_NIL;
		colontmpD_ = rope__ropes_u15(((NI64) (id_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_ = rawNewString((*(*p_p0).module).tmpBase.len + colontmpD_.len + 0);
appendString((&T8_), (*(*p_p0).module).tmpBase);
appendString((&T8_), colontmpD_);
		tmpName_1 = T8_;
		{
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T14_;
			tyArray__TonP9cxJgj8gXu71dWIyNlA T15_;
			if (!(id_1 == (*(*p_p0).module).labels)) goto LA11_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			(*(*p_p0).module).labels += ((NI)1);
			colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, (*n_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T14_[0] = colontmpD__2;
			T14_[1] = tmpName_1;
			colontmpD__3 = percent___cgen_u20252(T14_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__3.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__3);
			genRawSetData__cgen_u20229(cs_1, size_1, (&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			colontmpD__4 = percent___cgen_u20257(T15_, 0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__4.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)7))- 0]), colontmpD__4);
			{
				LA13_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
LA11_: ;
		prepareAdd((&(*result_p2)), tmpName_1.len + 0);
appendString((&(*result_p2)), tmpName_1);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(tmpName_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		genRawSetData__cgen_u20229(cs_1, size_1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___pureZtimes_u2620(cs_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSetConstr__cgen_u26333)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw idx_1;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin28_;
NIM_BOOL oldNimErrFin76_;
NIM_BOOL oldNimErrFin68_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&idx_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		NimStringV2 elem_1;
		if (!(((*e_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)4)))&31U)))!=0)) goto LA4_;
		elem_1.len = 0; elem_1.p = NIM_NIL;
		elem_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		genSetNode__cgen_u20239(p_p0, e_p1, (&elem_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, elem_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(elem_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T14_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA12_;
			nimZeroMem((void*)(&T14_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&T14_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqsink___ast_u6293((&(*d_p2)), T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA12_: ;
		{
			NI64 T17_;
			NimStringV2 res_1;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2* T21_;
			NimStringV2* T22_;
			T17_ = (NI64)0;
			T17_ = getSize__types_u3397((*(*(*p_p0).module).g).config, (*e_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(IL64(8) < T17_)) goto LA18_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T21_ = (NimStringV2*)0;
			T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			addIndent__cgen_u315(p_p0, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T22_ = (NimStringV2*)0;
			T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			res_1 = rawNewString(((NI)80));
			colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2647);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			cgFormatValue__cgen_u163((&res_1), colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2648);
			colontmpD__2 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2649);
			colontmpD__3 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2650);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA25_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2651);
			}
LA25_: ;
			prepareAdd((&(*T22_)), res_1.len + 0);
appendString((&(*T22_)), res_1);
			{
				tySequence__9ahcSjIErJohSBBFLwuF56Q colontmp_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** it_1;
				NI i_1;
				NI L_1;
				NI T29_;
				colontmp_.len = 0; colontmp_.p = NIM_NIL;
				it_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
				eqcopy___ast_u3699((&colontmp_), (*e_p1)._kind_6.sons);
				if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
				i_1 = ((NI)0);
				T29_ = colontmp_.len;
				L_1 = T29_;
				{
					while (1) {
						if (!(i_1 < L_1)) goto LA31;
						it_1 = &colontmp_.p->data[i_1];
						{
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
							NimStringV2 aa_1;
							NimStringV2 bb_1;
							NimStringV2 colontmpD__5;
							NimStringV2 colontmpD__6;
							NimStringV2 colontmpD__7;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T37_;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T38_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T39_;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T40_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T41_;
							NimStringV2* T42_;
							NimStringV2* T43_;
							tyArray__Seu7uK9aaOSN0BK3EAjjSHw T44_;
							if (!((*(*it_1)).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA34_;
							colontmpD__4 = NIM_NIL;
							aa_1.len = 0; aa_1.p = NIM_NIL;
							bb_1.len = 0; bb_1.p = NIM_NIL;
							colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
							colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
							colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
							colontmpD__4 = getSysType__magicsys_u55((*(*(*p_p0).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							nimZeroMem((void*)(&T37_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							getTemp__cgen_u9546(p_p0, colontmpD__4, NIM_FALSE, (&T37_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							eqsink___ast_u6293((&idx_1), T37_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							T38_ = 0;
							nimZeroMem((void*)(&T39_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, (*(*it_1))._kind_6.sons.p->data[((NI)0)], T38_, (&T39_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							eqsink___ast_u6293((&a_1), T39_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							T40_ = 0;
							nimZeroMem((void*)(&T41_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, (*(*it_1))._kind_6.sons.p->data[((NI)1)], T40_, (&T41_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							eqsink___ast_u6293((&b_1), T41_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							aa_1 = newRopeAppender__ropes_u7(((NI)80));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, a_1, (*e_p1).typField, (&aa_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							bb_1 = newRopeAppender__ropes_u7(((NI)80));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, b_1, (*e_p1).typField, (&bb_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							T42_ = (NimStringV2*)0;
							T42_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							addIndent__cgen_u315(p_p0, T42_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							T43_ = (NimStringV2*)0;
							T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							colontmpD__5 = rdLoc__cgen_u470(idx_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							T44_[0] = colontmpD__5;
							colontmpD__6 = rdLoc__cgen_u470((*d_p2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							T44_[1] = colontmpD__6;
							T44_[2] = aa_1;
							T44_[3] = bb_1;
							colontmpD__7 = percent___cgen_u26372(T44_, 4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
							prepareAdd((&(*T43_)), colontmpD__7.len + 0);
appendString((&(*T43_)), colontmpD__7);
							{
								LA36_:;
							}
							{
								oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___system_u2691(colontmpD__7);
								eqdestroy___system_u2691(colontmpD__6);
								eqdestroy___system_u2691(colontmpD__5);
								eqdestroy___system_u2691(bb_1);
								eqdestroy___system_u2691(aa_1);
								eqdestroy___ast_u3378(colontmpD__4);
								if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
								*nimErr_ = oldNimErrFin36_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
						}
						goto LA32_;
LA34_: ;
						{
							NimStringV2 aa_2;
							NimStringV2 colontmpD__8;
							NimStringV2 colontmpD__9;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T49_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T50_;
							NimStringV2* T51_;
							NimStringV2* T52_;
							tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T53_;
							aa_2.len = 0; aa_2.p = NIM_NIL;
							colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
							colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
							T49_ = 0;
							nimZeroMem((void*)(&T50_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, (*it_1), T49_, (&T50_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							eqsink___ast_u6293((&a_1), T50_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							aa_2 = newRopeAppender__ropes_u7(((NI)80));
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, a_1, (*e_p1).typField, (&aa_2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							T51_ = (NimStringV2*)0;
							T51_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							addIndent__cgen_u315(p_p0, T51_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							T52_ = (NimStringV2*)0;
							T52_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							colontmpD__8 = rdLoc__cgen_u470((*d_p2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							T53_[0] = colontmpD__8;
							T53_[1] = aa_2;
							colontmpD__9 = percent___cgen_u26378(T53_, 2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
							prepareAdd((&(*T52_)), colontmpD__9.len + 0);
appendString((&(*T52_)), colontmpD__9);
							{
								LA48_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__9);
								eqdestroy___system_u2691(colontmpD__8);
								eqdestroy___system_u2691(aa_2);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
						}
LA32_: ;
						i_1 += ((NI)1);
					} LA31: ;
				}
				{
					LA28_:;
				}
				{
					oldNimErrFin28_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3696(colontmp_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
					*nimErr_ = oldNimErrFin28_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			}
			{
				LA20_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA15_;
LA18_: ;
		{
			NimStringV2 ts_1;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 T62_;
			NI64 T63_;
			NimStringV2* T64_;
			NimStringV2* T65_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T66_;
			ts_1.len = 0; ts_1.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			T62_.len = 0; T62_.p = NIM_NIL;
			T63_ = (NI64)0;
			T63_ = getSize__types_u3397((*(*(*p_p0).module).g).config, (*e_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			colontmpD__10 = dollar___systemZdollars_u29((NI64)(T63_ * IL64(8)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			T62_ = rawNewString(colontmpD__10.len + 2);
appendString((&T62_), TM__MQdRN7fpbG7rPm4JpVVAhA_2652);
appendString((&T62_), colontmpD__10);
			ts_1 = T62_;
			T64_ = (NimStringV2*)0;
			T64_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			addIndent__cgen_u315(p_p0, T64_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			T65_ = (NimStringV2*)0;
			T65_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			colontmpD__11 = rdLoc__cgen_u470((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			T66_[0] = colontmpD__11;
			colontmpD__12 = percent___cgen_u26384(T66_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			prepareAdd((&(*T65_)), colontmpD__12.len + 0);
appendString((&(*T65_)), colontmpD__12);
			{
				tySequence__9ahcSjIErJohSBBFLwuF56Q colontmp__2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** it_2;
				NI i_2;
				NI L_2;
				NI T69_;
				colontmp__2.len = 0; colontmp__2.p = NIM_NIL;
				it_2 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
				eqcopy___ast_u3699((&colontmp__2), (*e_p1)._kind_6.sons);
				if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
				i_2 = ((NI)0);
				T69_ = colontmp__2.len;
				L_2 = T69_;
				{
					while (1) {
						if (!(i_2 < L_2)) goto LA71;
						it_2 = &colontmp__2.p->data[i_2];
						{
							tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__13;
							NimStringV2 aa_3;
							NimStringV2 bb_2;
							NimStringV2 colontmpD__14;
							NimStringV2 colontmpD__15;
							NimStringV2 colontmpD__16;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T77_;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T78_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T79_;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T80_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T81_;
							NimStringV2* T82_;
							NimStringV2* T83_;
							tyArray__awn6UrBeChh9cVy9ccoluuYg T84_;
							if (!((*(*it_2)).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA74_;
							colontmpD__13 = NIM_NIL;
							aa_3.len = 0; aa_3.p = NIM_NIL;
							bb_2.len = 0; bb_2.p = NIM_NIL;
							colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
							colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
							colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
							colontmpD__13 = getSysType__magicsys_u55((*(*(*p_p0).module).g).graph, unknownLineInfo__lineinfos_u364, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							nimZeroMem((void*)(&T77_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							getTemp__cgen_u9546(p_p0, colontmpD__13, NIM_FALSE, (&T77_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							eqsink___ast_u6293((&idx_1), T77_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							T78_ = 0;
							nimZeroMem((void*)(&T79_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, (*(*it_2))._kind_6.sons.p->data[((NI)0)], T78_, (&T79_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							eqsink___ast_u6293((&a_1), T79_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							T80_ = 0;
							nimZeroMem((void*)(&T81_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, (*(*it_2))._kind_6.sons.p->data[((NI)1)], T80_, (&T81_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							eqsink___ast_u6293((&b_1), T81_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							aa_3 = newRopeAppender__ropes_u7(((NI)80));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, a_1, (*e_p1).typField, (&aa_3));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							bb_2 = newRopeAppender__ropes_u7(((NI)80));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, b_1, (*e_p1).typField, (&bb_2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							T82_ = (NimStringV2*)0;
							T82_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							addIndent__cgen_u315(p_p0, T82_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							T83_ = (NimStringV2*)0;
							T83_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							colontmpD__14 = rdLoc__cgen_u470(idx_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							T84_[0] = colontmpD__14;
							colontmpD__15 = rdLoc__cgen_u470((*d_p2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							T84_[1] = colontmpD__15;
							T84_[2] = aa_3;
							T84_[3] = bb_2;
							T84_[4] = ts_1;
							colontmpD__16 = percent___cgen_u26399(T84_, 5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
							prepareAdd((&(*T83_)), colontmpD__16.len + 0);
appendString((&(*T83_)), colontmpD__16);
							{
								LA76_:;
							}
							{
								oldNimErrFin76_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___system_u2691(colontmpD__16);
								eqdestroy___system_u2691(colontmpD__15);
								eqdestroy___system_u2691(colontmpD__14);
								eqdestroy___system_u2691(bb_2);
								eqdestroy___system_u2691(aa_3);
								eqdestroy___ast_u3378(colontmpD__13);
								if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
								*nimErr_ = oldNimErrFin76_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
						}
						goto LA72_;
LA74_: ;
						{
							NimStringV2 aa_4;
							NimStringV2 colontmpD__17;
							NimStringV2 colontmpD__18;
							tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T89_;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T90_;
							NimStringV2* T91_;
							NimStringV2* T92_;
							tyArray__dyW7vpmfeTYw8kX3EXuaJA T93_;
							aa_4.len = 0; aa_4.p = NIM_NIL;
							colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
							colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
							T89_ = 0;
							nimZeroMem((void*)(&T90_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							initLocExpr__cgen_u14111(p_p0, (*it_2), T89_, (&T90_));
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							eqsink___ast_u6293((&a_1), T90_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							aa_4 = newRopeAppender__ropes_u7(((NI)80));
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, a_1, (*e_p1).typField, (&aa_4));
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							T91_ = (NimStringV2*)0;
							T91_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							addIndent__cgen_u315(p_p0, T91_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							T92_ = (NimStringV2*)0;
							T92_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							colontmpD__17 = rdLoc__cgen_u470((*d_p2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							T93_[0] = colontmpD__17;
							T93_[1] = aa_4;
							T93_[2] = ts_1;
							colontmpD__18 = percent___cgen_u26405(T93_, 3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
							prepareAdd((&(*T92_)), colontmpD__18.len + 0);
appendString((&(*T92_)), colontmpD__18);
							{
								LA88_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__18);
								eqdestroy___system_u2691(colontmpD__17);
								eqdestroy___system_u2691(aa_4);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA68_;
						}
LA72_: ;
						i_2 += ((NI)1);
					} LA71: ;
				}
				{
					LA68_:;
				}
				{
					oldNimErrFin68_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3696(colontmp__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
					*nimErr_ = oldNimErrFin68_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			}
			{
				LA61_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(ts_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA15_: ;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(idx_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, exprComplexConst__cgen_u26739)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	NimStringV2 colontmpD_;
	NimStringV2 tmp_1;
	NimStringV2 colontmpD__2;
	NI id_1;
	NimStringV2 T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	eqcopy___ast_u3381(&t_1, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	id_1 = nodeTableTestOrSet__treetab_u225((&(*(*p_p0).module).dataCache), n_p1, (*(*p_p0).module).labels);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	colontmpD__2 = rope__ropes_u15(((NI64) (id_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString((*(*p_p0).module).tmpBase.len + colontmpD__2.len + 0);
appendString((&T2_), (*(*p_p0).module).tmpBase);
appendString((&T2_), colontmpD__2);
	tmp_1 = T2_;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* T9_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T10_;
		if (!(id_1 == (*(*p_p0).module).labels)) goto LA5_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		(*(*p_p0).module).labels += ((NI)1);
		colontmpD__3 = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)6));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T8_[0] = colontmpD__3;
		T8_[1] = tmp_1;
		colontmpD__4 = percent___cgen_u20252(T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), colontmpD__4.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), colontmpD__4);
		T9_ = NIM_NIL;
		T9_ = p_p0;
		genBracedInit__cgen_u16526(T9_, n_p1, NIM_TRUE, t_1, (&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__5 = percent___cgen_u20257(T10_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), colontmpD__5.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), colontmpD__5);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA15_;
		fillLoc__cgen_u78(d_p2, ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)8), n_p1, tmp_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA13_;
LA15_: ;
	{
		putDataIntoDest__cgen_u21128(p_p0, d_p2, n_p1, tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!!(((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24) || (*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28)))) goto LA20_;
			(*d_p2).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1);
		}
LA20_: ;
	}
LA13_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, handleConstExpr__cgen_u23535)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
		if (!(T4_)) goto LA5_;
		T6_ = (NI)0;
		T6_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38)) < T6_);
LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T3_ = isDeepConstExpr__trees_u153(n_p1, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA7_: ;
		if (!T3_) goto LA8_;
		rawConstExpr__cgen_u12894(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA8_: ;
	{
		result = NIM_FALSE;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayConstr__cgen_u26510)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw arr_1;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&arr_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = handleConstExpr__cgen_u23535(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T11_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA9_;
			nimZeroMem((void*)(&T11_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T11_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqsink___ast_u6293((&(*d_p2)), T11_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA9_: ;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
					NimStringV2 lit_1;
					NimStringV2 colontmpD__4;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T16_;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T17_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T18_;
					NimStringV2 T19_;
					if (!(i_2 < colontmp_)) goto LA14;
					colontmpD_ = NIM_NIL;
					colontmpD__2 = NIM_NIL;
					colontmpD__3 = NIM_NIL;
					lit_1.len = 0; lit_1.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					i_1 = i_2;
					colontmpD_ = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					colontmpD__2 = elemType__types_u254(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					colontmpD__3 = lodeTyp__cgen_u104(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					T16_ = 0;
					nimZeroMem((void*)(&T17_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), colontmpD__3, (*d_p2).storage, T16_, (&T17_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					eqsink___ast_u6293((&arr_1), T17_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					lit_1 = newRopeAppender__ropes_u7(((NI)80));
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					intLiteral__cgen_u14092(((NI64) (i_1)), (&lit_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					colontmpD__4 = rdLoc__cgen_u470((*d_p2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					T18_[0] = colontmpD__4;
					T18_[1] = lit_1;
					T19_.len = 0; T19_.p = NIM_NIL;
					T19_ = percent___cgen_u9083(T18_, 2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T19_); goto LA15_;}
					eqsink___system_u2700((&arr_1.snippet), T19_);
					expr__cgen_u14084(p_p0, (*n_p1)._kind_6.sons.p->data[i_1], (&arr_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					i_2 += ((NI)1);
					{
						LA15_:;
					}
					{
						oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(lit_1);
						eqdestroy___ast_u3252(colontmpD__3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3378(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin15_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA14: ;
			}
		}
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(arr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isRoutine__ast_u7152)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	NIM_BOOL result;
	result = ((*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
	return result;
}
static N_INLINE(NIM_BOOL, isConstClosure__cgen_u26453)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*(*n_p0)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
	if (!(T2_)) goto LA3_;
	T2_ = isRoutine__ast_u7152((*(*n_p0)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*n_p0)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA4_: ;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosure__cgen_u26464)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
NIM_BOOL oldNimErrFin13_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 tmp_1;
		NimStringV2 colontmpD_;
		NimStringV2 data_1;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T7_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = isConstClosure__cgen_u26453(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		data_1.len = 0; data_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		(*(*p_p0).module).labels += ((NI)1);
		T7_.len = 0; T7_.p = NIM_NIL;
		colontmpD_ = rope__ropes_u15(((NI64) ((*(*p_p0).module).labels)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_ = rawNewString(colontmpD_.len + 11);
appendString((&T7_), TM__MQdRN7fpbG7rPm4JpVVAhA_2654);
appendString((&T7_), colontmpD_);
		tmp_1 = T7_;
		colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, (*n_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T8_[0] = colontmpD__2;
		T8_[1] = tmp_1;
		data_1 = percent___cgen_u20252(T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		genBracedInit__cgen_u16526(p_p0, n_p1, NIM_TRUE, (*n_p1).typField, (&data_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__3 = percent___cgen_u20257(T9_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		prepareAdd((&data_1), colontmpD__3.len + 0);
appendString((&data_1), colontmpD__3);
		prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), data_1.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)8))- 0]), data_1);
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, tmp_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(data_1);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(tmp_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_2;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
		NimStringV2 res_1;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T14_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T15_;
		NimStringV2* T20_;
		NimStringV2* T21_;
		nimZeroMem((void*)(&tmp_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__4 = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		T14_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T14_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T15_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], T15_, (&b_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			colontmpD__4 = skipConv__types_u3715((*n_p1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			if (!((*colontmpD__4).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)155))) goto LA18_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2656, TM__MQdRN7fpbG7rPm4JpVVAhA_2657);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
LA18_: ;
		getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&tmp_2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T20_ = (NimStringV2*)0;
		T20_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		addIndent__cgen_u315(p_p0, T20_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T21_ = (NimStringV2*)0;
		T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		res_1 = rawNewString(((NI)80));
		colontmpD__5 = rdLoc__cgen_u470(tmp_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2658);
		colontmpD__6 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2659);
		colontmpD__7 = rdLoc__cgen_u470(tmp_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_1), 9);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2661);
		colontmpD__8 = rdLoc__cgen_u470(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2662);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA24_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2663);
		}
LA24_: ;
		prepareAdd((&(*T21_)), res_1.len + 0);
appendString((&(*T21_)), res_1);
		putLocIntoDest__cgen_u14088(p_p0, d_p2, tmp_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(res_1);
			eqdestroy___ast_u3252(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(tmp_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleConstr__cgen_u26410)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw rec_1;
NIM_BOOL oldNimErrFin26_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&rec_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		NIM_BOOL T4_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
		NimStringV2 colontmpD_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* colontmpD__2;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* colontmpD__3;
		NIM_BOOL doesAlias_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_1;
		T4_ = (NIM_BOOL)0;
		T4_ = handleConstExpr__cgen_u23535(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		t_1 = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__2 = (tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw*)0;
		colontmpD__3 = (tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw*)0;
		eqcopy___ast_u3381(&t_1, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		(void)(colontmpD_);
		nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		doesAlias_1 = lhsDoesAlias__cgen_u23654((*d_p2).lode, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			if (!doesAlias_1) goto LA10_;
			colontmpD__2 = (&tmp_1);
			dest_1 = colontmpD__2;
		}
		goto LA8_;
LA10_: ;
		{
			colontmpD__3 = d_p2;
			dest_1 = colontmpD__3;
		}
LA8_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T17_;
			if (!doesAlias_1) goto LA15_;
			nimZeroMem((void*)(&T17_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T17_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqsink___ast_u6293((&tmp_1), T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
		goto LA13_;
LA15_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T21_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA19_;
			nimZeroMem((void*)(&T21_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T21_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			eqsink___ast_u6293((&(*d_p2)), T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
		goto LA13_;
LA19_: ;
LA13_: ;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA24;
					i_1 = i_2;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
						NimStringV2 colontmpD__4;
						NimStringV2 colontmpD__5;
						tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T37_;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T38_;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T39_;
						NimStringV2 T40_;
						it_1 = NIM_NIL;
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						{
							if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA29_;
							eqcopy___ast_u3255(&it_1, (*it_1)._kind_6.sons.p->data[((NI)1)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						}
LA29_: ;
						{
							NIM_BOOL T33_;
							T33_ = (NIM_BOOL)0;
							T33_ = !(((*it_1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
							if (!(T33_)) goto LA34_;
							T33_ = isEmptyType__ast_u7234((*it_1).typField);
							if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
LA34_: ;
							if (!T33_) goto LA35_;
							eqdestroy___system_u2691(colontmpD__5);
							eqdestroy___system_u2691(colontmpD__4);
							eqdestroy___ast_u3252(it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
							goto LA25;
						}
LA35_: ;
						T37_ = 0;
						nimZeroMem((void*)(&T38_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), it_1, (*dest_1).storage, T37_, (&T38_));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						eqsink___ast_u6293((&rec_1), T38_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						colontmpD__4 = rdLoc__cgen_u470((*dest_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						T39_[0] = colontmpD__4;
						colontmpD__5 = rope__ropes_u15(((NI64) (i_1)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						T39_[1] = colontmpD__5;
						T40_.len = 0; T40_.p = NIM_NIL;
						T40_ = percent___cgen_u15846(T39_, 2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T40_); goto LA26_;}
						eqsink___system_u2700((&rec_1.snippet), T40_);
						rec_1.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)8))) & 15);
						expr__cgen_u14084(p_p0, it_1, (&rec_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						{
							LA26_:;
						}
						{
							oldNimErrFin26_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__5);
							eqdestroy___system_u2691(colontmpD__4);
							eqdestroy___ast_u3252(it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
							*nimErr_ = oldNimErrFin26_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					} LA25: ;
					i_2 += ((NI)1);
				} LA24: ;
			}
		}
		{
			if (!doesAlias_1) goto LA45_;
			{
				if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA49_;
				eqsink___ast_u6293((&(*d_p2)), tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				eqwasMoved___ast_u6281((&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			}
			goto LA47_;
LA49_: ;
			{
				tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T52_;
				T52_ = 0;
				genAssignment__cgen_u12898(p_p0, (*d_p2), tmp_1, T52_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			}
LA47_: ;
		}
LA45_: ;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6284(tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(rec_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, lookupFieldAgain__cgen_u22086)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p2, NimStringV2* r_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** resTyp_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	ty_2 = NIM_NIL;
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	eqcopy___ast_u3381(&ty_2, ty_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T4_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T5_;
			if (!!((ty_2 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA3;
			T4_ = NIM_NIL;
			T4_ = skipTypes__ast_u5379(ty_2, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T4_); goto LA1_;}
			eqsink___ast_u3387(&ty_2, T4_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T5_ = NIM_NIL;
			T5_ = lookupInRecord__astalgo_u30((*ty_2).n, (*field_p2).name);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T5_); goto LA1_;}
			eqsink___ast_u4583(&result, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA8_;
				{
					if (!!((resTyp_p4 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**) NIM_NIL)))) goto LA12_;
					eqsink___ast_u3387(&(*resTyp_p4), ty_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqwasMoved___ast_u3375(&ty_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA12_: ;
				goto LA2;
			}
LA8_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
				if (T16_) goto LA17_;
				T16_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA17_: ;
				if (!!(T16_)) goto LA18_;
				prepareAdd((&(*r_p3)), 4);
appendString((&(*r_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_2665);
			}
LA18_: ;
			eqcopy___ast_u3381(&ty_2, (*ty_2).sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA3: ;
	} LA2: ;
	{
		if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA22_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*field_p2).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2667, TM__MQdRN7fpbG7rPm4JpVVAhA_2668);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA22_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(ty_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u707)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_2674;
	colontmpD_ = toMsgFilename__msgs_u688(conf_p0, info_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
	{
		if (!(((NI)0) < ((NI) (info_p1.line)))) goto LA4_;
		prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_2675);
		addInt__stdZprivateZdigitsutils_u204((&result), ((NI) (info_p1.line)));
		{
			if (!(((NI)0) < (NI)(((NI) (info_p1.col)) + ((NI)1)))) goto LA8_;
			prepareAdd((&result), 2);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_2676);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)(((NI) (info_p1.col)) + ((NI)1)));
		}
LA8_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_2677);
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genFieldCheck__cgen_u22241)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, NimStringV2 obj_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p3) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw test_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw u_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw v_1;
NIM_BOOL oldNimErrFin40_;
NIM_BOOL oldNimErrFin38_;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&test_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&u_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&v_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* disc_1;
				NimStringV2 msg_1;
				NimStringV2 colontmpD_;
				NimStringV2 strLit_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
				NimStringV2 discIndex_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
				NimStringV2 res_1;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T10_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T11_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T12_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T13_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T14_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T15_;
				NimStringV2 T16_;
				NimStringV2* T61_;
				NimStringV2* T62_;
				NimStringV2* T63_;
				if (!(i_2 < colontmp_)) goto LA4;
				it_1 = NIM_NIL;
				op_1 = NIM_NIL;
				disc_1 = NIM_NIL;
				msg_1.len = 0; msg_1.p = NIM_NIL;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				strLit_1.len = 0; strLit_1.p = NIM_NIL;
				colontmpD__2 = NIM_NIL;
				discIndex_1.len = 0; discIndex_1.p = NIM_NIL;
				colontmpD__3 = NIM_NIL;
				res_1.len = 0; res_1.p = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*e_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				eqcopy___ast_u4577(&op_1, (*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					if (!((*op_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96))) goto LA8_;
					eqcopy___ast_u3255(&it_1, (*it_1)._kind_6.sons.p->data[((NI)1)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA8_: ;
				disc_1 = skipConv__types_u3715((*it_1)._kind_6.sons.p->data[((NI)2)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T10_ = 0;
				nimZeroMem((void*)(&T11_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0), it_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2), T10_, (&T11_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				eqsink___ast_u6293((&test_1), T11_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T12_ = 0;
				nimZeroMem((void*)(&T13_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLocExpr__cgen_u14111(p_p0, (*it_1)._kind_6.sons.p->data[((NI)1)], T12_, (&T13_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				eqsink___ast_u6293((&u_1), T13_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T14_ = 0;
				nimZeroMem((void*)(&T15_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), disc_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T14_, (&T15_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				eqsink___ast_u6293((&v_1), T15_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T16_.len = 0; T16_.p = NIM_NIL;
				T16_ = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T16_); goto LA5_;}
				eqsink___system_u2700((&v_1.snippet), T16_);
				prepareAdd((&v_1.snippet), obj_p2.len + 0);
appendString((&v_1.snippet), obj_p2);
				prepareAdd((&v_1.snippet), 1);
appendString((&v_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_2672);
				prepareAdd((&v_1.snippet), (*(*disc_1)._kind_4.sym).loc.snippet.len + 0);
appendString((&v_1.snippet), (*(*disc_1)._kind_4.sym).loc.snippet);
				genInExprAux__cgen_u22235(p_p0, it_1, (&u_1), (&v_1), (&test_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				msg_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2673;
				{
					NimStringV2 colontmpD__4;
					NimStringV2 colontmpD__5;
					NimStringV2 T22_;
					if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)41)))&63U)))!=0)) goto LA19_;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					T22_.len = 0; T22_.p = NIM_NIL;
					colontmpD__4 = toFileLineCol__msgs_u707((*(*(*p_p0).module).g).config, (*e_p1).info);
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
					T22_ = rawNewString(colontmpD__4.len + 1);
appendString((&T22_), colontmpD__4);
appendString((&T22_), TM__MQdRN7fpbG7rPm4JpVVAhA_2678);
					colontmpD__5 = T22_;
					prepareAdd((&msg_1), colontmpD__5.len + 0);
appendString((&msg_1), colontmpD__5);
					{
						LA21_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___system_u2691(colontmpD__4);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA19_: ;
				colontmpD_ = genFieldDefect__astmsgs_u68((*(*(*p_p0).module).g).config, (*(*field_p3).name).s, (*disc_1)._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				prepareAdd((&msg_1), colontmpD_.len + 0);
appendString((&msg_1), colontmpD_);
				strLit_1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				colontmpD__2 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), msg_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				genStringLiteral__cgen_u714((*p_p0).module, colontmpD__2, (&strLit_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					NimStringV2 res_2;
					NimStringV2 colontmpD__6;
					NimStringV2* T29_;
					NimStringV2* T30_;
					if (!((*op_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96))) goto LA27_;
					res_2.len = 0; res_2.p = NIM_NIL;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					T29_ = (NimStringV2*)0;
					T29_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					addIndent__cgen_u315(p_p0, T29_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					T30_ = (NimStringV2*)0;
					T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					res_2 = rawNewString(((NI)80));
					prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2679);
					colontmpD__6 = rdLoc__cgen_u470(test_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2680);
					prepareAdd((&(*T30_)), res_2.len + 0);
appendString((&(*T30_)), res_2);
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(res_2);
				}
				goto LA25_;
LA27_: ;
				{
					NimStringV2 res_3;
					NimStringV2 colontmpD__7;
					NimStringV2* T32_;
					NimStringV2* T33_;
					res_3.len = 0; res_3.p = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					T32_ = (NimStringV2*)0;
					T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					addIndent__cgen_u315(p_p0, T32_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					T33_ = (NimStringV2*)0;
					T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					res_3 = rawNewString(((NI)80));
					prepareAdd((&res_3), 6);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2681);
					colontmpD__7 = rdLoc__cgen_u470(test_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					cgFormatValue__cgen_u163((&res_3), colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2682);
					prepareAdd((&(*T33_)), res_3.len + 0);
appendString((&(*T33_)), res_3);
					eqdestroy___system_u2691(colontmpD__7);
					eqdestroy___system_u2691(res_3);
				}
LA25_: ;
				discIndex_1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				colontmpD__3 = t__cgen_u97(u_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				rdSetElemLoc__cgen_u20092((*(*(*p_p0).module).g).config, v_1, colontmpD__3, (&discIndex_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* base_1;
					if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA36_;
					base_1 = NIM_NIL;
					base_1 = skipTypes__ast_u5379((*disc_1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2058);
					if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
					switch ((*base_1).kind) {
					case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* toStrProc_1;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw toStr_1;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
						NimStringV2 enumStr_1;
						NimStringV2 colontmpD__9;
						NimStringV2 colontmpD__10;
						NimStringV2 res_4;
						NimStringV2 colontmpD__11;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T41_;
						NimStringV2* T42_;
						NimStringV2* T43_;
						toStrProc_1 = NIM_NIL;
						nimZeroMem((void*)(&toStr_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						colontmpD__8 = NIM_NIL;
						enumStr_1.len = 0; enumStr_1.p = NIM_NIL;
						colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
						colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
						res_4.len = 0; res_4.p = NIM_NIL;
						colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
						toStrProc_1 = getToStringProc__modulegraphs_u8679((*(*(*p_p0).module).g).graph, base_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						nimZeroMem((void*)(&toStr_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						colontmpD__8 = newSymNode__ast_u5168(toStrProc_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						expr__cgen_u14084(p_p0, colontmpD__8, (&toStr_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						colontmpD__9 = rdLoc__cgen_u470(toStr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						T41_[0] = colontmpD__9;
						colontmpD__10 = rdLoc__cgen_u470(v_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						T41_[1] = colontmpD__10;
						enumStr_1 = percent___cgen_u22329(T41_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						T42_ = (NimStringV2*)0;
						T42_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						addIndent__cgen_u315(p_p0, T42_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						T43_ = (NimStringV2*)0;
						T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						res_4 = rawNewString(((NI)80));
						prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2684);
						colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2686);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						cgFormatValue__cgen_u163((&res_4), colontmpD__11);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2687);
						cgFormatValue__cgen_u163((&res_4), strLit_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2688);
						cgFormatValue__cgen_u163((&res_4), enumStr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
						prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2689);
						prepareAdd((&(*T43_)), res_4.len + 0);
appendString((&(*T43_)), res_4);
						{
							LA40_:;
						}
						{
							oldNimErrFin40_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__11);
							eqdestroy___system_u2691(res_4);
							eqdestroy___system_u2691(colontmpD__10);
							eqdestroy___system_u2691(colontmpD__9);
							eqdestroy___system_u2691(enumStr_1);
							eqdestroy___ast_u3252(colontmpD__8);
							if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
							eqdestroy___ast_u6284(toStr_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
							eqdestroy___ast_u4574(toStrProc_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
							*nimErr_ = oldNimErrFin40_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
					}
					break;
					default:
					{
						NimStringV2 res_5;
						NimStringV2 colontmpD__12;
						NimStringV2* T48_;
						NimStringV2* T49_;
						res_5.len = 0; res_5.p = NIM_NIL;
						colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
						T48_ = (NimStringV2*)0;
						T48_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
						addIndent__cgen_u315(p_p0, T48_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
						T49_ = (NimStringV2*)0;
						T49_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
						res_5 = rawNewString(((NI)80));
						prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2690);
						colontmpD__12 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2692);
						if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
						cgFormatValue__cgen_u163((&res_5), colontmpD__12);
						if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
						prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2693);
						cgFormatValue__cgen_u163((&res_5), strLit_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
						prepareAdd((&res_5), 6);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2695);
						cgFormatValue__cgen_u163((&res_5), discIndex_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
						prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2696);
						prepareAdd((&(*T49_)), res_5.len + 0);
appendString((&(*T49_)), res_5);
						{
							LA47_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__12);
							eqdestroy___system_u2691(res_5);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
					}
					break;
					}
					{
						LA38_:;
					}
					{
						oldNimErrFin38_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(base_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						*nimErr_ = oldNimErrFin38_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
				goto LA34_;
LA36_: ;
				{
					NimStringV2 firstLit_1;
					NimStringV2 discName_1;
					NimStringV2 res_6;
					NimStringV2 colontmpD__13;
					NimStringV2 colontmpD__14;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg first_1;
					union { tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg source; NI dest; } LOC56;
					NimStringV2* T57_;
					NimStringV2* T58_;
					firstLit_1.len = 0; firstLit_1.p = NIM_NIL;
					discName_1.len = 0; discName_1.p = NIM_NIL;
					res_6.len = 0; res_6.p = NIM_NIL;
					colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
					colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
					first_1 = firstOrd__types_u1182((*(*(*p_p0).module).g).config, (*(*disc_1)._kind_4.sym).typ);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					firstLit_1 = newRopeAppender__ropes_u7(((NI)80));
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					LOC56.source = first_1;
					int64Literal__cgen_u20097(((NI64) (LOC56.dest)), (&firstLit_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					discName_1 = genTypeInfo__cgen_u12748((*(*(*p_p0).module).g).config, (*p_p0).module, (*(*disc_1)._kind_4.sym).typ, (*e_p1).info);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					T57_ = (NimStringV2*)0;
					T57_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					addIndent__cgen_u315(p_p0, T57_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					T58_ = (NimStringV2*)0;
					T58_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					res_6 = rawNewString(((NI)80));
					prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2697);
					colontmpD__13 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2698);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					cgFormatValue__cgen_u163((&res_6), colontmpD__13);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2699);
					cgFormatValue__cgen_u163((&res_6), strLit_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2700);
					colontmpD__14 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2702);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					cgFormatValue__cgen_u163((&res_6), colontmpD__14);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					prepareAdd((&res_6), 6);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2704);
					cgFormatValue__cgen_u163((&res_6), discIndex_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					prepareAdd((&res_6), 8);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2706);
					cgFormatValue__cgen_u163((&res_6), firstLit_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2707);
					cgFormatValue__cgen_u163((&res_6), discName_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2709);
					prepareAdd((&(*T58_)), res_6.len + 0);
appendString((&(*T58_)), res_6);
					{
						LA55_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__14);
						eqdestroy___system_u2691(colontmpD__13);
						eqdestroy___system_u2691(res_6);
						eqdestroy___system_u2691(discName_1);
						eqdestroy___system_u2691(firstLit_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA34_: ;
				T61_ = (NimStringV2*)0;
				T61_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				raiseInstr__cgen_u457(p_p0, T61_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T62_ = (NimStringV2*)0;
				T62_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				addIndent__cgen_u315(p_p0, T62_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T63_ = (NimStringV2*)0;
				T63_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				res_1 = rawNewString(((NI)80));
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2710);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA66_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2711);
				}
LA66_: ;
				prepareAdd((&(*T63_)), res_1.len + 0);
appendString((&(*T63_)), res_1);
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(res_1);
					eqdestroy___ast_u3378(colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(discIndex_1);
					eqdestroy___ast_u3252(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(strLit_1);
					eqdestroy___system_u2691(colontmpD_);
					eqdestroy___system_u2691(msg_1);
					eqdestroy___ast_u3252(disc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u4574(op_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin5_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(v_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(u_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(test_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genFieldObjConstr__cgen_u23551)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_p1, NIM_BOOL useTemp_p2, NIM_BOOL isRef_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nField_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val_p5, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* check_p6, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p7, NimStringV2 r_p8, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p9) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp2_1;
	NimStringV2 colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
NIM_BOOL oldNimErrFin37_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&tmp2_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	field_1 = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	nimZeroMem((void*)(&tmp2_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = eqdup___system_u2697(r_p8);
	tmp2_1.snippet = colontmpD_;
	field_1 = lookupFieldAgain__cgen_u22086(p_p0, ty_p1, (*nField_p4)._kind_4.sym, (&tmp2_1.snippet), ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*field_1).loc.snippet.len == 0)) goto LA4_;
		fillObjectFields__cgen_u5401((*p_p0).module, ty_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		if (!((*field_1).loc.snippet.len == 0)) goto LA8_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, info_p9, TM__MQdRN7fpbG7rPm4JpVVAhA_2670, TM__MQdRN7fpbG7rPm4JpVVAhA_2671);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = !((check_p6 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
		if (!(T12_)) goto LA13_;
		T12_ = (((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)2)))&31U)))!=0);
LA13_: ;
		if (!T12_) goto LA14_;
		genFieldCheck__cgen_u22241(p_p0, check_p6, r_p8, field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA14_: ;
	prepareAdd((&tmp2_1.snippet), 1);
appendString((&tmp2_1.snippet), TM__MQdRN7fpbG7rPm4JpVVAhA_2712);
	prepareAdd((&tmp2_1.snippet), (*field_1).loc.snippet.len + 0);
appendString((&tmp2_1.snippet), (*field_1).loc.snippet);
	{
		tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg T20_;
		if (!useTemp_p2) goto LA18_;
		tmp2_1.k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1);
		T20_ = (tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0;
		{
			if (!isRef_p3) goto LA23_;
			tmp2_1.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3);
		}
		goto LA21_;
LA23_: ;
		{
			tmp2_1.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2);
		}
LA21_: ;
	}
	goto LA16_;
LA18_: ;
	{
		tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg T27_;
		tmp2_1.k = (*d_p7).k;
		T27_ = (tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0;
		{
			if (!isRef_p3) goto LA30_;
			tmp2_1.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3);
		}
		goto LA28_;
LA30_: ;
		{
			tmp2_1.storage = (*d_p7).storage;
		}
LA28_: ;
	}
LA16_: ;
	eqcopy___ast_u3255(&tmp2_1.lode, val_p5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp3_1;
		tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T38_;
		colontmpD__2 = skipTypes__ast_u5379((*nField_p4).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48))) goto LA35_;
		nimZeroMem((void*)(&tmp3_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*val_p5).typField, NIM_FALSE, (&tmp3_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		expr__cgen_u14084(p_p0, val_p5, (&tmp3_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		T38_ = 0;
		genOpenArrayConv__cgen_u20514(p_p0, tmp2_1, tmp3_1, T38_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		{
			LA37_:;
		}
		{
			oldNimErrFin37_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u6284(tmp3_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin37_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA33_;
LA35_: ;
	{
		expr__cgen_u14084(p_p0, val_p5, (&tmp2_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA33_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(tmp2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genObjConstr__cgen_u12890)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
	NimStringV2 r_1;
	NimStringV2 colontmpD__4;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	NIM_BOOL isRef_1;
	NIM_BOOL useTemp_1;
	NIM_BOOL T15_;
	NIM_BOOL T16_;
	NIM_BOOL T17_;
	NIM_BOOL T20_;
	NIM_BOOL T22_;
	tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ T24_;
	NIM_BOOL needsZeroMem_1;
	NIM_BOOL T25_;
NIM_BOOL oldNimErrFin36_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL oldNimErrFin65_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	r_1.len = 0; r_1.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	ty_1 = NIM_NIL;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T5_) goto LA6_;
		T5_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA6_: ;
		T4_ = !(T5_);
		if (!(T4_)) goto LA7_;
		T4_ = !((((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0));
LA7_: ;
		if (!T4_) goto LA8_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = handleConstExpr__cgen_u23535(p_p0, e_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T12_) goto LA13_;
			eqdestroy___ast_u3378(ty_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(r_1);
			eqdestroy___ast_u6284(tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA13_: ;
	}
LA8_: ;
	t_1 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	isRef_1 = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22));
	T15_ = (NIM_BOOL)0;
	T16_ = (NIM_BOOL)0;
	T17_ = (NIM_BOOL)0;
	T17_ = isRef_1;
	if (T17_) goto LA18_;
	T17_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
LA18_: ;
	T16_ = T17_;
	if (T16_) goto LA19_;
	T20_ = (NIM_BOOL)0;
	colontmpD_ = t__cgen_u97((*d_p2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T20_ = !((colontmpD_ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
	if (!(T20_)) goto LA21_;
	colontmpD__2 = t__cgen_u97((*d_p2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = skipTypes__ast_u5379(colontmpD__2, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T22_ = (NIM_BOOL)0;
	T22_ = sameBackendType__types_u637(t_1, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T20_ = !(T22_);
LA21_: ;
	T16_ = T20_;
LA19_: ;
	T15_ = T16_;
	if (T15_) goto LA23_;
	T24_ = (tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ)0;
	T24_ = isPartOf__aliases_u120((*d_p2).lode, e_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T15_ = !((T24_ == ((tyEnum_TAnalysisResult__Y9b4HDQn2qbT5xWKGFH75iQ)0)));
LA23_: ;
	useTemp_1 = T15_;
	nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T25_ = (NIM_BOOL)0;
	T25_ = !(((*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*p_p0).module).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5)));
	if (T25_) goto LA26_;
	T25_ = !((((*e_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)1)))&31U)))!=0));
LA26_: ;
	needsZeroMem_1 = T25_;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T31_;
		if (!useTemp_1) goto LA29_;
		nimZeroMem((void*)(&T31_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, t_1, NIM_FALSE, (&T31_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&tmp_1), T31_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		r_1 = rdLoc__cgen_u470(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T37_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T38_;
			NimStringV2 T39_;
			if (!isRef_1) goto LA34_;
			colontmpD__5 = NIM_NIL;
			rawGenNew__cgen_u23197(p_p0, (&tmp_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2664, !((((*e_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)1)))&31U)))!=0)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			colontmpD__5 = elementType__ast_u5331(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			T37_ = NIM_NIL;
			T37_ = skipTypes__ast_u5379(colontmpD__5, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T37_); goto LA36_;}
			eqsink___ast_u3387(&t_1, T37_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			T38_[0] = r_1;
			T39_.len = 0; T39_.p = NIM_NIL;
			T39_ = percent___cgen_u12921(T38_, 1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T39_); goto LA36_;}
			eqsink___system_u2700((&r_1), T39_);
			gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, e_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA36_;
			{
				LA36_:;
			}
			{
				oldNimErrFin36_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin36_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA32_;
LA34_: ;
		{
			if (!needsZeroMem_1) goto LA43_;
			constructLoc__cgen_u13487(p_p0, (&tmp_1), NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA32_;
LA43_: ;
		{
			genObjectInit__cgen_u12909(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2), t_1, (&tmp_1), ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA32_: ;
	}
	goto LA27_;
LA29_: ;
	{
		{
			if (!needsZeroMem_1) goto LA49_;
			resetLoc__cgen_u13360(p_p0, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA47_;
LA49_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
			tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q colontmpD__7;
			tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q colontmpD__8;
			tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q T53_;
			colontmpD__6 = NIM_NIL;
			colontmpD__7 = (tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0;
			colontmpD__8 = (tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0;
			colontmpD__6 = t__cgen_u97((*d_p2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			T53_ = (tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0;
			{
				if (!isRef_1) goto LA56_;
				colontmpD__7 = ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)1);
				T53_ = colontmpD__7;
			}
			goto LA54_;
LA56_: ;
			{
				colontmpD__8 = ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0);
				T53_ = colontmpD__8;
			}
LA54_: ;
			genObjectInit__cgen_u12909(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2), colontmpD__6, d_p2, T53_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			{
				LA52_:;
			}
			{
				oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin52_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA47_: ;
		r_1 = rdLoc__cgen_u470((*d_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA27_: ;
	colontmpD__4 = getTypeDesc__cgen_u8738((*p_p0).module, t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD__4);
	ty_1 = t_1;
	eqwasMoved___ast_u3375(&t_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA63;
				i_1 = i_2;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* check_1;
					check_1 = NIM_NIL;
					{
						if (!(((*(*e_p1)._kind_6.sons.p->data[i_1]).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)15)))&31U)))!=0)) goto LA68_;
						eqdestroy___ast_u3252(check_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						goto LA64;
					}
LA68_: ;
					check_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
					{
						NIM_BOOL T72_;
						NI T73_;
						T72_ = (NIM_BOOL)0;
						T73_ = (NI)0;
						T73_ = len__ast_u3190((*e_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
						T72_ = (T73_ == ((NI)3));
						if (!(T72_)) goto LA74_;
						T72_ = (((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)2)))&31U)))!=0);
LA74_: ;
						if (!T72_) goto LA75_;
						eqcopy___ast_u3255(&check_1, (*(*e_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)2)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
					}
LA75_: ;
					genFieldObjConstr__cgen_u23551(p_p0, ty_1, useTemp_1, isRef_1, (*(*e_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], (*(*e_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)1)], check_1, d_p2, r_1, (*e_p1).info);
					if (NIM_UNLIKELY(*nimErr_)) goto LA65_;
					{
						LA65_:;
					}
					{
						oldNimErrFin65_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(check_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin65_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA64: ;
				i_2 += ((NI)1);
			} LA63: ;
		}
	}
	{
		if (!useTemp_1) goto LA81_;
		{
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA85_;
			eqsink___ast_u6293((&(*d_p2)), tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqwasMoved___ast_u6281((&tmp_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA83_;
LA85_: ;
		{
			tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T88_;
			T88_ = 0;
			genAssignment__cgen_u12898(p_p0, (*d_p2), tmp_1, T88_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA83_: ;
	}
LA81_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(r_1);
		eqdestroy___ast_u6284(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCast__cgen_u25245)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* destt_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srct_1;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	destt_1 = NIM_NIL;
	srct_1 = NIM_NIL;
	destt_1 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	srct_1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_1574);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 lbl_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
		NimStringV2 colontmpD_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
		NimStringV2 T10_;
		NI64 destsize_1;
		NI64 srcsize_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T38_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T39_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*destt_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*destt_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39) || (*destt_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18) || (*destt_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*destt_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16));
		if (T4_) goto LA5_;
		T4_ = ((*srct_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) && (*srct_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39) || (*srct_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18) || (*srct_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*srct_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16));
LA5_: ;
		if (!T4_) goto LA6_;
		lbl_1.len = 0; lbl_1.p = NIM_NIL;
		nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		(*p_p0).labels += ((NI)1);
		lbl_1 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		T9_[0] = lbl_1;
		T10_.len = 0; T10_.p = NIM_NIL;
		T10_ = percent___cgen_u25271(T9_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T10_); goto LA8_;}
		eqsink___system_u2700((&tmp_1.snippet), T10_);
		destsize_1 = getSize__types_u3397((*(*(*p_p0).module).g).config, destt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		srcsize_1 = getSize__types_u3397((*(*(*p_p0).module).g).config, srct_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			NimStringV2 res_1;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2* T16_;
			NimStringV2* T17_;
			if (!(srcsize_1 < destsize_1)) goto LA13_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T16_ = (NimStringV2*)0;
			T16_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			addIndent__cgen_u315(p_p0, T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T17_ = (NimStringV2*)0;
			T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 8);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2714);
			colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2716);
			colontmpD__3 = getTypeDesc__cgen_u8738((*p_p0).module, (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 14);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2718);
			cgFormatValue__cgen_u163((&res_1), lbl_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2719);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA20_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2720);
			}
LA20_: ;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2721);
			colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2722);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2724);
			cgFormatValue__cgen_u163((&res_1), lbl_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 12);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2726);
			cgFormatValue__cgen_u163((&res_1), lbl_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2727);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA24_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2728);
			}
LA24_: ;
			prepareAdd((&(*T17_)), res_1.len + 0);
appendString((&(*T17_)), res_1);
			{
				LA15_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
		goto LA11_;
LA13_: ;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2* T30_;
			NimStringV2* T31_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			T30_ = (NimStringV2*)0;
			T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			addIndent__cgen_u315(p_p0, T30_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			T31_ = (NimStringV2*)0;
			T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2729);
			colontmpD__5 = getTypeDesc__cgen_u8738((*p_p0).module, (*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2731);
			colontmpD__6 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_2), 12);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2733);
			cgFormatValue__cgen_u163((&res_2), lbl_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2734);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA34_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2735);
			}
LA34_: ;
			prepareAdd((&(*T31_)), res_2.len + 0);
appendString((&(*T31_)), res_2);
			{
				LA29_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA11_: ;
		tmp_1.k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6);
		T38_ = NIM_NIL;
		T38_ = lodeTyp__cgen_u104(srct_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T38_); goto LA8_;}
		eqsink___ast_u3261(&tmp_1.lode, T38_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		tmp_1.storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2);
		tmp_1.flags = 0;
		expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], (&tmp_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T39_[0] = lbl_1;
		colontmpD_ = percent___cgen_u25308(T39_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD_, tmp_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u6284(tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(lbl_1);
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		genSomeCast__cgen_u25144(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(srct_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(destt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConv__cgen_u25399)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* destTypeX60gensym6207__1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srcTypeX60gensym6207__1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	destTypeX60gensym6207__1 = NIM_NIL;
	srcTypeX60gensym6207__1 = NIM_NIL;
	{
		NIM_BOOL T4_;
		destTypeX60gensym6207__1 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2736);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		srcTypeX60gensym6207__1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2736);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = (NIM_BOOL)0;
		T4_ = sameBackendTypePickyAliases__types_u2757(destTypeX60gensym6207__1, srcTypeX60gensym6207__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA5_: ;
	{
		genSomeCast__cgen_u25144(p_p0, e_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(srcTypeX60gensym6207__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(destTypeX60gensym6207__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isCppRef__cgen_u21817)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
	if (T3_) goto LA4_;
	T3_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	colontmpD_ = skipTypes__ast_u5379(typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
LA5_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA6_;
	colontmpD__2 = skipTypes__ast_u5379(typ_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = !((((*colontmpD__2).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)20)))&63U)))!=0));
LA6_: ;
	result = T1_;
	eqdestroy___ast_u3378(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genAddr__cgen_u22001)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__2;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__3;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin33_;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	colontmpD__3 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		NimStringV2 colontmpD__4;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T7_;
		NimStringV2 T8_;
		colontmpD_ = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA4_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T7_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], T7_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rawNewString(a_1.snippet.len + 1);
appendString((&T8_), TM__MQdRN7fpbG7rPm4JpVVAhA_2737);
appendString((&T8_), a_1.snippet);
		colontmpD__4 = T8_;
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__4, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T12_;
		tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T13_;
		tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA T19_;
		T12_ = (NIM_BOOL)0;
		T13_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
		{
			if (!((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA16_;
			colontmpD__2 = (*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).kind;
			T13_ = colontmpD__2;
		}
		goto LA14_;
LA16_: ;
		{
			colontmpD__3 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
			T13_ = colontmpD__3;
		}
LA14_: ;
		T19_ = (tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)0;
		T19_ = mapType__cgen_u1315((*(*(*p_p0).module).g).config, (*(*e_p1)._kind_6.sons.p->data[((NI)0)]).typField, (T13_ == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T12_ = (T19_ == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17));
		if (T12_) goto LA20_;
		T12_ = isCppRef__cgen_u21817(p_p0, (*e_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA20_: ;
		if (!T12_) goto LA21_;
		expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqcopy___ast_u3255(&(*d_p2).lode, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA21_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* destTypeX60gensym4662__1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srcTypeX60gensym4662__1;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T25_;
		nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		destTypeX60gensym4662__1 = NIM_NIL;
		srcTypeX60gensym4662__1 = NIM_NIL;
		T25_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], T25_, (&a_2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		{
			NIM_BOOL T28_;
			NIM_BOOL T30_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw exprLoc_1;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T34_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T35_;
			T28_ = (NIM_BOOL)0;
			T28_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58) || (*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59) || (*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)60));
			if (!(T28_)) goto LA29_;
			destTypeX60gensym4662__1 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2736);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			srcTypeX60gensym4662__1 = skipTypes__ast_u5379((*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2736);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			T30_ = (NIM_BOOL)0;
			T30_ = sameBackendTypePickyAliases__types_u2757(destTypeX60gensym4662__1, srcTypeX60gensym4662__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			T28_ = !(T30_);
LA29_: ;
			if (!T28_) goto LA31_;
			nimZeroMem((void*)(&exprLoc_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			T34_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)], T34_, (&exprLoc_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			getTemp__cgen_u9546(p_p0, (*e_p1).typField, NIM_FALSE, (&tmp_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			colontmpD__5 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			T35_[0] = colontmpD__5;
			colontmpD__6 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, exprLoc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			T35_[1] = colontmpD__6;
			colontmpD__7 = percent___cgen_u22033(T35_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			putIntoDest__cgen_u21142(p_p0, (&tmp_1), e_p1, colontmpD__7, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			colontmpD__8 = rdLoc__cgen_u470(tmp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__8, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
			{
				LA33_:;
			}
			{
				oldNimErrFin33_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___ast_u6284(tmp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				eqdestroy___ast_u6284(exprLoc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				*nimErr_ = oldNimErrFin33_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		}
		goto LA26_;
LA31_: ;
		{
			NimStringV2 colontmpD__9;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__9 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__9, a_2.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
			{
				LA39_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__9);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		}
LA26_: ;
		{
			LA24_:;
		}
		{
			oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(srcTypeX60gensym4662__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(destTypeX60gensym4662__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u6284(a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin24_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genUncheckedArrayElem__cgen_u22408)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, x_p2, T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, y_p3, T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*d_p4).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA6_;
		(*d_p4).storage = a_1.storage;
	}
LA6_: ;
	res_1 = rawNewString(((NI)80));
	colontmpD_ = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2739);
	colontmpD__2 = rdCharLoc__cgen_u12869(b_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2740);
	putIntoDest__cgen_u21142(p_p0, d_p4, n_p1, res_1, a_1.storage);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genArrayElem__cgen_u22429)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 first_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T4_;
NIM_BOOL oldNimErrFin24_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	ty_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	first_1.len = 0; first_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, x_p2, T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, y_p3, T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ty_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_2741);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	first_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ty_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	intLiteral__cgen_u20135(T4_, (&first_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = (((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0);
		if (!(T7_)) goto LA8_;
		T7_ = !(((*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49)));
LA8_: ;
		if (!T7_) goto LA9_;
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = isConstExpr__trees_u129(y_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T13_)) goto LA14_;
			{
				NIM_BOOL T18_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T19_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T21_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
				T18_ = (NIM_BOOL)0;
				T19_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ty_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T18_ = eqeq___int128_u980(T19_, IL64(0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(T18_)) goto LA20_;
				T21_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ty_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T18_ = lteq___int128_u973(IL64(0), T21_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA20_: ;
				if (!T18_) goto LA22_;
				colontmpD__4 = NIM_NIL;
				colontmpD__5 = NIM_NIL;
				{
					NIM_BOOL T27_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T28_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T29_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T31_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T32_;
					NimStringV2 last_1;
					NimStringV2 res_2;
					NimStringV2 colontmpD__6;
					NimStringV2 colontmpD__7;
					NimStringV2 colontmpD__8;
					NimStringV2 res_3;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T36_;
					NimStringV2* T37_;
					NimStringV2* T38_;
					NimStringV2* T39_;
					NimStringV2* T40_;
					NimStringV2* T41_;
					T27_ = (NIM_BOOL)0;
					colontmpD__4 = t__cgen_u97(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					T28_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					T29_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ty_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					T27_ = lt___int128_u404(T28_, T29_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					if (T27_) goto LA30_;
					T31_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ty_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					colontmpD__5 = t__cgen_u97(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					T32_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					T27_ = lt___int128_u404(T31_, T32_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
LA30_: ;
					if (!T27_) goto LA33_;
					last_1.len = 0; last_1.p = NIM_NIL;
					res_2.len = 0; res_2.p = NIM_NIL;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					res_3.len = 0; res_3.p = NIM_NIL;
					last_1 = newRopeAppender__ropes_u7(((NI)80));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					T36_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ty_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					intLiteral__cgen_u20135(T36_, (&last_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					T37_ = (NimStringV2*)0;
					T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					addIndent__cgen_u315(p_p0, T37_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					T38_ = (NimStringV2*)0;
					T38_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					res_2 = rawNewString(((NI)80));
					prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2743);
					colontmpD__6 = rdCharLoc__cgen_u12869(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					prepareAdd((&res_2), 9);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2745);
					cgFormatValue__cgen_u163((&res_2), last_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2746);
					colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2748);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2749);
					colontmpD__8 = rdCharLoc__cgen_u12869(b_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2750);
					cgFormatValue__cgen_u163((&res_2), last_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2751);
					prepareAdd((&(*T38_)), res_2.len + 0);
appendString((&(*T38_)), res_2);
					T39_ = (NimStringV2*)0;
					T39_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					raiseInstr__cgen_u457(p_p0, T39_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					T40_ = (NimStringV2*)0;
					T40_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					addIndent__cgen_u315(p_p0, T40_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					T41_ = (NimStringV2*)0;
					T41_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					res_3 = rawNewString(((NI)80));
					prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2752);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA44_;
						prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2753);
					}
LA44_: ;
					prepareAdd((&(*T41_)), res_3.len + 0);
appendString((&(*T41_)), res_3);
					{
						LA35_:;
					}
					{
						eqdestroy___system_u2691(res_3);
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(res_2);
						eqdestroy___system_u2691(last_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
				}
LA33_: ;
				{
					LA24_:;
				}
				{
					oldNimErrFin24_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin24_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA16_;
LA22_: ;
			{
				NimStringV2 last_2;
				NimStringV2 res_4;
				NimStringV2 colontmpD__9;
				NimStringV2 colontmpD__10;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				NimStringV2 res_5;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T52_;
				NimStringV2* T53_;
				NimStringV2* T54_;
				NimStringV2* T55_;
				NimStringV2* T56_;
				NimStringV2* T57_;
				last_2.len = 0; last_2.p = NIM_NIL;
				res_4.len = 0; res_4.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				res_5.len = 0; res_5.p = NIM_NIL;
				last_2 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T52_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ty_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				intLiteral__cgen_u20135(T52_, (&last_2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T53_ = (NimStringV2*)0;
				T53_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				addIndent__cgen_u315(p_p0, T53_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T54_ = (NimStringV2*)0;
				T54_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				res_4 = rawNewString(((NI)80));
				prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2754);
				colontmpD__9 = rdCharLoc__cgen_u12869(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2755);
				cgFormatValue__cgen_u163((&res_4), first_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2756);
				colontmpD__10 = rdCharLoc__cgen_u12869(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2757);
				cgFormatValue__cgen_u163((&res_4), last_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2758);
				colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2760);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__11);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2761);
				colontmpD__12 = rdCharLoc__cgen_u12869(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__12);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2762);
				cgFormatValue__cgen_u163((&res_4), first_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2763);
				cgFormatValue__cgen_u163((&res_4), last_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2764);
				prepareAdd((&(*T54_)), res_4.len + 0);
appendString((&(*T54_)), res_4);
				T55_ = (NimStringV2*)0;
				T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				raiseInstr__cgen_u457(p_p0, T55_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T56_ = (NimStringV2*)0;
				T56_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				addIndent__cgen_u315(p_p0, T56_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T57_ = (NimStringV2*)0;
				T57_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				res_5 = rawNewString(((NI)80));
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2765);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA60_;
					prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2766);
				}
LA60_: ;
				prepareAdd((&(*T57_)), res_5.len + 0);
appendString((&(*T57_)), res_5);
				{
					LA51_:;
				}
				{
					eqdestroy___system_u2691(res_5);
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___system_u2691(colontmpD__10);
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(res_4);
					eqdestroy___system_u2691(last_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA16_: ;
		}
		goto LA11_;
LA14_: ;
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg idx_1;
			idx_1 = getOrdValue__types_u167(y_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				NIM_BOOL T67_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T68_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T70_;
				NimStringV2 colontmpD__13;
				NimStringV2 colontmpD__14;
				NimStringV2 T74_;
				T67_ = (NIM_BOOL)0;
				T68_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ty_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T67_ = lt___int128_u404(idx_1, T68_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (T67_) goto LA69_;
				T70_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ty_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T67_ = lt___int128_u404(T70_, idx_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA69_: ;
				if (!T67_) goto LA71_;
				colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				T74_.len = 0; T74_.p = NIM_NIL;
				{
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T77_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T78_;
					NIM_BOOL T79_;
					T77_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ty_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
					T78_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ty_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
					T79_ = (NIM_BOOL)0;
					T79_ = lt___int128_u404(T77_, T78_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
					if (!T79_) goto LA80_;
					colontmpD__13 = TM__MQdRN7fpbG7rPm4JpVVAhA_2768;
					T74_ = colontmpD__13;
				}
				goto LA75_;
LA80_: ;
				{
					NimStringV2 colontmpD__15;
					NimStringV2 colontmpD__16;
					NimStringV2 colontmpD__17;
					NimStringV2 T84_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T85_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T86_;
					colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
					colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
					colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
					T84_.len = 0; T84_.p = NIM_NIL;
					colontmpD__15 = dollar___int128_u36(idx_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
					T85_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, ty_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
					colontmpD__16 = dollar___int128_u36(T85_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
					T86_ = lastOrd__types_u1298((*(*(*p_p0).module).g).config, ty_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
					colontmpD__17 = dollar___int128_u36(T86_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
					T84_ = rawNewString(colontmpD__15.len + colontmpD__16.len + colontmpD__17.len + 18);
appendString((&T84_), TM__MQdRN7fpbG7rPm4JpVVAhA_2770);
appendString((&T84_), colontmpD__15);
appendString((&T84_), TM__MQdRN7fpbG7rPm4JpVVAhA_2772);
appendString((&T84_), colontmpD__16);
appendString((&T84_), TM__MQdRN7fpbG7rPm4JpVVAhA_2774);
appendString((&T84_), colontmpD__17);
					colontmpD__14 = T84_;
					T74_ = colontmpD__14;
					{
						LA83_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__17);
						eqdestroy___system_u2691(colontmpD__16);
						eqdestroy___system_u2691(colontmpD__15);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
				}
LA75_: ;
				liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*x_p2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), T74_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2775, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
				{
					LA73_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(colontmpD__13);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA71_: ;
		}
LA11_: ;
	}
LA9_: ;
	{
		if (!((*d_p4).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA93_;
		(*d_p4).storage = a_1.storage;
	}
LA93_: ;
	res_1 = rawNewString(((NI)80));
	colontmpD__2 = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2777);
	colontmpD__3 = rdCharLoc__cgen_u12869(b_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2779);
	cgFormatValue__cgen_u163((&res_1), first_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2780);
	putIntoDest__cgen_u21142(p_p0, d_p4, n_p1, res_1, a_1.storage);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(first_1);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genOpenArrayElem__cgen_u22621)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, x_p2, T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, y_p3, T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T6_;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		T6_ = (NIM_BOOL)0;
		T6_ = reifiedOpenArray__cgen_u14410(x_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T6_)) goto LA7_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 res_3;
			NimStringV2* T15_;
			NimStringV2* T16_;
			NimStringV2* T17_;
			NimStringV2* T18_;
			NimStringV2* T19_;
			if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0)) goto LA12_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			res_3.len = 0; res_3.p = NIM_NIL;
			T15_ = (NimStringV2*)0;
			T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			addIndent__cgen_u315(p_p0, T15_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			T16_ = (NimStringV2*)0;
			T16_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2781);
			colontmpD__3 = rdCharLoc__cgen_u12869(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2782);
			colontmpD__4 = rdCharLoc__cgen_u12869(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2783);
			colontmpD__5 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2785);
			colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2786);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2787);
			colontmpD__7 = rdCharLoc__cgen_u12869(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2788);
			colontmpD__8 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			prepareAdd((&res_2), 10);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2790);
			prepareAdd((&(*T16_)), res_2.len + 0);
appendString((&(*T16_)), res_2);
			T17_ = (NimStringV2*)0;
			T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			raiseInstr__cgen_u457(p_p0, T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			T18_ = (NimStringV2*)0;
			T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			addIndent__cgen_u315(p_p0, T18_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			T19_ = (NimStringV2*)0;
			T19_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2791);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA22_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2792);
			}
LA22_: ;
			prepareAdd((&(*T19_)), res_3.len + 0);
appendString((&(*T19_)), res_3);
			{
				LA14_:;
			}
			{
				eqdestroy___system_u2691(res_3);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA12_: ;
		{
			if (!((*d_p4).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA28_;
			(*d_p4).storage = a_1.storage;
		}
LA28_: ;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2793);
		colontmpD__2 = rdCharLoc__cgen_u12869(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2794);
		putIntoDest__cgen_u21142(p_p0, d_p4, n_p1, res_1, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA7_: ;
	{
		NimStringV2 res_4;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		{
			NimStringV2 res_5;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 res_6;
			NimStringV2* T39_;
			NimStringV2* T40_;
			NimStringV2* T41_;
			NimStringV2* T42_;
			NimStringV2* T43_;
			if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0)) goto LA36_;
			res_5.len = 0; res_5.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			res_6.len = 0; res_6.p = NIM_NIL;
			T39_ = (NimStringV2*)0;
			T39_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			addIndent__cgen_u315(p_p0, T39_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			T40_ = (NimStringV2*)0;
			T40_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			res_5 = rawNewString(((NI)80));
			prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2795);
			colontmpD__11 = rdCharLoc__cgen_u12869(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			prepareAdd((&res_5), 8);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2796);
			colontmpD__12 = rdCharLoc__cgen_u12869(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__12);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2797);
			colontmpD__13 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__13);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			prepareAdd((&res_5), 10);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2799);
			colontmpD__14 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2800);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__14);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2801);
			colontmpD__15 = rdCharLoc__cgen_u12869(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2802);
			colontmpD__16 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			cgFormatValue__cgen_u163((&res_5), colontmpD__16);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			prepareAdd((&res_5), 12);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2804);
			prepareAdd((&(*T40_)), res_5.len + 0);
appendString((&(*T40_)), res_5);
			T41_ = (NimStringV2*)0;
			T41_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			raiseInstr__cgen_u457(p_p0, T41_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			T42_ = (NimStringV2*)0;
			T42_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			addIndent__cgen_u315(p_p0, T42_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			T43_ = (NimStringV2*)0;
			T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
			res_6 = rawNewString(((NI)80));
			prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2805);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA46_;
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_2806);
			}
LA46_: ;
			prepareAdd((&(*T43_)), res_6.len + 0);
appendString((&(*T43_)), res_6);
			{
				LA38_:;
			}
			{
				eqdestroy___system_u2691(res_6);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(res_5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
LA36_: ;
		{
			if (!((*d_p4).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA52_;
			(*d_p4).storage = a_1.storage;
		}
LA52_: ;
		res_4 = rawNewString(((NI)80));
		colontmpD__9 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		prepareAdd((&res_4), 8);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2808);
		colontmpD__10 = rdCharLoc__cgen_u12869(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2809);
		putIntoDest__cgen_u21142(p_p0, d_p4, n_p1, res_4, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			LA33_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(res_4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSeqElem__cgen_u22707)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
	NimStringV2 res_1;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	ty_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, x_p2, T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, y_p3, T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ty_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T8_;
		if (!((*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA6_;
		colontmpD__7 = NIM_NIL;
		colontmpD__7 = elementType__ast_u5331(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_ = NIM_NIL;
		T8_ = skipTypes__ast_u5379(colontmpD__7, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T8_); goto LA1_;}
		eqsink___ast_u3387(&ty_1, T8_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3378(colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 res_3;
		NimStringV2* T14_;
		NimStringV2* T15_;
		NimStringV2* T16_;
		NimStringV2* T17_;
		NimStringV2* T18_;
		if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)4)))&31U)))!=0)) goto LA11_;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		res_3.len = 0; res_3.p = NIM_NIL;
		T14_ = (NimStringV2*)0;
		T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		addIndent__cgen_u315(p_p0, T14_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T15_ = (NimStringV2*)0;
		T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2810);
		colontmpD__8 = rdCharLoc__cgen_u12869(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2811);
		colontmpD__9 = rdCharLoc__cgen_u12869(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2812);
		colontmpD__10 = lenExpr__cgen_u495(p_p0, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2813);
		colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2814);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__11);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2815);
		colontmpD__12 = rdCharLoc__cgen_u12869(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2816);
		colontmpD__13 = lenExpr__cgen_u495(p_p0, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__13);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 5);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2818);
		prepareAdd((&(*T15_)), res_2.len + 0);
appendString((&(*T15_)), res_2);
		T16_ = (NimStringV2*)0;
		T16_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		raiseInstr__cgen_u457(p_p0, T16_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T17_ = (NimStringV2*)0;
		T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		addIndent__cgen_u315(p_p0, T17_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T18_ = (NimStringV2*)0;
		T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		res_3 = rawNewString(((NI)80));
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2819);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA21_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2820);
		}
LA21_: ;
		prepareAdd((&(*T18_)), res_3.len + 0);
appendString((&(*T18_)), res_3);
		{
			LA13_:;
		}
		{
			eqdestroy___system_u2691(res_3);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	{
		if (!((*d_p4).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA27_;
		(*d_p4).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3);
	}
LA27_: ;
	{
		NimStringV2 res_4;
		colontmpD__2 = t__cgen_u97(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__3 = skipTypes__ast_u5379(colontmpD__2, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*colontmpD__3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*colontmpD__3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA31_;
		res_4.len = 0; res_4.p = NIM_NIL;
		res_4 = rawNewString(((NI)80));
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2821);
		cgFormatValue__cgen_u163((&res_4), a_1.snippet);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2822);
		eqsink___system_u2700((&a_1.snippet), res_4);
	}
LA31_: ;
	{
		NIM_BOOL T35_;
		NIM_BOOL T36_;
		NimStringV2 res_5;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2* T42_;
		NimStringV2* T43_;
		T35_ = (NIM_BOOL)0;
		T36_ = (NIM_BOOL)0;
		T36_ = (((*d_p4).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)9)))&15U)))!=0);
		if (!(T36_)) goto LA37_;
		T36_ = ((*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28));
LA37_: ;
		T35_ = T36_;
		if (!(T35_)) goto LA38_;
		T35_ = (((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
LA38_: ;
		if (!T35_) goto LA39_;
		res_5.len = 0; res_5.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		T42_ = (NimStringV2*)0;
		T42_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		addIndent__cgen_u315(p_p0, T42_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		T43_ = (NimStringV2*)0;
		T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		res_5 = rawNewString(((NI)80));
		colontmpD__14 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2823);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__14);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2824);
		colontmpD__15 = byRefLoc__cgen_u12841(p_p0, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		cgFormatValue__cgen_u163((&res_5), colontmpD__15);
		if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
		prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2825);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA46_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2826);
		}
LA46_: ;
		prepareAdd((&(*T43_)), res_5.len + 0);
appendString((&(*T43_)), res_5);
		{
			LA41_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(res_5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA39_: ;
	res_1 = rawNewString(((NI)80));
	colontmpD__4 = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = dataField__cgen_u516(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2827);
	colontmpD__6 = rdCharLoc__cgen_u12869(b_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__6);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2828);
	putIntoDest__cgen_u21142(p_p0, d_p4, n_p1, res_1, a_1.storage);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCStringElem__cgen_u22516)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p3, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p4) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&b_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, x_p2, T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, y_p3, T3_, (&b_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*d_p4).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA6_;
		(*d_p4).storage = a_1.storage;
	}
LA6_: ;
	res_1 = rawNewString(((NI)80));
	colontmpD_ = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2829);
	colontmpD__2 = rdCharLoc__cgen_u12869(b_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2830);
	putIntoDest__cgen_u21142(p_p0, d_p4, n_p1, res_1, a_1.storage);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTupleElem__cgen_u22054)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tupType_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 r_1;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NI i_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	tupType_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	r_1.len = 0; r_1.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	i_1 = ((NI)0);
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tupType_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_2831);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA5_;
		(*d_p2).storage = a_1.storage;
	}
LA5_: ;
	colontmpD__2 = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD__3);
	r_1 = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		i_1 = ((NI) ((*(*e_p1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal));
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2833, TM__MQdRN7fpbG7rPm4JpVVAhA_2834);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	colontmpD__4 = rope__ropes_u15(((NI64) (i_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T9_[0] = colontmpD__4;
	colontmpD__5 = percent___cgen_u22081(T9_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&r_1), colontmpD__5.len + 0);
appendString((&r_1), colontmpD__5);
	putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, r_1, a_1.storage);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(r_1);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(tupType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBracketExpr__cgen_u22797)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	NimStringV2 colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ty_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	ty_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_2738);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T6_;
		if (!((*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21))) goto LA4_;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = elementType__ast_u5331(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T6_ = NIM_NIL;
		T6_ = skipTypes__ast_u5379(colontmpD__2, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T6_); goto LA1_;}
		eqsink___ast_u3387(&ty_1, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	switch ((*ty_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
	{
		genUncheckedArrayElem__cgen_u22408(p_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		genArrayElem__cgen_u22429(p_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		genOpenArrayElem__cgen_u22621(p_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		genSeqElem__cgen_u22707(p_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	{
		genCStringElem__cgen_u22516(p_p0, n_p1, (*n_p1)._kind_6.sons.p->data[((NI)0)], (*n_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		genTupleElem__cgen_u22054(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T15_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T15_.len = 0; T15_.p = NIM_NIL;
		colontmpD__3 = dollar___ast_u182((*ty_1).kind);
		T15_ = rawNewString(colontmpD__3.len + 21);
appendString((&T15_), TM__MQdRN7fpbG7rPm4JpVVAhA_2836);
appendString((&T15_), colontmpD__3);
appendChar((&T15_), 41);
		colontmpD__4 = T15_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__4, TM__MQdRN7fpbG7rPm4JpVVAhA_2837);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, (*n_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genDeref__cgen_u21837)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD_;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q colontmpD__2;
	tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA mt_1;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q T1_;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin21_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	colontmpD__2 = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	T1_ = (tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0;
	{
		if (!((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA4_;
		colontmpD_ = (*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).kind;
		T1_ = colontmpD_;
	}
	goto LA2_;
LA4_: ;
	{
		colontmpD__2 = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8);
		T1_ = colontmpD__2;
	}
LA2_: ;
	mt_1 = mapType__cgen_u1315((*(*(*p_p0).module).g).config, (*(*e_p1)._kind_6.sons.p->data[((NI)0)]).typField, (T1_ == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T9_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		T9_ = (NIM_BOOL)0;
		T9_ = (mt_1 == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)17) || mt_1 == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)18));
		if (!(T9_)) goto LA10_;
		T9_ = !((((*d_p2).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)8)))&15U)))!=0));
LA10_: ;
		if (!T9_) goto LA11_;
		colontmpD__3 = NIM_NIL;
		expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			colontmpD__3 = skipTypes__ast_u5379((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			if (!((*colontmpD__3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22))) goto LA16_;
			(*d_p2).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3);
		}
LA16_: ;
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA7_;
LA11_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T29_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		typ_1 = NIM_NIL;
		colontmpD__4 = NIM_NIL;
		eqcopy___ast_u3381(&typ_1, (*(*e_p1)._kind_6.sons.p->data[((NI)0)]).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		{
			NIM_BOOL T24_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T28_;
			T24_ = (NIM_BOOL)0;
			T24_ = ((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)52) || (*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)53));
			if (!(T24_)) goto LA25_;
			T24_ = (((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)10)))&63U)))!=0);
LA25_: ;
			if (!T24_) goto LA26_;
			T28_ = NIM_NIL;
			T28_ = last__ast_u5278(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T28_); goto LA21_;}
			eqsink___ast_u3387(&typ_1, T28_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		}
LA26_: ;
		T29_ = NIM_NIL;
		T29_ = skipTypes__ast_u5379(typ_1, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T29_); goto LA21_;}
		eqsink___ast_u3387(&typ_1, T29_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		{
			NIM_BOOL T32_;
			NIM_BOOL T33_;
			NIM_BOOL T34_;
			NIM_BOOL T35_;
			NIM_BOOL T38_;
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T44_;
			T32_ = (NIM_BOOL)0;
			T33_ = (NIM_BOOL)0;
			T34_ = (NIM_BOOL)0;
			T35_ = (NIM_BOOL)0;
			T35_ = ((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
			if (!(T35_)) goto LA36_;
			T35_ = !((((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)20)))&63U)))!=0));
LA36_: ;
			T34_ = T35_;
			if (!(T34_)) goto LA37_;
			T38_ = (NIM_BOOL)0;
			T38_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T38_) goto LA39_;
			T38_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA39_: ;
			T34_ = T38_;
LA37_: ;
			T33_ = T34_;
			if (!(T33_)) goto LA40_;
			T33_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64));
LA40_: ;
			T32_ = T33_;
			if (!(T32_)) goto LA41_;
			T32_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
LA41_: ;
			if (!T32_) goto LA42_;
			nimZeroMem((void*)(&T44_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			initLocExprSingleUse__cgen_u14116(p_p0, (*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)], (&T44_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			eqsink___ast_u6293((&(*d_p2)), T44_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
		goto LA30_;
LA42_: ;
		{
			initLocExprSingleUse__cgen_u14116(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], (&a_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		}
LA30_: ;
		{
			NIM_BOOL T48_;
			NimStringV2 colontmpD__5;
			T48_ = (NIM_BOOL)0;
			T48_ = !(((*e_p1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
			if (!(T48_)) goto LA49_;
			colontmpD__4 = skipTypes__ast_u5379((*e_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			T48_ = ((*colontmpD__4).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17));
LA49_: ;
			if (!T48_) goto LA50_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__5 = getTypeDesc__cgen_u8738((*p_p0).module, (*e_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			(void)(colontmpD__5);
			{
				LA52_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		}
LA50_: ;
		{
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA57_;
			switch ((*typ_1).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
			{
				(*d_p2).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)3);
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
			{
				(*d_p2).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0);
				{
					NIM_BOOL T63_;
					NIM_BOOL T64_;
					NIM_BOOL T66_;
					NimStringV2 colontmpD__6;
					T63_ = (NIM_BOOL)0;
					T64_ = (NIM_BOOL)0;
					T64_ = !((((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)20)))&63U)))!=0));
					if (!(T64_)) goto LA65_;
					T66_ = (NIM_BOOL)0;
					T66_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
					if (T66_) goto LA67_;
					T66_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA67_: ;
					T64_ = T66_;
LA65_: ;
					T63_ = T64_;
					if (!(T63_)) goto LA68_;
					T63_ = ((*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65));
LA68_: ;
					if (!T63_) goto LA69_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__6 = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
					putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__6, a_1.storage);
					if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___ast_u3378(colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___ast_u3378(typ_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___ast_u6284(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
					{
						LA71_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__6);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
				}
LA69_: ;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
			{
				(*d_p2).storage = ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0);
			}
			break;
			default:
			{
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2 T77_;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				T77_.len = 0; T77_.p = NIM_NIL;
				colontmpD__7 = dollar___ast_u182((*typ_1).kind);
				T77_ = rawNewString(colontmpD__7.len + 9);
appendString((&T77_), TM__MQdRN7fpbG7rPm4JpVVAhA_2839);
appendString((&T77_), colontmpD__7);
				colontmpD__8 = T77_;
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, colontmpD__8, TM__MQdRN7fpbG7rPm4JpVVAhA_2840);
				if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
				{
					LA76_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			}
			break;
			}
		}
		goto LA55_;
LA57_: ;
		{
			NIM_BOOL T81_;
			T81_ = (NIM_BOOL)0;
			T81_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T81_) goto LA82_;
			T81_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA82_: ;
			if (!T81_) goto LA83_;
			{
				NIM_BOOL T87_;
				NIM_BOOL T88_;
				NimStringV2 colontmpD__9;
				T87_ = (NIM_BOOL)0;
				T88_ = (NIM_BOOL)0;
				T88_ = ((*typ_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
				if (!(T88_)) goto LA89_;
				T88_ = !((((*typ_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)20)))&63U)))!=0));
LA89_: ;
				T87_ = T88_;
				if (!(T87_)) goto LA90_;
				T87_ = ((*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65));
LA90_: ;
				if (!T87_) goto LA91_;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__9 = rdLoc__cgen_u470(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__9, a_1.storage);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u3378(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u6284(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
				{
					LA93_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
			}
LA91_: ;
		}
		goto LA55_;
LA83_: ;
LA55_: ;
		{
			NIM_BOOL T98_;
			NimStringV2 colontmpD__10;
			T98_ = (NIM_BOOL)0;
			T98_ = (mt_1 == ((tyEnum_TCTypeKind__AKlc9bMDDlzKRPgHnk2Q3pA)18));
			if (!(T98_)) goto LA99_;
			T98_ = (((*d_p2).flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)8)))&15U)))!=0);
LA99_: ;
			if (!T98_) goto LA100_;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__10 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__10, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
			{
				LA102_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		}
		goto LA96_;
LA100_: ;
		{
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			tyArray__YgExxhfgKcesA5EOUj1MOA T107_;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__11 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			T107_[0] = colontmpD__11;
			colontmpD__12 = percent___cgen_u12921(T107_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, colontmpD__12, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
			{
				LA106_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		}
LA96_: ;
		{
			LA21_:;
		}
		{
			oldNimErrFin21_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin21_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRecordFieldAux__cgen_u22041)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	NimStringV2 colontmpD__2;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_ = 0;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&T3_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___ast_u6293((&(*a_p3)), T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!(((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA6_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2842, TM__MQdRN7fpbG7rPm4JpVVAhA_2843);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	{
		if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA10_;
		(*d_p2).storage = (*a_p3).storage;
	}
LA10_: ;
	colontmpD_ = t__cgen_u97((*a_p3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD_, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD__2);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRecordField__cgen_u22128)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 r_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* f_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin33_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	r_1.len = 0; r_1.p = NIM_NIL;
	f_1 = NIM_NIL;
	ty_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T7_) goto LA8_;
		T7_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA8_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA9_;
		T6_ = ((*e_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45));
LA9_: ;
		T5_ = T6_;
		if (!(T5_)) goto LA10_;
		T5_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
LA10_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA11_;
		T4_ = ((*(*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
LA11_: ;
		if (!T4_) goto LA12_;
		typ_1 = NIM_NIL;
		typ_1 = elementType__ast_u5331((*(*e_p1)._kind_6.sons.p->data[((NI)1)]).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			NIM_BOOL T17_;
			NimStringV2 colontmpD__2;
			T17_ = (NIM_BOOL)0;
			T17_ = contains__cgen_u4125((*(*(*(*p_p0).module).g).graph).memberProcsPerType, (*typ_1).itemId);
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
			if (!T17_) goto LA18_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, typ_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			(void)(colontmpD__2);
			{
				LA20_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		}
LA18_: ;
		{
			LA14_:;
		}
		{
			oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin14_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA12_: ;
	genRecordFieldAux__cgen_u22041(p_p0, e_p1, d_p2, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	r_1 = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u4577(&f_1, (*(*e_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	ty_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_388);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD__3;
		if (!((*ty_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18))) goto LA27_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		prepareAdd((&r_1), 6);
appendString((&r_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2844);
		colontmpD__3 = rope__ropes_u15(((NI64) ((*f_1).position)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		prepareAdd((&r_1), colontmpD__3.len + 0);
appendString((&r_1), colontmpD__3);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, r_1, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		{
			LA29_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA25_;
LA27_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* rtyp_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		rtyp_1 = NIM_NIL;
		field_1 = NIM_NIL;
		rtyp_1 = ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL);
		field_1 = lookupFieldAgain__cgen_u22086(p_p0, ty_1, f_1, (&r_1), &rtyp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			NIM_BOOL T36_;
			T36_ = (NIM_BOOL)0;
			T36_ = ((*field_1).loc.snippet.len == 0);
			if (!(T36_)) goto LA37_;
			T36_ = !((rtyp_1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA37_: ;
			if (!T36_) goto LA38_;
			fillObjectFields__cgen_u5401((*p_p0).module, rtyp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
LA38_: ;
		{
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2 T45_;
			if (!((*field_1).loc.snippet.len == 0)) goto LA42_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T45_.len = 0; T45_.p = NIM_NIL;
			colontmpD__4 = typeToString__types_u54(ty_1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T45_ = rawNewString(colontmpD__4.len + 17);
appendString((&T45_), TM__MQdRN7fpbG7rPm4JpVVAhA_2846);
appendString((&T45_), colontmpD__4);
			colontmpD__5 = T45_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, colontmpD__5, TM__MQdRN7fpbG7rPm4JpVVAhA_2847);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			{
				LA44_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		}
LA42_: ;
		prepareAdd((&r_1), 1);
appendString((&r_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2848);
		prepareAdd((&r_1), (*field_1).loc.snippet.len + 0);
appendString((&r_1), (*field_1).loc.snippet);
		putIntoDest__cgen_u21142(p_p0, d_p2, e_p1, r_1, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			LA33_:;
		}
		{
			oldNimErrFin33_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u3378(rtyp_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin33_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA25_: ;
	freeze__ropes_u10(r_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(ty_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(f_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(r_1);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCheckedRecordField__cgen_u22380)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
NIM_BOOL oldNimErrFin5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ty_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		NimStringV2 r_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* f_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)2)))&31U)))!=0)) goto LA3_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		ty_1 = NIM_NIL;
		colontmpD_ = NIM_NIL;
		r_1.len = 0; r_1.p = NIM_NIL;
		f_1 = NIM_NIL;
		field_1 = NIM_NIL;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		genRecordFieldAux__cgen_u22041(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], d_p2, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD_ = t__cgen_u97(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		ty_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_388);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		r_1 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		f_1 = (*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)])._kind_4.sym;
		field_1 = lookupFieldAgain__cgen_u22086(p_p0, ty_1, f_1, (&r_1), ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			if (!((*field_1).loc.snippet.len == 0)) goto LA8_;
			fillObjectFields__cgen_u5401((*p_p0).module, ty_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA8_: ;
		{
			if (!((*field_1).loc.snippet.len == 0)) goto LA12_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*e_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2849, TM__MQdRN7fpbG7rPm4JpVVAhA_2850);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA12_: ;
		genFieldCheck__cgen_u22241(p_p0, e_p1, r_1, field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&r_1), 1);
appendString((&r_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2851);
		prepareAdd((&r_1), (*field_1).loc.snippet.len + 0);
appendString((&r_1), (*field_1).loc.snippet);
		putIntoDest__cgen_u21142(p_p0, d_p2, (*e_p1)._kind_6.sons.p->data[((NI)0)], r_1, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		freeze__ropes_u10(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(r_1);
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(ty_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		genRecordField__cgen_u22128(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBlock__cgen_u17227)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	NimStringV2 res_1;
	NI oldBreakIdxX60gensym2331__1;
	NimStringV2* T12_;
	NimStringV2* T13_;
	NI T18_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	res_1.len = 0; res_1.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isEmptyType__ast_u7234((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T11_;
			if (!((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA9_;
			nimZeroMem((void*)(&T11_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T11_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqsink___ast_u6293((&(*d_p2)), T11_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA9_: ;
		(*d_p2).flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)8))) & 15);
	}
LA5_: ;
	oldBreakIdxX60gensym2331__1 = (*p_p0).breakIdx;
	T12_ = (NimStringV2*)0;
	T12_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_ = (NimStringV2*)0;
	T13_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2852);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA16_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2853);
	}
LA16_: ;
	prepareAdd((&(*T13_)), res_1.len + 0);
appendString((&(*T13_)), res_1);
	T18_ = (NI)0;
	T18_ = startBlockInternal__cgen_u15729(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).breakIdx = T18_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA21_;
		sym_1 = NIM_NIL;
		eqcopy___ast_u4577(&sym_1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*sym_1).loc.k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)10);
		(*sym_1).position = (NI)((*p_p0).breakIdx + ((NI)1));
		eqdestroy___ast_u4574(sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA21_: ;
	expr__cgen_u14084(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], d_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	endBlock__cgen_u15767(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).breakIdx = oldBreakIdxX60gensym2331__1;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, initFrameNoDebug__cgen_u20024)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 frame_p1, NimStringV2 procname_p2, NimStringV2 filename_p3, NI line_p4) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 res_1;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	cgsym__cgen_u138((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2858);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = frame_p1;
	colontmpD_ = percent___cgen_u20031(T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*p_p0).blocks.p->data[((NI)0)].sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0))- 0]), colontmpD_.len + 0);
appendString((&(*p_p0).blocks.p->data[((NI)0)].sections[(((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0))- 0]), colontmpD_);
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2859);
	cgFormatValue__cgen_u163((&res_1), frame_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 12);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2861);
	cgFormatValue__cgen_u163((&res_1), procname_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2862);
	cgFormatValue__cgen_u163((&res_1), frame_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 12);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2864);
	cgFormatValue__cgen_u163((&res_1), filename_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2866);
	cgFormatValue__cgen_u163((&res_1), frame_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 8);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2868);
	cgFormatValue__cgen_u166((&res_1), ((NI64) (line_p4)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2869);
	cgFormatValue__cgen_u163((&res_1), frame_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 21);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2871);
	cgFormatValue__cgen_u163((&res_1), frame_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2872);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA5_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2873);
	}
LA5_: ;
	result = res_1;
	eqwasMoved___system_u2688((&res_1));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, deinitFrameNoDebug__cgen_u20049)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NimStringV2 frame_p1) {
	NimStringV2 result;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2874);
	colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2876);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2877);
	cgFormatValue__cgen_u163((&res_1), frame_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2878);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA4_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2879);
	}
LA4_: ;
	result = res_1;
	eqwasMoved___system_u2688((&res_1));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStmtListExpr__cgen_u26542)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	NimStringV2 frameName_1;
	NIM_BOOL hasNimFrame_1;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
NIM_BOOL oldNimErrFin21_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	frameName_1.len = 0; frameName_1.p = NIM_NIL;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = !(((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T3_)) goto LA4_;
	T3_ = !((((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0));
LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = (((*(*p_p0).prc).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0);
LA5_: ;
	hasNimFrame_1 = T2_;
	frameName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2854;
	{
		NI i_1;
		NI colontmp_;
		NI T7_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T7_ = (NI)0;
		T7_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T7_ - ((NI)1));
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA9;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				{
					if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)24))) goto LA13_;
					{
						NIM_BOOL T17_;
						NimStringV2 colontmpD_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* theMacro_1;
						NimStringV2 colontmpD__2;
						NimStringV2 colontmpD__3;
						NimStringV2 colontmpD__4;
						NimStringV2 T22_;
						NimStringV2* T23_;
						T17_ = (NIM_BOOL)0;
						T17_ = hasNimFrame_1;
						if (!(T17_)) goto LA18_;
						T17_ = (frameName_1.len == 0);
LA18_: ;
						if (!T17_) goto LA19_;
						colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
						theMacro_1 = NIM_NIL;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						(*p_p0).labels += ((NI)1);
						T22_.len = 0; T22_.p = NIM_NIL;
						colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).labels)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						T22_ = rawNewString(colontmpD_.len + 3);
appendString((&T22_), TM__MQdRN7fpbG7rPm4JpVVAhA_2856);
appendString((&T22_), colontmpD_);
appendString((&T22_), TM__MQdRN7fpbG7rPm4JpVVAhA_2857);
						eqsink___system_u2700((&frameName_1), T22_);
						eqcopy___ast_u4577(&theMacro_1, (*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						T23_ = (NimStringV2*)0;
						T23_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__2 = makeCString__msgs_u83((*(*theMacro_1).name).s);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__3 = quotedFilename__msgs_u1638((*(*(*p_p0).module).g).config, (*theMacro_1).info);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__4 = initFrameNoDebug__cgen_u20024(p_p0, frameName_1, colontmpD__2, colontmpD__3, ((NI) ((*it_1).info.line)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						prepareAdd((&(*T23_)), colontmpD__4.len + 0);
appendString((&(*T23_)), colontmpD__4);
						{
							LA21_:;
						}
						{
							oldNimErrFin21_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__4);
							eqdestroy___system_u2691(colontmpD__3);
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___ast_u4574(theMacro_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
							eqdestroy___system_u2691(colontmpD_);
							*nimErr_ = oldNimErrFin21_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					}
LA19_: ;
				}
				goto LA11_;
LA13_: ;
				{
					genStmts__cgen_u14081(p_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
LA11_: ;
				i_2 += ((NI)1);
				{
					LA10_:;
				}
				{
					oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin10_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA9: ;
		}
	}
	{
		NI T31_;
		NI T34_;
		T31_ = (NI)0;
		T31_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)0) < T31_)) goto LA32_;
		T34_ = (NI)0;
		T34_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		expr__cgen_u14084(p_p0, (*n_p1)._kind_6.sons.p->data[(NI)(T34_ - ((NI)1))], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA32_: ;
	{
		NimStringV2 colontmpD__5;
		NimStringV2* T40_;
		if (!!((frameName_1.len == 0))) goto LA37_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T40_ = (NimStringV2*)0;
		T40_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
		colontmpD__5 = deinitFrameNoDebug__cgen_u20049(p_p0, frameName_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
		prepareAdd((&(*T40_)), colontmpD__5.len + 0);
appendString((&(*T40_)), colontmpD__5);
		{
			LA39_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA37_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(frameName_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStmtList__cgen_u26576)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 frameName_1;
	NIM_BOOL hasNimFrame_1;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
NIM_BOOL oldNimErrFin21_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	frameName_1.len = 0; frameName_1.p = NIM_NIL;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = !(((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T3_)) goto LA4_;
	T3_ = !((((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0));
LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = (((*(*p_p0).prc).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0);
LA5_: ;
	hasNimFrame_1 = T2_;
	frameName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2880;
	{
		NI i_1;
		NI colontmp_;
		NI T7_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T7_ = (NI)0;
		T7_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T7_ - ((NI)1));
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA9;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				{
					if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)24))) goto LA13_;
					{
						NIM_BOOL T17_;
						NimStringV2 colontmpD_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* theMacro_1;
						NimStringV2 colontmpD__2;
						NimStringV2 colontmpD__3;
						NimStringV2 colontmpD__4;
						NimStringV2 T22_;
						NimStringV2* T23_;
						T17_ = (NIM_BOOL)0;
						T17_ = hasNimFrame_1;
						if (!(T17_)) goto LA18_;
						T17_ = (frameName_1.len == 0);
LA18_: ;
						if (!T17_) goto LA19_;
						colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
						theMacro_1 = NIM_NIL;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						(*p_p0).labels += ((NI)1);
						T22_.len = 0; T22_.p = NIM_NIL;
						colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).labels)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						T22_ = rawNewString(colontmpD_.len + 3);
appendString((&T22_), TM__MQdRN7fpbG7rPm4JpVVAhA_2881);
appendString((&T22_), colontmpD_);
appendString((&T22_), TM__MQdRN7fpbG7rPm4JpVVAhA_2882);
						eqsink___system_u2700((&frameName_1), T22_);
						eqcopy___ast_u4577(&theMacro_1, (*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						T23_ = (NimStringV2*)0;
						T23_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__2 = makeCString__msgs_u83((*(*theMacro_1).name).s);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__3 = quotedFilename__msgs_u1638((*(*(*p_p0).module).g).config, (*theMacro_1).info);
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						colontmpD__4 = initFrameNoDebug__cgen_u20024(p_p0, frameName_1, colontmpD__2, colontmpD__3, ((NI) ((*it_1).info.line)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
						prepareAdd((&(*T23_)), colontmpD__4.len + 0);
appendString((&(*T23_)), colontmpD__4);
						{
							LA21_:;
						}
						{
							oldNimErrFin21_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__4);
							eqdestroy___system_u2691(colontmpD__3);
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___ast_u4574(theMacro_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
							eqdestroy___system_u2691(colontmpD_);
							*nimErr_ = oldNimErrFin21_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					}
LA19_: ;
				}
				goto LA11_;
LA13_: ;
				{
					genStmts__cgen_u14081(p_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
LA11_: ;
				i_2 += ((NI)1);
				{
					LA10_:;
				}
				{
					oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin10_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA9: ;
		}
	}
	{
		NI T31_;
		NI T34_;
		T31_ = (NI)0;
		T31_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)0) < T31_)) goto LA32_;
		T34_ = (NI)0;
		T34_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		genStmts__cgen_u14081(p_p0, (*n_p1)._kind_6.sons.p->data[(NI)(T34_ - ((NI)1))]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA32_: ;
	{
		NimStringV2 colontmpD__5;
		NimStringV2* T40_;
		if (!!((frameName_1.len == 0))) goto LA37_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T40_ = (NimStringV2*)0;
		T40_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
		colontmpD__5 = deinitFrameNoDebug__cgen_u20049(p_p0, frameName_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
		prepareAdd((&(*T40_)), colontmpD__5.len + 0);
appendString((&(*T40_)), colontmpD__5);
		{
			LA39_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA37_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(frameName_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genIf__cgen_u16832)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 lelse_1;
	NimStringV2 lend_1;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	lelse_1.len = 0; lelse_1.p = NIM_NIL;
	lend_1.len = 0; lend_1.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T9_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = isEmptyType__ast_u7234((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !(T5_);
		if (!(T4_)) goto LA6_;
		T4_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
LA6_: ;
		if (!T4_) goto LA7_;
		nimZeroMem((void*)(&T9_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*n_p1).typField, NIM_FALSE, (&T9_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&(*d_p2)), T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	genLineDir__cgen_u418(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	lend_1 = getLabel__cgen_u14059(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tySequence__9ahcSjIErJohSBBFLwuF56Q colontmp_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** it_1;
		NI i_1;
		NI L_1;
		NI T12_;
		colontmp_.len = 0; colontmp_.p = NIM_NIL;
		it_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
		eqcopy___ast_u3699((&colontmp_), (*n_p1)._kind_6.sons);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		i_1 = ((NI)0);
		T12_ = colontmp_.len;
		L_1 = T12_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA14;
				it_1 = &colontmp_.p->data[i_1];
				{
					NIM_BOOL T17_;
					T17_ = (NIM_BOOL)0;
					T17_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1));
					if (!(T17_)) goto LA18_;
					T17_ = isEmptyType__ast_u7234((*n_p1).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
LA18_: ;
					if (!T17_) goto LA19_;
					(*d_p2).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0);
				}
LA19_: ;
				{
					NI T23_;
					NimStringV2 res_1;
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					NimStringV2* T27_;
					NimStringV2* T28_;
					NI T33_;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T34_;
					NimStringV2 T35_;
					NimStringV2* T36_;
					NimStringV2* T37_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T38_;
					T23_ = (NI)0;
					T23_ = len__ast_u3190((*it_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					if (!(T23_ == ((NI)2))) goto LA24_;
					res_1.len = 0; res_1.p = NIM_NIL;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					T27_ = (NimStringV2*)0;
					T27_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					addIndent__cgen_u315(p_p0, T27_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T28_ = (NimStringV2*)0;
					T28_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					res_1 = rawNewString(((NI)80));
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2883);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA31_;
						prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2884);
					}
LA31_: ;
					prepareAdd((&(*T28_)), res_1.len + 0);
appendString((&(*T28_)), res_1);
					T33_ = (NI)0;
					T33_ = startBlockInternal__cgen_u15729(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					nimZeroMem((void*)(&T34_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					initLocExprSingleUse__cgen_u14116(p_p0, (*(*it_1))._kind_6.sons.p->data[((NI)0)], (&T34_));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					eqsink___ast_u6293((&a_1), T34_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T35_.len = 0; T35_.p = NIM_NIL;
					T35_ = getLabel__cgen_u14059(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T35_); goto LA26_;}
					eqsink___system_u2700((&lelse_1), T35_);
					(*p_p0).labels += ((NI)1);
					T36_ = (NimStringV2*)0;
					T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					addIndent__cgen_u315(p_p0, T36_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T37_ = (NimStringV2*)0;
					T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					colontmpD_ = rdLoc__cgen_u470(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					T38_[0] = colontmpD_;
					T38_[1] = lelse_1;
					colontmpD__2 = percent___cgen_u16869(T38_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					prepareAdd((&(*T37_)), colontmpD__2.len + 0);
appendString((&(*T37_)), colontmpD__2);
					{
						NIM_BOOL T41_;
						NimStringV2* T45_;
						NimStringV2* T46_;
						T41_ = (NIM_BOOL)0;
						T41_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
						if (T41_) goto LA42_;
						T41_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA42_: ;
						if (!T41_) goto LA43_;
						T45_ = (NimStringV2*)0;
						T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						prepareAdd((&(*T45_)), 1);
appendString((&(*T45_)), TM__MQdRN7fpbG7rPm4JpVVAhA_2885);
						expr__cgen_u14084(p_p0, (*(*it_1))._kind_6.sons.p->data[((NI)1)], d_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						T46_ = (NimStringV2*)0;
						T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						prepareAdd((&(*T46_)), 1);
appendString((&(*T46_)), TM__MQdRN7fpbG7rPm4JpVVAhA_2886);
					}
					goto LA39_;
LA43_: ;
					{
						expr__cgen_u14084(p_p0, (*(*it_1))._kind_6.sons.p->data[((NI)1)], d_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					}
LA39_: ;
					endBlock__cgen_u15767(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					{
						NI T50_;
						NimStringV2 colontmpD__3;
						NimStringV2* T53_;
						NimStringV2* T54_;
						tyArray__YgExxhfgKcesA5EOUj1MOA T55_;
						T50_ = (NI)0;
						T50_ = len__ast_u3190(n_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						if (!(((NI)1) < T50_)) goto LA51_;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						T53_ = (NimStringV2*)0;
						T53_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						addIndent__cgen_u315(p_p0, T53_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						T54_ = (NimStringV2*)0;
						T54_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						T55_[0] = lend_1;
						colontmpD__3 = percent___cgen_u16882(T55_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
						prepareAdd((&(*T54_)), colontmpD__3.len + 0);
appendString((&(*T54_)), colontmpD__3);
						eqdestroy___system_u2691(colontmpD__3);
					}
LA51_: ;
					fixLabel__cgen_u14067(p_p0, lelse_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
					{
						LA26_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(res_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				}
				goto LA21_;
LA24_: ;
				{
					NI T59_;
					NimStringV2 res_2;
					NimStringV2* T63_;
					NimStringV2* T64_;
					NI T69_;
					T59_ = (NI)0;
					T59_ = len__ast_u3190((*it_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					if (!(T59_ == ((NI)1))) goto LA60_;
					res_2.len = 0; res_2.p = NIM_NIL;
					T63_ = (NimStringV2*)0;
					T63_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
					addIndent__cgen_u315(p_p0, T63_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
					T64_ = (NimStringV2*)0;
					T64_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
					res_2 = rawNewString(((NI)80));
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2887);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA67_;
						prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2888);
					}
LA67_: ;
					prepareAdd((&(*T64_)), res_2.len + 0);
appendString((&(*T64_)), res_2);
					T69_ = (NI)0;
					T69_ = startBlockInternal__cgen_u15729(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
					expr__cgen_u14084(p_p0, (*(*it_1))._kind_6.sons.p->data[((NI)0)], d_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
					endBlock__cgen_u15767(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
					{
						LA62_:;
					}
					{
						eqdestroy___system_u2691(res_2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				}
				goto LA21_;
LA60_: ;
				{
					internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_2890, TM__MQdRN7fpbG7rPm4JpVVAhA_2891);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				}
LA21_: ;
				i_1 += ((NI)1);
			} LA14: ;
		}
		{
			LA11_:;
		}
		{
			oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3696(colontmp_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin11_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		NI T77_;
		T77_ = (NI)0;
		T77_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)1) < T77_)) goto LA78_;
		fixLabel__cgen_u14067(p_p0, lend_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA78_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(lend_1);
		eqdestroy___system_u2691(lelse_1);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, downConv__cgen_u26695)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_1;
	NimStringV2 colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
	NIM_BOOL isRef_1;
NIM_BOOL oldNimErrFin14_;
NIM_BOOL oldNimErrFin27_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	arg_1 = NIM_NIL;
	dest_1 = NIM_NIL;
	src_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	eqcopy___ast_u3255(&arg_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			if (!((*arg_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66))) goto LA3;
			eqcopy___ast_u3255(&arg_1, (*arg_1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA3: ;
	}
	dest_1 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	src_1 = skipTypes__ast_u5379((*arg_1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, src_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	colontmpD__2 = skipTypes__ast_u5379((*arg_1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	isRef_1 = ((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47));
	{
		NIM_BOOL T6_;
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T15_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T16_;
		T6_ = (NIM_BOOL)0;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T8_ = isRef_1;
		if (!(T8_)) goto LA9_;
		T8_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
LA9_: ;
		T7_ = T8_;
		if (!(T7_)) goto LA10_;
		colontmpD__3 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_515);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = ((*colontmpD__3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*colontmpD__3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21));
LA10_: ;
		T6_ = T7_;
		if (!(T6_)) goto LA11_;
		T6_ = isLValue__parampatterns_u491(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA11_: ;
		if (!T6_) goto LA12_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		T15_ = 0;
		initLocExpr__cgen_u14111(p_p0, arg_1, T15_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		colontmpD__4 = getTypeDesc__cgen_u8738((*p_p0).module, (*n_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T16_[0] = colontmpD__4;
		colontmpD__5 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T16_[1] = colontmpD__5;
		colontmpD__6 = percent___cgen_u26682(T16_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, colontmpD__6, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			LA14_:;
		}
		{
			oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin14_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA12_: ;
	{
		NIM_BOOL T20_;
		NIM_BOOL T21_;
		T20_ = (NIM_BOOL)0;
		T21_ = (NIM_BOOL)0;
		T21_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T21_) goto LA22_;
		T21_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA22_: ;
		T20_ = T21_;
		if (T20_) goto LA23_;
		T20_ = isImportedType__cgen_u1373(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA23_: ;
		if (!T20_) goto LA24_;
		expr__cgen_u14084(p_p0, arg_1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA24_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
		NimStringV2 r_1;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T28_;
		NimStringV2 T29_;
		NimStringV2 T30_;
		NimStringV2 T40_;
		nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		r_1.len = 0; r_1.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		T28_ = 0;
		initLocExpr__cgen_u14111(p_p0, arg_1, T28_, (&a_2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T29_.len = 0; T29_.p = NIM_NIL;
		colontmpD__7 = rdLoc__cgen_u470(a_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T30_.len = 0; T30_.p = NIM_NIL;
		{
			if (!isRef_1) goto LA33_;
			colontmpD__8 = TM__MQdRN7fpbG7rPm4JpVVAhA_2893;
			T30_ = colontmpD__8;
		}
		goto LA31_;
LA33_: ;
		{
			colontmpD__9 = TM__MQdRN7fpbG7rPm4JpVVAhA_2894;
			T30_ = colontmpD__9;
		}
LA31_: ;
		T29_ = rawNewString(colontmpD__7.len + T30_.len + 0);
appendString((&T29_), colontmpD__7);
appendString((&T29_), T30_);
		r_1 = T29_;
		{
			NI i_1;
			NI colontmp_;
			NI T37_;
			NI res_1;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T37_ = (NI)0;
			T37_ = inheritanceDiff__types_u2785(dest_1, src_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			colontmp_ = (T37_ > 0? (T37_) : -(T37_));
			res_1 = ((NI)2);
			{
				while (1) {
					if (!(res_1 <= colontmp_)) goto LA39;
					i_1 = ((NI) (res_1));
					prepareAdd((&r_1), 4);
appendString((&r_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2895);
					res_1 += ((NI)1);
				} LA39: ;
			}
		}
		T40_.len = 0; T40_.p = NIM_NIL;
		{
			NimStringV2 T45_;
			if (!isRef_1) goto LA43_;
			T45_.len = 0; T45_.p = NIM_NIL;
			T45_ = rawNewString(r_1.len + 1);
appendString((&T45_), TM__MQdRN7fpbG7rPm4JpVVAhA_2896);
appendString((&T45_), r_1);
			colontmpD__10 = T45_;
			T40_ = colontmpD__10;
		}
		goto LA41_;
LA43_: ;
		{
			colontmpD__11 = r_1;
			eqwasMoved___system_u2688((&r_1));
			T40_ = colontmpD__11;
		}
LA41_: ;
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, T40_, a_2.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		{
			LA27_:;
		}
		{
			oldNimErrFin27_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(r_1);
			eqdestroy___ast_u6284(a_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin27_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(src_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(arg_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, upConv__cgen_u26610)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	dest_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	dest_1 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		NIM_BOOL T7_;
		NimStringV2 nilCheck_1;
		NimStringV2 r_1;
		NimStringV2 res_1;
		NimStringV2* T55_;
		NimStringV2* T56_;
		NimStringV2* T57_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)1)))&31U)))!=0);
		if (!(T5_)) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = isObjLackingTypeField__types_u2952(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T5_ = !(T7_);
LA6_: ;
		if (!T5_) goto LA8_;
		nilCheck_1.len = 0; nilCheck_1.p = NIM_NIL;
		r_1.len = 0; r_1.p = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		nilCheck_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2897;
		r_1 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		rdMType__cgen_u24093(p_p0, a_1, (&nilCheck_1), (&r_1), NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			NimStringV2 checkFor_1;
			NimStringV2 token_1;
			NI16 T16_;
			tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T17_;
			NU32 T18_;
			if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA13_;
			checkFor_1.len = 0; checkFor_1.p = NIM_NIL;
			token_1.len = 0; token_1.p = NIM_NIL;
			T16_ = (NI16)0;
			T16_ = getObjDepth__cgen_u10096(dest_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			checkFor_1 = dollar___systemZdollars_u19(T16_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			nimZeroMem((void*)T17_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
			hashType__sighashes_u411(dest_1, (*(*(*p_p0).module).g).config, 2, T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			T18_ = (NU32)0;
			T18_ = genDisplayElem__cgen_u10109(T17_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			token_1 = dollar___systemZdollars_u49(T18_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			{
				NimStringV2 res_2;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				NimStringV2* T24_;
				NimStringV2* T25_;
				if (!!((nilCheck_1.len == 0))) goto LA21_;
				res_2.len = 0; res_2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				T24_ = (NimStringV2*)0;
				T24_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				addIndent__cgen_u315(p_p0, T24_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				T25_ = (NimStringV2*)0;
				T25_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				res_2 = rawNewString(((NI)80));
				prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2898);
				cgFormatValue__cgen_u163((&res_2), nilCheck_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				prepareAdd((&res_2), 5);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2900);
				colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2901);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2902);
				cgFormatValue__cgen_u163((&res_2), r_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2903);
				cgFormatValue__cgen_u163((&res_2), checkFor_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2904);
				cgFormatValue__cgen_u163((&res_2), token_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2905);
				colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2907);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				cgFormatValue__cgen_u163((&res_2), colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2908);
				prepareAdd((&(*T25_)), res_2.len + 0);
appendString((&(*T25_)), res_2);
				{
					LA23_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(res_2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			}
			goto LA19_;
LA21_: ;
			{
				NimStringV2 res_3;
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				NimStringV2* T30_;
				NimStringV2* T31_;
				res_3.len = 0; res_3.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				T30_ = (NimStringV2*)0;
				T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				addIndent__cgen_u315(p_p0, T30_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				T31_ = (NimStringV2*)0;
				T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				res_3 = rawNewString(((NI)80));
				prepareAdd((&res_3), 5);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2910);
				colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2911);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2912);
				cgFormatValue__cgen_u163((&res_3), r_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2913);
				cgFormatValue__cgen_u163((&res_3), checkFor_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2914);
				cgFormatValue__cgen_u163((&res_3), token_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2915);
				colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2916);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				cgFormatValue__cgen_u163((&res_3), colontmpD__6);
				if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
				prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2917);
				prepareAdd((&(*T31_)), res_3.len + 0);
appendString((&(*T31_)), res_3);
				{
					LA29_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(res_3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			}
LA19_: ;
			{
				LA15_:;
			}
			{
				eqdestroy___system_u2691(token_1);
				eqdestroy___system_u2691(checkFor_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
		goto LA11_;
LA13_: ;
		{
			NimStringV2 checkFor_2;
			checkFor_2.len = 0; checkFor_2.p = NIM_NIL;
			checkFor_2 = genTypeInfoV1__cgen_u9076((*p_p0).module, dest_1, (*n_p1).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			{
				NimStringV2 res_4;
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2* T43_;
				NimStringV2* T44_;
				if (!!((nilCheck_1.len == 0))) goto LA40_;
				res_4.len = 0; res_4.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				T43_ = (NimStringV2*)0;
				T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				addIndent__cgen_u315(p_p0, T43_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				T44_ = (NimStringV2*)0;
				T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				res_4 = rawNewString(((NI)80));
				prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2918);
				cgFormatValue__cgen_u163((&res_4), nilCheck_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_4), 5);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2919);
				colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2921);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2922);
				cgFormatValue__cgen_u163((&res_4), r_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2923);
				cgFormatValue__cgen_u163((&res_4), checkFor_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2924);
				colontmpD__8 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2925);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				cgFormatValue__cgen_u163((&res_4), colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
				prepareAdd((&res_4), 4);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2926);
				prepareAdd((&(*T44_)), res_4.len + 0);
appendString((&(*T44_)), res_4);
				{
					LA42_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
					eqdestroy___system_u2691(res_4);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			}
			goto LA38_;
LA40_: ;
			{
				NimStringV2 res_5;
				NimStringV2 colontmpD__9;
				NimStringV2 colontmpD__10;
				NimStringV2* T49_;
				NimStringV2* T50_;
				res_5.len = 0; res_5.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				T49_ = (NimStringV2*)0;
				T49_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				addIndent__cgen_u315(p_p0, T49_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				T50_ = (NimStringV2*)0;
				T50_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				res_5 = rawNewString(((NI)80));
				prepareAdd((&res_5), 5);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2927);
				colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2928);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2929);
				cgFormatValue__cgen_u163((&res_5), r_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2930);
				cgFormatValue__cgen_u163((&res_5), checkFor_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2931);
				colontmpD__10 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2932);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA48_;
				prepareAdd((&res_5), 4);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_2933);
				prepareAdd((&(*T50_)), res_5.len + 0);
appendString((&(*T50_)), res_5);
				{
					LA48_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__10);
					eqdestroy___system_u2691(colontmpD__9);
					eqdestroy___system_u2691(res_5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
			}
LA38_: ;
			{
				LA37_:;
			}
			{
				eqdestroy___system_u2691(checkFor_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		}
LA11_: ;
		T55_ = (NimStringV2*)0;
		T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		raiseInstr__cgen_u457(p_p0, T55_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T56_ = (NimStringV2*)0;
		T56_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		addIndent__cgen_u315(p_p0, T56_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T57_ = (NimStringV2*)0;
		T57_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2934);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA60_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2935);
		}
LA60_: ;
		prepareAdd((&(*T57_)), res_1.len + 0);
appendString((&(*T57_)), res_1);
		{
			LA10_:;
		}
		{
			eqdestroy___system_u2691(res_1);
			eqdestroy___system_u2691(r_1);
			eqdestroy___system_u2691(nilCheck_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, (*n_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!eqStrings(colontmpD_, colontmpD__2)) goto LA66_;
		expr__cgen_u14084(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA64_;
LA66_: ;
	{
		if (!!(((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17)))) goto LA69_;
		{
			NIM_BOOL T73_;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T77_;
			T73_ = (NIM_BOOL)0;
			T73_ = isLValue__parampatterns_u491(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T73_) goto LA74_;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__11 = getTypeDesc__cgen_u8738((*p_p0).module, (*n_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			T77_[0] = colontmpD__11;
			colontmpD__12 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			T77_[1] = colontmpD__12;
			colontmpD__13 = percent___cgen_u26682(T77_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, colontmpD__13, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA76_;
			{
				LA76_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA71_;
LA74_: ;
		{
			NimStringV2 colontmpD__14;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T82_;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__14 = getTypeDesc__cgen_u8738((*p_p0).module, (*n_p1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			T82_[0] = colontmpD__14;
			colontmpD__15 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			T82_[1] = colontmpD__15;
			colontmpD__16 = percent___cgen_u14793(T82_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, colontmpD__16, a_1.storage);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			{
				LA81_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(colontmpD__14);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA71_: ;
	}
	goto LA64_;
LA69_: ;
	{
		NimStringV2 colontmpD__17;
		NimStringV2 colontmpD__18;
		NimStringV2 colontmpD__19;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T87_;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__17 = getTypeDesc__cgen_u8738((*p_p0).module, dest_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
		T87_[0] = colontmpD__17;
		colontmpD__18 = addrLoc__cgen_u12821((*(*(*p_p0).module).g).config, a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
		T87_[1] = colontmpD__18;
		colontmpD__19 = percent___cgen_u25164(T87_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, colontmpD__19, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA86_;
		{
			LA86_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___system_u2691(colontmpD__17);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA64_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRangeChck__cgen_u25313)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	dest_1 = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	dest_1 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		NIM_BOOL T7_;
		T5_ = (NIM_BOOL)0;
		T5_ = !((((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)3)))&31U)))!=0));
		if (T5_) goto LA6_;
		T7_ = (NIM_BOOL)0;
		T7_ = ((*dest_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*dest_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44));
		if (!(T7_)) goto LA8_;
		T7_ = !((((*(*(*(*p_p0).module).g).config).legacyFeatures &((NU8)1<<((NU)((((tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA)1)))&7U)))!=0));
LA8_: ;
		T5_ = T7_;
LA6_: ;
		if (!T5_) goto LA9_;
	}
	goto LA3_;
LA9_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n0t_1;
		n0t_1 = NIM_NIL;
		eqcopy___ast_u3381(&n0t_1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			NimStringV2 first_1;
			NimStringV2 last_1;
			NimStringV2 res_1;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 res_2;
			NimStringV2* T18_;
			NimStringV2* T19_;
			NimStringV2* T20_;
			NimStringV2* T21_;
			NimStringV2* T22_;
			if (!((*n0t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) || (*n0t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44))) goto LA15_;
			first_1.len = 0; first_1.p = NIM_NIL;
			last_1.len = 0; last_1.p = NIM_NIL;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			res_2.len = 0; res_2.p = NIM_NIL;
			first_1 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			genLiteral__cgen_u20138(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], dest_1, (&first_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			last_1 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			genLiteral__cgen_u20138(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], dest_1, (&last_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			T18_ = (NimStringV2*)0;
			T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			addIndent__cgen_u315(p_p0, T18_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			T19_ = (NimStringV2*)0;
			T19_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2936);
			colontmpD_ = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			cgFormatValue__cgen_u163((&res_1), colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2938);
			colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, n0t_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2939);
			cgFormatValue__cgen_u163((&res_1), last_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2940);
			colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2942);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2943);
			prepareAdd((&(*T19_)), res_1.len + 0);
appendString((&(*T19_)), res_1);
			T20_ = (NimStringV2*)0;
			T20_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			raiseInstr__cgen_u457(p_p0, T20_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			T21_ = (NimStringV2*)0;
			T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			addIndent__cgen_u315(p_p0, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			T22_ = (NimStringV2*)0;
			T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2944);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA25_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2945);
			}
LA25_: ;
			prepareAdd((&(*T22_)), res_2.len + 0);
appendString((&(*T22_)), res_2);
			{
				LA17_:;
			}
			{
				eqdestroy___system_u2691(res_2);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u2691(res_1);
				eqdestroy___system_u2691(last_1);
				eqdestroy___system_u2691(first_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		}
		goto LA13_;
LA15_: ;
		{
			NimStringV2 raiser_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			NimStringV2 boundaryCast_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
			NimStringV2 first_2;
			NimStringV2 last_2;
			NimStringV2 res_3;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 res_4;
			NimStringV2 T31_;
			NimStringV2 T35_;
			NimStringV2* T41_;
			NimStringV2* T42_;
			NimStringV2* T43_;
			NimStringV2* T44_;
			NimStringV2* T45_;
			raiser_1.len = 0; raiser_1.p = NIM_NIL;
			colontmpD__4 = NIM_NIL;
			boundaryCast_1.len = 0; boundaryCast_1.p = NIM_NIL;
			colontmpD__5 = NIM_NIL;
			first_2.len = 0; first_2.p = NIM_NIL;
			last_2.len = 0; last_2.p = NIM_NIL;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			res_4.len = 0; res_4.p = NIM_NIL;
			T31_.len = 0; T31_.p = NIM_NIL;
			colontmpD__4 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			switch ((*colontmpD__4).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
			{
				raiser_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2947;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
			{
				raiser_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2949;
			}
			break;
			default:
			{
				raiser_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2951;
			}
			break;
			}
			cgsym__cgen_u138((*p_p0).module, raiser_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T35_.len = 0; T35_.p = NIM_NIL;
			{
				colontmpD__5 = skipTypes__ast_u5379(n0t_1, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				if (!((*colontmpD__5).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) || (*colontmpD__5).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43) || (*colontmpD__5).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44))) goto LA38_;
				boundaryCast_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2953;
			}
			goto LA36_;
LA38_: ;
			{
				boundaryCast_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_2954;
			}
LA36_: ;
			first_2 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			genLiteral__cgen_u20138(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], dest_1, (&first_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			last_2 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			genLiteral__cgen_u20138(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], dest_1, (&last_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T41_ = (NimStringV2*)0;
			T41_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			addIndent__cgen_u315(p_p0, T41_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T42_ = (NimStringV2*)0;
			T42_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2955);
			cgFormatValue__cgen_u163((&res_3), boundaryCast_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2956);
			colontmpD__6 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2958);
			cgFormatValue__cgen_u163((&res_3), first_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2959);
			cgFormatValue__cgen_u163((&res_3), boundaryCast_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2960);
			colontmpD__7 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2962);
			cgFormatValue__cgen_u163((&res_3), last_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2963);
			cgFormatValue__cgen_u163((&res_3), raiser_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2964);
			colontmpD__8 = rdCharLoc__cgen_u12869(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2965);
			cgFormatValue__cgen_u163((&res_3), first_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2966);
			cgFormatValue__cgen_u163((&res_3), last_2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_2967);
			prepareAdd((&(*T42_)), res_3.len + 0);
appendString((&(*T42_)), res_3);
			T43_ = (NimStringV2*)0;
			T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			raiseInstr__cgen_u457(p_p0, T43_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T44_ = (NimStringV2*)0;
			T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			addIndent__cgen_u315(p_p0, T44_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T45_ = (NimStringV2*)0;
			T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			res_4 = rawNewString(((NI)80));
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2968);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA48_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_2969);
			}
LA48_: ;
			prepareAdd((&(*T45_)), res_4.len + 0);
appendString((&(*T45_)), res_4);
			{
				LA30_:;
			}
			{
				oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(res_4);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(res_3);
				eqdestroy___system_u2691(last_2);
				eqdestroy___system_u2691(first_2);
				eqdestroy___ast_u3378(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				*nimErr_ = oldNimErrFin30_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		}
LA13_: ;
		{
			LA12_:;
		}
		{
			oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(n0t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin12_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	{
		NIM_BOOL T56_;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		tyArray__YgExxhfgKcesA5EOUj1MOA T60_;
		T56_ = (NIM_BOOL)0;
		T56_ = sameBackendTypeIgnoreRange__types_u2744(dest_1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T56_) goto LA57_;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__9 = rdCharLoc__cgen_u12869(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		T60_[0] = colontmpD__9;
		colontmpD__10 = percent___cgen_u25390(T60_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, colontmpD__10, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		{
			LA59_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA54_;
LA57_: ;
	{
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T65_;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__11 = getTypeDesc__cgen_u8738((*p_p0).module, dest_1, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
		T65_[0] = colontmpD__11;
		colontmpD__12 = rdCharLoc__cgen_u12869(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
		T65_[1] = colontmpD__12;
		colontmpD__13 = percent___cgen_u14793(T65_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, colontmpD__13, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
		{
			LA64_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA54_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(dest_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, convStrToCStr__cgen_u25407)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2970);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2971);
	colontmpD__2 = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2972);
	putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, res_1, a_1.storage);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, convCStrToStr__cgen_u25421)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T5_) goto LA6_;
		T5_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA6_: ;
		if (!T5_) goto LA7_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2973);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		prepareAdd((&res_1), 12);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2974);
		colontmpD__2 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_2975);
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, res_1, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA7_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		res_2 = rawNewString(((NI)80));
		colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_2976);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2977);
		colontmpD__4 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2978);
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, res_2, a_1.storage);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	gcUsage__cgen_u22947((*(*(*p_p0).module).g).config, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genComputedGoto__cgen_u17010)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
	NimStringV2 tmp_1;
	NimStringV2 colontmpD_;
	NimStringV2 gotoArray_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* caseStmt_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NI casePos_1;
	NI arraySize_1;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin5_;
	NI id_1;
	tyArray__YgExxhfgKcesA5EOUj1MOA T39_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T40_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T45_;
	NimStringV2* T46_;
	NimStringV2* T47_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T51_;
	NimStringV2* T52_;
	NimStringV2* T53_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T54_;
NIM_BOOL oldNimErrFin110_;
NIM_BOOL oldNimErrFin104_;
NIM_BOOL oldNimErrFin96_;
NIM_BOOL oldNimErrFin94_;
NIM_BOOL oldNimErrFin92_;
NIM_BOOL oldNimErrFin87_;
NIM_BOOL oldNimErrFin58_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_2 = NIM_NIL;
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	gotoArray_1.len = 0; gotoArray_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	caseStmt_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	n_2 = flattenStmts__trees_u359(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	casePos_1 = ((NI)-1);
	arraySize_1 = ((NI)0);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA4;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_2)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__7;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg aSize_1;
					if (!((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)97))) goto LA8_;
					colontmpD__7 = NIM_NIL;
					{
						colontmpD__7 = lastSon__ast_u5208(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						if (!!(((*colontmpD__7).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85)))) goto LA13_;
						liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2982, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2983, NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						eqdestroy___ast_u3252(colontmpD__7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___ast_u6284(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___ast_u3252(caseStmt_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(gotoArray_1);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(tmp_1);
						eqdestroy___ast_u3252(n_2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA13_: ;
					casePos_1 = i_1;
					{
						NIM_BOOL T17_;
						T17_ = (NIM_BOOL)0;
						T17_ = enumHasHoles__types_u271((*(*it_1)._kind_6.sons.p->data[((NI)0)]).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						if (!T17_) goto LA18_;
						liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2985, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2986, NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						eqdestroy___ast_u3252(colontmpD__7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___ast_u6284(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___ast_u3252(caseStmt_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(gotoArray_1);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(tmp_1);
						eqdestroy___ast_u3252(n_2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA18_: ;
					aSize_1 = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, (*(*it_1)._kind_6.sons.p->data[((NI)0)]).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					{
						NIM_BOOL T22_;
						T22_ = (NIM_BOOL)0;
						T22_ = lt___int128_u959(IL64(10000), aSize_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						if (!T22_) goto LA23_;
						liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2988, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2989, NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						eqdestroy___ast_u3252(colontmpD__7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___ast_u6284(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___ast_u3252(caseStmt_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(gotoArray_1);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(tmp_1);
						eqdestroy___ast_u3252(n_2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA23_: ;
					arraySize_1 = toInt__int128_u257(aSize_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					{
						tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T27_;
						NIM_BOOL T28_;
						T27_ = firstOrd__types_u1182((*(*(*p_p0).module).g).config, (*(*it_1)._kind_6.sons.p->data[((NI)0)]).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						T28_ = (NIM_BOOL)0;
						T28_ = eqeq___int128_u980(T27_, IL64(0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						if (!!(T28_)) goto LA29_;
						liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2991, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2992, NIM_FALSE, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						eqdestroy___ast_u3252(colontmpD__7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___ast_u6284(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___ast_u3252(caseStmt_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(gotoArray_1);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(tmp_1);
						eqdestroy___ast_u3252(n_2);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA29_: ;
					{
						LA10_:;
					}
					{
						oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__7);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						*nimErr_ = oldNimErrFin10_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA8_: ;
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin5_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	{
		if (!(casePos_1 < ((NI)0))) goto LA37_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*n_2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2994, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_2995, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(caseStmt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(gotoArray_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA37_: ;
	id_1 = (NI)((*p_p0).labels + ((NI)1));
	(*p_p0).labels += (NI)(arraySize_1 + ((NI)1));
	colontmpD_ = rope__ropes_u15(((NI64) (id_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T39_[0] = colontmpD_;
	tmp_1 = percent___cgen_u17037(T39_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T40_[0] = tmp_1;
	colontmpD__2 = rope__ropes_u15(((NI64) (arraySize_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T40_[1] = colontmpD__2;
	gotoArray_1 = percent___cgen_u17043(T40_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_3;
		NI colontmp__2;
		NI res_1;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = (NI)(arraySize_1 - ((NI)1));
		res_1 = ((NI)1);
		{
			while (1) {
				NimStringV2 colontmpD__8;
				NimStringV2 colontmpD__9;
				tyArray__YgExxhfgKcesA5EOUj1MOA T44_;
				if (!(res_1 <= colontmp__2)) goto LA43;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				i_3 = ((NI) (res_1));
				colontmpD__8 = rope__ropes_u15(((NI64) ((NI)(id_1 + i_3))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T44_[0] = colontmpD__8;
				colontmpD__9 = percent___cgen_u17054(T44_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&gotoArray_1), colontmpD__9.len + 0);
appendString((&gotoArray_1), colontmpD__9);
				res_1 += ((NI)1);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
			} LA43: ;
		}
	}
	colontmpD__3 = rope__ropes_u15(((NI64) ((NI)(id_1 + arraySize_1))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T45_[0] = colontmpD__3;
	colontmpD__4 = percent___cgen_u17059(T45_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&gotoArray_1), colontmpD__4.len + 0);
appendString((&gotoArray_1), colontmpD__4);
	T46_ = (NimStringV2*)0;
	T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T46_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T47_ = (NimStringV2*)0;
	T47_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T47_)), gotoArray_1.len + 0);
appendString((&(*T47_)), gotoArray_1);
	{
		NI j_1;
		NI i_4;
		j_1 = (NI)0;
		i_4 = ((NI)0);
		{
			while (1) {
				if (!(i_4 < casePos_1)) goto LA50;
				j_1 = i_4;
				genStmts__cgen_u14081(p_p0, (*n_2)._kind_6.sons.p->data[j_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				i_4 += ((NI)1);
			} LA50: ;
		}
	}
	eqcopy___ast_u3255(&caseStmt_1, (*n_2)._kind_6.sons.p->data[casePos_1]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T51_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*caseStmt_1)._kind_6.sons.p->data[((NI)0)], T51_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T52_ = (NimStringV2*)0;
	T52_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T52_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T53_ = (NimStringV2*)0;
	T53_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T54_[0] = tmp_1;
	colontmpD__5 = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T54_[1] = colontmpD__5;
	colontmpD__6 = percent___cgen_u17071(T54_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T53_)), colontmpD__6.len + 0);
appendString((&(*T53_)), colontmpD__6);
	{
		NI i_5;
		NI colontmp__3;
		NI i_6;
		i_5 = (NI)0;
		colontmp__3 = (NI)0;
		colontmp__3 = len__ast_u3190(caseStmt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_6 = ((NI)1);
		{
			while (1) {
				NimStringV2 res_2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__10;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				NimStringV2* T59_;
				NimStringV2* T60_;
				NI T65_;
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T128_;
				NimStringV2* T129_;
				NimStringV2* T130_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T131_;
				if (!(i_6 < colontmp__3)) goto LA57;
				res_2.len = 0; res_2.p = NIM_NIL;
				it_2 = NIM_NIL;
				colontmpD__10 = NIM_NIL;
				nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				i_5 = i_6;
				T59_ = (NimStringV2*)0;
				T59_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				addIndent__cgen_u315(p_p0, T59_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				T60_ = (NimStringV2*)0;
				T60_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				res_2 = rawNewString(((NI)80));
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2996);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA63_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_2997);
				}
LA63_: ;
				prepareAdd((&(*T60_)), res_2.len + 0);
appendString((&(*T60_)), res_2);
				T65_ = (NI)0;
				T65_ = startBlockInternal__cgen_u15729(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				eqcopy___ast_u3255(&it_2, (*caseStmt_1)._kind_6.sons.p->data[i_5]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				{
					NI j_2;
					NI colontmp__4;
					NI T67_;
					NI i_7;
					j_2 = (NI)0;
					colontmp__4 = (NI)0;
					T67_ = (NI)0;
					T67_ = len__ast_u3190(it_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
					colontmp__4 = (NI)(T67_ - ((NI)1));
					i_7 = ((NI)0);
					{
						while (1) {
							NimStringV2 lit_1;
							NimStringV2 colontmpD__13;
							tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg val_1;
							NI64 T75_;
							NimStringV2* T76_;
							NimStringV2* T77_;
							tyArray__YgExxhfgKcesA5EOUj1MOA T78_;
							if (!(i_7 < colontmp__4)) goto LA69;
							lit_1.len = 0; lit_1.p = NIM_NIL;
							colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
							j_2 = i_7;
							{
								if (!((*(*it_2)._kind_6.sons.p->data[j_2]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA73_;
								liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*it_2).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_2999, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_3000, NIM_FALSE, NIM_FALSE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
								eqdestroy___system_u2691(colontmpD__13);
								eqdestroy___system_u2691(lit_1);
								eqdestroy___system_u2691(colontmpD__12);
								eqdestroy___system_u2691(colontmpD__11);
								eqdestroy___ast_u6284(a_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___ast_u3252(colontmpD__10);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___ast_u3252(it_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								eqdestroy___system_u2691(res_2);
								eqdestroy___system_u2691(colontmpD__6);
								eqdestroy___system_u2691(colontmpD__5);
								eqdestroy___ast_u6284(a_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								eqdestroy___ast_u3252(caseStmt_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								eqdestroy___system_u2691(colontmpD__4);
								eqdestroy___system_u2691(colontmpD__3);
								eqdestroy___system_u2691(colontmpD__2);
								eqdestroy___system_u2691(gotoArray_1);
								eqdestroy___system_u2691(colontmpD_);
								eqdestroy___system_u2691(tmp_1);
								eqdestroy___ast_u3252(n_2);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto BeforeRet_;
							}
LA73_: ;
							val_1 = getOrdValue__types_u167((*it_2)._kind_6.sons.p->data[j_2]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							lit_1 = newRopeAppender__ropes_u7(((NI)80));
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							T75_ = (NI64)0;
							T75_ = toInt64__int128_u53(val_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							intLiteral__cgen_u14092((NI64)((NI64)(T75_ + ((NI64) (id_1))) + IL64(1)), (&lit_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							T76_ = (NimStringV2*)0;
							T76_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							addIndent__cgen_u315(p_p0, T76_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							T77_ = (NimStringV2*)0;
							T77_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							T78_[0] = lit_1;
							colontmpD__13 = percent___cgen_u17106(T78_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
							prepareAdd((&(*T77_)), colontmpD__13.len + 0);
appendString((&(*T77_)), colontmpD__13);
							i_7 += ((NI)1);
							{
								LA70_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__13);
								eqdestroy___system_u2691(lit_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
						} LA69: ;
					}
				}
				colontmpD__10 = lastSon__ast_u5208(it_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				genStmts__cgen_u14081(p_p0, colontmpD__10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				{
					NI j_3;
					NI colontmp__5;
					NI colontmp__6;
					NI i_8;
					j_3 = (NI)0;
					colontmp__5 = (NI)0;
					colontmp__6 = (NI)0;
					colontmp__5 = (NI)(casePos_1 + ((NI)1));
					colontmp__6 = len__ast_u3190(n_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
					i_8 = colontmp__5;
					{
						while (1) {
							if (!(i_8 < colontmp__6)) goto LA83;
							j_3 = i_8;
							genStmts__cgen_u14081(p_p0, (*n_2)._kind_6.sons.p->data[j_3]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
							i_8 += ((NI)1);
						} LA83: ;
					}
				}
				{
					NI j_4;
					NI i_9;
					j_4 = (NI)0;
					i_9 = ((NI)0);
					{
						while (1) {
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_3;
							if (!(i_9 < casePos_1)) goto LA86;
							it_3 = NIM_NIL;
							j_4 = i_9;
							eqcopy___ast_u3255(&it_3, (*n_2)._kind_6.sons.p->data[j_4]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
							{
								tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* asgn_1;
								if (!((*it_3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100) || (*it_3).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99))) goto LA90_;
								asgn_1 = NIM_NIL;
								asgn_1 = copyNode__ast_u6736(it_3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
								transitionSonsKind__ast_u6769(asgn_1, ((tyEnum_TNodeKind__fgQOep3rrztw9aeZI9aS2Ltg)73));
								if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
								setLen__ast_u3718((&(*asgn_1)._kind_6.sons), ((NI)2));
								{
									tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* sym_1;
									tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* value_1;
									sym_1 = NIM_NIL;
									value_1 = NIM_NIL;
									sym_1 = 0;
									value_1 = 0;
									{
										tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* identDefs_1;
										identDefs_1 = NIM_NIL;
										identDefs_1 = 0;
										{
											NI i_10;
											NI colontmp__7;
											NI i_11;
											i_10 = (NI)0;
											colontmp__7 = (NI)0;
											colontmp__7 = safeLen__ast_u3197(it_3);
											if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
											i_11 = ((NI)0);
											{
												while (1) {
													if (!(i_11 < colontmp__7)) goto LA99;
													i_10 = i_11;
													eqcopy___ast_u3255(&identDefs_1, (*it_3)._kind_6.sons.p->data[i_10]);
													if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
													{
														tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* valueSym_1;
														NI T105_;
														if (!((*identDefs_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)35))) goto LA102_;
														valueSym_1 = NIM_NIL;
														T105_ = (NI)0;
														T105_ = len__ast_u3190(identDefs_1);
														if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
														eqcopy___ast_u3255(&valueSym_1, (*identDefs_1)._kind_6.sons.p->data[(NI)(T105_ - ((NI)1))]);
														if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
														{
															NI i_12;
															NI colontmp__8;
															NI T107_;
															NI i_13;
															i_12 = (NI)0;
															colontmp__8 = (NI)0;
															T107_ = (NI)0;
															T107_ = len__ast_u3190(identDefs_1);
															if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
															colontmp__8 = (NI)(T107_ - ((NI)2));
															i_13 = ((NI)0);
															{
																while (1) {
																	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* memberSym_1;
																	if (!(i_13 < colontmp__8)) goto LA109;
																	memberSym_1 = NIM_NIL;
																	i_12 = i_13;
																	eqcopy___ast_u3255(&memberSym_1, (*identDefs_1)._kind_6.sons.p->data[i_12]);
																	if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																	eqsink___ast_u3261(&sym_1, memberSym_1);
																	if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																	eqwasMoved___ast_u3249(&memberSym_1);
																	if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																	eqcopy___ast_u3255(&value_1, valueSym_1);
																	if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																	{
																		if (!!(((*value_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA113_;
																		eqsink___ast_u3261(&(*asgn_1)._kind_6.sons.p->data[((NI)0)], sym_1);
																		if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																		eqwasMoved___ast_u3249(&sym_1);
																		if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																		eqsink___ast_u3261(&(*asgn_1)._kind_6.sons.p->data[((NI)1)], value_1);
																		if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																		eqwasMoved___ast_u3249(&value_1);
																		if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																		genStmts__cgen_u14081(p_p0, asgn_1);
																		if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
																	}
LA113_: ;
																	i_13 += ((NI)1);
																	{
																		LA110_:;
																	}
																	{
																		oldNimErrFin110_ = *nimErr_; *nimErr_ = NIM_FALSE;
																		eqdestroy___ast_u3252(memberSym_1);
																		if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
																		*nimErr_ = oldNimErrFin110_;
																	}
																	if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
																} LA109: ;
															}
														}
														{
															LA104_:;
														}
														{
															oldNimErrFin104_ = *nimErr_; *nimErr_ = NIM_FALSE;
															eqdestroy___ast_u3252(valueSym_1);
															if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
															*nimErr_ = oldNimErrFin104_;
														}
														if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
													}
LA102_: ;
													i_11 += ((NI)1);
												} LA99: ;
											}
										}
										{
											LA96_:;
										}
										{
											oldNimErrFin96_ = *nimErr_; *nimErr_ = NIM_FALSE;
											eqdestroy___ast_u3252(identDefs_1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
											*nimErr_ = oldNimErrFin96_;
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA94_;
									}
									{
										LA94_:;
									}
									{
										oldNimErrFin94_ = *nimErr_; *nimErr_ = NIM_FALSE;
										eqdestroy___ast_u3252(value_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
										eqdestroy___ast_u3252(sym_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
										*nimErr_ = oldNimErrFin94_;
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
								}
								{
									LA92_:;
								}
								{
									oldNimErrFin92_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___ast_u3252(asgn_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
									*nimErr_ = oldNimErrFin92_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
							}
							goto LA88_;
LA90_: ;
							{
								genStmts__cgen_u14081(p_p0, it_3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
							}
LA88_: ;
							i_9 += ((NI)1);
							{
								LA87_:;
							}
							{
								oldNimErrFin87_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(it_3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
								*nimErr_ = oldNimErrFin87_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
						} LA86: ;
					}
				}
				T128_ = 0;
				initLocExpr__cgen_u14111(p_p0, (*caseStmt_1)._kind_6.sons.p->data[((NI)0)], T128_, (&a_2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				T129_ = (NimStringV2*)0;
				T129_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				addIndent__cgen_u315(p_p0, T129_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				T130_ = (NimStringV2*)0;
				T130_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				T131_[0] = tmp_1;
				colontmpD__11 = rdLoc__cgen_u470(a_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				T131_[1] = colontmpD__11;
				colontmpD__12 = percent___cgen_u17071(T131_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				prepareAdd((&(*T130_)), colontmpD__12.len + 0);
appendString((&(*T130_)), colontmpD__12);
				endBlock__cgen_u15767(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
				i_6 += ((NI)1);
				{
					LA58_:;
				}
				{
					oldNimErrFin58_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
					eqdestroy___ast_u6284(a_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(it_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(res_2);
					*nimErr_ = oldNimErrFin58_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA57: ;
		}
	}
	{
		NI j_5;
		NI colontmp__9;
		NI colontmp__10;
		NI i_14;
		j_5 = (NI)0;
		colontmp__9 = (NI)0;
		colontmp__10 = (NI)0;
		colontmp__9 = (NI)(casePos_1 + ((NI)1));
		colontmp__10 = len__ast_u3190(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_14 = colontmp__9;
		{
			while (1) {
				if (!(i_14 < colontmp__10)) goto LA136;
				j_5 = i_14;
				genStmts__cgen_u14081(p_p0, (*n_2)._kind_6.sons.p->data[j_5]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				i_14 += ((NI)1);
			} LA136: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(caseStmt_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(gotoArray_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, assignLabel__cgen_u16174)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* b_p0, NimStringV2* result_p1) {
	NimStringV2 colontmpD_;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	colontmpD_ = rope__ropes_u15(((NI64) ((*b_p0).id)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = rawNewString(colontmpD_.len + 2);
appendString((&T1_), TM__MQdRN7fpbG7rPm4JpVVAhA_3004);
appendString((&T1_), colontmpD_);
	eqsink___system_u2700((&(*b_p0).label), T1_);
	prepareAdd((&(*result_p1)), (*b_p0).label.len + 0);
appendString((&(*result_p1)), (*b_p0).label);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genWhileStmt__cgen_u17147)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* loopBody_1;
	NI oldBreakIdxX60gensym2289__1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	loopBody_1 = NIM_NIL;
	(*p_p0).withinLoop += ((NI)1);
	genLineDir__cgen_u418(p_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	oldBreakIdxX60gensym2289__1 = (*p_p0).breakIdx;
	eqcopy___ast_u3255(&loopBody_1, (*t_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = stmtsContainPragma__ccgutils_u37(loopBody_1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)208));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_)) goto LA5_;
		T4_ = ((CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)1)))&15U)))!=0);
LA5_: ;
		if (!T4_) goto LA6_;
		{
			NIM_BOOL T10_;
			NI T11_;
			T10_ = (NIM_BOOL)0;
			T11_ = (NI)0;
			T11_ = len__ast_u3190(loopBody_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T10_ = (T11_ == ((NI)2));
			if (!(T10_)) goto LA12_;
			T10_ = ((*(*loopBody_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
LA12_: ;
			if (!T10_) goto LA13_;
			eqcopy___ast_u3255(&loopBody_1, (*loopBody_1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA13_: ;
		genComputedGoto__cgen_u17010(p_p0, loopBody_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 res_1;
		NimStringV2* T17_;
		NimStringV2* T18_;
		NI T23_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T24_;
		res_1.len = 0; res_1.p = NIM_NIL;
		T17_ = (NimStringV2*)0;
		T17_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		addIndent__cgen_u315(p_p0, T17_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		T18_ = (NimStringV2*)0;
		T18_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 11);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3002);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA21_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3003);
		}
LA21_: ;
		prepareAdd((&(*T18_)), res_1.len + 0);
appendString((&(*T18_)), res_1);
		T23_ = (NI)0;
		T23_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		(*p_p0).breakIdx = T23_;
		(*p_p0).blocks.p->data[(*p_p0).breakIdx].isLoop = NIM_TRUE;
		T24_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], T24_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		{
			NIM_BOOL T27_;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 res_2;
			NimStringV2* T31_;
			NimStringV2* T32_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T33_;
			NimStringV2* T34_;
			NimStringV2* T35_;
			T27_ = (NIM_BOOL)0;
			T27_ = !(((*(*t_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6)));
			if (T27_) goto LA28_;
			T27_ = ((*(*t_p1)._kind_6.sons.p->data[((NI)0)])._kind_1.intVal == IL64(0));
LA28_: ;
			if (!T27_) goto LA29_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			res_2.len = 0; res_2.p = NIM_NIL;
			T31_ = (NimStringV2*)0;
			T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			addIndent__cgen_u315(p_p0, T31_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			T32_ = (NimStringV2*)0;
			T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			colontmpD_ = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			T33_[0] = colontmpD_;
			colontmpD__2 = percent___cgen_u17187(T33_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			prepareAdd((&(*T32_)), colontmpD__2.len + 0);
appendString((&(*T32_)), colontmpD__2);
			T34_ = (NimStringV2*)0;
			T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			assignLabel__cgen_u16174((&(*p_p0).blocks.p->data[(*p_p0).breakIdx]), T34_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			T35_ = (NimStringV2*)0;
			T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3005);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA38_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3006);
			}
LA38_: ;
			prepareAdd((&(*T35_)), res_2.len + 0);
appendString((&(*T35_)), res_2);
			eqdestroy___system_u2691(res_2);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
LA29_: ;
		genStmts__cgen_u14081(p_p0, loopBody_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		{
			NimStringV2 res_3;
			NimStringV2 colontmpD__3;
			NimStringV2* T45_;
			NimStringV2* T46_;
			if (!(((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)21)))&31U)))!=0)) goto LA42_;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T45_ = (NimStringV2*)0;
			T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			addIndent__cgen_u315(p_p0, T45_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			T46_ = (NimStringV2*)0;
			T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			res_3 = rawNewString(((NI)80));
			colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3007);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
			prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3008);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA49_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3009);
			}
LA49_: ;
			prepareAdd((&(*T46_)), res_3.len + 0);
appendString((&(*T46_)), res_3);
			{
				LA44_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(res_3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		}
LA42_: ;
		endBlock__cgen_u15767(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		{
			LA16_:;
		}
		{
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	(*p_p0).breakIdx = oldBreakIdxX60gensym2289__1;
	(*p_p0).withinLoop -= ((NI)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(loopBody_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genSingleVar__cgen_u16780)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	v_1 = NIM_NIL;
	v_1 = (*(*a_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym;
	{
		if (!(((*v_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0)) goto LA3_;
		{
			NIM_BOOL T7_;
			NIM_BOOL T8_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NIM_BOOL)0;
			T8_ = (((*v_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3)))&63U)))!=0);
			if (!(T8_)) goto LA9_;
			T8_ = !(((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA9_: ;
			T7_ = T8_;
			if (!(T7_)) goto LA10_;
			T7_ = ((*(*p_p0).prc).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12));
LA10_: ;
			if (!T7_) goto LA11_;
		}
		goto LA5_;
LA11_: ;
		{
			goto BeforeRet_;
		}
LA5_: ;
	}
LA3_: ;
	genSingleVar__cgen_u16620(p_p0, v_1, (*a_p1)._kind_6.sons.p->data[((NI)0)], (*a_p1)._kind_6.sons.p->data[((NI)2)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genClosureVar__cgen_u16800)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw v_1;
	NIM_BOOL immediateAsgn_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&v_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	immediateAsgn_1 = !(((*(*a_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)));
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*a_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&v_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genLineDir__cgen_u418(p_p0, a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!immediateAsgn_1) goto LA5_;
		loadInto__cgen_u16153(p_p0, (*a_p1)._kind_6.sons.p->data[((NI)0)], (*a_p1)._kind_6.sons.p->data[((NI)2)], (&v_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		if (!!((((*(*(*(*a_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0))) goto LA8_;
		constructLoc__cgen_u13487(p_p0, (&v_1), NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA8_: ;
LA3_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(v_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarTuple__cgen_u15769)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NimStringV2 hcrCond_1;
	tySequence__1cgZIGFge8OGY6Zlwa9aRnw hcrGlobals_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tup_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin14_;
	NIM_BOOL forHcr_1;
	NimStringV2 T17_;
	NIM_BOOL isGlobalInBlock_1;
	NIM_BOOL T23_;
	NI T25_;
	NIM_BOOL T26_;
	NI T45_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T46_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	hcrCond_1.len = 0; hcrCond_1.p = NIM_NIL;
	hcrGlobals_1.len = 0; hcrGlobals_1.p = NIM_NIL;
	nimZeroMem((void*)(&tup_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	t_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	{
		if (!!(((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)36)))) goto LA4_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_3011, TM__MQdRN7fpbG7rPm4JpVVAhA_3012);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		NI i_1;
		NI colontmp_;
		NI T7_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T7_ = (NI)0;
		T7_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T7_ - ((NI)2));
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA9;
				i_1 = i_2;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
					if (!!(((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA12_;
					colontmpD__2 = NIM_NIL;
					colontmpD__2 = lowerTupleUnpacking__lowerings_u56((*(*(*p_p0).module).g).graph, n_p1, (*(*p_p0).module).Sup.idgen, (*p_p0).prc);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					genStmts__cgen_u14081(p_p0, colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					eqdestroy___ast_u3252(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3378(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___ast_u3378(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___ast_u6284(tup_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___cgen_u15931(hcrGlobals_1);
					eqdestroy___system_u2691(hcrCond_1);
					goto BeforeRet_;
					{
						LA14_:;
					}
					{
						oldNimErrFin14_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin14_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA12_: ;
				i_2 += ((NI)1);
			} LA9: ;
		}
	}
	forHcr_1 = treatGlobalDifferentlyForHCR__cgen_u13851((*p_p0).module, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T17_.len = 0; T17_.p = NIM_NIL;
	{
		if (!forHcr_1) goto LA20_;
		hcrCond_1 = getTempName__cgen_u462((*p_p0).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA18_;
LA20_: ;
	{
		hcrCond_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3013;
	}
LA18_: ;
	hcrGlobals_1.len = 0; hcrGlobals_1.p = (tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content*) newSeqPayload(0, sizeof(tyTuple__IGtaz2jo9ahodpWjWgc5c5A), NIM_ALIGNOF(tyTuple__IGtaz2jo9ahodpWjWgc5c5A));
	T23_ = (NIM_BOOL)0;
	T23_ = forHcr_1;
	if (!(T23_)) goto LA24_;
	T25_ = (*p_p0).blocks.len;
	T23_ = (((NI)2) < T25_);
LA24_: ;
	isGlobalInBlock_1 = T23_;
	T26_ = (NIM_BOOL)0;
	T26_ = forHcr_1;
	if (!(T26_)) goto LA27_;
	T26_ = !(isGlobalInBlock_1);
LA27_: ;
	forHcr_1 = T26_;
	{
		NimStringV2 res_1;
		NimStringV2 res_2;
		NimStringV2* T32_;
		NimStringV2* T33_;
		NimStringV2* T38_;
		NimStringV2* T39_;
		NI T44_;
		if (!forHcr_1) goto LA30_;
		res_1.len = 0; res_1.p = NIM_NIL;
		res_2.len = 0; res_2.p = NIM_NIL;
		T32_ = (NimStringV2*)0;
		T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T32_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T33_ = (NimStringV2*)0;
		T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3014);
		cgFormatValue__cgen_u163((&res_1), hcrCond_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3015);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA36_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3016);
		}
LA36_: ;
		prepareAdd((&(*T33_)), res_1.len + 0);
appendString((&(*T33_)), res_1);
		T38_ = (NimStringV2*)0;
		T38_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T38_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T39_ = (NimStringV2*)0;
		T39_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3017);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA42_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3018);
		}
LA42_: ;
		prepareAdd((&(*T39_)), res_2.len + 0);
appendString((&(*T39_)), res_2);
		T44_ = (NI)0;
		T44_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(res_2);
		eqdestroy___system_u2691(res_1);
	}
LA30_: ;
	genLineDir__cgen_u418(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T45_ = (NI)0;
	T45_ = len__ast_u3190(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T46_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[(NI)(T45_ - ((NI)1))], T46_, (&tup_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(tup_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379(colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_3;
		NI colontmp__2;
		NI T48_;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		T48_ = (NI)0;
		T48_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp__2 = (NI)(T48_ - ((NI)2));
		i_4 = ((NI)0);
		{
			while (1) {
				if (!(i_4 < colontmp__2)) goto LA50;
				i_3 = i_4;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* vn_1;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v_1;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw field_1;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T65_;
					vn_1 = NIM_NIL;
					v_1 = NIM_NIL;
					nimZeroMem((void*)(&field_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					eqcopy___ast_u3255(&vn_1, (*n_p1)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					eqcopy___ast_u4577(&v_1, (*vn_1)._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					{
						if (!(((*v_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0)) goto LA55_;
						eqdestroy___ast_u6284(field_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u4574(v_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3252(vn_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						goto LA51;
					}
LA55_: ;
					{
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T61_;
						if (!(((*v_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3)))&63U)))!=0)) goto LA59_;
						assignGlobalVar__cgen_u13919(p_p0, vn_1, TM__MQdRN7fpbG7rPm4JpVVAhA_3019);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						T61_ = NIM_NIL;
						T61_ = (*v_1).typ;
						genObjectInit__cgen_u12909(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1), T61_, (&(*v_1).loc), ((tyEnum_ObjConstrMode__xsPOYROdUH9ay3kug3jxK8Q)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						registerTraverseProc__cgen_u15592(p_p0, v_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					}
					goto LA57_;
LA59_: ;
					{
						NI T63_;
						NIM_BOOL T64_;
						assignLocalVar__cgen_u13691(p_p0, vn_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						T63_ = (NI)0;
						T63_ = len__ast_u3190(n_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						T64_ = (NIM_BOOL)0;
						T64_ = isAssignedImmediately__cgen_u15650((*(*(*p_p0).module).g).config, (*n_p1)._kind_6.sons.p->data[(NI)(T63_ - ((NI)1))]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						initLocalVar__cgen_u13552(p_p0, v_1, T64_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					}
LA57_: ;
					T65_ = 0;
					initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), vn_1, tup_1.storage, T65_, (&field_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					{
						NimStringV2 colontmpD__3;
						NimStringV2 colontmpD__4;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T70_;
						NimStringV2 T71_;
						if (!((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18))) goto LA68_;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						colontmpD__3 = rdLoc__cgen_u470(tup_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						T70_[0] = colontmpD__3;
						colontmpD__4 = rope__ropes_u15(((NI64) (i_3)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						T70_[1] = colontmpD__4;
						T71_.len = 0; T71_.p = NIM_NIL;
						T71_ = percent___cgen_u15846(T70_, 2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T71_); goto LA52_;}
						eqsink___system_u2700((&field_1.snippet), T71_);
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
					}
					goto LA66_;
LA68_: ;
					{
						NimStringV2 colontmpD__5;
						NimStringV2 colontmpD__6;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T78_;
						NimStringV2 T79_;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						{
							if (!!(((*(*(*t_1).n)._kind_6.sons.p->data[i_3]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA76_;
							internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_3020, TM__MQdRN7fpbG7rPm4JpVVAhA_3021);
							if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
						}
LA76_: ;
						colontmpD__5 = rdLoc__cgen_u470(tup_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
						T78_[0] = colontmpD__5;
						colontmpD__6 = mangleRecFieldName__cgen_u4042((*p_p0).module, (*(*(*t_1).n)._kind_6.sons.p->data[i_3])._kind_4.sym);
						if (NIM_UNLIKELY(*nimErr_)) goto LA73_;
						T78_[1] = colontmpD__6;
						T79_.len = 0; T79_.p = NIM_NIL;
						T79_ = percent___cgen_u9620(T78_, 2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T79_); goto LA73_;}
						eqsink___system_u2700((&field_1.snippet), T79_);
						{
							LA73_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__6);
							eqdestroy___system_u2691(colontmpD__5);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					}
LA66_: ;
					putLocIntoDest__cgen_u14088(p_p0, (&(*v_1).loc), field_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
					{
						NIM_BOOL T84_;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw colontmpD__7;
						tyTuple__IGtaz2jo9ahodpWjWgc5c5A T88_;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T89_;
						T84_ = (NIM_BOOL)0;
						T84_ = forHcr_1;
						if (T84_) goto LA85_;
						T84_ = isGlobalInBlock_1;
LA85_: ;
						if (!T84_) goto LA86_;
						nimZeroMem((void*)(&T88_), sizeof(tyTuple__IGtaz2jo9ahodpWjWgc5c5A));
						nimZeroMem((void*)(&T89_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						eqdup___ast_u6290((*v_1).loc, (&T89_));
						colontmpD__7 = T89_;
						if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
						T88_.Field0 = colontmpD__7;
						T88_.Field1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3022;
						add__cgen_u15861((&hcrGlobals_1), T88_);
					}
LA86_: ;
					{
						LA52_:;
					}
					{
						oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u6284(field_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u4574(v_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u3252(vn_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin52_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA51: ;
				i_4 += ((NI)1);
			} LA50: ;
		}
	}
	{
		if (!forHcr_1) goto LA94_;
		endBlock__cgen_u15767(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA94_: ;
	{
		NIM_BOOL T98_;
		NimStringV2 res_3;
		NimStringV2* T103_;
		NimStringV2* T104_;
		T98_ = (NIM_BOOL)0;
		T98_ = forHcr_1;
		if (T98_) goto LA99_;
		T98_ = isGlobalInBlock_1;
LA99_: ;
		if (!T98_) goto LA100_;
		res_3.len = 0; res_3.p = NIM_NIL;
		T103_ = (NimStringV2*)0;
		T103_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
		addIndent__cgen_u315(p_p0, T103_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
		T104_ = (NimStringV2*)0;
		T104_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
		res_3 = rawNewString(((NI)80));
		prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3024);
		cgFormatValue__cgen_u163((&res_3), hcrCond_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
		prepareAdd((&res_3), 13);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3026);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA107_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3027);
		}
LA107_: ;
		prepareAdd((&(*T104_)), res_3.len + 0);
appendString((&(*T104_)), res_3);
		{
			tyTuple__IGtaz2jo9ahodpWjWgc5c5A* curr_1;
			NI i_5;
			NI L_1;
			NI T110_;
			curr_1 = (tyTuple__IGtaz2jo9ahodpWjWgc5c5A*)0;
			i_5 = ((NI)0);
			T110_ = hcrGlobals_1.len;
			L_1 = T110_;
			{
				while (1) {
					NimStringV2 res_4;
					NimStringV2 colontmpD__8;
					NimStringV2 colontmpD__9;
					NimStringV2* T114_;
					NimStringV2* T115_;
					if (!(i_5 < L_1)) goto LA112;
					res_4.len = 0; res_4.p = NIM_NIL;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					curr_1 = (&hcrGlobals_1.p->data[i_5]);
					T114_ = (NimStringV2*)0;
					T114_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					addIndent__cgen_u315(p_p0, T114_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					T115_ = (NimStringV2*)0;
					T115_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					res_4 = rawNewString(((NI)80));
					cgFormatValue__cgen_u163((&res_4), hcrCond_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					prepareAdd((&res_4), 22);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3029);
					colontmpD__8 = getModuleDllPath__cgen_u158((*p_p0).module, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					cgFormatValue__cgen_u163((&res_4), colontmpD__8);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3030);
					cgFormatValue__cgen_u163((&res_4), (*curr_1).Field0.snippet);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					prepareAdd((&res_4), 10);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3031);
					colontmpD__9 = rdLoc__cgen_u470((*curr_1).Field0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					cgFormatValue__cgen_u163((&res_4), colontmpD__9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3032);
					cgFormatValue__cgen_u163((&res_4), (*curr_1).Field1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					prepareAdd((&res_4), 11);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3033);
					cgFormatValue__cgen_u163((&res_4), (*curr_1).Field0.snippet);
					if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
					prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3034);
					prepareAdd((&(*T115_)), res_4.len + 0);
appendString((&(*T115_)), res_4);
					i_5 += ((NI)1);
					{
						LA113_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__9);
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(res_4);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA102_;
				} LA112: ;
			}
		}
		{
			LA102_:;
		}
		{
			eqdestroy___system_u2691(res_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA100_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(tup_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___cgen_u15931(hcrGlobals_1);
		eqdestroy___system_u2691(hcrCond_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genVarStmt__cgen_u16813)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tySequence__9ahcSjIErJohSBBFLwuF56Q colontmp_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** it_1;
		NI i_1;
		NI L_1;
		NI T3_;
		colontmp_.len = 0; colontmp_.p = NIM_NIL;
		it_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
		eqcopy___ast_u3699((&colontmp_), (*n_p1)._kind_6.sons);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		i_1 = ((NI)0);
		T3_ = colontmp_.len;
		L_1 = T3_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA5;
				it_1 = &colontmp_.p->data[i_1];
				{
					{
						if (!((*(*it_1)).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125))) goto LA9_;
						goto LA6;
					}
LA9_: ;
					{
						if (!((*(*it_1)).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)35))) goto LA13_;
						{
							if (!((*(*(*it_1))._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA17_;
							genSingleVar__cgen_u16780(p_p0, (*it_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
						}
						goto LA15_;
LA17_: ;
						{
							genClosureVar__cgen_u16800(p_p0, (*it_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
						}
LA15_: ;
					}
					goto LA11_;
LA13_: ;
					{
						genVarTuple__cgen_u15769(p_p0, (*it_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					}
LA11_: ;
				} LA6: ;
				i_1 += ((NI)1);
			} LA5: ;
		}
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3696(colontmp_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genConstStmt__cgen_u26853)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_1;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	m_1 = NIM_NIL;
	eqcopy___cgendata_u721(&m_1, (*p_p0).module, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
		it_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA6;
					i_1 = i_2;
					eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
						if (!((*(*it_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA9_;
						sym_1 = NIM_NIL;
						eqcopy___ast_u4577(&sym_1, (*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
						{
							NIM_BOOL T14_;
							NIM_BOOL T15_;
							NIM_BOOL T16_;
							T14_ = (NIM_BOOL)0;
							T15_ = (NIM_BOOL)0;
							T16_ = (NIM_BOOL)0;
							T16_ = isSimpleConst__cgen_u107((*sym_1).typ);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
							T15_ = !(T16_);
							if (!(T15_)) goto LA17_;
							T15_ = contains__astalgo_u2846((&(*m_1).alive), ((NI) ((*sym_1).itemId.item)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
LA17_: ;
							T14_ = T15_;
							if (!(T14_)) goto LA18_;
							T14_ = genConstSetup__cgen_u26767(p_p0, sym_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
LA18_: ;
							if (!T14_) goto LA19_;
							genConstDefinition__cgen_u26816(m_1, p_p0, sym_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
						}
LA19_: ;
						{
							LA11_:;
						}
						{
							oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u4574(sym_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
							*nimErr_ = oldNimErrFin11_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					}
LA9_: ;
					i_2 += ((NI)1);
				} LA6: ;
			}
		}
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u718(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCaseStringBranch__cgen_u17704)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw e_p2, NimStringV2 labl_p3, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg stringKind_p4, NimStringV2* branches_p5, NI branches_p5Len_0) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw x_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&x_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__ast_u3190(b_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T3_ - ((NI)1));
		i_2 = ((NI)0);
		{
			while (1) {
				tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T6_;
				tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T7_;
				NI j_1;
				if (!(i_2 < colontmp_)) goto LA5;
				i_1 = i_2;
				T6_ = 0;
				nimZeroMem((void*)(&T7_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
				initLocExpr__cgen_u14111(p_p0, (*b_p1)._kind_6.sons.p->data[i_1], T6_, (&T7_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqsink___ast_u6293((&x_1), T7_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				j_1 = ((NI)0);
				switch ((*(*b_p1)._kind_6.sons.p->data[i_1]).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
				{
					NI64 T9_;
					T9_ = (NI64)0;
					T9_ = hashString__ccgutils_u45((*(*(*p_p0).module).g).config, (*(*b_p1)._kind_6.sons.p->data[i_1])._kind_3.strVal);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					j_1 = ((NI) ((NI64)(T9_ & ((NI64) ((branches_p5Len_0-1))))));
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
				{
					j_1 = ((NI)0);
				}
				break;
				default:
				{
				}
				break;
				}
				{
					NimStringV2 res_1;
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					NimStringV2 colontmpD__3;
					if (!(stringKind_p4 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29))) goto LA14_;
					res_1.len = 0; res_1.p = NIM_NIL;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					res_1 = rawNewString(((NI)80));
					prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3038);
					colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3040);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					cgFormatValue__cgen_u163((&res_1), colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3041);
					colontmpD__2 = rdLoc__cgen_u470(e_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					cgFormatValue__cgen_u163((&res_1), colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3042);
					colontmpD__3 = rdLoc__cgen_u470(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					cgFormatValue__cgen_u163((&res_1), colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					prepareAdd((&res_1), 8);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3044);
					cgFormatValue__cgen_u163((&res_1), labl_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3045);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA19_;
						prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3046);
					}
LA19_: ;
					prepareAdd((&branches_p5[j_1]), res_1.len + 0);
appendString((&branches_p5[j_1]), res_1);
					{
						LA16_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__3);
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
						eqdestroy___system_u2691(res_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA12_;
LA14_: ;
				{
					NimStringV2 res_2;
					NimStringV2 colontmpD__4;
					NimStringV2 colontmpD__5;
					NimStringV2 colontmpD__6;
					res_2.len = 0; res_2.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					res_2 = rawNewString(((NI)80));
					prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3047);
					colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3048);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3049);
					colontmpD__5 = rdLoc__cgen_u470(e_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__5);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3050);
					colontmpD__6 = rdLoc__cgen_u470(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					cgFormatValue__cgen_u163((&res_2), colontmpD__6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3051);
					cgFormatValue__cgen_u163((&res_2), labl_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3052);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA27_;
						prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3053);
					}
LA27_: ;
					prepareAdd((&branches_p5[j_1]), res_2.len + 0);
appendString((&branches_p5[j_1]), res_2);
					{
						LA24_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__6);
						eqdestroy___system_u2691(colontmpD__5);
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(res_2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA12_: ;
				i_2 += ((NI)1);
			} LA5: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, exprBlock__cgen_u16234)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	NimStringV2 res_1;
	NimStringV2* T2_;
	NimStringV2* T3_;
	NI T8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	res_1.len = 0; res_1.p = NIM_NIL;
	T2_ = (NimStringV2*)0;
	T2_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = (NimStringV2*)0;
	T3_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3073);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA6_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3074);
	}
LA6_: ;
	prepareAdd((&(*T3_)), res_1.len + 0);
appendString((&(*T3_)), res_1);
	T8_ = (NI)0;
	T8_ = startBlockInternal__cgen_u15729(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	expr__cgen_u14084(p_p0, n_p1, d_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	endBlock__cgen_u15767(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genCaseSecondPass__cgen_u17654)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2, NI labId_p3, NI until_p4) {
	NimStringV2 result;
	NimStringV2 lend_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	lend_1.len = 0; lend_1.p = NIM_NIL;
	lend_1 = getLabel__cgen_u14059(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI res_1;
		i_1 = (NI)0;
		res_1 = ((NI)1);
		{
			while (1) {
				NimStringV2 colontmpD_;
				NimStringV2 colontmpD__2;
				NimStringV2* T12_;
				NimStringV2* T13_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T14_;
				if (!(res_1 <= until_p4)) goto LA4;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				i_1 = ((NI) (res_1));
				{
					NIM_BOOL T8_;
					T8_ = (NIM_BOOL)0;
					T8_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1));
					if (!(T8_)) goto LA9_;
					T8_ = isEmptyType__ast_u7234((*t_p1).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
LA9_: ;
					if (!T8_) goto LA10_;
					(*d_p2).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0);
				}
LA10_: ;
				T12_ = (NimStringV2*)0;
				T12_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				addIndent__cgen_u315(p_p0, T12_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T13_ = (NimStringV2*)0;
				T13_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				colontmpD_ = rope__ropes_u15(((NI64) ((NI)(labId_p3 + i_1))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T14_[0] = colontmpD_;
				colontmpD__2 = percent___cgen_u17671(T14_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				prepareAdd((&(*T13_)), colontmpD__2.len + 0);
appendString((&(*T13_)), colontmpD__2);
				{
					NimStringV2 colontmpD__3;
					NI T20_;
					NimStringV2* T21_;
					NimStringV2* T22_;
					tyArray__YgExxhfgKcesA5EOUj1MOA T23_;
					if (!((*(*t_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA17_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					T20_ = (NI)0;
					T20_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					exprBlock__cgen_u16234(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[(NI)(T20_ - ((NI)1))], d_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					T21_ = (NimStringV2*)0;
					T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					addIndent__cgen_u315(p_p0, T21_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					T22_ = (NimStringV2*)0;
					T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					T23_[0] = lend_1;
					colontmpD__3 = percent___cgen_u16882(T23_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					prepareAdd((&(*T22_)), colontmpD__3.len + 0);
appendString((&(*T22_)), colontmpD__3);
					{
						LA19_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
				goto LA15_;
LA17_: ;
				{
					exprBlock__cgen_u16234(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], d_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA15_: ;
				res_1 += ((NI)1);
				{
					LA5_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	result = lend_1;
	eqwasMoved___system_u2688((&lend_1));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(lend_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genStringCase__cgen_u17761)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg stringKind_p2, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p3) {
	NI strings_1;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin91_;
NIM_BOOL oldNimErrFin81_;
NIM_BOOL oldNimErrFin159_;
NIM_BOOL oldNimErrFin149_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	strings_1 = ((NI)0);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)1);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA3;
				i_1 = i_2;
				{
					NI T8_;
					if (!((*(*t_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA6_;
					T8_ = (NI)0;
					T8_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					strings_1 += (NI)(T8_ - ((NI)1));
				}
LA6_: ;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	{
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ branches_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		NimStringV2 colontmpD_;
		NimStringV2 lend_1;
		NI bitMask_1;
		NI T14_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T15_;
		NI labId_1;
		NimStringV2* T62_;
		NimStringV2* T63_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T64_;
		NI T73_;
		if (!(((NI)8) < strings_1)) goto LA11_;
		branches_1.len = 0; branches_1.p = NIM_NIL;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		lend_1.len = 0; lend_1.p = NIM_NIL;
		T14_ = (NI)0;
		T14_ = nextPowerOfTwo__pureZmath_u256(strings_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		bitMask_1 = (NI)(T14_ - ((NI)1));
		newSeq__system_u5399((&branches_1), ((NI)(bitMask_1 + ((NI)1))));
		T15_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], T15_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		labId_1 = (*p_p0).labels;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			i_4 = ((NI)1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA18;
					i_3 = i_4;
					(*p_p0).labels += ((NI)1);
					{
						NimStringV2 colontmpD__2;
						NimStringV2 colontmpD__3;
						NimStringV2 T24_;
						if (!((*(*t_p1)._kind_6.sons.p->data[i_3]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA21_;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						T24_.len = 0; T24_.p = NIM_NIL;
						colontmpD__2 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
						T24_ = rawNewString(colontmpD__2.len + 3);
appendString((&T24_), TM__MQdRN7fpbG7rPm4JpVVAhA_3054);
appendString((&T24_), colontmpD__2);
appendString((&T24_), TM__MQdRN7fpbG7rPm4JpVVAhA_3055);
						colontmpD__3 = T24_;
						genCaseStringBranch__cgen_u17704(p_p0, (*t_p1)._kind_6.sons.p->data[i_3], a_1, colontmpD__3, stringKind_p2, ((branches_1).p) ? (branches_1.p->data) : NIM_NIL, branches_1.len);
						if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
						{
							LA23_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__3);
							eqdestroy___system_u2691(colontmpD__2);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					}
					goto LA19_;
LA21_: ;
					{
					}
LA19_: ;
					i_4 += ((NI)1);
				} LA18: ;
			}
		}
		{
			NimStringV2 res_1;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2* T33_;
			NimStringV2* T34_;
			if (!(stringKind_p2 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29))) goto LA30_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T33_ = (NimStringV2*)0;
			T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			addIndent__cgen_u315(p_p0, T33_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			T34_ = (NimStringV2*)0;
			T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 8);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3057);
			colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3059);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3060);
			colontmpD__5 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3062);
			cgFormatValue__cgen_u166((&res_1), ((NI64) (bitMask_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
			prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3064);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA37_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3065);
			}
LA37_: ;
			prepareAdd((&(*T34_)), res_1.len + 0);
appendString((&(*T34_)), res_1);
			{
				LA32_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
		goto LA28_;
LA30_: ;
		{
			NimStringV2 res_2;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2* T43_;
			NimStringV2* T44_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			T43_ = (NimStringV2*)0;
			T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
			addIndent__cgen_u315(p_p0, T43_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
			T44_ = (NimStringV2*)0;
			T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 8);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3066);
			colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3068);
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3069);
			colontmpD__7 = rdLoc__cgen_u470(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
			prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3070);
			cgFormatValue__cgen_u166((&res_2), ((NI64) (bitMask_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
			prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3071);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA47_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3072);
			}
LA47_: ;
			prepareAdd((&(*T44_)), res_2.len + 0);
appendString((&(*T44_)), res_2);
			{
				LA42_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
LA28_: ;
		{
			NI j_1;
			NI colontmp__3;
			NI T52_;
			NI res_3;
			j_1 = (NI)0;
			colontmp__3 = (NI)0;
			T52_ = (branches_1.len-1);
			colontmp__3 = T52_;
			res_3 = ((NI)0);
			{
				while (1) {
					if (!(res_3 <= colontmp__3)) goto LA54;
					j_1 = ((NI) (res_3));
					{
						NimStringV2 lit_1;
						NimStringV2 colontmpD__8;
						NimStringV2* T59_;
						NimStringV2* T60_;
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T61_;
						if (!!((branches_1.p->data[j_1].len == 0))) goto LA57_;
						lit_1.len = 0; lit_1.p = NIM_NIL;
						colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
						lit_1 = newRopeAppender__ropes_u7(((NI)80));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						intLiteral__cgen_u14092(((NI64) (j_1)), (&lit_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T59_ = (NimStringV2*)0;
						T59_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						addIndent__cgen_u315(p_p0, T59_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T60_ = (NimStringV2*)0;
						T60_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T61_[0] = lit_1;
						T61_[1] = branches_1.p->data[j_1];
						colontmpD__8 = percent___cgen_u17842(T61_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						prepareAdd((&(*T60_)), colontmpD__8.len + 0);
appendString((&(*T60_)), colontmpD__8);
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(lit_1);
					}
LA57_: ;
					res_3 += ((NI)1);
				} LA54: ;
			}
		}
		T62_ = (NimStringV2*)0;
		T62_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		addIndent__cgen_u315(p_p0, T62_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T63_ = (NimStringV2*)0;
		T63_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		colontmpD_ = percent___cgen_u9681(T64_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&(*T63_)), colontmpD_.len + 0);
appendString((&(*T63_)), colontmpD_);
		{
			NI T67_;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2* T70_;
			NimStringV2* T71_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T72_;
			T67_ = (NI)0;
			T67_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			if (!!(((*(*t_p1)._kind_6.sons.p->data[(NI)(T67_ - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85)))) goto LA68_;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T70_ = (NimStringV2*)0;
			T70_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			addIndent__cgen_u315(p_p0, T70_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T71_ = (NimStringV2*)0;
			T71_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			colontmpD__9 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T72_[0] = colontmpD__9;
			colontmpD__10 = percent___cgen_u17855(T72_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&(*T71_)), colontmpD__10.len + 0);
appendString((&(*T71_)), colontmpD__10);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
		}
LA68_: ;
		T73_ = (NI)0;
		T73_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		lend_1 = genCaseSecondPass__cgen_u17654(p_p0, t_p1, d_p3, labId_1, (NI)(T73_ - ((NI)1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		fixLabel__cgen_u14067(p_p0, lend_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(lend_1);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u5506(branches_1);
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA9_;
LA11_: ;
	{
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym2577__1;
			NimStringV2 lendX60gensym2577__1;
			NimStringV2 resX60gensym2579__1;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T82_;
			NI labIdX60gensym2579__1;
			if (!(stringKind_p2 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29))) goto LA79_;
			nimZeroMem((void*)(&aX60gensym2577__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			lendX60gensym2577__1.len = 0; lendX60gensym2577__1.p = NIM_NIL;
			resX60gensym2579__1.len = 0; resX60gensym2579__1.p = NIM_NIL;
			T82_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], T82_, (&aX60gensym2577__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			labIdX60gensym2579__1 = (*p_p0).labels;
			{
				NI iX60gensym2579__1;
				NI colontmp__4;
				NI T84_;
				NI res_4;
				iX60gensym2579__1 = (NI)0;
				colontmp__4 = (NI)0;
				T84_ = (NI)0;
				T84_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				colontmp__4 = (NI)(T84_ - ((NI)1));
				res_4 = ((NI)1);
				{
					while (1) {
						if (!(res_4 <= colontmp__4)) goto LA86;
						iX60gensym2579__1 = ((NI) (res_4));
						(*p_p0).labels += ((NI)1);
						{
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw xX60gensym2582__1;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw yX60gensym2582__1;
							if (!((*(*t_p1)._kind_6.sons.p->data[iX60gensym2579__1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA89_;
							nimZeroMem((void*)(&xX60gensym2582__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							nimZeroMem((void*)(&yX60gensym2582__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							nimZeroMem((void*)(&xX60gensym2582__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							nimZeroMem((void*)(&yX60gensym2582__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							{
								NI iX60gensym2582__1;
								NI colontmp__5;
								NI T93_;
								NI i_5;
								iX60gensym2582__1 = (NI)0;
								colontmp__5 = (NI)0;
								T93_ = (NI)0;
								T93_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[iX60gensym2579__1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
								colontmp__5 = (NI)(T93_ - ((NI)1));
								i_5 = ((NI)0);
								{
									while (1) {
										if (!(i_5 < colontmp__5)) goto LA95;
										iX60gensym2582__1 = i_5;
										{
											NimStringV2 res_5;
											tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T101_;
											tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T102_;
											tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T103_;
											tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T104_;
											NimStringV2* T105_;
											NimStringV2* T106_;
											if (!((*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2579__1])._kind_6.sons.p->data[iX60gensym2582__1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA98_;
											res_5.len = 0; res_5.p = NIM_NIL;
											T101_ = 0;
											nimZeroMem((void*)(&T102_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
											initLocExpr__cgen_u14111(p_p0, (*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2579__1])._kind_6.sons.p->data[iX60gensym2582__1])._kind_6.sons.p->data[((NI)0)], T101_, (&T102_));
											if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
											eqsink___ast_u6293((&xX60gensym2582__1), T102_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
											T103_ = 0;
											nimZeroMem((void*)(&T104_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
											initLocExpr__cgen_u14111(p_p0, (*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2579__1])._kind_6.sons.p->data[iX60gensym2582__1])._kind_6.sons.p->data[((NI)1)], T103_, (&T104_));
											if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
											eqsink___ast_u6293((&yX60gensym2582__1), T104_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
											T105_ = (NimStringV2*)0;
											T105_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
											addIndent__cgen_u315(p_p0, T105_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
											T106_ = (NimStringV2*)0;
											T106_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
											res_5 = rawNewString(((NI)80));
											prepareAdd((&(*T106_)), res_5.len + 0);
appendString((&(*T106_)), res_5);
											{
												LA100_:;
											}
											{
												eqdestroy___system_u2691(res_5);
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
										}
										goto LA96_;
LA98_: ;
										{
											NimStringV2 res_6;
											NimStringV2 colontmpD__11;
											NimStringV2 colontmpD__12;
											NimStringV2 colontmpD__13;
											NimStringV2 colontmpD__14;
											NimStringV2 colontmpD__15;
											tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T111_;
											tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T112_;
											NimStringV2* T113_;
											NimStringV2* T114_;
											NimStringV2 T115_;
											res_6.len = 0; res_6.p = NIM_NIL;
											colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
											colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
											colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
											colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
											colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
											T111_ = 0;
											nimZeroMem((void*)(&T112_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
											initLocExpr__cgen_u14111(p_p0, (*(*t_p1)._kind_6.sons.p->data[iX60gensym2579__1])._kind_6.sons.p->data[iX60gensym2582__1], T111_, (&T112_));
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											eqsink___ast_u6293((&xX60gensym2582__1), T112_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											T113_ = (NimStringV2*)0;
											T113_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											addIndent__cgen_u315(p_p0, T113_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											T114_ = (NimStringV2*)0;
											T114_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											res_6 = rawNewString(((NI)80));
											prepareAdd((&res_6), 4);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3075);
											colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3076);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											cgFormatValue__cgen_u163((&res_6), colontmpD__11);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3077);
											colontmpD__12 = rdCharLoc__cgen_u12869(aX60gensym2577__1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											cgFormatValue__cgen_u163((&res_6), colontmpD__12);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											prepareAdd((&res_6), 2);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3078);
											colontmpD__13 = rdCharLoc__cgen_u12869(xX60gensym2582__1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											cgFormatValue__cgen_u163((&res_6), colontmpD__13);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											prepareAdd((&res_6), 8);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3079);
											T115_.len = 0; T115_.p = NIM_NIL;
											colontmpD__14 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											T115_ = rawNewString(colontmpD__14.len + 3);
appendString((&T115_), TM__MQdRN7fpbG7rPm4JpVVAhA_3080);
appendString((&T115_), colontmpD__14);
appendString((&T115_), TM__MQdRN7fpbG7rPm4JpVVAhA_3081);
											colontmpD__15 = T115_;
											cgFormatValue__cgen_u163((&res_6), colontmpD__15);
											if (NIM_UNLIKELY(*nimErr_)) goto LA110_;
											prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3082);
											{
												if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA118_;
												prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3083);
											}
LA118_: ;
											prepareAdd((&(*T114_)), res_6.len + 0);
appendString((&(*T114_)), res_6);
											{
												LA110_:;
											}
											{
												eqdestroy___system_u2691(colontmpD__15);
												eqdestroy___system_u2691(colontmpD__14);
												eqdestroy___system_u2691(colontmpD__13);
												eqdestroy___system_u2691(colontmpD__12);
												eqdestroy___system_u2691(colontmpD__11);
												eqdestroy___system_u2691(res_6);
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA91_;
										}
LA96_: ;
										i_5 += ((NI)1);
									} LA95: ;
								}
							}
							{
								LA91_:;
							}
							{
								oldNimErrFin91_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u6284(yX60gensym2582__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
								eqdestroy___ast_u6284(xX60gensym2582__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
								*nimErr_ = oldNimErrFin91_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						}
						goto LA87_;
LA89_: ;
						{
							NimStringV2 colontmpD__16;
							NimStringV2 colontmpD__17;
							NimStringV2* T125_;
							NimStringV2* T126_;
							tyArray__YgExxhfgKcesA5EOUj1MOA T127_;
							colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
							colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
							T125_ = (NimStringV2*)0;
							T125_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
							addIndent__cgen_u315(p_p0, T125_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
							T126_ = (NimStringV2*)0;
							T126_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
							colontmpD__16 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
							T127_[0] = colontmpD__16;
							colontmpD__17 = percent___cgen_u17855(T127_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
							prepareAdd((&(*T126_)), colontmpD__17.len + 0);
appendString((&(*T126_)), colontmpD__17);
							eqdestroy___system_u2691(colontmpD__17);
							eqdestroy___system_u2691(colontmpD__16);
						}
LA87_: ;
						res_4 += ((NI)1);
					} LA86: ;
				}
			}
			{
				NI T130_;
				NI T131_;
				NimStringV2 colontmpD__18;
				NimStringV2 colontmpD__19;
				NimStringV2 colontmpD__20;
				NimStringV2 colontmpD__21;
				NI gotoTargetX60gensym2579__1;
				NimStringV2* T135_;
				NimStringV2* T136_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T137_;
				NI T138_;
				NimStringV2* T139_;
				NimStringV2* T140_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T141_;
				T130_ = (NI)0;
				T130_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				T131_ = (NI)0;
				T131_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				if (!((NI)(T130_ - ((NI)1)) < (NI)(T131_ - ((NI)1)))) goto LA132_;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
				colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
				colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
				(*p_p0).labels += ((NI)1);
				gotoTargetX60gensym2579__1 = (*p_p0).labels;
				T135_ = (NimStringV2*)0;
				T135_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				addIndent__cgen_u315(p_p0, T135_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				T136_ = (NimStringV2*)0;
				T136_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				colontmpD__18 = rope__ropes_u15(((NI64) (gotoTargetX60gensym2579__1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				T137_[0] = colontmpD__18;
				colontmpD__19 = percent___cgen_u17855(T137_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				prepareAdd((&(*T136_)), colontmpD__19.len + 0);
appendString((&(*T136_)), colontmpD__19);
				T138_ = (NI)0;
				T138_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				resX60gensym2579__1 = genCaseSecondPass__cgen_u17654(p_p0, t_p1, d_p3, labIdX60gensym2579__1, (NI)(T138_ - ((NI)1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				T139_ = (NimStringV2*)0;
				T139_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				addIndent__cgen_u315(p_p0, T139_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				T140_ = (NimStringV2*)0;
				T140_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				colontmpD__20 = rope__ropes_u15(((NI64) (gotoTargetX60gensym2579__1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				T141_[0] = colontmpD__20;
				colontmpD__21 = percent___cgen_u17671(T141_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				prepareAdd((&(*T140_)), colontmpD__21.len + 0);
appendString((&(*T140_)), colontmpD__21);
				{
					LA134_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__21);
					eqdestroy___system_u2691(colontmpD__20);
					eqdestroy___system_u2691(colontmpD__19);
					eqdestroy___system_u2691(colontmpD__18);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			}
			goto LA128_;
LA132_: ;
			{
				NI T145_;
				T145_ = (NI)0;
				T145_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				resX60gensym2579__1 = genCaseSecondPass__cgen_u17654(p_p0, t_p1, d_p3, labIdX60gensym2579__1, (NI)(T145_ - ((NI)1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			}
LA128_: ;
			lendX60gensym2577__1 = resX60gensym2579__1;
			eqwasMoved___system_u2688((&resX60gensym2579__1));
			fixLabel__cgen_u14067(p_p0, lendX60gensym2577__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			{
				LA81_:;
			}
			{
				oldNimErrFin81_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(resX60gensym2579__1);
				eqdestroy___system_u2691(lendX60gensym2577__1);
				eqdestroy___ast_u6284(aX60gensym2577__1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin81_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA77_;
LA79_: ;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym2607__1;
			NimStringV2 lendX60gensym2607__1;
			NimStringV2 resX60gensym2609__1;
			tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T150_;
			NI labIdX60gensym2609__1;
			nimZeroMem((void*)(&aX60gensym2607__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			lendX60gensym2607__1.len = 0; lendX60gensym2607__1.p = NIM_NIL;
			resX60gensym2609__1.len = 0; resX60gensym2609__1.p = NIM_NIL;
			T150_ = 0;
			initLocExpr__cgen_u14111(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], T150_, (&aX60gensym2607__1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			labIdX60gensym2609__1 = (*p_p0).labels;
			{
				NI iX60gensym2609__1;
				NI colontmp__6;
				NI T152_;
				NI res_7;
				iX60gensym2609__1 = (NI)0;
				colontmp__6 = (NI)0;
				T152_ = (NI)0;
				T152_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
				colontmp__6 = (NI)(T152_ - ((NI)1));
				res_7 = ((NI)1);
				{
					while (1) {
						if (!(res_7 <= colontmp__6)) goto LA154;
						iX60gensym2609__1 = ((NI) (res_7));
						(*p_p0).labels += ((NI)1);
						{
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw xX60gensym2612__1;
							tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw yX60gensym2612__1;
							if (!((*(*t_p1)._kind_6.sons.p->data[iX60gensym2609__1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA157_;
							nimZeroMem((void*)(&xX60gensym2612__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							nimZeroMem((void*)(&yX60gensym2612__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							nimZeroMem((void*)(&xX60gensym2612__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							nimZeroMem((void*)(&yX60gensym2612__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
							{
								NI iX60gensym2612__1;
								NI colontmp__7;
								NI T161_;
								NI i_6;
								iX60gensym2612__1 = (NI)0;
								colontmp__7 = (NI)0;
								T161_ = (NI)0;
								T161_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[iX60gensym2609__1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA159_;
								colontmp__7 = (NI)(T161_ - ((NI)1));
								i_6 = ((NI)0);
								{
									while (1) {
										if (!(i_6 < colontmp__7)) goto LA163;
										iX60gensym2612__1 = i_6;
										{
											NimStringV2 res_8;
											tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T169_;
											tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T170_;
											tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T171_;
											tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T172_;
											NimStringV2* T173_;
											NimStringV2* T174_;
											if (!((*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2609__1])._kind_6.sons.p->data[iX60gensym2612__1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA166_;
											res_8.len = 0; res_8.p = NIM_NIL;
											T169_ = 0;
											nimZeroMem((void*)(&T170_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
											initLocExpr__cgen_u14111(p_p0, (*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2609__1])._kind_6.sons.p->data[iX60gensym2612__1])._kind_6.sons.p->data[((NI)0)], T169_, (&T170_));
											if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
											eqsink___ast_u6293((&xX60gensym2612__1), T170_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
											T171_ = 0;
											nimZeroMem((void*)(&T172_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
											initLocExpr__cgen_u14111(p_p0, (*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2609__1])._kind_6.sons.p->data[iX60gensym2612__1])._kind_6.sons.p->data[((NI)1)], T171_, (&T172_));
											if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
											eqsink___ast_u6293((&yX60gensym2612__1), T172_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
											T173_ = (NimStringV2*)0;
											T173_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
											addIndent__cgen_u315(p_p0, T173_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
											T174_ = (NimStringV2*)0;
											T174_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA168_;
											res_8 = rawNewString(((NI)80));
											prepareAdd((&(*T174_)), res_8.len + 0);
appendString((&(*T174_)), res_8);
											{
												LA168_:;
											}
											{
												eqdestroy___system_u2691(res_8);
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA159_;
										}
										goto LA164_;
LA166_: ;
										{
											NimStringV2 res_9;
											NimStringV2 colontmpD__22;
											NimStringV2 colontmpD__23;
											NimStringV2 colontmpD__24;
											NimStringV2 colontmpD__25;
											NimStringV2 colontmpD__26;
											tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T179_;
											tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T180_;
											NimStringV2* T181_;
											NimStringV2* T182_;
											NimStringV2 T183_;
											res_9.len = 0; res_9.p = NIM_NIL;
											colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
											colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
											colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
											colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
											colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
											T179_ = 0;
											nimZeroMem((void*)(&T180_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
											initLocExpr__cgen_u14111(p_p0, (*(*t_p1)._kind_6.sons.p->data[iX60gensym2609__1])._kind_6.sons.p->data[iX60gensym2612__1], T179_, (&T180_));
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											eqsink___ast_u6293((&xX60gensym2612__1), T180_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											T181_ = (NimStringV2*)0;
											T181_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											addIndent__cgen_u315(p_p0, T181_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											T182_ = (NimStringV2*)0;
											T182_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											res_9 = rawNewString(((NI)80));
											prepareAdd((&res_9), 4);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3084);
											colontmpD__22 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3085);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											cgFormatValue__cgen_u163((&res_9), colontmpD__22);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3086);
											colontmpD__23 = rdCharLoc__cgen_u12869(aX60gensym2607__1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											cgFormatValue__cgen_u163((&res_9), colontmpD__23);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											prepareAdd((&res_9), 2);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3087);
											colontmpD__24 = rdCharLoc__cgen_u12869(xX60gensym2612__1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											cgFormatValue__cgen_u163((&res_9), colontmpD__24);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											prepareAdd((&res_9), 8);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3088);
											T183_.len = 0; T183_.p = NIM_NIL;
											colontmpD__25 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											T183_ = rawNewString(colontmpD__25.len + 3);
appendString((&T183_), TM__MQdRN7fpbG7rPm4JpVVAhA_3089);
appendString((&T183_), colontmpD__25);
appendString((&T183_), TM__MQdRN7fpbG7rPm4JpVVAhA_3090);
											colontmpD__26 = T183_;
											cgFormatValue__cgen_u163((&res_9), colontmpD__26);
											if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
											prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3091);
											{
												if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA186_;
												prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3092);
											}
LA186_: ;
											prepareAdd((&(*T182_)), res_9.len + 0);
appendString((&(*T182_)), res_9);
											{
												LA178_:;
											}
											{
												eqdestroy___system_u2691(colontmpD__26);
												eqdestroy___system_u2691(colontmpD__25);
												eqdestroy___system_u2691(colontmpD__24);
												eqdestroy___system_u2691(colontmpD__23);
												eqdestroy___system_u2691(colontmpD__22);
												eqdestroy___system_u2691(res_9);
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA159_;
										}
LA164_: ;
										i_6 += ((NI)1);
									} LA163: ;
								}
							}
							{
								LA159_:;
							}
							{
								oldNimErrFin159_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u6284(yX60gensym2612__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
								eqdestroy___ast_u6284(xX60gensym2612__1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
								*nimErr_ = oldNimErrFin159_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
						}
						goto LA155_;
LA157_: ;
						{
							NimStringV2 colontmpD__27;
							NimStringV2 colontmpD__28;
							NimStringV2* T193_;
							NimStringV2* T194_;
							tyArray__YgExxhfgKcesA5EOUj1MOA T195_;
							colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
							colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
							T193_ = (NimStringV2*)0;
							T193_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							addIndent__cgen_u315(p_p0, T193_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							T194_ = (NimStringV2*)0;
							T194_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							colontmpD__27 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							T195_[0] = colontmpD__27;
							colontmpD__28 = percent___cgen_u17855(T195_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							prepareAdd((&(*T194_)), colontmpD__28.len + 0);
appendString((&(*T194_)), colontmpD__28);
							eqdestroy___system_u2691(colontmpD__28);
							eqdestroy___system_u2691(colontmpD__27);
						}
LA155_: ;
						res_7 += ((NI)1);
					} LA154: ;
				}
			}
			{
				NI T198_;
				NI T199_;
				NimStringV2 colontmpD__29;
				NimStringV2 colontmpD__30;
				NimStringV2 colontmpD__31;
				NimStringV2 colontmpD__32;
				NI gotoTargetX60gensym2609__1;
				NimStringV2* T203_;
				NimStringV2* T204_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T205_;
				NI T206_;
				NimStringV2* T207_;
				NimStringV2* T208_;
				tyArray__YgExxhfgKcesA5EOUj1MOA T209_;
				T198_ = (NI)0;
				T198_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
				T199_ = (NI)0;
				T199_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
				if (!((NI)(T198_ - ((NI)1)) < (NI)(T199_ - ((NI)1)))) goto LA200_;
				colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
				colontmpD__30.len = 0; colontmpD__30.p = NIM_NIL;
				colontmpD__31.len = 0; colontmpD__31.p = NIM_NIL;
				colontmpD__32.len = 0; colontmpD__32.p = NIM_NIL;
				(*p_p0).labels += ((NI)1);
				gotoTargetX60gensym2609__1 = (*p_p0).labels;
				T203_ = (NimStringV2*)0;
				T203_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				addIndent__cgen_u315(p_p0, T203_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				T204_ = (NimStringV2*)0;
				T204_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				colontmpD__29 = rope__ropes_u15(((NI64) (gotoTargetX60gensym2609__1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				T205_[0] = colontmpD__29;
				colontmpD__30 = percent___cgen_u17855(T205_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				prepareAdd((&(*T204_)), colontmpD__30.len + 0);
appendString((&(*T204_)), colontmpD__30);
				T206_ = (NI)0;
				T206_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				resX60gensym2609__1 = genCaseSecondPass__cgen_u17654(p_p0, t_p1, d_p3, labIdX60gensym2609__1, (NI)(T206_ - ((NI)1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				T207_ = (NimStringV2*)0;
				T207_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				addIndent__cgen_u315(p_p0, T207_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				T208_ = (NimStringV2*)0;
				T208_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				colontmpD__31 = rope__ropes_u15(((NI64) (gotoTargetX60gensym2609__1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				T209_[0] = colontmpD__31;
				colontmpD__32 = percent___cgen_u17671(T209_, 1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
				prepareAdd((&(*T208_)), colontmpD__32.len + 0);
appendString((&(*T208_)), colontmpD__32);
				{
					LA202_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__32);
					eqdestroy___system_u2691(colontmpD__31);
					eqdestroy___system_u2691(colontmpD__30);
					eqdestroy___system_u2691(colontmpD__29);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			}
			goto LA196_;
LA200_: ;
			{
				NI T213_;
				T213_ = (NI)0;
				T213_ = len__ast_u3190(t_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
				resX60gensym2609__1 = genCaseSecondPass__cgen_u17654(p_p0, t_p1, d_p3, labIdX60gensym2609__1, (NI)(T213_ - ((NI)1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			}
LA196_: ;
			lendX60gensym2607__1 = resX60gensym2609__1;
			eqwasMoved___system_u2688((&resX60gensym2609__1));
			fixLabel__cgen_u14067(p_p0, lendX60gensym2607__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			{
				LA149_:;
			}
			{
				oldNimErrFin149_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(resX60gensym2609__1);
				eqdestroy___system_u2691(lendX60gensym2607__1);
				eqdestroy___ast_u6284(aX60gensym2607__1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin149_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA77_: ;
	}
LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoForCase__cgen_u16948)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* caseStmt_p1) {
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(caseStmt_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)1);
		{
			while (1) {
				NimStringV2 res_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
				NimStringV2* T5_;
				NimStringV2* T6_;
				NI T11_;
				if (!(i_2 < colontmp_)) goto LA3;
				res_1.len = 0; res_1.p = NIM_NIL;
				it_1 = NIM_NIL;
				colontmpD_ = NIM_NIL;
				i_1 = i_2;
				T5_ = (NimStringV2*)0;
				T5_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				addIndent__cgen_u315(p_p0, T5_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				T6_ = (NimStringV2*)0;
				T6_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				res_1 = rawNewString(((NI)80));
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3112);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA9_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3113);
				}
LA9_: ;
				prepareAdd((&(*T6_)), res_1.len + 0);
appendString((&(*T6_)), res_1);
				T11_ = (NI)0;
				T11_ = startBlockInternal__cgen_u15729(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				eqcopy___ast_u3255(&it_1, (*caseStmt_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				{
					NI j_1;
					NI colontmp__2;
					NI T13_;
					NI i_3;
					j_1 = (NI)0;
					colontmp__2 = (NI)0;
					T13_ = (NI)0;
					T13_ = len__ast_u3190(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
					colontmp__2 = (NI)(T13_ - ((NI)1));
					i_3 = ((NI)0);
					{
						while (1) {
							NimStringV2 colontmpD__2;
							NimStringV2 colontmpD__3;
							tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg val_1;
							NimStringV2* T21_;
							NimStringV2* T22_;
							tyArray__YgExxhfgKcesA5EOUj1MOA T23_;
							if (!(i_3 < colontmp__2)) goto LA15;
							colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
							colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
							j_1 = i_3;
							{
								if (!((*(*it_1)._kind_6.sons.p->data[j_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA19_;
								liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_3114, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_3115, NIM_FALSE, NIM_FALSE);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								eqdestroy___system_u2691(colontmpD__3);
								eqdestroy___system_u2691(colontmpD__2);
								eqdestroy___ast_u3252(colontmpD_);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								eqdestroy___ast_u3252(it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								eqdestroy___system_u2691(res_1);
								goto BeforeRet_;
							}
LA19_: ;
							val_1 = getOrdValue__types_u167((*it_1)._kind_6.sons.p->data[j_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T21_ = (NimStringV2*)0;
							T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							addIndent__cgen_u315(p_p0, T21_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T22_ = (NimStringV2*)0;
							T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							colontmpD__2 = rope__cgen_u9217(val_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							T23_[0] = colontmpD__2;
							colontmpD__3 = percent___cgen_u16980(T23_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							prepareAdd((&(*T22_)), colontmpD__3.len + 0);
appendString((&(*T22_)), colontmpD__3);
							i_3 += ((NI)1);
							{
								LA16_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__3);
								eqdestroy___system_u2691(colontmpD__2);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						} LA15: ;
					}
				}
				colontmpD_ = lastSon__ast_u5208(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				genStmts__cgen_u14081(p_p0, colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				endBlock__cgen_u15767(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___system_u2691(res_1);
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, branchHasTooBigRange__cgen_u18021)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p0) {
	NIM_BOOL result;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
		it_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(b_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i_1 = i_2;
					eqcopy___ast_u3255(&it_1, (*b_p0)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					{
						NIM_BOOL T8_;
						T8_ = (NIM_BOOL)0;
						T8_ = ((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44));
						if (!(T8_)) goto LA9_;
						T8_ = (IL64(256) < (NI64)((*(*it_1)._kind_6.sons.p->data[((NI)1)])._kind_1.intVal - (*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_1.intVal));
LA9_: ;
						if (!T8_) goto LA10_;
						result = NIM_TRUE;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA10_: ;
					i_2 += ((NI)1);
				} LA5: ;
			}
		}
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, ifSwitchSplitPoint__cgen_u18029)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((NI)0);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)1);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* stmtBlock_1;
				if (!(i_2 < colontmp_)) goto LA3;
				branch_1 = NIM_NIL;
				stmtBlock_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&branch_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				stmtBlock_1 = lastSon__ast_u5208(branch_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					NIM_BOOL T6_;
					T6_ = (NIM_BOOL)0;
					T6_ = stmtsContainPragma__ccgutils_u37(stmtBlock_1, ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)207));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T6_) goto LA7_;
					result = i_1;
				}
				goto LA4_;
LA7_: ;
				{
					if (!!(((CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)0)))&15U)))!=0))) goto LA10_;
					{
						NIM_BOOL T14_;
						T14_ = (NIM_BOOL)0;
						T14_ = ((*branch_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85));
						if (!(T14_)) goto LA15_;
						T14_ = branchHasTooBigRange__cgen_u18021(branch_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA15_: ;
						if (!T14_) goto LA16_;
						result = i_1;
					}
LA16_: ;
				}
				goto LA4_;
LA10_: ;
LA4_: ;
				i_2 += ((NI)1);
				eqdestroy___ast_u3252(stmtBlock_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u3252(branch_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genOrdinalCase__cgen_u18088)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 lend_1;
	NI splitPoint_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	NimStringV2 T3_;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin88_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	lend_1.len = 0; lend_1.p = NIM_NIL;
	splitPoint_1 = ifSwitchSplitPoint__cgen_u18029(p_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_.len = 0; T3_.p = NIM_NIL;
	{
		NimStringV2 resX60gensym2660__1;
		NI labIdX60gensym2660__1;
		if (!(((NI)0) < splitPoint_1)) goto LA6_;
		resX60gensym2660__1.len = 0; resX60gensym2660__1.p = NIM_NIL;
		labIdX60gensym2660__1 = (*p_p0).labels;
		{
			NI iX60gensym2660__1;
			NI res_1;
			iX60gensym2660__1 = (NI)0;
			res_1 = ((NI)1);
			{
				while (1) {
					if (!(res_1 <= splitPoint_1)) goto LA11;
					iX60gensym2660__1 = ((NI) (res_1));
					(*p_p0).labels += ((NI)1);
					{
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw xX60gensym2663__1;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw yX60gensym2663__1;
						if (!((*(*n_p1)._kind_6.sons.p->data[iX60gensym2660__1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA14_;
						nimZeroMem((void*)(&xX60gensym2663__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						nimZeroMem((void*)(&yX60gensym2663__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						nimZeroMem((void*)(&xX60gensym2663__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						nimZeroMem((void*)(&yX60gensym2663__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						{
							NI iX60gensym2663__1;
							NI colontmp_;
							NI T18_;
							NI i_1;
							iX60gensym2663__1 = (NI)0;
							colontmp_ = (NI)0;
							T18_ = (NI)0;
							T18_ = len__ast_u3190((*n_p1)._kind_6.sons.p->data[iX60gensym2660__1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							colontmp_ = (NI)(T18_ - ((NI)1));
							i_1 = ((NI)0);
							{
								while (1) {
									if (!(i_1 < colontmp_)) goto LA20;
									iX60gensym2663__1 = i_1;
									{
										NimStringV2 res_2;
										NimStringV2 colontmpD_;
										NimStringV2 colontmpD__2;
										NimStringV2 colontmpD__3;
										NimStringV2 colontmpD__4;
										NimStringV2 colontmpD__5;
										NimStringV2 colontmpD__6;
										tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T26_;
										tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T27_;
										tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T28_;
										tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T29_;
										NimStringV2* T30_;
										NimStringV2* T31_;
										NimStringV2 T32_;
										if (!((*(*(*n_p1)._kind_6.sons.p->data[iX60gensym2660__1])._kind_6.sons.p->data[iX60gensym2663__1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA23_;
										res_2.len = 0; res_2.p = NIM_NIL;
										colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
										colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
										colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
										colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
										colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
										colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
										T26_ = 0;
										nimZeroMem((void*)(&T27_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
										initLocExpr__cgen_u14111(p_p0, (*(*(*n_p1)._kind_6.sons.p->data[iX60gensym2660__1])._kind_6.sons.p->data[iX60gensym2663__1])._kind_6.sons.p->data[((NI)0)], T26_, (&T27_));
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										eqsink___ast_u6293((&xX60gensym2663__1), T27_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										T28_ = 0;
										nimZeroMem((void*)(&T29_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
										initLocExpr__cgen_u14111(p_p0, (*(*(*n_p1)._kind_6.sons.p->data[iX60gensym2660__1])._kind_6.sons.p->data[iX60gensym2663__1])._kind_6.sons.p->data[((NI)1)], T28_, (&T29_));
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										eqsink___ast_u6293((&yX60gensym2663__1), T29_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										T30_ = (NimStringV2*)0;
										T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										addIndent__cgen_u315(p_p0, T30_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										T31_ = (NimStringV2*)0;
										T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										res_2 = rawNewString(((NI)80));
										prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3116);
										colontmpD_ = rdCharLoc__cgen_u12869(a_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										cgFormatValue__cgen_u163((&res_2), colontmpD_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3117);
										colontmpD__2 = rdCharLoc__cgen_u12869(xX60gensym2663__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__2);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3118);
										colontmpD__3 = rdCharLoc__cgen_u12869(a_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__3);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3119);
										colontmpD__4 = rdCharLoc__cgen_u12869(yX60gensym2663__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__4);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										prepareAdd((&res_2), 7);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3120);
										T32_.len = 0; T32_.p = NIM_NIL;
										colontmpD__5 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										T32_ = rawNewString(colontmpD__5.len + 3);
appendString((&T32_), TM__MQdRN7fpbG7rPm4JpVVAhA_3121);
appendString((&T32_), colontmpD__5);
appendString((&T32_), TM__MQdRN7fpbG7rPm4JpVVAhA_3122);
										colontmpD__6 = T32_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__6);
										if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
										prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3123);
										{
											if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA35_;
											prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3124);
										}
LA35_: ;
										prepareAdd((&(*T31_)), res_2.len + 0);
appendString((&(*T31_)), res_2);
										{
											LA25_:;
										}
										{
											eqdestroy___system_u2691(colontmpD__6);
											eqdestroy___system_u2691(colontmpD__5);
											eqdestroy___system_u2691(colontmpD__4);
											eqdestroy___system_u2691(colontmpD__3);
											eqdestroy___system_u2691(colontmpD__2);
											eqdestroy___system_u2691(colontmpD_);
											eqdestroy___system_u2691(res_2);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
									}
									goto LA21_;
LA23_: ;
									{
										NimStringV2 res_3;
										NimStringV2 colontmpD__7;
										NimStringV2 colontmpD__8;
										NimStringV2 colontmpD__9;
										NimStringV2 colontmpD__10;
										tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T41_;
										tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T42_;
										NimStringV2* T43_;
										NimStringV2* T44_;
										NimStringV2 T45_;
										res_3.len = 0; res_3.p = NIM_NIL;
										colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
										colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
										colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
										colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
										T41_ = 0;
										nimZeroMem((void*)(&T42_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
										initLocExpr__cgen_u14111(p_p0, (*(*n_p1)._kind_6.sons.p->data[iX60gensym2660__1])._kind_6.sons.p->data[iX60gensym2663__1], T41_, (&T42_));
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										eqsink___ast_u6293((&xX60gensym2663__1), T42_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										T43_ = (NimStringV2*)0;
										T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										addIndent__cgen_u315(p_p0, T43_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										T44_ = (NimStringV2*)0;
										T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										res_3 = rawNewString(((NI)80));
										prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3125);
										colontmpD__7 = rdCharLoc__cgen_u12869(a_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										cgFormatValue__cgen_u163((&res_3), colontmpD__7);
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3126);
										colontmpD__8 = rdCharLoc__cgen_u12869(xX60gensym2663__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										cgFormatValue__cgen_u163((&res_3), colontmpD__8);
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										prepareAdd((&res_3), 7);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3127);
										T45_.len = 0; T45_.p = NIM_NIL;
										colontmpD__9 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										T45_ = rawNewString(colontmpD__9.len + 3);
appendString((&T45_), TM__MQdRN7fpbG7rPm4JpVVAhA_3128);
appendString((&T45_), colontmpD__9);
appendString((&T45_), TM__MQdRN7fpbG7rPm4JpVVAhA_3129);
										colontmpD__10 = T45_;
										cgFormatValue__cgen_u163((&res_3), colontmpD__10);
										if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
										prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3130);
										{
											if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA48_;
											prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3131);
										}
LA48_: ;
										prepareAdd((&(*T44_)), res_3.len + 0);
appendString((&(*T44_)), res_3);
										{
											LA40_:;
										}
										{
											eqdestroy___system_u2691(colontmpD__10);
											eqdestroy___system_u2691(colontmpD__9);
											eqdestroy___system_u2691(colontmpD__8);
											eqdestroy___system_u2691(colontmpD__7);
											eqdestroy___system_u2691(res_3);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
									}
LA21_: ;
									i_1 += ((NI)1);
								} LA20: ;
							}
						}
						{
							LA16_:;
						}
						{
							oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u6284(yX60gensym2663__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
							eqdestroy___ast_u6284(xX60gensym2663__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
							*nimErr_ = oldNimErrFin16_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					}
					goto LA12_;
LA14_: ;
					{
						NimStringV2 colontmpD__11;
						NimStringV2 colontmpD__12;
						NimStringV2* T55_;
						NimStringV2* T56_;
						tyArray__YgExxhfgKcesA5EOUj1MOA T57_;
						colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
						colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
						T55_ = (NimStringV2*)0;
						T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						addIndent__cgen_u315(p_p0, T55_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						T56_ = (NimStringV2*)0;
						T56_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						colontmpD__11 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						T57_[0] = colontmpD__11;
						colontmpD__12 = percent___cgen_u17855(T57_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						prepareAdd((&(*T56_)), colontmpD__12.len + 0);
appendString((&(*T56_)), colontmpD__12);
						eqdestroy___system_u2691(colontmpD__12);
						eqdestroy___system_u2691(colontmpD__11);
					}
LA12_: ;
					res_1 += ((NI)1);
				} LA11: ;
			}
		}
		{
			NI T60_;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NI gotoTargetX60gensym2660__1;
			NimStringV2* T64_;
			NimStringV2* T65_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T66_;
			NimStringV2* T67_;
			NimStringV2* T68_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T69_;
			T60_ = (NI)0;
			T60_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			if (!(splitPoint_1 < (NI)(T60_ - ((NI)1)))) goto LA61_;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			(*p_p0).labels += ((NI)1);
			gotoTargetX60gensym2660__1 = (*p_p0).labels;
			T64_ = (NimStringV2*)0;
			T64_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			addIndent__cgen_u315(p_p0, T64_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			T65_ = (NimStringV2*)0;
			T65_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			colontmpD__13 = rope__ropes_u15(((NI64) (gotoTargetX60gensym2660__1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			T66_[0] = colontmpD__13;
			colontmpD__14 = percent___cgen_u17855(T66_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			prepareAdd((&(*T65_)), colontmpD__14.len + 0);
appendString((&(*T65_)), colontmpD__14);
			resX60gensym2660__1 = genCaseSecondPass__cgen_u17654(p_p0, n_p1, d_p2, labIdX60gensym2660__1, splitPoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			T67_ = (NimStringV2*)0;
			T67_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			addIndent__cgen_u315(p_p0, T67_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			T68_ = (NimStringV2*)0;
			T68_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			colontmpD__15 = rope__ropes_u15(((NI64) (gotoTargetX60gensym2660__1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			T69_[0] = colontmpD__15;
			colontmpD__16 = percent___cgen_u17671(T69_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			prepareAdd((&(*T68_)), colontmpD__16.len + 0);
appendString((&(*T68_)), colontmpD__16);
			{
				LA63_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
		goto LA58_;
LA61_: ;
		{
			resX60gensym2660__1 = genCaseSecondPass__cgen_u17654(p_p0, n_p1, d_p2, labIdX60gensym2660__1, splitPoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA58_: ;
		lend_1 = resX60gensym2660__1;
		eqwasMoved___system_u2688((&resX60gensym2660__1));
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(resX60gensym2660__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA6_: ;
	{
		lend_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3132;
	}
LA4_: ;
	{
		NI T78_;
		NimStringV2 colontmpD__17;
		NimStringV2 colontmpD__18;
		NimStringV2 colontmpD__19;
		NimStringV2* T82_;
		NimStringV2* T83_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T84_;
		NIM_BOOL hasDefault_1;
		NimStringV2* T125_;
		NimStringV2* T126_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T127_;
		T78_ = (NI)0;
		T78_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((NI)(splitPoint_1 + ((NI)1)) < T78_)) goto LA79_;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		T82_ = (NimStringV2*)0;
		T82_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		addIndent__cgen_u315(p_p0, T82_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		T83_ = (NimStringV2*)0;
		T83_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		colontmpD__17 = rdCharLoc__cgen_u12869(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		T84_[0] = colontmpD__17;
		colontmpD__18 = percent___cgen_u16453(T84_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		prepareAdd((&(*T83_)), colontmpD__18.len + 0);
appendString((&(*T83_)), colontmpD__18);
		hasDefault_1 = NIM_FALSE;
		{
			NI i_2;
			NI colontmp__2;
			NI colontmp__3;
			NI i_3;
			i_2 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__3 = (NI)0;
			colontmp__2 = (NI)(splitPoint_1 + ((NI)1));
			colontmp__3 = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
			i_3 = colontmp__2;
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* branch_1;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__20;
					NimStringV2 colontmpD__21;
					NimStringV2* T103_;
					NimStringV2* T104_;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T105_;
					if (!(i_3 < colontmp__3)) goto LA87;
					branch_1 = NIM_NIL;
					colontmpD__20 = NIM_NIL;
					colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
					i_2 = i_3;
					{
						NIM_BOOL T91_;
						T91_ = (NIM_BOOL)0;
						T91_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1));
						if (!(T91_)) goto LA92_;
						T91_ = isEmptyType__ast_u7234((*n_p1).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
LA92_: ;
						if (!T91_) goto LA93_;
						(*d_p2).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0);
					}
LA93_: ;
					eqcopy___ast_u3255(&branch_1, (*n_p1)._kind_6.sons.p->data[i_2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					{
						if (!((*branch_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA97_;
						genCaseRange__cgen_u9543(p_p0, branch_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					}
					goto LA95_;
LA97_: ;
					{
						NimStringV2 colontmpD__22;
						NimStringV2* T100_;
						NimStringV2* T101_;
						tyArray__TonP9cxJgj8gXu71dWIyNlA T102_;
						colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
						T100_ = (NimStringV2*)0;
						T100_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
						addIndent__cgen_u315(p_p0, T100_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
						T101_ = (NimStringV2*)0;
						T101_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
						colontmpD__22 = percent___cgen_u9596(T102_, 0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
						prepareAdd((&(*T101_)), colontmpD__22.len + 0);
appendString((&(*T101_)), colontmpD__22);
						hasDefault_1 = NIM_TRUE;
						eqdestroy___system_u2691(colontmpD__22);
					}
LA95_: ;
					colontmpD__20 = lastSon__ast_u5208(branch_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					exprBlock__cgen_u16234(p_p0, colontmpD__20, d_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					T103_ = (NimStringV2*)0;
					T103_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					addIndent__cgen_u315(p_p0, T103_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					T104_ = (NimStringV2*)0;
					T104_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					colontmpD__21 = percent___cgen_u9601(T105_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					prepareAdd((&(*T104_)), colontmpD__21.len + 0);
appendString((&(*T104_)), colontmpD__21);
					i_3 += ((NI)1);
					{
						LA88_:;
					}
					{
						oldNimErrFin88_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__21);
						eqdestroy___ast_u3252(colontmpD__20);
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						eqdestroy___ast_u3252(branch_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
						*nimErr_ = oldNimErrFin88_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				} LA87: ;
			}
		}
		{
			if (!!(hasDefault_1)) goto LA110_;
			{
				NimStringV2 colontmpD__23;
				NimStringV2* T116_;
				NimStringV2* T117_;
				tyArray__TonP9cxJgj8gXu71dWIyNlA T118_;
				if (!((CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)8)))&15U)))!=0)) goto LA114_;
				colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
				T116_ = (NimStringV2*)0;
				T116_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				addIndent__cgen_u315(p_p0, T116_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				T117_ = (NimStringV2*)0;
				T117_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				colontmpD__23 = percent___cgen_u18204(T118_, 0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				prepareAdd((&(*T117_)), colontmpD__23.len + 0);
appendString((&(*T117_)), colontmpD__23);
				eqdestroy___system_u2691(colontmpD__23);
			}
			goto LA112_;
LA114_: ;
			{
				NimStringV2 colontmpD__24;
				NimStringV2* T122_;
				NimStringV2* T123_;
				tyArray__TonP9cxJgj8gXu71dWIyNlA T124_;
				if (!((CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)3)))&15U)))!=0)) goto LA120_;
				colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
				T122_ = (NimStringV2*)0;
				T122_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				addIndent__cgen_u315(p_p0, T122_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				T123_ = (NimStringV2*)0;
				T123_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				colontmpD__24 = percent___cgen_u18213(T124_, 0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
				prepareAdd((&(*T123_)), colontmpD__24.len + 0);
appendString((&(*T123_)), colontmpD__24);
				eqdestroy___system_u2691(colontmpD__24);
			}
			goto LA112_;
LA120_: ;
LA112_: ;
		}
LA110_: ;
		T125_ = (NimStringV2*)0;
		T125_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		addIndent__cgen_u315(p_p0, T125_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		T126_ = (NimStringV2*)0;
		T126_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		colontmpD__19 = percent___cgen_u9681(T127_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA81_;
		prepareAdd((&(*T126_)), colontmpD__19.len + 0);
appendString((&(*T126_)), colontmpD__19);
		{
			LA81_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___system_u2691(colontmpD__17);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA79_: ;
	{
		if (!!((lend_1.len == 0))) goto LA132_;
		fixLabel__cgen_u14067(p_p0, lend_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA132_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(lend_1);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genCase__cgen_u18222)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL oldNimErrFin23_;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	genLineDir__cgen_u418(p_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T9_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = isEmptyType__ast_u7234((*t_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !(T5_);
		if (!(T4_)) goto LA6_;
		T4_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
LA6_: ;
		if (!T4_) goto LA7_;
		nimZeroMem((void*)(&T9_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*t_p1).typField, NIM_FALSE, (&T9_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&(*d_p2)), T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	colontmpD_ = skipTypes__ast_u5379((*(*t_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*colontmpD_).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		genStringCase__cgen_u17761(p_p0, t_p1, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28), d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	{
		genStringCase__cgen_u17761(p_p0, t_p1, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29), d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw aX60gensym2708__1;
		NimStringV2 lendX60gensym2708__1;
		NimStringV2 resX60gensym2710__1;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T14_;
		NI labIdX60gensym2710__1;
		nimZeroMem((void*)(&aX60gensym2708__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		lendX60gensym2708__1.len = 0; lendX60gensym2708__1.p = NIM_NIL;
		resX60gensym2710__1.len = 0; resX60gensym2710__1.p = NIM_NIL;
		T14_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], T14_, (&aX60gensym2708__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		labIdX60gensym2710__1 = (*p_p0).labels;
		{
			NI iX60gensym2710__1;
			NI colontmp_;
			NI T16_;
			NI res_1;
			iX60gensym2710__1 = (NI)0;
			colontmp_ = (NI)0;
			T16_ = (NI)0;
			T16_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			colontmp_ = (NI)(T16_ - ((NI)1));
			res_1 = ((NI)1);
			{
				while (1) {
					if (!(res_1 <= colontmp_)) goto LA18;
					iX60gensym2710__1 = ((NI) (res_1));
					(*p_p0).labels += ((NI)1);
					{
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw xX60gensym2713__1;
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw yX60gensym2713__1;
						if (!((*(*t_p1)._kind_6.sons.p->data[iX60gensym2710__1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)85))) goto LA21_;
						nimZeroMem((void*)(&xX60gensym2713__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						nimZeroMem((void*)(&yX60gensym2713__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						nimZeroMem((void*)(&xX60gensym2713__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						nimZeroMem((void*)(&yX60gensym2713__1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						{
							NI iX60gensym2713__1;
							NI colontmp__2;
							NI T25_;
							NI i_1;
							iX60gensym2713__1 = (NI)0;
							colontmp__2 = (NI)0;
							T25_ = (NI)0;
							T25_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[iX60gensym2710__1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
							colontmp__2 = (NI)(T25_ - ((NI)1));
							i_1 = ((NI)0);
							{
								while (1) {
									if (!(i_1 < colontmp__2)) goto LA27;
									iX60gensym2713__1 = i_1;
									{
										NimStringV2 res_2;
										NimStringV2 colontmpD__2;
										NimStringV2 colontmpD__3;
										NimStringV2 colontmpD__4;
										NimStringV2 colontmpD__5;
										NimStringV2 colontmpD__6;
										NimStringV2 colontmpD__7;
										tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T33_;
										tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T34_;
										tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T35_;
										tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T36_;
										NimStringV2* T37_;
										NimStringV2* T38_;
										NimStringV2 T39_;
										if (!((*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2710__1])._kind_6.sons.p->data[iX60gensym2713__1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44))) goto LA30_;
										res_2.len = 0; res_2.p = NIM_NIL;
										colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
										colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
										colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
										colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
										colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
										colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
										T33_ = 0;
										nimZeroMem((void*)(&T34_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
										initLocExpr__cgen_u14111(p_p0, (*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2710__1])._kind_6.sons.p->data[iX60gensym2713__1])._kind_6.sons.p->data[((NI)0)], T33_, (&T34_));
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										eqsink___ast_u6293((&xX60gensym2713__1), T34_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										T35_ = 0;
										nimZeroMem((void*)(&T36_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
										initLocExpr__cgen_u14111(p_p0, (*(*(*t_p1)._kind_6.sons.p->data[iX60gensym2710__1])._kind_6.sons.p->data[iX60gensym2713__1])._kind_6.sons.p->data[((NI)1)], T35_, (&T36_));
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										eqsink___ast_u6293((&yX60gensym2713__1), T36_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										T37_ = (NimStringV2*)0;
										T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										addIndent__cgen_u315(p_p0, T37_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										T38_ = (NimStringV2*)0;
										T38_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										res_2 = rawNewString(((NI)80));
										prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3093);
										colontmpD__2 = rdCharLoc__cgen_u12869(aX60gensym2708__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__2);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3094);
										colontmpD__3 = rdCharLoc__cgen_u12869(xX60gensym2713__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__3);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3096);
										colontmpD__4 = rdCharLoc__cgen_u12869(aX60gensym2708__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__4);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3098);
										colontmpD__5 = rdCharLoc__cgen_u12869(yX60gensym2713__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__5);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										prepareAdd((&res_2), 7);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3100);
										T39_.len = 0; T39_.p = NIM_NIL;
										colontmpD__6 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										T39_ = rawNewString(colontmpD__6.len + 3);
appendString((&T39_), TM__MQdRN7fpbG7rPm4JpVVAhA_3101);
appendString((&T39_), colontmpD__6);
appendString((&T39_), TM__MQdRN7fpbG7rPm4JpVVAhA_3102);
										colontmpD__7 = T39_;
										cgFormatValue__cgen_u163((&res_2), colontmpD__7);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3103);
										{
											if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA42_;
											prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3104);
										}
LA42_: ;
										prepareAdd((&(*T38_)), res_2.len + 0);
appendString((&(*T38_)), res_2);
										{
											LA32_:;
										}
										{
											eqdestroy___system_u2691(colontmpD__7);
											eqdestroy___system_u2691(colontmpD__6);
											eqdestroy___system_u2691(colontmpD__5);
											eqdestroy___system_u2691(colontmpD__4);
											eqdestroy___system_u2691(colontmpD__3);
											eqdestroy___system_u2691(colontmpD__2);
											eqdestroy___system_u2691(res_2);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
									}
									goto LA28_;
LA30_: ;
									{
										NimStringV2 res_3;
										NimStringV2 colontmpD__8;
										NimStringV2 colontmpD__9;
										NimStringV2 colontmpD__10;
										NimStringV2 colontmpD__11;
										tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T48_;
										tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T49_;
										NimStringV2* T50_;
										NimStringV2* T51_;
										NimStringV2 T52_;
										res_3.len = 0; res_3.p = NIM_NIL;
										colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
										colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
										colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
										colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
										T48_ = 0;
										nimZeroMem((void*)(&T49_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
										initLocExpr__cgen_u14111(p_p0, (*(*t_p1)._kind_6.sons.p->data[iX60gensym2710__1])._kind_6.sons.p->data[iX60gensym2713__1], T48_, (&T49_));
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										eqsink___ast_u6293((&xX60gensym2713__1), T49_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										T50_ = (NimStringV2*)0;
										T50_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										addIndent__cgen_u315(p_p0, T50_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										T51_ = (NimStringV2*)0;
										T51_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										res_3 = rawNewString(((NI)80));
										prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3105);
										colontmpD__8 = rdCharLoc__cgen_u12869(aX60gensym2708__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										cgFormatValue__cgen_u163((&res_3), colontmpD__8);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3106);
										colontmpD__9 = rdCharLoc__cgen_u12869(xX60gensym2713__1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										cgFormatValue__cgen_u163((&res_3), colontmpD__9);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										prepareAdd((&res_3), 7);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3107);
										T52_.len = 0; T52_.p = NIM_NIL;
										colontmpD__10 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										T52_ = rawNewString(colontmpD__10.len + 3);
appendString((&T52_), TM__MQdRN7fpbG7rPm4JpVVAhA_3108);
appendString((&T52_), colontmpD__10);
appendString((&T52_), TM__MQdRN7fpbG7rPm4JpVVAhA_3109);
										colontmpD__11 = T52_;
										cgFormatValue__cgen_u163((&res_3), colontmpD__11);
										if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
										prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3110);
										{
											if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA55_;
											prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3111);
										}
LA55_: ;
										prepareAdd((&(*T51_)), res_3.len + 0);
appendString((&(*T51_)), res_3);
										{
											LA47_:;
										}
										{
											eqdestroy___system_u2691(colontmpD__11);
											eqdestroy___system_u2691(colontmpD__10);
											eqdestroy___system_u2691(colontmpD__9);
											eqdestroy___system_u2691(colontmpD__8);
											eqdestroy___system_u2691(res_3);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
									}
LA28_: ;
									i_1 += ((NI)1);
								} LA27: ;
							}
						}
						{
							LA23_:;
						}
						{
							oldNimErrFin23_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u6284(yX60gensym2713__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							eqdestroy___ast_u6284(xX60gensym2713__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							*nimErr_ = oldNimErrFin23_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					}
					goto LA19_;
LA21_: ;
					{
						NimStringV2 colontmpD__12;
						NimStringV2 colontmpD__13;
						NimStringV2* T62_;
						NimStringV2* T63_;
						tyArray__YgExxhfgKcesA5EOUj1MOA T64_;
						colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
						colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
						T62_ = (NimStringV2*)0;
						T62_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						addIndent__cgen_u315(p_p0, T62_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T63_ = (NimStringV2*)0;
						T63_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						colontmpD__12 = rope__ropes_u15(((NI64) ((*p_p0).labels)));
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						T64_[0] = colontmpD__12;
						colontmpD__13 = percent___cgen_u17855(T64_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						prepareAdd((&(*T63_)), colontmpD__13.len + 0);
appendString((&(*T63_)), colontmpD__13);
						eqdestroy___system_u2691(colontmpD__13);
						eqdestroy___system_u2691(colontmpD__12);
					}
LA19_: ;
					res_1 += ((NI)1);
				} LA18: ;
			}
		}
		{
			NI T67_;
			NI T68_;
			NimStringV2 colontmpD__14;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			NI gotoTargetX60gensym2710__1;
			NimStringV2* T72_;
			NimStringV2* T73_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T74_;
			NI T75_;
			NimStringV2* T76_;
			NimStringV2* T77_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T78_;
			T67_ = (NI)0;
			T67_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T68_ = (NI)0;
			T68_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			if (!((NI)(T67_ - ((NI)1)) < (NI)(T68_ - ((NI)1)))) goto LA69_;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			(*p_p0).labels += ((NI)1);
			gotoTargetX60gensym2710__1 = (*p_p0).labels;
			T72_ = (NimStringV2*)0;
			T72_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			addIndent__cgen_u315(p_p0, T72_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			T73_ = (NimStringV2*)0;
			T73_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			colontmpD__14 = rope__ropes_u15(((NI64) (gotoTargetX60gensym2710__1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			T74_[0] = colontmpD__14;
			colontmpD__15 = percent___cgen_u17855(T74_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			prepareAdd((&(*T73_)), colontmpD__15.len + 0);
appendString((&(*T73_)), colontmpD__15);
			T75_ = (NI)0;
			T75_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			resX60gensym2710__1 = genCaseSecondPass__cgen_u17654(p_p0, t_p1, d_p2, labIdX60gensym2710__1, (NI)(T75_ - ((NI)1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			T76_ = (NimStringV2*)0;
			T76_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			addIndent__cgen_u315(p_p0, T76_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			T77_ = (NimStringV2*)0;
			T77_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			colontmpD__16 = rope__ropes_u15(((NI64) (gotoTargetX60gensym2710__1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			T78_[0] = colontmpD__16;
			colontmpD__17 = percent___cgen_u17671(T78_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA71_;
			prepareAdd((&(*T77_)), colontmpD__17.len + 0);
appendString((&(*T77_)), colontmpD__17);
			{
				LA71_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(colontmpD__14);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
		goto LA65_;
LA69_: ;
		{
			NI T82_;
			T82_ = (NI)0;
			T82_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			resX60gensym2710__1 = genCaseSecondPass__cgen_u17654(p_p0, t_p1, d_p2, labIdX60gensym2710__1, (NI)(T82_ - ((NI)1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
LA65_: ;
		lendX60gensym2708__1 = resX60gensym2710__1;
		eqwasMoved___system_u2688((&resX60gensym2710__1));
		fixLabel__cgen_u14067(p_p0, lendX60gensym2708__1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(resX60gensym2710__1);
			eqdestroy___system_u2691(lendX60gensym2708__1);
			eqdestroy___ast_u6284(aX60gensym2708__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		{
			NIM_BOOL T88_;
			T88_ = (NIM_BOOL)0;
			T88_ = ((*(*t_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
			if (!(T88_)) goto LA89_;
			T88_ = (((*(*(*t_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)59)))&63U)))!=0);
LA89_: ;
			if (!T88_) goto LA90_;
			genGotoForCase__cgen_u16948(p_p0, t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA86_;
LA90_: ;
		{
			genOrdinalCase__cgen_u18088(p_p0, t_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA86_: ;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, pop__cgen_u16349)(tySequence__olcP618a61wlx6oJIT9b0sA* s_p0, tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* Result) {
	NI L_1;
	NI T1_;
	T1_ = (*s_p0).len;
	L_1 = (NI)(T1_ - ((NI)1));
	(*Result).Field0 = (*s_p0).p->data[L_1].Field0;
	(*Result).Field1 = (*s_p0).p->data[L_1].Field1;
	(*Result).Field2 = (*s_p0).p->data[L_1].Field2;
	eqwasMoved___cgendata_u1155((&(*s_p0).p->data[L_1]));
	shrink__cgendata_u1108(s_p0, (L_1));
}
static N_INLINE(NIM_BOOL, isClosureIterator__ast_u7426)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*typ_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
	if (!(T2_)) goto LA3_;
	T2_ = (((*typ_p0).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)15)))&63U)))!=0);
LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*typ_p0).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, blockLeaveActions__cgen_u16297)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, NI howManyTrys_p1, NI howManyExcepts_p2, NIM_BOOL isReturnStmt_p3) {
	tySequence__olcP618a61wlx6oJIT9b0sA stack_1;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	stack_1.len = 0; stack_1.p = NIM_NIL;
	stack_1 = newSeq__cgen_u16321(((NI)0));
	(*p_p0).withinBlockLeaveActions += ((NI)1);
	{
		NI i_1;
		NI res_1;
		i_1 = (NI)0;
		res_1 = ((NI)1);
		{
			while (1) {
				tyTuple__P9bg2wlfPi4dSSTi3ICCeVA tryStmt_1;
				tyTuple__P9bg2wlfPi4dSSTi3ICCeVA colontmpD_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* finallyStmt_1;
				if (!(res_1 <= howManyTrys_p1)) goto LA4;
				nimZeroMem((void*)(&tryStmt_1), sizeof(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA));
				finallyStmt_1 = NIM_NIL;
				i_1 = ((NI) (res_1));
				pop__cgen_u16349((&(*p_p0).nestedTryStmts), (&tryStmt_1));
				{
					if (!((*(*(*(*p_p0).module).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)1))) goto LA8_;
					{
						NimStringV2 res_2;
						NimStringV2 colontmpD__2;
						NimStringV2* T15_;
						NimStringV2* T16_;
						if (!!(tryStmt_1.Field1)) goto LA12_;
						res_2.len = 0; res_2.p = NIM_NIL;
						colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
						T15_ = (NimStringV2*)0;
						T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						addIndent__cgen_u315(p_p0, T15_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						T16_ = (NimStringV2*)0;
						T16_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						res_2 = rawNewString(((NI)80));
						colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3134);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						cgFormatValue__cgen_u163((&res_2), colontmpD__2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
						prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3135);
						{
							if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA19_;
							prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3136);
						}
LA19_: ;
						prepareAdd((&(*T16_)), res_2.len + 0);
appendString((&(*T16_)), res_2);
						{
							LA14_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___system_u2691(res_2);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					}
LA12_: ;
				}
LA8_: ;
				eqdup___cgendata_u1164(tryStmt_1, (&colontmpD_));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				add__cgen_u16386((&stack_1), colontmpD_);
				finallyStmt_1 = tryStmt_1.Field0;
				eqwasMoved___ast_u3249(&tryStmt_1.Field0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				{
					if (!!((finallyStmt_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA25_;
					genStmts__cgen_u14081(p_p0, (*finallyStmt_1)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				}
LA25_: ;
				res_1 += ((NI)1);
				{
					LA5_:;
				}
				{
					oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(finallyStmt_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___cgendata_u1158(tryStmt_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin5_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA4: ;
		}
	}
	(*p_p0).withinBlockLeaveActions -= ((NI)1);
	{
		NI i_2;
		NI colontmp_;
		NI res_3;
		i_2 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(howManyTrys_p1 - ((NI)1));
		res_3 = colontmp_;
		{
			while (1) {
				tyTuple__P9bg2wlfPi4dSSTi3ICCeVA colontmpD__3;
				if (!(((NI)0) <= res_3)) goto LA31;
				i_2 = ((NI) (res_3));
				eqdup___cgendata_u1164(stack_1.p->data[i_2], (&colontmpD__3));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				add__cgen_u16386((&(*p_p0).nestedTryStmts), colontmpD__3);
				res_3 -= ((NI)1);
			} LA31: ;
		}
	}
	{
		NIM_BOOL T34_;
		NIM_BOOL T36_;
		T34_ = (NIM_BOOL)0;
		T34_ = !((((*p_p0).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)3)))&7U)))!=0));
		if (!(T34_)) goto LA35_;
		T36_ = (NIM_BOOL)0;
		T36_ = isReturnStmt_p3;
		if (!(T36_)) goto LA37_;
		T36_ = isClosureIterator__ast_u7426((*(*p_p0).prc).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA37_: ;
		T34_ = !(T36_);
LA35_: ;
		if (!T34_) goto LA38_;
		{
			NI i_3;
			NI colontmp__2;
			NI res_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = (NI)(howManyExcepts_p2 - ((NI)1));
			res_4 = colontmp__2;
			{
				while (1) {
					NimStringV2 res_5;
					NimStringV2 colontmpD__4;
					NimStringV2* T44_;
					NimStringV2* T45_;
					if (!(((NI)0) <= res_4)) goto LA42;
					res_5.len = 0; res_5.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					i_3 = ((NI) (res_4));
					T44_ = (NimStringV2*)0;
					T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
					addIndent__cgen_u315(p_p0, T44_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
					T45_ = (NimStringV2*)0;
					T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
					res_5 = rawNewString(((NI)80));
					colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3138);
					if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
					cgFormatValue__cgen_u163((&res_5), colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA43_;
					prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3139);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA48_;
						prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3140);
					}
LA48_: ;
					prepareAdd((&(*T45_)), res_5.len + 0);
appendString((&(*T45_)), res_5);
					res_4 -= ((NI)1);
					{
						LA43_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(res_5);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA42: ;
			}
		}
	}
LA38_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u1078(stack_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genReturnStmt__cgen_u16900)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
	NimStringV2 colontmpD_;
	NI T10_;
	NI T11_;
	NimStringV2* T29_;
	NimStringV2* T30_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T31_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		if (!(((*t_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)15)))&31U)))!=0)) goto LA4_;
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
	}
LA4_: ;
	(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)0))) & 7);
	genLineDir__cgen_u418(p_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!(((*(*t_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA8_;
		genStmts__cgen_u14081(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	T10_ = (*p_p0).nestedTryStmts.len;
	T11_ = (NI)0;
	T11_ = inExceptBlockLen__cgen_u15682(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	blockLeaveActions__cgen_u16297(p_p0, T10_, T11_, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T14_;
		NI T15_;
		NimStringV2 safePoint_1;
		NimStringV2 res_1;
		NimStringV2 colontmpD__2;
		NimStringV2* T20_;
		NimStringV2* T21_;
		NimStringV2* T22_;
		T14_ = (NIM_BOOL)0;
		T15_ = (*p_p0).finallySafePoints.len;
		T14_ = (((NI)0) < T15_);
		if (!(T14_)) goto LA16_;
		T14_ = !((((*p_p0).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)3)))&7U)))!=0));
LA16_: ;
		if (!T14_) goto LA17_;
		safePoint_1.len = 0; safePoint_1.p = NIM_NIL;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T20_ = (NimStringV2*)0;
		T20_ = X5BX5D___cgen_u3675((((*p_p0).finallySafePoints).p) ? ((*p_p0).finallySafePoints.p->data) : NIM_NIL, (*p_p0).finallySafePoints.len, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		eqcopy___system_u2694((&safePoint_1), (*T20_));
		T21_ = (NimStringV2*)0;
		T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		addIndent__cgen_u315(p_p0, T21_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		T22_ = (NimStringV2*)0;
		T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3141);
		cgFormatValue__cgen_u163((&res_1), safePoint_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		prepareAdd((&res_1), 14);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3143);
		colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3144);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3145);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA25_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3146);
		}
LA25_: ;
		prepareAdd((&(*T22_)), res_1.len + 0);
appendString((&(*T22_)), res_1);
		{
			LA19_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(res_1);
			eqdestroy___system_u2691(safePoint_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA17_: ;
	T29_ = (NimStringV2*)0;
	T29_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T29_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T30_ = (NimStringV2*)0;
	T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = percent___cgen_u16943(T31_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T30_)), colontmpD_.len + 0);
appendString((&(*T30_)), colontmpD_);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakStmt__cgen_u17320)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NI idx_1;
	NimStringV2 T21_;
	NI T22_;
	NI T23_;
	NimStringV2* T24_;
	NimStringV2* T25_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T26_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	idx_1 = (*p_p0).breakIdx;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
		if (!!(((*(*t_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA4_;
		sym_1 = NIM_NIL;
		sym_1 = (*(*t_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym;
		{
			if (!!(((*sym_1).loc.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)10)))) goto LA8_;
			failedAssertImpl__stdZassertions_u79(TM__MQdRN7fpbG7rPm4JpVVAhA_3148);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA8_: ;
		idx_1 = (NI)((*sym_1).position - ((NI)1));
	}
	goto LA2_;
LA4_: ;
	{
		{
			while (1) {
				NIM_BOOL T13_;
				T13_ = (NIM_BOOL)0;
				T13_ = (((NI)0) <= idx_1);
				if (!(T13_)) goto LA14_;
				T13_ = !((*p_p0).blocks.p->data[idx_1].isLoop);
LA14_: ;
				if (!T13_) goto LA12;
				idx_1 -= ((NI)1);
			} LA12: ;
		}
		{
			NIM_BOOL T17_;
			T17_ = (NIM_BOOL)0;
			T17_ = (idx_1 < ((NI)0));
			if (T17_) goto LA18_;
			T17_ = !((*p_p0).blocks.p->data[idx_1].isLoop);
LA18_: ;
			if (!T17_) goto LA19_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*t_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_3150, TM__MQdRN7fpbG7rPm4JpVVAhA_3151);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA19_: ;
	}
LA2_: ;
	T21_.len = 0; T21_.p = NIM_NIL;
	colontmpD_ = rope__ropes_u15(((NI64) ((*p_p0).blocks.p->data[idx_1].id)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T21_ = rawNewString(colontmpD_.len + 2);
appendString((&T21_), TM__MQdRN7fpbG7rPm4JpVVAhA_3152);
appendString((&T21_), colontmpD_);
	eqsink___system_u2700((&(*p_p0).blocks.p->data[idx_1].label), T21_);
	T22_ = (*p_p0).nestedTryStmts.len;
	T23_ = (NI)0;
	T23_ = inExceptBlockLen__cgen_u15682(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	blockLeaveActions__cgen_u16297(p_p0, (NI)(T22_ - ((NI) ((*p_p0).blocks.p->data[idx_1].nestedTryStmts))), (NI)(T23_ - ((NI) ((*p_p0).blocks.p->data[idx_1].nestedExceptStmts))), NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genLineDir__cgen_u418(p_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T24_ = (NimStringV2*)0;
	T24_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T24_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T25_ = (NimStringV2*)0;
	T25_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T26_[0] = (*p_p0).blocks.p->data[idx_1].label;
	colontmpD__2 = percent___cgen_u16882(T26_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T25_)), colontmpD__2.len + 0);
appendString((&(*T25_)), colontmpD__2);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, cow__cgen_u21990)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA3_;
		cowBracket__cgen_u21960(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, discriminatorTableDecl__cgen_u9220)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* objtype_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* d_p2) {
	NimStringV2 result;
	NimStringV2 tmp_1;
	NimStringV2 colontmpD_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T2_;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T3_;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	cgsym__cgen_u138(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3154);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tmp_1 = discriminatorTableName__cgen_u9198(m_p0, objtype_p1, d_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = tmp_1;
	T3_ = lengthOrd__types_u1491((*(*m_p0).g).config, (*d_p2).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = plus___int128_u1015(T3_, IL64(1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = rope__cgen_u9217(T4_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[1] = colontmpD_;
	result = percent___cgen_u9226(T2_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tmp_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDiscriminantCheck__cgen_u19804)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* objtype_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_p4) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	NimStringV2 colontmpD_;
	NimStringV2 lit_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T10_;
	NI64 T11_;
	NimStringV2* T12_;
	NimStringV2* T13_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	lit_1.len = 0; lit_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	t_1 = skipTypes__ast_u5379(objtype_p3, TM__MQdRN7fpbG7rPm4JpVVAhA_948);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = genTypeInfoV1__cgen_u9076((*p_p0).module, t_1, (*a_p1.lode).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	{
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym3713__1;
		NIM_BOOL T4_;
		NimStringV2 res_2;
		NimStringV2 colontmpD__6;
		xX60gensym3713__1 = (*field_p4).itemId;
		T4_ = (NIM_BOOL)0;
		T4_ = containsOrIncl__astyaml_u223((&(*(*p_p0).module).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym3713__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym3713__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T4_)) goto LA5_;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 7);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3153);
		colontmpD__6 = discriminatorTableDecl__cgen_u9220((*p_p0).module, t_1, field_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), res_2.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), res_2);
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	lit_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_ = lengthOrd__types_u1491((*(*(*p_p0).module).g).config, (*field_p4).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_ = (NI64)0;
	T11_ = toInt64__int128_u53(T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	intLiteral__cgen_u14092((NI64)(T11_ + IL64(1)), (&lit_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_ = (NimStringV2*)0;
	T12_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_ = (NimStringV2*)0;
	T13_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3156);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 10);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3158);
	colontmpD__3 = rdLoc__cgen_u470(a_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 12);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3160);
	colontmpD__4 = rdLoc__cgen_u470(tmp_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3161);
	colontmpD__5 = discriminatorTableName__cgen_u9198((*p_p0).module, t_1, field_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3162);
	cgFormatValue__cgen_u163((&res_1), lit_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3163);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA16_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3164);
	}
LA16_: ;
	prepareAdd((&(*T13_)), res_1.len + 0);
appendString((&(*T13_)), res_1);
	{
		if (!((*(*(*(*p_p0).module).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3))) goto LA20_;
		raiseExit__cgen_u14106(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA20_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(lit_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, asgnFieldDiscriminant__cgen_u19926)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dotExpr_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tmp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T6_;
NIM_BOOL oldNimErrFin11_;
	tySet_tyEnum_TAssignmentFlag__KWRsV9a7zJ9aBz5oQy2Fyu6w T14_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	dotExpr_1 = NIM_NIL;
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&tmp_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_ = NIM_NIL;
	eqcopy___ast_u3255(&dotExpr_1, (*e_p1)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*dotExpr_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46))) goto LA4_;
		eqcopy___ast_u3255(&dotExpr_1, (*dotExpr_1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	T6_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)0)], T6_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = t__cgen_u97(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	getTemp__cgen_u9546(p_p0, colontmpD_, NIM_FALSE, (&tmp_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	expr__cgen_u14084(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)], (&tmp_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
		if (!((*p_p0).inUncheckedAssignSection == ((NI)0))) goto LA9_;
		field_1 = NIM_NIL;
		eqcopy___ast_u4577(&field_1, (*(*dotExpr_1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		genDiscriminantCheck__cgen_u19804(p_p0, a_1, tmp_1, (*(*dotExpr_1)._kind_6.sons.p->data[((NI)0)]).typField, field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*e_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)61), TM__MQdRN7fpbG7rPm4JpVVAhA_3165, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_3166, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		{
			LA11_:;
		}
		{
			oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(field_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin11_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA9_: ;
	T14_ = 0;
	genAssignment__cgen_u12898(p_p0, a_1, tmp_1, T14_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(tmp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(dotExpr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsgn__cgen_u19937)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_p1, NIM_BOOL fastAsgn_p2) {
NIM_BOOL oldNimErrFin13_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*(*e_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T3_)) goto LA4_;
		T3_ = (((*(*(*e_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)59)))&63U)))!=0);
LA4_: ;
		if (!T3_) goto LA5_;
		genLineDir__cgen_u418(p_p0, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		genGotoVar__cgen_u16514(p_p0, (*e_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (((*p_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)2)))&31U)))!=0);
		if (!(T8_)) goto LA9_;
		T8_ = isDiscriminantField__astalgo_u3497((*e_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA9_: ;
		if (!T8_) goto LA10_;
		genLineDir__cgen_u418(p_p0, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		asgnFieldDiscriminant__cgen_u19926(p_p0, e_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA10_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* le_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ri_1;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		NimStringV2 colontmpD__2;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T14_;
		le_1 = NIM_NIL;
		ri_1 = NIM_NIL;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD_ = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		eqcopy___ast_u3255(&le_1, (*e_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		eqcopy___ast_u3255(&ri_1, (*e_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_ = 0;
		initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0), le_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T14_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		colontmpD_ = skipTypes__ast_u5379((*le_1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_425);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		colontmpD__2 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD_, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		(void)(colontmpD__2);
		a_1.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)8))) & 15);
		a_1.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)9))) & 15);
		genLineDir__cgen_u418(p_p0, le_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		expr__cgen_u14084(p_p0, le_1, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		a_1.flags &= ~(((NU16)1) << (((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)9))) & 15));
		{
			if (!fastAsgn_p2) goto LA17_;
			a_1.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)1))) & 15);
		}
LA17_: ;
		genLineDir__cgen_u418(p_p0, ri_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		loadInto__cgen_u16153(p_p0, le_1, ri_1, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(ri_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(le_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsmOrEmitStmt__cgen_u19682)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, NIM_BOOL isAsmStmt_p2, NimStringV2* result_p3) {
	NimStringV2 res_1;
	NI colontmpD_;
	NI colontmpD__2;
	NI offset_1;
NIM_BOOL oldNimErrFin18_;
NIM_BOOL oldNimErrFin29_;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin39_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_ = (NI)0;
	colontmpD__2 = (NI)0;
	res_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3178;
	{
		if (!isAsmStmt_p2) goto LA4_;
		colontmpD_ = ((NI)1);
		offset_1 = colontmpD_;
	}
	goto LA2_;
LA4_: ;
	{
		colontmpD__2 = ((NI)0);
		offset_1 = colontmpD__2;
	}
LA2_: ;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = offset_1;
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA9;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*t_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				switch ((*it_1).kind) {
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
				{
					prepareAdd((&res_1), (*it_1)._kind_3.strVal.len + 0);
appendString((&res_1), (*it_1)._kind_3.strVal);
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
					sym_1 = NIM_NIL;
					eqcopy___ast_u4577(&sym_1, (*it_1)._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					{
						tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
						NimStringV2 colontmpD__3;
						tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T19_;
						if (!((*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14))) goto LA16_;
						nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
						colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
						T19_ = 0;
						initLocExpr__cgen_u14111(p_p0, it_1, T19_, (&a_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						colontmpD__3 = rdLoc__cgen_u470(a_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
						prepareAdd((&res_1), colontmpD__3.len + 0);
appendString((&res_1), colontmpD__3);
						{
							LA18_:;
						}
						{
							oldNimErrFin18_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__3);
							eqdestroy___ast_u6284(a_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							*nimErr_ = oldNimErrFin18_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					}
					goto LA14_;
LA16_: ;
					{
						NimStringV2 colontmpD__4;
						if (!((*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7))) goto LA23_;
						colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
						colontmpD__4 = getTypeDesc__cgen_u8738((*p_p0).module, (*sym_1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
						prepareAdd((&res_1), colontmpD__4.len + 0);
appendString((&res_1), colontmpD__4);
						{
							LA25_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__4);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					}
					goto LA14_;
LA23_: ;
					{
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
						NimStringV2 colontmpD__6;
						colontmpD__5 = NIM_NIL;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						colontmpD__5 = skipTypes__ast_u5379((*sym_1).typ, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						colontmpD__6 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__5, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						(void)(colontmpD__6);
						fillBackendName__cgen_u896((*p_p0).module, sym_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
						prepareAdd((&res_1), (*sym_1).loc.snippet.len + 0);
appendString((&res_1), (*sym_1).loc.snippet);
						{
							LA29_:;
						}
						{
							oldNimErrFin29_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___system_u2691(colontmpD__6);
							eqdestroy___ast_u3378(colontmpD__5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							*nimErr_ = oldNimErrFin29_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
					}
LA14_: ;
					{
						LA13_:;
					}
					{
						oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(sym_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						*nimErr_ = oldNimErrFin13_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
				break;
				case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)132):
				{
					NimStringV2 colontmpD__7;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					colontmpD__7 = getTypeDesc__cgen_u8738((*p_p0).module, (*it_1).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
					prepareAdd((&res_1), colontmpD__7.len + 0);
appendString((&res_1), colontmpD__7);
					{
						LA35_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__7);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
				break;
				default:
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
					NimStringV2 colontmpD__9;
					tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
					NimStringV2 colontmpD__10;
					tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T40_;
					colontmpD__8 = NIM_NIL;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
					colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
					colontmpD__8 = skipTypes__ast_u5379((*it_1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
					if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
					colontmpD__9 = getTypeDesc__cgen_u8738((*p_p0).module, colontmpD__8, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
					(void)(colontmpD__9);
					T40_ = 0;
					initLocExpr__cgen_u14111(p_p0, it_1, T40_, (&a_2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
					colontmpD__10 = rdLoc__cgen_u470(a_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
					prepareAdd((&res_1), colontmpD__10.len + 0);
appendString((&res_1), colontmpD__10);
					{
						LA39_:;
					}
					{
						oldNimErrFin39_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__10);
						eqdestroy___ast_u6284(a_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						eqdestroy___system_u2691(colontmpD__9);
						eqdestroy___ast_u3378(colontmpD__8);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						*nimErr_ = oldNimErrFin39_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
				break;
				}
				i_2 += ((NI)1);
				{
					LA10_:;
				}
				{
					oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin10_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA9: ;
		}
	}
	{
		NIM_BOOL T47_;
		T47_ = (NIM_BOOL)0;
		T47_ = isAsmStmt_p2;
		if (!(T47_)) goto LA48_;
		T47_ = ((CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)5)))&15U)))!=0);
LA48_: ;
		if (!T47_) goto LA49_;
		{
			NimStringV2 x_1;
			NI first_1;
			NI last_1;
			NI eolpos_1;
			x_1.len = 0; x_1.p = NIM_NIL;
			first_1 = ((NI)0);
			last_1 = ((NI)0);
			eolpos_1 = ((NI)0);
			{
				while (1) {
					NI colontmpD__11;
					NI colontmpD__12;
					NI T76_;
					NimStringV2 T82_;
					NI j_1;
					colontmpD__11 = (NI)0;
					colontmpD__12 = (NI)0;
					{
						while (1) {
							NIM_BOOL T57_;
							T57_ = (NIM_BOOL)0;
							T57_ = (last_1 < res_1.len);
							if (!(T57_)) goto LA58_;
							T57_ = !((((NU8)(res_1.p->data[last_1])) == ((NU8)(13)) || ((NU8)(res_1.p->data[last_1])) == ((NU8)(10))));
LA58_: ;
							if (!T57_) goto LA56;
							last_1 += ((NI)1);
						} LA56: ;
					}
					eolpos_1 = last_1;
					{
						if (!(last_1 < res_1.len)) goto LA61_;
						{
							if (!((NU8)(res_1.p->data[last_1]) == (NU8)(10))) goto LA65_;
							last_1 += ((NI)1);
						}
						goto LA63_;
LA65_: ;
						{
							if (!((NU8)(res_1.p->data[last_1]) == (NU8)(13))) goto LA68_;
							last_1 += ((NI)1);
							{
								NIM_BOOL T72_;
								T72_ = (NIM_BOOL)0;
								T72_ = (last_1 < res_1.len);
								if (!(T72_)) goto LA73_;
								T72_ = ((NU8)(res_1.p->data[last_1]) == (NU8)(10));
LA73_: ;
								if (!T72_) goto LA74_;
								last_1 += ((NI)1);
							}
LA74_: ;
						}
						goto LA63_;
LA68_: ;
LA63_: ;
					}
LA61_: ;
					T76_ = (NI)0;
					{
						if (!NIM_FALSE) goto LA79_;
						colontmpD__11 = (NI)(last_1 - ((NI)1));
						T76_ = colontmpD__11;
					}
					goto LA77_;
LA79_: ;
					{
						colontmpD__12 = (NI)(eolpos_1 - ((NI)1));
						T76_ = colontmpD__12;
					}
LA77_: ;
					T82_.len = 0; T82_.p = NIM_NIL;
					T82_ = substr__system_u8632(res_1, first_1, T76_);
					eqsink___system_u2700((&x_1), T82_);
					j_1 = ((NI)0);
					{
						while (1) {
							NIM_BOOL T85_;
							T85_ = (NIM_BOOL)0;
							T85_ = (j_1 < x_1.len);
							if (!(T85_)) goto LA86_;
							T85_ = (((NU8)(x_1.p->data[j_1])) == ((NU8)(32)) || ((NU8)(x_1.p->data[j_1])) == ((NU8)(9)));
LA86_: ;
							if (!T85_) goto LA84;
							j_1 += ((NI)1);
						} LA84: ;
					}
					{
						if (!(j_1 < x_1.len)) goto LA89_;
						{
							if (!(((NU8)(x_1.p->data[j_1])) == ((NU8)(34)) || ((NU8)(x_1.p->data[j_1])) == ((NU8)(58)))) goto LA93_;
							prepareAdd((&(*result_p3)), x_1.len + 0);
appendString((&(*result_p3)), x_1);
							prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_3179);
						}
						goto LA91_;
LA93_: ;
						{
							NimStringV2 colontmpD__13;
							colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
							prepareAdd((&(*result_p3)), 1);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_3181);
							colontmpD__13 = nsuReplaceStr(x_1, TM__MQdRN7fpbG7rPm4JpVVAhA_3182, TM__MQdRN7fpbG7rPm4JpVVAhA_3184);
							if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
							prepareAdd((&(*result_p3)), colontmpD__13.len + 0);
appendString((&(*result_p3)), colontmpD__13);
							prepareAdd((&(*result_p3)), 4);
appendString((&(*result_p3)), TM__MQdRN7fpbG7rPm4JpVVAhA_3186);
							eqdestroy___system_u2691(colontmpD__13);
						}
LA91_: ;
					}
LA89_: ;
					{
						if (!(eolpos_1 == last_1)) goto LA98_;
						goto LA53;
					}
LA98_: ;
					first_1 = last_1;
				}
			} LA53: ;
			{
				LA52_:;
			}
			{
				eqdestroy___system_u2691(x_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
	goto LA45_;
LA49_: ;
	{
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3187);
		prepareAdd((&(*result_p3)), res_1.len + 0);
appendString((&(*result_p3)), res_1);
	}
LA45_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genAsmStmt__cgen_u19725)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
	NimStringV2 s_1;
	NimStringV2 asmSyntax_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* p_2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1.len = 0; s_1.p = NIM_NIL;
	asmSyntax_1.len = 0; asmSyntax_1.p = NIM_NIL;
	p_2 = NIM_NIL;
	genLineDir__cgen_u418(p_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	s_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	asmSyntax_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3170;
	{
		eqcopy___ast_u3255(&p_2, (*t_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*p_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90))) goto LA4_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* i_1;
			i_1 = NIM_NIL;
			{
				NI i_2;
				NI colontmp_;
				NI i_3;
				i_2 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(p_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				i_3 = ((NI)0);
				{
					while (1) {
						if (!(i_3 < colontmp_)) goto LA9;
						i_2 = i_3;
						eqcopy___ast_u3255(&i_1, (*p_2)._kind_6.sons.p->data[i_2]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						{
							tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T12_;
							T12_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
							T12_ = whichPragma__trees_u218(i_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							if (!(T12_ == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)219))) goto LA13_;
							eqcopy___system_u2694((&asmSyntax_1), (*(*i_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
						}
LA13_: ;
						i_3 += ((NI)1);
					} LA9: ;
				}
			}
			eqdestroy___ast_u3252(i_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
LA4_: ;
	{
		NIM_BOOL T17_;
		NIM_BOOL T19_;
		NIM_BOOL T20_;
		NIM_BOOL T23_;
		T17_ = (NIM_BOOL)0;
		T17_ = !((asmSyntax_1.len == 0));
		if (!(T17_)) goto LA18_;
		T19_ = (NIM_BOOL)0;
		T20_ = (NIM_BOOL)0;
		T20_ = eqStrings(asmSyntax_1, TM__MQdRN7fpbG7rPm4JpVVAhA_3172);
		if (!(T20_)) goto LA21_;
		T20_ = ((CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)5)))&15U)))!=0);
LA21_: ;
		T19_ = T20_;
		if (T19_) goto LA22_;
		T23_ = (NIM_BOOL)0;
		T23_ = eqStrings(asmSyntax_1, TM__MQdRN7fpbG7rPm4JpVVAhA_3174);
		if (!(T23_)) goto LA24_;
		T23_ = !(((CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field21 &((NU16)1<<((NU)((((tyEnum_TInfoCCProp__iDs813gw4el4q2vkEYZ9cBw)5)))&15U)))!=0));
LA24_: ;
		T19_ = T23_;
LA22_: ;
		T17_ = !(T19_);
LA18_: ;
		if (!T17_) goto LA25_;
		liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*t_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__MQdRN7fpbG7rPm4JpVVAhA_3176, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_3177, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA25_: ;
	genAsmOrEmitStmt__cgen_u19682(p_p0, t_p1, NIM_TRUE, (&s_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T31_;
		if (!((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA29_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T31_[0] = s_1;
		colontmpD_ = runtimeFormat__ropes_u39(CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field17, T31_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD_.len + 0);
appendString((&(*(*p_p0).module).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA27_;
LA29_: ;
	{
		NimStringV2 colontmpD__2;
		NimStringV2* T33_;
		NimStringV2* T34_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T35_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T33_ = (NimStringV2*)0;
		T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T33_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T34_ = (NimStringV2*)0;
		T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T35_[0] = s_1;
		colontmpD__2 = runtimeFormat__ropes_u39(CC__extccomp_u624[((*(*(*(*p_p0).module).g).config).cCompiler)- 1].Field17, T35_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*T34_)), colontmpD__2.len + 0);
appendString((&(*T34_)), colontmpD__2);
		eqdestroy___system_u2691(colontmpD__2);
	}
LA27_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(p_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(asmSyntax_1);
		eqdestroy___system_u2691(s_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, bodyCanRaise__cgen_u18917)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		result = canRaiseDisp__cgen_u14148(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!!(result)) goto LA4_;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 = ((NI)1);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA8;
						i_1 = i_2;
						{
							NIM_BOOL T11_;
							T11_ = (NIM_BOOL)0;
							T11_ = bodyCanRaise__cgen_u18917(p_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							if (!T11_) goto LA12_;
							result = NIM_TRUE;
							goto BeforeRet_;
						}
LA12_: ;
						i_2 += ((NI)1);
					} LA8: ;
				}
			}
		}
LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)108):
	{
		result = NIM_TRUE;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)51):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)52):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
		result = NIM_FALSE;
	}
	break;
	default:
	{
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = safeLen__ast_u3197(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_4 = ((NI)0);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA19;
					i_3 = i_4;
					{
						NIM_BOOL T22_;
						T22_ = (NIM_BOOL)0;
						T22_ = bodyCanRaise__cgen_u18917(p_p0, (*n_p1)._kind_6.sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T22_) goto LA23_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
LA23_: ;
					i_4 += ((NI)1);
				} LA19: ;
			}
		}
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTryGoto__cgen_u18931)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fin_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NI colontmpD__2;
	NI colontmpD__3;
	NimStringV2 res_1;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA colontmpD__4;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2_;
	NI lab_1;
	NIM_BOOL hasExcept_1;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA T14_;
	NI T23_;
	NimStringV2* T44_;
	NimStringV2* T45_;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T50_;
	NI i_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	fin_1 = NIM_NIL;
	colontmpD__2 = (NI)0;
	colontmpD__3 = (NI)0;
	res_1.len = 0; res_1.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__4), sizeof(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA));
	T2_ = NIM_NIL;
	{
		NI T5_;
		NI T8_;
		T5_ = (NI)0;
		T5_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*(*t_p1)._kind_6.sons.p->data[(NI)(T5_ - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107))) goto LA6_;
		T8_ = (NI)0;
		T8_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		fin_1 = (*t_p1)._kind_6.sons.p->data[(NI)(T8_ - ((NI)1))];
	}
	goto LA3_;
LA6_: ;
	{
		fin_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA3_: ;
	(*p_p0).labels += ((NI)1);
	lab_1 = (*p_p0).labels;
	hasExcept_1 = ((*(*t_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87));
	{
		if (!hasExcept_1) goto LA12_;
		(*p_p0).withinTryWithExcept += ((NI)1);
	}
LA12_: ;
	nimZeroMem((void*)(&T14_), sizeof(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA));
	colontmpD_ = eqdup___ast_u3258(fin_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T14_.Field0 = colontmpD_;
	T14_.Field1 = NIM_FALSE;
	T14_.Field2 = lab_1;
	add__cgen_u16386((&(*p_p0).nestedTryStmts), T14_);
	(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)4))) & 7);
	{
		NIM_BOOL T17_;
		NIM_BOOL T18_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T22_;
		T17_ = (NIM_BOOL)0;
		T18_ = (NIM_BOOL)0;
		T18_ = isEmptyType__ast_u7234((*t_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T17_ = !(T18_);
		if (!(T17_)) goto LA19_;
		T17_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
LA19_: ;
		if (!T17_) goto LA20_;
		nimZeroMem((void*)(&T22_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*t_p1).typField, NIM_FALSE, (&T22_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&(*d_p2)), T22_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA20_: ;
	expr__cgen_u14084(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], d_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T23_ = (NI)0;
	{
		NIM_BOOL T26_;
		NI T27_;
		NimStringV2 res_2;
		NimStringV2* T31_;
		NimStringV2* T32_;
		T26_ = (NIM_BOOL)0;
		T27_ = (NI)0;
		T27_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T26_ = (((NI)1) < T27_);
		if (!(T26_)) goto LA28_;
		T26_ = ((*(*t_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87));
LA28_: ;
		if (!T26_) goto LA29_;
		res_2.len = 0; res_2.p = NIM_NIL;
		T31_ = (NimStringV2*)0;
		T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T31_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T32_ = (NimStringV2*)0;
		T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 29);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3188);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA35_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3189);
		}
LA35_: ;
		prepareAdd((&(*T32_)), res_2.len + 0);
appendString((&(*T32_)), res_2);
		colontmpD__2 = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(res_2);
		T23_ = colontmpD__2;
	}
	goto LA24_;
LA29_: ;
	{
		NimStringV2 res_3;
		NimStringV2* T38_;
		NimStringV2* T39_;
		res_3.len = 0; res_3.p = NIM_NIL;
		T38_ = (NimStringV2*)0;
		T38_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T38_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T39_ = (NimStringV2*)0;
		T39_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_3 = rawNewString(((NI)80));
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3190);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA42_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3191);
		}
LA42_: ;
		prepareAdd((&(*T39_)), res_3.len + 0);
appendString((&(*T39_)), res_3);
		colontmpD__3 = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(res_3);
		T23_ = colontmpD__3;
	}
LA24_: ;
	T44_ = (NimStringV2*)0;
	T44_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T44_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T45_ = (NimStringV2*)0;
	T45_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3192);
	cgFormatValue__cgen_u166((&res_1), ((NI64) (lab_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3194);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA48_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3195);
	}
LA48_: ;
	prepareAdd((&(*T45_)), res_1.len + 0);
appendString((&(*T45_)), res_1);
	T50_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
	T50_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*T50_).Field1 = NIM_TRUE;
	i_1 = ((NI)1);
	{
		while (1) {
			NIM_BOOL T53_;
			NI T54_;
			NimStringV2 res_4;
			NimStringV2 colontmpD__5;
			NimStringV2 res_5;
			NI nextExcept_1;
			tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T57_;
			NimStringV2* T149_;
			NimStringV2* T150_;
			NimStringV2* T155_;
			NimStringV2* T156_;
			T53_ = (NIM_BOOL)0;
			T54_ = (NI)0;
			T54_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T53_ = (i_1 < T54_);
			if (!(T53_)) goto LA55_;
			T53_ = ((*(*t_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87));
LA55_: ;
			if (!T53_) goto LA52;
			res_4.len = 0; res_4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			res_5.len = 0; res_5.p = NIM_NIL;
			(*p_p0).labels += ((NI)1);
			nextExcept_1 = (*p_p0).labels;
			T57_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
			T57_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			(*T57_).Field2 = nextExcept_1;
			{
				NIM_BOOL T60_;
				T60_ = (NIM_BOOL)0;
				T60_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1));
				if (!(T60_)) goto LA61_;
				T60_ = isEmptyType__ast_u7234((*t_p1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
LA61_: ;
				if (!T60_) goto LA62_;
				(*d_p2).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0);
			}
LA62_: ;
			{
				NI T66_;
				NimStringV2 res_6;
				NimStringV2 res_7;
				NimStringV2* T77_;
				NimStringV2* T78_;
				NI T83_;
				NimStringV2* T84_;
				NimStringV2* T85_;
				T66_ = (NI)0;
				T66_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				if (!(T66_ == ((NI)1))) goto LA67_;
				res_6.len = 0; res_6.p = NIM_NIL;
				res_7.len = 0; res_7.p = NIM_NIL;
				{
					NimStringV2 colontmpD__6;
					NimStringV2* T74_;
					NimStringV2* T75_;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T76_;
					if (!(((NI)1) < i_1)) goto LA72_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					T74_ = (NimStringV2*)0;
					T74_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
					addIndent__cgen_u315(p_p0, T74_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
					T75_ = (NimStringV2*)0;
					T75_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
					colontmpD__6 = percent___cgen_u19034(T76_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
					prepareAdd((&(*T75_)), colontmpD__6.len + 0);
appendString((&(*T75_)), colontmpD__6);
					eqdestroy___system_u2691(colontmpD__6);
				}
LA72_: ;
				T77_ = (NimStringV2*)0;
				T77_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				addIndent__cgen_u315(p_p0, T77_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				T78_ = (NimStringV2*)0;
				T78_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				res_6 = rawNewString(((NI)80));
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3196);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA81_;
					prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3197);
				}
LA81_: ;
				prepareAdd((&(*T78_)), res_6.len + 0);
appendString((&(*T78_)), res_6);
				T83_ = (NI)0;
				T83_ = startBlockInternal__cgen_u15729(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				T84_ = (NimStringV2*)0;
				T84_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				addIndent__cgen_u315(p_p0, T84_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				T85_ = (NimStringV2*)0;
				T85_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				res_7 = rawNewString(((NI)80));
				prepareAdd((&res_7), 21);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3199);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA88_;
					prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3200);
				}
LA88_: ;
				prepareAdd((&(*T85_)), res_7.len + 0);
appendString((&(*T85_)), res_7);
				expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], d_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
				{
					LA69_:;
				}
				{
					eqdestroy___system_u2691(res_7);
					eqdestroy___system_u2691(res_6);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			}
			goto LA64_;
LA67_: ;
			{
				NimStringV2 orExpr_1;
				NimStringV2 res_8;
				NimStringV2 res_9;
				NimStringV2* T133_;
				NimStringV2* T134_;
				NI T139_;
				NimStringV2* T140_;
				NimStringV2* T141_;
				NI T146_;
				orExpr_1.len = 0; orExpr_1.p = NIM_NIL;
				res_8.len = 0; res_8.p = NIM_NIL;
				res_9.len = 0; res_9.p = NIM_NIL;
				orExpr_1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				{
					NI j_1;
					NI colontmp_;
					NI T95_;
					NI i_2;
					j_1 = (NI)0;
					colontmp_ = (NI)0;
					T95_ = (NI)0;
					T95_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
					colontmp_ = (NI)(T95_ - ((NI)1));
					i_2 = ((NI)0);
					{
						while (1) {
							NimStringV2 memberName_1;
							NimStringV2 T103_;
							if (!(i_2 < colontmp_)) goto LA97;
							memberName_1.len = 0; memberName_1.p = NIM_NIL;
							j_1 = i_2;
							{
								if (!!((orExpr_1.len == ((NI)0)))) goto LA101_;
								prepareAdd((&orExpr_1), 2);
appendString((&orExpr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3201);
							}
LA101_: ;
							T103_.len = 0; T103_.p = NIM_NIL;
							{
								NIM_BOOL T106_;
								T106_ = (NIM_BOOL)0;
								T106_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
								if (T106_) goto LA107_;
								T106_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA107_: ;
								if (!T106_) goto LA108_;
								memberName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3202;
							}
							goto LA104_;
LA108_: ;
							{
								memberName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3204;
							}
LA104_: ;
							{
								NimStringV2 checkFor_1;
								NimStringV2 res_10;
								NimStringV2 colontmpD__7;
								NimStringV2 colontmpD__8;
								NimStringV2 colontmpD__9;
								NI16 T116_;
								tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T117_;
								NU32 T118_;
								if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA113_;
								checkFor_1.len = 0; checkFor_1.p = NIM_NIL;
								res_10.len = 0; res_10.p = NIM_NIL;
								colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
								colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
								colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
								T116_ = (NI16)0;
								T116_ = getObjDepth__cgen_u10096((*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]).typField);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								checkFor_1 = dollar___systemZdollars_u19(T116_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								res_10 = rawNewString(((NI)80));
								colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3205);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								cgFormatValue__cgen_u163((&res_10), colontmpD__7);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3206);
								colontmpD__8 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3208);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								cgFormatValue__cgen_u163((&res_10), colontmpD__8);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								prepareAdd((&res_10), 4);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3210);
								cgFormatValue__cgen_u163((&res_10), memberName_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								prepareAdd((&res_10), 2);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3211);
								cgFormatValue__cgen_u163((&res_10), checkFor_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								prepareAdd((&res_10), 2);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3212);
								nimZeroMem((void*)T117_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
								hashType__sighashes_u411((*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]).typField, (*(*(*p_p0).module).g).config, 2, T117_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								T118_ = (NU32)0;
								T118_ = genDisplayElem__cgen_u10109(T117_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								colontmpD__9 = dollar___systemZdollars_u49(T118_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								cgFormatValue__cgen_u163((&res_10), colontmpD__9);
								if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
								prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3213);
								prepareAdd((&orExpr_1), res_10.len + 0);
appendString((&orExpr_1), res_10);
								{
									LA115_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__9);
									eqdestroy___system_u2691(colontmpD__8);
									eqdestroy___system_u2691(colontmpD__7);
									eqdestroy___system_u2691(res_10);
									eqdestroy___system_u2691(checkFor_1);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
							}
							goto LA111_;
LA113_: ;
							{
								NimStringV2 checkFor_2;
								NimStringV2 res_11;
								NimStringV2 colontmpD__10;
								NimStringV2 colontmpD__11;
								checkFor_2.len = 0; checkFor_2.p = NIM_NIL;
								res_11.len = 0; res_11.p = NIM_NIL;
								colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
								colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
								checkFor_2 = genTypeInfoV1__cgen_u9076((*p_p0).module, (*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]).typField, (*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]).info);
								if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
								res_11 = rawNewString(((NI)80));
								colontmpD__10 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3214);
								if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
								cgFormatValue__cgen_u163((&res_11), colontmpD__10);
								if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
								prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3215);
								colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3216);
								if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
								cgFormatValue__cgen_u163((&res_11), colontmpD__11);
								if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
								prepareAdd((&res_11), 4);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3217);
								cgFormatValue__cgen_u163((&res_11), memberName_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
								prepareAdd((&res_11), 2);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3218);
								cgFormatValue__cgen_u163((&res_11), checkFor_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA122_;
								prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3219);
								prepareAdd((&orExpr_1), res_11.len + 0);
appendString((&orExpr_1), res_11);
								{
									LA122_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__11);
									eqdestroy___system_u2691(colontmpD__10);
									eqdestroy___system_u2691(res_11);
									eqdestroy___system_u2691(checkFor_2);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA98_;
							}
LA111_: ;
							i_2 += ((NI)1);
							{
								LA98_:;
							}
							{
								eqdestroy___system_u2691(memberName_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
						} LA97: ;
					}
				}
				{
					NimStringV2* T131_;
					NimStringV2* T132_;
					if (!(((NI)1) < i_1)) goto LA129_;
					T131_ = (NimStringV2*)0;
					T131_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
					addIndent__cgen_u315(p_p0, T131_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
					T132_ = (NimStringV2*)0;
					T132_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
					prepareAdd((&(*T132_)), 5);
appendString((&(*T132_)), TM__MQdRN7fpbG7rPm4JpVVAhA_3221);
				}
LA129_: ;
				T133_ = (NimStringV2*)0;
				T133_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				addIndent__cgen_u315(p_p0, T133_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				T134_ = (NimStringV2*)0;
				T134_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				res_8 = rawNewString(((NI)80));
				prepareAdd((&res_8), 4);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3222);
				cgFormatValue__cgen_u163((&res_8), orExpr_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				prepareAdd((&res_8), 3);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3223);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA137_;
					prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3224);
				}
LA137_: ;
				prepareAdd((&(*T134_)), res_8.len + 0);
appendString((&(*T134_)), res_8);
				T139_ = (NI)0;
				T139_ = startBlockInternal__cgen_u15729(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				T140_ = (NimStringV2*)0;
				T140_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				addIndent__cgen_u315(p_p0, T140_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				T141_ = (NimStringV2*)0;
				T141_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				res_9 = rawNewString(((NI)80));
				prepareAdd((&res_9), 21);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3225);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA144_;
					prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3226);
				}
LA144_: ;
				prepareAdd((&(*T141_)), res_9.len + 0);
appendString((&(*T141_)), res_9);
				T146_ = (NI)0;
				T146_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[(NI)(T146_ - ((NI)1))], d_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA93_;
				{
					LA93_:;
				}
				{
					eqdestroy___system_u2691(res_9);
					eqdestroy___system_u2691(res_8);
					eqdestroy___system_u2691(orExpr_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			}
LA64_: ;
			T149_ = (NimStringV2*)0;
			T149_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			addIndent__cgen_u315(p_p0, T149_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			T150_ = (NimStringV2*)0;
			T150_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			res_4 = rawNewString(((NI)80));
			colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3227);
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			cgFormatValue__cgen_u163((&res_4), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			prepareAdd((&res_4), 3);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3228);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA153_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3229);
			}
LA153_: ;
			prepareAdd((&(*T150_)), res_4.len + 0);
appendString((&(*T150_)), res_4);
			T155_ = (NimStringV2*)0;
			T155_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			addIndent__cgen_u315(p_p0, T155_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			T156_ = (NimStringV2*)0;
			T156_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			res_5 = rawNewString(((NI)80));
			prepareAdd((&res_5), 2);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3230);
			cgFormatValue__cgen_u166((&res_5), ((NI64) (nextExcept_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3231);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA159_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3232);
			}
LA159_: ;
			prepareAdd((&(*T156_)), res_5.len + 0);
appendString((&(*T156_)), res_5);
			endBlock__cgen_u15767(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			i_1 += ((NI)1);
			{
				LA56_:;
			}
			{
				eqdestroy___system_u2691(res_5);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(res_4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA52: ;
	}
	pop__cgen_u16349((&(*p_p0).nestedTryStmts), (&colontmpD__4));
	(void)(colontmpD__4);
	endBlock__cgen_u15767(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T165_;
		NI T166_;
		NimStringV2 res_12;
		NimStringV2* T171_;
		NimStringV2* T172_;
		NI T177_;
		T165_ = (NIM_BOOL)0;
		T166_ = (NI)0;
		T166_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T165_ = (i_1 < T166_);
		if (!(T165_)) goto LA167_;
		T165_ = ((*(*t_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107));
LA167_: ;
		if (!T165_) goto LA168_;
		res_12.len = 0; res_12.p = NIM_NIL;
		T171_ = (NimStringV2*)0;
		T171_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
		addIndent__cgen_u315(p_p0, T171_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
		T172_ = (NimStringV2*)0;
		T172_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
		res_12 = rawNewString(((NI)80));
		prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3233);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA175_;
			prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3234);
		}
LA175_: ;
		prepareAdd((&(*T172_)), res_12.len + 0);
appendString((&(*T172_)), res_12);
		T177_ = (NI)0;
		T177_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
		{
			NIM_BOOL T180_;
			T180_ = (NIM_BOOL)0;
			T180_ = bodyCanRaise__cgen_u18917(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
			if (!!(T180_)) goto LA181_;
			genStmts__cgen_u14081(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
		}
		goto LA178_;
LA181_: ;
		{
			NimStringV2 res_13;
			NimStringV2 res_14;
			NimStringV2 res_15;
			NimStringV2* T185_;
			NimStringV2* T190_;
			NimStringV2* T191_;
			NimStringV2* T196_;
			NimStringV2* T197_;
			res_13.len = 0; res_13.p = NIM_NIL;
			res_14.len = 0; res_14.p = NIM_NIL;
			res_15.len = 0; res_15.p = NIM_NIL;
			T185_ = (NimStringV2*)0;
			T185_ = procSec__cgendata_u464(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			res_13 = rawNewString(((NI)80));
			prepareAdd((&res_13), 21);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3236);
			cgFormatValue__cgen_u166((&res_13), ((NI64) (lab_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			prepareAdd((&res_13), 2);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3237);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA188_;
				prepareAdd((&res_13), 1);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3238);
			}
LA188_: ;
			prepareAdd((&(*T185_)), res_13.len + 0);
appendString((&(*T185_)), res_13);
			T190_ = (NimStringV2*)0;
			T190_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			addIndent__cgen_u315(p_p0, T190_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			T191_ = (NimStringV2*)0;
			T191_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			res_14 = rawNewString(((NI)80));
			prepareAdd((&res_14), 12);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_3240);
			cgFormatValue__cgen_u166((&res_14), ((NI64) (lab_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			prepareAdd((&res_14), 35);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_3242);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA194_;
				prepareAdd((&res_14), 1);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_3243);
			}
LA194_: ;
			prepareAdd((&(*T191_)), res_14.len + 0);
appendString((&(*T191_)), res_14);
			genStmts__cgen_u14081(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			T196_ = (NimStringV2*)0;
			T196_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			addIndent__cgen_u315(p_p0, T196_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			T197_ = (NimStringV2*)0;
			T197_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			res_15 = rawNewString(((NI)80));
			prepareAdd((&res_15), 23);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3245);
			cgFormatValue__cgen_u166((&res_15), ((NI64) (lab_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
			prepareAdd((&res_15), 2);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3246);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA200_;
				prepareAdd((&res_15), 1);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3247);
			}
LA200_: ;
			prepareAdd((&(*T197_)), res_15.len + 0);
appendString((&(*T197_)), res_15);
			{
				LA184_:;
			}
			{
				eqdestroy___system_u2691(res_15);
				eqdestroy___system_u2691(res_14);
				eqdestroy___system_u2691(res_13);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
		}
LA178_: ;
		endBlock__cgen_u15767(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA170_;
		{
			LA170_:;
		}
		{
			eqdestroy___system_u2691(res_12);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA168_: ;
	raiseExit__cgen_u14106(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!hasExcept_1) goto LA208_;
		(*p_p0).withinTryWithExcept += ((NI)1);
	}
LA208_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u1158(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(res_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRestoreFrameAfterException__cgen_u18320)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD_;
		NimStringV2* T23_;
		NimStringV2* T24_;
		if (!(((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0)) goto LA3_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		{
			NimStringV2 res_2;
			NimStringV2 res_3;
			NimStringV2 colontmpD__2;
			NimStringV2* T11_;
			NimStringV2* T16_;
			if (!!((((*p_p0).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)2)))&7U)))!=0))) goto LA8_;
			res_2.len = 0; res_2.p = NIM_NIL;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)2))) & 7);
			T11_ = (NimStringV2*)0;
			T11_ = procSec__cgendata_u464(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 22);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3271);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA14_;
				prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3272);
			}
LA14_: ;
			prepareAdd((&(*T11_)), res_2.len + 0);
appendString((&(*T11_)), res_2);
			T16_ = (NimStringV2*)0;
			T16_ = procSec__cgendata_u464(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 16);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3274);
			colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3276);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3277);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA19_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3278);
			}
LA19_: ;
			prepareAdd((&(*T16_)), res_3.len + 0);
appendString((&(*T16_)), res_3);
			{
				LA10_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(res_3);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA8_: ;
		T23_ = (NimStringV2*)0;
		T23_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		addIndent__cgen_u315(p_p0, T23_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T24_ = (NimStringV2*)0;
		T24_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		res_1 = rawNewString(((NI)80));
		colontmpD_ = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3280);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		cgFormatValue__cgen_u163((&res_1), colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&res_1), 15);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3282);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA27_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3283);
		}
LA27_: ;
		prepareAdd((&(*T24_)), res_1.len + 0);
appendString((&(*T24_)), res_1);
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTryCpp__cgen_u18373)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	NimStringV2 res_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fin_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NimStringV2 res_2;
	NimStringV2 colontmpD__2;
	NimStringV2 res_3;
	NimStringV2 res_4;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA colontmpD__3;
	NI etmp_1;
	NimStringV2* T10_;
	NimStringV2* T11_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA T24_;
	NimStringV2* T55_;
	NimStringV2* T56_;
	NimStringV2* T61_;
	NimStringV2* T62_;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T67_;
	NIM_BOOL hasImportedCppExceptions_1;
	NI i_1;
	NIM_BOOL hasIf_1;
	NIM_BOOL hasElse_1;
NIM_BOOL oldNimErrFin113_;
NIM_BOOL oldNimErrFin108_;
	NimStringV2* T222_;
	NimStringV2* T223_;
	NIM_BOOL catchAllPresent_1;
NIM_BOOL oldNimErrFin276_;
NIM_BOOL oldNimErrFin265_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	res_1.len = 0; res_1.p = NIM_NIL;
	fin_1 = NIM_NIL;
	res_2.len = 0; res_2.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	res_3.len = 0; res_3.p = NIM_NIL;
	res_4.len = 0; res_4.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__3), sizeof(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA));
	includeHeader__cgendata_u217((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3249);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T9_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = isEmptyType__ast_u7234((*t_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !(T5_);
		if (!(T4_)) goto LA6_;
		T4_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
LA6_: ;
		if (!T4_) goto LA7_;
		nimZeroMem((void*)(&T9_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*t_p1).typField, NIM_FALSE, (&T9_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&(*d_p2)), T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	genLineDir__cgen_u418(p_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).labels += ((NI)2);
	etmp_1 = (*p_p0).labels;
	T10_ = (NimStringV2*)0;
	T10_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_ = (NimStringV2*)0;
	T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 20);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3251);
	cgFormatValue__cgen_u166((&res_1), ((NI64) (etmp_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3252);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA14_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3253);
	}
LA14_: ;
	prepareAdd((&(*T11_)), res_1.len + 0);
appendString((&(*T11_)), res_1);
	T16_ = NIM_NIL;
	{
		NI T19_;
		NI T22_;
		T19_ = (NI)0;
		T19_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*(*t_p1)._kind_6.sons.p->data[(NI)(T19_ - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107))) goto LA20_;
		T22_ = (NI)0;
		T22_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		fin_1 = (*t_p1)._kind_6.sons.p->data[(NI)(T22_ - ((NI)1))];
	}
	goto LA17_;
LA20_: ;
	{
		fin_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA17_: ;
	nimZeroMem((void*)(&T24_), sizeof(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA));
	colontmpD_ = eqdup___ast_u3258(fin_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T24_.Field0 = colontmpD_;
	T24_.Field1 = NIM_FALSE;
	T24_.Field2 = ((NI)0);
	add__cgen_u16386((&(*p_p0).nestedTryStmts), T24_);
	{
		NimStringV2 res_5;
		NimStringV2 res_6;
		NimStringV2* T30_;
		NimStringV2* T31_;
		NimStringV2* T36_;
		NimStringV2* T37_;
		if (!((*t_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)154))) goto LA27_;
		res_5.len = 0; res_5.p = NIM_NIL;
		res_6.len = 0; res_6.p = NIM_NIL;
		T30_ = (NimStringV2*)0;
		T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		addIndent__cgen_u315(p_p0, T30_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		T31_ = (NimStringV2*)0;
		T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		res_5 = rawNewString(((NI)80));
		prepareAdd((&res_5), 5);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3255);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA34_;
			prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3256);
		}
LA34_: ;
		prepareAdd((&(*T31_)), res_5.len + 0);
appendString((&(*T31_)), res_5);
		expr__cgen_u14084(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		T36_ = (NimStringV2*)0;
		T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		addIndent__cgen_u315(p_p0, T36_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		T37_ = (NimStringV2*)0;
		T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA29_;
		res_6 = rawNewString(((NI)80));
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3257);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA40_;
			prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3258);
		}
LA40_: ;
		prepareAdd((&(*T37_)), res_6.len + 0);
appendString((&(*T37_)), res_6);
		{
			LA29_:;
		}
		{
			eqdestroy___system_u2691(res_6);
			eqdestroy___system_u2691(res_5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA25_;
LA27_: ;
	{
		NimStringV2 res_7;
		NimStringV2* T46_;
		NimStringV2* T47_;
		NI T52_;
		res_7.len = 0; res_7.p = NIM_NIL;
		T46_ = (NimStringV2*)0;
		T46_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		addIndent__cgen_u315(p_p0, T46_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T47_ = (NimStringV2*)0;
		T47_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		res_7 = rawNewString(((NI)80));
		prepareAdd((&res_7), 5);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3259);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA50_;
			prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3260);
		}
LA50_: ;
		prepareAdd((&(*T47_)), res_7.len + 0);
appendString((&(*T47_)), res_7);
		T52_ = (NI)0;
		T52_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		expr__cgen_u14084(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		endBlock__cgen_u15767(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		{
			LA45_:;
		}
		{
			eqdestroy___system_u2691(res_7);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA25_: ;
	T55_ = (NimStringV2*)0;
	T55_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T55_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T56_ = (NimStringV2*)0;
	T56_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_2 = rawNewString(((NI)80));
	prepareAdd((&res_2), 7);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3262);
	colontmpD__2 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3264);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_2), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3266);
	cgFormatValue__cgen_u166((&res_2), ((NI64) ((NI)(etmp_1 + ((NI)1)))));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_2), 4);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3268);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA59_;
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3269);
	}
LA59_: ;
	prepareAdd((&(*T56_)), res_2.len + 0);
appendString((&(*T56_)), res_2);
	genRestoreFrameAfterException__cgen_u18320(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T61_ = (NimStringV2*)0;
	T61_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T61_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T62_ = (NimStringV2*)0;
	T62_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_3 = rawNewString(((NI)80));
	prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3284);
	cgFormatValue__cgen_u166((&res_3), ((NI64) (etmp_1)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_3), 29);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3286);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA65_;
		prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3287);
	}
LA65_: ;
	prepareAdd((&(*T62_)), res_3.len + 0);
appendString((&(*T62_)), res_3);
	T67_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
	T67_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*T67_).Field1 = NIM_TRUE;
	hasImportedCppExceptions_1 = NIM_FALSE;
	i_1 = ((NI)1);
	hasIf_1 = NIM_FALSE;
	hasElse_1 = NIM_FALSE;
	{
		while (1) {
			NIM_BOOL T70_;
			NI T71_;
			T70_ = (NIM_BOOL)0;
			T71_ = (NI)0;
			T71_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T70_ = (i_1 < T71_);
			if (!(T70_)) goto LA72_;
			T70_ = ((*(*t_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87));
LA72_: ;
			if (!T70_) goto LA69;
			{
				NIM_BOOL T75_;
				T75_ = (NIM_BOOL)0;
				T75_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1));
				if (!(T75_)) goto LA76_;
				T75_ = isEmptyType__ast_u7234((*t_p1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA76_: ;
				if (!T75_) goto LA77_;
				(*d_p2).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0);
			}
LA77_: ;
			{
				NI T81_;
				NimStringV2 res_8;
				NimStringV2 res_9;
				NimStringV2 colontmpD__4;
				NimStringV2* T92_;
				NimStringV2* T93_;
				NI T98_;
				NimStringV2* T99_;
				NimStringV2* T100_;
				T81_ = (NI)0;
				T81_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(T81_ == ((NI)1))) goto LA82_;
				res_8.len = 0; res_8.p = NIM_NIL;
				res_9.len = 0; res_9.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				hasImportedCppExceptions_1 = NIM_TRUE;
				hasElse_1 = NIM_TRUE;
				{
					NimStringV2 colontmpD__5;
					NimStringV2* T89_;
					NimStringV2* T90_;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T91_;
					if (!hasIf_1) goto LA87_;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					T89_ = (NimStringV2*)0;
					T89_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					addIndent__cgen_u315(p_p0, T89_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					T90_ = (NimStringV2*)0;
					T90_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					colontmpD__5 = percent___cgen_u18494(T91_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
					prepareAdd((&(*T90_)), colontmpD__5.len + 0);
appendString((&(*T90_)), colontmpD__5);
					eqdestroy___system_u2691(colontmpD__5);
				}
LA87_: ;
				T92_ = (NimStringV2*)0;
				T92_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				addIndent__cgen_u315(p_p0, T92_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				T93_ = (NimStringV2*)0;
				T93_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				res_8 = rawNewString(((NI)80));
				prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3288);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA96_;
					prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3289);
				}
LA96_: ;
				prepareAdd((&(*T93_)), res_8.len + 0);
appendString((&(*T93_)), res_8);
				T98_ = (NI)0;
				T98_ = startBlockInternal__cgen_u15729(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], d_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				T99_ = (NimStringV2*)0;
				T99_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				addIndent__cgen_u315(p_p0, T99_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				T100_ = (NimStringV2*)0;
				T100_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				res_9 = rawNewString(((NI)80));
				colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3290);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				cgFormatValue__cgen_u163((&res_9), colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				prepareAdd((&res_9), 3);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3291);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA103_;
					prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3292);
				}
LA103_: ;
				prepareAdd((&(*T100_)), res_9.len + 0);
appendString((&(*T100_)), res_9);
				endBlock__cgen_u15767(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA84_;
				{
					LA84_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(res_9);
					eqdestroy___system_u2691(res_8);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA79_;
LA82_: ;
			{
				NimStringV2 orExpr_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* exvar_1;
				orExpr_1.len = 0; orExpr_1.p = NIM_NIL;
				exvar_1 = NIM_NIL;
				orExpr_1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
				exvar_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
				{
					NI j_1;
					NI colontmp_;
					NI T110_;
					NI i_2;
					j_1 = (NI)0;
					colontmp_ = (NI)0;
					T110_ = (NI)0;
					T110_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
					colontmp_ = (NI)(T110_ - ((NI)1));
					i_2 = ((NI)0);
					{
						while (1) {
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* typeNode_1;
							if (!(i_2 < colontmp_)) goto LA112;
							typeNode_1 = NIM_NIL;
							j_1 = i_2;
							eqcopy___ast_u3255(&typeNode_1, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
							{
								NIM_BOOL T116_;
								T116_ = (NIM_BOOL)0;
								T116_ = isInfixAs__ast_u7333((*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
								if (!T116_) goto LA117_;
								eqcopy___ast_u3255(&typeNode_1, (*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)1)]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
								eqcopy___ast_u3255(&exvar_1, (*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1])._kind_6.sons.p->data[((NI)2)]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
							}
LA117_: ;
							{
								NIM_BOOL T121_;
								T121_ = (NIM_BOOL)0;
								T121_ = isImportedException__ast_u7302((*typeNode_1).typField, (*(*(*p_p0).module).g).config);
								if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
								if (!T121_) goto LA122_;
								hasImportedCppExceptions_1 = NIM_TRUE;
							}
							goto LA119_;
LA122_: ;
							{
								NimStringV2 memberName_1;
								NimStringV2 T130_;
								memberName_1.len = 0; memberName_1.p = NIM_NIL;
								{
									if (!!((orExpr_1.len == ((NI)0)))) goto LA128_;
									prepareAdd((&orExpr_1), 2);
appendString((&orExpr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3293);
								}
LA128_: ;
								T130_.len = 0; T130_.p = NIM_NIL;
								{
									NIM_BOOL T133_;
									T133_ = (NIM_BOOL)0;
									T133_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
									if (T133_) goto LA134_;
									T133_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA134_: ;
									if (!T133_) goto LA135_;
									memberName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3294;
								}
								goto LA131_;
LA135_: ;
								{
									memberName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3295;
								}
LA131_: ;
								{
									NimStringV2 checkFor_1;
									NimStringV2 res_10;
									NimStringV2 colontmpD__6;
									NimStringV2 colontmpD__7;
									NimStringV2 colontmpD__8;
									NI16 T143_;
									tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T144_;
									NU32 T145_;
									if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA140_;
									checkFor_1.len = 0; checkFor_1.p = NIM_NIL;
									res_10.len = 0; res_10.p = NIM_NIL;
									colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
									colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
									colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
									T143_ = (NI16)0;
									T143_ = getObjDepth__cgen_u10096((*typeNode_1).typField);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									checkFor_1 = dollar___systemZdollars_u19(T143_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									res_10 = rawNewString(((NI)80));
									colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3296);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									cgFormatValue__cgen_u163((&res_10), colontmpD__6);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3297);
									colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3298);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									cgFormatValue__cgen_u163((&res_10), colontmpD__7);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									prepareAdd((&res_10), 4);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3299);
									cgFormatValue__cgen_u163((&res_10), memberName_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									prepareAdd((&res_10), 2);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3300);
									cgFormatValue__cgen_u163((&res_10), checkFor_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									prepareAdd((&res_10), 2);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3301);
									nimZeroMem((void*)T144_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
									hashType__sighashes_u411((*typeNode_1).typField, (*(*(*p_p0).module).g).config, 2, T144_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									T145_ = (NU32)0;
									T145_ = genDisplayElem__cgen_u10109(T144_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									colontmpD__8 = dollar___systemZdollars_u49(T145_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									cgFormatValue__cgen_u163((&res_10), colontmpD__8);
									if (NIM_UNLIKELY(*nimErr_)) goto LA142_;
									prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3302);
									prepareAdd((&orExpr_1), res_10.len + 0);
appendString((&orExpr_1), res_10);
									{
										LA142_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__8);
										eqdestroy___system_u2691(colontmpD__7);
										eqdestroy___system_u2691(colontmpD__6);
										eqdestroy___system_u2691(res_10);
										eqdestroy___system_u2691(checkFor_1);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
								}
								goto LA138_;
LA140_: ;
								{
									NimStringV2 checkFor_2;
									NimStringV2 res_11;
									NimStringV2 colontmpD__9;
									NimStringV2 colontmpD__10;
									checkFor_2.len = 0; checkFor_2.p = NIM_NIL;
									res_11.len = 0; res_11.p = NIM_NIL;
									colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
									colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
									checkFor_2 = genTypeInfoV1__cgen_u9076((*p_p0).module, (*typeNode_1).typField, (*typeNode_1).info);
									if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
									res_11 = rawNewString(((NI)80));
									colontmpD__9 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3303);
									if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
									cgFormatValue__cgen_u163((&res_11), colontmpD__9);
									if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
									prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3304);
									colontmpD__10 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3305);
									if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
									cgFormatValue__cgen_u163((&res_11), colontmpD__10);
									if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
									prepareAdd((&res_11), 4);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3306);
									cgFormatValue__cgen_u163((&res_11), memberName_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
									prepareAdd((&res_11), 2);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3307);
									cgFormatValue__cgen_u163((&res_11), checkFor_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
									prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3308);
									prepareAdd((&orExpr_1), res_11.len + 0);
appendString((&orExpr_1), res_11);
									{
										LA149_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__10);
										eqdestroy___system_u2691(colontmpD__9);
										eqdestroy___system_u2691(res_11);
										eqdestroy___system_u2691(checkFor_2);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
								}
LA138_: ;
								{
									LA125_:;
								}
								{
									eqdestroy___system_u2691(memberName_1);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
							}
LA119_: ;
							i_2 += ((NI)1);
							{
								LA113_:;
							}
							{
								oldNimErrFin113_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(typeNode_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
								*nimErr_ = oldNimErrFin113_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
						} LA112: ;
					}
				}
				{
					NimStringV2 res_12;
					NimStringV2 res_13;
					NimStringV2 colontmpD__11;
					NimStringV2* T193_;
					NimStringV2* T194_;
					NI T199_;
					NimStringV2* T200_;
					NimStringV2* T201_;
					if (!!((orExpr_1.len == ((NI)0)))) goto LA158_;
					res_12.len = 0; res_12.p = NIM_NIL;
					res_13.len = 0; res_13.p = NIM_NIL;
					colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
					{
						NimStringV2 res_14;
						NimStringV2* T165_;
						NimStringV2* T166_;
						NI T171_;
						if (!hasIf_1) goto LA163_;
						res_14.len = 0; res_14.p = NIM_NIL;
						T165_ = (NimStringV2*)0;
						T165_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						addIndent__cgen_u315(p_p0, T165_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						T166_ = (NimStringV2*)0;
						T166_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						res_14 = rawNewString(((NI)80));
						prepareAdd((&res_14), 9);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_3310);
						cgFormatValue__cgen_u163((&res_14), orExpr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						prepareAdd((&res_14), 3);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_3311);
						{
							if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA169_;
							prepareAdd((&res_14), 1);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_3312);
						}
LA169_: ;
						prepareAdd((&(*T166_)), res_14.len + 0);
appendString((&(*T166_)), res_14);
						T171_ = (NI)0;
						T171_ = startBlockInternal__cgen_u15729(p_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						eqdestroy___system_u2691(res_14);
					}
					goto LA161_;
LA163_: ;
					{
						NimStringV2 res_15;
						NimStringV2* T173_;
						NimStringV2* T174_;
						NI T179_;
						res_15.len = 0; res_15.p = NIM_NIL;
						T173_ = (NimStringV2*)0;
						T173_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						addIndent__cgen_u315(p_p0, T173_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						T174_ = (NimStringV2*)0;
						T174_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						res_15 = rawNewString(((NI)80));
						prepareAdd((&res_15), 4);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3313);
						cgFormatValue__cgen_u163((&res_15), orExpr_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						prepareAdd((&res_15), 3);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3314);
						{
							if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA177_;
							prepareAdd((&res_15), 1);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3315);
						}
LA177_: ;
						prepareAdd((&(*T174_)), res_15.len + 0);
appendString((&(*T174_)), res_15);
						T179_ = (NI)0;
						T179_ = startBlockInternal__cgen_u15729(p_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
						hasIf_1 = NIM_TRUE;
						eqdestroy___system_u2691(res_15);
					}
LA161_: ;
					{
						NimStringV2 res_16;
						NimStringV2 colontmpD__12;
						NimStringV2 colontmpD__13;
						NimStringV2 colontmpD__14;
						NimStringV2* T185_;
						NimStringV2* T186_;
						if (!!((exvar_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA182_;
						res_16.len = 0; res_16.p = NIM_NIL;
						colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
						colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
						colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
						fillLocalName__cgen_u920(p_p0, (*exvar_1)._kind_4.sym);
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						fillLoc__cgen_u88((&(*(*exvar_1)._kind_4.sym).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1), exvar_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						T185_ = (NimStringV2*)0;
						T185_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						addIndent__cgen_u315(p_p0, T185_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						T186_ = (NimStringV2*)0;
						T186_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						res_16 = rawNewString(((NI)80));
						colontmpD__12 = getTypeDesc__cgen_u8738((*p_p0).module, (*(*exvar_1)._kind_4.sym).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						cgFormatValue__cgen_u163((&res_16), colontmpD__12);
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						prepareAdd((&res_16), 1);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_3316);
						colontmpD__13 = rdLoc__cgen_u470((*(*exvar_1)._kind_4.sym).loc);
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						cgFormatValue__cgen_u163((&res_16), colontmpD__13);
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						prepareAdd((&res_16), 4);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_3318);
						colontmpD__14 = rope__ropes_u15(((NI64) ((NI)(etmp_1 + ((NI)1)))));
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						cgFormatValue__cgen_u163((&res_16), colontmpD__14);
						if (NIM_UNLIKELY(*nimErr_)) goto LA184_;
						prepareAdd((&res_16), 2);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_3319);
						{
							if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA189_;
							prepareAdd((&res_16), 1);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_3320);
						}
LA189_: ;
						prepareAdd((&(*T186_)), res_16.len + 0);
appendString((&(*T186_)), res_16);
						{
							LA184_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__14);
							eqdestroy___system_u2691(colontmpD__13);
							eqdestroy___system_u2691(colontmpD__12);
							eqdestroy___system_u2691(res_16);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					}
LA182_: ;
					T193_ = (NimStringV2*)0;
					T193_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					addIndent__cgen_u315(p_p0, T193_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					T194_ = (NimStringV2*)0;
					T194_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					res_12 = rawNewString(((NI)80));
					prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3321);
					cgFormatValue__cgen_u166((&res_12), ((NI64) (etmp_1)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					prepareAdd((&res_12), 12);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3323);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA197_;
						prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3324);
					}
LA197_: ;
					prepareAdd((&(*T194_)), res_12.len + 0);
appendString((&(*T194_)), res_12);
					T199_ = (NI)0;
					T199_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[(NI)(T199_ - ((NI)1))], d_p2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					T200_ = (NimStringV2*)0;
					T200_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					addIndent__cgen_u315(p_p0, T200_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					T201_ = (NimStringV2*)0;
					T201_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					res_13 = rawNewString(((NI)80));
					colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3325);
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					cgFormatValue__cgen_u163((&res_13), colontmpD__11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					prepareAdd((&res_13), 3);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3326);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA204_;
						prepareAdd((&res_13), 1);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3327);
					}
LA204_: ;
					prepareAdd((&(*T201_)), res_13.len + 0);
appendString((&(*T201_)), res_13);
					endBlock__cgen_u15767(p_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA160_;
					{
						LA160_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__11);
						eqdestroy___system_u2691(res_13);
						eqdestroy___system_u2691(res_12);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
				}
LA158_: ;
				{
					LA108_:;
				}
				{
					oldNimErrFin108_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(exvar_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(orExpr_1);
					*nimErr_ = oldNimErrFin108_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA79_: ;
			i_1 += ((NI)1);
		} LA69: ;
	}
	{
		NIM_BOOL T212_;
		NimStringV2 res_17;
		NimStringV2* T216_;
		NimStringV2* T217_;
		T212_ = (NIM_BOOL)0;
		T212_ = hasIf_1;
		if (!(T212_)) goto LA213_;
		T212_ = !(hasElse_1);
LA213_: ;
		if (!T212_) goto LA214_;
		res_17.len = 0; res_17.p = NIM_NIL;
		T216_ = (NimStringV2*)0;
		T216_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T216_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T217_ = (NimStringV2*)0;
		T217_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_17 = rawNewString(((NI)80));
		prepareAdd((&res_17), 11);
appendString((&res_17), TM__MQdRN7fpbG7rPm4JpVVAhA_3329);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA220_;
			prepareAdd((&res_17), 1);
appendString((&res_17), TM__MQdRN7fpbG7rPm4JpVVAhA_3330);
		}
LA220_: ;
		prepareAdd((&(*T217_)), res_17.len + 0);
appendString((&(*T217_)), res_17);
		eqdestroy___system_u2691(res_17);
	}
LA214_: ;
	T222_ = (NimStringV2*)0;
	T222_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T222_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T223_ = (NimStringV2*)0;
	T223_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_4 = rawNewString(((NI)80));
	prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3331);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA226_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3332);
	}
LA226_: ;
	prepareAdd((&(*T223_)), res_4.len + 0);
appendString((&(*T223_)), res_4);
	catchAllPresent_1 = NIM_FALSE;
	(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)3))) & 7);
	{
		if (!hasImportedCppExceptions_1) goto LA230_;
		{
			NI i_3;
			NI colontmp__2;
			NI i_4;
			i_3 = (NI)0;
			colontmp__2 = (NI)0;
			colontmp__2 = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_4 = ((NI)1);
			{
				while (1) {
					if (!(i_4 < colontmp__2)) goto LA234;
					i_3 = i_4;
					{
						if (!!(((*(*t_p1)._kind_6.sons.p->data[i_3]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87)))) goto LA237_;
						goto LA232;
					}
LA237_: ;
					{
						NIM_BOOL T241_;
						T241_ = (NIM_BOOL)0;
						T241_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1));
						if (!(T241_)) goto LA242_;
						T241_ = isEmptyType__ast_u7234((*t_p1).typField);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA242_: ;
						if (!T241_) goto LA243_;
						(*d_p2).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0);
					}
LA243_: ;
					{
						NI T247_;
						NimStringV2 res_18;
						NimStringV2* T251_;
						NimStringV2* T252_;
						NI T257_;
						T247_ = (NI)0;
						T247_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!(T247_ == ((NI)1))) goto LA248_;
						res_18.len = 0; res_18.p = NIM_NIL;
						T251_ = (NimStringV2*)0;
						T251_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA250_;
						addIndent__cgen_u315(p_p0, T251_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA250_;
						T252_ = (NimStringV2*)0;
						T252_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA250_;
						res_18 = rawNewString(((NI)80));
						prepareAdd((&res_18), 13);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_3334);
						{
							if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA255_;
							prepareAdd((&res_18), 1);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_3335);
						}
LA255_: ;
						prepareAdd((&(*T252_)), res_18.len + 0);
appendString((&(*T252_)), res_18);
						T257_ = (NI)0;
						T257_ = startBlockInternal__cgen_u15729(p_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA250_;
						genRestoreFrameAfterException__cgen_u18320(p_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA250_;
						expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[((NI)0)], d_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA250_;
						endBlock__cgen_u15767(p_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA250_;
						catchAllPresent_1 = NIM_TRUE;
						{
							LA250_:;
						}
						{
							eqdestroy___system_u2691(res_18);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					goto LA245_;
LA248_: ;
					{
						{
							NI j_2;
							NI colontmp__3;
							NI T262_;
							NI i_5;
							j_2 = (NI)0;
							colontmp__3 = (NI)0;
							T262_ = (NI)0;
							T262_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_3]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							colontmp__3 = (NI)(T262_ - ((NI)1));
							i_5 = ((NI)0);
							{
								while (1) {
									tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* typeNode_2;
									if (!(i_5 < colontmp__3)) goto LA264;
									typeNode_2 = NIM_NIL;
									j_2 = i_5;
									eqcopy___ast_u3255(&typeNode_2, (*(*t_p1)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[j_2]);
									if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
									{
										NIM_BOOL T268_;
										T268_ = (NIM_BOOL)0;
										T268_ = isInfixAs__ast_u7333((*(*t_p1)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[j_2]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
										if (!T268_) goto LA269_;
										eqcopy___ast_u3255(&typeNode_2, (*(*(*t_p1)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[j_2])._kind_6.sons.p->data[((NI)1)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
										{
											NIM_BOOL T273_;
											tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* exvar_2;
											NimStringV2 res_19;
											NimStringV2 colontmpD__15;
											NimStringV2 colontmpD__16;
											NimStringV2* T277_;
											NimStringV2* T278_;
											NI T283_;
											NI T284_;
											T273_ = (NIM_BOOL)0;
											T273_ = isImportedException__ast_u7302((*typeNode_2).typField, (*(*(*p_p0).module).g).config);
											if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
											if (!T273_) goto LA274_;
											exvar_2 = NIM_NIL;
											res_19.len = 0; res_19.p = NIM_NIL;
											colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
											colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
											eqcopy___ast_u3255(&exvar_2, (*(*(*t_p1)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[j_2])._kind_6.sons.p->data[((NI)2)]);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											fillLocalName__cgen_u920(p_p0, (*exvar_2)._kind_4.sym);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											fillLoc__cgen_u88((&(*(*exvar_2)._kind_4.sym).loc), ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1), exvar_2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											T277_ = (NimStringV2*)0;
											T277_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											addIndent__cgen_u315(p_p0, T277_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											T278_ = (NimStringV2*)0;
											T278_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											res_19 = rawNewString(((NI)80));
											prepareAdd((&res_19), 7);
appendString((&res_19), TM__MQdRN7fpbG7rPm4JpVVAhA_3336);
											colontmpD__15 = getTypeDesc__cgen_u8738((*p_p0).module, (*typeNode_2).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											cgFormatValue__cgen_u163((&res_19), colontmpD__15);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											prepareAdd((&res_19), 2);
appendString((&res_19), TM__MQdRN7fpbG7rPm4JpVVAhA_3338);
											colontmpD__16 = rdLoc__cgen_u470((*(*exvar_2)._kind_4.sym).loc);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											cgFormatValue__cgen_u163((&res_19), colontmpD__16);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											prepareAdd((&res_19), 3);
appendString((&res_19), TM__MQdRN7fpbG7rPm4JpVVAhA_3339);
											{
												if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA281_;
												prepareAdd((&res_19), 1);
appendString((&res_19), TM__MQdRN7fpbG7rPm4JpVVAhA_3340);
											}
LA281_: ;
											prepareAdd((&(*T278_)), res_19.len + 0);
appendString((&(*T278_)), res_19);
											T283_ = (NI)0;
											T283_ = startBlockInternal__cgen_u15729(p_p0);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											genRestoreFrameAfterException__cgen_u18320(p_p0);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											T284_ = (NI)0;
											T284_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_3]);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[(NI)(T284_ - ((NI)1))], d_p2);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											endBlock__cgen_u15767(p_p0);
											if (NIM_UNLIKELY(*nimErr_)) goto LA276_;
											{
												LA276_:;
											}
											{
												oldNimErrFin276_ = *nimErr_; *nimErr_ = NIM_FALSE;
												eqdestroy___system_u2691(colontmpD__16);
												eqdestroy___system_u2691(colontmpD__15);
												eqdestroy___system_u2691(res_19);
												eqdestroy___ast_u3252(exvar_2);
												if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
												*nimErr_ = oldNimErrFin276_;
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
										}
LA274_: ;
									}
									goto LA266_;
LA269_: ;
									{
										NIM_BOOL T288_;
										NimStringV2 res_20;
										NimStringV2 colontmpD__17;
										NimStringV2* T292_;
										NimStringV2* T293_;
										NI T298_;
										NI T299_;
										T288_ = (NIM_BOOL)0;
										T288_ = isImportedException__ast_u7302((*typeNode_2).typField, (*(*(*p_p0).module).g).config);
										if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
										if (!T288_) goto LA289_;
										res_20.len = 0; res_20.p = NIM_NIL;
										colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
										T292_ = (NimStringV2*)0;
										T292_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										addIndent__cgen_u315(p_p0, T292_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										T293_ = (NimStringV2*)0;
										T293_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										res_20 = rawNewString(((NI)80));
										prepareAdd((&res_20), 7);
appendString((&res_20), TM__MQdRN7fpbG7rPm4JpVVAhA_3341);
										colontmpD__17 = getTypeDesc__cgen_u8738((*p_p0).module, (*(*(*t_p1)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[j_2]).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										cgFormatValue__cgen_u163((&res_20), colontmpD__17);
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										prepareAdd((&res_20), 4);
appendString((&res_20), TM__MQdRN7fpbG7rPm4JpVVAhA_3343);
										{
											if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA296_;
											prepareAdd((&res_20), 1);
appendString((&res_20), TM__MQdRN7fpbG7rPm4JpVVAhA_3344);
										}
LA296_: ;
										prepareAdd((&(*T293_)), res_20.len + 0);
appendString((&(*T293_)), res_20);
										T298_ = (NI)0;
										T298_ = startBlockInternal__cgen_u15729(p_p0);
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										genRestoreFrameAfterException__cgen_u18320(p_p0);
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										T299_ = (NI)0;
										T299_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_3]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[(NI)(T299_ - ((NI)1))], d_p2);
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										endBlock__cgen_u15767(p_p0);
										if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
										{
											LA291_:;
										}
										{
											eqdestroy___system_u2691(colontmpD__17);
											eqdestroy___system_u2691(res_20);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
									}
									goto LA266_;
LA289_: ;
LA266_: ;
									i_5 += ((NI)1);
									{
										LA265_:;
									}
									{
										oldNimErrFin265_ = *nimErr_; *nimErr_ = NIM_FALSE;
										eqdestroy___ast_u3252(typeNode_2);
										if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
										*nimErr_ = oldNimErrFin265_;
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								} LA264: ;
							}
						}
					}
LA245_: ;
					i_4 += ((NI)1);
				} LA234: ;
			}
		} LA232: ;
	}
LA230_: ;
	(*p_p0).flags &= ~(((NU8)1) << (((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)3))) & 7));
	pop__cgen_u16349((&(*p_p0).nestedTryStmts), (&colontmpD__3));
	(void)(colontmpD__3);
	{
		NIM_BOOL T306_;
		NI T307_;
		NI T309_;
		NimStringV2 res_21;
		NimStringV2 res_22;
		NimStringV2* T333_;
		NimStringV2* T334_;
		NI T339_;
		NI T340_;
		NimStringV2* T341_;
		NimStringV2* T342_;
		T306_ = (NIM_BOOL)0;
		T307_ = (NI)0;
		T307_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T306_ = (((NI)0) < T307_);
		if (!(T306_)) goto LA308_;
		T309_ = (NI)0;
		T309_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T306_ = ((*(*t_p1)._kind_6.sons.p->data[(NI)(T309_ - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107));
LA308_: ;
		if (!T306_) goto LA310_;
		res_21.len = 0; res_21.p = NIM_NIL;
		res_22.len = 0; res_22.p = NIM_NIL;
		{
			NimStringV2 res_23;
			NimStringV2 res_24;
			NimStringV2* T318_;
			NimStringV2* T319_;
			NI T324_;
			NimStringV2* T325_;
			NimStringV2* T326_;
			if (!!(catchAllPresent_1)) goto LA315_;
			res_23.len = 0; res_23.p = NIM_NIL;
			res_24.len = 0; res_24.p = NIM_NIL;
			T318_ = (NimStringV2*)0;
			T318_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			addIndent__cgen_u315(p_p0, T318_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			T319_ = (NimStringV2*)0;
			T319_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			res_23 = rawNewString(((NI)80));
			prepareAdd((&res_23), 13);
appendString((&res_23), TM__MQdRN7fpbG7rPm4JpVVAhA_3345);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA322_;
				prepareAdd((&res_23), 1);
appendString((&res_23), TM__MQdRN7fpbG7rPm4JpVVAhA_3346);
			}
LA322_: ;
			prepareAdd((&(*T319_)), res_23.len + 0);
appendString((&(*T319_)), res_23);
			T324_ = (NI)0;
			T324_ = startBlockInternal__cgen_u15729(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			genRestoreFrameAfterException__cgen_u18320(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			T325_ = (NimStringV2*)0;
			T325_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			addIndent__cgen_u315(p_p0, T325_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			T326_ = (NimStringV2*)0;
			T326_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			res_24 = rawNewString(((NI)80));
			prepareAdd((&res_24), 1);
appendString((&res_24), TM__MQdRN7fpbG7rPm4JpVVAhA_3347);
			cgFormatValue__cgen_u166((&res_24), ((NI64) (etmp_1)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			prepareAdd((&res_24), 29);
appendString((&res_24), TM__MQdRN7fpbG7rPm4JpVVAhA_3348);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA329_;
				prepareAdd((&res_24), 1);
appendString((&res_24), TM__MQdRN7fpbG7rPm4JpVVAhA_3349);
			}
LA329_: ;
			prepareAdd((&(*T326_)), res_24.len + 0);
appendString((&(*T326_)), res_24);
			endBlock__cgen_u15767(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA317_;
			{
				LA317_:;
			}
			{
				eqdestroy___system_u2691(res_24);
				eqdestroy___system_u2691(res_23);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		}
LA315_: ;
		T333_ = (NimStringV2*)0;
		T333_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		addIndent__cgen_u315(p_p0, T333_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		T334_ = (NimStringV2*)0;
		T334_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		res_21 = rawNewString(((NI)80));
		prepareAdd((&res_21), 1);
appendString((&res_21), TM__MQdRN7fpbG7rPm4JpVVAhA_3350);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA337_;
			prepareAdd((&res_21), 1);
appendString((&res_21), TM__MQdRN7fpbG7rPm4JpVVAhA_3351);
		}
LA337_: ;
		prepareAdd((&(*T334_)), res_21.len + 0);
appendString((&(*T334_)), res_21);
		T339_ = (NI)0;
		T339_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		T340_ = (NI)0;
		T340_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		genStmts__cgen_u14081(p_p0, (*(*t_p1)._kind_6.sons.p->data[(NI)(T340_ - ((NI)1))])._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		T341_ = (NimStringV2*)0;
		T341_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		addIndent__cgen_u315(p_p0, T341_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		T342_ = (NimStringV2*)0;
		T342_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		res_22 = rawNewString(((NI)80));
		prepareAdd((&res_22), 5);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3353);
		cgFormatValue__cgen_u166((&res_22), ((NI64) (etmp_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		prepareAdd((&res_22), 27);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3355);
		cgFormatValue__cgen_u166((&res_22), ((NI64) (etmp_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		prepareAdd((&res_22), 3);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3357);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA345_;
			prepareAdd((&res_22), 1);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3358);
		}
LA345_: ;
		prepareAdd((&(*T342_)), res_22.len + 0);
appendString((&(*T342_)), res_22);
		endBlock__cgen_u15767(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA312_;
		{
			LA312_:;
		}
		{
			eqdestroy___system_u2691(res_22);
			eqdestroy___system_u2691(res_21);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA310_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u1158(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(res_4);
		eqdestroy___system_u2691(res_3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(res_2);
		eqdestroy___system_u2691(res_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NimStringV2, pop__stdZprivateZosdirs_u415)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0) {
	NimStringV2 result;
	NI L_1;
	NI T1_;
	T1_ = (*s_p0).len;
	L_1 = (NI)(T1_ - ((NI)1));
	result = (*s_p0).p->data[L_1];
	eqwasMoved___system_u2688((&(*s_p0).p->data[L_1]));
	shrink__system_u5403(s_p0, (L_1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genTrySetjmp__cgen_u19232)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	NimStringV2 safePoint_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fin_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA colontmpD__2;
	NIM_BOOL quirkyExceptions_1;
	NIM_BOOL T10_;
	NIM_BOOL T12_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T118_;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA T126_;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T183_;
	NI i_1;
NIM_BOOL oldNimErrFin307_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	safePoint_1.len = 0; safePoint_1.p = NIM_NIL;
	fin_1 = NIM_NIL;
	nimZeroMem((void*)(&colontmpD__2), sizeof(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA));
	{
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T9_;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = isEmptyType__ast_u7234((*t_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = !(T5_);
		if (!(T4_)) goto LA6_;
		T4_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0));
LA6_: ;
		if (!T4_) goto LA7_;
		nimZeroMem((void*)(&T9_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		getTemp__cgen_u9546(p_p0, (*t_p1).typField, NIM_FALSE, (&T9_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u6293((&(*d_p2)), T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	T10_ = (NIM_BOOL)0;
	T10_ = ((*(*(*(*p_p0).module).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)4));
	if (T10_) goto LA11_;
	T12_ = (NIM_BOOL)0;
	T12_ = ((*t_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)154));
	if (!(T12_)) goto LA13_;
	T12_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0);
LA13_: ;
	T10_ = T12_;
LA11_: ;
	quirkyExceptions_1 = T10_;
	{
		if (!!(quirkyExceptions_1)) goto LA16_;
		includeHeader__cgendata_u217((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3360);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA14_;
LA16_: ;
	{
		(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)3))) & 7);
	}
LA14_: ;
	genLineDir__cgen_u418(p_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgsym__cgen_u138((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3361);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	safePoint_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3362;
	{
		NimStringV2 res_1;
		NimStringV2 colontmpD__3;
		NimStringV2 res_2;
		NimStringV2 colontmpD__4;
		NimStringV2 res_3;
		NimStringV2 T24_;
		NimStringV2* T25_;
		NimStringV2* T26_;
		NimStringV2* T31_;
		NimStringV2* T32_;
		NimStringV2* T110_;
		NimStringV2* T111_;
		if (!!(quirkyExceptions_1)) goto LA21_;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		res_3.len = 0; res_3.p = NIM_NIL;
		T24_.len = 0; T24_.p = NIM_NIL;
		T24_ = getTempName__cgen_u462((*p_p0).module);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T24_); goto LA23_;}
		eqsink___system_u2700((&safePoint_1), T24_);
		T25_ = (NimStringV2*)0;
		T25_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		addIndent__cgen_u315(p_p0, T25_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T26_ = (NimStringV2*)0;
		T26_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		res_1 = rawNewString(((NI)80));
		colontmpD__3 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3364);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3365);
		cgFormatValue__cgen_u163((&res_1), safePoint_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3366);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA29_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3367);
		}
LA29_: ;
		prepareAdd((&(*T26_)), res_1.len + 0);
appendString((&(*T26_)), res_1);
		T31_ = (NimStringV2*)0;
		T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		addIndent__cgen_u315(p_p0, T31_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T32_ = (NimStringV2*)0;
		T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		res_2 = rawNewString(((NI)80));
		colontmpD__4 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3369);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3370);
		cgFormatValue__cgen_u163((&res_2), safePoint_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		prepareAdd((&res_2), 2);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3371);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA35_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3372);
		}
LA35_: ;
		prepareAdd((&(*T32_)), res_2.len + 0);
appendString((&(*T32_)), res_2);
		{
			NIM_BOOL T39_;
			NimStringV2 res_4;
			NimStringV2* T42_;
			NimStringV2* T43_;
			T39_ = (NIM_BOOL)0;
			T39_ = isDefined__options_u959((*(*(*p_p0).module).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_3374);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			if (!T39_) goto LA40_;
			res_4.len = 0; res_4.p = NIM_NIL;
			T42_ = (NimStringV2*)0;
			T42_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			addIndent__cgen_u315(p_p0, T42_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T43_ = (NimStringV2*)0;
			T43_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			res_4 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_4), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_4), 17);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3376);
			cgFormatValue__cgen_u163((&res_4), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_4), 10);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3378);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA46_;
				prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3379);
			}
LA46_: ;
			prepareAdd((&(*T43_)), res_4.len + 0);
appendString((&(*T43_)), res_4);
			eqdestroy___system_u2691(res_4);
		}
		goto LA37_;
LA40_: ;
		{
			NIM_BOOL T49_;
			NimStringV2 res_5;
			NimStringV2* T52_;
			NimStringV2* T53_;
			T49_ = (NIM_BOOL)0;
			T49_ = isDefined__options_u959((*(*(*p_p0).module).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_3381);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			if (!T49_) goto LA50_;
			res_5.len = 0; res_5.p = NIM_NIL;
			T52_ = (NimStringV2*)0;
			T52_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			addIndent__cgen_u315(p_p0, T52_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T53_ = (NimStringV2*)0;
			T53_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			res_5 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_5), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_5), 20);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3383);
			cgFormatValue__cgen_u163((&res_5), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_5), 13);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3385);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA56_;
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3386);
			}
LA56_: ;
			prepareAdd((&(*T53_)), res_5.len + 0);
appendString((&(*T53_)), res_5);
			eqdestroy___system_u2691(res_5);
		}
		goto LA37_;
LA50_: ;
		{
			NIM_BOOL T59_;
			NimStringV2 res_6;
			NimStringV2* T62_;
			NimStringV2* T63_;
			T59_ = (NIM_BOOL)0;
			T59_ = isDefined__options_u959((*(*(*p_p0).module).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_3388);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			if (!T59_) goto LA60_;
			res_6.len = 0; res_6.p = NIM_NIL;
			T62_ = (NimStringV2*)0;
			T62_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			addIndent__cgen_u315(p_p0, T62_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T63_ = (NimStringV2*)0;
			T63_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			res_6 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_6), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_6), 27);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3390);
			cgFormatValue__cgen_u163((&res_6), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_6), 10);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3391);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA66_;
				prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3392);
			}
LA66_: ;
			prepareAdd((&(*T63_)), res_6.len + 0);
appendString((&(*T63_)), res_6);
			eqdestroy___system_u2691(res_6);
		}
		goto LA37_;
LA60_: ;
		{
			NIM_BOOL T69_;
			T69_ = (NIM_BOOL)0;
			T69_ = isDefined__options_u959((*(*(*p_p0).module).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_3394);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			if (!T69_) goto LA70_;
			{
				NIM_BOOL T74_;
				T74_ = (NIM_BOOL)0;
				T74_ = isDefined__options_u959((*(*(*p_p0).module).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_3396);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				if (!T74_) goto LA75_;
				{
					NIM_BOOL T79_;
					NimStringV2 res_7;
					NimStringV2* T83_;
					NimStringV2* T84_;
					T79_ = (NIM_BOOL)0;
					T79_ = isDefined__options_u959((*(*(*p_p0).module).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_3397);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					if (T79_) goto LA80_;
					T79_ = isDefined__options_u959((*(*(*p_p0).module).g).config, TM__MQdRN7fpbG7rPm4JpVVAhA_3399);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
LA80_: ;
					if (!T79_) goto LA81_;
					res_7.len = 0; res_7.p = NIM_NIL;
					T83_ = (NimStringV2*)0;
					T83_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					addIndent__cgen_u315(p_p0, T83_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					T84_ = (NimStringV2*)0;
					T84_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					res_7 = rawNewString(((NI)80));
					cgFormatValue__cgen_u163((&res_7), safePoint_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					prepareAdd((&res_7), 17);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3400);
					cgFormatValue__cgen_u163((&res_7), safePoint_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					prepareAdd((&res_7), 10);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3401);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA87_;
						prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3402);
					}
LA87_: ;
					prepareAdd((&(*T84_)), res_7.len + 0);
appendString((&(*T84_)), res_7);
					eqdestroy___system_u2691(res_7);
				}
				goto LA77_;
LA81_: ;
				{
					NimStringV2 res_8;
					NimStringV2* T90_;
					NimStringV2* T91_;
					res_8.len = 0; res_8.p = NIM_NIL;
					T90_ = (NimStringV2*)0;
					T90_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					addIndent__cgen_u315(p_p0, T90_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					T91_ = (NimStringV2*)0;
					T91_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					res_8 = rawNewString(((NI)80));
					cgFormatValue__cgen_u163((&res_8), safePoint_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					prepareAdd((&res_8), 18);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3404);
					cgFormatValue__cgen_u163((&res_8), safePoint_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
					prepareAdd((&res_8), 13);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3405);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA94_;
						prepareAdd((&res_8), 1);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3406);
					}
LA94_: ;
					prepareAdd((&(*T91_)), res_8.len + 0);
appendString((&(*T91_)), res_8);
					eqdestroy___system_u2691(res_8);
				}
LA77_: ;
			}
			goto LA72_;
LA75_: ;
			{
				NimStringV2 res_9;
				NimStringV2* T97_;
				NimStringV2* T98_;
				res_9.len = 0; res_9.p = NIM_NIL;
				T97_ = (NimStringV2*)0;
				T97_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				addIndent__cgen_u315(p_p0, T97_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				T98_ = (NimStringV2*)0;
				T98_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				res_9 = rawNewString(((NI)80));
				cgFormatValue__cgen_u163((&res_9), safePoint_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				prepareAdd((&res_9), 18);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3407);
				cgFormatValue__cgen_u163((&res_9), safePoint_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
				prepareAdd((&res_9), 10);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3408);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA101_;
					prepareAdd((&res_9), 1);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3409);
				}
LA101_: ;
				prepareAdd((&(*T98_)), res_9.len + 0);
appendString((&(*T98_)), res_9);
				eqdestroy___system_u2691(res_9);
			}
LA72_: ;
		}
		goto LA37_;
LA70_: ;
		{
			NimStringV2 res_10;
			NimStringV2* T104_;
			NimStringV2* T105_;
			res_10.len = 0; res_10.p = NIM_NIL;
			T104_ = (NimStringV2*)0;
			T104_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			addIndent__cgen_u315(p_p0, T104_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			T105_ = (NimStringV2*)0;
			T105_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			res_10 = rawNewString(((NI)80));
			cgFormatValue__cgen_u163((&res_10), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_10), 17);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3410);
			cgFormatValue__cgen_u163((&res_10), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			prepareAdd((&res_10), 10);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3411);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA108_;
				prepareAdd((&res_10), 1);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3412);
			}
LA108_: ;
			prepareAdd((&(*T105_)), res_10.len + 0);
appendString((&(*T105_)), res_10);
			eqdestroy___system_u2691(res_10);
		}
LA37_: ;
		T110_ = (NimStringV2*)0;
		T110_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		addIndent__cgen_u315(p_p0, T110_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		T111_ = (NimStringV2*)0;
		T111_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		res_3 = rawNewString(((NI)80));
		prepareAdd((&res_3), 4);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3413);
		cgFormatValue__cgen_u163((&res_3), safePoint_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
		prepareAdd((&res_3), 15);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3415);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA114_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3416);
		}
LA114_: ;
		prepareAdd((&(*T111_)), res_3.len + 0);
appendString((&(*T111_)), res_3);
		{
			LA23_:;
		}
		{
			eqdestroy___system_u2691(res_3);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(res_2);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(res_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA21_: ;
	T118_ = NIM_NIL;
	{
		NI T121_;
		NI T124_;
		T121_ = (NI)0;
		T121_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!((*(*t_p1)._kind_6.sons.p->data[(NI)(T121_ - ((NI)1))]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107))) goto LA122_;
		T124_ = (NI)0;
		T124_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		fin_1 = (*t_p1)._kind_6.sons.p->data[(NI)(T124_ - ((NI)1))];
	}
	goto LA119_;
LA122_: ;
	{
		fin_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA119_: ;
	nimZeroMem((void*)(&T126_), sizeof(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA));
	colontmpD_ = eqdup___ast_u3258(fin_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T126_.Field0 = colontmpD_;
	T126_.Field1 = quirkyExceptions_1;
	T126_.Field2 = ((NI)0);
	add__cgen_u16386((&(*p_p0).nestedTryStmts), T126_);
	expr__cgen_u14084(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], d_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 res_11;
		NimStringV2 colontmpD__5;
		NimStringV2 res_12;
		NimStringV2 res_13;
		NimStringV2 res_14;
		NimStringV2 colontmpD__6;
		NimStringV2* T132_;
		NimStringV2* T133_;
		NimStringV2* T138_;
		NimStringV2* T139_;
		NimStringV2* T144_;
		NimStringV2* T145_;
		NI T150_;
		NimStringV2* T151_;
		NimStringV2* T152_;
		if (!!(quirkyExceptions_1)) goto LA129_;
		res_11.len = 0; res_11.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		res_12.len = 0; res_12.p = NIM_NIL;
		res_13.len = 0; res_13.p = NIM_NIL;
		res_14.len = 0; res_14.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		T132_ = (NimStringV2*)0;
		T132_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		addIndent__cgen_u315(p_p0, T132_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		T133_ = (NimStringV2*)0;
		T133_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		res_11 = rawNewString(((NI)80));
		colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3417);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		cgFormatValue__cgen_u163((&res_11), colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		prepareAdd((&res_11), 3);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3418);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA136_;
			prepareAdd((&res_11), 1);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3419);
		}
LA136_: ;
		prepareAdd((&(*T133_)), res_11.len + 0);
appendString((&(*T133_)), res_11);
		T138_ = (NimStringV2*)0;
		T138_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		addIndent__cgen_u315(p_p0, T138_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		T139_ = (NimStringV2*)0;
		T139_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		res_12 = rawNewString(((NI)80));
		prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3420);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA142_;
			prepareAdd((&res_12), 1);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3421);
		}
LA142_: ;
		prepareAdd((&(*T139_)), res_12.len + 0);
appendString((&(*T139_)), res_12);
		T144_ = (NimStringV2*)0;
		T144_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		addIndent__cgen_u315(p_p0, T144_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		T145_ = (NimStringV2*)0;
		T145_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		res_13 = rawNewString(((NI)80));
		prepareAdd((&res_13), 6);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3423);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA148_;
			prepareAdd((&res_13), 1);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3424);
		}
LA148_: ;
		prepareAdd((&(*T145_)), res_13.len + 0);
appendString((&(*T145_)), res_13);
		T150_ = (NI)0;
		T150_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		T151_ = (NimStringV2*)0;
		T151_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		addIndent__cgen_u315(p_p0, T151_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		T152_ = (NimStringV2*)0;
		T152_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		res_14 = rawNewString(((NI)80));
		colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3425);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		cgFormatValue__cgen_u163((&res_14), colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		prepareAdd((&res_14), 3);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_3426);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA155_;
			prepareAdd((&res_14), 1);
appendString((&res_14), TM__MQdRN7fpbG7rPm4JpVVAhA_3427);
		}
LA155_: ;
		prepareAdd((&(*T152_)), res_14.len + 0);
appendString((&(*T152_)), res_14);
		genRestoreFrameAfterException__cgen_u18320(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA131_;
		{
			LA131_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(res_14);
			eqdestroy___system_u2691(res_13);
			eqdestroy___system_u2691(res_12);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(res_11);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA127_;
LA129_: ;
	{
		NIM_BOOL T160_;
		NI T161_;
		NimStringV2 res_15;
		NimStringV2 colontmpD__7;
		NimStringV2* T166_;
		NimStringV2* T167_;
		NI T172_;
		T160_ = (NIM_BOOL)0;
		T161_ = (NI)0;
		T161_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T160_ = (((NI)1) < T161_);
		if (!(T160_)) goto LA162_;
		T160_ = ((*(*t_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87));
LA162_: ;
		if (!T160_) goto LA163_;
		res_15.len = 0; res_15.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T166_ = (NimStringV2*)0;
		T166_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
		addIndent__cgen_u315(p_p0, T166_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
		T167_ = (NimStringV2*)0;
		T167_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
		res_15 = rawNewString(((NI)80));
		prepareAdd((&res_15), 4);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3428);
		colontmpD__7 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3429);
		if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
		cgFormatValue__cgen_u163((&res_15), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
		prepareAdd((&res_15), 5);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3431);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA170_;
			prepareAdd((&res_15), 1);
appendString((&res_15), TM__MQdRN7fpbG7rPm4JpVVAhA_3432);
		}
LA170_: ;
		prepareAdd((&(*T167_)), res_15.len + 0);
appendString((&(*T167_)), res_15);
		T172_ = (NI)0;
		T172_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
		{
			LA165_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(res_15);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA127_;
LA163_: ;
	{
		NimStringV2 res_16;
		NimStringV2* T176_;
		NimStringV2* T177_;
		NI T182_;
		res_16.len = 0; res_16.p = NIM_NIL;
		T176_ = (NimStringV2*)0;
		T176_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T176_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T177_ = (NimStringV2*)0;
		T177_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_16 = rawNewString(((NI)80));
		prepareAdd((&res_16), 1);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_3433);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA180_;
			prepareAdd((&res_16), 1);
appendString((&res_16), TM__MQdRN7fpbG7rPm4JpVVAhA_3434);
		}
LA180_: ;
		prepareAdd((&(*T177_)), res_16.len + 0);
appendString((&(*T177_)), res_16);
		T182_ = (NI)0;
		T182_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(res_16);
	}
LA127_: ;
	T183_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
	T183_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*T183_).Field1 = NIM_TRUE;
	i_1 = ((NI)1);
	{
		while (1) {
			NIM_BOOL T186_;
			NI T187_;
			T186_ = (NIM_BOOL)0;
			T187_ = (NI)0;
			T187_ = len__ast_u3190(t_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T186_ = (i_1 < T187_);
			if (!(T186_)) goto LA188_;
			T186_ = ((*(*t_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)87));
LA188_: ;
			if (!T186_) goto LA185;
			{
				NIM_BOOL T191_;
				T191_ = (NIM_BOOL)0;
				T191_ = ((*d_p2).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1));
				if (!(T191_)) goto LA192_;
				T191_ = isEmptyType__ast_u7234((*t_p1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA192_: ;
				if (!T191_) goto LA193_;
				(*d_p2).k = ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0);
			}
LA193_: ;
			{
				NI T197_;
				NimStringV2 res_17;
				NimStringV2 res_18;
				NimStringV2 colontmpD__8;
				NimStringV2* T208_;
				NimStringV2* T209_;
				NI T214_;
				NimStringV2* T225_;
				NimStringV2* T226_;
				T197_ = (NI)0;
				T197_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(T197_ == ((NI)1))) goto LA198_;
				res_17.len = 0; res_17.p = NIM_NIL;
				res_18.len = 0; res_18.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				{
					NimStringV2 colontmpD__9;
					NimStringV2* T205_;
					NimStringV2* T206_;
					tyArray__TonP9cxJgj8gXu71dWIyNlA T207_;
					if (!(((NI)1) < i_1)) goto LA203_;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					T205_ = (NimStringV2*)0;
					T205_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
					addIndent__cgen_u315(p_p0, T205_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
					T206_ = (NimStringV2*)0;
					T206_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
					colontmpD__9 = percent___cgen_u19034(T207_, 0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
					prepareAdd((&(*T206_)), colontmpD__9.len + 0);
appendString((&(*T206_)), colontmpD__9);
					eqdestroy___system_u2691(colontmpD__9);
				}
LA203_: ;
				T208_ = (NimStringV2*)0;
				T208_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				addIndent__cgen_u315(p_p0, T208_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				T209_ = (NimStringV2*)0;
				T209_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				res_17 = rawNewString(((NI)80));
				prepareAdd((&res_17), 1);
appendString((&res_17), TM__MQdRN7fpbG7rPm4JpVVAhA_3435);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA212_;
					prepareAdd((&res_17), 1);
appendString((&res_17), TM__MQdRN7fpbG7rPm4JpVVAhA_3436);
				}
LA212_: ;
				prepareAdd((&(*T209_)), res_17.len + 0);
appendString((&(*T209_)), res_17);
				T214_ = (NI)0;
				T214_ = startBlockInternal__cgen_u15729(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				{
					NimStringV2 res_19;
					NimStringV2* T219_;
					NimStringV2* T220_;
					if (!!(quirkyExceptions_1)) goto LA217_;
					res_19.len = 0; res_19.p = NIM_NIL;
					T219_ = (NimStringV2*)0;
					T219_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
					addIndent__cgen_u315(p_p0, T219_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
					T220_ = (NimStringV2*)0;
					T220_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
					res_19 = rawNewString(((NI)80));
					cgFormatValue__cgen_u163((&res_19), safePoint_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
					prepareAdd((&res_19), 12);
appendString((&res_19), TM__MQdRN7fpbG7rPm4JpVVAhA_3438);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA223_;
						prepareAdd((&res_19), 1);
appendString((&res_19), TM__MQdRN7fpbG7rPm4JpVVAhA_3439);
					}
LA223_: ;
					prepareAdd((&(*T220_)), res_19.len + 0);
appendString((&(*T220_)), res_19);
					eqdestroy___system_u2691(res_19);
				}
LA217_: ;
				expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)], d_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				T225_ = (NimStringV2*)0;
				T225_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				addIndent__cgen_u315(p_p0, T225_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				T226_ = (NimStringV2*)0;
				T226_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				res_18 = rawNewString(((NI)80));
				colontmpD__8 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3440);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				cgFormatValue__cgen_u163((&res_18), colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				prepareAdd((&res_18), 3);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_3441);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA229_;
					prepareAdd((&res_18), 1);
appendString((&res_18), TM__MQdRN7fpbG7rPm4JpVVAhA_3442);
				}
LA229_: ;
				prepareAdd((&(*T226_)), res_18.len + 0);
appendString((&(*T226_)), res_18);
				endBlock__cgen_u15767(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				{
					LA200_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(res_18);
					eqdestroy___system_u2691(res_17);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA195_;
LA198_: ;
			{
				NimStringV2 orExpr_1;
				NimStringV2 res_20;
				NimStringV2 res_21;
				NimStringV2 colontmpD__10;
				NimStringV2* T274_;
				NimStringV2* T275_;
				NI T280_;
				NI T291_;
				NimStringV2* T292_;
				NimStringV2* T293_;
				orExpr_1.len = 0; orExpr_1.p = NIM_NIL;
				res_20.len = 0; res_20.p = NIM_NIL;
				res_21.len = 0; res_21.p = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				orExpr_1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				{
					NI j_1;
					NI colontmp_;
					NI T236_;
					NI i_2;
					j_1 = (NI)0;
					colontmp_ = (NI)0;
					T236_ = (NI)0;
					T236_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
					colontmp_ = (NI)(T236_ - ((NI)1));
					i_2 = ((NI)0);
					{
						while (1) {
							NimStringV2 memberName_1;
							NimStringV2 T244_;
							if (!(i_2 < colontmp_)) goto LA238;
							memberName_1.len = 0; memberName_1.p = NIM_NIL;
							j_1 = i_2;
							{
								if (!!((orExpr_1.len == ((NI)0)))) goto LA242_;
								prepareAdd((&orExpr_1), 2);
appendString((&orExpr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3443);
							}
LA242_: ;
							T244_.len = 0; T244_.p = NIM_NIL;
							{
								NIM_BOOL T247_;
								T247_ = (NIM_BOOL)0;
								T247_ = ((*(*(*(*p_p0).module).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
								if (T247_) goto LA248_;
								T247_ = (((*(*(*p_p0).module).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA248_: ;
								if (!T247_) goto LA249_;
								memberName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3444;
							}
							goto LA245_;
LA249_: ;
							{
								memberName_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3445;
							}
LA245_: ;
							{
								NimStringV2 checkFor_1;
								NimStringV2 res_22;
								NimStringV2 colontmpD__11;
								NimStringV2 colontmpD__12;
								NimStringV2 colontmpD__13;
								NI16 T257_;
								tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T258_;
								NU32 T259_;
								if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)46)))&63U)))!=0)) goto LA254_;
								checkFor_1.len = 0; checkFor_1.p = NIM_NIL;
								res_22.len = 0; res_22.p = NIM_NIL;
								colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
								colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
								colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
								T257_ = (NI16)0;
								T257_ = getObjDepth__cgen_u10096((*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]).typField);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								checkFor_1 = dollar___systemZdollars_u19(T257_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								res_22 = rawNewString(((NI)80));
								colontmpD__11 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3446);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								cgFormatValue__cgen_u163((&res_22), colontmpD__11);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								prepareAdd((&res_22), 1);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3447);
								colontmpD__12 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3448);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								cgFormatValue__cgen_u163((&res_22), colontmpD__12);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								prepareAdd((&res_22), 4);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3449);
								cgFormatValue__cgen_u163((&res_22), memberName_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								prepareAdd((&res_22), 2);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3450);
								cgFormatValue__cgen_u163((&res_22), checkFor_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								prepareAdd((&res_22), 2);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3451);
								nimZeroMem((void*)T258_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
								hashType__sighashes_u411((*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]).typField, (*(*(*p_p0).module).g).config, 2, T258_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								T259_ = (NU32)0;
								T259_ = genDisplayElem__cgen_u10109(T258_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								colontmpD__13 = dollar___systemZdollars_u49(T259_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								cgFormatValue__cgen_u163((&res_22), colontmpD__13);
								if (NIM_UNLIKELY(*nimErr_)) goto LA256_;
								prepareAdd((&res_22), 1);
appendString((&res_22), TM__MQdRN7fpbG7rPm4JpVVAhA_3452);
								prepareAdd((&orExpr_1), res_22.len + 0);
appendString((&orExpr_1), res_22);
								{
									LA256_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__13);
									eqdestroy___system_u2691(colontmpD__12);
									eqdestroy___system_u2691(colontmpD__11);
									eqdestroy___system_u2691(res_22);
									eqdestroy___system_u2691(checkFor_1);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
							}
							goto LA252_;
LA254_: ;
							{
								NimStringV2 checkFor_2;
								NimStringV2 res_23;
								NimStringV2 colontmpD__14;
								NimStringV2 colontmpD__15;
								checkFor_2.len = 0; checkFor_2.p = NIM_NIL;
								res_23.len = 0; res_23.p = NIM_NIL;
								colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
								colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
								checkFor_2 = genTypeInfoV1__cgen_u9076((*p_p0).module, (*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]).typField, (*(*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[j_1]).info);
								if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
								res_23 = rawNewString(((NI)80));
								colontmpD__14 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3453);
								if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
								cgFormatValue__cgen_u163((&res_23), colontmpD__14);
								if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
								prepareAdd((&res_23), 1);
appendString((&res_23), TM__MQdRN7fpbG7rPm4JpVVAhA_3454);
								colontmpD__15 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3455);
								if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
								cgFormatValue__cgen_u163((&res_23), colontmpD__15);
								if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
								prepareAdd((&res_23), 4);
appendString((&res_23), TM__MQdRN7fpbG7rPm4JpVVAhA_3456);
								cgFormatValue__cgen_u163((&res_23), memberName_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
								prepareAdd((&res_23), 2);
appendString((&res_23), TM__MQdRN7fpbG7rPm4JpVVAhA_3457);
								cgFormatValue__cgen_u163((&res_23), checkFor_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
								prepareAdd((&res_23), 1);
appendString((&res_23), TM__MQdRN7fpbG7rPm4JpVVAhA_3458);
								prepareAdd((&orExpr_1), res_23.len + 0);
appendString((&orExpr_1), res_23);
								{
									LA263_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__15);
									eqdestroy___system_u2691(colontmpD__14);
									eqdestroy___system_u2691(res_23);
									eqdestroy___system_u2691(checkFor_2);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA239_;
							}
LA252_: ;
							i_2 += ((NI)1);
							{
								LA239_:;
							}
							{
								eqdestroy___system_u2691(memberName_1);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
						} LA238: ;
					}
				}
				{
					NimStringV2* T272_;
					NimStringV2* T273_;
					if (!(((NI)1) < i_1)) goto LA270_;
					T272_ = (NimStringV2*)0;
					T272_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
					addIndent__cgen_u315(p_p0, T272_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
					T273_ = (NimStringV2*)0;
					T273_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
					prepareAdd((&(*T273_)), 5);
appendString((&(*T273_)), TM__MQdRN7fpbG7rPm4JpVVAhA_3459);
				}
LA270_: ;
				T274_ = (NimStringV2*)0;
				T274_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				addIndent__cgen_u315(p_p0, T274_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				T275_ = (NimStringV2*)0;
				T275_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				res_20 = rawNewString(((NI)80));
				prepareAdd((&res_20), 4);
appendString((&res_20), TM__MQdRN7fpbG7rPm4JpVVAhA_3460);
				cgFormatValue__cgen_u163((&res_20), orExpr_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				prepareAdd((&res_20), 3);
appendString((&res_20), TM__MQdRN7fpbG7rPm4JpVVAhA_3461);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA278_;
					prepareAdd((&res_20), 1);
appendString((&res_20), TM__MQdRN7fpbG7rPm4JpVVAhA_3462);
				}
LA278_: ;
				prepareAdd((&(*T275_)), res_20.len + 0);
appendString((&(*T275_)), res_20);
				T280_ = (NI)0;
				T280_ = startBlockInternal__cgen_u15729(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				{
					NimStringV2 res_24;
					NimStringV2* T285_;
					NimStringV2* T286_;
					if (!!(quirkyExceptions_1)) goto LA283_;
					res_24.len = 0; res_24.p = NIM_NIL;
					T285_ = (NimStringV2*)0;
					T285_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
					addIndent__cgen_u315(p_p0, T285_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
					T286_ = (NimStringV2*)0;
					T286_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
					if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
					res_24 = rawNewString(((NI)80));
					cgFormatValue__cgen_u163((&res_24), safePoint_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
					prepareAdd((&res_24), 12);
appendString((&res_24), TM__MQdRN7fpbG7rPm4JpVVAhA_3463);
					{
						if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA289_;
						prepareAdd((&res_24), 1);
appendString((&res_24), TM__MQdRN7fpbG7rPm4JpVVAhA_3464);
					}
LA289_: ;
					prepareAdd((&(*T286_)), res_24.len + 0);
appendString((&(*T286_)), res_24);
					eqdestroy___system_u2691(res_24);
				}
LA283_: ;
				T291_ = (NI)0;
				T291_ = len__ast_u3190((*t_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				expr__cgen_u14084(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[(NI)(T291_ - ((NI)1))], d_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				T292_ = (NimStringV2*)0;
				T292_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				addIndent__cgen_u315(p_p0, T292_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				T293_ = (NimStringV2*)0;
				T293_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				res_21 = rawNewString(((NI)80));
				colontmpD__10 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3465);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				cgFormatValue__cgen_u163((&res_21), colontmpD__10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				prepareAdd((&res_21), 3);
appendString((&res_21), TM__MQdRN7fpbG7rPm4JpVVAhA_3466);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA296_;
					prepareAdd((&res_21), 1);
appendString((&res_21), TM__MQdRN7fpbG7rPm4JpVVAhA_3467);
				}
LA296_: ;
				prepareAdd((&(*T293_)), res_21.len + 0);
appendString((&(*T293_)), res_21);
				endBlock__cgen_u15767(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA234_;
				{
					LA234_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__10);
					eqdestroy___system_u2691(res_21);
					eqdestroy___system_u2691(res_20);
					eqdestroy___system_u2691(orExpr_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA195_: ;
			i_1 += ((NI)1);
		} LA185: ;
	}
	pop__cgen_u16349((&(*p_p0).nestedTryStmts), (&colontmpD__2));
	(void)(colontmpD__2);
	endBlock__cgen_u15767(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T302_;
		NI T303_;
		NimStringV2 colontmpD__16;
		NimStringV2 res_25;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__17;
		NimStringV2 colontmpD__18;
		NimStringV2* T308_;
		NimStringV2* T309_;
		NI T314_;
		T302_ = (NIM_BOOL)0;
		T303_ = (NI)0;
		T303_ = len__ast_u3190(t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T302_ = (i_1 < T303_);
		if (!(T302_)) goto LA304_;
		T302_ = ((*(*t_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)107));
LA304_: ;
		if (!T302_) goto LA305_;
		res_25.len = 0; res_25.p = NIM_NIL;
		colontmpD__17 = NIM_NIL;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__16 = eqdup___system_u2697(safePoint_1);
		add__stdZenumutils_u71((&(*p_p0).finallySafePoints), colontmpD__16);
		T308_ = (NimStringV2*)0;
		T308_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA307_;
		addIndent__cgen_u315(p_p0, T308_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA307_;
		T309_ = (NimStringV2*)0;
		T309_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA307_;
		res_25 = rawNewString(((NI)80));
		prepareAdd((&res_25), 1);
appendString((&res_25), TM__MQdRN7fpbG7rPm4JpVVAhA_3468);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA312_;
			prepareAdd((&res_25), 1);
appendString((&res_25), TM__MQdRN7fpbG7rPm4JpVVAhA_3469);
		}
LA312_: ;
		prepareAdd((&(*T309_)), res_25.len + 0);
appendString((&(*T309_)), res_25);
		T314_ = (NI)0;
		T314_ = startBlockInternal__cgen_u15729(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA307_;
		genStmts__cgen_u14081(p_p0, (*(*t_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA307_;
		{
			NIM_BOOL T317_;
			NimStringV2 res_26;
			NimStringV2 colontmpD__19;
			NimStringV2* T322_;
			NimStringV2* T323_;
			T317_ = (NIM_BOOL)0;
			T317_ = !(quirkyExceptions_1);
			if (!(T317_)) goto LA318_;
			colontmpD__17 = getCompilerProc__magicsys_u150((*(*(*p_p0).module).g).graph, TM__MQdRN7fpbG7rPm4JpVVAhA_3471);
			if (NIM_UNLIKELY(*nimErr_)) goto LA307_;
			T317_ = !((colontmpD__17 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA318_: ;
			if (!T317_) goto LA319_;
			res_26.len = 0; res_26.p = NIM_NIL;
			colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
			T322_ = (NimStringV2*)0;
			T322_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA321_;
			addIndent__cgen_u315(p_p0, T322_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA321_;
			T323_ = (NimStringV2*)0;
			T323_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA321_;
			res_26 = rawNewString(((NI)80));
			prepareAdd((&res_26), 4);
appendString((&res_26), TM__MQdRN7fpbG7rPm4JpVVAhA_3472);
			cgFormatValue__cgen_u163((&res_26), safePoint_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA321_;
			prepareAdd((&res_26), 14);
appendString((&res_26), TM__MQdRN7fpbG7rPm4JpVVAhA_3473);
			colontmpD__19 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3474);
			if (NIM_UNLIKELY(*nimErr_)) goto LA321_;
			cgFormatValue__cgen_u163((&res_26), colontmpD__19);
			if (NIM_UNLIKELY(*nimErr_)) goto LA321_;
			prepareAdd((&res_26), 3);
appendString((&res_26), TM__MQdRN7fpbG7rPm4JpVVAhA_3475);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA326_;
				prepareAdd((&res_26), 1);
appendString((&res_26), TM__MQdRN7fpbG7rPm4JpVVAhA_3476);
			}
LA326_: ;
			prepareAdd((&(*T323_)), res_26.len + 0);
appendString((&(*T323_)), res_26);
			{
				LA321_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__19);
				eqdestroy___system_u2691(res_26);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA307_;
		}
LA319_: ;
		endBlock__cgen_u15767(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA307_;
		colontmpD__18 = pop__stdZprivateZosdirs_u415((&(*p_p0).finallySafePoints));
		(void)(colontmpD__18);
		{
			LA307_:;
		}
		{
			oldNimErrFin307_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__18);
			eqdestroy___ast_u4574(colontmpD__17);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(res_25);
			*nimErr_ = oldNimErrFin307_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA305_: ;
	{
		NimStringV2 res_27;
		NimStringV2 colontmpD__20;
		NimStringV2* T337_;
		NimStringV2* T338_;
		if (!!(quirkyExceptions_1)) goto LA334_;
		res_27.len = 0; res_27.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		T337_ = (NimStringV2*)0;
		T337_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
		addIndent__cgen_u315(p_p0, T337_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
		T338_ = (NimStringV2*)0;
		T338_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
		res_27 = rawNewString(((NI)80));
		prepareAdd((&res_27), 4);
appendString((&res_27), TM__MQdRN7fpbG7rPm4JpVVAhA_3477);
		cgFormatValue__cgen_u163((&res_27), safePoint_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
		prepareAdd((&res_27), 14);
appendString((&res_27), TM__MQdRN7fpbG7rPm4JpVVAhA_3478);
		colontmpD__20 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3480);
		if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
		cgFormatValue__cgen_u163((&res_27), colontmpD__20);
		if (NIM_UNLIKELY(*nimErr_)) goto LA336_;
		prepareAdd((&res_27), 3);
appendString((&res_27), TM__MQdRN7fpbG7rPm4JpVVAhA_3481);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA341_;
			prepareAdd((&res_27), 1);
appendString((&res_27), TM__MQdRN7fpbG7rPm4JpVVAhA_3482);
		}
LA341_: ;
		prepareAdd((&(*T338_)), res_27.len + 0);
appendString((&(*T338_)), res_27);
		{
			LA336_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(res_27);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA334_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u1158(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(safePoint_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, genSimpleBlock__cgen_u16218)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* stmts_p1) {
	NimStringV2 res_1;
	NimStringV2* T2_;
	NimStringV2* T3_;
	NI T8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	res_1.len = 0; res_1.p = NIM_NIL;
	T2_ = (NimStringV2*)0;
	T2_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = (NimStringV2*)0;
	T3_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3483);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA6_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3484);
	}
LA6_: ;
	prepareAdd((&(*T3_)), res_1.len + 0);
appendString((&(*T3_)), res_1);
	T8_ = (NI)0;
	T8_ = startBlockInternal__cgen_u15729(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genStmts__cgen_u14081(p_p0, stmts_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	endBlock__cgen_u15767(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(res_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, finallyActions__cgen_u17512)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0) {
NIM_BOOL oldNimErrFin11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NI T6_;
		tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T8_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* finallyBlock_1;
		tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T12_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*(*(*(*p_p0).module).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3)));
		if (!(T4_)) goto LA5_;
		T6_ = (*p_p0).nestedTryStmts.len;
		T4_ = (((NI)0) < T6_);
LA5_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA7_;
		T8_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
		T8_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (*T8_).Field1;
LA7_: ;
		if (!T3_) goto LA9_;
		finallyBlock_1 = NIM_NIL;
		T12_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
		T12_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		eqcopy___ast_u3255(&finallyBlock_1, (*T12_).Field0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		{
			if (!!((finallyBlock_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA15_;
			genSimpleBlock__cgen_u16218(p_p0, (*finallyBlock_1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
		}
LA15_: ;
		{
			LA11_:;
		}
		{
			oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(finallyBlock_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin11_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genRaiseStmt__cgen_u17575)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
NIM_BOOL oldNimErrFin5_;
	NimStringV2* T68_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
		NimStringV2 e_1;
		NimStringV2 colontmpD_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
		if (!!(((*(*t_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA3_;
		nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		e_1.len = 0; e_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		typ_1 = NIM_NIL;
		initLocExprSingleUse__cgen_u14116(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)], (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		finallyActions__cgen_u17512(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		e_1 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD_ = getTypeDesc__cgen_u8738((*p_p0).module, (*(*t_p1)._kind_6.sons.p->data[((NI)0)]).typField, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		(void)(colontmpD_);
		typ_1 = skipTypes__ast_u5379((*(*t_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_672);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		switch ((*(*(*(*p_p0).module).g).config).exc) {
		case ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)2):
		{
			NI T7_;
			T7_ = (NI)0;
			T7_ = inExceptBlockLen__cgen_u15682(p_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			blockLeaveActions__cgen_u16297(p_p0, ((NI)0), T7_, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		break;
		case ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3):
		{
			NI colontmpD__2;
			NI colontmpD__3;
			tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* T9_;
			NI T10_;
			colontmpD__2 = (NI)0;
			colontmpD__3 = (NI)0;
			T9_ = NIM_NIL;
			T9_ = p_p0;
			T10_ = (NI)0;
			{
				NIM_BOOL T13_;
				NI T14_;
				tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* T16_;
				T13_ = (NIM_BOOL)0;
				T14_ = (*p_p0).nestedTryStmts.len;
				T13_ = (((NI)0) < T14_);
				if (!(T13_)) goto LA15_;
				T16_ = (tyTuple__P9bg2wlfPi4dSSTi3ICCeVA*)0;
				T16_ = X5BX5D___cgen_u17403((((*p_p0).nestedTryStmts).p) ? ((*p_p0).nestedTryStmts.p->data) : NIM_NIL, (*p_p0).nestedTryStmts.len, ((NI)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T13_ = (*T16_).Field1;
LA15_: ;
				if (!T13_) goto LA17_;
				colontmpD__2 = ((NI)1);
				T10_ = colontmpD__2;
			}
			goto LA11_;
LA17_: ;
			{
				colontmpD__3 = ((NI)0);
				T10_ = colontmpD__3;
			}
LA11_: ;
			blockLeaveActions__cgen_u16297(T9_, ((NI)0), T10_, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
		break;
		default:
		{
		}
		break;
		}
		genLineDir__cgen_u418(p_p0, t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			NIM_BOOL T23_;
			NimStringV2 colontmpD__4;
			NimStringV2* T26_;
			NimStringV2* T27_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T28_;
			T23_ = (NIM_BOOL)0;
			T23_ = isImportedException__ast_u7302(typ_1, (*(*(*p_p0).module).g).config);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			if (!T23_) goto LA24_;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T26_ = (NimStringV2*)0;
			T26_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			addIndent__cgen_u315(p_p0, T26_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			T27_ = (NimStringV2*)0;
			T27_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			T28_[0] = e_1;
			colontmpD__4 = percent___cgen_u17592(T28_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			prepareAdd((&(*T27_)), colontmpD__4.len + 0);
appendString((&(*T27_)), colontmpD__4);
			eqdestroy___system_u2691(colontmpD__4);
		}
		goto LA21_;
LA24_: ;
		{
			NimStringV2 res_1;
			NimStringV2 colontmpD__5;
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2* T31_;
			NimStringV2* T32_;
			NimStringV2 T33_;
			NI T39_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			T31_ = (NimStringV2*)0;
			T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			addIndent__cgen_u315(p_p0, T31_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			T32_ = (NimStringV2*)0;
			T32_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			res_1 = rawNewString(((NI)80));
			colontmpD__5 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3486);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3487);
			colontmpD__6 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3488);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3490);
			cgFormatValue__cgen_u163((&res_1), e_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3491);
			colontmpD__7 = makeCString__msgs_u83((*(*(*typ_1).sym).name).s);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3492);
			T33_.len = 0; T33_.p = NIM_NIL;
			{
				if (!!(((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA36_;
				eqcopy___system_u2694((&colontmpD__8), (*(*(*p_p0).prc).name).s);
				T33_ = colontmpD__8;
			}
			goto LA34_;
LA36_: ;
			{
				eqcopy___system_u2694((&colontmpD__9), (*(*(*(*p_p0).module).module).name).s);
				T33_ = colontmpD__9;
			}
LA34_: ;
			colontmpD__10 = makeCString__msgs_u83(T33_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3493);
			colontmpD__11 = quotedFilename__msgs_u1638((*(*(*p_p0).module).g).config, (*t_p1).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3494);
			T39_ = (NI)0;
			T39_ = toLinenumber__msgs_u695((*t_p1).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			cgFormatValue__cgen_u166((&res_1), ((NI64) (T39_)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3495);
			{
				if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA42_;
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3496);
			}
LA42_: ;
			prepareAdd((&(*T32_)), res_1.len + 0);
appendString((&(*T32_)), res_1);
			{
				NimStringV2 res_2;
				NimStringV2* T48_;
				NimStringV2* T49_;
				if (!(((*(*(*(*p_p0).module).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)47)))&63U)))!=0)) goto LA46_;
				res_2.len = 0; res_2.p = NIM_NIL;
				T48_ = (NimStringV2*)0;
				T48_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				addIndent__cgen_u315(p_p0, T48_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				T49_ = (NimStringV2*)0;
				T49_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				res_2 = rawNewString(((NI)80));
				cgFormatValue__cgen_u163((&res_2), e_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				prepareAdd((&res_2), 11);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3497);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA52_;
					prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3498);
				}
LA52_: ;
				prepareAdd((&(*T49_)), res_2.len + 0);
appendString((&(*T49_)), res_2);
				eqdestroy___system_u2691(res_2);
			}
LA46_: ;
			{
				LA30_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		}
LA21_: ;
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(typ_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(e_1);
			eqdestroy___ast_u6284(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NimStringV2 res_3;
		NimStringV2 colontmpD__12;
		NimStringV2* T60_;
		NimStringV2* T61_;
		res_3.len = 0; res_3.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		finallyActions__cgen_u17512(p_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		genLineDir__cgen_u418(p_p0, t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		T60_ = (NimStringV2*)0;
		T60_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		addIndent__cgen_u315(p_p0, T60_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		T61_ = (NimStringV2*)0;
		T61_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		res_3 = rawNewString(((NI)80));
		colontmpD__12 = cgsymValue__cgen_u141((*p_p0).module, TM__MQdRN7fpbG7rPm4JpVVAhA_3499);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		cgFormatValue__cgen_u163((&res_3), colontmpD__12);
		if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
		prepareAdd((&res_3), 3);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3500);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA64_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3501);
		}
LA64_: ;
		prepareAdd((&(*T61_)), res_3.len + 0);
appendString((&(*T61_)), res_3);
		{
			LA59_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(res_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	T68_ = (NimStringV2*)0;
	T68_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	raiseInstr__cgen_u457(p_p0, T68_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTypeSection__cgen_u12758)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA intSet_1;
NIM_BOOL oldNimErrFin19_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&intSet_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&intSet_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				{
					{
						NI T8_;
						T8_ = (NI)0;
						T8_ = len__ast_u3190((*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						if (!(T8_ == ((NI)0))) goto LA9_;
						goto LA5;
					}
LA9_: ;
					{
						if (!!(((*(*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)43)))) goto LA13_;
						goto LA5;
					}
LA13_: ;
					{
						NI p_1;
						NI colontmp__2;
						NI i_3;
						p_1 = (NI)0;
						colontmp__2 = (NI)0;
						colontmp__2 = len__ast_u3190((*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						i_3 = ((NI)0);
						{
							while (1) {
								if (!(i_3 < colontmp__2)) goto LA17;
								p_1 = i_3;
								{
									tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_1;
									s_1 = NIM_NIL;
									{
										if (!!(((*(*(*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[p_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3) || (*(*(*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[p_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31)))) goto LA22_;
										eqdestroy___ast_u3252(s_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
										goto LA18;
									}
LA22_: ;
									eqcopy___ast_u3255(&s_1, (*(*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[p_1]);
									if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
									{
										if (!((*s_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31))) goto LA26_;
										eqcopy___ast_u3255(&s_1, (*(*(*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[p_1])._kind_6.sons.p->data[((NI)1)]);
										if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
									}
LA26_: ;
									{
										NimStringV2 colontmpD_;
										tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q T33_;
										if (!((262272 & (*(*s_1)._kind_4.sym).flags) == 128)) goto LA30_;
										colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
										T33_ = (tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0;
										T33_ = descKindFromSymKind__cgen_u735((*(*s_1)._kind_4.sym).kind);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										colontmpD_ = getTypeDescAux__cgen_u1419(m_p0, (*s_1).typField, (&intSet_1), T33_);
										if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										(void)(colontmpD_);
										{
											NimStringV2 colontmpD__2;
											tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q T39_;
											if (!!(((*(*m_p0).g).generatedHeader == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)))) goto LA36_;
											colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
											T39_ = (tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0;
											T39_ = descKindFromSymKind__cgen_u735((*(*s_1)._kind_4.sym).kind);
											if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
											colontmpD__2 = getTypeDescAux__cgen_u1419((*(*m_p0).g).generatedHeader, (*s_1).typField, (&intSet_1), T39_);
											if (NIM_UNLIKELY(*nimErr_)) goto LA38_;
											(void)(colontmpD__2);
											{
												LA38_:;
											}
											{
												eqdestroy___system_u2691(colontmpD__2);
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
										}
LA36_: ;
										{
											LA32_:;
										}
										{
											eqdestroy___system_u2691(colontmpD_);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
									}
LA30_: ;
									{
										LA19_:;
									}
									{
										oldNimErrFin19_ = *nimErr_; *nimErr_ = NIM_FALSE;
										eqdestroy___ast_u3252(s_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
										*nimErr_ = oldNimErrFin19_;
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
								} LA18: ;
								i_3 += ((NI)1);
							} LA17: ;
						}
					}
				} LA5: ;
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pureZcollectionsZintsets_u230((&intSet_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ, determineSection__cgen_u19759)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6);
	{
		NIM_BOOL T3_;
		NI T4_;
		NimStringV2 sec_1;
		T3_ = (NIM_BOOL)0;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (((NI)1) <= T4_);
		if (!(T3_)) goto LA5_;
		T3_ = ((*(*n_p0)._kind_6.sons.p->data[((NI)0)]).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*(*n_p0)._kind_6.sons.p->data[((NI)0)]).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22));
LA5_: ;
		if (!T3_) goto LA6_;
		sec_1.len = 0; sec_1.p = NIM_NIL;
		sec_1 = (*(*n_p0)._kind_6.sons.p->data[((NI)0)])._kind_3.strVal;
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = nsuStartsWith(sec_1, TM__MQdRN7fpbG7rPm4JpVVAhA_3503);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T10_) goto LA11_;
			result = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)2);
		}
		goto LA8_;
LA11_: ;
		{
			NIM_BOOL T14_;
			T14_ = (NIM_BOOL)0;
			T14_ = nsuStartsWith(sec_1, TM__MQdRN7fpbG7rPm4JpVVAhA_3505);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA15_;
			result = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9);
		}
		goto LA8_;
LA15_: ;
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = nsuStartsWith(sec_1, TM__MQdRN7fpbG7rPm4JpVVAhA_3507);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T18_) goto LA19_;
			result = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0);
		}
		goto LA8_;
LA19_: ;
LA8_: ;
	}
LA6_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genEmit__cgen_u19786)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
	NimStringV2 s_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1.len = 0; s_1.p = NIM_NIL;
	s_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genAsmOrEmitStmt__cgen_u19682(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)1)], NIM_FALSE, (&s_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ section_1;
		if (!((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA4_;
		section_1 = determineSection__cgen_u19759((*t_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		genCLineDir__cgen_u396((&(*(*p_p0).module).s[(section_1)- 0]), (*t_p1).info, (*(*(*p_p0).module).g).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*(*p_p0).module).s[(section_1)- 0]), s_1.len + 0);
appendString((&(*(*p_p0).module).s[(section_1)- 0]), s_1);
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2* T7_;
		NimStringV2* T8_;
		genLineDir__cgen_u418(p_p0, t_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T7_ = (NimStringV2*)0;
		T7_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		addIndent__cgen_u315(p_p0, T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_ = (NimStringV2*)0;
		T8_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*T8_)), s_1.len + 0);
appendString((&(*T8_)), s_1);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(s_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genPragma__cgen_u19795)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T5_;
				if (!(i_2 < colontmp_)) goto LA3;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				T5_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
				T5_ = whichPragma__trees_u218(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				switch (T5_) {
				case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)217):
				{
					genEmit__cgen_u19786(p_p0, it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
				break;
				case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)129):
				{
					tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T8_;
					tySequence__bdNIx7Bah2llfuqeoTJEWQ* T9_;
					T8_ = NIM_NIL;
					T8_ = (*(*(*p_p0).module).g).config;
					T9_ = (tySequence__bdNIx7Bah2llfuqeoTJEWQ*)0;
					T9_ = (&(*p_p0).optionsStack);
					processPushBackendOption__pushpoppragmas_u288(T8_, T9_, (&(*p_p0).options), n_p1, (NI)(i_1 + ((NI)1)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
				break;
				case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)130):
				{
					tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T11_;
					tySequence__bdNIx7Bah2llfuqeoTJEWQ* T12_;
					T11_ = NIM_NIL;
					T11_ = (*(*(*p_p0).module).g).config;
					T12_ = (tySequence__bdNIx7Bah2llfuqeoTJEWQ*)0;
					T12_ = (&(*p_p0).optionsStack);
					popBackendOption__pushpoppragmas_u230(T11_, T12_, (&(*p_p0).options));
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
				break;
				default:
				{
				}
				break;
				}
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genParForStmt__cgen_u17266)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* forLoopVar_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* call_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw rangeA_1;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw rangeB_1;
	NimStringV2 res_1;
	NI oldBreakIdxX60gensym2351__1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T3_;
NIM_BOOL oldNimErrFin27_;
	NimStringV2* T34_;
	NimStringV2* T35_;
	NI T40_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	forLoopVar_1 = NIM_NIL;
	call_1 = NIM_NIL;
	nimZeroMem((void*)(&rangeA_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&rangeB_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	res_1.len = 0; res_1.p = NIM_NIL;
	(*p_p0).withinLoop += ((NI)1);
	genLineDir__cgen_u418(p_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	oldBreakIdxX60gensym2351__1 = (*p_p0).breakIdx;
	eqcopy___ast_u4577(&forLoopVar_1, (*(*t_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	assignLocalVar__cgen_u13691(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3255(&call_1, (*t_p1)._kind_6.sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*call_1)._kind_6.sons.p->data[((NI)1)], T2_, (&rangeA_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*call_1)._kind_6.sons.p->data[((NI)2)], T3_, (&rangeB_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T6_;
		T6_ = (NI)0;
		T6_ = len__ast_u3190(call_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T6_ == ((NI)4))) goto LA7_;
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			NimStringV2* T14_;
			NimStringV2* T15_;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T16_;
			if (!eqStrings((*(*(*(*call_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s, TM__MQdRN7fpbG7rPm4JpVVAhA_3508)) goto LA11_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T14_ = (NimStringV2*)0;
			T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			addIndent__cgen_u315(p_p0, T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T15_ = (NimStringV2*)0;
			T15_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			colontmpD_ = rdLoc__cgen_u470((*forLoopVar_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T16_[0] = colontmpD_;
			colontmpD__2 = rdLoc__cgen_u470(rangeA_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T16_[1] = colontmpD__2;
			colontmpD__3 = rdLoc__cgen_u470(rangeB_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T16_[2] = colontmpD__3;
			colontmpD__4 = getStr__ast_u7064((*call_1)._kind_6.sons.p->data[((NI)3)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			T16_[3] = colontmpD__4;
			colontmpD__5 = percent___cgen_u17286(T16_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			prepareAdd((&(*T15_)), colontmpD__5.len + 0);
appendString((&(*T15_)), colontmpD__5);
			{
				LA13_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA9_;
LA11_: ;
		{
			NimStringV2 colontmpD__6;
			NimStringV2 colontmpD__7;
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2* T21_;
			NimStringV2* T22_;
			tyArray__Seu7uK9aaOSN0BK3EAjjSHw T23_;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			T21_ = (NimStringV2*)0;
			T21_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			addIndent__cgen_u315(p_p0, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T22_ = (NimStringV2*)0;
			T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			colontmpD__6 = rdLoc__cgen_u470((*forLoopVar_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T23_[0] = colontmpD__6;
			colontmpD__7 = rdLoc__cgen_u470(rangeA_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T23_[1] = colontmpD__7;
			colontmpD__8 = rdLoc__cgen_u470(rangeB_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T23_[2] = colontmpD__8;
			colontmpD__9 = getStr__ast_u7064((*call_1)._kind_6.sons.p->data[((NI)3)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			T23_[3] = colontmpD__9;
			colontmpD__10 = percent___cgen_u17291(T23_, 4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			prepareAdd((&(*T22_)), colontmpD__10.len + 0);
appendString((&(*T22_)), colontmpD__10);
			{
				LA20_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA9_: ;
	}
	goto LA4_;
LA7_: ;
	{
		tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw step_1;
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T28_;
		NimStringV2* T29_;
		NimStringV2* T30_;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T31_;
		nimZeroMem((void*)(&step_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		T28_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*call_1)._kind_6.sons.p->data[((NI)3)], T28_, (&step_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T29_ = (NimStringV2*)0;
		T29_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		addIndent__cgen_u315(p_p0, T29_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T30_ = (NimStringV2*)0;
		T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		colontmpD__11 = rdLoc__cgen_u470((*forLoopVar_1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T31_[0] = colontmpD__11;
		colontmpD__12 = rdLoc__cgen_u470(rangeA_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T31_[1] = colontmpD__12;
		colontmpD__13 = rdLoc__cgen_u470(rangeB_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T31_[2] = colontmpD__13;
		colontmpD__14 = rdLoc__cgen_u470(step_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T31_[3] = colontmpD__14;
		colontmpD__15 = getStr__ast_u7064((*call_1)._kind_6.sons.p->data[((NI)4)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		T31_[4] = colontmpD__15;
		colontmpD__16 = percent___cgen_u17297(T31_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
		prepareAdd((&(*T30_)), colontmpD__16.len + 0);
appendString((&(*T30_)), colontmpD__16);
		{
			LA27_:;
		}
		{
			oldNimErrFin27_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___ast_u6284(step_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin27_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	T34_ = (NimStringV2*)0;
	T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T34_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T35_ = (NimStringV2*)0;
	T35_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3509);
	{
		if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA38_;
		prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3510);
	}
LA38_: ;
	prepareAdd((&(*T35_)), res_1.len + 0);
appendString((&(*T35_)), res_1);
	T40_ = (NI)0;
	T40_ = startBlockInternal__cgen_u15729(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).breakIdx = T40_;
	(*p_p0).blocks.p->data[(*p_p0).breakIdx].isLoop = NIM_TRUE;
	genStmts__cgen_u14081(p_p0, (*t_p1)._kind_6.sons.p->data[((NI)2)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	endBlock__cgen_u15767(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*p_p0).breakIdx = oldBreakIdxX60gensym2351__1;
	(*p_p0).withinLoop -= ((NI)1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(res_1);
		eqdestroy___ast_u6284(rangeB_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u6284(rangeA_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(call_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(forLoopVar_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genState__cgen_u16254)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n0_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n0_1 = NIM_NIL;
	{
		NI T3_;
		NimStringV2 argX60gensym1983__1;
		T3_ = (NI)0;
		T3_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == ((NI)1)))) goto LA4_;
		argX60gensym1983__1.len = 0; argX60gensym1983__1.p = NIM_NIL;
		argX60gensym1983__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_3511);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, argX60gensym1983__1, TM__MQdRN7fpbG7rPm4JpVVAhA_3511);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym1983__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	n0_1 = (*n_p1)._kind_6.sons.p->data[((NI)0)];
	{
		NimStringV2 res_1;
		NI64 idx_1;
		NimStringV2* T13_;
		NimStringV2* T14_;
		if (!((*n0_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6))) goto LA11_;
		res_1.len = 0; res_1.p = NIM_NIL;
		idx_1 = (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_1.intVal;
		T13_ = (NimStringV2*)0;
		T13_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		addIndent__cgen_u315(p_p0, T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T14_ = (NimStringV2*)0;
		T14_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 5);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3513);
		cgFormatValue__cgen_u166((&res_1), idx_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3515);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA17_;
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3516);
		}
LA17_: ;
		prepareAdd((&(*T14_)), res_1.len + 0);
appendString((&(*T14_)), res_1);
		eqdestroy___system_u2691(res_1);
	}
	goto LA9_;
LA11_: ;
	{
		NimStringV2 res_2;
		NimStringV2* T22_;
		NimStringV2* T23_;
		if (!((*n0_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20))) goto LA20_;
		res_2.len = 0; res_2.p = NIM_NIL;
		T22_ = (NimStringV2*)0;
		T22_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		addIndent__cgen_u315(p_p0, T22_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T23_ = (NimStringV2*)0;
		T23_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		res_2 = rawNewString(((NI)80));
		cgFormatValue__cgen_u163((&res_2), (*n0_1)._kind_3.strVal);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3517);
		{
			if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA26_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3518);
		}
LA26_: ;
		prepareAdd((&(*T23_)), res_2.len + 0);
appendString((&(*T23_)), res_2);
		eqdestroy___system_u2691(res_2);
	}
	goto LA9_;
LA20_: ;
LA9_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genGotoState__cgen_u16449)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 prefix_1;
	NimStringV2 colontmpD__5;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	NimStringV2* T3_;
	NimStringV2* T4_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T5_;
	NimStringV2* T6_;
	NimStringV2* T7_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T8_;
	NI T9_;
	NI T10_;
	NimStringV2* T11_;
	NimStringV2* T12_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T13_;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg statesCounter_1;
	NimStringV2 T21_;
	NimStringV2* T36_;
	NimStringV2* T37_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T38_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	prefix_1.len = 0; prefix_1.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	T2_ = 0;
	initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T2_, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_ = (NimStringV2*)0;
	T3_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T4_ = (NimStringV2*)0;
	T4_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = rdLoc__cgen_u470(a_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T5_[0] = colontmpD_;
	colontmpD__2 = percent___cgen_u16453(T5_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T4_)), colontmpD__2.len + 0);
appendString((&(*T4_)), colontmpD__2);
	(*p_p0).flags |= ((NU8)1)<<(((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)0))) & 7);
	T6_ = (NimStringV2*)0;
	T6_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T7_ = (NimStringV2*)0;
	T7_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = percent___cgen_u16462(T8_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T7_)), colontmpD__3.len + 0);
appendString((&(*T7_)), colontmpD__3);
	T9_ = (*p_p0).nestedTryStmts.len;
	T10_ = (NI)0;
	T10_ = inExceptBlockLen__cgen_u15682(p_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	blockLeaveActions__cgen_u16297(p_p0, T9_, T10_, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_ = (NimStringV2*)0;
	T11_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T11_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_ = (NimStringV2*)0;
	T12_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = percent___cgen_u16470(T13_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T12_)), colontmpD__4.len + 0);
appendString((&(*T12_)), colontmpD__4);
	statesCounter_1 = lastOrd__types_u1298((*(*(*p_p0).module).g).config, (*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T16_;
		NI T17_;
		T16_ = (NIM_BOOL)0;
		T17_ = (NI)0;
		T17_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T16_ = (((NI)2) <= T17_);
		if (!(T16_)) goto LA18_;
		T16_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
LA18_: ;
		if (!T16_) goto LA19_;
		statesCounter_1 = getInt__ast_u7046((*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA19_: ;
	T21_.len = 0; T21_.p = NIM_NIL;
	{
		NIM_BOOL T24_;
		NI T25_;
		T24_ = (NIM_BOOL)0;
		T25_ = (NI)0;
		T25_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T24_ = (T25_ == ((NI)3));
		if (!(T24_)) goto LA26_;
		T24_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20));
LA26_: ;
		if (!T24_) goto LA27_;
		eqcopy___system_u2694((&prefix_1), (*(*n_p1)._kind_6.sons.p->data[((NI)2)])._kind_3.strVal);
	}
	goto LA22_;
LA27_: ;
	{
		prefix_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3520;
	}
LA22_: ;
	{
		NI64 i_1;
		NI64 colontmp_;
		NI64 res_1;
		i_1 = (NI64)0;
		colontmp_ = (NI64)0;
		colontmp_ = toInt64__int128_u53(statesCounter_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		res_1 = IL64(0);
		{
			while (1) {
				NimStringV2 colontmpD__6;
				NimStringV2 colontmpD__7;
				NimStringV2* T33_;
				NimStringV2* T34_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T35_;
				if (!(res_1 <= colontmp_)) goto LA32;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				i_1 = res_1;
				T33_ = (NimStringV2*)0;
				T33_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				addIndent__cgen_u315(p_p0, T33_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T34_ = (NimStringV2*)0;
				T34_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T35_[0] = prefix_1;
				colontmpD__6 = rope__ropes_u15(i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T35_[1] = colontmpD__6;
				colontmpD__7 = percent___cgen_u16486(T35_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&(*T34_)), colontmpD__7.len + 0);
appendString((&(*T34_)), colontmpD__7);
				res_1 += ((NI)1);
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(colontmpD__6);
			} LA32: ;
		}
	}
	T36_ = (NimStringV2*)0;
	T36_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addIndent__cgen_u315(p_p0, T36_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T37_ = (NimStringV2*)0;
	T37_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__5 = percent___cgen_u9681(T38_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&(*T37_)), colontmpD__5.len + 0);
appendString((&(*T37_)), colontmpD__5);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(prefix_1);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genBreakState__cgen_u16495)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T2_;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	T2_ = 0;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	initLoc__cgen_u72(((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6), n_p1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0), T2_, (&T3_));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___ast_u6293((&(*d_p2)), T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T9_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T10_;
		NimStringV2 T11_;
		if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)155))) goto LA6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T9_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)], T9_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		colontmpD_ = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T10_[0] = colontmpD_;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = percent___cgen_u16504(T10_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA8_;}
		eqsink___system_u2700((&(*d_p2).snippet), T11_);
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA4_;
LA6_: ;
	{
		NimStringV2 colontmpD__2;
		tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg T16_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T17_;
		NimStringV2 T18_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T16_ = 0;
		initLocExpr__cgen_u14111(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], T16_, (&a_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		colontmpD__2 = rdLoc__cgen_u470(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T17_[0] = colontmpD__2;
		T18_.len = 0; T18_.p = NIM_NIL;
		T18_ = percent___cgen_u16509(T17_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T18_); goto LA15_;}
		eqsink___system_u2700((&(*d_p2).snippet), T18_);
		{
			LA15_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, expr__cgen_u14084)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* d_p2) {
NIM_BOOL oldNimErrFin44_;
NIM_BOOL oldNimErrFin66_;
NIM_BOOL oldNimErrFin56_;
NIM_BOOL oldNimErrFin97_;
NIM_BOOL oldNimErrFin111_;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL oldNimErrFin154_;
NIM_BOOL oldNimErrFin149_;
NIM_BOOL oldNimErrFin187_;
NIM_BOOL oldNimErrFin237_;
NIM_BOOL oldNimErrFin265_;
NIM_BOOL oldNimErrFin261_;
NIM_BOOL oldNimErrFin296_;
NIM_BOOL oldNimErrFin291_;
NIM_BOOL oldNimErrFin314_;
NIM_BOOL oldNimErrFin334_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*p_p0).currLineInfo = (*n_p1).info;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
		sym_1 = NIM_NIL;
		eqcopy___ast_u4577(&sym_1, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		switch ((*sym_1).kind) {
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14):
		{
			{
				NIM_BOOL T6_;
				tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T8_;
				T6_ = (NIM_BOOL)0;
				T6_ = (((*(*p_p0).module).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)6)))&7U)))!=0);
				if (T6_) goto LA7_;
				T8_ = 0;
				T6_ = !(((1073741840 & (*sym_1).flags) == T8_));
LA7_: ;
				if (!T6_) goto LA9_;
				fillProcLoc__cgen_u14051((*p_p0).module, n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				genProcPrototype__cgen_u523((*p_p0).module, sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			goto LA4_;
LA9_: ;
			{
				genProc__cgen_u454((*p_p0).module, sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA4_: ;
			putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12):
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16):
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15):
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13):
		{
			{
				NimStringV2 colontmpD_;
				NimStringV2 T18_;
				if (!(((*sym_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0)) goto LA15_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				T18_.len = 0; T18_.p = NIM_NIL;
				T18_ = rawNewString((*(*sym_1).name).s.len + 48);
appendString((&T18_), TM__MQdRN7fpbG7rPm4JpVVAhA_1406);
appendString((&T18_), (*(*sym_1).name).s);
				colontmpD_ = T18_;
				liMessage__msgs_u1227((*(*(*p_p0).module).g).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__MQdRN7fpbG7rPm4JpVVAhA_1407, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
				{
					LA17_:;
				}
				{
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA15_: ;
			{
				NIM_BOOL T23_;
				T23_ = (NIM_BOOL)0;
				T23_ = (((*(*p_p0).module).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)6)))&7U)))!=0);
				if (!(T23_)) goto LA24_;
				T23_ = !(((*(*sym_1).typ).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)5)));
LA24_: ;
				if (!T23_) goto LA25_;
				fillProcLoc__cgen_u14051((*p_p0).module, n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				genProcPrototype__cgen_u523((*p_p0).module, sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			goto LA21_;
LA25_: ;
			{
				genProc__cgen_u454((*p_p0).module, sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA21_: ;
			{
				NIM_BOOL T30_;
				NimStringV2 colontmpD__2;
				NimStringV2 T35_;
				T30_ = (NIM_BOOL)0;
				T30_ = ((*sym_1).loc.snippet.len == 0);
				if (T30_) goto LA31_;
				T30_ = ((*sym_1).loc.lode == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA31_: ;
				if (!T30_) goto LA32_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				T35_.len = 0; T35_.p = NIM_NIL;
				T35_ = rawNewString((*(*sym_1).name).s.len + 20);
appendString((&T35_), TM__MQdRN7fpbG7rPm4JpVVAhA_1409);
appendString((&T35_), (*(*sym_1).name).s);
				colontmpD__2 = T35_;
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__2, TM__MQdRN7fpbG7rPm4JpVVAhA_1410);
				if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
				{
					LA34_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA32_: ;
			putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10):
		{
			{
				NIM_BOOL T41_;
				NimStringV2 lit_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
				T41_ = (NIM_BOOL)0;
				T41_ = isSimpleConst__cgen_u107((*sym_1).typ);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				if (!T41_) goto LA42_;
				lit_1.len = 0; lit_1.p = NIM_NIL;
				colontmpD__3 = NIM_NIL;
				lit_1 = newRopeAppender__ropes_u7(((NI)80));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				colontmpD__3 = astdef__ast_u4596(sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				genLiteral__cgen_u20138(p_p0, colontmpD__3, (*sym_1).typ, (&lit_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, lit_1, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA44_;
				{
					LA44_:;
				}
				{
					oldNimErrFin44_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					eqdestroy___system_u2691(lit_1);
					*nimErr_ = oldNimErrFin44_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			goto LA39_;
LA42_: ;
			{
				if (!(((*(*p_p0).module).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)6)))&7U)))!=0)) goto LA48_;
				genConstHeader__cgen_u26784((*p_p0).module, (*p_p0).module, p_p0, sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			goto LA39_;
LA48_: ;
			{
				genComplexConst__cgen_u26529(p_p0, sym_1, d_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA39_: ;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20):
		{
			NimStringV2 colontmpD__4;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__4 = rope__ropes_u15(((NI64) ((*sym_1).position)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, colontmpD__4, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			{
				LA52_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11):
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
			colontmpD__5 = NIM_NIL;
			{
				tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T59_;
				T59_ = 0;
				if (!!(((67108872 & (*sym_1).flags) == T59_))) goto LA60_;
				genVarPrototype__cgen_u14075((*p_p0).module, n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__6;
					if (!(((*sym_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0)) goto LA64_;
					colontmpD__6 = NIM_NIL;
					colontmpD__6 = astdef__ast_u4596(sym_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
					genSingleVar__cgen_u16620(p_p0, sym_1, n_p1, colontmpD__6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA66_;
					{
						LA66_:;
					}
					{
						oldNimErrFin66_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(colontmpD__6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
						*nimErr_ = oldNimErrFin66_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				}
LA64_: ;
			}
LA60_: ;
			{
				NIM_BOOL T71_;
				NimStringV2 colontmpD__7;
				NimStringV2 colontmpD__8;
				NimStringV2 T76_;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym6928__1;
				T71_ = (NIM_BOOL)0;
				T71_ = ((*sym_1).loc.snippet.len == 0);
				if (T71_) goto LA72_;
				colontmpD__5 = t__cgen_u97((*sym_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				T71_ = (colontmpD__5 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
LA72_: ;
				if (!T71_) goto LA73_;
				colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				T76_.len = 0; T76_.p = NIM_NIL;
				xX60gensym6928__1 = (*sym_1).itemId;
				colontmpD__7 = dollar___systemZdollars_u9((NI)((NI)((NU32)(((NI) (xX60gensym6928__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym6928__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				T76_ = rawNewString((*(*sym_1).name).s.len + colontmpD__7.len + 20);
appendString((&T76_), TM__MQdRN7fpbG7rPm4JpVVAhA_1719);
appendString((&T76_), (*(*sym_1).name).s);
appendString((&T76_), TM__MQdRN7fpbG7rPm4JpVVAhA_1720);
appendString((&T76_), colontmpD__7);
				colontmpD__8 = T76_;
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__8, TM__MQdRN7fpbG7rPm4JpVVAhA_1721);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				{
					LA75_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
					eqdestroy___system_u2691(colontmpD__7);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			}
LA73_: ;
			{
				if (!(((*sym_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26)))&63U)))!=0)) goto LA81_;
				accessThreadLocalVar__cgen_u449(p_p0, sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				{
					NIM_BOOL T85_;
					NimStringV2 colontmpD__9;
					NimStringV2 T89_;
					T85_ = (NIM_BOOL)0;
					T85_ = emulatedThreadVars__cgen_u452((*(*(*p_p0).module).g).config);
					if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
					if (!T85_) goto LA86_;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					T89_.len = 0; T89_.p = NIM_NIL;
					T89_ = rawNewString((*sym_1).loc.snippet.len + 8);
appendString((&T89_), TM__MQdRN7fpbG7rPm4JpVVAhA_1722);
appendString((&T89_), (*sym_1).loc.snippet);
					colontmpD__9 = T89_;
					putIntoDest__cgen_u21142(p_p0, d_p2, (*sym_1).loc.lode, colontmpD__9, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA88_;
					{
						LA88_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__9);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				}
				goto LA83_;
LA86_: ;
				{
					putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_1).loc);
					if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
				}
LA83_: ;
			}
			goto LA79_;
LA81_: ;
			{
				putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
			}
LA79_: ;
			{
				LA56_:;
			}
			{
				oldNimErrFin56_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				*nimErr_ = oldNimErrFin56_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
			colontmpD__10 = NIM_NIL;
			{
				NIM_BOOL T100_;
				NimStringV2 colontmpD__11;
				NimStringV2 colontmpD__12;
				NimStringV2 T105_;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym6935__1;
				T100_ = (NIM_BOOL)0;
				T100_ = ((*sym_1).loc.snippet.len == 0);
				if (T100_) goto LA101_;
				colontmpD__10 = t__cgen_u97((*sym_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
				T100_ = (colontmpD__10 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
LA101_: ;
				if (!T100_) goto LA102_;
				colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
				colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
				T105_.len = 0; T105_.p = NIM_NIL;
				xX60gensym6935__1 = (*sym_1).itemId;
				colontmpD__11 = dollar___systemZdollars_u9((NI)((NI)((NU32)(((NI) (xX60gensym6935__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym6935__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
				T105_ = rawNewString((*(*sym_1).name).s.len + colontmpD__11.len + 21);
appendString((&T105_), TM__MQdRN7fpbG7rPm4JpVVAhA_1724);
appendString((&T105_), (*(*sym_1).name).s);
appendString((&T105_), TM__MQdRN7fpbG7rPm4JpVVAhA_1725);
appendString((&T105_), colontmpD__11);
				colontmpD__12 = T105_;
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__12, TM__MQdRN7fpbG7rPm4JpVVAhA_1726);
				if (NIM_UNLIKELY(*nimErr_)) goto LA104_;
				{
					LA104_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__12);
					eqdestroy___system_u2691(colontmpD__11);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
			}
LA102_: ;
			putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA97_;
			{
				LA97_:;
			}
			{
				oldNimErrFin97_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__10);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				*nimErr_ = oldNimErrFin97_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__13;
			colontmpD__13 = NIM_NIL;
			{
				NIM_BOOL T114_;
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				NimStringV2 T119_;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym6940__1;
				T114_ = (NIM_BOOL)0;
				T114_ = ((*sym_1).loc.snippet.len == 0);
				if (T114_) goto LA115_;
				colontmpD__13 = t__cgen_u97((*sym_1).loc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
				T114_ = (colontmpD__13 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
LA115_: ;
				if (!T114_) goto LA116_;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				T119_.len = 0; T119_.p = NIM_NIL;
				xX60gensym6940__1 = (*sym_1).itemId;
				colontmpD__14 = dollar___systemZdollars_u9((NI)((NI)((NU32)(((NI) (xX60gensym6940__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym6940__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
				T119_ = rawNewString((*(*sym_1).name).s.len + colontmpD__14.len + 22);
appendString((&T119_), TM__MQdRN7fpbG7rPm4JpVVAhA_1728);
appendString((&T119_), (*(*sym_1).name).s);
appendString((&T119_), TM__MQdRN7fpbG7rPm4JpVVAhA_1729);
appendString((&T119_), colontmpD__14);
				colontmpD__15 = T119_;
				internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__15, TM__MQdRN7fpbG7rPm4JpVVAhA_1730);
				if (NIM_UNLIKELY(*nimErr_)) goto LA118_;
				{
					LA118_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
			}
LA116_: ;
			putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_1).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
			{
				LA111_:;
			}
			{
				oldNimErrFin111_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__13);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				*nimErr_ = oldNimErrFin111_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		default:
		{
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			NimStringV2 T126_;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			T126_.len = 0; T126_.p = NIM_NIL;
			colontmpD__16 = dollar___ast_u309((*sym_1).kind);
			T126_ = rawNewString(colontmpD__16.len + 22);
appendString((&T126_), TM__MQdRN7fpbG7rPm4JpVVAhA_1732);
appendString((&T126_), colontmpD__16);
appendString((&T126_), TM__MQdRN7fpbG7rPm4JpVVAhA_1734);
			colontmpD__17 = T126_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__17, TM__MQdRN7fpbG7rPm4JpVVAhA_1735);
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			{
				LA125_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(colontmpD__16);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		}
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(sym_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
		{
			NIM_BOOL T134_;
			NimStringV2 lit_2;
			T134_ = (NIM_BOOL)0;
			T134_ = isEmptyType__ast_u7234((*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T134_)) goto LA135_;
			lit_2.len = 0; lit_2.p = NIM_NIL;
			lit_2 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
			genLiteral__cgen_u14095(p_p0, n_p1, (&lit_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
			putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, lit_2, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
			{
				LA137_:;
			}
			{
				eqdestroy___system_u2691(lit_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA135_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		NimStringV2 lit_3;
		lit_3.len = 0; lit_3.p = NIM_NIL;
		lit_3 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
		genLiteral__cgen_u14095(p_p0, n_p1, (&lit_3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
		putDataIntoDest__cgen_u21128(p_p0, d_p2, n_p1, lit_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA141_;
		{
			LA141_:;
		}
		{
			eqdestroy___system_u2691(lit_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5):
	{
		NimStringV2 lit_4;
		lit_4.len = 0; lit_4.p = NIM_NIL;
		lit_4 = newRopeAppender__ropes_u7(((NI)80));
		if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
		genLiteral__cgen_u14095(p_p0, n_p1, (&lit_4));
		if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
		putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, lit_4, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA145_;
		{
			LA145_:;
		}
		{
			eqdestroy___system_u2691(lit_4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* op_1;
		op_1 = NIM_NIL;
		genLineDir__cgen_u418(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
		eqcopy___ast_u3255(&op_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
			if (!((*n_p1).typField == 0)) goto LA152_;
			nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			{
				NIM_BOOL T157_;
				T157_ = (NIM_BOOL)0;
				T157_ = ((*op_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
				if (!(T157_)) goto LA158_;
				T157_ = !(((*(*op_1)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0)));
LA158_: ;
				if (!T157_) goto LA159_;
				genMagicExpr__cgen_u25880(p_p0, n_p1, (&a_1), (*(*op_1)._kind_4.sym).magic);
				if (NIM_UNLIKELY(*nimErr_)) goto LA154_;
			}
			goto LA155_;
LA159_: ;
			{
				genCall__cgen_u15586(p_p0, n_p1, (&a_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA154_;
			}
LA155_: ;
			{
				LA154_:;
			}
			{
				oldNimErrFin154_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u6284(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
				*nimErr_ = oldNimErrFin154_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
		}
		goto LA150_;
LA152_: ;
		{
			{
				NIM_BOOL T167_;
				T167_ = (NIM_BOOL)0;
				T167_ = ((*op_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
				if (!(T167_)) goto LA168_;
				T167_ = !(((*(*op_1)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0)));
LA168_: ;
				if (!T167_) goto LA169_;
				genMagicExpr__cgen_u25880(p_p0, n_p1, d_p2, (*(*op_1)._kind_4.sym).magic);
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			}
			goto LA165_;
LA169_: ;
			{
				genCall__cgen_u15586(p_p0, n_p1, d_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
			}
LA165_: ;
		}
LA150_: ;
		{
			LA149_:;
		}
		{
			oldNimErrFin149_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin149_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39):
	{
		{
			NIM_BOOL T177_;
			NI T179_;
			NimStringV2 lit_5;
			T177_ = (NIM_BOOL)0;
			T177_ = isDeepConstExpr__trees_u153(n_p1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T177_)) goto LA178_;
			T179_ = (NI)0;
			T179_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T177_ = !((T179_ == ((NI)0)));
LA178_: ;
			if (!T177_) goto LA180_;
			lit_5.len = 0; lit_5.p = NIM_NIL;
			lit_5 = newRopeAppender__ropes_u7(((NI)80));
			if (NIM_UNLIKELY(*nimErr_)) goto LA182_;
			genSetNode__cgen_u20239(p_p0, n_p1, (&lit_5));
			if (NIM_UNLIKELY(*nimErr_)) goto LA182_;
			putIntoDest__cgen_u21142(p_p0, d_p2, n_p1, lit_5, ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA182_;
			{
				LA182_:;
			}
			{
				eqdestroy___system_u2691(lit_5);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA175_;
LA180_: ;
		{
			genSetConstr__cgen_u26333(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA175_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__18;
		colontmpD__18 = NIM_NIL;
		{
			NIM_BOOL T190_;
			NI T192_;
			T190_ = (NIM_BOOL)0;
			T190_ = isDeepConstExpr__trees_u153(n_p1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			if (!(T190_)) goto LA191_;
			T192_ = (NI)0;
			T192_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			T190_ = !((T192_ == ((NI)0)));
LA191_: ;
			if (!T190_) goto LA193_;
			exprComplexConst__cgen_u26739(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
		}
		goto LA188_;
LA193_: ;
		{
			colontmpD__18 = skipTypes__ast_u5379((*n_p1).typField, TM__MQdRN7fpbG7rPm4JpVVAhA_596);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			if (!((*colontmpD__18).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24))) goto LA196_;
			genSeqConstr__cgen_u23663(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
		}
		goto LA188_;
LA196_: ;
		{
			genArrayConstr__cgen_u26510(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
		}
LA188_: ;
		{
			LA187_:;
		}
		{
			oldNimErrFin187_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__18);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin187_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
	{
		{
			NIM_BOOL T204_;
			NIM_BOOL T205_;
			NI T208_;
			T204_ = (NIM_BOOL)0;
			T205_ = (NIM_BOOL)0;
			T205_ = !(((*n_p1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
			if (!(T205_)) goto LA206_;
			T205_ = ((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA206_: ;
			T204_ = T205_;
			if (!(T204_)) goto LA207_;
			T208_ = (NI)0;
			T208_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T204_ = (T208_ == ((NI)2));
LA207_: ;
			if (!T204_) goto LA209_;
			genClosure__cgen_u26464(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA202_;
LA209_: ;
		{
			NIM_BOOL T212_;
			NI T214_;
			T212_ = (NIM_BOOL)0;
			T212_ = isDeepConstExpr__trees_u153(n_p1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T212_)) goto LA213_;
			T214_ = (NI)0;
			T214_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T212_ = !((T214_ == ((NI)0)));
LA213_: ;
			if (!T212_) goto LA215_;
			exprComplexConst__cgen_u26739(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA202_;
LA215_: ;
		{
			genTupleConstr__cgen_u26410(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA202_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38):
	{
		genObjConstr__cgen_u12890(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)61):
	{
		genCast__cgen_u25245(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)60):
	{
		genConv__cgen_u25399(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64):
	{
		genAddr__cgen_u22001(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
	{
		genBracketExpr__cgen_u22797(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
	{
		genDeref__cgen_u21837(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	{
		genRecordField__cgen_u22128(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46):
	{
		genCheckedRecordField__cgen_u22380(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)127):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)112):
	{
		genBlock__cgen_u17227(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126):
	{
		genStmtListExpr__cgen_u26542(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115):
	{
		genStmtList__cgen_u26576(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)48):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)92):
	{
		genIf__cgen_u16832(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)93):
	{
		expr__cgen_u14084(p_p0, (*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_6.sons.p->data[((NI)0)], d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)66):
	{
		downConv__cgen_u26695(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)67):
	{
		upConv__cgen_u26610(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)68):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)69):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)70):
	{
		genRangeChck__cgen_u25313(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)71):
	{
		convStrToCStr__cgen_u25407(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)72):
	{
		convCStrToStr__cgen_u25421(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)51) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)52):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_2;
		sym_2 = NIM_NIL;
		eqcopy___ast_u4577(&sym_2, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA237_;
		genProc__cgen_u454((*p_p0).module, sym_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA237_;
		{
			NIM_BOOL T240_;
			NimStringV2 colontmpD__19;
			NimStringV2 T245_;
			T240_ = (NIM_BOOL)0;
			T240_ = ((*sym_2).loc.snippet.len == 0);
			if (T240_) goto LA241_;
			T240_ = ((*sym_2).loc.lode == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA241_: ;
			if (!T240_) goto LA242_;
			colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
			T245_.len = 0; T245_.p = NIM_NIL;
			T245_ = rawNewString((*(*sym_2).name).s.len + 20);
appendString((&T245_), TM__MQdRN7fpbG7rPm4JpVVAhA_2979);
appendString((&T245_), (*(*sym_2).name).s);
			colontmpD__19 = T245_;
			internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__19, TM__MQdRN7fpbG7rPm4JpVVAhA_2980);
			if (NIM_UNLIKELY(*nimErr_)) goto LA244_;
			{
				LA244_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__19);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA237_;
		}
LA242_: ;
		putLocIntoDest__cgen_u14088(p_p0, d_p2, (*sym_2).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA237_;
		{
			LA237_:;
		}
		{
			oldNimErrFin237_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(sym_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin237_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)155):
	{
		genClosure__cgen_u26464(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)96):
	{
		genWhileStmt__cgen_u17147(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100):
	{
		genVarStmt__cgen_u16813(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)101):
	{
		{
			if (!(((*(*p_p0).module).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)6)))&7U)))!=0)) goto LA257_;
			genConstStmt__cgen_u26853(p_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA255_;
LA257_: ;
		{
			tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_1;
			m_1 = NIM_NIL;
			m_1 = (*p_p0).module;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				it_1 = NIM_NIL;
				{
					NI i_1;
					NI colontmp_;
					NI i_2;
					i_1 = (NI)0;
					colontmp_ = (NI)0;
					colontmp_ = safeLen__ast_u3197(n_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA261_;
					i_2 = ((NI)0);
					{
						while (1) {
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* symNode_1;
							if (!(i_2 < colontmp_)) goto LA264;
							symNode_1 = NIM_NIL;
							i_1 = i_2;
							eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
							symNode_1 = skipPragmaExpr__ast_u4047((*it_1)._kind_6.sons.p->data[((NI)0)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
							{
								NIM_BOOL T268_;
								T268_ = (NIM_BOOL)0;
								T268_ = ((*symNode_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
								if (!(T268_)) goto LA269_;
								T268_ = (((*(*symNode_1)._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7)))&63U)))!=0);
LA269_: ;
								if (!T268_) goto LA270_;
								requestConstImpl__cgen_u14078(p_p0, (*symNode_1)._kind_4.sym);
								if (NIM_UNLIKELY(*nimErr_)) goto LA265_;
							}
LA270_: ;
							i_2 += ((NI)1);
							{
								LA265_:;
							}
							{
								oldNimErrFin265_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(symNode_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA261_;
								*nimErr_ = oldNimErrFin265_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA261_;
						} LA264: ;
					}
				}
				{
					LA261_:;
				}
				{
					oldNimErrFin261_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin261_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
		}
LA255_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)94):
	{
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_3036, TM__MQdRN7fpbG7rPm4JpVVAhA_3037);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)97):
	{
		genCase__cgen_u18222(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)109):
	{
		genReturnStmt__cgen_u16900(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)110):
	{
		genBreakStmt__cgen_u17320(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73):
	{
		cow__cgen_u21990(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!!((((*n_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)15)))&31U)))!=0))) goto LA283_;
			genAsgn__cgen_u19937(p_p0, n_p1, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA283_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)74):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149):
	{
		cow__cgen_u21990(p_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!!((((*n_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)15)))&31U)))!=0))) goto LA288_;
			genAsgn__cgen_u19937(p_p0, n_p1, !(((*p_p0).prc == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA288_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)114):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ex_1;
		ex_1 = NIM_NIL;
		eqcopy___ast_u3255(&ex_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
		{
			tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_2;
			NimStringV2 colontmpD__20;
			NimStringV2* T297_;
			NimStringV2* T298_;
			NimStringV2 T299_;
			if (!!(((*ex_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA294_;
			nimZeroMem((void*)(&a_2), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
			colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
			genLineDir__cgen_u418(p_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA296_;
			initLocExprSingleUse__cgen_u14116(p_p0, ex_1, (&a_2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA296_;
			T297_ = (NimStringV2*)0;
			T297_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA296_;
			addIndent__cgen_u315(p_p0, T297_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA296_;
			T298_ = (NimStringV2*)0;
			T298_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA296_;
			T299_.len = 0; T299_.p = NIM_NIL;
			T299_ = rawNewString(a_2.snippet.len + 10);
appendString((&T299_), TM__MQdRN7fpbG7rPm4JpVVAhA_3168);
appendString((&T299_), a_2.snippet);
appendString((&T299_), TM__MQdRN7fpbG7rPm4JpVVAhA_3169);
			colontmpD__20 = T299_;
			prepareAdd((&(*T298_)), colontmpD__20.len + 0);
appendString((&(*T298_)), colontmpD__20);
			{
				LA296_:;
			}
			{
				oldNimErrFin296_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___system_u2691(colontmpD__20);
				eqdestroy___ast_u6284(a_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
				*nimErr_ = oldNimErrFin296_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA291_;
		}
LA294_: ;
		{
			LA291_:;
		}
		{
			oldNimErrFin291_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(ex_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin291_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)89):
	{
		genAsmStmt__cgen_u19725(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)106):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)154):
	{
		switch ((*(*(*(*p_p0).module).g).config).exc) {
		case ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3):
		{
			genTryGoto__cgen_u18931(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)2):
		{
			genTryCpp__cgen_u18373(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		default:
		{
			genTrySetjmp__cgen_u19232(p_p0, n_p1, d_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)108):
	{
		genRaiseStmt__cgen_u17575(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)98):
	{
		genTypeSection__cgen_u12758((*p_p0).module, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)121):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)116):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)117):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)118):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)119):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)120):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)83):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)82):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)113):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)90):
	{
		genPragma__cgen_u19795(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)91):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragmaList_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__21;
		NI inUncheckedAssignSection_1;
		pragmaList_1 = NIM_NIL;
		colontmpD__21 = NIM_NIL;
		inUncheckedAssignSection_1 = ((NI)0);
		eqcopy___ast_u3255(&pragmaList_1, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pi_1;
			pi_1 = NIM_NIL;
			{
				NI i_3;
				NI colontmp__2;
				NI i_4;
				i_3 = (NI)0;
				colontmp__2 = (NI)0;
				colontmp__2 = safeLen__ast_u3197(pragmaList_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
				i_4 = ((NI)0);
				{
					while (1) {
						if (!(i_4 < colontmp__2)) goto LA318;
						i_3 = i_4;
						eqcopy___ast_u3255(&pi_1, (*pragmaList_1)._kind_6.sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
						{
							tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T321_;
							tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw T324_;
							T321_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
							T321_ = whichPragma__trees_u218(pi_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
							if (!(T321_ == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)9))) goto LA322_;
							T324_ = (tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)0;
							T324_ = whichPragma__trees_u218((*pi_1)._kind_6.sons.p->data[((NI)1)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
							switch (T324_) {
							case ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)87):
							{
								inUncheckedAssignSection_1 = ((NI)1);
							}
							break;
							default:
							{
							}
							break;
							}
						}
LA322_: ;
						i_4 += ((NI)1);
					} LA318: ;
				}
			}
			eqdestroy___ast_u3252(pi_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
		}
		(*p_p0).inUncheckedAssignSection += inUncheckedAssignSection_1;
		colontmpD__21 = lastSon__ast_u5208(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
		expr__cgen_u14084(p_p0, colontmpD__21, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA314_;
		(*p_p0).inUncheckedAssignSection -= inUncheckedAssignSection_1;
		{
			LA314_:;
		}
		{
			oldNimErrFin314_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__21);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(pragmaList_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin314_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)80):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)81):
	{
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__22;
			if (!((*(*n_p1)._kind_6.sons.p->data[((NI)2)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1))) goto LA332_;
			prc_1 = NIM_NIL;
			colontmpD__22 = NIM_NIL;
			eqcopy___ast_u4577(&prc_1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto LA334_;
			{
				if (!(((*(*p_p0).module).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)6)))&7U)))!=0)) goto LA337_;
				{
					NIM_BOOL T341_;
					T341_ = (NIM_BOOL)0;
					T341_ = contains__astalgo_u2846((&(*(*p_p0).module).alive), ((NI) ((*prc_1).itemId.item)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA334_;
					if (!(T341_)) goto LA342_;
					T341_ = ((*prc_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0) || (*prc_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)157) || (*prc_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)156) || (*prc_1).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)144));
LA342_: ;
					if (!T341_) goto LA343_;
					genProc__cgen_u454((*p_p0).module, prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA334_;
				}
LA343_: ;
			}
			goto LA335_;
LA337_: ;
			{
				NIM_BOOL T346_;
				T346_ = (NIM_BOOL)0;
				colontmpD__22 = skipGenericOwner__ast_u7111(prc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA334_;
				T346_ = ((*colontmpD__22).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
				if (!(T346_)) goto LA347_;
				T346_ = !((((*prc_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28)))&63U)))!=0));
LA347_: ;
				if (!T346_) goto LA348_;
				{
					NIM_BOOL T352_;
					NIM_BOOL T353_;
					NIM_BOOL T355_;
					T352_ = (NIM_BOOL)0;
					T353_ = (NIM_BOOL)0;
					T353_ = ((262272 & (*prc_1).flags) == 128);
					if (T353_) goto LA354_;
					T355_ = (NIM_BOOL)0;
					T355_ = (((*prc_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7)))&63U)))!=0);
					if (!(T355_)) goto LA356_;
					T355_ = (((*prc_1).loc.flags &((NU16)1<<((NU)((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)4)))&15U)))!=0);
LA356_: ;
					T353_ = T355_;
LA354_: ;
					T352_ = T353_;
					if (T352_) goto LA357_;
					T352_ = ((*prc_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14));
LA357_: ;
					if (!T352_) goto LA358_;
					genProc__cgen_u454((*p_p0).module, prc_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA334_;
				}
LA358_: ;
			}
			goto LA335_;
LA348_: ;
LA335_: ;
			{
				LA334_:;
			}
			{
				oldNimErrFin334_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(colontmpD__22);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u4574(prc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin334_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA332_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)95):
	{
		genParForStmt__cgen_u17266(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)157):
	{
		genState__cgen_u16254(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)156):
	{
		(*p_p0).splitDecls += ((NI)1);
		genGotoState__cgen_u16449(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)158):
	{
		genBreakState__cgen_u16495(p_p0, n_p1, d_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)123):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)122):
	{
	}
	break;
	default:
	{
		NimStringV2 colontmpD__23;
		NimStringV2 colontmpD__24;
		NimStringV2 T369_;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
		T369_.len = 0; T369_.p = NIM_NIL;
		colontmpD__23 = dollar___nodekinds_u168((*n_p1).kind);
		T369_ = rawNewString(colontmpD__23.len + 25);
appendString((&T369_), TM__MQdRN7fpbG7rPm4JpVVAhA_3521);
appendString((&T369_), colontmpD__23);
appendString((&T369_), TM__MQdRN7fpbG7rPm4JpVVAhA_3523);
		colontmpD__24 = T369_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, (*n_p1).info, colontmpD__24, TM__MQdRN7fpbG7rPm4JpVVAhA_3524);
		if (NIM_UNLIKELY(*nimErr_)) goto LA368_;
		{
			LA368_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__24);
			eqdestroy___system_u2691(colontmpD__23);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genStmts__cgen_u14081)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* t_p1) {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw a_1;
	NIM_BOOL isPush_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	nimZeroMem((void*)(&a_1), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	isPush_1 = hasHint__options_u557((*(*(*p_p0).module).g).config, ((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)120));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!isPush_1) goto LA4_;
		pushInfoContext__msgs_u569((*(*(*p_p0).module).g).config, (*t_p1).info, TM__MQdRN7fpbG7rPm4JpVVAhA_16);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	expr__cgen_u14084(p_p0, t_p1, (&a_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!isPush_1) goto LA8_;
		popInfoContext__msgs_u593((*(*(*p_p0).module).g).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		NimStringV2 argX60gensym3758__1;
		if (!!((a_1.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0) || a_1.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)1) || a_1.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)2) || a_1.k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)6)))) goto LA12_;
		argX60gensym3758__1.len = 0; argX60gensym3758__1.p = NIM_NIL;
		argX60gensym3758__1 = toFileLineCol__msgs_u701(TM__MQdRN7fpbG7rPm4JpVVAhA_3525);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		internalErrorImpl__msgs_u1598((*(*(*p_p0).module).g).config, unknownLineInfo__lineinfos_u364, argX60gensym3758__1, TM__MQdRN7fpbG7rPm4JpVVAhA_3525);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym3758__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA12_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u6284(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addHcrInitGuards__cgen_u31085)(tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL* inInitGuard_p2) {
NIM_BOOL oldNimErrFin6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115))) goto LA3_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* child_1;
			child_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA9;
						i_1 = i_2;
						eqcopy___ast_u3255(&child_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						addHcrInitGuards__cgen_u31085(p_p0, child_1, inInitGuard_p2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						i_2 += ((NI)1);
					} LA9: ;
				}
			}
			{
				LA6_:;
			}
			{
				oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(child_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin6_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL stmtShouldExecute_1;
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)99) || (*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)100));
		if (T13_) goto LA14_;
		T13_ = (((*n_p1).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)20)))&31U)))!=0);
LA14_: ;
		stmtShouldExecute_1 = T13_;
		{
			if (!(*inInitGuard_p2)) goto LA17_;
			{
				if (!stmtShouldExecute_1) goto LA21_;
				endBlock__cgen_u15767(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				(*inInitGuard_p2) = NIM_FALSE;
			}
LA21_: ;
		}
		goto LA15_;
LA17_: ;
		{
			{
				NimStringV2 res_1;
				NimStringV2* T28_;
				NimStringV2* T29_;
				NimStringV2* T30_;
				NimStringV2* T31_;
				NI T36_;
				if (!!(stmtShouldExecute_1)) goto LA26_;
				res_1.len = 0; res_1.p = NIM_NIL;
				T28_ = (NimStringV2*)0;
				T28_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				addIndent__cgen_u315(p_p0, T28_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T29_ = (NimStringV2*)0;
				T29_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				prepareAdd((&(*T29_)), 22);
appendString((&(*T29_)), TM__MQdRN7fpbG7rPm4JpVVAhA_11);
				T30_ = (NimStringV2*)0;
				T30_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				addIndent__cgen_u315(p_p0, T30_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T31_ = (NimStringV2*)0;
				T31_ = s__cgendata_u228(p_p0, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 = rawNewString(((NI)80));
				prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_13);
				{
					if (!!((((*(*(*(*p_p0).module).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA34_;
					prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_15);
				}
LA34_: ;
				prepareAdd((&(*T31_)), res_1.len + 0);
appendString((&(*T31_)), res_1);
				T36_ = (NI)0;
				T36_ = startBlockInternal__cgen_u15729(p_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				(*inInitGuard_p2) = NIM_TRUE;
				eqdestroy___system_u2691(res_1);
			}
LA26_: ;
		}
LA15_: ;
		genStmts__cgen_u14081(p_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, handleProcGlobals__cgen_u31116)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals_1;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	procGlobals_1.len = 0; procGlobals_1.p = NIM_NIL;
	procGlobals_1 = (*(*(*m_p0).g).graph).procGlobals;
	eqwasMoved___ast_u3693((&(*(*(*m_p0).g).graph).procGlobals));
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = procGlobals_1.len;
		colontmp_ = T3_;
		i_2 = ((NI)0);
		{
			while (1) {
				NimStringV2 stmts_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedN_1;
				NimStringV2 T7_;
				NimStringV2* T8_;
				NimStringV2 T14_;
				NimStringV2* T15_;
				NimStringV2* T16_;
				if (!(i_2 < colontmp_)) goto LA5;
				stmts_1.len = 0; stmts_1.p = NIM_NIL;
				transformedN_1 = NIM_NIL;
				i_1 = i_2;
				stmts_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3526;
				T7_.len = 0; T7_.p = NIM_NIL;
				T8_ = (NimStringV2*)0;
				T8_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T7_ = stmts_1;
				stmts_1 = (*T8_);
				(*T8_) = T7_;
				eqcopy___ast_u3255(&transformedN_1, procGlobals_1.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T13_;
					if (!(((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)42)))&63U)))!=0)) goto LA11_;
					T13_ = NIM_NIL;
					T13_ = injectDestructorCalls__injectdestructors_u3431((*(*m_p0).g).graph, (*m_p0).Sup.idgen, (*m_p0).module, transformedN_1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T13_); goto LA6_;}
					eqsink___ast_u3261(&transformedN_1, T13_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				}
LA11_: ;
				genStmts__cgen_u14081((*m_p0).preInitProc, transformedN_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T14_.len = 0; T14_.p = NIM_NIL;
				T15_ = (NimStringV2*)0;
				T15_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T14_ = stmts_1;
				stmts_1 = (*T15_);
				(*T15_) = T14_;
				handleProcGlobals__cgen_u31116(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T16_ = (NimStringV2*)0;
				T16_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				prepareAdd((&(*T16_)), stmts_1.len + 0);
appendString((&(*T16_)), stmts_1);
				i_2 += ((NI)1);
				{
					LA6_:;
				}
				{
					oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(transformedN_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(stmts_1);
					*nimErr_ = oldNimErrFin6_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA5: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3696(procGlobals_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genTopLevelStmt__cgen_u31144)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedN_1;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T7_;
	tySet_tyEnum_TransformFlag__CzUOfRCXpoYcP43GAlt9cnA T8_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	transformedN_1 = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = skipCodegen__pipelineutils_u8((*(*m_p0).g).config, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		eqdestroy___ast_u3252(transformedN_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA5_: ;
	nimZeroMem((void*)(&T7_), sizeof(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ));
	T7_ = initProcOptions__cgen_u30744(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*(*m_p0).initProc).options = T7_;
	T8_ = 0;
	transformedN_1 = transformStmt__transf_u3500((*(*m_p0).g).graph, (*m_p0).Sup.idgen, (*m_p0).module, n_p1, T8_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T13_;
		if (!(((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)42)))&63U)))!=0)) goto LA11_;
		T13_ = NIM_NIL;
		T13_ = injectDestructorCalls__injectdestructors_u3431((*(*m_p0).g).graph, (*m_p0).Sup.idgen, (*m_p0).module, transformedN_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T13_); goto LA1_;}
		eqsink___ast_u3261(&transformedN_1, T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	{
		NIM_BOOL T16_;
		tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* T19_;
		T16_ = (NIM_BOOL)0;
		T16_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T16_) goto LA17_;
		T19_ = NIM_NIL;
		T19_ = (*m_p0).initProc;
		addHcrInitGuards__cgen_u31085(T19_, transformedN_1, (&(*m_p0).inHcrInitGuard));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA14_;
LA17_: ;
	{
		genProcBody__cgen_u28369((*m_p0).initProc, transformedN_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA14_: ;
	handleProcGlobals__cgen_u31116(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(transformedN_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, generateLibraryDestroyGlobals__cgen_u31183)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2, NIM_BOOL isDynlib_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NimStringV2 prefixedName_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* procname_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* theProc_1;
	NimStringV2 T1_;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T2_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T3_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	prefixedName_1.len = 0; prefixedName_1.p = NIM_NIL;
	procname_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	theProc_1 = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = rawNewString((*(*(*m_p1).g).config).nimMainPrefix.len + 17);
appendString((&T1_), (*(*(*m_p1).g).config).nimMainPrefix);
appendString((&T1_), TM__MQdRN7fpbG7rPm4JpVVAhA_3531);
	prefixedName_1 = T1_;
	procname_1 = getIdent__idents_u206((*graph_p0).cache, prefixedName_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = owner__ast_u6254((*m_p1).module);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = 0;
	result = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12), procname_1, (*m_p1).Sup.idgen, colontmpD_, (*(*m_p1).module).info, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = owner__ast_u6254((*m_p1).module);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_ = NIM_NIL;
	T3_ = newProcType__ast_u7492((*(*m_p1).module).info, (*m_p1).Sup.idgen, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T3_); goto BeforeRet_;}
	eqsink___ast_u3387(&(*result).typ, T3_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*(*result).typ).callConv = ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)2);
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7))) & 63);
	eqsink___system_u2700((&(*result).loc.snippet), prefixedName_1);
	{
		if (!isDynlib_p3) goto LA6_;
		(*result).loc.flags |= ((NU16)1)<<(((((tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg)4))) & 15);
	}
LA6_: ;
	theProc_1 = newNodeI__ast_u4095(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79), (*(*m_p1).module).info, ((NI)7));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(theProc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T11_;
				if (!(i_2 < colontmp_)) goto LA10;
				i_1 = i_2;
				T11_ = NIM_NIL;
				T11_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), (*(*m_p1).module).info);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T11_); goto BeforeRet_;}
				eqsink___ast_u3261(&(*theProc_1)._kind_6.sons.p->data[i_1], T11_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA10: ;
		}
	}
	T12_ = NIM_NIL;
	T12_ = newSymNode__ast_u5168(result);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T12_); goto BeforeRet_;}
	eqsink___ast_u3261(&(*theProc_1)._kind_6.sons.p->data[((NI)0)], T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&(*theProc_1)._kind_6.sons.p->data[((NI)6)], body_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___ast_u3261(&(*result).ast, theProc_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u4574(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___idents_u155(procname_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, moduleHasChanged__pipelineutils_u29)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1) {
	NIM_BOOL result;
	result = NIM_TRUE;
	return result;
}
static N_INLINE(void, nimMarkCyclic)(void* p_p0) {
}
N_LIB_PRIVATE N_NIMCALL(void, finalCodegenActions__cgen_u31211)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* mm_1;
NIM_BOOL oldNimErrFin23_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin52_;
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* blitTmp_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	mm_1 = NIM_NIL;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		if (!(((*(*m_p1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA4_;
		colontmpD_ = NIM_NIL;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = ((*(*(*m_p1).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3));
			if (!(T9_)) goto LA10_;
			colontmpD_ = getCompilerProc__magicsys_u150(graph_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3528);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
			T9_ = !((colontmpD_ == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA10_: ;
			if (!T9_) goto LA11_;
			cgsym__cgen_u138(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3529);
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA11_: ;
		{
			tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A T15_;
			T15_ = 0;
			if (!((8388992 & (*(*(*m_p1).g).config).globalOptions) == T15_)) goto LA16_;
			{
				NI i_1;
				NI colontmp_;
				NI T19_;
				NI res_1;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				T19_ = ((*graph_p0).globalDestructors.len-1);
				colontmp_ = T19_;
				res_1 = colontmp_;
				{
					while (1) {
						if (!(((NI)0) <= res_1)) goto LA21;
						i_1 = ((NI) (res_1));
						add__ast_u3215(n_p2, (*graph_p0).globalDestructors.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						res_1 -= ((NI)1);
					} LA21: ;
				}
			}
		}
		goto LA13_;
LA16_: ;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dtor_1;
			body_1 = NIM_NIL;
			dtor_1 = NIM_NIL;
			body_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), (*(*m_p1).module).info);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			{
				NI i_2;
				NI colontmp__2;
				NI T25_;
				NI res_2;
				i_2 = (NI)0;
				colontmp__2 = (NI)0;
				T25_ = ((*graph_p0).globalDestructors.len-1);
				colontmp__2 = T25_;
				res_2 = colontmp__2;
				{
					while (1) {
						if (!(((NI)0) <= res_2)) goto LA27;
						i_2 = ((NI) (res_2));
						add__ast_u3215(body_1, (*graph_p0).globalDestructors.p->data[i_2]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
						res_2 -= ((NI)1);
					} LA27: ;
				}
			}
			(*body_1).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)5))) & 31);
			dtor_1 = generateLibraryDestroyGlobals__cgen_u31183(graph_p0, m_p1, body_1, (((*(*(*m_p1).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)7)))&63U)))!=0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			genProcAux__cgen_u28424(m_p1, dtor_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
			{
				LA23_:;
			}
			{
				oldNimErrFin23_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(dtor_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				eqdestroy___ast_u3252(body_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				*nimErr_ = oldNimErrFin23_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
LA13_: ;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		NIM_BOOL T34_;
		T34_ = (NIM_BOOL)0;
		T34_ = skipCodegen__pipelineutils_u8((*(*m_p1).g).config, n_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T34_) goto LA35_;
		eqdestroy___cgendata_u718(mm_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA35_: ;
	{
		NIM_BOOL T39_;
		T39_ = (NIM_BOOL)0;
		T39_ = moduleHasChanged__pipelineutils_u29(graph_p0, (*m_p1).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T39_) goto LA40_;
		{
			tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T46_;
			if (!!((n_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA44_;
			nimZeroMem((void*)(&T46_), sizeof(tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ));
			T46_ = initProcOptions__cgen_u30744(m_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			(*(*m_p1).initProc).options = T46_;
			genProcBody__cgen_u28369((*m_p1).initProc, n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA44_: ;
		{
			NIM_BOOL T49_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
			T49_ = (NIM_BOOL)0;
			T49_ = hcrOn__cgen_u49(m_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T49_) goto LA50_;
			sym_1 = NIM_NIL;
			sym_1 = getCompilerProc__magicsys_u150((*(*m_p1).g).graph, TM__MQdRN7fpbG7rPm4JpVVAhA_3533);
			if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			{
				if (!!((sym_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA55_;
				cgsymImpl__cgen_u28031(m_p1, sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			}
LA55_: ;
			{
				if (!(*m_p1).inHcrInitGuard) goto LA59_;
				endBlock__cgen_u15767((*m_p1).initProc);
				if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
			}
LA59_: ;
			{
				LA52_:;
			}
			{
				oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(sym_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin52_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA50_: ;
		{
			if (!(((*(*m_p1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA65_;
			{
				NIM_BOOL T69_;
				T69_ = (NIM_BOOL)0;
				T69_ = hcrOn__cgen_u49(m_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T69_) goto LA70_;
				cgsym__cgen_u138(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3534);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				cgsym__cgen_u138(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3535);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				cgsym__cgen_u138(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3536);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				cgsym__cgen_u138(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3538);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				cgsym__cgen_u138(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3540);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA70_: ;
			{
				NIM_BOOL T74_;
				T74_ = (NIM_BOOL)0;
				T74_ = !(((*(*(*m_p1).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)29)));
				if (!(T74_)) goto LA75_;
				T74_ = !(((*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)1) || (*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5)));
LA75_: ;
				if (!T74_) goto LA76_;
				cgsym__cgen_u138(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3542);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA76_: ;
			{
				NIM_BOOL T80_;
				T80_ = (NIM_BOOL)0;
				T80_ = emulatedThreadVars__cgen_u452((*(*m_p1).g).config);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!(T80_)) goto LA81_;
				T80_ = !(((*(*(*m_p1).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)29)));
LA81_: ;
				if (!T80_) goto LA82_;
				cgsym__cgen_u138(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3544);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA82_: ;
			{
				NI T86_;
				T86_ = (*(*m_p1).g).forwardedProcs.len;
				if (!(T86_ == ((NI)0))) goto LA87_;
				(*m_p1).flags |= ((NU8)1)<<(((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)5))) & 7);
			}
LA87_: ;
			{
				NIM_BOOL T91_;
				NIM_BOOL T92_;
				T91_ = (NIM_BOOL)0;
				T92_ = (NIM_BOOL)0;
				T92_ = (((*(*(*m_p1).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)48)))&63U)))!=0);
				if (T92_) goto LA93_;
				T92_ = !(((*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5) || (*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6)));
LA93_: ;
				T91_ = T92_;
				if (T91_) goto LA94_;
				T91_ = !((((*(*(*m_p1).g).config).features &((NU32)1<<((NU)((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)23)))&31U)))!=0));
LA94_: ;
				if (!T91_) goto LA95_;
				generateIfMethodDispatchers__cgmeth_u1019(graph_p0, (*m_p1).Sup.idgen);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA95_: ;
		}
LA65_: ;
	}
LA40_: ;
	eqcopy___cgendata_u721(&mm_1, m_p1, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	blitTmp_1 = mm_1;
	nimMarkCyclic(mm_1);
	eqwasMoved___cgendata_u715(&mm_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__cgen_u31308((&(*(*m_p1).g).modulesClosed), blitTmp_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u718(mm_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, pop__icZic_u3359)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NI L_1;
	NI T1_;
	T1_ = (*s_p0).len;
	L_1 = (NI)(T1_ - ((NI)1));
	result = (*s_p0).p->data[L_1];
	eqwasMoved___ast_u4571((&(*s_p0).p->data[L_1]));
	shrink__ast_u4732(s_p0, (L_1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genForwardedProcs__cgen_u31328)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0) {
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		while (1) {
			NI T3_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_1;
			tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_1;
			T3_ = (*g_p0).forwardedProcs.len;
			if (!(((NI)0) < T3_)) goto LA2;
			prc_1 = NIM_NIL;
			m_1 = NIM_NIL;
			prc_1 = pop__icZic_u3359((&(*g_p0).forwardedProcs));
			eqcopy___cgendata_u721(&m_1, (*g_p0).modules.p->data[(*prc_1).itemId.module], NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
			{
				NimStringV2 colontmpD_;
				NimStringV2 T10_;
				if (!(((*prc_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4)))&63U)))!=0)) goto LA7_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				T10_.len = 0; T10_.p = NIM_NIL;
				T10_ = rawNewString((*(*prc_1).name).s.len + 17);
appendString((&T10_), TM__MQdRN7fpbG7rPm4JpVVAhA_3546);
appendString((&T10_), (*(*prc_1).name).s);
				colontmpD_ = T10_;
				internalErrorImpl__msgs_u1598((*(*m_1).g).config, (*prc_1).info, colontmpD_, TM__MQdRN7fpbG7rPm4JpVVAhA_3547);
				if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				{
					LA9_:;
				}
				{
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
			}
LA7_: ;
			genProcNoForward__cgen_u28805(m_1, prc_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
			{
				LA4_:;
			}
			{
				oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___cgendata_u718(m_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u4574(prc_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin4_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSomeNameForModule__cgen_u29403)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = mangleModuleName__modulepaths_u40((*(*m_p0).g).config, (*m_p0).filename);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = mangle__mangleutils_u4(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSomeInitName__cgen_u29423)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 suffix_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		result = getSomeNameForModule__cgen_u29403(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		result = TM__MQdRN7fpbG7rPm4JpVVAhA_3550;
	}
LA1_: ;
	prepareAdd((&result), suffix_p1.len + 0);
appendString((&result), suffix_p1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getInitName__cgen_u29427)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NimStringV2 T5_;
		if (!(((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA3_;
		T5_.len = 0; T5_.p = NIM_NIL;
		T5_ = rawNewString((*(*(*m_p0).g).config).nimMainPrefix.len + 13);
appendString((&T5_), (*(*(*m_p0).g).config).nimMainPrefix);
appendString((&T5_), TM__MQdRN7fpbG7rPm4JpVVAhA_3549);
		result = T5_;
	}
	goto LA1_;
LA3_: ;
	{
		result = getSomeInitName__cgen_u29423(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3552);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getHcrInitName__cgen_u29437)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = getSomeInitName__cgen_u29423(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3616);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, hcrGetProcLoadCode__cgen_u29440)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 sym_p1, NimStringV2 prefix_p2, NimStringV2 handle_p3, NimStringV2 getProcFunc_p4) {
	NimStringV2 result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_1;
	NimStringV2 extname_1;
	NimStringV2 tmp_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 T2_;
NIM_BOOL oldNimErrFin8_;
	tyArray__awn6UrBeChh9cVy9ccoluuYg T12_;
	NimStringV2 T13_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	prc_1 = NIM_NIL;
	extname_1.len = 0; extname_1.p = NIM_NIL;
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	prc_1 = getCompilerProc__magicsys_u150((*(*m_p0).g).graph, sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	fillProcLoc__cgen_u14051(m_p0, (*(*prc_1).ast)._kind_6.sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = rawNewString(prefix_p2.len + sym_p1.len + 0);
appendString((&T2_), prefix_p2);
appendString((&T2_), sym_p1);
	extname_1 = T2_;
	tmp_1 = mangleDynLibProc__cgen_u5410(prc_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___system_u2694((&(*prc_1).loc.snippet), tmp_1);
	eqsink___ast_u4583(&(*(*prc_1).typ).sym, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym7782__1;
		NIM_BOOL T5_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T9_;
		xX60gensym7782__1 = (*prc_1).itemId;
		T5_ = (NIM_BOOL)0;
		T5_ = containsOrIncl__astyaml_u223((&(*m_p0).declaredThings), (NI)((NI)((NU32)(((NI) (xX60gensym7782__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym7782__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T5_)) goto LA6_;
		colontmpD__4 = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		T9_[0] = (*prc_1).loc.snippet;
		colontmpD__4 = t__cgen_u97((*prc_1).loc);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		colontmpD__5 = getTypeDesc__cgen_u8738(m_p0, colontmpD__4, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_[1] = colontmpD__5;
		colontmpD__6 = percent___cgen_u30387(T9_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__6.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)9))- 0]), colontmpD__6);
		{
			LA8_:;
		}
		{
			oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___ast_u3378(colontmpD__4);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin8_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	T12_[0] = tmp_1;
	colontmpD_ = getTypeDesc__cgen_u8738(m_p0, (*prc_1).typ, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_[1] = colontmpD_;
	T12_[2] = getProcFunc_p4;
	T12_[3] = handle_p3;
	T13_.len = 0; T13_.p = NIM_NIL;
	T13_ = rawNewString(prefix_p2.len + sym_p1.len + 0);
appendString((&T13_), prefix_p2);
appendString((&T13_), sym_p1);
	colontmpD__2 = T13_;
	colontmpD__3 = makeCString__msgs_u83(colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T12_[4] = colontmpD__3;
	result = percent___cgen_u30392(T12_, 5);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tmp_1);
		eqdestroy___system_u2691(extname_1);
		eqdestroy___ast_u4574(prc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getDatInitName__cgen_u29434)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = getSomeInitName__cgen_u29423(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3629);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genDatInitCode__cgen_u30323)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 prc_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NIM_BOOL moduleDatInitRequired_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T2_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T16_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	prc_1.len = 0; prc_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	moduleDatInitRequired_1 = hcrOn__cgen_u49(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T5_) goto LA6_;
		colontmpD_ = TM__MQdRN7fpbG7rPm4JpVVAhA_3626;
		T2_[0] = colontmpD_;
	}
	goto LA3_;
LA6_: ;
	{
		colontmpD__2 = TM__MQdRN7fpbG7rPm4JpVVAhA_3627;
		T2_[0] = colontmpD__2;
	}
LA3_: ;
	colontmpD__3 = getDatInitName__cgen_u29434(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[1] = colontmpD__3;
	prc_1 = percent___cgen_u30326(T2_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genCLineDir__cgen_u370((&prc_1), ((NI32)-1), ((NI)999999), (*(*m_p0).g).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ i_1;
		NI res_1;
		i_1 = (tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0;
		res_1 = ((NI)13);
		{
			while (1) {
				if (!(res_1 <= ((NI)15))) goto LA11;
				i_1 = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ) (res_1));
				{
					if (!!(((*m_p0).s[(i_1)- 0].len == ((NI)0)))) goto LA14_;
					moduleDatInitRequired_1 = NIM_TRUE;
					prepareAdd((&prc_1), (*m_p0).s[(i_1)- 0].len + 0);
appendString((&prc_1), (*m_p0).s[(i_1)- 0]);
				}
LA14_: ;
				res_1 += ((NI)1);
			} LA11: ;
		}
	}
	colontmpD__4 = percent___cgen_u30337(T16_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&prc_1), colontmpD__4.len + 0);
appendString((&prc_1), colontmpD__4);
	{
		if (!moduleDatInitRequired_1) goto LA19_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)12))- 0]), prc_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)12))- 0]), prc_1);
	}
LA19_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(prc_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NU64, hiXorLoFallback64__pureZhashes_u37)(NU64 a_p0, NU64 b_p1) {
	NU64 result;
	NU64 colontmpD_;
	NU64 colontmpD__2;
	NU64 colontmpD__3;
	NU64 colontmpD__4;
	NU64 aH_1;
	NU64 aL_1;
	NU64 bH_1;
	NU64 bL_1;
	NU64 rHH_1;
	NU64 rHL_1;
	NU64 rLH_1;
	NU64 rLL_1;
	NU64 t_1;
	NU64 c_1;
	NU64 lo_1;
	NU64 T6_;
	NU64 hi_1;
{	colontmpD_ = (NU64)0;
	colontmpD__2 = (NU64)0;
	colontmpD__3 = (NU64)0;
	colontmpD__4 = (NU64)0;
	aH_1 = (NU64)((NU64)(a_p0) >> (NU64)(((NI)32) & (64 - 1)));
	aL_1 = (NU64)(a_p0 & 4294967295ULL);
	bH_1 = (NU64)((NU64)(b_p1) >> (NU64)(((NI)32) & (64 - 1)));
	bL_1 = (NU64)(b_p1 & 4294967295ULL);
	rHH_1 = (NU64)((NU64)(aH_1) * (NU64)(bH_1));
	rHL_1 = (NU64)((NU64)(aH_1) * (NU64)(bL_1));
	rLH_1 = (NU64)((NU64)(aL_1) * (NU64)(bH_1));
	rLL_1 = (NU64)((NU64)(aL_1) * (NU64)(bL_1));
	t_1 = (NU64)((NU64)(rLL_1) + (NU64)((NU64)((NU64)(rHL_1) << (NU64)(((NI)32) & (64 - 1)))));
	{
		if (!((NU64)(t_1) < (NU64)(rLL_1))) goto LA3_;
		colontmpD_ = 1ULL;
		c_1 = colontmpD_;
	}
	goto LA1_;
LA3_: ;
	{
		colontmpD__2 = 0ULL;
		c_1 = colontmpD__2;
	}
LA1_: ;
	lo_1 = (NU64)((NU64)(t_1) + (NU64)((NU64)((NU64)(rLH_1) << (NU64)(((NI)32) & (64 - 1)))));
	T6_ = (NU64)0;
	{
		if (!((NU64)(lo_1) < (NU64)(t_1))) goto LA9_;
		colontmpD__3 = 1ULL;
		T6_ = colontmpD__3;
	}
	goto LA7_;
LA9_: ;
	{
		colontmpD__4 = 0ULL;
		T6_ = colontmpD__4;
	}
LA7_: ;
	c_1 += T6_;
	hi_1 = (NU64)((NU64)((NU64)((NU64)((NU64)((NU64)(rHH_1) + (NU64)((NU64)((NU64)(rHL_1) >> (NU64)(((NI)32) & (64 - 1)))))) + (NU64)((NU64)((NU64)(rLH_1) >> (NU64)(((NI)32) & (64 - 1)))))) + (NU64)(c_1));
	result = (NU64)(hi_1 ^ lo_1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NU64, hiXorLo__pureZhashes_u81)(NU64 a_p0, NU64 b_p1) {
	NU64 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NU64)0;
	result = hiXorLoFallback64__pureZhashes_u37(a_p0, b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, hashWangYi1__pureZhashes_u140)(NU64 x_p0) {
	NI result;
	NU64 T1_;
	NU64 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NU64)0;
	T1_ = hiXorLo__pureZhashes_u81(11562461410679940143ULL, (NU64)(x_p0 ^ 16646288086500911323ULL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NU64)0;
	T2_ = hiXorLo__pureZhashes_u81(T1_, 16952864883938283885ULL);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = ((NI) (T2_));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, hash__ast_u624)(NI32 x_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = hashWangYi1__pureZhashes_u140(((NU64) (x_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0) {
	NIM_BOOL result;
	result = !((hcode_p0 == ((NI)0)));
	return result;
}
static N_INLINE(NI, nextTry__pureZcollectionsZtables_u35)(NI h_p0, NI maxHash_p1) {
	NI result;
	result = (NI)((NI)(h_p0 + ((NI)1)) & maxHash_p1);
	return result;
}
static N_INLINE(NI, rawGet__cgen_u29842)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw t_p0, NI32 key_p1, NI* hc_p2) {
	NI result;
	NI T1_;
	NI h_1;
	NI T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(key_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*hc_p2) = T1_;
	{
		if (!((*hc_p2) == ((NI)0))) goto LA4_;
		(*hc_p2) = ((NI)314159265);
	}
LA4_: ;
	{
		NI T8_;
		T8_ = t_p0.data.len;
		if (!(T8_ == ((NI)0))) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	T11_ = (t_p0.data.len-1);
	h_1 = (NI)((*hc_p2) & T11_);
	{
		while (1) {
			NIM_BOOL T14_;
			NI T21_;
			T14_ = (NIM_BOOL)0;
			T14_ = isFilled__pureZcollectionsZtables_u32(t_p0.data.p->data[h_1].Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T14_) goto LA13;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (t_p0.data.p->data[h_1].Field0 == (*hc_p2));
				if (!(T17_)) goto LA18_;
				T17_ = (t_p0.data.p->data[h_1].Field1 == key_p1);
LA18_: ;
				if (!T17_) goto LA19_;
				result = h_1;
				goto BeforeRet_;
			}
LA19_: ;
			T21_ = (t_p0.data.len-1);
			h_1 = nextTry__pureZcollectionsZtables_u35(h_1, T21_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA13: ;
	}
	result = (NI)(((NI)-1) - h_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerModuleToMain__cgen_u29814)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p1) {
	NimStringV2 init_1;
	NimStringV2 datInit_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	init_1.len = 0; init_1.p = NIM_NIL;
	datInit_1.len = 0; datInit_1.p = NIM_NIL;
	init_1 = getInitName__cgen_u29427(m_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	datInit_1 = getDatInitName__cgen_u29434(m_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 hcrModuleMeta_1;
		NimStringV2 systemModulePath_1;
		NimStringV2 mainModulePath_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T8_;
		NI hcX60gensym7723__1;
		NI indexX60gensym7723__1;
		NIM_BOOL hasKeyX60gensym7723__1;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T26_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T27_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T28_;
		tyArray__dnD8kjh6rJ1Yy5jHvid0Ow T29_;
		T4_ = (NIM_BOOL)0;
		T4_ = hcrOn__cgen_u49(m_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		hcrModuleMeta_1.len = 0; hcrModuleMeta_1.p = NIM_NIL;
		systemModulePath_1.len = 0; systemModulePath_1.p = NIM_NIL;
		mainModulePath_1.len = 0; mainModulePath_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		hcrModuleMeta_1 = percent___cgen_u29819(T8_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		systemModulePath_1 = getModuleDllPath__cgen_u158(m_p1, (*(*g_p0).modules.p->data[((NI) ((*(*(*g_p0).graph).config).m.systemFileIdx))]).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		mainModulePath_1 = getModuleDllPath__cgen_u158(m_p1, (*m_p1).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			NimStringV2 colontmpD__5;
			tyArray__YgExxhfgKcesA5EOUj1MOA T13_;
			if (!(((*(*m_p1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA11_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T13_[0] = systemModulePath_1;
			colontmpD__5 = percent___cgen_u29831(T13_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			prepareAdd((&hcrModuleMeta_1), colontmpD__5.len + 0);
appendString((&hcrModuleMeta_1), colontmpD__5);
			eqdestroy___system_u2691(colontmpD__5);
		}
LA11_: ;
		hcX60gensym7723__1 = (NI)0;
		indexX60gensym7723__1 = rawGet__cgen_u29842((*(*g_p0).graph).importDeps, ((NI32) ((*(*m_p1).module).position)), (&hcX60gensym7723__1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		hasKeyX60gensym7723__1 = (((NI)0) <= indexX60gensym7723__1);
		{
			tySequence__48JTohSgTy339bRxHzUD8KA* deps_1;
			if (!hasKeyX60gensym7723__1) goto LA16_;
			deps_1 = (&(*(*g_p0).graph).importDeps.data.p->data[indexX60gensym7723__1].Field2);
			{
				NI32* curr_1;
				NI i_1;
				NI L_1;
				NI T19_;
				curr_1 = (NI32*)0;
				i_1 = ((NI)0);
				T19_ = (*deps_1).len;
				L_1 = T19_;
				{
					while (1) {
						NimStringV2 colontmpD__6;
						NimStringV2 colontmpD__7;
						tyArray__YgExxhfgKcesA5EOUj1MOA T23_;
						if (!(i_1 < L_1)) goto LA21;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
						curr_1 = (&(*deps_1).p->data[i_1]);
						colontmpD__6 = getModuleDllPath__cgen_u158(m_p1, (*(*g_p0).modules.p->data[((NI) ((*curr_1)))]).module);
						if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
						T23_[0] = colontmpD__6;
						colontmpD__7 = percent___cgen_u29831(T23_, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
						prepareAdd((&hcrModuleMeta_1), colontmpD__7.len + 0);
appendString((&hcrModuleMeta_1), colontmpD__7);
						i_1 += ((NI)1);
						{
							LA22_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__7);
							eqdestroy___system_u2691(colontmpD__6);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					} LA21: ;
				}
			}
		}
LA16_: ;
		colontmpD_ = percent___cgen_u30163(T26_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&hcrModuleMeta_1), colontmpD_.len + 0);
appendString((&hcrModuleMeta_1), colontmpD_);
		colontmpD__2 = percent___cgen_u30168(T27_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&hcrModuleMeta_1), colontmpD__2.len + 0);
appendString((&hcrModuleMeta_1), colontmpD__2);
		nimZeroMem((void*)T29_, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
		sigHash__sighashes_u522((*m_p1).module, (*(*m_p1).g).config, T29_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		colontmpD__3 = dollar___modulegraphs_u10732(T29_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		T28_[0] = colontmpD__3;
		colontmpD__4 = percent___cgen_u30173(T28_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		prepareAdd((&hcrModuleMeta_1), colontmpD__4.len + 0);
appendString((&hcrModuleMeta_1), colontmpD__4);
		{
			NimStringV2 colontmpD__8;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			NimStringV2 colontmpD__15;
			NimStringV2 colontmpD__16;
			NimStringV2 colontmpD__17;
			NimStringV2 colontmpD__18;
			NimStringV2 colontmpD__19;
			NimStringV2 osModulePath_1;
			NimStringV2 colontmpD__20;
			NimStringV2 colontmpD__21;
			NimStringV2 colontmpD__22;
			tyArray__TonP9cxJgj8gXu71dWIyNlA T35_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T36_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T37_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T38_;
			tyArray__TonP9cxJgj8gXu71dWIyNlA T39_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T40_;
			tyArray__dyW7vpmfeTYw8kX3EXuaJA T41_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T42_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T43_;
			tyArray__TonP9cxJgj8gXu71dWIyNlA T44_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T45_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T46_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T47_;
			if (!(((*(*m_p1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA32_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
			osModulePath_1.len = 0; osModulePath_1.p = NIM_NIL;
			colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
			colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
			colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
			prepareAdd((&(*g_p0).mainModProcs), hcrModuleMeta_1.len + 0);
appendString((&(*g_p0).mainModProcs), hcrModuleMeta_1);
			colontmpD__8 = percent___cgen_u30182(T35_, 0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainModProcs), colontmpD__8.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__8);
			T36_[0] = init_1;
			colontmpD__9 = percent___cgen_u30187(T36_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainModProcs), colontmpD__9.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__9);
			T37_[0] = datInit_1;
			colontmpD__10 = percent___cgen_u30187(T37_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainModProcs), colontmpD__10.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__10);
			colontmpD__11 = getHcrInitName__cgen_u29437(m_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T38_[0] = colontmpD__11;
			colontmpD__12 = percent___cgen_u30196(T38_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainModProcs), colontmpD__12.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__12);
			colontmpD__13 = percent___cgen_u30201(T39_, 0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainModProcs), colontmpD__13.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__13);
			T40_[0] = init_1;
			colontmpD__14 = percent___cgen_u29745(T40_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainModInit), colontmpD__14.len + 0);
appendString((&(*g_p0).mainModInit), colontmpD__14);
			T41_[0] = mainModulePath_1;
			T41_[1] = systemModulePath_1;
			T41_[2] = datInit_1;
			colontmpD__15 = percent___cgen_u30210(T41_, 3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).otherModsInit), colontmpD__15.len + 0);
appendString((&(*g_p0).otherModsInit), colontmpD__15);
			colontmpD__16 = getHcrInitName__cgen_u29437(m_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T42_[0] = colontmpD__16;
			colontmpD__17 = percent___cgen_u30215(T42_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainDatInit), colontmpD__17.len + 0);
appendString((&(*g_p0).mainDatInit), colontmpD__17);
			T43_[0] = mainModulePath_1;
			colontmpD__18 = percent___cgen_u30220(T43_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainDatInit), colontmpD__18.len + 0);
appendString((&(*g_p0).mainDatInit), colontmpD__18);
			colontmpD__19 = percent___cgen_u30225(T44_, 0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainDatInit), colontmpD__19.len + 0);
appendString((&(*g_p0).mainDatInit), colontmpD__19);
			osModulePath_1 = nsuReplaceStr(systemModulePath_1, TM__MQdRN7fpbG7rPm4JpVVAhA_3631, TM__MQdRN7fpbG7rPm4JpVVAhA_3633);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			T45_[0] = osModulePath_1;
			colontmpD__20 = percent___cgen_u30220(T45_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainDatInit), colontmpD__20.len + 0);
appendString((&(*g_p0).mainDatInit), colontmpD__20);
			prepareAdd((&(*g_p0).mainDatInit), 17);
appendString((&(*g_p0).mainDatInit), TM__MQdRN7fpbG7rPm4JpVVAhA_3635);
			prepareAdd((&(*g_p0).mainDatInit), 19);
appendString((&(*g_p0).mainDatInit), TM__MQdRN7fpbG7rPm4JpVVAhA_3637);
			T46_[0] = osModulePath_1;
			colontmpD__21 = percent___cgen_u30235(T46_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainDatInit), colontmpD__21.len + 0);
appendString((&(*g_p0).mainDatInit), colontmpD__21);
			T47_[0] = osModulePath_1;
			colontmpD__22 = percent___cgen_u30240(T47_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA34_;
			prepareAdd((&(*g_p0).mainDatInit), colontmpD__22.len + 0);
appendString((&(*g_p0).mainDatInit), colontmpD__22);
			prepareAdd((&(*g_p0).mainDatInit), 24);
appendString((&(*g_p0).mainDatInit), TM__MQdRN7fpbG7rPm4JpVVAhA_3639);
			prepareAdd((&(*g_p0).mainDatInit), 22);
appendString((&(*g_p0).mainDatInit), TM__MQdRN7fpbG7rPm4JpVVAhA_3641);
			{
				LA34_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__22);
				eqdestroy___system_u2691(colontmpD__21);
				eqdestroy___system_u2691(colontmpD__20);
				eqdestroy___system_u2691(osModulePath_1);
				eqdestroy___system_u2691(colontmpD__19);
				eqdestroy___system_u2691(colontmpD__18);
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(colontmpD__16);
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
				eqdestroy___system_u2691(colontmpD__12);
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(colontmpD__8);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		}
		goto LA30_;
LA32_: ;
		{
			prepareAdd((&(*m_p1).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), hcrModuleMeta_1.len + 0);
appendString((&(*m_p1).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), hcrModuleMeta_1);
		}
LA30_: ;
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(mainModulePath_1);
		eqdestroy___system_u2691(systemModulePath_1);
		eqdestroy___system_u2691(hcrModuleMeta_1);
		eqdestroy___system_u2691(datInit_1);
		eqdestroy___system_u2691(init_1);
		goto BeforeRet_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(mainModulePath_1);
			eqdestroy___system_u2691(systemModulePath_1);
			eqdestroy___system_u2691(hcrModuleMeta_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		NimStringV2 colontmpD__23;
		NimStringV2 colontmpD__24;
		tyArray__YgExxhfgKcesA5EOUj1MOA T57_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T58_;
		if (!(((NI)0) < (*m_p1).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)12))- 0].len)) goto LA55_;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
		T57_[0] = datInit_1;
		colontmpD__23 = percent___cgen_u29740(T57_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*g_p0).mainModProcs), colontmpD__23.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__23);
		T58_[0] = datInit_1;
		colontmpD__24 = percent___cgen_u29745(T58_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*g_p0).mainDatInit), colontmpD__24.len + 0);
appendString((&(*g_p0).mainDatInit), colontmpD__24);
		eqdestroy___system_u2691(colontmpD__24);
		eqdestroy___system_u2691(colontmpD__23);
	}
LA55_: ;
	{
		if (!(((*(*m_p1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0)) goto LA61_;
		{
			NIM_BOOL T65_;
			NimStringV2 res_1;
			NimStringV2 colontmpD__25;
			T65_ = (NIM_BOOL)0;
			T65_ = emulatedThreadVars__cgen_u452((*(*m_p1).g).config);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(T65_)) goto LA66_;
			T65_ = !(((*(*(*m_p1).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)29)));
LA66_: ;
			if (!T65_) goto LA67_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3642);
			colontmpD__25 = cgsymValue__cgen_u141(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3643);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__25);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
			prepareAdd((&res_1), 4);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3645);
			prepareAdd((&(*g_p0).mainDatInit), res_1.len + 0);
appendString((&(*g_p0).mainDatInit), res_1);
			{
				LA69_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__25);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA67_: ;
		{
			NIM_BOOL T74_;
			NimStringV2 res_2;
			NimStringV2 colontmpD__26;
			T74_ = (NIM_BOOL)0;
			T74_ = !(((*(*(*m_p1).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)29)));
			if (!(T74_)) goto LA75_;
			T74_ = !(((*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)1) || (*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*m_p1).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5)));
LA75_: ;
			if (!T74_) goto LA76_;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__26.len = 0; colontmpD__26.p = NIM_NIL;
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3646);
			colontmpD__26 = cgsymValue__cgen_u141(m_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3647);
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto LA78_;
			prepareAdd((&res_2), 18);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3649);
			prepareAdd((&(*g_p0).mainDatInit), res_2.len + 0);
appendString((&(*g_p0).mainDatInit), res_2);
			{
				LA78_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__26);
				eqdestroy___system_u2691(res_2);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA76_: ;
	}
LA61_: ;
	{
		NimStringV2 colontmpD__27;
		NimStringV2 initCall_1;
		tyArray__YgExxhfgKcesA5EOUj1MOA T85_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T86_;
		if (!(((NI)0) < (*m_p1).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0].len)) goto LA83_;
		colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
		initCall_1.len = 0; initCall_1.p = NIM_NIL;
		T85_[0] = init_1;
		colontmpD__27 = percent___cgen_u29740(T85_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*g_p0).mainModProcs), colontmpD__27.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__27);
		T86_[0] = init_1;
		initCall_1 = percent___cgen_u29745(T86_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(((*(*m_p1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA89_;
			prepareAdd((&(*g_p0).mainModInit), initCall_1.len + 0);
appendString((&(*g_p0).mainModInit), initCall_1);
		}
		goto LA87_;
LA89_: ;
		{
			if (!(((*(*m_p1).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0)) goto LA92_;
			prepareAdd((&(*g_p0).mainDatInit), initCall_1.len + 0);
appendString((&(*g_p0).mainDatInit), initCall_1);
		}
		goto LA87_;
LA92_: ;
		{
			prepareAdd((&(*g_p0).otherModsInit), initCall_1.len + 0);
appendString((&(*g_p0).otherModsInit), initCall_1);
		}
LA87_: ;
		eqdestroy___system_u2691(initCall_1);
		eqdestroy___system_u2691(colontmpD__27);
	}
LA83_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(datInit_1);
		eqdestroy___system_u2691(init_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genInitCode__cgen_u30397)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 initname_1;
	NimStringV2 prc_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NIM_BOOL moduleInitRequired_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T2_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T103_;
NIM_BOOL oldNimErrFin178_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T201_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T202_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	initname_1.len = 0; initname_1.p = NIM_NIL;
	prc_1.len = 0; prc_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	moduleInitRequired_1 = hcrOn__cgen_u49(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	initname_1 = getInitName__cgen_u29427(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T5_) goto LA6_;
		colontmpD_ = TM__MQdRN7fpbG7rPm4JpVVAhA_3554;
		T2_[0] = colontmpD_;
	}
	goto LA3_;
LA6_: ;
	{
		colontmpD__2 = TM__MQdRN7fpbG7rPm4JpVVAhA_3556;
		T2_[0] = colontmpD__2;
	}
LA3_: ;
	T2_[1] = initname_1;
	prc_1 = percent___cgen_u30326(T2_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genCLineDir__cgen_u370((&prc_1), ((NI32)-1), ((NI)999999), (*(*m_p0).g).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(((NI)0) < (*m_p0).typeNodes)) goto LA11_;
		{
			NIM_BOOL T15_;
			NimStringV2 res_1;
			NimStringV2 colontmpD__6;
			NimStringV2 res_2;
			NimStringV2 colontmpD__7;
			T15_ = (NIM_BOOL)0;
			T15_ = hcrOn__cgen_u49(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T15_) goto LA16_;
			res_1.len = 0; res_1.p = NIM_NIL;
			colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
			res_2.len = 0; res_2.p = NIM_NIL;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			res_1 = rawNewString(((NI)80));
			prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3557);
			colontmpD__6 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3558);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			cgFormatValue__cgen_u163((&res_1), colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3560);
			cgFormatValue__cgen_u163((&res_1), (*m_p0).typeNodesName);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			prepareAdd((&res_1), 2);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3561);
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), res_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), res_1);
			res_2 = rawNewString(((NI)80));
			prepareAdd((&res_2), 19);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3563);
			colontmpD__7 = getModuleDllPath__cgen_u158(m_p0, (*m_p0).module);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			cgFormatValue__cgen_u163((&res_2), colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3564);
			cgFormatValue__cgen_u163((&res_2), (*m_p0).typeNodesName);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3565);
			cgFormatValue__cgen_u166((&res_2), ((NI64) ((*m_p0).typeNodes)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			prepareAdd((&res_2), 22);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3567);
			cgFormatValue__cgen_u166((&res_2), ((NI64) ((*m_p0).typeNodes)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			prepareAdd((&res_2), 17);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3569);
			cgFormatValue__cgen_u163((&res_2), (*m_p0).typeNodesName);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			prepareAdd((&res_2), 3);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3570);
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), res_2.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), res_2);
			{
				LA18_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
				eqdestroy___system_u2691(res_2);
				eqdestroy___system_u2691(colontmpD__6);
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA13_;
LA16_: ;
		{
			NimStringV2 res_3;
			NimStringV2 colontmpD__8;
			res_3.len = 0; res_3.p = NIM_NIL;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 7);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3571);
			colontmpD__8 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3572);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			cgFormatValue__cgen_u163((&res_3), colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3573);
			cgFormatValue__cgen_u163((&res_3), (*m_p0).typeNodesName);
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3574);
			cgFormatValue__cgen_u166((&res_3), ((NI64) ((*m_p0).typeNodes)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
			prepareAdd((&res_3), 2);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3575);
			{
				if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA25_;
				prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3576);
			}
LA25_: ;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), res_3.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), res_3);
			{
				LA22_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__8);
				eqdestroy___system_u2691(res_3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA13_: ;
	}
LA11_: ;
	{
		NimStringV2 res_4;
		NimStringV2 colontmpD__9;
		if (!(((NI)0) < (*m_p0).nimTypes)) goto LA31_;
		res_4.len = 0; res_4.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		res_4 = rawNewString(((NI)80));
		prepareAdd((&res_4), 7);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3577);
		colontmpD__9 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3578);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		cgFormatValue__cgen_u163((&res_4), colontmpD__9);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3579);
		cgFormatValue__cgen_u163((&res_4), (*m_p0).nimTypesName);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3580);
		cgFormatValue__cgen_u166((&res_4), ((NI64) ((*m_p0).nimTypes)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		prepareAdd((&res_4), 2);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3581);
		{
			if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA36_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3582);
		}
LA36_: ;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), res_4.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)13))- 0]), res_4);
		{
			LA33_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(res_4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA31_: ;
	{
		NIM_BOOL T42_;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmpD__11;
		tyArray__YgExxhfgKcesA5EOUj1MOA T46_;
		T42_ = (NIM_BOOL)0;
		T42_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T42_) goto LA43_;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__10 = getModuleDllPath__cgen_u158(m_p0, (*m_p0).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		T46_[0] = colontmpD__10;
		colontmpD__11 = percent___cgen_u30450(T46_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA45_;
		prepareAdd((&prc_1), colontmpD__11.len + 0);
appendString((&prc_1), colontmpD__11);
		{
			LA45_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmpD__10);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA43_: ;
	{
		NIM_BOOL T51_;
		NimStringV2* T52_;
		NimStringV2* T54_;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T57_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T102_;
		T51_ = (NIM_BOOL)0;
		T52_ = (NimStringV2*)0;
		T52_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T51_ = (((NI)0) < (*T52_).len);
		if (T51_) goto LA53_;
		T54_ = (NimStringV2*)0;
		T54_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T51_ = (((NI)0) < (*T54_).len);
LA53_: ;
		if (!T51_) goto LA55_;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__12 = percent___cgen_u30459(T57_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&prc_1), colontmpD__12.len + 0);
appendString((&prc_1), colontmpD__12);
		prepareAdd((&prc_1), 26);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3584);
		{
			NimStringV2* T60_;
			NimStringV2* T67_;
			T60_ = (NimStringV2*)0;
			T60_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)0) < (*T60_).len)) goto LA61_;
			moduleInitRequired_1 = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA65_;
				prepareAdd((&prc_1), 26);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3586);
			}
LA65_: ;
			T67_ = (NimStringV2*)0;
			T67_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&prc_1), (*T67_).len + 0);
appendString((&prc_1), (*T67_));
			{
				if (!NIM_FALSE) goto LA70_;
				prepareAdd((&prc_1), 24);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3588);
			}
LA70_: ;
		}
LA61_: ;
		{
			NimStringV2* T74_;
			NimStringV2* T82_;
			T74_ = (NimStringV2*)0;
			T74_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)0) < (*T74_).len)) goto LA75_;
			moduleInitRequired_1 = NIM_TRUE;
			{
				NIM_BOOL T79_;
				T79_ = (NIM_BOOL)0;
				T79_ = hcrOn__cgen_u49(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T79_) goto LA80_;
				prepareAdd((&prc_1), 26);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3589);
			}
LA80_: ;
			T82_ = (NimStringV2*)0;
			T82_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&prc_1), (*T82_).len + 0);
appendString((&prc_1), (*T82_));
			{
				NIM_BOOL T85_;
				T85_ = (NIM_BOOL)0;
				T85_ = hcrOn__cgen_u49(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T85_) goto LA86_;
				prepareAdd((&prc_1), 24);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3590);
			}
LA86_: ;
		}
LA75_: ;
		{
			NimStringV2* T90_;
			NimStringV2* T97_;
			T90_ = (NimStringV2*)0;
			T90_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)0) < (*T90_).len)) goto LA91_;
			moduleInitRequired_1 = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA95_;
				prepareAdd((&prc_1), 26);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3591);
			}
LA95_: ;
			T97_ = (NimStringV2*)0;
			T97_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&prc_1), (*T97_).len + 0);
appendString((&prc_1), (*T97_));
			{
				if (!NIM_FALSE) goto LA100_;
				prepareAdd((&prc_1), 24);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3592);
			}
LA100_: ;
		}
LA91_: ;
		colontmpD__13 = percent___cgen_u30464(T102_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&prc_1), colontmpD__13.len + 0);
appendString((&prc_1), colontmpD__13);
		eqdestroy___system_u2691(colontmpD__13);
		eqdestroy___system_u2691(colontmpD__12);
	}
LA55_: ;
	colontmpD__3 = percent___cgen_u30459(T103_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&prc_1), colontmpD__3.len + 0);
appendString((&prc_1), colontmpD__3);
	{
		NimStringV2* T106_;
		NimStringV2* T113_;
		T106_ = (NimStringV2*)0;
		T106_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)0) < (*T106_).len)) goto LA107_;
		moduleInitRequired_1 = NIM_TRUE;
		{
			if (!NIM_FALSE) goto LA111_;
			prepareAdd((&prc_1), 26);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3593);
		}
LA111_: ;
		T113_ = (NimStringV2*)0;
		T113_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&prc_1), (*T113_).len + 0);
appendString((&prc_1), (*T113_));
		{
			if (!NIM_FALSE) goto LA116_;
			prepareAdd((&prc_1), 24);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3594);
		}
LA116_: ;
	}
LA107_: ;
	{
		NIM_BOOL T120_;
		NimStringV2* T121_;
		NimStringV2* T123_;
		T120_ = (NIM_BOOL)0;
		T121_ = (NimStringV2*)0;
		T121_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T120_ = (((NI)0) < (*T121_).len);
		if (T120_) goto LA122_;
		T123_ = (NimStringV2*)0;
		T123_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T120_ = (((NI)0) < (*T123_).len);
LA122_: ;
		if (!T120_) goto LA124_;
		moduleInitRequired_1 = NIM_TRUE;
		{
			NIM_BOOL T128_;
			T128_ = (NIM_BOOL)0;
			T128_ = (((*(*m_p0).initProc).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0);
			if (!(T128_)) goto LA129_;
			T128_ = !((((*m_p0).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)2)))&7U)))!=0));
LA129_: ;
			if (!T128_) goto LA130_;
			(*m_p0).flags |= ((NU8)1)<<(((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)2))) & 7);
			{
				NimStringV2 procname_1;
				NimStringV2 colontmpD__14;
				NimStringV2 colontmpD__15;
				if (!!((((*m_p0).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)0)))&7U)))!=0))) goto LA134_;
				procname_1.len = 0; procname_1.p = NIM_NIL;
				colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
				colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
				procname_1 = makeCString__msgs_u83((*(*(*m_p0).module).name).s);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				colontmpD__14 = quotedFilename__msgs_u1638((*(*m_p0).g).config, (*(*m_p0).module).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				colontmpD__15 = initFrame__cgen_u19996((*m_p0).initProc, procname_1, colontmpD__14);
				if (NIM_UNLIKELY(*nimErr_)) goto LA136_;
				prepareAdd((&prc_1), colontmpD__15.len + 0);
appendString((&prc_1), colontmpD__15);
				{
					LA136_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__15);
					eqdestroy___system_u2691(colontmpD__14);
					eqdestroy___system_u2691(procname_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA132_;
LA134_: ;
			{
				prepareAdd((&prc_1), 26);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3595);
			}
LA132_: ;
		}
LA130_: ;
		{
			NimStringV2* T142_;
			NimStringV2* T150_;
			T142_ = (NimStringV2*)0;
			T142_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)0) < (*T142_).len)) goto LA143_;
			moduleInitRequired_1 = NIM_TRUE;
			{
				NIM_BOOL T147_;
				T147_ = (NIM_BOOL)0;
				T147_ = hcrOn__cgen_u49(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T147_) goto LA148_;
				prepareAdd((&prc_1), 26);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3596);
			}
LA148_: ;
			T150_ = (NimStringV2*)0;
			T150_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&prc_1), (*T150_).len + 0);
appendString((&prc_1), (*T150_));
			{
				NIM_BOOL T153_;
				T153_ = (NIM_BOOL)0;
				T153_ = hcrOn__cgen_u49(m_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T153_) goto LA154_;
				prepareAdd((&prc_1), 24);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3597);
			}
LA154_: ;
		}
LA143_: ;
		{
			NimStringV2* T158_;
			NimStringV2* T165_;
			T158_ = (NimStringV2*)0;
			T158_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)0) < (*T158_).len)) goto LA159_;
			moduleInitRequired_1 = NIM_TRUE;
			{
				if (!NIM_FALSE) goto LA163_;
				prepareAdd((&prc_1), 26);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3598);
			}
LA163_: ;
			T165_ = (NimStringV2*)0;
			T165_ = s__cgendata_u228((*m_p0).initProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&prc_1), (*T165_).len + 0);
appendString((&prc_1), (*T165_));
			{
				if (!NIM_FALSE) goto LA168_;
				prepareAdd((&prc_1), 24);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3599);
			}
LA168_: ;
		}
LA159_: ;
		{
			if (!(((*(*m_p0).initProc).flags &((NU8)1<<((NU)((((tyEnum_TCProcFlag__rjMLtUxeLhGjW8sIRJRLVQ)0)))&7U)))!=0)) goto LA172_;
			prepareAdd((&prc_1), 15);
appendString((&prc_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3601);
		}
LA172_: ;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__16;
			if (!((*(*(*m_p0).g).config).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)3))) goto LA176_;
			colontmpD__16 = NIM_NIL;
			{
				NimStringV2 res_5;
				NimStringV2 colontmpD__17;
				colontmpD__16 = getCompilerProc__magicsys_u150((*(*m_p0).g).graph, TM__MQdRN7fpbG7rPm4JpVVAhA_3602);
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
				if (!!((colontmpD__16 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA181_;
				res_5.len = 0; res_5.p = NIM_NIL;
				colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
				res_5 = rawNewString(((NI)80));
				prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3603);
				colontmpD__17 = cgsymValue__cgen_u141(m_p0, TM__MQdRN7fpbG7rPm4JpVVAhA_3604);
				if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
				cgFormatValue__cgen_u163((&res_5), colontmpD__17);
				if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
				prepareAdd((&res_5), 3);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3605);
				{
					if (!!((((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0))) goto LA186_;
					prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3606);
				}
LA186_: ;
				prepareAdd((&prc_1), res_5.len + 0);
appendString((&prc_1), res_5);
				{
					LA183_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__17);
					eqdestroy___system_u2691(res_5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA178_;
			}
LA181_: ;
			{
				LA178_:;
			}
			{
				oldNimErrFin178_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(colontmpD__16);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin178_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA176_: ;
		{
			NIM_BOOL T194_;
			NimStringV2 colontmpD__18;
			T194_ = (NIM_BOOL)0;
			T194_ = (((*(*m_p0).initProc).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)17)))&31U)))!=0);
			if (!(T194_)) goto LA195_;
			T194_ = !((((*m_p0).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)0)))&7U)))!=0));
LA195_: ;
			if (!T194_) goto LA196_;
			colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
			colontmpD__18 = deinitFrame__cgen_u20066((*m_p0).initProc);
			if (NIM_UNLIKELY(*nimErr_)) goto LA198_;
			prepareAdd((&prc_1), colontmpD__18.len + 0);
appendString((&prc_1), colontmpD__18);
			{
				LA198_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__18);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA196_: ;
	}
LA124_: ;
	colontmpD__4 = percent___cgen_u30523(T201_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&prc_1), colontmpD__4.len + 0);
appendString((&prc_1), colontmpD__4);
	colontmpD__5 = percent___cgen_u30337(T202_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&prc_1), colontmpD__5.len + 0);
appendString((&prc_1), colontmpD__5);
	{
		NIM_BOOL T205_;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ procsToLoad_1;
		NimStringV2 colontmpD__19;
		NimStringV2 colontmpD__20;
		NimStringV2 colontmpD__21;
		tyArray__YgExxhfgKcesA5EOUj1MOA T209_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T221_;
		T205_ = (NIM_BOOL)0;
		T205_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T205_) goto LA206_;
		procsToLoad_1.len = 0; procsToLoad_1.p = NIM_NIL;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		procsToLoad_1.len = 4; procsToLoad_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(4, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		procsToLoad_1.p->data[0] = TM__MQdRN7fpbG7rPm4JpVVAhA_3608;
		procsToLoad_1.p->data[1] = TM__MQdRN7fpbG7rPm4JpVVAhA_3610;
		procsToLoad_1.p->data[2] = TM__MQdRN7fpbG7rPm4JpVVAhA_3612;
		procsToLoad_1.p->data[3] = TM__MQdRN7fpbG7rPm4JpVVAhA_3614;
		colontmpD__19 = getHcrInitName__cgen_u29437(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
		T209_[0] = colontmpD__19;
		colontmpD__20 = percent___cgen_u30537(T209_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__20.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__20);
		{
			if (!(((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA212_;
			add__stdZenumutils_u71((&procsToLoad_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3618);
			add__stdZenumutils_u71((&procsToLoad_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3620);
		}
LA212_: ;
		{
			NimStringV2* curr_1;
			NI i_1;
			NI L_1;
			NI T215_;
			curr_1 = (NimStringV2*)0;
			i_1 = ((NI)0);
			T215_ = procsToLoad_1.len;
			L_1 = T215_;
			{
				while (1) {
					NimStringV2 colontmpD__22;
					if (!(i_1 < L_1)) goto LA217;
					colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
					curr_1 = (&procsToLoad_1.p->data[i_1]);
					colontmpD__22 = hcrGetProcLoadCode__cgen_u29440(m_p0, (*curr_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3621, TM__MQdRN7fpbG7rPm4JpVVAhA_3623, TM__MQdRN7fpbG7rPm4JpVVAhA_3625);
					if (NIM_UNLIKELY(*nimErr_)) goto LA218_;
					prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__22.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__22);
					i_1 += ((NI)1);
					{
						LA218_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__22);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
				} LA217: ;
			}
		}
		colontmpD__21 = percent___cgen_u30337(T221_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA208_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__21.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__21);
		{
			LA208_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(colontmpD__19);
			eqdestroy___system_u5506(procsToLoad_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA206_: ;
	{
		NimStringV2 el_1;
		NIM_CHAR i_2;
		NIM_CHAR i_3;
		el_1.len = 0; el_1.p = NIM_NIL;
		i_2 = (NIM_CHAR)0;
		i_3 = 48;
		{
			while (1) {
				i_2 = i_3;
				eqcopy___system_u2694((&el_1), (*m_p0).extensionLoaders[(((NU8)(i_3)))- 48]);
				{
					NimStringV2 ex_1;
					NimStringV2 colontmpD__23;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T232_;
					if (!!((el_1.len == 0))) goto LA230_;
					ex_1.len = 0; ex_1.p = NIM_NIL;
					colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
					colontmpD__23 = rope__ropes_u15(((NI64) ((NI)(((NU8)(i_2)) - ((NI)48)))));
					if (NIM_UNLIKELY(*nimErr_)) goto LA225_;
					T232_[0] = colontmpD__23;
					T232_[1] = el_1;
					ex_1 = percent___cgen_u30673(T232_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA225_;
					moduleInitRequired_1 = NIM_TRUE;
					prepareAdd((&prc_1), ex_1.len + 0);
appendString((&prc_1), ex_1);
					eqdestroy___system_u2691(colontmpD__23);
					eqdestroy___system_u2691(ex_1);
				}
LA230_: ;
				{
					if (!((NU8)(57) <= (NU8)(i_3))) goto LA235_;
					goto LA226;
				}
LA235_: ;
				i_3 += ((NI)1);
			}
		} LA226: ;
		{
			LA225_:;
		}
		{
			eqdestroy___system_u2691(el_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		NIM_BOOL T241_;
		T241_ = (NIM_BOOL)0;
		T241_ = moduleInitRequired_1;
		if (T241_) goto LA242_;
		T241_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0);
LA242_: ;
		if (!T241_) goto LA243_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), prc_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), prc_1);
	}
LA243_: ;
	genDatInitCode__cgen_u30323(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T247_;
		NimStringV2 colontmpD__24;
		NimStringV2 colontmpD__25;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T250_;
		tyArray__TonP9cxJgj8gXu71dWIyNlA T251_;
		T247_ = (NIM_BOOL)0;
		T247_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T247_) goto LA248_;
		colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
		colontmpD__25.len = 0; colontmpD__25.p = NIM_NIL;
		colontmpD__24 = percent___cgen_u30683(T250_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__24.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__24);
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), (*m_p0).hcrCreateTypeInfosProc.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), (*m_p0).hcrCreateTypeInfosProc);
		colontmpD__25 = percent___cgen_u30337(T251_, 0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__25.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]), colontmpD__25);
		eqdestroy___system_u2691(colontmpD__25);
		eqdestroy___system_u2691(colontmpD__24);
	}
LA248_: ;
	registerModuleToMain__cgen_u29814((*m_p0).g, m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(prc_1);
		eqdestroy___system_u2691(initname_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, seqV2ContentType__cgen_u3527)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* check_p2) {
	NimStringV2 result_1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow sig_1;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result_1.len = 0; result_1.p = NIM_NIL;
	nimZeroMem((void*)sig_1, sizeof(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow));
	hashType__sighashes_u411(t_p1, (*(*m_p0).g).config, 2, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result_1 = cacheGetType__cgen_u1466((*m_p0).typeCache, sig_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD_;
		if (!(result_1.len == 0)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = getTypeDescAux__cgen_u1419(m_p0, t_p1, check_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		(void)(colontmpD_);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 res_1;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		NimStringV2 colontmpD__3;
		res_1.len = 0; res_1.p = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		res_1 = rawNewString(((NI)80));
		prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3650);
		cgFormatValue__cgen_u163((&res_1), result_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_1), 19);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3652);
		colontmpD__2 = skipTypes__ast_u5379(t_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		colontmpD__3 = getTypeDescAux__cgen_u1419(m_p0, (*colontmpD__2).sons.p->data[((NI)0)], check_p2, ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		cgFormatValue__cgen_u163((&res_1), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		prepareAdd((&res_1), 25);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3654);
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), res_1.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)3))- 0]), res_1);
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(res_1);
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(result_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, finishTypeDescriptions__cgen_u8787)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA check_1;
	NI i_1;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&check_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	i_1 = ((NI)0);
	initIntSet__pureZcollectionsZintsets_u598((&check_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			NI T4_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			T4_ = (*m_p0).typeStack.len;
			if (!(i_1 < T4_)) goto LA3;
			t_1 = NIM_NIL;
			colontmpD_ = NIM_NIL;
			eqcopy___ast_u3381(&t_1, (*m_p0).typeStack.p->data[i_1]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			{
				NIM_BOOL T8_;
				T8_ = (NIM_BOOL)0;
				T8_ = (((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)45)))&63U)))!=0);
				if (!(T8_)) goto LA9_;
				colontmpD_ = skipTypes__ast_u5379(t_1, TM__MQdRN7fpbG7rPm4JpVVAhA_155);
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				T8_ = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24));
LA9_: ;
				if (!T8_) goto LA10_;
				seqV2ContentType__cgen_u3527(m_p0, t_1, (&check_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			}
			goto LA6_;
LA10_: ;
			{
				NimStringV2 colontmpD__2;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__2 = getTypeDescAux__cgen_u1419(m_p0, t_1, (&check_1), ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
				(void)(colontmpD__2);
				{
					LA13_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			}
LA6_: ;
			i_1 += ((NI)1);
			{
				LA5_:;
			}
			{
				oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				eqdestroy___ast_u3378(t_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin5_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA3: ;
	}
	setLen__ast_u3333((&(*m_p0).typeStack), ((NI)0));
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pureZcollectionsZintsets_u230((&check_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u34864)(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn((*dest_p0).m0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose((*dest_p0).m0);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__cgen_u34938)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___cgen_u34864((&(*((tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) + (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, add__system_u3018)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2) {
	void** colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3026(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p1));
		add__system_u3018((&(*j_1).traceStack), p_1, (*((TNimTypeV2**) ((*p_1)))));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___cgen_u34876)(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).m0, env_p1);
}
N_LIB_PRIVATE N_CLOSURE(NimStringV2, loadLib__cgen_u29449)(NimStringV2 handle_p0, NimStringV2 name_p1, void* ClE_0) {
	NimStringV2 result;
	tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* colonenvP__1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
	NimStringV2 strLit_1;
	NimStringV2 res_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colonenvP__1 = (tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw*) ClE_0;
	prc_1 = NIM_NIL;
	n_1 = NIM_NIL;
	strLit_1.len = 0; strLit_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	result = TM__MQdRN7fpbG7rPm4JpVVAhA_3657;
	prc_1 = getCompilerProc__magicsys_u150((*(*(*colonenvP__1).m0).g).graph, name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	n_1 = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), (*(*(*prc_1).annex).path)._kind_3.strVal);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*n_1).info = (*(*(*prc_1).annex).path).info;
	strLit_1 = newRopeAppender__ropes_u7(((NI)80));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	genStringLiteral__cgen_u714((*colonenvP__1).m0, n_1, (&strLit_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 7);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3659);
	cgFormatValue__cgen_u163((&res_1), handle_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3660);
	colontmpD_ = cgsymValue__cgen_u141((*colonenvP__1).m0, TM__MQdRN7fpbG7rPm4JpVVAhA_3661);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3662);
	cgFormatValue__cgen_u163((&res_1), strLit_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 6);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3664);
	colontmpD__2 = cgsymValue__cgen_u141((*colonenvP__1).m0, TM__MQdRN7fpbG7rPm4JpVVAhA_3665);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cgFormatValue__cgen_u163((&res_1), colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3666);
	cgFormatValue__cgen_u163((&res_1), strLit_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3667);
	prepareAdd((&result), res_1.len + 0);
appendString((&result), res_1);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(strLit_1);
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(prc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, closeNamespaceNim__cgen_u28091)(NimStringV2* result_p0) {
	prepareAdd((&(*result_p0)), 2);
appendString((&(*result_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_3784);
}
N_LIB_PRIVATE N_NIMCALL(void, openNamespaceNim__cgen_u28088)(NimStringV2 namespace_p0, NimStringV2* result_p1) {
	prepareAdd((&(*result_p1)), 10);
appendString((&(*result_p1)), TM__MQdRN7fpbG7rPm4JpVVAhA_3819);
	prepareAdd((&(*result_p1)), namespace_p0.len + 0);
appendString((&(*result_p1)), namespace_p0);
	prepareAdd((&(*result_p1)), 3);
appendString((&(*result_p1)), TM__MQdRN7fpbG7rPm4JpVVAhA_3821);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u34892)(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicStatic(dest_p0, ((TNimTypeV2*) ((&NTIv2__JS0sf27XzZG7UDuztDBfOw_))));
		if (!T3_) goto LA4_;
		eqdestroy___cgen_u34864((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, genMainProc__cgen_u29446)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* colonenv__1;
	NimStringV2 preMainCode_1;
	NimStringV2 posixCmdLine_1;
	NimStringV2 initStackBottomCall_1;
	NimStringV2 isVolatile_1;
	NimStringV2 res_1;
	tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw* T2_;
	NimStringV2 T39_;
	NimStringV2 T50_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colonenv__1 = NIM_NIL;
	preMainCode_1.len = 0; preMainCode_1.p = NIM_NIL;
	posixCmdLine_1.len = 0; posixCmdLine_1.p = NIM_NIL;
	initStackBottomCall_1.len = 0; initStackBottomCall_1.p = NIM_NIL;
	isVolatile_1.len = 0; isVolatile_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	T2_ = NIM_NIL;
	T2_ = (tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw*) nimNewObj(sizeof(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw), NIM_ALIGNOF(tyObject_Env_cgendotnim_genMainProc___JS0sf27XzZG7UDuztDBfOw));
	(*T2_).Sup.m_type = (&NTIv2__JS0sf27XzZG7UDuztDBfOw_);
	colonenv__1 = T2_;
	eqcopy___cgendata_u721(&(*colonenv__1).m0, m_p0, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	preMainCode_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3656;
	{
		NIM_BOOL T5_;
		NimStringV2 colontmpD_;
		tyProc__1MHlivbOO3FSj4t5m5NfuA T9_;
		T5_ = (NIM_BOOL)0;
		T5_ = hcrOn__cgen_u49((*colonenv__1).m0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T5_) goto LA6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimZeroMem((void*)(&T9_), sizeof(tyProc__1MHlivbOO3FSj4t5m5NfuA));
		T9_.ClP_0 = loadLib__cgen_u29449; T9_.ClE_0 = colonenv__1;
		colontmpD_ = T9_.ClE_0? T9_.ClP_0(TM__MQdRN7fpbG7rPm4JpVVAhA_3669, TM__MQdRN7fpbG7rPm4JpVVAhA_3670, T9_.ClE_0):((TM__MQdRN7fpbG7rPm4JpVVAhA_3671)(T9_.ClP_0))(TM__MQdRN7fpbG7rPm4JpVVAhA_3669, TM__MQdRN7fpbG7rPm4JpVVAhA_3670);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		prepareAdd((&preMainCode_1), colontmpD_.len + 0);
appendString((&preMainCode_1), colontmpD_);
		{
			NimStringV2 colontmpD__2;
			tyArray__YgExxhfgKcesA5EOUj1MOA T14_;
			if (!((*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5))) goto LA12_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T14_[0] = (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix;
			colontmpD__2 = percent___cgen_u29476(T14_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			prepareAdd((&preMainCode_1), colontmpD__2.len + 0);
appendString((&preMainCode_1), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
		}
		goto LA10_;
LA12_: ;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 colontmpD__5;
			tyProc__1MHlivbOO3FSj4t5m5NfuA T17_;
			tyArray__YgExxhfgKcesA5EOUj1MOA T18_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			prepareAdd((&preMainCode_1), 19);
appendString((&preMainCode_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3673);
			nimZeroMem((void*)(&T17_), sizeof(tyProc__1MHlivbOO3FSj4t5m5NfuA));
			T17_.ClP_0 = loadLib__cgen_u29449; T17_.ClE_0 = colonenv__1;
			colontmpD__3 = T17_.ClE_0? T17_.ClP_0(TM__MQdRN7fpbG7rPm4JpVVAhA_3675, TM__MQdRN7fpbG7rPm4JpVVAhA_3677, T17_.ClE_0):((TM__MQdRN7fpbG7rPm4JpVVAhA_3678)(T17_.ClP_0))(TM__MQdRN7fpbG7rPm4JpVVAhA_3675, TM__MQdRN7fpbG7rPm4JpVVAhA_3677);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			prepareAdd((&preMainCode_1), colontmpD__3.len + 0);
appendString((&preMainCode_1), colontmpD__3);
			colontmpD__4 = hcrGetProcLoadCode__cgen_u29440((*colonenv__1).m0, TM__MQdRN7fpbG7rPm4JpVVAhA_3679, TM__MQdRN7fpbG7rPm4JpVVAhA_3681, TM__MQdRN7fpbG7rPm4JpVVAhA_3682, TM__MQdRN7fpbG7rPm4JpVVAhA_3683);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			prepareAdd((&preMainCode_1), colontmpD__4.len + 0);
appendString((&preMainCode_1), colontmpD__4);
			T18_[0] = (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix;
			colontmpD__5 = percent___cgen_u29481(T18_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
			prepareAdd((&preMainCode_1), colontmpD__5.len + 0);
appendString((&preMainCode_1), colontmpD__5);
			prepareAdd((&preMainCode_1), 45);
appendString((&preMainCode_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3685);
			prepareAdd((&preMainCode_1), 13);
appendString((&preMainCode_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3687);
			{
				LA16_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__5);
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		}
LA10_: ;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA6_: ;
	{
		NimStringV2 colontmpD__6;
		tyArray__YgExxhfgKcesA5EOUj1MOA T24_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		T24_[0] = (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix;
		colontmpD__6 = percent___cgen_u29476(T24_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&preMainCode_1), colontmpD__6.len + 0);
appendString((&preMainCode_1), colontmpD__6);
		eqdestroy___system_u2691(colontmpD__6);
	}
LA3_: ;
	posixCmdLine_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3688;
	{
		if (!!((((*(*(*(*colonenv__1).m0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)23)))&63U)))!=0))) goto LA27_;
		prepareAdd((&posixCmdLine_1), 28);
appendString((&posixCmdLine_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3690);
		prepareAdd((&posixCmdLine_1), 30);
appendString((&posixCmdLine_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3692);
		prepareAdd((&posixCmdLine_1), 27);
appendString((&posixCmdLine_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3694);
	}
LA27_: ;
	{
		NIM_BOOL T31_;
		tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A T33_;
		T31_ = (NIM_BOOL)0;
		T31_ = ((*(*(*(*colonenv__1).m0).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)2));
		if (!(T31_)) goto LA32_;
		T33_ = 0;
		T31_ = !((((*(*(*(*colonenv__1).m0).g).config).globalOptions & 640) == T33_));
LA32_: ;
		if (!T31_) goto LA34_;
		includeHeader__cgendata_u217((*colonenv__1).m0, TM__MQdRN7fpbG7rPm4JpVVAhA_3696);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA29_;
LA34_: ;
	{
		if (!((*(*(*(*colonenv__1).m0).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)26))) goto LA37_;
		includeHeader__cgendata_u217((*colonenv__1).m0, TM__MQdRN7fpbG7rPm4JpVVAhA_3698);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA29_;
LA37_: ;
LA29_: ;
	T39_.len = 0; T39_.p = NIM_NIL;
	{
		NIM_BOOL T42_;
		T42_ = (NIM_BOOL)0;
		T42_ = ((*(*(*(*colonenv__1).m0).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)29));
		if (T42_) goto LA43_;
		T42_ = ((*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)1) || (*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5));
LA43_: ;
		if (!T42_) goto LA44_;
		initStackBottomCall_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3699;
	}
	goto LA40_;
LA44_: ;
	{
		NimStringV2 res_2;
		NimStringV2 colontmpD__7;
		res_2.len = 0; res_2.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		res_2 = rawNewString(((NI)80));
		prepareAdd((&res_2), 1);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3700);
		colontmpD__7 = cgsymValue__cgen_u141((*colonenv__1).m0, TM__MQdRN7fpbG7rPm4JpVVAhA_3701);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		cgFormatValue__cgen_u163((&res_2), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA47_;
		prepareAdd((&res_2), 18);
appendString((&res_2), TM__MQdRN7fpbG7rPm4JpVVAhA_3702);
		initStackBottomCall_1 = res_2;
		eqwasMoved___system_u2688((&res_2));
		{
			LA47_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(res_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA40_: ;
	(*(*colonenv__1).m0).labels += ((NI)1);
	T50_.len = 0; T50_.p = NIM_NIL;
	{
		if (!!(((*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)1) || (*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)4) || (*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)6) || (*(*(*(*colonenv__1).m0).g).config).selectedGC == ((tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg)5)))) goto LA53_;
		isVolatile_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3704;
	}
	goto LA51_;
LA53_: ;
	{
		isVolatile_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3705;
	}
LA51_: ;
	res_1 = rawNewString(((NI)80));
	prepareAdd((&res_1), 20);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3707);
	cgFormatValue__cgen_u163((&res_1), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 21);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3709);
	cgFormatValue__cgen_u163((&res_1), (*(*(*colonenv__1).m0).g).otherModsInit);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 3);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3710);
	cgFormatValue__cgen_u163((&res_1), posixCmdLine_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 19);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3712);
	cgFormatValue__cgen_u163((&res_1), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 20);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3714);
	cgFormatValue__cgen_u163((&res_1), isVolatile_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 41);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3716);
	cgFormatValue__cgen_u163((&res_1), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 14);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3718);
	cgFormatValue__cgen_u163((&res_1), (*(*(*colonenv__1).m0).g).mainDatInit);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 19);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3720);
	cgFormatValue__cgen_u163((&res_1), (*(*(*colonenv__1).m0).g).mainDatInit);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 1);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3721);
	cgFormatValue__cgen_u163((&res_1), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&res_1), 26);
appendString((&res_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3723);
	prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_1.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_1);
	{
		NIM_BOOL T58_;
		tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A T60_;
		T58_ = (NIM_BOOL)0;
		T58_ = ((*(*(*(*colonenv__1).m0).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)2));
		if (!(T58_)) goto LA59_;
		T60_ = 0;
		T58_ = !((((*(*(*(*colonenv__1).m0).g).config).globalOptions & 640) == T60_));
LA59_: ;
		if (!T58_) goto LA61_;
		{
			NimStringV2 res_3;
			if (!(((*(*(*(*colonenv__1).m0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9)))&63U)))!=0)) goto LA65_;
			res_3.len = 0; res_3.p = NIM_NIL;
			res_3 = rawNewString(((NI)80));
			prepareAdd((&res_3), 28);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3725);
			cgFormatValue__cgen_u163((&res_3), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 22);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3727);
			cgFormatValue__cgen_u163((&res_3), (*(*(*colonenv__1).m0).g).mainModInit);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 17);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3729);
			cgFormatValue__cgen_u163((&res_3), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 21);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3731);
			cgFormatValue__cgen_u163((&res_3), isVolatile_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 32);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3733);
			cgFormatValue__cgen_u163((&res_3), preMainCode_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 9);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3735);
			cgFormatValue__cgen_u163((&res_3), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 14);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3737);
			cgFormatValue__cgen_u163((&res_3), initStackBottomCall_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 19);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3738);
			cgFormatValue__cgen_u163((&res_3), preMainCode_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_3), initStackBottomCall_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 1);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3739);
			cgFormatValue__cgen_u163((&res_3), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_3), 26);
appendString((&res_3), TM__MQdRN7fpbG7rPm4JpVVAhA_3741);
			prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_3.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_3);
			eqdestroy___system_u2691(res_3);
		}
		goto LA63_;
LA65_: ;
		{
			NimStringV2 res_4;
			res_4.len = 0; res_4.p = NIM_NIL;
			res_4 = rawNewString(((NI)80));
			prepareAdd((&res_4), 28);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3742);
			cgFormatValue__cgen_u163((&res_4), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 22);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3743);
			cgFormatValue__cgen_u163((&res_4), (*(*(*colonenv__1).m0).g).mainModInit);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 30);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3745);
			cgFormatValue__cgen_u163((&res_4), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 21);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3746);
			cgFormatValue__cgen_u163((&res_4), isVolatile_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 32);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3747);
			cgFormatValue__cgen_u163((&res_4), preMainCode_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 9);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3748);
			cgFormatValue__cgen_u163((&res_4), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 14);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3749);
			cgFormatValue__cgen_u163((&res_4), initStackBottomCall_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 19);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3750);
			cgFormatValue__cgen_u163((&res_4), preMainCode_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			cgFormatValue__cgen_u163((&res_4), initStackBottomCall_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 1);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3751);
			cgFormatValue__cgen_u163((&res_4), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_4), 26);
appendString((&res_4), TM__MQdRN7fpbG7rPm4JpVVAhA_3752);
			prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_4.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_4);
			eqdestroy___system_u2691(res_4);
		}
LA63_: ;
	}
	goto LA56_;
LA61_: ;
	{
		NimStringV2 res_5;
		if (!((*(*(*(*colonenv__1).m0).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)26))) goto LA69_;
		res_5.len = 0; res_5.p = NIM_NIL;
		res_5 = rawNewString(((NI)80));
		prepareAdd((&res_5), 121);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3754);
		cgFormatValue__cgen_u163((&res_5), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 22);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3755);
		cgFormatValue__cgen_u163((&res_5), (*(*(*colonenv__1).m0).g).mainModInit);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 17);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3756);
		cgFormatValue__cgen_u163((&res_5), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 21);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3757);
		cgFormatValue__cgen_u163((&res_5), isVolatile_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 32);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3758);
		cgFormatValue__cgen_u163((&res_5), preMainCode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 9);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3759);
		cgFormatValue__cgen_u163((&res_5), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 14);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3760);
		cgFormatValue__cgen_u163((&res_5), initStackBottomCall_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 19);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3761);
		cgFormatValue__cgen_u163((&res_5), preMainCode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_5), initStackBottomCall_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 1);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3762);
		cgFormatValue__cgen_u163((&res_5), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_5), 26);
appendString((&res_5), TM__MQdRN7fpbG7rPm4JpVVAhA_3763);
		prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_5.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_5);
		eqdestroy___system_u2691(res_5);
	}
	goto LA56_;
LA69_: ;
	{
		NimStringV2 res_6;
		if (!(((*(*(*(*colonenv__1).m0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)7)))&63U)))!=0)) goto LA72_;
		res_6.len = 0; res_6.p = NIM_NIL;
		res_6 = rawNewString(((NI)80));
		prepareAdd((&res_6), 28);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3764);
		cgFormatValue__cgen_u163((&res_6), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 22);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3765);
		cgFormatValue__cgen_u163((&res_6), (*(*(*colonenv__1).m0).g).mainModInit);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 30);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3766);
		cgFormatValue__cgen_u163((&res_6), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 21);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3767);
		cgFormatValue__cgen_u163((&res_6), isVolatile_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 32);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3768);
		cgFormatValue__cgen_u163((&res_6), preMainCode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 9);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3769);
		cgFormatValue__cgen_u163((&res_6), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 14);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3770);
		cgFormatValue__cgen_u163((&res_6), initStackBottomCall_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 19);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3771);
		cgFormatValue__cgen_u163((&res_6), preMainCode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_6), initStackBottomCall_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 1);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3772);
		cgFormatValue__cgen_u163((&res_6), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_6), 26);
appendString((&res_6), TM__MQdRN7fpbG7rPm4JpVVAhA_3773);
		prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_6.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_6);
		eqdestroy___system_u2691(res_6);
	}
	goto LA56_;
LA72_: ;
	{
		NimStringV2 res_7;
		res_7.len = 0; res_7.p = NIM_NIL;
		res_7 = rawNewString(((NI)80));
		prepareAdd((&res_7), 28);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3774);
		cgFormatValue__cgen_u163((&res_7), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 22);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3775);
		cgFormatValue__cgen_u163((&res_7), (*(*(*colonenv__1).m0).g).mainModInit);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 17);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3776);
		cgFormatValue__cgen_u163((&res_7), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 21);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3777);
		cgFormatValue__cgen_u163((&res_7), isVolatile_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 32);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3778);
		cgFormatValue__cgen_u163((&res_7), preMainCode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 9);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3779);
		cgFormatValue__cgen_u163((&res_7), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 14);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3780);
		cgFormatValue__cgen_u163((&res_7), initStackBottomCall_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 19);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3781);
		cgFormatValue__cgen_u163((&res_7), preMainCode_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		cgFormatValue__cgen_u163((&res_7), initStackBottomCall_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 1);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3782);
		cgFormatValue__cgen_u163((&res_7), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&res_7), 26);
appendString((&res_7), TM__MQdRN7fpbG7rPm4JpVVAhA_3783);
		prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_7.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_7);
		eqdestroy___system_u2691(res_7);
	}
LA56_: ;
	{
		if (!!((((*(*(*(*colonenv__1).m0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)23)))&63U)))!=0))) goto LA77_;
		{
			NimStringV2 colontmpD__8;
			NimStringV2 T83_;
			if (!(((NI)0) < (*(*(*(*colonenv__1).m0).g).config).cppCustomNamespace.len)) goto LA81_;
			colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
			closeNamespaceNim__cgen_u28091((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T83_.len = 0; T83_.p = NIM_NIL;
			T83_ = rawNewString((*(*(*(*colonenv__1).m0).g).config).cppCustomNamespace.len + 18);
appendString((&T83_), TM__MQdRN7fpbG7rPm4JpVVAhA_3786);
appendString((&T83_), (*(*(*(*colonenv__1).m0).g).config).cppCustomNamespace);
appendString((&T83_), TM__MQdRN7fpbG7rPm4JpVVAhA_3787);
			colontmpD__8 = T83_;
			prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), colontmpD__8.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), colontmpD__8);
			eqdestroy___system_u2691(colontmpD__8);
		}
LA81_: ;
		{
			NIM_BOOL T86_;
			tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A T88_;
			T86_ = (NIM_BOOL)0;
			T86_ = ((*(*(*(*colonenv__1).m0).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)2));
			if (!(T86_)) goto LA87_;
			T88_ = 0;
			T86_ = !((((*(*(*(*colonenv__1).m0).g).config).globalOptions & 640) == T88_));
LA87_: ;
			if (!T86_) goto LA89_;
			{
				NimStringV2 res_8;
				NimStringV2 colontmpD__9;
				NimStringV2 colontmpD__10;
				NimStringV2 T95_;
				if (!(((*(*(*(*colonenv__1).m0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9)))&63U)))!=0)) goto LA93_;
				res_8.len = 0; res_8.p = NIM_NIL;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
				res_8 = rawNewString(((NI)80));
				prepareAdd((&res_8), 157);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3789);
				cgFormatValue__cgen_u163((&res_8), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&res_8), 19);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3791);
				T95_.len = 0; T95_.p = NIM_NIL;
				{
					NIM_BOOL T98_;
					T98_ = (NIM_BOOL)0;
					T98_ = hcrOn__cgen_u49((*colonenv__1).m0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					if (!T98_) goto LA99_;
					colontmpD__9 = TM__MQdRN7fpbG7rPm4JpVVAhA_3792;
					T95_ = colontmpD__9;
				}
				goto LA96_;
LA99_: ;
				{
					colontmpD__10 = TM__MQdRN7fpbG7rPm4JpVVAhA_3793;
					T95_ = colontmpD__10;
				}
LA96_: ;
				cgFormatValue__cgen_u163((&res_8), T95_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&res_8), 23);
appendString((&res_8), TM__MQdRN7fpbG7rPm4JpVVAhA_3795);
				prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_8.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_8);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(res_8);
			}
			goto LA91_;
LA93_: ;
			{
				NimStringV2 res_9;
				res_9.len = 0; res_9.p = NIM_NIL;
				res_9 = rawNewString(((NI)80));
				prepareAdd((&res_9), 141);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3797);
				cgFormatValue__cgen_u163((&res_9), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				prepareAdd((&res_9), 28);
appendString((&res_9), TM__MQdRN7fpbG7rPm4JpVVAhA_3799);
				prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_9.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_9);
				eqdestroy___system_u2691(res_9);
			}
LA91_: ;
		}
		goto LA84_;
LA89_: ;
		{
			NimStringV2 res_10;
			if (!((*(*(*(*colonenv__1).m0).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)26))) goto LA104_;
			res_10.len = 0; res_10.p = NIM_NIL;
			res_10 = rawNewString(((NI)80));
			prepareAdd((&res_10), 185);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3801);
			cgFormatValue__cgen_u163((&res_10), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_10), 83);
appendString((&res_10), TM__MQdRN7fpbG7rPm4JpVVAhA_3803);
			prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_10.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_10);
			eqdestroy___system_u2691(res_10);
		}
		goto LA84_;
LA104_: ;
		{
			NimStringV2 res_11;
			if (!(((*(*(*(*colonenv__1).m0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)7)))&63U)))!=0)) goto LA107_;
			res_11.len = 0; res_11.p = NIM_NIL;
			res_11 = rawNewString(((NI)80));
			prepareAdd((&res_11), 55);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3805);
			cgFormatValue__cgen_u163((&res_11), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_11), 14);
appendString((&res_11), TM__MQdRN7fpbG7rPm4JpVVAhA_3807);
			prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_11.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_11);
			eqdestroy___system_u2691(res_11);
		}
		goto LA84_;
LA107_: ;
		{
			NimStringV2 res_12;
			if (!((*(*(*(*colonenv__1).m0).g).config).target.targetOS == ((tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw)29))) goto LA110_;
			res_12.len = 0; res_12.p = NIM_NIL;
			res_12 = rawNewString(((NI)80));
			prepareAdd((&res_12), 18);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3809);
			cgFormatValue__cgen_u163((&res_12), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_12), 25);
appendString((&res_12), TM__MQdRN7fpbG7rPm4JpVVAhA_3811);
			prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_12.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_12);
			eqdestroy___system_u2691(res_12);
		}
		goto LA84_;
LA110_: ;
		{
			NimStringV2 res_13;
			NimStringV2 colontmpD__11;
			NimStringV2 colontmpD__12;
			NimStringV2 T113_;
			res_13.len = 0; res_13.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			res_13 = rawNewString(((NI)80));
			prepareAdd((&res_13), 95);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3813);
			cgFormatValue__cgen_u163((&res_13), (*(*(*(*colonenv__1).m0).g).config).nimMainPrefix);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_13), 19);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3814);
			T113_.len = 0; T113_.p = NIM_NIL;
			{
				NIM_BOOL T116_;
				T116_ = (NIM_BOOL)0;
				T116_ = hcrOn__cgen_u49((*colonenv__1).m0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T116_) goto LA117_;
				colontmpD__11 = TM__MQdRN7fpbG7rPm4JpVVAhA_3815;
				T113_ = colontmpD__11;
			}
			goto LA114_;
LA117_: ;
			{
				colontmpD__12 = TM__MQdRN7fpbG7rPm4JpVVAhA_3816;
				T113_ = colontmpD__12;
			}
LA114_: ;
			cgFormatValue__cgen_u163((&res_13), T113_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&res_13), 23);
appendString((&res_13), TM__MQdRN7fpbG7rPm4JpVVAhA_3817);
			prepareAdd((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_13.len + 0);
appendString((&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), res_13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(res_13);
		}
LA84_: ;
		{
			NimStringV2 T124_;
			if (!(((NI)0) < (*(*(*(*colonenv__1).m0).g).config).cppCustomNamespace.len)) goto LA122_;
			T124_.len = 0; T124_.p = NIM_NIL;
			T124_ = (*(*(*(*colonenv__1).m0).g).config).cppCustomNamespace;
			openNamespaceNim__cgen_u28088(T124_, (&(*(*colonenv__1).m0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA122_: ;
	}
LA77_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(initStackBottomCall_1);
		eqdestroy___system_u2691(posixCmdLine_1);
		eqdestroy___system_u2691(preMainCode_1);
		eqdestroy___cgen_u34892(colonenv__1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateThreadVarsSize__cgen_u13832)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 externc_1;
		NimStringV2 colontmpD_;
		NimStringV2 T5_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T13_;
		if (!!(((*(*m_p0).g).nimtv.len == 0))) goto LA3_;
		externc_1.len = 0; externc_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T5_.len = 0; T5_.p = NIM_NIL;
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = ((*(*(*m_p0).g).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
			if (T8_) goto LA9_;
			T8_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA9_: ;
			if (!T8_) goto LA10_;
			externc_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3822;
		}
		goto LA6_;
LA10_: ;
		{
			externc_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3823;
		}
LA6_: ;
		T13_[0] = externc_1;
		colontmpD_ = percent___cgen_u13843(T13_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)10))- 0]), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, headerTop__cgen_u29375)(void) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = percent___cgen_u29377(TM__MQdRN7fpbG7rPm4JpVVAhA_3824, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getCopyright__cgen_u29382)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = headerTop__cgen_u29375();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T6_;
		if (!!((((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)4)))&63U)))!=0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_[0] = OS__platform_u534[((*conf_p0).target.targetOS)- 1].Field0;
		T6_[1] = CPU__platform_u740[((*conf_p0).target.targetCPU)- 1].Field0;
		T6_[2] = CC__extccomp_u624[((*conf_p0).cCompiler)- 1].Field0;
		colontmpD_ = getCompileCFileCmd__extccomp_u1228(conf_p0, cfile_p1, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_[3] = colontmpD_;
		colontmpD__2 = percent___cgen_u29390(T6_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&result), colontmpD__2.len + 0);
appendString((&result), colontmpD__2);
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addNimDefines__cgen_u29367)(NimStringV2* result_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyArray__YgExxhfgKcesA5EOUj1MOA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = rope__ropes_u15(((NI64) (CPU__platform_u740[((*conf_p1).target.targetCPU)- 1].Field1)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_[0] = colontmpD_;
	colontmpD__2 = percent___cgen_u29370(T1_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&(*result_p0)), colontmpD__2.len + 0);
appendString((&(*result_p0)), colontmpD__2);
	{
		if (!(((NI)0) < (*conf_p1).cppCustomNamespace.len)) goto LA4_;
		prepareAdd((&(*result_p0)), 26);
appendString((&(*result_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_3829);
		prepareAdd((&(*result_p0)), (*conf_p1).cppCustomNamespace.len + 0);
appendString((&(*result_p0)), (*conf_p1).cppCustomNamespace);
		prepareAdd((&(*result_p0)), 1);
appendString((&(*result_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_3830);
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = isDefined__options_u959(conf_p1, TM__MQdRN7fpbG7rPm4JpVVAhA_3832);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T8_) goto LA9_;
		prepareAdd((&(*result_p0)), 34);
appendString((&(*result_p0)), TM__MQdRN7fpbG7rPm4JpVVAhA_3834);
	}
LA9_: ;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getFileHeader__cgen_u29395)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = getCopyright__cgen_u29382(conf_p0, cfile_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = hcrOn__options_u629(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		prepareAdd((&result), 31);
appendString((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_3827);
	}
LA4_: ;
	addNimDefines__cgen_u29367((&result), conf_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, generateThreadLocalStorage__cgen_u13813)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NimStringV2 colontmpD_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T17_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*(*m_p0).g).nimtv.len == 0));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = (((*m_p0).flags &((NU8)1<<((NU)((((tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g)1)))&7U)))!=0);
		if (T5_) goto LA6_;
		T5_ = (((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0);
LA6_: ;
		T3_ = T5_;
LA4_: ;
		if (!T3_) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** t_1;
			NI i_1;
			NI L_1;
			NI T11_;
			t_1 = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
			i_1 = ((NI)0);
			T11_ = (*(*m_p0).g).nimtvDeps.len;
			L_1 = T11_;
			{
				while (1) {
					NimStringV2 colontmpD__2;
					if (!(i_1 < L_1)) goto LA13;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					t_1 = &(*(*m_p0).g).nimtvDeps.p->data[i_1];
					colontmpD__2 = getTypeDesc__cgen_u8738(m_p0, (*t_1), ((tyEnum_TypeDescKind__iVCpxW7bx8Tst6W09ary9b5Q)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					(void)(colontmpD__2);
					i_1 += ((NI)1);
					{
						LA14_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
				} LA13: ;
			}
		}
		finishTypeDescriptions__cgen_u8787(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T17_[0] = (*(*m_p0).g).nimtv;
		colontmpD_ = percent___cgen_u13827(T17_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)4))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)4))- 0]), colontmpD_);
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, generateHeaders__cgen_u28062)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 nimbase_1;
	NimStringV2 colontmpD_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimbase_1.len = 0; nimbase_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	eqcopy___system_u2694((&nimbase_1), (*(*(*m_p0).g).config).nimbasePattern);
	{
		if (!(nimbase_1.len == 0)) goto LA3_;
		eqsink___system_u2700((&nimbase_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3836);
	}
LA3_: ;
	T5_[0] = nimbase_1;
	colontmpD_ = percent___cgen_u28065(T5_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), colontmpD_.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), colontmpD_);
	{
		NimStringV2* it_1;
		NI i_1;
		NI L_1;
		NI T7_;
		it_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		T7_ = (*m_p0).headerFiles.len;
		L_1 = T7_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA9;
				it_1 = (&(*m_p0).headerFiles.p->data[i_1]);
				{
					NimStringV2 colontmpD__2;
					NimStringV2 colontmpD__3;
					NimStringV2 T14_;
					if (!((NU8)((*it_1).p->data[((NI)0)]) == (NU8)(35))) goto LA12_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					T14_.len = 0; T14_.p = NIM_NIL;
					colontmpD__2 = nsuReplaceChar((*it_1), 96, 34);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T14_ = rawNewString(colontmpD__2.len + 1);
appendString((&T14_), colontmpD__2);
appendString((&T14_), TM__MQdRN7fpbG7rPm4JpVVAhA_3837);
					colontmpD__3 = T14_;
					prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), colontmpD__3.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), colontmpD__3);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
				}
				goto LA10_;
LA12_: ;
				{
					NimStringV2 colontmpD__4;
					tyArray__YgExxhfgKcesA5EOUj1MOA T18_;
					if (!!((((NU8)((*it_1).p->data[((NI)0)])) == ((NU8)(34)) || ((NU8)((*it_1).p->data[((NI)0)])) == ((NU8)(60))))) goto LA16_;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					T18_[0] = (*it_1);
					colontmpD__4 = percent___cgen_u28078(T18_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), colontmpD__4.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), colontmpD__4);
					eqdestroy___system_u2691(colontmpD__4);
				}
				goto LA10_;
LA16_: ;
				{
					NimStringV2 colontmpD__5;
					tyArray__YgExxhfgKcesA5EOUj1MOA T20_;
					colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
					T20_[0] = (*it_1);
					colontmpD__5 = percent___cgen_u28083(T20_, 1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), colontmpD__5.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), colontmpD__5);
					eqdestroy___system_u2691(colontmpD__5);
				}
LA10_: ;
				i_1 += ((NI)1);
			} LA9: ;
		}
	}
	prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), 170);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]), TM__MQdRN7fpbG7rPm4JpVVAhA_3839);
	eqdestroy___system_u2691(colontmpD_);
	eqdestroy___system_u2691(nimbase_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, postprocessCode__cgen_u30692)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2* r_p1) {
	NimStringV2 nimlnDirLastF_1;
	NimStringV2 res_1;
	NI f_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimlnDirLastF_1.len = 0; nimlnDirLastF_1.p = NIM_NIL;
	res_1.len = 0; res_1.p = NIM_NIL;
	f_1 = nsuFindChar((*r_p1), 1, ((NI)0), ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(f_1 == ((NI)-1))) goto LA4_;
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(nimlnDirLastF_1);
		goto BeforeRet_;
	}
LA4_: ;
	nimlnDirLastF_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3846;
	res_1 = substr__system_u8632((*r_p1), ((NI)0), (NI)(f_1 - ((NI)1)));
	{
		while (1) {
			tySequence__sM4lkSb7zS6F7OVMvW9cffQ dir_1;
			NimStringV2 colontmpD_;
			NI e_1;
			if (!!((f_1 == ((NI)-1)))) goto LA7;
			dir_1.len = 0; dir_1.p = NIM_NIL;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			e_1 = nsuFindChar((*r_p1), 23, ((NI)(f_1 + ((NI)1))), ((NI)-1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			colontmpD_ = substr__system_u8632((*r_p1), (NI)(f_1 + ((NI)1)), (NI)(e_1 - ((NI)1)));
			dir_1 = nsuSplitChar(colontmpD_, 31, ((NI)-1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			if (eqStrings(dir_1.p->data[((NI)0)], TM__MQdRN7fpbG7rPm4JpVVAhA_3847)) goto LA9_;
			goto LA10_;
			LA9_: ;
			{
				{
					NimStringV2 colontmpD__2;
					NimStringV2 T17_;
					if (!eqStrings(dir_1.p->data[((NI)2)], nimlnDirLastF_1)) goto LA15_;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					T17_.len = 0; T17_.p = NIM_NIL;
					T17_ = rawNewString(dir_1.p->data[((NI)1)].len + 9);
appendString((&T17_), TM__MQdRN7fpbG7rPm4JpVVAhA_3849);
appendString((&T17_), dir_1.p->data[((NI)1)]);
appendString((&T17_), TM__MQdRN7fpbG7rPm4JpVVAhA_3850);
					colontmpD__2 = T17_;
					prepareAdd((&res_1), colontmpD__2.len + 0);
appendString((&res_1), colontmpD__2);
					eqdestroy___system_u2691(colontmpD__2);
				}
				goto LA13_;
LA15_: ;
				{
					NimStringV2 colontmpD__3;
					NimStringV2 colontmpD__4;
					NimStringV2 T20_;
					NI T21_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					T20_.len = 0; T20_.p = NIM_NIL;
					T21_ = (NI)0;
					T21_ = nsuParseInt(dir_1.p->data[((NI)2)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					colontmpD__3 = quotedFilename__msgs_u1630(conf_p0, ((NI32) (T21_)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
					T20_ = rawNewString(dir_1.p->data[((NI)1)].len + colontmpD__3.len + 11);
appendString((&T20_), TM__MQdRN7fpbG7rPm4JpVVAhA_3852);
appendString((&T20_), dir_1.p->data[((NI)1)]);
appendString((&T20_), TM__MQdRN7fpbG7rPm4JpVVAhA_3853);
appendString((&T20_), colontmpD__3);
appendString((&T20_), TM__MQdRN7fpbG7rPm4JpVVAhA_3854);
					colontmpD__4 = T20_;
					prepareAdd((&res_1), colontmpD__4.len + 0);
appendString((&res_1), colontmpD__4);
					eqsink___system_u2700((&nimlnDirLastF_1), dir_1.p->data[((NI)2)]);
					eqwasMoved___system_u2688((&dir_1.p->data[((NI)2)]));
					{
						LA19_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__4);
						eqdestroy___system_u2691(colontmpD__3);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				}
LA13_: ;
			}
			goto LA11_;
			LA10_: ;
			{
				raiseAssert__stdZassertions_u15(TM__MQdRN7fpbG7rPm4JpVVAhA_3856);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			}
LA11_: ;
			f_1 = nsuFindChar((*r_p1), 1, ((NI)(e_1 + ((NI)1))), ((NI)-1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			{
				NimStringV2 colontmpD__5;
				if (!!((f_1 == ((NI)-1)))) goto LA27_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__5 = substr__system_u8632((*r_p1), (NI)(e_1 + ((NI)1)), (NI)(f_1 - ((NI)1)));
				prepareAdd((&res_1), colontmpD__5.len + 0);
appendString((&res_1), colontmpD__5);
				eqdestroy___system_u2691(colontmpD__5);
			}
			goto LA25_;
LA27_: ;
			{
				NimStringV2 colontmpD__6;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__6 = substr__system_u8645((*r_p1), (NI)(e_1 + ((NI)1)));
				prepareAdd((&res_1), colontmpD__6.len + 0);
appendString((&res_1), colontmpD__6);
				eqdestroy___system_u2691(colontmpD__6);
			}
LA25_: ;
			{
				LA8_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
				eqdestroy___system_u5506(dir_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA7: ;
	}
	eqsink___system_u2700((&(*r_p1)), res_1);
	eqwasMoved___system_u2688((&res_1));
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(res_1);
		eqdestroy___system_u2691(nimlnDirLastF_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, genModule__cgen_u30700)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p1) {
	NimStringV2 result;
	NIM_BOOL moduleIsEmpty_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	moduleIsEmpty_1 = NIM_TRUE;
	result = getFileHeader__cgen_u29395((*(*m_p0).g).config, cfile_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	generateThreadLocalStorage__cgen_u13813(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	generateHeaders__cgen_u28062(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&result), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0].len + 0);
appendString((&result), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0))- 0]);
	{
		if (!(((NI)0) < (*(*(*m_p0).g).config).cppCustomNamespace.len)) goto LA3_;
		openNamespaceNim__cgen_u28088((*(*(*m_p0).g).config).cppCustomNamespace, (&result));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(((NI)0) < (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)1))- 0].len)) goto LA7_;
		prepareAdd((&result), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)1))- 0].len + 0);
appendString((&result), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)1))- 0]);
	}
LA7_: ;
	{
		tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ i_1;
		NI res_1;
		i_1 = (tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0;
		res_1 = ((NI)2);
		{
			while (1) {
				if (!(res_1 <= ((NI)10))) goto LA11;
				i_1 = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ) (res_1));
				{
					if (!(((NI)0) < (*m_p0).s[(i_1)- 0].len)) goto LA14_;
					moduleIsEmpty_1 = NIM_FALSE;
					prepareAdd((&result), (*m_p0).s[(i_1)- 0].len + 0);
appendString((&result), (*m_p0).s[(i_1)- 0]);
				}
LA14_: ;
				res_1 += ((NI)1);
			} LA11: ;
		}
	}
	{
		if (!(((NI)0) < (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0].len)) goto LA18_;
		moduleIsEmpty_1 = NIM_FALSE;
		prepareAdd((&result), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0].len + 0);
appendString((&result), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]);
	}
LA18_: ;
	{
		NIM_BOOL T22_;
		T22_ = (NIM_BOOL)0;
		T22_ = (((NI)0) < (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)12))- 0].len);
		if (T22_) goto LA23_;
		T22_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA23_: ;
		if (!T22_) goto LA24_;
		moduleIsEmpty_1 = NIM_FALSE;
		prepareAdd((&result), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)12))- 0].len + 0);
appendString((&result), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)12))- 0]);
	}
LA24_: ;
	{
		if (!(((NI)0) < (*(*(*m_p0).g).config).cppCustomNamespace.len)) goto LA28_;
		closeNamespaceNim__cgen_u28091((&result));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA28_: ;
	{
		NimStringV2 srcFileDefs_1;
		NimStringV2 T39_;
		if (!(((*(*(*m_p0).g).config).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)12)))&31U)))!=0)) goto LA32_;
		srcFileDefs_1.len = 0; srcFileDefs_1.p = NIM_NIL;
		srcFileDefs_1 = TM__MQdRN7fpbG7rPm4JpVVAhA_3840;
		{
			NI fi_1;
			NI colontmp_;
			NI T35_;
			NI res_2;
			fi_1 = (NI)0;
			colontmp_ = (NI)0;
			T35_ = ((*(*(*m_p0).g).config).m.fileInfos.len-1);
			colontmp_ = T35_;
			res_2 = ((NI)0);
			{
				while (1) {
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					NimStringV2 colontmpD__3;
					NimStringV2 colontmpD__4;
					NimStringV2 T38_;
					if (!(res_2 <= colontmp_)) goto LA37;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					fi_1 = ((NI) (res_2));
					T38_.len = 0; T38_.p = NIM_NIL;
					colontmpD_ = dollar___systemZdollars_u9(fi_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					colontmpD__2 = toFullPath__msgs_u624((*(*m_p0).g).config, ((NI32) (fi_1)));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					colontmpD__3 = makeSingleLineCString__ccgutils_u103(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T38_ = rawNewString(colontmpD_.len + colontmpD__3.len + 13);
appendString((&T38_), TM__MQdRN7fpbG7rPm4JpVVAhA_3842);
appendString((&T38_), colontmpD_);
appendString((&T38_), TM__MQdRN7fpbG7rPm4JpVVAhA_3843);
appendString((&T38_), colontmpD__3);
appendString((&T38_), TM__MQdRN7fpbG7rPm4JpVVAhA_3844);
					colontmpD__4 = T38_;
					prepareAdd((&srcFileDefs_1), colontmpD__4.len + 0);
appendString((&srcFileDefs_1), colontmpD__4);
					res_2 += ((NI)1);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
				} LA37: ;
			}
		}
		T39_.len = 0; T39_.p = NIM_NIL;
		T39_ = rawNewString(srcFileDefs_1.len + result.len + 0);
appendString((&T39_), srcFileDefs_1);
appendString((&T39_), result);
		eqsink___system_u2700((&result), T39_);
		eqdestroy___system_u2691(srcFileDefs_1);
	}
LA32_: ;
	{
		if (!moduleIsEmpty_1) goto LA42_;
		eqsink___system_u2700((&result), TM__MQdRN7fpbG7rPm4JpVVAhA_3845);
	}
LA42_: ;
	postprocessCode__cgen_u30692((*(*m_p0).g).config, (&result));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, shouldRecompile__cgen_u31152)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NimStringV2 code_p1, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* cfile_p2) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		if (!!((((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)1)))&63U)))!=0))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = moduleHasChanged__pipelineutils_u29((*(*m_p0).g).graph, (*m_p0).module);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T7_)) goto LA8_;
			result = NIM_FALSE;
		}
		goto LA5_;
LA8_: ;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = equalsFile__ropes_u230(code_p1, (*cfile_p2).cname);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T11_)) goto LA12_;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = writeRope__ropes_u27(code_p1, (*cfile_p2).cname);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!!(T16_)) goto LA17_;
				liMessage__msgs_u1227((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), (*cfile_p2).cname, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), TM__MQdRN7fpbG7rPm4JpVVAhA_3857, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA17_: ;
			result = NIM_TRUE;
		}
		goto LA5_;
LA12_: ;
		{
			NIM_BOOL T20_;
			T20_ = (NIM_BOOL)0;
			T20_ = nosfileExists((*cfile_p2).obj);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T20_)) goto LA21_;
			T20_ = nosfileNewer((*cfile_p2).obj, (*cfile_p2).cname);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA21_: ;
			if (!T20_) goto LA22_;
			result = NIM_FALSE;
		}
		goto LA5_;
LA22_: ;
		{
			result = NIM_TRUE;
		}
LA5_: ;
	}
	goto LA1_;
LA3_: ;
	{
		{
			NIM_BOOL T28_;
			T28_ = (NIM_BOOL)0;
			T28_ = writeRope__ropes_u27(code_p1, (*cfile_p2).cname);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T28_)) goto LA29_;
			liMessage__msgs_u1227((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), (*cfile_p2).cname, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), TM__MQdRN7fpbG7rPm4JpVVAhA_3858, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA29_: ;
		result = NIM_TRUE;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, writeModule__cgen_u31161)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0, NIM_BOOL pending_p1) {
	NimStringV2 cfile_1;
	tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg cf_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 code_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	cfile_1.len = 0; cfile_1.p = NIM_NIL;
	nimZeroMem((void*)(&cf_1), sizeof(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg));
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	code_1.len = 0; code_1.p = NIM_NIL;
	cfile_1 = getCFile__cgen_u144(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = moduleHasChanged__pipelineutils_u29((*(*m_p0).g).graph, (*m_p0).module);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		genInitCode__cgen_u30397(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		finishTypeDescriptions__cgen_u8787(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(((*(*m_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA9_;
			genMainProc__cgen_u29446(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			prepareAdd((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), (*(*m_p0).g).mainModProcs.len + 0);
appendString((&(*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)6))- 0]), (*(*m_p0).g).mainModProcs);
			generateThreadVarsSize__cgen_u13832(m_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA9_: ;
	}
LA5_: ;
	nimZeroMem((void*)(&cf_1), sizeof(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg));
	colontmpD_ = eqdup___system_u2697((*(*(*m_p0).module).name).s);
	cf_1.nimname = colontmpD_;
	colontmpD__2 = eqdup___system_u2697(cfile_1);
	cf_1.cname = colontmpD__2;
	colontmpD__3 = toObjFile__extccomp_u934((*(*m_p0).g).config, cfile_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cf_1.obj = completeCfilePath__extccomp_u929((*(*m_p0).g).config, colontmpD__3, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	cf_1.flags = 0;
	code_1 = genModule__cgen_u30700(m_p0, (&cf_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = !((code_1.len == 0));
		if (T13_) goto LA14_;
		T13_ = !(((*(*(*m_p0).g).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)));
LA14_: ;
		if (!T13_) goto LA15_;
		{
			NIM_BOOL T19_;
			T19_ = (NIM_BOOL)0;
			T19_ = shouldRecompile__cgen_u31152(m_p0, code_1, (&cf_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T19_)) goto LA20_;
			cf_1.flags = 1;
		}
LA20_: ;
		addFileToCompile__extccomp_u938((*(*m_p0).g).config, (&cf_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA15_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(code_1);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___options_u1619((&cf_1));
		eqdestroy___system_u2691(cfile_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeHeader__cgen_u31027)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	NimStringV2 result_1;
	NimStringV2 guard_1;
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T3_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T17_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T22_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result_1.len = 0; result_1.p = NIM_NIL;
	guard_1.len = 0; guard_1.p = NIM_NIL;
	nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	result_1 = headerTop__cgen_u29375();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = splitFile__pathutils_u39((*m_p0).filename);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = colontmpD_.Field1;
	guard_1 = percent___cgen_u31030(T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_[0] = guard_1;
	colontmpD__2 = percent___cgen_u31036(T3_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result_1), colontmpD__2.len + 0);
appendString((&result_1), colontmpD__2);
	addNimDefines__cgen_u29367((&result_1), (*(*m_p0).g).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	generateHeaders__cgen_u28062(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	generateThreadLocalStorage__cgen_u13813(m_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ i_1;
		NI res_1;
		i_1 = (tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= ((NI)10))) goto LA6;
				i_1 = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ) (res_1));
				prepareAdd((&result_1), (*m_p0).s[(i_1)- 0].len + 0);
appendString((&result_1), (*m_p0).s[(i_1)- 0]);
				{
					NIM_BOOL T9_;
					T9_ = (NIM_BOOL)0;
					T9_ = (((NI)0) < (*(*(*m_p0).g).config).cppCustomNamespace.len);
					if (!(T9_)) goto LA10_;
					T9_ = (i_1 == ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0));
LA10_: ;
					if (!T9_) goto LA11_;
					openNamespaceNim__cgen_u28088((*(*(*m_p0).g).config).cppCustomNamespace, (&result_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA11_: ;
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	prepareAdd((&result_1), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0].len + 0);
appendString((&result_1), (*m_p0).s[(((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)11))- 0]);
	{
		if (!(((*(*(*m_p0).g).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)7)))&63U)))!=0)) goto LA15_;
		prepareAdd((&result_1), 13);
appendString((&result_1), TM__MQdRN7fpbG7rPm4JpVVAhA_3859);
	}
LA15_: ;
	T17_[0] = (*(*(*m_p0).g).config).nimMainPrefix;
	colontmpD__3 = percent___cgen_u31055(T17_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result_1), colontmpD__3.len + 0);
appendString((&result_1), colontmpD__3);
	{
		if (!(((NI)0) < (*(*(*m_p0).g).config).cppCustomNamespace.len)) goto LA20_;
		closeNamespaceNim__cgen_u28091((&result_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA20_: ;
	T22_[0] = guard_1;
	colontmpD__4 = percent___cgen_u31060(T22_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result_1), colontmpD__4.len + 0);
appendString((&result_1), colontmpD__4);
	{
		NIM_BOOL T25_;
		T25_ = (NIM_BOOL)0;
		T25_ = writeRope__ropes_u27(result_1, (*m_p0).filename);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!!(T25_)) goto LA26_;
		liMessage__msgs_u1227((*(*m_p0).g).config, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4), (*m_p0).filename, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), TM__MQdRN7fpbG7rPm4JpVVAhA_3860, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA26_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___pathutils_u73(colontmpD_);
		eqdestroy___system_u2691(guard_1);
		eqdestroy___system_u2691(result_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, cgenWriteModules__cgen_u31342)(RootObj* backend_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1) {
	tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_1;
	RootObj* colontmpD_;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	g_1 = NIM_NIL;
	colontmpD_ = eqdup___ast_u4951(backend_p0, NIM_TRUE);
	g_1 = (*((tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g**) (&(colontmpD_))));
	eqcopy___options_u2138(&(*g_1).config, config_p1);
	genForwardedProcs__cgen_u31328(g_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_1;
		m_1 = NIM_NIL;
		{
			tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA** m_2;
			NI i_1;
			NI L_1;
			NI T5_;
			m_2 = (tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA**)0;
			i_1 = ((NI)0);
			T5_ = (*g_1).modulesClosed.len;
			L_1 = T5_;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA7;
					m_2 = &(*g_1).modulesClosed.p->data[i_1];
					eqcopy___cgendata_u721(&m_1, (*m_2), NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					writeModule__cgen_u31161(m_1, NIM_TRUE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					i_1 += ((NI)1);
				} LA7: ;
			}
		}
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___cgendata_u718(m_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	writeMapping__extccomp_u3284(config_p1, (*g_1).mapping);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!(((*g_1).generatedHeader == ((tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA*) NIM_NIL)))) goto LA12_;
		writeHeader__cgen_u31027((*g_1).generatedHeader);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA12_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___cgendata_u2191(g_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ, whichInitProcs__cgen_u29772)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* m_p0) {
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = 0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NimStringV2* T6_;
		NimStringV2* T8_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T4_ = hcrOn__cgen_u49(m_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (T4_) goto LA5_;
		T6_ = (NimStringV2*)0;
		T6_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (((NI)0) < (*T6_).len);
LA5_: ;
		T3_ = T4_;
		if (T3_) goto LA7_;
		T8_ = (NimStringV2*)0;
		T8_ = s__cgendata_u228((*m_p0).preInitProc, ((tyEnum_TCProcSection__UGthXxElLFOAJhjKRse9c2g)2));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = (((NI)0) < (*T8_).len);
LA7_: ;
		if (!T3_) goto LA9_;
		result |= ((NU8)1)<<(((((tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ)1))) & 7);
	}
LA9_: ;
	{
		tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ i_1;
		NI res_1;
		i_1 = (tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ)0;
		res_1 = ((NI)13);
		{
			while (1) {
				if (!(res_1 <= ((NI)15))) goto LA13;
				i_1 = ((tyEnum_TCFileSection__xzMTNu0cusxUWYE59ajMPPQ) (res_1));
				{
					if (!!(((*m_p0).s[(i_1)- 0].len == ((NI)0)))) goto LA16_;
					result |= ((NU8)1)<<(((((tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ)0))) & 7);
					goto LA11;
				}
LA16_: ;
				res_1 += ((NI)1);
			} LA13: ;
		}
	} LA11: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSomeNameForModule__cgen_u29399)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = mangleModuleName__modulepaths_u40(conf_p0, filename_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = mangle__mangleutils_u4(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, registerInitProcs__cgen_u29730)(tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ flags_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 datInit_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T6_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T7_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T8_;
		if (!((flags_p2 &((NU8)1<<((NU)((((tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ)0)))&7U)))!=0)) goto LA3_;
		datInit_1.len = 0; datInit_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T6_.len = 0; T6_.p = NIM_NIL;
		colontmpD_ = toFullPath__msgs_u624((*g_p0).config, (*m_p1).info.fileIndex);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD__2 = getSomeNameForModule__cgen_u29399((*g_p0).config, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_ = rawNewString(colontmpD__2.len + 10);
appendString((&T6_), colontmpD__2);
appendString((&T6_), TM__MQdRN7fpbG7rPm4JpVVAhA_3861);
		datInit_1 = T6_;
		T7_[0] = datInit_1;
		colontmpD__3 = percent___cgen_u29740(T7_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&(*g_p0).mainModProcs), colontmpD__3.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__3);
		T8_[0] = datInit_1;
		colontmpD__4 = percent___cgen_u29745(T8_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		prepareAdd((&(*g_p0).mainDatInit), colontmpD__4.len + 0);
appendString((&(*g_p0).mainDatInit), colontmpD__4);
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(datInit_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		NimStringV2 init_1;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 initCall_1;
		NimStringV2 T16_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T17_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T18_;
		if (!((flags_p2 &((NU8)1<<((NU)((((tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ)1)))&7U)))!=0)) goto LA13_;
		init_1.len = 0; init_1.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		initCall_1.len = 0; initCall_1.p = NIM_NIL;
		T16_.len = 0; T16_.p = NIM_NIL;
		colontmpD__5 = toFullPath__msgs_u624((*g_p0).config, (*m_p1).info.fileIndex);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		colontmpD__6 = getSomeNameForModule__cgen_u29399((*g_p0).config, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T16_ = rawNewString(colontmpD__6.len + 7);
appendString((&T16_), colontmpD__6);
appendString((&T16_), TM__MQdRN7fpbG7rPm4JpVVAhA_3862);
		init_1 = T16_;
		T17_[0] = init_1;
		colontmpD__7 = percent___cgen_u29740(T17_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		prepareAdd((&(*g_p0).mainModProcs), colontmpD__7.len + 0);
appendString((&(*g_p0).mainModProcs), colontmpD__7);
		T18_[0] = init_1;
		initCall_1 = percent___cgen_u29745(T18_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		{
			if (!(((*m_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0)) goto LA21_;
			prepareAdd((&(*g_p0).mainModInit), initCall_1.len + 0);
appendString((&(*g_p0).mainModInit), initCall_1);
		}
		goto LA19_;
LA21_: ;
		{
			if (!(((*m_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15)))&63U)))!=0)) goto LA24_;
			prepareAdd((&(*g_p0).mainDatInit), initCall_1.len + 0);
appendString((&(*g_p0).mainDatInit), initCall_1);
		}
		goto LA19_;
LA24_: ;
		{
			prepareAdd((&(*g_p0).otherModsInit), initCall_1.len + 0);
appendString((&(*g_p0).otherModsInit), initCall_1);
		}
LA19_: ;
		{
			LA15_:;
		}
		{
			eqdestroy___system_u2691(initCall_1);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(init_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA13_: ;
	}BeforeRet_: ;
}
