/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct RootObj RootObj;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw tySequence__hRbbzIynOoxrYjHTIKZ3Gw;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ;
typedef struct tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag;
typedef struct tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ;
typedef struct tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA;
typedef struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__Oubp8LPEu86EPyDuc56AXg tyTuple__Oubp8LPEu86EPyDuc56AXg;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw {
  NI len; tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content* p;
};
struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ {
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug {
	NI32 module;
	NI32 symId;
	NI32 typeId_0;
	NIM_BOOL sealed;
	tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ disambTable;
};
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tyEnum_PrefixMatch__ocee5pBJwvwPKYUp2SRA4g;
struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA {
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng section;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ qualifiedPath;
	NimStringV2* name;
	NimStringV2 filePath;
	NI line;
	NI column;
	NimStringV2 doc;
	NimStringV2 forth;
	NI quality;
	NIM_BOOL isGlobal;
	NIM_BOOL contextFits;
	tyEnum_PrefixMatch__ocee5pBJwvwPKYUp2SRA4g prefix;
	NU8 symkind;
	NI scope;
	NI localUsages;
	NI globalUsages;
	NI tokenLen;
	NI version;
	NU16 endLine;
	NI endCol;
	tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw* inlayHintInfo;
};
typedef tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* tyArray__s9a2jZbmN9cnqFaNnzUrYEjg[8192];
struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA {
	tyArray__s9a2jZbmN9cnqFaNnzUrYEjg buckets;
	NI wordCounter;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idAnon;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idDelegator;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* emptyIdent;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef NU tyArray__KznKlIbW0OmA9ckg0NfmHVQ[8];
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg concreteTypes;
	NI compilesId;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
typedef NU8 tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA;
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
typedef tyTuple__UV3llMMYFckfui8YMBuUZA tyArray__8dwr5YZa3jdi3OLJPUYHGQ[1];
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA {
	NI a;
	NI b;
};
typedef NU8 tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
typedef NimStringV2 tyArray__awn6UrBeChh9cVy9ccoluuYg[5];
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag {
	NI h;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
};
struct tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA {
	NI lastModule;
	NU32 lastLit;
	NI32 lastFile;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
};
struct tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ {
	tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA decoder;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw values;
	NI i;
	NI module;
};
struct tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ {
	NIM_BOOL fromRod;
	NI modIndex;
	tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti;
	tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ rodIt;
	NIM_BOOL importHidden;
};
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ {
	NI len;
	void* p;
};
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
typedef NimStringV2 tyArray__RFO5owyhZgSVTHBCk8ZhJA[64];
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tyTuple__Oubp8LPEu86EPyDuc56AXg {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field0;
	NI Field1;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content { NI cap; tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13532)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3696)(tySequence__9ahcSjIErJohSBBFLwuF56Q dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3074)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14425)(tySequence__WbW5Q8QVks0bQpUJSGmuVg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12789)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12466)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12255)(tySequence__R9c39btP6BwOBBPnbaNUtMQg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13172)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13005)(tySequence__vJcM7B74R2U5db9cxyXT9coA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3288)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2823)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u7400)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14113)(tySequence__T7nNEWoEbKBa0G5Htr45Xw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14008)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13327)(tySequence__kHjIdgrpmuSn9cUIIKpSiDg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12037)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11782)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___suggestsymdb_u1866)(tySequence__fz0REU1l0nYmKHXgMLRrIg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u274)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u16091)(tySequence__48JTohSgTy339bRxHzUD8KA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11545)(tySequence__kxu4GK0onha2t9bo86mdVAg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11373)(tySequence__fdmz6VkIf1ewwrssKYqRFg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u100)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u66)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u566)(tySequence__7lEisrXlQEzwtUKW5pzRCw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u5326)(tySequence__3vEEVfBECLN6NIRA3FIp5g dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13804)(tySequence__GYDW6wGgERshoSd16jJ3eQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13652)(tySequence__N589c2UsUgqqOITU2JfIuAQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u9130)(tySequence__9aSa87aKMiolq9a7z3kC0jTw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u4629)(tySequence__C2ivDnhTZ6IxAdui1rfuqw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1177)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1206)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3934)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13595)(tySequence__dtr79aXjHrgHuH79ac55I2aw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3311)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u1393)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13551)(tySequence__5reviU45axUMPQgL9aoENrg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13228)(tySequence__TfHJycarvNts8E4mVG4Mfg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u2138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg** dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___idents_u341)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA** dest_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, initModuleGraphFields__modulegraphs_u11203)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* result_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3109)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug** dest_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6347)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* dest_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg, initStrTable__ast_u6321)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6338)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZcollectionsZintsets_u236)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* src_p1);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_u37)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11364)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw* dest_p0, tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw, initTable__modulegraphs_u11217)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11355)(tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u13237)(tySequence__TfHJycarvNts8E4mVG4Mfg* dest_p0, tySequence__TfHJycarvNts8E4mVG4Mfg src_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u16100)(tySequence__48JTohSgTy339bRxHzUD8KA* dest_p0, tySequence__48JTohSgTy339bRxHzUD8KA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11536)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* dest_p0, tyObject_Table__AC9bec2JdoOuC3xQePGWgmA src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA, initTable__modulegraphs_u11433)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11527)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4857)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0, tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11628)(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ* dest_p0, tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ, initTable__modulegraphs_u11598)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11619)(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12028)(tyObject_Table__w2vCG1OPnHmNolvQVT168g* dest_p0, tyObject_Table__w2vCG1OPnHmNolvQVT168g src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__w2vCG1OPnHmNolvQVT168g, initTable__modulegraphs_u11649)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12019)(tyObject_Table__w2vCG1OPnHmNolvQVT168g dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u13336)(tySequence__kHjIdgrpmuSn9cUIIKpSiDg* dest_p0, tySequence__kHjIdgrpmuSn9cUIIKpSiDg src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNode__ast_u4069)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12246)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ* dest_p0, tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ, initTable__modulegraphs_u12093)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12237)(tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12457)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw* dest_p0, tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw, initTable__modulegraphs_u12310)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12448)(tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12780)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ* dest_p0, tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ, initTable__modulegraphs_u12520)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12771)(tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u12996)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw* dest_p0, tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw, initTable__modulegraphs_u12844)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12987)(tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u13163)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg* dest_p0, tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg, initTable__modulegraphs_u13060)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13154)(tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11106)(tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* dest_p0, tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, initOperators__modulegraphs_u11091)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, createMagic__modulegraphs_u10820)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NimStringV2 name_p1, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, createMagic__modulegraphs_u10814)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, NimStringV2 name_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___lineinfos_u557)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* dest_p0, tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A, initTable__lineinfos_u410)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u548)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZstrtabs_u536)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg** dest_p0, tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg*, nstnewStringTableWithTableConstr)(tyTuple__UV3llMMYFckfui8YMBuUZA* keyValuePairs_p0, NI keyValuePairs_p0Len_0, tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA mode_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZstrtabs_u525)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_u366)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
static N_INLINE(NI, dependsOn__modulegraphs_u14880)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKeyOrPut__modulegraphs_u14941)(tyObject_Table__AC9bec2JdoOuC3xQePGWgmA* t_p0, NI32 key_p1, NI32 val_p2);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u2997)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, moduleFromRodFile__icZic_u21165)(tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p2, NI32 fileIdx_p3, tySequence__48JTohSgTy339bRxHzUD8KA* cachedModules_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getPackage__packages_u8)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, NI32 fileIdx_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, strTableGet__astalgo_u2726)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_u2666)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* t_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u10899)(tySequence__TfHJycarvNts8E4mVG4Mfg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u12940)(tySequence__5reviU45axUMPQgL9aoENrg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u10952)(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* dest_p0, tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, uniqueModuleName__modulegraphs_u10825)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuStartsWith)(NimStringV2 s_p0, NimStringV2 prefix_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, relativeTo__pathutils_u196)(NimStringV2 fullPath_p0, NimStringV2 baseFilename_p1, NIM_CHAR sep_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToProjectPackage__packages_u81)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindStr)(NimStringV2 s_p0, NimStringV2 sub_p1, NI start_p2, NI last_p3);
static N_INLINE(NI, skipUntil__pureZparseutils_u931)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw until_p1, NI start_p2);
static N_INLINE(NI, skipUntil__pureZparseutils_u181)(NIM_CHAR* s_p0, NI s_p0Len_0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw until_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1286)(NimStringV2 s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringV2 s_p0, NimStringV2 suffix_p1);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, initStrTables__modulegraphs_u2990)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFilenameOption__msgs_u676)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ opt_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuRepeatStr)(NimStringV2 s_p0, NI n_p1);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, percent___modulegraphs_u17932)(NimStringV2* args_p1, NI args_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u2135)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
static N_INLINE(void, nimIncRef)(void* p_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u3024)(tySequence__dtr79aXjHrgHuH79ac55I2aw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, initEncoder__icZic_u2995)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* moduleSym_p2, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p3, tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ pc_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, loadTypeFromId__icZic_u21257)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p2, NI module_p3, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig id_p4);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getAttachedOp__modulegraphs_u4987)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__modulegraphs_u5048)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, resolveAttachedOp__modulegraphs_u3583)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, loadSymFromId__icZic_u21336)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p2, NI module_p3, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig id_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*, X5BX5D___modulegraphs_u5532)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(void, setAttachedOp__modulegraphs_u5617)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* value_p4);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___modulegraphs_u5663)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA val_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u672)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u694)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initRodIter__icZic_u21451)(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ* it_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p2, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p3, NI32 module_p4, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p5, NIM_BOOL importHidden_p6);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initIdentIter__astalgo_u2768)(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag* ti_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tab_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextRodIter__icZic_u21968)(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ* it_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextIdentIter__astalgo_u2744)(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag* ti_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tab_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u3941)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u173)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, someSym__modulegraphs_u3324)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p2);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u3008)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, interfaceSymbol__icZic_u22076)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p2, NI32 module_p3, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p4, NIM_BOOL importHidden_p5);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u3564)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ** dest_p0, tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u3570)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ** dest_p0, tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3320)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* dest_p0, tySequence__d8ZV4IMgHt9biik9cS9a0hrmg src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg, newSeq__icZic_u16261)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1156)(tySequence__apM9bRAO19cVjhWlxqd1PGeA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u1308)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__YxH9cgSorHRI8ZPzHf47NNQ, eqdup___modulegraphs_u1212)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ src_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u1226)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* s_p0, NI newlen_p1);
static N_INLINE(void, nimCopySeqPayload)(void* dest_p0, void* src_p1, NI elemSize_p2, NI elemAlign_p3);
N_LIB_PRIVATE N_NIMCALL(NI, align__system_u1639)(NI address_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*, eqdup___options_u2141)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA*, eqdup___idents_u344)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* src_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__qBes3XzcQQ9cyia9bRwnmbJw, getOrDefault__icZic_u21531)(tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, loadSym__icZic_u12255)(tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA* c_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p1, NI thisModule_p2, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig s_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u12620)(tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3391)(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toBase64a__modulegraphs_u2902)(NCSTRING s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, searchForCompilerproc__icZic_u22268)(tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA* m_p0, NimStringV2 name_p1);
static N_INLINE(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig, toPackedItemId__icZpacked95ast_u1268)(NI32 item_p0);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, toPackedGeneratedProcDef__icZic_u7511)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* encoder_p1, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__modulegraphs_u10641)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* x_p0, tyTuple__lGHLhAAUpxgfrnQkIzNrMw* y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw*, mgetOrPut__modulegraphs_u9537)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__9bW2eTK9b7vXE70Sx5VPH1mw val_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2212)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u2234)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14134)(tySequence__juxPMVNF1FoR2ltzeQu8NQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11761)(tySequence__nSO1ltijM4vhc0UrrXKEqA dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, getPackageId__packages_u71)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getPackageSymbol__packages_u18)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___modulegraphs_u6956)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__olFOFaYzOJN9aV5BWqK4b9bA val_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u2826)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* dest_p0, tySequence__olFOFaYzOJN9aV5BWqK4b9bA src_p1);
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u2414)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__modulegraphs_u6885)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* x_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA y_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, resolveSym__modulegraphs_u3497)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* t_p1);
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(void, saveRodFile__icZic_u10284)(NimStringV2 filename_p0, tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* encoder_p1, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toRodFile__icZic_u7718)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 f_p1, NimStringV2 ext_p2);
N_LIB_PRIVATE N_NIMCALL(void, simulateCachedModule__modulegraphs_u3012)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* moduleSym_p1, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p2);
N_LIB_PRIVATE N_NIMCALL(void, simulateLoadedModule__icZic_u21421)(tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* moduleSym_p3, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p4);
N_LIB_PRIVATE N_NIMCALL(void, registerModule__modulegraphs_u10878)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1);
N_LIB_PRIVATE N_NIMCALL(void, transitiveClosure__modulegraphs_u16379)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* g_p0, NI n_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_u2846)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(void, markDirty__modulegraphs_u16593)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getModule__modulegraphs_u14809)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(void, del__modulegraphs_u16637)(tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ* t_p0, NI32 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, del__modulegraphs_u17066)(tyObject_Table__w2vCG1OPnHmNolvQVT168g* t_p0, NI32 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, rememberStartupConfig__icZic_u1046)(tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ* dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u374)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u869)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u1571)(tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u1925)(tyObject_Table__tEqt8LkShErhjQ9acvGyE7g* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, clear__modulegraphs_u2536)(tyObject_Table__5vmBY49areSIlgIs4A1LLKQ* t_p0);
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vJDjRhiQWnfbAi9csscWSug_2 = { 2 | NIM_STRLIT_FLAG, "<=" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_3 = {2, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_4 = { 1 | NIM_STRLIT_FLAG, "<" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_5 = {1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_4};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vJDjRhiQWnfbAi9csscWSug_6 = { 3 | NIM_STRLIT_FLAG, "and" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_7 = {3, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_6};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vJDjRhiQWnfbAi9csscWSug_8 = { 2 | NIM_STRLIT_FLAG, "or" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_9 = {2, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_8};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vJDjRhiQWnfbAi9csscWSug_10 = { 5 | NIM_STRLIT_FLAG, "isnil" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_11 = {5, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_10};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vJDjRhiQWnfbAi9csscWSug_12 = { 2 | NIM_STRLIT_FLAG, "==" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_13 = {2, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_12};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_14 = { 1 | NIM_STRLIT_FLAG, "+" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_15 = {1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_14};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_16 = { 1 | NIM_STRLIT_FLAG, "-" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_17 = {1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_16};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_18 = { 1 | NIM_STRLIT_FLAG, "*" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_19 = {1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_18};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vJDjRhiQWnfbAi9csscWSug_20 = { 3 | NIM_STRLIT_FLAG, "div" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_21 = {3, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_20};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vJDjRhiQWnfbAi9csscWSug_22 = { 3 | NIM_STRLIT_FLAG, "len" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_23 = {3, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_22};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vJDjRhiQWnfbAi9csscWSug_24 = { 3 | NIM_STRLIT_FLAG, "not" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_25 = {3, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_24};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__vJDjRhiQWnfbAi9csscWSug_26 = { 8 | NIM_STRLIT_FLAG, "contains" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_27 = {8, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_26};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__vJDjRhiQWnfbAi9csscWSug_28 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_29 = {0, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_28};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vJDjRhiQWnfbAi9csscWSug_30 = { 6 | NIM_STRLIT_FLAG, "pkgs2/" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_31 = {6, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_30};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__vJDjRhiQWnfbAi9csscWSug_32 = {
0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vJDjRhiQWnfbAi9csscWSug_33 = { 4 | NIM_STRLIT_FLAG, "pkg/" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_34 = {4, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_33};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vJDjRhiQWnfbAi9csscWSug_35 = { 4 | NIM_STRLIT_FLAG, ".nim" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_36 = {4, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_35};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vJDjRhiQWnfbAi9csscWSug_37 = { 9 | NIM_STRLIT_FLAG, "nimscript" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_38 = {9, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_37};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_39 = { 1 | NIM_STRLIT_FLAG, ">" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_40 = {1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_39};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__vJDjRhiQWnfbAi9csscWSug_41 = { 10 | NIM_STRLIT_FLAG, "(toplevel)" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_42 = {10, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_41};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vJDjRhiQWnfbAi9csscWSug_43 = { 7 | NIM_STRLIT_FLAG, "(nims) " };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_44 = {7, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_43};
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_45 = {0, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_28};
static const struct {
  NI cap; NIM_CHAR data[67+1];
} TM__vJDjRhiQWnfbAi9csscWSug_47 = { 67 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/modulegraphs.nim" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vJDjRhiQWnfbAi9csscWSug_48 = { 2 | NIM_STRLIT_FLAG, "__" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_49 = {2, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_48};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_50 = { 1 | NIM_STRLIT_FLAG, "A" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_51 = { 1 | NIM_STRLIT_FLAG, "B" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_52 = { 1 | NIM_STRLIT_FLAG, "C" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_53 = { 1 | NIM_STRLIT_FLAG, "D" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_54 = { 1 | NIM_STRLIT_FLAG, "E" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_55 = { 1 | NIM_STRLIT_FLAG, "F" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_56 = { 1 | NIM_STRLIT_FLAG, "G" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_57 = { 1 | NIM_STRLIT_FLAG, "H" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_58 = { 1 | NIM_STRLIT_FLAG, "I" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_59 = { 1 | NIM_STRLIT_FLAG, "J" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_60 = { 1 | NIM_STRLIT_FLAG, "K" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_61 = { 1 | NIM_STRLIT_FLAG, "L" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_62 = { 1 | NIM_STRLIT_FLAG, "M" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_63 = { 1 | NIM_STRLIT_FLAG, "N" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_64 = { 1 | NIM_STRLIT_FLAG, "O" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_65 = { 1 | NIM_STRLIT_FLAG, "P" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_66 = { 1 | NIM_STRLIT_FLAG, "Q" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_67 = { 1 | NIM_STRLIT_FLAG, "R" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_68 = { 1 | NIM_STRLIT_FLAG, "S" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_69 = { 1 | NIM_STRLIT_FLAG, "T" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_70 = { 1 | NIM_STRLIT_FLAG, "U" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_71 = { 1 | NIM_STRLIT_FLAG, "V" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_72 = { 1 | NIM_STRLIT_FLAG, "W" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_73 = { 1 | NIM_STRLIT_FLAG, "X" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_74 = { 1 | NIM_STRLIT_FLAG, "Y" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_75 = { 1 | NIM_STRLIT_FLAG, "Z" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_76 = { 1 | NIM_STRLIT_FLAG, "a" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_77 = { 1 | NIM_STRLIT_FLAG, "b" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_78 = { 1 | NIM_STRLIT_FLAG, "c" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_79 = { 1 | NIM_STRLIT_FLAG, "d" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_80 = { 1 | NIM_STRLIT_FLAG, "e" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_81 = { 1 | NIM_STRLIT_FLAG, "f" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_82 = { 1 | NIM_STRLIT_FLAG, "g" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_83 = { 1 | NIM_STRLIT_FLAG, "h" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_84 = { 1 | NIM_STRLIT_FLAG, "i" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_85 = { 1 | NIM_STRLIT_FLAG, "j" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_86 = { 1 | NIM_STRLIT_FLAG, "k" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_87 = { 1 | NIM_STRLIT_FLAG, "l" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_88 = { 1 | NIM_STRLIT_FLAG, "m" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_89 = { 1 | NIM_STRLIT_FLAG, "n" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_90 = { 1 | NIM_STRLIT_FLAG, "o" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_91 = { 1 | NIM_STRLIT_FLAG, "p" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_92 = { 1 | NIM_STRLIT_FLAG, "q" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_93 = { 1 | NIM_STRLIT_FLAG, "r" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_94 = { 1 | NIM_STRLIT_FLAG, "s" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_95 = { 1 | NIM_STRLIT_FLAG, "t" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_96 = { 1 | NIM_STRLIT_FLAG, "u" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_97 = { 1 | NIM_STRLIT_FLAG, "v" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_98 = { 1 | NIM_STRLIT_FLAG, "w" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_99 = { 1 | NIM_STRLIT_FLAG, "x" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_100 = { 1 | NIM_STRLIT_FLAG, "y" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_101 = { 1 | NIM_STRLIT_FLAG, "z" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_102 = { 1 | NIM_STRLIT_FLAG, "0" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_103 = { 1 | NIM_STRLIT_FLAG, "1" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_104 = { 1 | NIM_STRLIT_FLAG, "2" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_105 = { 1 | NIM_STRLIT_FLAG, "3" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_106 = { 1 | NIM_STRLIT_FLAG, "4" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_107 = { 1 | NIM_STRLIT_FLAG, "5" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_108 = { 1 | NIM_STRLIT_FLAG, "6" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_109 = { 1 | NIM_STRLIT_FLAG, "7" };
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vJDjRhiQWnfbAi9csscWSug_110 = { 1 | NIM_STRLIT_FLAG, "8" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vJDjRhiQWnfbAi9csscWSug_111 = { 2 | NIM_STRLIT_FLAG, "9a" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vJDjRhiQWnfbAi9csscWSug_112 = { 2 | NIM_STRLIT_FLAG, "9b" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vJDjRhiQWnfbAi9csscWSug_113 = { 2 | NIM_STRLIT_FLAG, "9c" };
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vJDjRhiQWnfbAi9csscWSug_114 = { 3 | NIM_STRLIT_FLAG, "rod" };
static const NimStringV2 TM__vJDjRhiQWnfbAi9csscWSug_115 = {3, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_114};
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__vJDjRhiQWnfbAi9csscWSug_46 = {{67, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_47},
((NI)753),
((NI)14)}
;
N_LIB_PRIVATE NIM_CONST tyArray__RFO5owyhZgSVTHBCk8ZhJA cb64__modulegraphs_u2901 = {{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_50},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_51},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_52},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_53},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_54},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_55},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_56},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_57},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_58},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_59},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_60},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_61},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_62},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_63},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_64},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_65},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_66},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_67},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_68},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_69},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_70},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_71},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_72},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_73},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_74},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_75},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_76},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_77},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_78},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_79},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_80},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_81},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_82},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_83},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_84},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_85},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_86},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_87},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_88},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_89},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_90},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_91},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_92},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_93},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_94},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_95},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_96},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_97},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_98},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_99},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_100},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_101},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_102},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_103},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_104},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_105},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_106},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_107},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_108},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_109},
{1, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_110},
{2, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_111},
{2, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_112},
{2, (NimStrPayload*)&TM__vJDjRhiQWnfbAi9csscWSug_113}}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14425)(tySequence__WbW5Q8QVks0bQpUJSGmuVg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__O3g9a8zTXSX36ljWponcAoA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2823)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].sym);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].sym)));
				nimRawDispose(dest_p0.p->data[colontmp_].sym, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14134)(tySequence__juxPMVNF1FoR2ltzeQu8NQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].Field1)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__V6P73hvHy70PBBwharKjig));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11761)(tySequence__nSO1ltijM4vhc0UrrXKEqA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLast(dest_p0.p->data[colontmp_]);
				if (!T6_) goto LA7_;
				eqdestroy___modulegraphs_u11782((&(*dest_p0.p->data[colontmp_])));
				nimRawDispose(dest_p0.p->data[colontmp_], ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA*));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2212)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1.sym);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field1.sym)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1.sym, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__lGHLhAAUpxgfrnQkIzNrMw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1206)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1156)(tySequence__apM9bRAO19cVjhWlxqd1PGeA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLast(dest_p0.p->data[colontmp_].inst);
				if (!T6_) goto LA7_;
				eqdestroy___modulegraphs_u1177((&(*dest_p0.p->data[colontmp_].inst)));
				nimRawDispose(dest_p0.p->data[colontmp_].inst, ((NI)8));
			}
LA7_: ;
			eqdestroy___modulegraphs_u1206(dest_p0.p->data[colontmp_].concreteTypes);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u672)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].typ);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].typ)));
				nimRawDispose(dest_p0.p->data[colontmp_].typ, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13595)(tySequence__dtr79aXjHrgHuH79ac55I2aw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].config);
				if (!T6_) goto LA7_;
				eqdestroy___options_u1751((&(*dest_p0.p->data[colontmp_].config)));
				nimRawDispose(dest_p0.p->data[colontmp_].config, ((NI)8));
			}
LA7_: ;
			eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_].symMarker.data);
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].symMarker.head);
				if (!T11_) goto LA12_;
				eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_].symMarker.head)));
				nimRawDispose(dest_p0.p->data[colontmp_].symMarker.head, ((NI)8));
			}
LA12_: ;
			eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_].typeMarker.data);
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].typeMarker.head);
				if (!T16_) goto LA17_;
				eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_].typeMarker.head)));
				nimRawDispose(dest_p0.p->data[colontmp_].typeMarker.head, ((NI)8));
			}
LA17_: ;
			eqdestroy___ast_u4848(dest_p0.p->data[colontmp_].pendingSyms);
			eqdestroy___ast_u3311(dest_p0.p->data[colontmp_].pendingTypes);
			eqdestroy___icZic_u1393(dest_p0.p->data[colontmp_].filenames.data);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13532)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0) {
	NI colontmp_;
	NI colontmp__2;
	eqdestroy___ast_u3696((*dest_p0).procGlobals);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn((*dest_p0).cachedFiles);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose((*dest_p0).cachedFiles);
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).operators.opLen);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opLen)));
		nimRawDispose((*dest_p0).operators.opLen, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).operators.opDiv);
		if (!T13_) goto LA14_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opDiv)));
		nimRawDispose((*dest_p0).operators.opDiv, ((NI)8));
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastDyn((*dest_p0).operators.opMul);
		if (!T18_) goto LA19_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opMul)));
		nimRawDispose((*dest_p0).operators.opMul, ((NI)8));
	}
LA19_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).operators.opSub);
		if (!T23_) goto LA24_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opSub)));
		nimRawDispose((*dest_p0).operators.opSub, ((NI)8));
	}
LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLastDyn((*dest_p0).operators.opAdd);
		if (!T28_) goto LA29_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opAdd)));
		nimRawDispose((*dest_p0).operators.opAdd, ((NI)8));
	}
LA29_: ;
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = nimDecRefIsLastDyn((*dest_p0).operators.opEq);
		if (!T33_) goto LA34_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opEq)));
		nimRawDispose((*dest_p0).operators.opEq, ((NI)8));
	}
LA34_: ;
	{
		NIM_BOOL T38_;
		T38_ = (NIM_BOOL)0;
		T38_ = nimDecRefIsLastDyn((*dest_p0).operators.opIsNil);
		if (!T38_) goto LA39_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opIsNil)));
		nimRawDispose((*dest_p0).operators.opIsNil, ((NI)8));
	}
LA39_: ;
	{
		NIM_BOOL T43_;
		T43_ = (NIM_BOOL)0;
		T43_ = nimDecRefIsLastDyn((*dest_p0).operators.opOr);
		if (!T43_) goto LA44_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opOr)));
		nimRawDispose((*dest_p0).operators.opOr, ((NI)8));
	}
LA44_: ;
	{
		NIM_BOOL T48_;
		T48_ = (NIM_BOOL)0;
		T48_ = nimDecRefIsLastDyn((*dest_p0).operators.opAnd);
		if (!T48_) goto LA49_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opAnd)));
		nimRawDispose((*dest_p0).operators.opAnd, ((NI)8));
	}
LA49_: ;
	{
		NIM_BOOL T53_;
		T53_ = (NIM_BOOL)0;
		T53_ = nimDecRefIsLastDyn((*dest_p0).operators.opLt);
		if (!T53_) goto LA54_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opLt)));
		nimRawDispose((*dest_p0).operators.opLt, ((NI)8));
	}
LA54_: ;
	{
		NIM_BOOL T58_;
		T58_ = (NIM_BOOL)0;
		T58_ = nimDecRefIsLastDyn((*dest_p0).operators.opLe);
		if (!T58_) goto LA59_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opLe)));
		nimRawDispose((*dest_p0).operators.opLe, ((NI)8));
	}
LA59_: ;
	{
		NIM_BOOL T63_;
		T63_ = (NIM_BOOL)0;
		T63_ = nimDecRefIsLastDyn((*dest_p0).operators.opContains);
		if (!T63_) goto LA64_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opContains)));
		nimRawDispose((*dest_p0).operators.opContains, ((NI)8));
	}
LA64_: ;
	{
		NIM_BOOL T68_;
		T68_ = (NIM_BOOL)0;
		T68_ = nimDecRefIsLastDyn((*dest_p0).operators.opNot);
		if (!T68_) goto LA69_;
		eqdestroy___ast_u3469((&(*(*dest_p0).operators.opNot)));
		nimRawDispose((*dest_p0).operators.opNot, ((NI)8));
	}
LA69_: ;
	{
		NIM_BOOL T73_;
		T73_ = (NIM_BOOL)0;
		T73_ = nimDecRefIsLast((*dest_p0).idgen);
		if (!T73_) goto LA74_;
		eqdestroy___ast_u3074((&(*(*dest_p0).idgen)));
		nimRawDispose((*dest_p0).idgen, ((NI)8));
	}
LA74_: ;
	eqdestroy___ast_u3696((*dest_p0).globalDestructors);
	eqdestroy___modulegraphs_u14425((*dest_p0).passes);
	eqdestroy___modulegraphs_u12789((*dest_p0).cacheTables.data);
	eqdestroy___modulegraphs_u12466((*dest_p0).cacheCounters.data);
	eqdestroy___modulegraphs_u12255((*dest_p0).cacheSeqs.data);
	eqdestroy___modulegraphs_u13172((*dest_p0).symBodyHashes.data);
	eqdestroy___modulegraphs_u13005((*dest_p0).canonTypes.data);
	{
		NIM_BOOL T78_;
		T78_ = (NIM_BOOL)0;
		T78_ = nimDecRefIsLastDyn((*dest_p0).emptyNode);
		if (!T78_) goto LA79_;
		eqdestroy___ast_u3270((&(*(*dest_p0).emptyNode)));
		nimRawDispose((*dest_p0).emptyNode, ((NI)8));
	}
LA79_: ;
	eqdestroy___ast_u4848((*dest_p0).packageTypes.data);
	eqdestroy___ast_u4848((*dest_p0).exposed.data);
	eqdestroy___ast_u4848((*dest_p0).compilerprocs.data);
	colontmp_ = ((NI)0);
	{
		while (1) {
			if (!(colontmp_ < ((NI)65))) goto LA82;
			{
				NIM_BOOL T85_;
				T85_ = (NIM_BOOL)0;
				T85_ = nimDecRefIsLastDyn((*dest_p0).sysTypes[(colontmp_)- 0]);
				if (!T85_) goto LA86_;
				eqdestroy___ast_u3288((&(*(*dest_p0).sysTypes[(colontmp_)- 0])));
				nimRawDispose((*dest_p0).sysTypes[(colontmp_)- 0], ((NI)8));
			}
LA86_: ;
			colontmp_ += ((NI)1);
		} LA82: ;
	}
	{
		NIM_BOOL T90_;
		T90_ = (NIM_BOOL)0;
		T90_ = nimDecRefIsLastDyn((*dest_p0).systemModule);
		if (!T90_) goto LA91_;
		eqdestroy___ast_u3469((&(*(*dest_p0).systemModule)));
		nimRawDispose((*dest_p0).systemModule, ((NI)8));
	}
LA91_: ;
	eqdestroy___modulegraphs_u2823((*dest_p0).dispatchers);
	eqdestroy___modulegraphs_u7400((*dest_p0).methodsPerType.data);
	eqdestroy___modulegraphs_u14113((*dest_p0).objectTree.data);
	eqdestroy___modulegraphs_u14008((*dest_p0).bucketTable.data);
	eqdestroy___modulegraphs_u13327((*dest_p0).methods);
	eqdestroy___modulegraphs_u12037((*dest_p0).suggestErrors.data);
	eqdestroy___suggestsymdb_u1866((*dest_p0).suggestSymbols.data);
	eqdestroy___ast_u4848((*dest_p0).owners);
	{
		NIM_BOOL T95_;
		T95_ = (NIM_BOOL)0;
		T95_ = nimDecRefIsLastDyn((*dest_p0).usageSym);
		if (!T95_) goto LA96_;
		eqdestroy___ast_u3469((&(*(*dest_p0).usageSym)));
		nimRawDispose((*dest_p0).usageSym, ((NI)8));
	}
LA96_: ;
	{
		NIM_BOOL T100_;
		T100_ = (NIM_BOOL)0;
		T100_ = nimDecRefIsLastCyclicDyn((*dest_p0).doStopCompile.ClE_0);
		if (!T100_) goto LA101_;
		nimDestroyAndDispose((*dest_p0).doStopCompile.ClE_0);
	}
LA101_: ;
	{
		NIM_BOOL T105_;
		T105_ = (NIM_BOOL)0;
		T105_ = nimDecRefIsLastCyclicDyn((*dest_p0).repl);
		if (!T105_) goto LA106_;
		nimDestroyAndDispose((*dest_p0).repl);
	}
LA106_: ;
	{
		NIM_BOOL T110_;
		T110_ = (NIM_BOOL)0;
		T110_ = nimDecRefIsLastCyclicDyn((*dest_p0).vm);
		if (!T110_) goto LA111_;
		nimDestroyAndDispose((*dest_p0).vm);
	}
LA111_: ;
	{
		NIM_BOOL T115_;
		T115_ = (NIM_BOOL)0;
		T115_ = nimDecRefIsLast((*dest_p0).cache);
		if (!T115_) goto LA116_;
		eqdestroy___idents_u274((&(*(*dest_p0).cache)));
		nimRawDispose((*dest_p0).cache, ((NI)8));
	}
LA116_: ;
	{
		NIM_BOOL T120_;
		T120_ = (NIM_BOOL)0;
		T120_ = nimDecRefIsLastDyn((*dest_p0).config);
		if (!T120_) goto LA121_;
		eqdestroy___options_u1751((&(*(*dest_p0).config)));
		nimRawDispose((*dest_p0).config, ((NI)8));
	}
LA121_: ;
	{
		NIM_BOOL T125_;
		T125_ = (NIM_BOOL)0;
		T125_ = nimDecRefIsLastCyclicDyn((*dest_p0).backend);
		if (!T125_) goto LA126_;
		nimDestroyAndDispose((*dest_p0).backend);
	}
LA126_: ;
	eqdestroy___icZic_u16091((*dest_p0).importStack);
	eqdestroy___modulegraphs_u11545((*dest_p0).inclToMod.data);
	eqdestroy___modulegraphs_u11373((*dest_p0).importDeps.data);
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).deps.data);
	{
		NIM_BOOL T130_;
		T130_ = (NIM_BOOL)0;
		T130_ = nimDecRefIsLastDyn((*dest_p0).deps.head);
		if (!T130_) goto LA131_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).deps.head)));
		nimRawDispose((*dest_p0).deps.head, ((NI)8));
	}
LA131_: ;
	eqdestroy___ast_u4848((*dest_p0).packageSyms.data);
	eqdestroy___lineinfos_u566((*dest_p0).emittedTypeInfo.data);
	eqdestroy___modulegraphs_u5326((*dest_p0).enumToStringProcs.data);
	eqdestroy___modulegraphs_u13804((*dest_p0).initializersPerType.data);
	eqdestroy___modulegraphs_u13652((*dest_p0).memberProcsPerType.data);
	eqdestroy___modulegraphs_u9130((*dest_p0).methodsPerGenericType.data);
	colontmp__2 = ((NI)0);
	{
		while (1) {
			if (!(colontmp__2 < ((NI)7))) goto LA134;
			eqdestroy___modulegraphs_u5326((*dest_p0).attachedOps[(colontmp__2)- 0].data);
			colontmp__2 += ((NI)1);
		} LA134: ;
	}
	eqdestroy___modulegraphs_u4629((*dest_p0).procInstCache.data);
	eqdestroy___modulegraphs_u3934((*dest_p0).typeInstCache.data);
	eqdestroy___modulegraphs_u13595((*dest_p0).encoders);
	eqdestroy___modulegraphs_u13551((*dest_p0).packed_0.pm);
	eqdestroy___modulegraphs_u13228((*dest_p0).ifaces);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14753)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u13532((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initPackedSet__pureZcollectionsZintsets_u37(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11106)(tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* dest_p0, tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).opNot);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opNot)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opNot, ((NI)8));
	}
LA4_: ;
	(*dest_p0).opNot = (*src_p1).opNot;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).opContains);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opContains)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opContains, ((NI)8));
	}
LA9_: ;
	(*dest_p0).opContains = (*src_p1).opContains;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).opLe);
		if (!T13_) goto LA14_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opLe)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opLe, ((NI)8));
	}
LA14_: ;
	(*dest_p0).opLe = (*src_p1).opLe;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastDyn((*dest_p0).opLt);
		if (!T18_) goto LA19_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opLt)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opLt, ((NI)8));
	}
LA19_: ;
	(*dest_p0).opLt = (*src_p1).opLt;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).opAnd);
		if (!T23_) goto LA24_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opAnd)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opAnd, ((NI)8));
	}
LA24_: ;
	(*dest_p0).opAnd = (*src_p1).opAnd;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLastDyn((*dest_p0).opOr);
		if (!T28_) goto LA29_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opOr)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opOr, ((NI)8));
	}
LA29_: ;
	(*dest_p0).opOr = (*src_p1).opOr;
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = nimDecRefIsLastDyn((*dest_p0).opIsNil);
		if (!T33_) goto LA34_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opIsNil)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opIsNil, ((NI)8));
	}
LA34_: ;
	(*dest_p0).opIsNil = (*src_p1).opIsNil;
	{
		NIM_BOOL T38_;
		T38_ = (NIM_BOOL)0;
		T38_ = nimDecRefIsLastDyn((*dest_p0).opEq);
		if (!T38_) goto LA39_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opEq)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opEq, ((NI)8));
	}
LA39_: ;
	(*dest_p0).opEq = (*src_p1).opEq;
	{
		NIM_BOOL T43_;
		T43_ = (NIM_BOOL)0;
		T43_ = nimDecRefIsLastDyn((*dest_p0).opAdd);
		if (!T43_) goto LA44_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opAdd)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opAdd, ((NI)8));
	}
LA44_: ;
	(*dest_p0).opAdd = (*src_p1).opAdd;
	{
		NIM_BOOL T48_;
		T48_ = (NIM_BOOL)0;
		T48_ = nimDecRefIsLastDyn((*dest_p0).opSub);
		if (!T48_) goto LA49_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opSub)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opSub, ((NI)8));
	}
LA49_: ;
	(*dest_p0).opSub = (*src_p1).opSub;
	{
		NIM_BOOL T53_;
		T53_ = (NIM_BOOL)0;
		T53_ = nimDecRefIsLastDyn((*dest_p0).opMul);
		if (!T53_) goto LA54_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opMul)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opMul, ((NI)8));
	}
LA54_: ;
	(*dest_p0).opMul = (*src_p1).opMul;
	{
		NIM_BOOL T58_;
		T58_ = (NIM_BOOL)0;
		T58_ = nimDecRefIsLastDyn((*dest_p0).opDiv);
		if (!T58_) goto LA59_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opDiv)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opDiv, ((NI)8));
	}
LA59_: ;
	(*dest_p0).opDiv = (*src_p1).opDiv;
	{
		NIM_BOOL T63_;
		T63_ = (NIM_BOOL)0;
		T63_ = nimDecRefIsLastDyn((*dest_p0).opLen);
		if (!T63_) goto LA64_;
		eqdestroy___ast_u3469((&(*(*dest_p0).opLen)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).opLen, ((NI)8));
	}
LA64_: ;
	(*dest_p0).opLen = (*src_p1).opLen;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, createMagic__modulegraphs_u10814)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, NimStringV2 name_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getIdent__idents_u206((*g_p0).cache, name_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = 0;
	result = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12), colontmpD_, idgen_p1, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL), unknownLineInfo__lineinfos_u364, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).magic = m_p3;
	(*result).flags = IL64(8796093022208);
	eqdestroy___idents_u155(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, createMagic__modulegraphs_u10820)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NimStringV2 name_p1, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = createMagic__modulegraphs_u10814(g_p0, (*g_p0).idgen, name_p1, m_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initOperators__modulegraphs_u11091)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ* Result) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T1_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T2_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T3_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T4_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T5_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T6_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T7_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T8_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T9_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T10_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T11_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T12_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T13_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ));
	T1_ = NIM_NIL;
	T1_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_3, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)71));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T1_); goto BeforeRet_;}
	(*Result).opLe = T1_;
	T2_ = NIM_NIL;
	T2_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_5, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)72));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T2_); goto BeforeRet_;}
	(*Result).opLt = T2_;
	T3_ = NIM_NIL;
	T3_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_7, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)106));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T3_); goto BeforeRet_;}
	(*Result).opAnd = T3_;
	T4_ = NIM_NIL;
	T4_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_9, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)107));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T4_); goto BeforeRet_;}
	(*Result).opOr = T4_;
	T5_ = NIM_NIL;
	T5_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_11, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)142));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T5_); goto BeforeRet_;}
	(*Result).opIsNil = T5_;
	T6_ = NIM_NIL;
	T6_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_13, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)70));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T6_); goto BeforeRet_;}
	(*Result).opEq = T6_;
	T7_ = NIM_NIL;
	T7_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_15, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)46));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T7_); goto BeforeRet_;}
	(*Result).opAdd = T7_;
	T8_ = NIM_NIL;
	T8_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_17, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)47));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T8_); goto BeforeRet_;}
	(*Result).opSub = T8_;
	T9_ = NIM_NIL;
	T9_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_19, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)48));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T9_); goto BeforeRet_;}
	(*Result).opMul = T9_;
	T10_ = NIM_NIL;
	T10_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_21, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)49));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T10_); goto BeforeRet_;}
	(*Result).opDiv = T10_;
	T11_ = NIM_NIL;
	T11_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_23, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)39));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T11_); goto BeforeRet_;}
	(*Result).opLen = T11_;
	T12_ = NIM_NIL;
	T12_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_25, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T12_); goto BeforeRet_;}
	(*Result).opNot = T12_;
	T13_ = NIM_NIL;
	T13_ = createMagic__modulegraphs_u10820(g_p0, TM__vJDjRhiQWnfbAi9csscWSug_27, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)132));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T13_); goto BeforeRet_;}
	(*Result).opContains = T13_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, initModuleGraphFields__modulegraphs_u11203)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* result_p0) {
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* T1_;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg T2_;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA T3_;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw T4_;
	tySequence__TfHJycarvNts8E4mVG4Mfg T5_;
	tySequence__48JTohSgTy339bRxHzUD8KA T6_;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA T7_;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA T8_;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ T9_;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g T10_;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg T11_;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg T12_;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg T13_;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg T14_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T15_;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ T16_;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw T17_;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ T18_;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw T19_;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg T20_;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ T21_;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A T22_;
	tyArray__8dwr5YZa3jdi3OLJPUYHGQ T23_;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* T24_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = NIM_NIL;
	T1_ = (tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug*) nimNewObj(sizeof(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug), NIM_ALIGNOF(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug));
	(*T1_).module = ((NI32)-1);
	(*T1_).symId = ((NI32)0);
	(*T1_).typeId_0 = ((NI32)0);
	eqsink___ast_u3109(&(*result_p0).idgen, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6338(T2_); goto BeforeRet_;}
	eqsink___ast_u6347((&(*result_p0).packageSyms), T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&T3_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___pureZcollectionsZintsets_u236((&(*result_p0).deps), (&T3_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T4_ = initTable__modulegraphs_u11217(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u11355(T4_); goto BeforeRet_;}
	eqsink___modulegraphs_u11364((&(*result_p0).importDeps), T4_);
	T5_.len = 0; T5_.p = NIM_NIL;
	T5_.len = 0; T5_.p = (tySequence__TfHJycarvNts8E4mVG4Mfg_Content*) newSeqPayload(0, sizeof(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow), NIM_ALIGNOF(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow));
	eqsink___modulegraphs_u13237((&(*result_p0).ifaces), T5_);
	T6_.len = 0; T6_.p = NIM_NIL;
	T6_.len = 0; T6_.p = (tySequence__48JTohSgTy339bRxHzUD8KA_Content*) newSeqPayload(0, sizeof(NI32), NIM_ALIGNOF(NI32));
	eqsink___icZic_u16100((&(*result_p0).importStack), T6_);
	T7_ = initTable__modulegraphs_u11433(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u11527(T7_); goto BeforeRet_;}
	eqsink___modulegraphs_u11536((&(*result_p0).inclToMod), T7_);
	T8_.len = 0; T8_.p = NIM_NIL;
	T8_.len = 0; T8_.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	eqsink___ast_u4857((&(*result_p0).owners), T8_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T9_ = initTable__modulegraphs_u11598(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u11619(T9_); goto BeforeRet_;}
	eqsink___modulegraphs_u11628((&(*result_p0).suggestSymbols), T9_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T10_ = initTable__modulegraphs_u11649(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u12019(T10_); goto BeforeRet_;}
	eqsink___modulegraphs_u12028((&(*result_p0).suggestErrors), T10_);
	T11_.len = 0; T11_.p = NIM_NIL;
	T11_.len = 0; T11_.p = (tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content*) newSeqPayload(0, sizeof(tyTuple__CvjVmQeIfivirDme2r5MRw), NIM_ALIGNOF(tyTuple__CvjVmQeIfivirDme2r5MRw));
	eqsink___modulegraphs_u13336((&(*result_p0).methods), T11_);
	T12_ = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6338(T12_); goto BeforeRet_;}
	eqsink___ast_u6347((&(*result_p0).compilerprocs), T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T13_ = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6338(T13_); goto BeforeRet_;}
	eqsink___ast_u6347((&(*result_p0).exposed), T13_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T14_ = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6338(T14_); goto BeforeRet_;}
	eqsink___ast_u6347((&(*result_p0).packageTypes), T14_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T15_ = NIM_NIL;
	T15_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T15_); goto BeforeRet_;}
	eqsink___ast_u3261(&(*result_p0).emptyNode, T15_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T16_ = initTable__modulegraphs_u12093(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u12237(T16_); goto BeforeRet_;}
	eqsink___modulegraphs_u12246((&(*result_p0).cacheSeqs), T16_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T17_ = initTable__modulegraphs_u12310(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u12448(T17_); goto BeforeRet_;}
	eqsink___modulegraphs_u12457((&(*result_p0).cacheCounters), T17_);
	T18_ = initTable__modulegraphs_u12520(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u12771(T18_); goto BeforeRet_;}
	eqsink___modulegraphs_u12780((&(*result_p0).cacheTables), T18_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T19_ = initTable__modulegraphs_u12844(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u12987(T19_); goto BeforeRet_;}
	eqsink___modulegraphs_u12996((&(*result_p0).canonTypes), T19_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T20_ = initTable__modulegraphs_u13060(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___modulegraphs_u13154(T20_); goto BeforeRet_;}
	eqsink___modulegraphs_u13163((&(*result_p0).symBodyHashes), T20_);
	nimZeroMem((void*)(&T21_), sizeof(tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ));
	initOperators__modulegraphs_u11091(result_p0, (&T21_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___modulegraphs_u11106((&(*result_p0).operators), (&T21_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T22_ = initTable__lineinfos_u410(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___lineinfos_u548(T22_); goto BeforeRet_;}
	eqsink___lineinfos_u557((&(*result_p0).emittedTypeInfo), T22_);
	T24_ = NIM_NIL;
	T24_ = nstnewStringTableWithTableConstr(T23_, 0, ((tyEnum_StringTableMode__u9a7txyB5iiP8Ga24K7XezA)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___pureZstrtabs_u525(T24_); goto BeforeRet_;}
	eqsink___pureZstrtabs_u536(&(*result_p0).cachedFiles, T24_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw*, newModuleGraph__modulegraphs_u13525)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1) {
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* result;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = NIM_NIL;
	T1_ = (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw*) nimNewObj(sizeof(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw), NIM_ALIGNOF(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw));
	result = T1_;
	eqcopy___options_u2138(&(*result).config, config_p1);
	eqcopy___idents_u341(&(*result).cache, cache_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	initModuleGraphFields__modulegraphs_u11203(result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, dependsOn__modulegraphs_u14880)(NI a_p0, NI b_p1) {
	NI result;
	result = (NI)((NI)((NU64)(a_p0) << (NU64)(((NI)15) & (64 - 1))) + b_p1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addDep__modulegraphs_u14888)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 dep_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T5_;
		if (!(*g_p0).suggestMode) goto LA3_;
		T5_ = (NI)0;
		T5_ = dependsOn__modulegraphs_u14880((*m_p1).position, ((NI) (dep_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		incl__pureZcollectionsZintsets_u366((&(*g_p0).deps), T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addIncludeDep__modulegraphs_u14911)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 module_p1, NI32 includeFile_p2) {
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (NIM_BOOL)0;
	T1_ = hasKeyOrPut__modulegraphs_u14941((&(*g_p0).inclToMod), includeFile_p2, module_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(void)(T1_);
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u2997)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*g_p0).packed_0.pm.len;
	T1_ = (module_p1 < T2_);
	if (!(T1_)) goto LA3_;
	T1_ = ((*g_p0).packed_0.pm.p->data[module_p1].status == ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)3));
LA3_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getModule__modulegraphs_u14809)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 fileIdx_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	{
		if (!(((NI32)0) <= fileIdx_p1)) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = isCachedModule__modulegraphs_u2997(g_p0, ((NI) (fileIdx_p1)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T7_) goto LA8_;
			eqcopy___ast_u4577(&result, (*g_p0).packed_0.pm.p->data[fileIdx_p1].module);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA5_;
LA8_: ;
		{
			NI T11_;
			T11_ = (*g_p0).ifaces.len;
			if (!(((NI) (fileIdx_p1)) < T11_)) goto LA12_;
			eqcopy___ast_u4577(&result, (*g_p0).ifaces.p->data[fileIdx_p1].module);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA5_;
LA12_: ;
LA5_: ;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, moduleFromRodFile__modulegraphs_u17899)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 fileIdx_p1, tySequence__48JTohSgTy339bRxHzUD8KA* cachedModules_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)2) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)4))) goto LA3_;
		result = moduleFromRodFile__icZic_u21165((&(*g_p0).packed_0), (*g_p0).config, (*g_p0).cache, fileIdx_p1, cachedModules_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getPackage__modulegraphs_u17974)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, NI32 fileIdx_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* pkgSym_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	pkgSym_1 = NIM_NIL;
	pkgSym_1 = getPackage__packages_u8((*graph_p0).config, (*graph_p0).cache, fileIdx_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = strTableGet__astalgo_u2726((*graph_p0).packageSyms, (*pkgSym_1).name);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA4_;
		eqcopy___ast_u4577(&result, pkgSym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		strTableAdd__astalgo_u2666((&(*graph_p0).packageSyms), pkgSym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(pkgSym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u10943)(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).uniqueName);
	eqdestroy___ast_u4848((*dest_p0).interfHidden.data);
	eqdestroy___ast_u4848((*dest_p0).interf.data);
	eqdestroy___modulegraphs_u2823((*dest_p0).pureEnums);
	eqdestroy___modulegraphs_u2823((*dest_p0).patterns);
	eqdestroy___modulegraphs_u2823((*dest_p0).converters);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).module);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).module)));
		nimRawDispose((*dest_p0).module, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u10940)(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* dest_p0) {
	(*dest_p0).module = 0;
	(*dest_p0).converters.len = 0; (*dest_p0).converters.p = NIM_NIL;
	(*dest_p0).patterns.len = 0; (*dest_p0).patterns.p = NIM_NIL;
	(*dest_p0).pureEnums.len = 0; (*dest_p0).pureEnums.p = NIM_NIL;
	(*dest_p0).interf.counter = 0;
	(*dest_p0).interf.data.len = 0; (*dest_p0).interf.data.p = NIM_NIL;
	(*dest_p0).interfHidden.counter = 0;
	(*dest_p0).interfHidden.data.len = 0; (*dest_p0).interfHidden.data.p = NIM_NIL;
	(*dest_p0).uniqueName.len = 0; (*dest_p0).uniqueName.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u10952)(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* dest_p0, tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).module);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).module)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).module, ((NI)8));
	}
LA4_: ;
	(*dest_p0).module = (*src_p1).module;
	if ((*dest_p0).converters.p != (*src_p1).converters.p) {	eqdestroy___modulegraphs_u2823((*dest_p0).converters);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).converters.len = (*src_p1).converters.len; (*dest_p0).converters.p = (*src_p1).converters.p;
	if ((*dest_p0).patterns.p != (*src_p1).patterns.p) {	eqdestroy___modulegraphs_u2823((*dest_p0).patterns);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).patterns.len = (*src_p1).patterns.len; (*dest_p0).patterns.p = (*src_p1).patterns.p;
	if ((*dest_p0).pureEnums.p != (*src_p1).pureEnums.p) {	eqdestroy___modulegraphs_u2823((*dest_p0).pureEnums);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).pureEnums.len = (*src_p1).pureEnums.len; (*dest_p0).pureEnums.p = (*src_p1).pureEnums.p;
	(*dest_p0).interf.counter = (*src_p1).interf.counter;
	if ((*dest_p0).interf.data.p != (*src_p1).interf.data.p) {	eqdestroy___ast_u4848((*dest_p0).interf.data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).interf.data.len = (*src_p1).interf.data.len; (*dest_p0).interf.data.p = (*src_p1).interf.data.p;
	(*dest_p0).interfHidden.counter = (*src_p1).interfHidden.counter;
	if ((*dest_p0).interfHidden.data.p != (*src_p1).interfHidden.data.p) {	eqdestroy___ast_u4848((*dest_p0).interfHidden.data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).interfHidden.data.len = (*src_p1).interfHidden.data.len; (*dest_p0).interfHidden.data.p = (*src_p1).interfHidden.data.p;
	if ((*dest_p0).uniqueName.p != (*src_p1).uniqueName.p) {	eqdestroy___system_u2691((*dest_p0).uniqueName);
	}
(*dest_p0).uniqueName.len = (*src_p1).uniqueName.len; (*dest_p0).uniqueName.p = (*src_p1).uniqueName.p;
	}BeforeRet_: ;
}
static N_INLINE(NI, skipUntil__pureZparseutils_u181)(NIM_CHAR* s_p0, NI s_p0Len_0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw until_p1) {
	NI result;
	result = ((NI)0);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = (result < s_p0Len_0);
			if (!(T3_)) goto LA4_;
			T3_ = !(((until_p1[(NU)((((NU8)(s_p0[result]))))>>3] &(1U<<((NU)((((NU8)(s_p0[result]))))&7U)))!=0));
LA4_: ;
			if (!T3_) goto LA2;
			result += ((NI)1);
		} LA2: ;
	}
	return result;
}
static N_INLINE(NI, skipUntil__pureZparseutils_u931)(NimStringV2 s_p0, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw until_p1, NI start_p2) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = skipUntil__pureZparseutils_u181((((s_p0).p) ? ((NIM_CHAR*)s_p0.p->data+(start_p2)) : NIM_NIL), ((s_p0.len-1))-(start_p2)+1, until_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1286)(NimStringV2 s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1) {
	NimStringV2 result;
	NI a_1;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)(x_p1.b - a_1) + ((NI)1));
	result = mnewString((L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				nimPrepareStrMutationV2((&result));
				result.p->data[i_1] = s_p0.p->data[(NI)(i_1 + a_1)];
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1) {
	tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, uniqueModuleName__modulegraphs_u10825)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
	NimStringV2 result;
	NimStringV2 path_1;
	NimStringV2 rel_1;
	NI colontmpD_;
	NI colontmpD__2;
	NI32 fid_1;
	NIM_BOOL isLib_1;
	NI trunc_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	path_1.len = 0; path_1.p = NIM_NIL;
	rel_1.len = 0; rel_1.p = NIM_NIL;
	colontmpD_ = (NI)0;
	colontmpD__2 = (NI)0;
	fid_1 = ((NI32) ((*m_p1).position));
	path_1 = toFullPath__msgs_u624(conf_p0, fid_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	isLib_1 = NIM_FALSE;
	rel_1 = TM__vJDjRhiQWnfbAi9csscWSug_29;
	{
		NIM_BOOL T4_;
		NimStringV2 T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = nsuStartsWith(path_1, (*conf_p0).libpath);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		isLib_1 = NIM_TRUE;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = relativeTo__pathutils_u196(path_1, (*conf_p0).libpath, 47);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA1_;}
		eqsink___system_u2700((&rel_1), T7_);
	}
	goto LA2_;
LA5_: ;
	{
		NimStringV2 T9_;
		T9_.len = 0; T9_.p = NIM_NIL;
		T9_ = relativeTo__pathutils_u196(path_1, (*conf_p0).projectPath, 47);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T9_); goto LA1_;}
		eqsink___system_u2700((&rel_1), T9_);
	}
LA2_: ;
	{
		NIM_BOOL T12_;
		NIM_BOOL T14_;
		NimStringV2 rel2_1;
		NI start_1;
		T12_ = (NIM_BOOL)0;
		T12_ = !(isLib_1);
		if (!(T12_)) goto LA13_;
		T14_ = (NIM_BOOL)0;
		T14_ = belongsToProjectPackage__packages_u81(conf_p0, m_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T12_ = !(T14_);
LA13_: ;
		if (!T12_) goto LA15_;
		rel2_1.len = 0; rel2_1.p = NIM_NIL;
		eqcopy___system_u2694((&rel2_1), rel_1);
		start_1 = nsuFindStr(rel2_1, TM__vJDjRhiQWnfbAi9csscWSug_31, ((NI)0), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NI T21_;
			if (!(((NI)0) <= start_1)) goto LA19_;
			start_1 += ((NI)6);
			T21_ = (NI)0;
			T21_ = skipUntil__pureZparseutils_u931(rel2_1, TM__vJDjRhiQWnfbAi9csscWSug_32, start_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			start_1 += T21_;
			{
				NimStringV2 colontmpD__3;
				NimStringV2 T26_;
				tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA T27_;
				if (!((NI)(start_1 + ((NI)1)) < rel2_1.len)) goto LA24_;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				T26_.len = 0; T26_.p = NIM_NIL;
				T27_ = dotdot___stdZstrbasics_u49((NI)(start_1 + ((NI)1)), (NI)(rel_1.len - ((NI)1)));
				colontmpD__3 = X5BX5D___pureZstrutils_u1286(rel2_1, T27_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T26_ = rawNewString(colontmpD__3.len + 4);
appendString((&T26_), TM__vJDjRhiQWnfbAi9csscWSug_34);
appendString((&T26_), colontmpD__3);
				eqsink___system_u2700((&rel_1), T26_);
				eqdestroy___system_u2691(colontmpD__3);
			}
LA24_: ;
		}
LA19_: ;
		eqdestroy___system_u2691(rel2_1);
	}
LA15_: ;
	{
		NIM_BOOL T30_;
		T30_ = (NIM_BOOL)0;
		T30_ = nsuEndsWith(rel_1, TM__vJDjRhiQWnfbAi9csscWSug_36);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T30_) goto LA31_;
		colontmpD_ = (NI)(rel_1.len - ((NI)4));
		trunc_1 = colontmpD_;
	}
	goto LA28_;
LA31_: ;
	{
		colontmpD__2 = rel_1.len;
		trunc_1 = colontmpD__2;
	}
LA28_: ;
	result = rawNewString((trunc_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				NIM_CHAR c_1;
				if (!(i_2 < trunc_1)) goto LA36;
				i_1 = i_2;
				c_1 = rel_1.p->data[i_1];
				switch (((NU8)(c_1))) {
				case 97 ... 122:
				case 48 ... 57:
				{
					nimAddCharV1((&result), c_1);
				}
				break;
				case 47:
				{
					nimAddCharV1((&result), 90);
				}
				break;
				case 46:
				{
					nimAddCharV1((&result), 79);
				}
				break;
				default:
				{
					addInt__stdZprivateZdigitsutils_u204((&result), ((NU8)(c_1)));
				}
				break;
				}
				i_2 += ((NI)1);
			} LA36: ;
		}
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(rel_1);
		eqdestroy___system_u2691(path_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initStrTables__modulegraphs_u2990)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg T1_;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6338(T1_); goto BeforeRet_;}
	eqsink___ast_u6347((&(*g_p0).ifaces.p->data[(*m_p1).position].interf), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6338(T2_); goto BeforeRet_;}
	eqsink___ast_u6347((&(*g_p0).ifaces.p->data[(*m_p1).position].interfHidden), T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, registerModule__modulegraphs_u10878)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (*g_p0).ifaces.len;
		if (!(T3_ <= (*m_p1).position)) goto LA4_;
		setLen__modulegraphs_u10899((&(*g_p0).ifaces), ((NI)((*m_p1).position + ((NI)1))));
	}
LA4_: ;
	{
		NI T8_;
		T8_ = (*g_p0).packed_0.pm.len;
		if (!(T8_ <= (*m_p1).position)) goto LA9_;
		setLen__icZic_u12940((&(*g_p0).packed_0.pm), ((NI)((*m_p1).position + ((NI)1))));
	}
LA9_: ;
	nimZeroMem((void*)(&T11_), sizeof(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow));
	nimZeroMem((void*)(&T11_), sizeof(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow));
	colontmpD_ = eqdup___ast_u4580(m_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T11_.module = colontmpD_;
	T11_.converters.len = 0; T11_.converters.p = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content*) newSeqPayload(0, sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA), NIM_ALIGNOF(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	T11_.patterns.len = 0; T11_.patterns.p = (tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content*) newSeqPayload(0, sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA), NIM_ALIGNOF(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	T11_.uniqueName = uniqueModuleName__modulegraphs_u10825((*g_p0).config, m_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___modulegraphs_u10952((&(*g_p0).ifaces.p->data[(*m_p1).position]), (&T11_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	initStrTables__modulegraphs_u2990(g_p0, m_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, onProcessing__modulegraphs_u17910)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, NI32 fileIdx_p1, NimStringV2 moduleStatus_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fromModule_p3) {
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_1;
	NIM_BOOL isNimscript_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	conf_1 = NIM_NIL;
	eqcopy___options_u2138(&conf_1, (*graph_p0).config);
	isNimscript_1 = isDefined__options_u959(conf_1, TM__vJDjRhiQWnfbAi9csscWSug_38);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NimStringV2 path_1;
		NimStringV2 indent_1;
		NimStringV2 fromModule2_1;
		NimStringV2 mode_1;
		NimStringV2 colontmpD_;
		NI T9_;
		NimStringV2 T10_;
		NimStringV2 T16_;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T22_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(isNimscript_1);
		if (T4_) goto LA5_;
		T4_ = (((*conf_1).cmdlineNotes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)99) - 20))&7U)))!=0);
LA5_: ;
		if (!T4_) goto LA6_;
		path_1.len = 0; path_1.p = NIM_NIL;
		indent_1.len = 0; indent_1.p = NIM_NIL;
		fromModule2_1.len = 0; fromModule2_1.p = NIM_NIL;
		mode_1.len = 0; mode_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		path_1 = toFilenameOption__msgs_u676(conf_1, fileIdx_p1, (*conf_1).filenameOption);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T9_ = (*graph_p0).importStack.len;
		indent_1 = nsuRepeatStr(TM__vJDjRhiQWnfbAi9csscWSug_40, (T9_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		T10_.len = 0; T10_.p = NIM_NIL;
		{
			if (!!((fromModule_p3 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA13_;
			fromModule2_1 = (*(*fromModule_p3).name).s;
		}
		goto LA11_;
LA13_: ;
		{
			fromModule2_1 = TM__vJDjRhiQWnfbAi9csscWSug_42;
		}
LA11_: ;
		T16_.len = 0; T16_.p = NIM_NIL;
		{
			if (!isNimscript_1) goto LA19_;
			mode_1 = TM__vJDjRhiQWnfbAi9csscWSug_44;
		}
		goto LA17_;
LA19_: ;
		{
			mode_1 = TM__vJDjRhiQWnfbAi9csscWSug_45;
		}
LA17_: ;
		T22_[0] = mode_1;
		T22_[1] = indent_1;
		T22_[2] = fromModule2_1;
		T22_[3] = moduleStatus_p2;
		T22_[4] = path_1;
		colontmpD_ = percent___modulegraphs_u17932(T22_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		liMessage__msgs_u1227(conf_1, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)99), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__vJDjRhiQWnfbAi9csscWSug_46), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
		{
			LA8_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(indent_1);
			eqdestroy___system_u2691(path_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___options_u2135(conf_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u30975)(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0);
	}
LA4_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw*, eqdup___modulegraphs_u14759)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p0) {
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initEncoder__modulegraphs_u3016)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1) {
	NI id_1;
	tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	id_1 = (*module_p1).position;
	{
		NI T3_;
		T3_ = (*g_p0).encoders.len;
		if (!(T3_ <= id_1)) goto LA4_;
		setLen__modulegraphs_u3024((&(*g_p0).encoders), ((NI)(id_1 + ((NI)1))));
	}
LA4_: ;
	T6_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
	T6_ = (&(*g_p0).encoders.p->data[id_1]);
	initEncoder__icZic_u2995(T6_, (&(*g_p0).packed_0.pm.p->data[id_1].fromDisk), module_p1, (*g_p0).config, (*g_p0).startupPackedConfig);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, resolveType__modulegraphs_u3482)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA* t_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*t_p1).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T7_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T8_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = isCachedModule__modulegraphs_u2997(g_p0, (*t_p1).id.module);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = (*g_p0).config;
		T8_ = NIM_NIL;
		T8_ = (*g_p0).cache;
		T9_ = NIM_NIL;
		T9_ = loadTypeFromId__icZic_u21257(T7_, T8_, (&(*g_p0).packed_0), (*t_p1).id.module, (*t_p1).id.packed_0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T9_); goto BeforeRet_;}
		eqsink___ast_u3387(&result, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___ast_u3381(&(*t_p1).typ, result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, resolveAttachedOp__modulegraphs_u3583)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* t_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*t_p1).sym);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T5_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T6_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T7_;
		if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = (*g_p0).config;
		T6_ = NIM_NIL;
		T6_ = (*g_p0).cache;
		T7_ = NIM_NIL;
		T7_ = loadSymFromId__icZic_u21336(T5_, T6_, (&(*g_p0).packed_0), (*t_p1).id.module, (*t_p1).id.packed_0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T7_); goto BeforeRet_;}
		eqsink___ast_u4583(&result, T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___ast_u4577(&(*t_p1).sym, result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getAttachedOp__modulegraphs_u4987)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* T6_;
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = contains__modulegraphs_u5048((*g_p0).attachedOps[(op_p2)- 0], (*t_p1).itemId);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = g_p0;
		T7_ = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
		T7_ = X5BX5D___modulegraphs_u5532((&(*g_p0).attachedOps[(op_p2)- 0]), (*t_p1).itemId);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = resolveAttachedOp__modulegraphs_u3583(T6_, T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u1867)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* dest_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).id.module = src_p1.id.module;
	(*dest_p0).id.packed_0.module = src_p1.id.packed_0.module;
	(*dest_p0).id.packed_0.item = src_p1.id.packed_0.item;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).sym);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).sym)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).sym, ((NI)8));
	}
LA4_: ;
	(*dest_p0).sym = src_p1.sym;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1855)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* dest_p0) {
	(*dest_p0).id.module = 0;
	(*dest_p0).id.packed_0.module = 0;
	(*dest_p0).id.packed_0.item = 0;
	(*dest_p0).sym = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, setAttachedOp__modulegraphs_u5617)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* value_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	colontmpD_ = eqdup___ast_u4580(value_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.sym = colontmpD_;
	X5BX5Deq___modulegraphs_u5663((&(*g_p0).attachedOps[(op_p3)- 0]), (*t_p2).itemId, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, copyTypeProps__modulegraphs_u10674)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p3) {
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q k_1;
		NI res_1;
		k_1 = (tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)0;
		res_1 = ((NI)0);
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
				if (!(res_1 <= ((NI)6))) goto LA3;
				op_1 = NIM_NIL;
				k_1 = ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q) (res_1));
				op_1 = getAttachedOp__modulegraphs_u4987(g_p0, src_p3, k_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				{
					if (!!((op_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA7_;
					setAttachedOp__modulegraphs_u5617(g_p0, module_p1, dest_p2, k_1, op_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
LA7_: ;
				res_1 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(op_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u681)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* dest_p0, tySequence__vb3AGHvMJTxdOSSwMmBmTQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___modulegraphs_u672((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u669)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u739)(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.typ);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*dest_p0.typ)));
		nimRawDispose(dest_p0.typ, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u736)(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA* dest_p0) {
	(*dest_p0).id.module = 0;
	(*dest_p0).id.packed_0.module = 0;
	(*dest_p0).id.packed_0.item = 0;
	(*dest_p0).typ = 0;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__vb3AGHvMJTxdOSSwMmBmTQ, eqdup___modulegraphs_u678)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ src_p0) {
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__modulegraphs_u694((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_].id.module = src_p0.p->data[colontmp_].id.module;
			result.p->data[colontmp_].id.packed_0.module = src_p0.p->data[colontmp_].id.packed_0.module;
			result.p->data[colontmp_].id.packed_0.item = src_p0.p->data[colontmp_].id.packed_0.item;
			result.p->data[colontmp_].typ = src_p0.p->data[colontmp_].typ;
			{
				if (!src_p0.p->data[colontmp_].typ) goto LA7_;
				nimIncRef(src_p0.p->data[colontmp_].typ);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, resolveSym__modulegraphs_u3497)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* t_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*t_p1).sym);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T7_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T8_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T9_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = isCachedModule__modulegraphs_u2997(g_p0, (*t_p1).id.module);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = (*g_p0).config;
		T8_ = NIM_NIL;
		T8_ = (*g_p0).cache;
		T9_ = NIM_NIL;
		T9_ = loadSymFromId__icZic_u21336(T7_, T8_, (&(*g_p0).packed_0), (*t_p1).id.module, (*t_p1).id.packed_0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T9_); goto BeforeRet_;}
		eqsink___ast_u4583(&result, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___ast_u4577(&(*t_p1).sym, result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initModuleIter__modulegraphs_u3177)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* mi_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p2, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	(*mi_p0).modIndex = (*m_p2).position;
	T1_ = (NIM_BOOL)0;
	T1_ = isCachedModule__modulegraphs_u2997(g_p1, (*mi_p0).modIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*mi_p0).fromRod = T1_;
	(*mi_p0).importHidden = (((*m_p2).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)27)))&31U)))!=0);
	{
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T6_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T7_;
		if (!(*mi_p0).fromRod) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = (*g_p1).config;
		T7_ = NIM_NIL;
		T7_ = (*g_p1).cache;
		result = initRodIter__icZic_u21451((&(*mi_p0).rodIt), T6_, T7_, (&(*g_p1).packed_0), ((NI32) ((*mi_p0).modIndex)), name_p3, (*mi_p0).importHidden);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA4_: ;
	{
		tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* retX60gensym16__1;
		retX60gensym16__1 = (&(*g_p1).ifaces.p->data[(*mi_p0).modIndex].interf);
		{
			if (!(*mi_p0).importHidden) goto LA11_;
			retX60gensym16__1 = (&(*g_p1).ifaces.p->data[(*mi_p0).modIndex].interfHidden);
		}
LA11_: ;
		result = initIdentIter__astalgo_u2768((&(*mi_p0).ti), (*retX60gensym16__1), name_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextModuleIter__modulegraphs_u3222)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* mi_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!(*mi_p0).fromRod) goto LA3_;
		result = nextRodIter__icZic_u21968((&(*mi_p0).rodIt), (&(*g_p1).packed_0));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* retX60gensym17__1;
		retX60gensym17__1 = (&(*g_p1).ifaces.p->data[(*mi_p0).modIndex].interf);
		{
			if (!(*mi_p0).importHidden) goto LA8_;
			retX60gensym17__1 = (&(*g_p1).ifaces.p->data[(*mi_p0).modIndex].interfHidden);
		}
LA8_: ;
		result = nextIdentIter__astalgo_u2744((&(*mi_p0).ti), (*retX60gensym17__1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3435)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* dest_p0) {
	eqdestroy___icZic_u3941((*dest_p0).rodIt.values);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0).rodIt.decoder.cache);
		if (!T3_) goto LA4_;
		eqdestroy___idents_u274((&(*(*dest_p0).rodIt.decoder.cache)));
		nimRawDispose((*dest_p0).rodIt.decoder.cache, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).rodIt.decoder.config);
		if (!T8_) goto LA9_;
		eqdestroy___options_u1751((&(*(*dest_p0).rodIt.decoder.config)));
		nimRawDispose((*dest_p0).rodIt.decoder.config, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).ti.name);
		if (!T13_) goto LA14_;
		eqdestroy___idents_u173((&(*(*dest_p0).ti.name)));
		nimRawDispose((*dest_p0).ti.name, ((NI)8));
	}
LA14_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u14756)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw** dest_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u3008)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = isCachedModule__modulegraphs_u2997(g_p0, (*m_p1).position);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, someSym__modulegraphs_u3324)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NIM_BOOL importHidden_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	importHidden_1 = (((*m_p1).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)27)))&31U)))!=0);
	{
		NIM_BOOL T3_;
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T6_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = isCachedModule__modulegraphs_u3008(g_p0, m_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = (*g_p0).config;
		T7_ = NIM_NIL;
		T7_ = (*g_p0).cache;
		result = interfaceSymbol__icZic_u22076(T6_, T7_, (&(*g_p0).packed_0), ((NI32) ((*m_p1).position)), name_p2, importHidden_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* retX60gensym25__1;
		retX60gensym25__1 = (&(*g_p0).ifaces.p->data[(*m_p1).position].interf);
		{
			if (!importHidden_1) goto LA11_;
			retX60gensym25__1 = (&(*g_p0).ifaces.p->data[(*m_p1).position].interfHidden);
		}
LA11_: ;
		result = strTableGet__astalgo_u2726((*retX60gensym25__1), name_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, systemModuleSym__modulegraphs_u3414)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = someSym__modulegraphs_u3324(g_p0, (*g_p0).systemModule, name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, strTableAdds__modulegraphs_u2993)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	strTableAdd__astalgo_u2666((&(*g_p0).ifaces.p->data[(*m_p1).position].interf), s_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	strTableAdd__astalgo_u2666((&(*g_p0).ifaces.p->data[(*m_p1).position].interfHidden), s_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ*, resolveInst__modulegraphs_u3512)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* t_p1) {
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___modulegraphs_u3564(&result, (*t_p1).inst);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* T7_;
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T8_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T9_;
		NI T10_;
		tySequence__d8ZV4IMgHt9biik9cS9a0hrmg T11_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == ((tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ*) NIM_NIL));
		if (!(T3_)) goto LA4_;
		T3_ = isCachedModule__modulegraphs_u2997(g_p0, (*t_p1).module);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = NIM_NIL;
		T7_ = (tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ*) nimNewObj(sizeof(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ), NIM_ALIGNOF(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ));
		T8_ = NIM_NIL;
		T8_ = (*g_p0).config;
		T9_ = NIM_NIL;
		T9_ = (*g_p0).cache;
		(*T7_).sym = loadSymFromId__icZic_u21336(T8_, T9_, (&(*g_p0).packed_0), (*t_p1).sym.module, (*t_p1).sym.packed_0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqsink___modulegraphs_u3570(&result, T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T10_ = (*t_p1).concreteTypes.len;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = newSeq__icZic_u16261((T10_));
		eqsink___ast_u3320((&(*result).concreteTypes), T11_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NI i_1;
			NI colontmp_;
			NI T13_;
			NI res_1;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T13_ = ((*result).concreteTypes.len-1);
			colontmp_ = T13_;
			res_1 = ((NI)0);
			{
				while (1) {
					tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T16_;
					tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T17_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T18_;
					if (!(res_1 <= colontmp_)) goto LA15;
					i_1 = ((NI) (res_1));
					T16_ = NIM_NIL;
					T16_ = (*g_p0).config;
					T17_ = NIM_NIL;
					T17_ = (*g_p0).cache;
					T18_ = NIM_NIL;
					T18_ = loadTypeFromId__icZic_u21257(T16_, T17_, (&(*g_p0).packed_0), (*t_p1).concreteTypes.p->data[i_1].module, (*t_p1).concreteTypes.p->data[i_1].packed_0);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T18_); goto BeforeRet_;}
					eqsink___ast_u3387(&(*result).concreteTypes.p->data[i_1], T18_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA15: ;
			}
		}
		eqcopy___modulegraphs_u3564(&(*t_p1).inst, result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u1165)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* dest_p0, tySequence__apM9bRAO19cVjhWlxqd1PGeA src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___modulegraphs_u1156((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1153)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1353)(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0).inst);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u1177((&(*(*dest_p0).inst)));
		nimRawDispose((*dest_p0).inst, ((NI)8));
	}
LA4_: ;
	eqdestroy___modulegraphs_u1206((*dest_p0).concreteTypes);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1350)(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* dest_p0) {
	(*dest_p0).module = 0;
	(*dest_p0).sym.module = 0;
	(*dest_p0).sym.packed_0.module = 0;
	(*dest_p0).sym.packed_0.item = 0;
	(*dest_p0).concreteTypes.len = 0; (*dest_p0).concreteTypes.p = NIM_NIL;
	(*dest_p0).inst = 0;
}
static N_INLINE(void, nimCopySeqPayload)(void* dest_p0, void* src_p1, NI elemSize_p2, NI elemAlign_p3) {
	tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ* d_1;
	tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ* s_1;
	d_1 = ((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (dest_p0));
	s_1 = ((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (src_p1));
	{
		NI headerSize_1;
		if (!(((NI)0) < (*s_1).len)) goto LA3_;
		headerSize_1 = align__system_u1639(((NI)8), elemAlign_p3);
		copyMem__system_u1742(((void*) ((NU)((NU64)(((NU) (ptrdiff_t) ((*d_1).p))) + (NU64)(((NU) (headerSize_1)))))), ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) ((*s_1).p))) + (NU64)(((NU) (headerSize_1)))))), ((NI)((*s_1).len * elemSize_p2)));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__YxH9cgSorHRI8ZPzHf47NNQ, eqdup___modulegraphs_u1212)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ src_p0) {
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ result;
	NI T1_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__modulegraphs_u1226((&result), T1_);
	nimCopySeqPayload((&result), (&src_p0), ((NI)16), ((NI)8));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__apM9bRAO19cVjhWlxqd1PGeA, eqdup___modulegraphs_u1162)(tySequence__apM9bRAO19cVjhWlxqd1PGeA src_p0) {
	tySequence__apM9bRAO19cVjhWlxqd1PGeA result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__modulegraphs_u1308((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_].module = src_p0.p->data[colontmp_].module;
			result.p->data[colontmp_].sym.module = src_p0.p->data[colontmp_].sym.module;
			result.p->data[colontmp_].sym.packed_0.module = src_p0.p->data[colontmp_].sym.packed_0.module;
			result.p->data[colontmp_].sym.packed_0.item = src_p0.p->data[colontmp_].sym.packed_0.item;
			result.p->data[colontmp_].concreteTypes = eqdup___modulegraphs_u1212(src_p0.p->data[colontmp_].concreteTypes);
			result.p->data[colontmp_].inst = src_p0.p->data[colontmp_].inst;
			{
				if (!src_p0.p->data[colontmp_].inst) goto LA7_;
				nimIncRef(src_p0.p->data[colontmp_].inst);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, someSymAmb__modulegraphs_u3342)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p2, NIM_BOOL* amb_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NIM_BOOL importHidden_1;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	importHidden_1 = (((*m_p1).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)27)))&31U)))!=0);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isCachedModule__modulegraphs_u3008(g_p0, m_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
			tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA decoder_1;
			tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* colontmpD_;
			tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* colontmpD__2;
			tySequence__qBes3XzcQQ9cyia9bRwnmbJw values_1;
			NI32 colontmp_;
			tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg* retX60gensym505__1;
			s_1 = NIM_NIL;
			nimZeroMem((void*)(&decoder_1), sizeof(tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA));
			values_1.len = 0; values_1.p = NIM_NIL;
			colontmp_ = (NI32)0;
			colontmp_ = ((NI32) ((*m_p1).position));
			decoder_1.lastModule = ((NI)-1);
			decoder_1.lastLit = ((NU32)0);
			decoder_1.lastFile = ((NI32)-1);
			colontmpD_ = eqdup___options_u2141((*g_p0).config);
			decoder_1.config = colontmpD_;
			colontmpD__2 = eqdup___idents_u344((*g_p0).cache);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			decoder_1.cache = colontmpD__2;
			retX60gensym505__1 = (&(*g_p0).packed_0.pm.p->data[((NI) (colontmp_))].iface);
			{
				if (!importHidden_1) goto LA10_;
				retX60gensym505__1 = (&(*g_p0).packed_0.pm.p->data[((NI) (colontmp_))].ifaceHidden);
			}
LA10_: ;
			values_1 = getOrDefault__icZic_u21531((*retX60gensym505__1), name_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
			{
				tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig* pid_1;
				NI i_1;
				NI L_1;
				NI T13_;
				pid_1 = (tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig*)0;
				i_1 = ((NI)0);
				T13_ = values_1.len;
				L_1 = T13_;
				{
					while (1) {
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
						if (!(i_1 < L_1)) goto LA15;
						s_2 = NIM_NIL;
						pid_1 = (&values_1.p->data[i_1]);
						s_2 = loadSym__icZic_u12255((&decoder_1), (&(*g_p0).packed_0), ((NI) (colontmp_)), (*pid_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						eqsink___ast_u4583(&s_1, s_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						eqwasMoved___ast_u4571(&s_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						{
							if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA19_;
							eqsink___ast_u4583(&result, s_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
							eqwasMoved___ast_u4571(&s_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
						}
						goto LA17_;
LA19_: ;
						{
							(*amb_p3) = NIM_TRUE;
							eqdestroy___ast_u4574(s_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
							eqdestroy___icZic_u3941(values_1);
							eqdestroy___icZic_u12620((&decoder_1));
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							eqdestroy___ast_u4574(s_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto LA6;
						}
LA17_: ;
						i_1 += ((NI)1);
						{
							LA16_:;
						}
						{
							oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u4574(s_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
							*nimErr_ = oldNimErrFin16_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					} LA15: ;
				}
			}
			{
				LA7_:;
			}
			{
				oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___icZic_u3941(values_1);
				eqdestroy___icZic_u12620((&decoder_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u4574(s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin7_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA6: ;
	}
	goto LA1_;
LA4_: ;
	{
		tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
		tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* retX60gensym27__1;
		nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
		colontmpD__3 = NIM_NIL;
		nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
		retX60gensym27__1 = (&(*g_p0).ifaces.p->data[(*m_p1).position].interf);
		{
			if (!importHidden_1) goto LA29_;
			retX60gensym27__1 = (&(*g_p0).ifaces.p->data[(*m_p1).position].interfHidden);
		}
LA29_: ;
		result = initIdentIter__astalgo_u2768((&ti_1), (*retX60gensym27__1), name_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T33_;
			tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* retX60gensym30__1;
			T33_ = (NIM_BOOL)0;
			T33_ = !((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
			if (!(T33_)) goto LA34_;
			retX60gensym30__1 = (&(*g_p0).ifaces.p->data[(*m_p1).position].interf);
			{
				if (!importHidden_1) goto LA37_;
				retX60gensym30__1 = (&(*g_p0).ifaces.p->data[(*m_p1).position].interfHidden);
			}
LA37_: ;
			colontmpD__3 = nextIdentIter__astalgo_u2744((&ti_1), (*retX60gensym30__1));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T33_ = !((colontmpD__3 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA34_: ;
			if (!T33_) goto LA39_;
			(*amb_p3) = NIM_TRUE;
		}
LA39_: ;
		eqdestroy___ast_u4574(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___modulegraphs_u3391(ti_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toBase64a__modulegraphs_u2902)(NCSTRING s_p0, NI len_p1) {
	NimStringV2 result;
	NI i_1;
	result.len = 0; result.p = NIM_NIL;
	result = rawNewString(((NI)((NI)((NI)(len_p1 + ((NI)2)) / ((NI)3)) * ((NI)4))));
	prepareAdd((&result), 2);
appendString((&result), TM__vJDjRhiQWnfbAi9csscWSug_49);
	i_1 = ((NI)0);
	{
		while (1) {
			NI a_1;
			NI b_1;
			NI c_1;
			if (!(i_1 < (NI)(len_p1 - ((NI)2)))) goto LA2;
			a_1 = ((NU8)(s_p0[i_1]));
			b_1 = ((NU8)(s_p0[(NI)(i_1 + ((NI)1))]));
			c_1 = ((NU8)(s_p0[(NI)(i_1 + ((NI)2))]));
			prepareAdd((&result), cb64__modulegraphs_u2901[((NI)((NI64)(a_1) >> (NU64)(((NI)2) & (64 - 1))))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)((NI64)(a_1) >> (NU64)(((NI)2) & (64 - 1))))- 0]);
			prepareAdd((&result), cb64__modulegraphs_u2901[((NI)((NI)((NU64)((NI)(a_1 & ((NI)3))) << (NU64)(((NI)4) & (64 - 1))) | (NI)((NI64)((NI)(b_1 & ((NI)240))) >> (NU64)(((NI)4) & (64 - 1)))))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)((NI)((NU64)((NI)(a_1 & ((NI)3))) << (NU64)(((NI)4) & (64 - 1))) | (NI)((NI64)((NI)(b_1 & ((NI)240))) >> (NU64)(((NI)4) & (64 - 1)))))- 0]);
			prepareAdd((&result), cb64__modulegraphs_u2901[((NI)((NI)((NU64)((NI)(b_1 & ((NI)15))) << (NU64)(((NI)2) & (64 - 1))) | (NI)((NI64)((NI)(c_1 & ((NI)192))) >> (NU64)(((NI)6) & (64 - 1)))))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)((NI)((NU64)((NI)(b_1 & ((NI)15))) << (NU64)(((NI)2) & (64 - 1))) | (NI)((NI64)((NI)(c_1 & ((NI)192))) >> (NU64)(((NI)6) & (64 - 1)))))- 0]);
			prepareAdd((&result), cb64__modulegraphs_u2901[((NI)(c_1 & ((NI)63)))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)(c_1 & ((NI)63)))- 0]);
			i_1 += ((NI)3);
		} LA2: ;
	}
	{
		NI a_2;
		NI b_2;
		if (!(i_1 < (NI)(len_p1 - ((NI)1)))) goto LA5_;
		a_2 = ((NU8)(s_p0[i_1]));
		b_2 = ((NU8)(s_p0[(NI)(i_1 + ((NI)1))]));
		prepareAdd((&result), cb64__modulegraphs_u2901[((NI)((NI64)(a_2) >> (NU64)(((NI)2) & (64 - 1))))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)((NI64)(a_2) >> (NU64)(((NI)2) & (64 - 1))))- 0]);
		prepareAdd((&result), cb64__modulegraphs_u2901[((NI)((NI)((NU64)((NI)(a_2 & ((NI)3))) << (NU64)(((NI)4) & (64 - 1))) | (NI)((NI64)((NI)(b_2 & ((NI)240))) >> (NU64)(((NI)4) & (64 - 1)))))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)((NI)((NU64)((NI)(a_2 & ((NI)3))) << (NU64)(((NI)4) & (64 - 1))) | (NI)((NI64)((NI)(b_2 & ((NI)240))) >> (NU64)(((NI)4) & (64 - 1)))))- 0]);
		prepareAdd((&result), cb64__modulegraphs_u2901[((NI)((NU64)((NI)(b_2 & ((NI)15))) << (NU64)(((NI)2) & (64 - 1))))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)((NU64)((NI)(b_2 & ((NI)15))) << (NU64)(((NI)2) & (64 - 1))))- 0]);
	}
	goto LA3_;
LA5_: ;
	{
		NI a_3;
		if (!(i_1 < len_p1)) goto LA8_;
		a_3 = ((NU8)(s_p0[i_1]));
		prepareAdd((&result), cb64__modulegraphs_u2901[((NI)((NI64)(a_3) >> (NU64)(((NI)2) & (64 - 1))))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)((NI64)(a_3) >> (NU64)(((NI)2) & (64 - 1))))- 0]);
		prepareAdd((&result), cb64__modulegraphs_u2901[((NI)((NU64)((NI)(a_3 & ((NI)3))) << (NU64)(((NI)4) & (64 - 1))))- 0].len + 0);
appendString((&result), cb64__modulegraphs_u2901[((NI)((NU64)((NI)(a_3 & ((NI)3))) << (NU64)(((NI)4) & (64 - 1))))- 0]);
	}
	goto LA3_;
LA8_: ;
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___modulegraphs_u10732)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow u_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = toBase64a__modulegraphs_u2902(((NCSTRING) (u_p0)), ((NI)16));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig, toPackedItemId__icZpacked95ast_u1268)(NI32 item_p0) {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig result;
	result.module = ((NU32)0);
	result.item = item_p0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, loadCompilerProc__modulegraphs_u10704)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NimStringV2 name_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	{
		if (!((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0))) goto LA3_;
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		goto BeforeRet_;
	}
LA3_: ;
	{
		NI module_1;
		NI colontmp_;
		NI T6_;
		NI i_1;
		module_1 = (NI)0;
		colontmp_ = (NI)0;
		T6_ = (*g_p0).packed_0.pm.len;
		colontmp_ = T6_;
		i_1 = ((NI)0);
		{
			while (1) {
				NI32 x_1;
				if (!(i_1 < colontmp_)) goto LA8;
				module_1 = i_1;
				x_1 = searchForCompilerproc__icZic_u22268((&(*g_p0).packed_0.pm.p->data[module_1]), name_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T13_;
					tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T14_;
					tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig T15_;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T16_;
					if (!(((NI32)0) <= x_1)) goto LA11_;
					T13_ = NIM_NIL;
					T13_ = (*g_p0).config;
					T14_ = NIM_NIL;
					T14_ = (*g_p0).cache;
					T15_ = toPackedItemId__icZpacked95ast_u1268(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T16_ = NIM_NIL;
					T16_ = loadSymFromId__icZic_u21336(T13_, T14_, (&(*g_p0).packed_0), module_1, T15_);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T16_); goto BeforeRet_;}
					eqsink___ast_u4583(&result, T16_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA19_;
						strTableAdd__astalgo_u2666((&(*g_p0).compilerprocs), result);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
LA19_: ;
					goto BeforeRet_;
				}
LA11_: ;
				i_1 += ((NI)1);
			} LA8: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, hash__modulegraphs_u10758)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow u_p0) {
	NI result;
	result = ((NI)0);
	{
		NI x_1;
		NI res_1;
		x_1 = (NI)0;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= ((NI)3))) goto LA3;
				x_1 = ((NI) (res_1));
				result = (NI)((NI)((NU64)(result) << (NU64)(((NI)8) & (64 - 1))) | ((NI) (u_p0[(x_1)- 0])));
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___modulegraphs_u10735)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow a_p0, tyArray__dnD8kjh6rJ1Yy5jHvid0Ow b_p1) {
	NIM_BOOL result;
	result = equalMem__system_u1750(((void*) (a_p0)), ((void*) (b_p1)), ((NI)16));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setAttachedOpPartial__modulegraphs_u6770)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* value_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	colontmpD_ = eqdup___ast_u4580(value_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.sym = colontmpD_;
	X5BX5Deq___modulegraphs_u5663((&(*g_p0).attachedOps[(op_p3)- 0]), (*t_p2).itemId, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, completePartialOp__modulegraphs_u6822)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* value_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*g_p0).encoders.p->data[module_p1]);
		toPackedGeneratedProcDef__icZic_u7511(value_p4, T5_, (&(*g_p0).packed_0.pm.p->data[module_p1].fromDisk));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdup___modulegraphs_u1864)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA src_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* Result) {
	nimZeroMem((void*)Result, sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	(*Result).id.module = src_p0.id.module;
	(*Result).id.packed_0.module = src_p0.id.packed_0.module;
	(*Result).id.packed_0.item = src_p0.id.packed_0.item;
	(*Result).sym = src_p0.sym;
	{
		if (!src_p0.sym) goto LA3_;
		nimIncRef(src_p0.sym);
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u2221)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* dest_p0, tySequence__9bW2eTK9b7vXE70Sx5VPH1mw src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___modulegraphs_u2212((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u2209)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2279)(tyTuple__lGHLhAAUpxgfrnQkIzNrMw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field1.sym);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).Field1.sym)));
		nimRawDispose((*dest_p0).Field1.sym, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u2276)(tyTuple__lGHLhAAUpxgfrnQkIzNrMw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.id.module = 0;
	(*dest_p0).Field1.id.packed_0.module = 0;
	(*dest_p0).Field1.id.packed_0.item = 0;
	(*dest_p0).Field1.sym = 0;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw, eqdup___modulegraphs_u2218)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw src_p0) {
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__modulegraphs_u2234((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_].Field0 = src_p0.p->data[colontmp_].Field0;
			result.p->data[colontmp_].Field1.id.module = src_p0.p->data[colontmp_].Field1.id.module;
			result.p->data[colontmp_].Field1.id.packed_0.module = src_p0.p->data[colontmp_].Field1.id.packed_0.module;
			result.p->data[colontmp_].Field1.id.packed_0.item = src_p0.p->data[colontmp_].Field1.id.packed_0.item;
			result.p->data[colontmp_].Field1.sym = src_p0.p->data[colontmp_].Field1.sym;
			{
				if (!src_p0.p->data[colontmp_].Field1.sym) goto LA7_;
				nimIncRef(src_p0.p->data[colontmp_].Field1.sym);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addMethodToGeneric__modulegraphs_u9475)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, NI col_p3, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw T1_;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* T2_;
	tyTuple__lGHLhAAUpxgfrnQkIzNrMw T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_.len = 0; T1_.p = (tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content*) newSeqPayload(0, sizeof(tyTuple__lGHLhAAUpxgfrnQkIzNrMw), NIM_ALIGNOF(tyTuple__lGHLhAAUpxgfrnQkIzNrMw));
	T2_ = (tySequence__9bW2eTK9b7vXE70Sx5VPH1mw*)0;
	T2_ = mgetOrPut__modulegraphs_u9537((&(*g_p0).methodsPerGenericType), (*t_p2).itemId, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T3_), sizeof(tyTuple__lGHLhAAUpxgfrnQkIzNrMw));
	T3_.Field0 = col_p3;
	nimZeroMem((void*)(&T3_.Field1), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	colontmpD_ = eqdup___ast_u4580(m_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_.Field1.sym = colontmpD_;
	add__modulegraphs_u10641((&(*T2_)), (&T3_));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u14143)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* dest_p0, tySequence__juxPMVNF1FoR2ltzeQu8NQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___modulegraphs_u14134((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u14131)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasDisabledAsgn__modulegraphs_u10661)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
	NIM_BOOL T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	op_1 = NIM_NIL;
	op_1 = getAttachedOp__modulegraphs_u4987(g_p0, t_p1, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = (NIM_BOOL)0;
	T2_ = !((op_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T2_)) goto LA3_;
	T2_ = (((*op_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)24)))&63U)))!=0);
LA3_: ;
	result = T2_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(op_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setToStringProc__modulegraphs_u8744)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* value_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	colontmpD_ = eqdup___ast_u4580(value_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.sym = colontmpD_;
	X5BX5Deq___modulegraphs_u5663((&(*g_p0).enumToStringProcs), (*t_p1).itemId, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u11770)(tySequence__nSO1ltijM4vhc0UrrXKEqA* dest_p0, tySequence__nSO1ltijM4vhc0UrrXKEqA src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___modulegraphs_u11761((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, belongsToStdlib__modulegraphs_u17983)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	NI T1_;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getPackageSymbol__packages_u18(sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	T1_ = getPackageId__packages_u71(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NI)0;
	T2_ = getPackageId__packages_u71((*graph_p0).systemModule);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = (T1_ == T2_);
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, loadPackedSym__modulegraphs_u10725)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T5_;
		tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T6_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T7_;
		if (!((*s_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = (*g_p0).config;
		T6_ = NIM_NIL;
		T6_ = (*g_p0).cache;
		T7_ = NIM_NIL;
		T7_ = loadSymFromId__icZic_u21336(T5_, T6_, (&(*g_p0).packed_0), (*s_p1).id.module, (*s_p1).id.packed_0);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T7_); goto BeforeRet_;}
		eqsink___ast_u4583(&(*s_p1).sym, T7_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u2832)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* dest_p0, tySequence__olFOFaYzOJN9aV5BWqK4b9bA src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___modulegraphs_u2823((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u2820)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1858)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.sym);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.sym)));
		nimRawDispose(dest_p0.sym, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1) {
	NIM_BOOL result;
	result = ((*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (x_p0))).p == (*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (y_p1))).p);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u2826)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* dest_p0, tySequence__olFOFaYzOJN9aV5BWqK4b9bA src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__modulegraphs_u2414((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			(*dest_p0).p->data[colontmp_].id.module = src_p1.p->data[colontmp_].id.module;
			(*dest_p0).p->data[colontmp_].id.packed_0.module = src_p1.p->data[colontmp_].id.packed_0.module;
			(*dest_p0).p->data[colontmp_].id.packed_0.item = src_p1.p->data[colontmp_].id.packed_0.item;
			{
				if (!src_p1.p->data[colontmp_].sym) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_].sym);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_].sym);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3469((&(*(*dest_p0).p->data[colontmp_].sym)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_].sym, ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_].sym = src_p1.p->data[colontmp_].sym;
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setMethodsPerType__modulegraphs_u6912)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA id_p1, tySequence__olFOFaYzOJN9aV5BWqK4b9bA methods_p2) {
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	eqcopy___modulegraphs_u2826((&colontmpD_), methods_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	X5BX5Deq___modulegraphs_u6956((&(*g_p0).methodsPerType), id_p1, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u1861)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* dest_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).id.module = src_p1.id.module;
	(*dest_p0).id.packed_0.module = src_p1.id.packed_0.module;
	(*dest_p0).id.packed_0.item = src_p1.id.packed_0.item;
	{
		if (!src_p1.sym) goto LA3_;
		nimIncRef(src_p1.sym);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0).sym);
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3469((&(*(*dest_p0).sym)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).sym, ((NI)8));
	}
LA8_: ;
	(*dest_p0).sym = src_p1.sym;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addDispatchers__modulegraphs_u6882)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* value_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
	colontmpD_ = eqdup___ast_u4580(value_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.sym = colontmpD_;
	add__modulegraphs_u6885((&(*g_p0).dispatchers), T1_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rememberEmittedTypeInfo__modulegraphs_u14828)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 m_p1, NimStringV2 ti_p2) {
	{
		NimStringV2 colontmpD_;
		if (!!(((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		colontmpD_ = eqdup___system_u2697(ti_p2);
		add__stdZenumutils_u71((&(*g_p0).packed_0.pm.p->data[m_p1].fromDisk.emittedTypeInfo), colontmpD_);
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getToStringProc__modulegraphs_u8679)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* T1_;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = g_p0;
	T2_ = (tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA*)0;
	T2_ = X5BX5D___modulegraphs_u5532((&(*g_p0).enumToStringProcs), (*t_p1).itemId);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = resolveSym__modulegraphs_u3497(T1_, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1) {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* h_1;
	NI T1_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	h_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_));
	(*h_1).rc = pluspercent___system_u785((*h_1).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, eqdup___cgen_u30982)(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* src_p0, NIM_BOOL cyclic_p1) {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* result;
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgen_u30972)(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, simulateCachedModule__modulegraphs_u3012)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* moduleSym_p1, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	simulateLoadedModule__icZic_u21421((&(*g_p0).packed_0), (*g_p0).config, (*g_p0).cache, moduleSym_p1, m_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, closeRodFile__modulegraphs_u14866)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NI mint_1;
		NimStringV2 T6_;
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T7_;
		if (!((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)2) || (*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)3))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		mint_1 = (*m_p1).position;
		colontmpD_ = toFullPath__msgs_u624((*g_p0).config, ((NI32) (mint_1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		colontmpD__2 = toRodFile__icZic_u7718((*g_p0).config, colontmpD_, TM__vJDjRhiQWnfbAi9csscWSug_115);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_.len = 0; T6_.p = NIM_NIL;
		T6_ = colontmpD__2;
		T7_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T7_ = (&(*g_p0).encoders.p->data[mint_1]);
		saveRodFile__icZic_u10284(T6_, T7_, (&(*g_p0).packed_0.pm.p->data[mint_1].fromDisk));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		(*g_p0).packed_0.pm.p->data[mint_1].status = ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)5);
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		NI mint_2;
		if (!((*(*g_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)4))) goto LA11_;
		mint_2 = (*m_p1).position;
		simulateCachedModule__modulegraphs_u3012(g_p0, m_p1, (&(*g_p0).packed_0.pm.p->data[mint_2].fromDisk));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*g_p0).packed_0.pm.p->data[mint_2].status = ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)3);
	}
	goto LA1_;
LA11_: ;
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, registerModuleById__modulegraphs_u11088)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 m_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	registerModule__modulegraphs_u10878(g_p0, (*g_p0).packed_0.pm.p->data[((NI) (m_p1))].module);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1203)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__olFOFaYzOJN9aV5BWqK4b9bA, eqdup___modulegraphs_u2829)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA src_p0) {
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__modulegraphs_u2414((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_].id.module = src_p0.p->data[colontmp_].id.module;
			result.p->data[colontmp_].id.packed_0.module = src_p0.p->data[colontmp_].id.packed_0.module;
			result.p->data[colontmp_].id.packed_0.item = src_p0.p->data[colontmp_].id.packed_0.item;
			result.p->data[colontmp_].sym = src_p0.p->data[colontmp_].sym;
			{
				if (!src_p0.p->data[colontmp_].sym) goto LA7_;
				nimIncRef(src_p0.p->data[colontmp_].sym);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDirty__modulegraphs_u17708)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (*g_p0).suggestMode;
	if (!(T1_)) goto LA2_;
	T1_ = (((*m_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)56)))&63U)))!=0);
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitiveClosure__modulegraphs_u16379)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* g_p0, NI n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI k_1;
		NI i_1;
		k_1 = (NI)0;
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 < n_p1)) goto LA3;
				k_1 = i_1;
				{
					NI i_2;
					NI i_3;
					i_2 = (NI)0;
					i_3 = ((NI)0);
					{
						while (1) {
							if (!(i_3 < n_p1)) goto LA6;
							i_2 = i_3;
							{
								NI j_1;
								NI i_4;
								j_1 = (NI)0;
								i_4 = ((NI)0);
								{
									while (1) {
										if (!(i_4 < n_p1)) goto LA9;
										j_1 = i_4;
										{
											NIM_BOOL T12_;
											NI T14_;
											NIM_BOOL T15_;
											T12_ = (NIM_BOOL)0;
											T12_ = !((i_2 == j_1));
											if (!(T12_)) goto LA13_;
											T14_ = (NI)0;
											T14_ = dependsOn__modulegraphs_u14880(i_2, j_1);
											if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
											T15_ = (NIM_BOOL)0;
											T15_ = contains__astalgo_u2846((&(*g_p0)), T14_);
											if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
											T12_ = !(T15_);
LA13_: ;
											if (!T12_) goto LA16_;
											{
												NIM_BOOL T20_;
												NI T21_;
												NI T23_;
												NI T26_;
												T20_ = (NIM_BOOL)0;
												T21_ = (NI)0;
												T21_ = dependsOn__modulegraphs_u14880(i_2, k_1);
												if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
												T20_ = contains__astalgo_u2846((&(*g_p0)), T21_);
												if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
												if (!(T20_)) goto LA22_;
												T23_ = (NI)0;
												T23_ = dependsOn__modulegraphs_u14880(k_1, j_1);
												if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
												T20_ = contains__astalgo_u2846((&(*g_p0)), T23_);
												if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA22_: ;
												if (!T20_) goto LA24_;
												T26_ = (NI)0;
												T26_ = dependsOn__modulegraphs_u14880(i_2, j_1);
												if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
												incl__pureZcollectionsZintsets_u366(g_p0, T26_);
												if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
											}
LA24_: ;
										}
LA16_: ;
										i_4 += ((NI)1);
									} LA9: ;
								}
							}
							i_3 += ((NI)1);
						} LA6: ;
					}
				}
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11758)(tySequence__nSO1ltijM4vhc0UrrXKEqA* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, markDirty__modulegraphs_u16593)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 fileIdx_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	m_1 = NIM_NIL;
	m_1 = getModule__modulegraphs_u14809(g_p0, fileIdx_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!!((m_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA3_;
		del__modulegraphs_u16637((&(*g_p0).suggestSymbols), fileIdx_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		del__modulegraphs_u17066((&(*g_p0).suggestErrors), fileIdx_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*m_1).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)56))) & 63);
	}
LA3_: ;
	eqdestroy___ast_u4574(m_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, markClientsDirty__modulegraphs_u17716)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI32 fileIdx_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T5_;
		if (!(*g_p0).invalidTransitiveClosure) goto LA3_;
		(*g_p0).invalidTransitiveClosure = NIM_FALSE;
		T5_ = (*g_p0).ifaces.len;
		transitiveClosure__modulegraphs_u16379((&(*g_p0).deps), T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		NI32 i_1;
		NI32 colontmp_;
		NI T7_;
		NI32 res_1;
		i_1 = (NI32)0;
		colontmp_ = (NI32)0;
		T7_ = (*g_p0).ifaces.len;
		colontmp_ = ((NI32) (T7_));
		res_1 = ((NI32)0);
		{
			while (1) {
				if (!(res_1 < colontmp_)) goto LA9;
				i_1 = res_1;
				{
					NI T12_;
					NIM_BOOL T13_;
					T12_ = (NI)0;
					T12_ = dependsOn__modulegraphs_u14880(((NI) (i_1)), ((NI) (fileIdx_p1)));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T13_ = (NIM_BOOL)0;
					T13_ = contains__astalgo_u2846((&(*g_p0).deps), T12_);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!T13_) goto LA14_;
					markDirty__modulegraphs_u16593(g_p0, i_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA14_: ;
				res_1 += ((NI)1);
			} LA9: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, configComplete__modulegraphs_u17908)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	rememberStartupConfig__icZic_u1046((&(*g_p0).startupPackedConfig), (*g_p0).config);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, resetForBackend__modulegraphs_u330)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0) {
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u6338(T1_); goto BeforeRet_;}
	eqsink___ast_u6347((&(*g_p0).compilerprocs), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	clear__modulegraphs_u374((&(*g_p0).typeInstCache));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	clear__modulegraphs_u869((&(*g_p0).procInstCache));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA* a_1;
		tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q i_1;
		a_1 = (tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA*)0;
		i_1 = ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)0);
		{
			while (1) {
				a_1 = (&(*g_p0).attachedOps[(i_1)- 0]);
				clear__modulegraphs_u1571(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					if (!(((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)6) <= i_1)) goto LA7_;
					goto LA3;
				}
LA7_: ;
				i_1 += ((NI)1);
			}
		} LA3: ;
	}
	clear__modulegraphs_u1925((&(*g_p0).methodsPerGenericType));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	clear__modulegraphs_u1571((&(*g_p0).enumToStringProcs));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setLen__modulegraphs_u2414((&(*g_p0).dispatchers), ((NI)0));
	clear__modulegraphs_u2536((&(*g_p0).methodsPerType));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
