/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <sys/mman.h>
#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <sys/types.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct Exception Exception;
typedef struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg;
typedef struct tyTuple__DTRsWi2kgTewbhN2TT5mbA tyTuple__DTRsWi2kgTewbhN2TT5mbA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ;
typedef struct tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA;
typedef struct tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg;
typedef struct tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg;
typedef struct tyObject_LLChunk__9cg7LlyOeeb21wFGpiSg37g tyObject_LLChunk__9cg7LlyOeeb21wFGpiSg37g;
typedef struct tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ;
typedef struct tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg;
typedef struct tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA;
typedef struct tyTuple__4BgqD9cyRAp80fL3mrBT7yQ tyTuple__4BgqD9cyRAp80fL3mrBT7yQ;
typedef struct tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w;
typedef struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg;
typedef struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyTuple__N4J9cV4JZGem3ljqqj5rT0Q;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
typedef struct tySequence__9chP3SzkaldXzawWQCDsqqg tySequence__9chP3SzkaldXzawWQCDsqqg;
typedef struct tySequence__9chP3SzkaldXzawWQCDsqqg_Content tySequence__9chP3SzkaldXzawWQCDsqqg_Content;
typedef struct tyObject_NimSeqV2__CVB9ceqf7MuYQ50y33G2eMQ tyObject_NimSeqV2__CVB9ceqf7MuYQ50y33G2eMQ;
typedef struct tyObject_NimSeqPayload__jE9cmDq9bcUuOOKfQy6CBC1A tyObject_NimSeqPayload__jE9cmDq9bcUuOOKfQy6CBC1A;
typedef struct tyTuple__aGv2fk9ceddvdC01ZJC2Q2g tyTuple__aGv2fk9ceddvdC01ZJC2Q2g;
typedef struct tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g;
typedef struct tyObject_NimSeqV2__z16azg5dzFTHfo9azxutGNA tyObject_NimSeqV2__z16azg5dzFTHfo9azxutGNA;
typedef struct tyObject_NimSeqPayload__0nxC5OGQFE7jyMqWtYaR7A tyObject_NimSeqPayload__0nxC5OGQFE7jyMqWtYaR7A;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ tySequence__xv3aaFd3JCw8NbmALHiezQ;
typedef struct tySequence__xv3aaFd3JCw8NbmALHiezQ_Content tySequence__xv3aaFd3JCw8NbmALHiezQ_Content;
typedef struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA tyTuple__sPaDkVPSC0MkcoXCxPH9ccA;
typedef struct tyObject_NimSeqV2__cmhMldmnNRYydfu2BEkRCg tyObject_NimSeqV2__cmhMldmnNRYydfu2BEkRCg;
typedef struct tyObject_NimSeqPayload__9aI6jznD9cwNqZ3317klA9bBQ tyObject_NimSeqPayload__9aI6jznD9cwNqZ3317klA9bBQ;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_NimSeqV2__zeIiXV75mf2Pfp9b3Cs5Wdg tyObject_NimSeqV2__zeIiXV75mf2Pfp9b3Cs5Wdg;
typedef struct tyObject_NimSeqPayload__Nsi2DL7cl1GFqRwjgk71Jw tyObject_NimSeqPayload__Nsi2DL7cl1GFqRwjgk71Jw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_NimSeqV2__xYeauJM9bj9aY9caH55lM1nKA tyObject_NimSeqV2__xYeauJM9bj9aY9caH55lM1nKA;
typedef struct tyObject_NimSeqPayload__5OkmQTkiYc9cnv9bZqKK9c19bA tyObject_NimSeqPayload__5OkmQTkiYc9cnv9bZqKK9c19bA;
typedef struct tySequence__FGxE1Nuen6pVDc58PZudJw tySequence__FGxE1Nuen6pVDc58PZudJw;
typedef struct tySequence__FGxE1Nuen6pVDc58PZudJw_Content tySequence__FGxE1Nuen6pVDc58PZudJw_Content;
typedef struct tyObject_NimSeqV2__Qnm9a1W1Vp9akt9cDxi9ajFnSQ tyObject_NimSeqV2__Qnm9a1W1Vp9akt9cDxi9ajFnSQ;
typedef struct tyObject_NimSeqPayload__d4XM9c4jiz4O1hJ3ujtvgcw tyObject_NimSeqPayload__d4XM9c4jiz4O1hJ3ujtvgcw;
typedef struct tyTuple__7xc1P89akJWzo77UAKrb3aA tyTuple__7xc1P89akJWzo77UAKrb3aA;
typedef struct tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw;
typedef struct tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw;
typedef struct tyObject_NimSeqPayload__40TpIbQQfNQeMf0E9czzDBw tyObject_NimSeqPayload__40TpIbQQfNQeMf0E9czzDBw;
typedef struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig;
typedef struct tyObject_NimSeqV2__XHO6qbtQL6Yo0q1oajKWkw tyObject_NimSeqV2__XHO6qbtQL6Yo0q1oajKWkw;
typedef struct tyObject_NimSeqPayload__381WimpkqKVRiIr1lhxEQA tyObject_NimSeqPayload__381WimpkqKVRiIr1lhxEQA;
typedef struct tySequence__6j25whH7XTBoIXcM0x1T7A tySequence__6j25whH7XTBoIXcM0x1T7A;
typedef struct tySequence__6j25whH7XTBoIXcM0x1T7A_Content tySequence__6j25whH7XTBoIXcM0x1T7A_Content;
typedef struct tyTuple__9cdgeqdY7FRioNKBoD6G66A tyTuple__9cdgeqdY7FRioNKBoD6G66A;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyObject_NimSeqV2__mvS7yZmzkLtB9bhcvc9atD6A tyObject_NimSeqV2__mvS7yZmzkLtB9bhcvc9atD6A;
typedef struct tyObject_NimSeqPayload__bjUrAWkgJv530yQxlKTwkg tyObject_NimSeqPayload__bjUrAWkgJv530yQxlKTwkg;
typedef struct tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg;
typedef struct tyObject_Defect__WFlDaIWu7hFOKoGSG7uH7g tyObject_Defect__WFlDaIWu7hFOKoGSG7uH7g;
typedef struct tyObject_NimSeqV2__pqlDFC3CU9b7yhxYpu5zLhQ tyObject_NimSeqV2__pqlDFC3CU9b7yhxYpu5zLhQ;
typedef struct tyObject_NimSeqPayload__Z5RrQYPm1Yz8sqF7utTx7Q tyObject_NimSeqPayload__Z5RrQYPm1Yz8sqF7utTx7Q;
typedef struct tyObject_NimSeqV2__QnANZjr9bbFykJmClmY2b9cQ tyObject_NimSeqV2__QnANZjr9bbFykJmClmY2b9cQ;
typedef struct tyObject_NimSeqPayload__ccVYQQMwnFZX6sMceS6iUw tyObject_NimSeqPayload__ccVYQQMwnFZX6sMceS6iUw;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tyObject_NimSeqV2__leUMr6KkmlAoo48M8CioZQ tyObject_NimSeqV2__leUMr6KkmlAoo48M8CioZQ;
typedef struct tyObject_NimSeqPayload__ItQROW58gGeBOtCRbSJrPQ tyObject_NimSeqPayload__ItQROW58gGeBOtCRbSJrPQ;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyObject_NimSeqV2__q9boMy8mhBOdkslxyrVM05g tyObject_NimSeqV2__q9boMy8mhBOdkslxyrVM05g;
typedef struct tyObject_NimSeqPayload__QsnCmrZp2km9cIOMZJvKjNg tyObject_NimSeqPayload__QsnCmrZp2km9cIOMZJvKjNg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tyObject_NimSeqV2__XeVWWFuLkzmWdnv6Nxpo5w tyObject_NimSeqV2__XeVWWFuLkzmWdnv6Nxpo5w;
typedef struct tyObject_NimSeqPayload__aRseLOMn9c4JoSRmriNiugw tyObject_NimSeqPayload__aRseLOMn9c4JoSRmriNiugw;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_NimSeqV2__tfNVrEviQRylDgr69bIF2PQ tyObject_NimSeqV2__tfNVrEviQRylDgr69bIF2PQ;
typedef struct tyObject_NimSeqPayload__y7oTNlyedm3Ce07Nr9cIzyg tyObject_NimSeqPayload__y7oTNlyedm3Ce07Nr9cIzyg;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyObject_NimSeqV2__1l823tnWpfUy9cANEEejxPg tyObject_NimSeqV2__1l823tnWpfUy9cANEEejxPg;
typedef struct tyObject_NimSeqPayload__dJ2CxradV9adiIXkmHsG8Lw tyObject_NimSeqPayload__dJ2CxradV9adiIXkmHsG8Lw;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyObject_NimSeqV2__4gA28oBPgxAGhj7tXEiiqw tyObject_NimSeqV2__4gA28oBPgxAGhj7tXEiiqw;
typedef struct tyObject_NimSeqPayload__08bsLIc9cknpzwJFrHSsc0w tyObject_NimSeqPayload__08bsLIc9cknpzwJFrHSsc0w;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyObject_NimSeqV2__OH9acz2AtycIlvWRolvoaNA tyObject_NimSeqV2__OH9acz2AtycIlvWRolvoaNA;
typedef struct tyObject_NimSeqPayload__lLVTTXn5ZKYsl9afpAy9ce4Q tyObject_NimSeqPayload__lLVTTXn5ZKYsl9afpAy9ce4Q;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyObject_NimSeqV2__6bctsNj71c7TwckMfJfb1g tyObject_NimSeqV2__6bctsNj71c7TwckMfJfb1g;
typedef struct tyObject_NimSeqPayload__oE6qyrap71jgxNstzHAiQg tyObject_NimSeqPayload__oE6qyrap71jgxNstzHAiQg;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyObject_NimSeqV2__c5hiGWTVLb0fIV9ae8w57Gw tyObject_NimSeqV2__c5hiGWTVLb0fIV9ae8w57Gw;
typedef struct tyObject_NimSeqPayload__aT4qJZQM9a6l4F5vjtFSZGQ tyObject_NimSeqPayload__aT4qJZQM9a6l4F5vjtFSZGQ;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_NimSeqV2__UVjWwOjJEIduaGR0AD4jzw tyObject_NimSeqV2__UVjWwOjJEIduaGR0AD4jzw;
typedef struct tyObject_NimSeqPayload__VRA8y5gOokZiYlpeofrQBQ tyObject_NimSeqPayload__VRA8y5gOokZiYlpeofrQBQ;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw tySequence__hRbbzIynOoxrYjHTIKZ3Gw;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content;
typedef struct tyTuple__Oubp8LPEu86EPyDuc56AXg tyTuple__Oubp8LPEu86EPyDuc56AXg;
typedef struct tyObject_NimSeqV2__Wzp3Ap879aFVENQEF8Qbb0A tyObject_NimSeqV2__Wzp3Ap879aFVENQEF8Qbb0A;
typedef struct tyObject_NimSeqPayload__Q9aTbDF780mmiKgw1sfNbag tyObject_NimSeqPayload__Q9aTbDF780mmiKgw1sfNbag;
typedef struct tyObject_Token__pst9a89bCqNyggpo6gRF7jhA tyObject_Token__pst9a89bCqNyggpo6gRF7jhA;
typedef struct tySequence__shxop0zPIs5Ec3k71aCLuQ tySequence__shxop0zPIs5Ec3k71aCLuQ;
typedef struct tySequence__shxop0zPIs5Ec3k71aCLuQ_Content tySequence__shxop0zPIs5Ec3k71aCLuQ_Content;
typedef struct tyObject_NimSeqV2__zpIo9bPR9aKvxkrKqNdODGXQ tyObject_NimSeqV2__zpIo9bPR9aKvxkrKqNdODGXQ;
typedef struct tyObject_NimSeqPayload__A5d1lLxIlLDjDoMqkeDyAA tyObject_NimSeqPayload__A5d1lLxIlLDjDoMqkeDyAA;
typedef struct tyObject_NimSeqV2__rpt17CTZKhcmivfqWPh5Ng tyObject_NimSeqV2__rpt17CTZKhcmivfqWPh5Ng;
typedef struct tyObject_NimSeqPayload__YOjgUJccqS0z21apIzbjhw tyObject_NimSeqPayload__YOjgUJccqS0z21apIzbjhw;
typedef struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ tySequence__7s5HyddQ0f9bxMNILHrXwJQ;
typedef struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content;
typedef struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g tyTuple__kuMQ1fbjJlHtwKTmBGAe6g;
typedef struct tyObject_NimSeqV2__9b8Iun9akN0pmaswXV4xzNHw tyObject_NimSeqV2__9b8Iun9akN0pmaswXV4xzNHw;
typedef struct tyObject_NimSeqPayload__NhGNL7A9cAki9adhGREqHjvQ tyObject_NimSeqPayload__NhGNL7A9cAki9adhGREqHjvQ;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_NimSeqV2__hxkEoe2aqyVy2PvaqyFybw tyObject_NimSeqV2__hxkEoe2aqyVy2PvaqyFybw;
typedef struct tyObject_NimSeqPayload__huYzbmxw1CWqexrcdhCzVQ tyObject_NimSeqPayload__huYzbmxw1CWqexrcdhCzVQ;
typedef struct tySequence__T69aiRC686UsUPVrEM9awLDA tySequence__T69aiRC686UsUPVrEM9awLDA;
typedef struct tySequence__T69aiRC686UsUPVrEM9awLDA_Content tySequence__T69aiRC686UsUPVrEM9awLDA_Content;
typedef struct tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ;
typedef struct tyObject_NimSeqV2__nzRDknQPEQ8tmY6MzxXfBA tyObject_NimSeqV2__nzRDknQPEQ8tmY6MzxXfBA;
typedef struct tyObject_NimSeqPayload__B9ajNKqEmXQfFf759aVJOmDQ tyObject_NimSeqPayload__B9ajNKqEmXQfFf759aVJOmDQ;
typedef struct tyObject_NimSeqV2__xawoyDHERXWhMB61uw9aFlw tyObject_NimSeqV2__xawoyDHERXWhMB61uw9aFlw;
typedef struct tyObject_NimSeqPayload__1F9aVmKGgcmPPhU4J9cqdFeA tyObject_NimSeqPayload__1F9aVmKGgcmPPhU4J9cqdFeA;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_NimSeqV2__zERsha2FLD27xkcyTtUe5w tyObject_NimSeqV2__zERsha2FLD27xkcyTtUe5w;
typedef struct tyObject_NimSeqPayload__4cPHQNh65eNeh02ZwhM4Vw tyObject_NimSeqPayload__4cPHQNh65eNeh02ZwhM4Vw;
typedef struct tyObject_NimSeqV2__wAKcmNV09bNcAakf5YD2A9aQ tyObject_NimSeqV2__wAKcmNV09bNcAakf5YD2A9aQ;
typedef struct tyObject_NimSeqPayload__J4VmartFf3o9c8SALClNLqQ tyObject_NimSeqPayload__J4VmartFf3o9c8SALClNLqQ;
typedef struct tyObject_NimSeqV2__xirGUCq5Yeys036wjTr9a9ag tyObject_NimSeqV2__xirGUCq5Yeys036wjTr9a9ag;
typedef struct tyObject_NimSeqPayload__BvkI5Fb1Dely7cGpGug48w tyObject_NimSeqPayload__BvkI5Fb1Dely7cGpGug48w;
typedef struct tyObject_NimSeqV2__O56sKEP9cSyEFKM0DbntvZg tyObject_NimSeqV2__O56sKEP9cSyEFKM0DbntvZg;
typedef struct tyObject_NimSeqPayload__CNYRHAW35ohZPTfy5ZiwWA tyObject_NimSeqPayload__CNYRHAW35ohZPTfy5ZiwWA;
typedef struct tyObject_NimSeqV2__kwk4E3fMMEr4O39a8w9chcVQ tyObject_NimSeqV2__kwk4E3fMMEr4O39a8w9chcVQ;
typedef struct tyObject_NimSeqPayload__0uKoWoKwrj0zsXW2OSD9crg tyObject_NimSeqPayload__0uKoWoKwrj0zsXW2OSD9crg;
typedef struct tyObject_NimSeqV2__G5wzdngs0i9cLnjn6UUm2QA tyObject_NimSeqV2__G5wzdngs0i9cLnjn6UUm2QA;
typedef struct tyObject_NimSeqPayload__CiPf6Xv05KUQiXqTUxpsUA tyObject_NimSeqPayload__CiPf6Xv05KUQiXqTUxpsUA;
typedef struct tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ;
typedef struct tyObject_NimSeqPayload__XiOLiKIdPX5U0AB70DNjbQ tyObject_NimSeqPayload__XiOLiKIdPX5U0AB70DNjbQ;
typedef struct tyObject_NimSeqV2__d3fv9a69bbApweAbY7myMCAA tyObject_NimSeqV2__d3fv9a69bbApweAbY7myMCAA;
typedef struct tyObject_NimSeqPayload__FxDYcVbzbzqu9bUx3WqGoTA tyObject_NimSeqPayload__FxDYcVbzbzqu9bUx3WqGoTA;
typedef struct tyObject_NimSeqV2__ZAx4OSjx7H2DxJ9ad9avCPsg tyObject_NimSeqV2__ZAx4OSjx7H2DxJ9ad9avCPsg;
typedef struct tyObject_NimSeqPayload__fcGqxIwgjERIIBSj9aK2oxg tyObject_NimSeqPayload__fcGqxIwgjERIIBSj9aK2oxg;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyObject_NimSeqV2__tgxZ7KAKIYkBA1bom1fW8w tyObject_NimSeqV2__tgxZ7KAKIYkBA1bom1fW8w;
typedef struct tyObject_NimSeqPayload__fjZ4qUgOZDh3YOPYb0LHnQ tyObject_NimSeqPayload__fjZ4qUgOZDh3YOPYb0LHnQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyObject_NimSeqV2__q7QzP045gko7DIG9ak9cJjvg tyObject_NimSeqV2__q7QzP045gko7DIG9ak9cJjvg;
typedef struct tyObject_NimSeqPayload__OlXaC6zsBmhDNWsqynhNbw tyObject_NimSeqPayload__OlXaC6zsBmhDNWsqynhNbw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyObject_NimSeqV2__iXDsgW33GmsE2gY9cAOO11Q tyObject_NimSeqV2__iXDsgW33GmsE2gY9cAOO11Q;
typedef struct tyObject_NimSeqPayload__YL9cEzDu8vsXEGN89csSy9crA tyObject_NimSeqPayload__YL9cEzDu8vsXEGN89csSy9crA;
typedef struct tyObject_NimSeqV2__dCwFm7iJYKqQeZSIzKc0NA tyObject_NimSeqV2__dCwFm7iJYKqQeZSIzKc0NA;
typedef struct tyObject_NimSeqPayload__mZuhNjviDK9b79bNVotwlwcw tyObject_NimSeqPayload__mZuhNjviDK9b79bNVotwlwcw;
typedef struct tyObject_NimSeqV2__gIwHLNdjfH4VRWhXpHypGA tyObject_NimSeqV2__gIwHLNdjfH4VRWhXpHypGA;
typedef struct tyObject_NimSeqPayload__5Z9a9aROEoDZcGRpcSYezyFg tyObject_NimSeqPayload__5Z9a9aROEoDZcGRpcSYezyFg;
typedef struct tyObject_NimSeqV2__15maDR19bknK34amedd1PnQ tyObject_NimSeqV2__15maDR19bknK34amedd1PnQ;
typedef struct tyObject_NimSeqPayload__iyj5NYk2cU9bjed29aLoecBQ tyObject_NimSeqPayload__iyj5NYk2cU9bjed29aLoecBQ;
typedef struct tyObject_NimSeqV2__eg19cQLnrM6yvo2xbN7Qm4g tyObject_NimSeqV2__eg19cQLnrM6yvo2xbN7Qm4g;
typedef struct tyObject_NimSeqPayload__3YPQ2gT1hEEt9cWshv20sYQ tyObject_NimSeqPayload__3YPQ2gT1hEEt9cWshv20sYQ;
typedef struct tyObject_NimSeqV2__5K6YMLUzOBOQi9cm4I2oc9bg tyObject_NimSeqV2__5K6YMLUzOBOQi9cm4I2oc9bg;
typedef struct tyObject_NimSeqPayload__u70jg4Sy9boIjAjNPaPSu6A tyObject_NimSeqPayload__u70jg4Sy9boIjAjNPaPSu6A;
typedef struct tyObject_NimSeqV2__7j9aCEhtB2gWiMpaLpLmDAA tyObject_NimSeqV2__7j9aCEhtB2gWiMpaLpLmDAA;
typedef struct tyObject_NimSeqPayload__O4qEUBsg9a9aB9bssXf66dmrA tyObject_NimSeqPayload__O4qEUBsg9a9aB9bssXf66dmrA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyObject_NimSeqV2__ofH9blJDuzy7lLp0Nu79aa9cQ tyObject_NimSeqV2__ofH9blJDuzy7lLp0Nu79aa9cQ;
typedef struct tyObject_NimSeqPayload__OzmveoJODUPJyabeUsARrg tyObject_NimSeqPayload__OzmveoJODUPJyabeUsARrg;
typedef struct tyObject_NimSeqV2__EnGyyCL9bP9bBkJIIw130JcA tyObject_NimSeqV2__EnGyyCL9bP9bBkJIIw130JcA;
typedef struct tyObject_NimSeqPayload__xJHATr8XqGiTUvmTQdd1YA tyObject_NimSeqPayload__xJHATr8XqGiTUvmTQdd1YA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyObject_NimSeqV2__8dnVBQrNdN4aYbHrPCeE8Q tyObject_NimSeqV2__8dnVBQrNdN4aYbHrPCeE8Q;
typedef struct tyObject_NimSeqPayload__OkEdEJcYExex9clzIWp3Fcw tyObject_NimSeqPayload__OkEdEJcYExex9clzIWp3Fcw;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyObject_NimSeqV2__whT1ft59bR5HcNlwxW9a1Sqw tyObject_NimSeqV2__whT1ft59bR5HcNlwxW9a1Sqw;
typedef struct tyObject_NimSeqPayload__wPuxrD4t1tdh9aWvKqI6vgg tyObject_NimSeqPayload__wPuxrD4t1tdh9aWvKqI6vgg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_NimSeqV2__pxiTcguNzAbu0Rv0PQ7RSQ tyObject_NimSeqV2__pxiTcguNzAbu0Rv0PQ7RSQ;
typedef struct tyObject_NimSeqPayload__3xRBpaE09cNEWepSBJ3qPrA tyObject_NimSeqPayload__3xRBpaE09cNEWepSBJ3qPrA;
typedef struct tyObject_NimSeqV2__bvyB5GGuyrRUoSB3KTNeag tyObject_NimSeqV2__bvyB5GGuyrRUoSB3KTNeag;
typedef struct tyObject_NimSeqPayload__L1t9aLhHZkDv9c4TR4CmTx4A tyObject_NimSeqPayload__L1t9aLhHZkDv9c4TR4CmTx4A;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A tySequence__4zAALtm0xUbRlYWQ2V8K7A;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content;
typedef struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA tySequence__lAikaRQvUF0uwNAz0U4FFA;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content tySequence__lAikaRQvUF0uwNAz0U4FFA_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_NimSeqV2__9aXnq9c5fz5Q0hbWElxyLjIg tyObject_NimSeqV2__9aXnq9c5fz5Q0hbWElxyLjIg;
typedef struct tyObject_NimSeqPayload__ZnfNx9cWQ79bKoiGpbxeUZ2w tyObject_NimSeqPayload__ZnfNx9cWQ79bKoiGpbxeUZ2w;
typedef struct tyObject_NimSeqV2__C0nzvajqtOMam85eM9bZNSg tyObject_NimSeqV2__C0nzvajqtOMam85eM9bZNSg;
typedef struct tyObject_NimSeqPayload__pOgCdk2AGTA5dRpCuIyXLw tyObject_NimSeqPayload__pOgCdk2AGTA5dRpCuIyXLw;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_NimSeqV2__fIXSsXmSNpJjT79aD9b4Wj0Q tyObject_NimSeqV2__fIXSsXmSNpJjT79aD9b4Wj0Q;
typedef struct tyObject_NimSeqPayload__AtCLKjq0LXyy7Wjf5A3iug tyObject_NimSeqPayload__AtCLKjq0LXyy7Wjf5A3iug;
typedef struct tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw;
typedef struct tySequence__s3NGK5xFNK6fPmXupxoolA tySequence__s3NGK5xFNK6fPmXupxoolA;
typedef struct tySequence__s3NGK5xFNK6fPmXupxoolA_Content tySequence__s3NGK5xFNK6fPmXupxoolA_Content;
typedef struct tyObject_NimSeqV2__b1hMoRB6FiMpAnxWZ6XFFw tyObject_NimSeqV2__b1hMoRB6FiMpAnxWZ6XFFw;
typedef struct tyObject_NimSeqPayload__JA074cUO4pLwgRHNarz1Ag tyObject_NimSeqPayload__JA074cUO4pLwgRHNarz1Ag;
typedef struct tyTuple__pX68bRYqY0ZF09cQ4s0LV9ag tyTuple__pX68bRYqY0ZF09cQ4s0LV9ag;
typedef struct tyTuple__FFspgHRWev9aDuj0fEpj9bUw tyTuple__FFspgHRWev9aDuj0fEpj9bUw;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ tySequence__7OXYQ6bHRkhJpRaiS7kiwQ;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content;
typedef struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg;
typedef struct tyObject_NimSeqV2__e19bLuPKJ5Taf2cU0C9c19amQ tyObject_NimSeqV2__e19bLuPKJ5Taf2cU0C9c19amQ;
typedef struct tyObject_NimSeqPayload__e9cx23BcmptS0R3g2j9cm8Ww tyObject_NimSeqPayload__e9cx23BcmptS0R3g2j9cm8Ww;
typedef struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw tySequence__ZUeR9b415wicThQ9cBWO9aYMw;
typedef struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content;
typedef struct tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A;
typedef struct tyObject_NimSeqV2__9bDdnwys3VzDJxw8wpw9aO7Q tyObject_NimSeqV2__9bDdnwys3VzDJxw8wpw9aO7Q;
typedef struct tyObject_NimSeqPayload__7jYcYku9aPa9cFZyhvKlw7MA tyObject_NimSeqPayload__7jYcYku9aPa9cFZyhvKlw7MA;
typedef struct tyObject_NimSeqV2__Ny5DgIVnJhWFNrwCKmbRfg tyObject_NimSeqV2__Ny5DgIVnJhWFNrwCKmbRfg;
typedef struct tyObject_NimSeqPayload__GaXw4OGVqFVkcJL41FVa2w tyObject_NimSeqPayload__GaXw4OGVqFVkcJL41FVa2w;
typedef struct tySequence__8Np6tlClE5az1CyqZdN19bQ tySequence__8Np6tlClE5az1CyqZdN19bQ;
typedef struct tySequence__8Np6tlClE5az1CyqZdN19bQ_Content tySequence__8Np6tlClE5az1CyqZdN19bQ_Content;
typedef struct tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q;
typedef struct tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_NimSeqV2__zIWP3GSgEW4HknsQ2JyF0Q tyObject_NimSeqV2__zIWP3GSgEW4HknsQ2JyF0Q;
typedef struct tyObject_NimSeqPayload__tvrm3bhXgSCURMsqnwLaHg tyObject_NimSeqPayload__tvrm3bhXgSCURMsqnwLaHg;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_NimSeqV2__cULPdsW0S5F0FBVWVpLANw tyObject_NimSeqV2__cULPdsW0S5F0FBVWVpLANw;
typedef struct tyObject_NimSeqPayload__9bmCK9aZILR9aqHJtn8GZl3zw tyObject_NimSeqPayload__9bmCK9aZILR9aqHJtn8GZl3zw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tyObject_NimSeqV2__t9bcqkWC9bif6Sx19bvRvfOKQ tyObject_NimSeqV2__t9bcqkWC9bif6Sx19bvRvfOKQ;
typedef struct tyObject_NimSeqPayload__Ng0bSFZhIo7fHn3Ribr6KQ tyObject_NimSeqPayload__Ng0bSFZhIo7fHn3Ribr6KQ;
typedef struct tySequence__G9cHmkmNmy6ZlkFfXcex3Hw tySequence__G9cHmkmNmy6ZlkFfXcex3Hw;
typedef struct tySequence__G9cHmkmNmy6ZlkFfXcex3Hw_Content tySequence__G9cHmkmNmy6ZlkFfXcex3Hw_Content;
typedef struct tyObject_NimSeqV2__gU0kQm69bws9bBab8H9cxj9akg tyObject_NimSeqV2__gU0kQm69bws9bBab8H9cxj9akg;
typedef struct tyObject_NimSeqPayload__h0EbKk00w6nXOIL0qL7dfw tyObject_NimSeqPayload__h0EbKk00w6nXOIL0qL7dfw;
typedef struct tyTuple__9ay7GjiPeMMFnmoYwk84apw tyTuple__9ay7GjiPeMMFnmoYwk84apw;
typedef struct tyTuple__JqV0huqZNAHtnE3agKOyZg tyTuple__JqV0huqZNAHtnE3agKOyZg;
typedef struct tySequence__GVxMaHC0xtgqjBZ8ubUwnA tySequence__GVxMaHC0xtgqjBZ8ubUwnA;
typedef struct tySequence__GVxMaHC0xtgqjBZ8ubUwnA_Content tySequence__GVxMaHC0xtgqjBZ8ubUwnA_Content;
typedef struct tyTuple__7SDQCf3TbPJf09bOXiapRgg tyTuple__7SDQCf3TbPJf09bOXiapRgg;
typedef struct tyObject_NimSeqV2__S1I41Ls1uuN23lNHHgFiYg tyObject_NimSeqV2__S1I41Ls1uuN23lNHHgFiYg;
typedef struct tyObject_NimSeqPayload__bJWoXcrO5IwDRDKMBghkbQ tyObject_NimSeqPayload__bJWoXcrO5IwDRDKMBghkbQ;
typedef struct tySequence__3rs2HI7A9bn1iHmZchCo1lg tySequence__3rs2HI7A9bn1iHmZchCo1lg;
typedef struct tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content;
typedef struct tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ;
typedef struct tyObject_NimSeqV2__QMj9cx3xUjX4pjRwTn9bDNzA tyObject_NimSeqV2__QMj9cx3xUjX4pjRwTn9bDNzA;
typedef struct tyObject_NimSeqPayload__dYf6sGrYd9byl9b8o9cXNn7cA tyObject_NimSeqPayload__dYf6sGrYd9byl9b8o9cXNn7cA;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q tySequence__tsHRsYLyvTCPLlGRExqi7Q;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content;
typedef struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg;
typedef struct tyObject_NimSeqV2__ZBXm7zuh6K0BF7EzvKbK7A tyObject_NimSeqV2__ZBXm7zuh6K0BF7EzvKbK7A;
typedef struct tyObject_NimSeqPayload__sqb841zyAWqdT69cCiVqhTg tyObject_NimSeqPayload__sqb841zyAWqdT69cCiVqhTg;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA tySequence__9bffTLF0HkxjFCzZL8og4GA;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content tySequence__9bffTLF0HkxjFCzZL8og4GA_Content;
typedef struct tyTuple__09aD69az7aYn14Gt61AHvLIA tyTuple__09aD69az7aYn14Gt61AHvLIA;
typedef struct tyObject_NimSeqV2__TPbyeV159aGPhQnGwOLv0sQ tyObject_NimSeqV2__TPbyeV159aGPhQnGwOLv0sQ;
typedef struct tyObject_NimSeqPayload__ejG43mfy2bZkAMGFTFM36Q tyObject_NimSeqPayload__ejG43mfy2bZkAMGFTFM36Q;
typedef struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ;
typedef struct tyObject_NimSeqV2__nIHI3lsoB9bBOORuoqOEj7g tyObject_NimSeqV2__nIHI3lsoB9bBOORuoqOEj7g;
typedef struct tyObject_NimSeqPayload__cNjQz1l4yr2UupmtFlt9b9aw tyObject_NimSeqPayload__cNjQz1l4yr2UupmtFlt9b9aw;
typedef struct tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ;
typedef struct tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ_Content tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ_Content;
typedef struct tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q;
typedef struct tyObject_NimSeqV2__VMGr7rbYO7pG7IK2TH9bz7A tyObject_NimSeqV2__VMGr7rbYO7pG7IK2TH9bz7A;
typedef struct tyObject_NimSeqPayload__sdH682KR9csVt7Lylj9aZ3vQ tyObject_NimSeqPayload__sdH682KR9csVt7Lylj9aZ3vQ;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tyObject_NimSeqV2__U11gVpqEuLiRu2f9bIfVRAA tyObject_NimSeqV2__U11gVpqEuLiRu2f9bIfVRAA;
typedef struct tyObject_NimSeqPayload__dDeJTSez5oo0HoO8Ee9cXRw tyObject_NimSeqPayload__dDeJTSez5oo0HoO8Ee9cXRw;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tyObject_NimSeqV2__M1TtJBuzN40ZSG9a8yOFJFw tyObject_NimSeqV2__M1TtJBuzN40ZSG9a8yOFJFw;
typedef struct tyObject_NimSeqPayload__B9b0oZGG5UQ5nkTLq9c9ajIag tyObject_NimSeqPayload__B9b0oZGG5UQ5nkTLq9c9ajIag;
typedef struct tyObject_NimSeqV2__9bQvx9cUUKun9bKhPG2a9bQj6Q tyObject_NimSeqV2__9bQvx9cUUKun9bKhPG2a9bQj6Q;
typedef struct tyObject_NimSeqPayload__0fSGlyKGHqXGdDH314aZKg tyObject_NimSeqPayload__0fSGlyKGHqXGdDH314aZKg;
typedef struct tyObject_NimSeqV2__9aK7YX9bxlc8s2KV3wh8rdkA tyObject_NimSeqV2__9aK7YX9bxlc8s2KV3wh8rdkA;
typedef struct tyObject_NimSeqPayload__5cCooviSXLEf9cwx1D5qZiA tyObject_NimSeqPayload__5cCooviSXLEf9cwx1D5qZiA;
typedef struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA;
typedef struct tyObject_NimSeqV2__bnJ5Yqhi12rJFQll9a29bK9aA tyObject_NimSeqV2__bnJ5Yqhi12rJFQll9a29bK9aA;
typedef struct tyObject_NimSeqPayload__zg0c9cy2kBgbyKYkekGNBUw tyObject_NimSeqPayload__zg0c9cy2kBgbyKYkekGNBUw;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA tySequence__TEgqV1E9aHqnwBUoeXjBI9aA;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content;
typedef struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg;
typedef struct tySequence__b9bG03Q6unwlMU0dM7uOPIA tySequence__b9bG03Q6unwlMU0dM7uOPIA;
typedef struct tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content;
typedef struct tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA tySequence__TLbZ2GqL3Zio1f8bNpj2NA;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyObject_NimSeqV2__qpKiDXWu1sjqjH7dOqAHZg tyObject_NimSeqV2__qpKiDXWu1sjqjH7dOqAHZg;
typedef struct tyObject_NimSeqPayload__nJDGOm2EjMPf1emtsI5R8Q tyObject_NimSeqPayload__nJDGOm2EjMPf1emtsI5R8Q;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w tySequence__GH1mmNKNA2QP4n1tnxJf1w;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content;
typedef struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ;
typedef struct tyObject_NimSeqV2__ZymipdgL8Pm9bmfGa9cwYJiQ tyObject_NimSeqV2__ZymipdgL8Pm9bmfGa9cwYJiQ;
typedef struct tyObject_NimSeqPayload__2Cej9bEoiMQ2LZffLyml1CQ tyObject_NimSeqPayload__2Cej9bEoiMQ2LZffLyml1CQ;
typedef struct tyObject_NimSeqV2__dAgwP2JJ1PDwPMpu9bzwC0w tyObject_NimSeqV2__dAgwP2JJ1PDwPMpu9bzwC0w;
typedef struct tyObject_NimSeqPayload__6xdpt2WgX9aW6Q639cRU5Rzw tyObject_NimSeqPayload__6xdpt2WgX9aW6Q639cRU5Rzw;
typedef struct tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ tySequence__6H5Oh5UUvVCLiakt9aTwtUQ;
typedef struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content;
typedef struct tyObject_NimSeqV2__HCcpPoYfekFJRNu9c9bYZ9bsQ tyObject_NimSeqV2__HCcpPoYfekFJRNu9c9bYZ9bsQ;
typedef struct tyObject_NimSeqPayload__6sY7wgvPGYvtAbG0tdSxiw tyObject_NimSeqPayload__6sY7wgvPGYvtAbG0tdSxiw;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q tySequence__4eQHGndY6XBYpFOH09apV8Q;
typedef struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content tySequence__4eQHGndY6XBYpFOH09apV8Q_Content;
typedef struct tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA;
typedef struct tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw;
typedef struct tySequence__e9ciFfeAg1p88UzCBnAPeVQ tySequence__e9ciFfeAg1p88UzCBnAPeVQ;
typedef struct tySequence__e9ciFfeAg1p88UzCBnAPeVQ_Content tySequence__e9ciFfeAg1p88UzCBnAPeVQ_Content;
typedef struct tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg;
typedef struct tyObject_NimSeqV2__Zsjz8m9cC0NIjfk437Kkqag tyObject_NimSeqV2__Zsjz8m9cC0NIjfk437Kkqag;
typedef struct tyObject_NimSeqPayload__Wh3Dn4q89bjoiLSTUCUOTew tyObject_NimSeqPayload__Wh3Dn4q89bjoiLSTUCUOTew;
typedef struct tySequence__GyTgETkn69b26Etj2zBgjMw tySequence__GyTgETkn69b26Etj2zBgjMw;
typedef struct tySequence__GyTgETkn69b26Etj2zBgjMw_Content tySequence__GyTgETkn69b26Etj2zBgjMw_Content;
typedef struct tyObject_NimSeqV2__sXtLBbV79ah32PP02mMBiTQ tyObject_NimSeqV2__sXtLBbV79ah32PP02mMBiTQ;
typedef struct tyObject_NimSeqPayload__Ijs8YZfDA75rhEW1XeXk2w tyObject_NimSeqPayload__Ijs8YZfDA75rhEW1XeXk2w;
typedef struct tyObject_NimSeqV2__diajJmNo8grsMWW9cZq9bErQ tyObject_NimSeqV2__diajJmNo8grsMWW9cZq9bErQ;
typedef struct tyObject_NimSeqPayload__GkrJrbi1Vf8NOdxV9aOX4vA tyObject_NimSeqPayload__GkrJrbi1Vf8NOdxV9aOX4vA;
typedef struct tyObject_NimSeqV2__y9bG85c5b3IiBNTnDEhDeCQ tyObject_NimSeqV2__y9bG85c5b3IiBNTnDEhDeCQ;
typedef struct tyObject_NimSeqPayload__8VWGiLi1AaEJ9bSMNLWx3Vw tyObject_NimSeqPayload__8VWGiLi1AaEJ9bSMNLWx3Vw;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q tySequence__Fc8Q26tsngy2yxcpyrnT4Q;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content;
typedef struct tyObject_NimSeqV2__J80ntPleGVJXp9bYXSkOm4g tyObject_NimSeqV2__J80ntPleGVJXp9bYXSkOm4g;
typedef struct tyObject_NimSeqPayload__OuLlEOw03e2DVzzSxes2OQ tyObject_NimSeqPayload__OuLlEOw03e2DVzzSxes2OQ;
typedef struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g tyTuple__y6bKAf9a9aaVwun6lVDxSX7g;
typedef struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg;
typedef struct tySequence__mnb4N9bRCddoL53waHA7kHQ tySequence__mnb4N9bRCddoL53waHA7kHQ;
typedef struct tySequence__mnb4N9bRCddoL53waHA7kHQ_Content tySequence__mnb4N9bRCddoL53waHA7kHQ_Content;
typedef struct tyTuple__bxYrf1dnwYK6GanDNddhgQ tyTuple__bxYrf1dnwYK6GanDNddhgQ;
typedef struct tyObject_NimSeqV2__o4fdV7x241MdiPUXNS1Raw tyObject_NimSeqV2__o4fdV7x241MdiPUXNS1Raw;
typedef struct tyObject_NimSeqPayload__S9csvyUBElFwh9cdA9bfA79bNA tyObject_NimSeqPayload__S9csvyUBElFwh9cdA9bfA79bNA;
typedef struct tySequence__R1mQMFmsdp1ChoJDXa9a0xQ tySequence__R1mQMFmsdp1ChoJDXa9a0xQ;
typedef struct tySequence__R1mQMFmsdp1ChoJDXa9a0xQ_Content tySequence__R1mQMFmsdp1ChoJDXa9a0xQ_Content;
typedef struct tyTuple__rczUtx07rG4YmHOEmcEUJw tyTuple__rczUtx07rG4YmHOEmcEUJw;
typedef struct tyObject_NimSeqV2__Lzxy9cA5Rb33mtr2JHP9brzg tyObject_NimSeqV2__Lzxy9cA5Rb33mtr2JHP9brzg;
typedef struct tyObject_NimSeqPayload__b9bbw4QVkyKerVSGwvbdccQ tyObject_NimSeqPayload__b9bbw4QVkyKerVSGwvbdccQ;
typedef struct tySequence__tt8kXsbz31MUMFUF6Q9aQuQ tySequence__tt8kXsbz31MUMFUF6Q9aQuQ;
typedef struct tySequence__tt8kXsbz31MUMFUF6Q9aQuQ_Content tySequence__tt8kXsbz31MUMFUF6Q9aQuQ_Content;
typedef struct tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg;
typedef struct tyObject_NimSeqV2__0LodDvQr7DY8VoMTmn0gQQ tyObject_NimSeqV2__0LodDvQr7DY8VoMTmn0gQQ;
typedef struct tyObject_NimSeqPayload__oi8YBrQ80CA2zAfCI7jsQA tyObject_NimSeqPayload__oi8YBrQ80CA2zAfCI7jsQA;
typedef struct tySequence__kQFByJmZecfF9a1LYqz7zYg tySequence__kQFByJmZecfF9a1LYqz7zYg;
typedef struct tySequence__kQFByJmZecfF9a1LYqz7zYg_Content tySequence__kQFByJmZecfF9a1LYqz7zYg_Content;
typedef struct tyObject_State__HKH8xQquLWVVc5hqriE25Q tyObject_State__HKH8xQquLWVVc5hqriE25Q;
typedef struct tyObject_NimSeqV2__lC1hOTcTO87hw9bWuOAbM2g tyObject_NimSeqV2__lC1hOTcTO87hw9bWuOAbM2g;
typedef struct tyObject_NimSeqPayload__k8khOtl7aYqusxo9bGR3rQA tyObject_NimSeqPayload__k8khOtl7aYqusxo9bGR3rQA;
typedef struct tySequence__kP47rw9c8bgVA53QKWe9bp7g tySequence__kP47rw9c8bgVA53QKWe9bp7g;
typedef struct tySequence__kP47rw9c8bgVA53QKWe9bp7g_Content tySequence__kP47rw9c8bgVA53QKWe9bp7g_Content;
typedef struct tyObject_NimSeqV2__aKUzzy2BRdkBxUZZR9bCG8w tyObject_NimSeqV2__aKUzzy2BRdkBxUZZR9bCG8w;
typedef struct tyObject_NimSeqPayload__9bmbJLvM9bUDGfEL9aJJFJ2gg tyObject_NimSeqPayload__9bmbJLvM9bUDGfEL9aJJFJ2gg;
typedef struct tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw;
typedef struct tySequence__qff4v1r3n1JKmy1NzJOChA tySequence__qff4v1r3n1JKmy1NzJOChA;
typedef struct tySequence__qff4v1r3n1JKmy1NzJOChA_Content tySequence__qff4v1r3n1JKmy1NzJOChA_Content;
typedef struct tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw;
typedef struct tyObject_NimSeqV2__JeoY27Pa9c4R0cGDrOzzfuw tyObject_NimSeqV2__JeoY27Pa9c4R0cGDrOzzfuw;
typedef struct tyObject_NimSeqPayload__u09cKovRhfBEvwzI8DLG51A tyObject_NimSeqPayload__u09cKovRhfBEvwzI8DLG51A;
typedef struct tySequence__grdS5PdBBxkq9bxi4lFAdAw tySequence__grdS5PdBBxkq9bxi4lFAdAw;
typedef struct tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content;
typedef struct tyObject_NimSeqV2__Vd5JoD8wWcbD6k2tc9b28YA tyObject_NimSeqV2__Vd5JoD8wWcbD6k2tc9b28YA;
typedef struct tyObject_NimSeqPayload__zIcZNLCZJO9bK3dKATuA4aA tyObject_NimSeqPayload__zIcZNLCZJO9bK3dKATuA4aA;
typedef struct tyTuple__9ap1MJ9bVBlP34AqrUq01n8w tyTuple__9ap1MJ9bVBlP34AqrUq01n8w;
typedef struct tyObject_NimSeqV2__SV7rrCQn9cRoWKHTGChlSgg tyObject_NimSeqV2__SV7rrCQn9cRoWKHTGChlSgg;
typedef struct tyObject_NimSeqPayload__YkZ78cEwLiT49csnUl1ZM7Q tyObject_NimSeqPayload__YkZ78cEwLiT49csnUl1ZM7Q;
typedef struct tyObject_NimSeqV2__IKAN89cMTsMj9cqIMW3TeGDQ tyObject_NimSeqV2__IKAN89cMTsMj9cqIMW3TeGDQ;
typedef struct tyObject_NimSeqPayload__ny1pnHdrVxdJu0cxGMS9cUA tyObject_NimSeqPayload__ny1pnHdrVxdJu0cxGMS9cUA;
typedef struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA tySequence__9c9aWmheGsuf9aHtY7gTnUcPA;
typedef struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content;
typedef struct tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A;
typedef struct tyObject_NimSeqV2__RKcuYGEqMOT1amULBWqJ5w tyObject_NimSeqV2__RKcuYGEqMOT1amULBWqJ5w;
typedef struct tyObject_NimSeqPayload__PS0QbMt2xGKSjAh0h609cSw tyObject_NimSeqPayload__PS0QbMt2xGKSjAh0h609cSw;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw tySequence__fnH5Zt4fsGx0AgDTOw8pKw;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content;
typedef struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ;
typedef struct tyObject_NimSeqV2__rxauo4ztHD3oKCBNw6YZdQ tyObject_NimSeqV2__rxauo4ztHD3oKCBNw6YZdQ;
typedef struct tyObject_NimSeqPayload__Npgmi4jcd6ILOol9cT13nsA tyObject_NimSeqPayload__Npgmi4jcd6ILOol9cT13nsA;
typedef struct tySequence__hMc5eJjVGjq6i857yHjTtg tySequence__hMc5eJjVGjq6i857yHjTtg;
typedef struct tySequence__hMc5eJjVGjq6i857yHjTtg_Content tySequence__hMc5eJjVGjq6i857yHjTtg_Content;
typedef struct tyTuple__Wipq1508vNWp3jwczem6TQ tyTuple__Wipq1508vNWp3jwczem6TQ;
typedef struct tyObject_NimSeqV2__8Rn9aEpI9bjowSiva9cw60GCA tyObject_NimSeqV2__8Rn9aEpI9bjowSiva9cw60GCA;
typedef struct tyObject_NimSeqPayload__EFYfInpTvq5UuayU59c5baw tyObject_NimSeqPayload__EFYfInpTvq5UuayU59c5baw;
typedef struct tyObject_NimSeqV2__ynMyB4FKj1HYwsLlDC7vBw tyObject_NimSeqV2__ynMyB4FKj1HYwsLlDC7vBw;
typedef struct tyObject_NimSeqPayload__IucIGHa7Bf2A1RksuF5C6A tyObject_NimSeqPayload__IucIGHa7Bf2A1RksuF5C6A;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyObject_NimSeqV2__FfnYizxy8EW3T73hRy9bWzQ tyObject_NimSeqV2__FfnYizxy8EW3T73hRy9bWzQ;
typedef struct tyObject_NimSeqPayload__1RCWgTQyEDGzZv39a0L0udg tyObject_NimSeqPayload__1RCWgTQyEDGzZv39a0L0udg;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyObject_NimSeqV2__2xPIecK5aI1kPl45dNVVfg tyObject_NimSeqV2__2xPIecK5aI1kPl45dNVVfg;
typedef struct tyObject_NimSeqPayload__Wj9bKru2STjGwpTlwyUrEVA tyObject_NimSeqPayload__Wj9bKru2STjGwpTlwyUrEVA;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_NimSeqV2__P3nKlTxWcYJ29bn9aOCrEnFQ tyObject_NimSeqV2__P3nKlTxWcYJ29bn9aOCrEnFQ;
typedef struct tyObject_NimSeqPayload__qPCxF3TEe9c5GUYvcQEpaFw tyObject_NimSeqPayload__qPCxF3TEe9c5GUYvcQEpaFw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tyObject_NimSeqV2__h3xmmlVt9cH1Qr9a6iHd7FGw tyObject_NimSeqV2__h3xmmlVt9cH1Qr9a6iHd7FGw;
typedef struct tyObject_NimSeqPayload__rXin5DrZ8p5RYP2zMTAsqg tyObject_NimSeqPayload__rXin5DrZ8p5RYP2zMTAsqg;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_NimSeqV2__TFl78m7ywyQTyT4zs389bvg tyObject_NimSeqV2__TFl78m7ywyQTyT4zs389bvg;
typedef struct tyObject_NimSeqPayload__6YewsLaF0A0PiS3nEaN55g tyObject_NimSeqPayload__6YewsLaF0A0PiS3nEaN55g;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyObject_NimSeqV2__WKgwRMN0CacAqOQYQOKBLA tyObject_NimSeqV2__WKgwRMN0CacAqOQYQOKBLA;
typedef struct tyObject_NimSeqPayload__a9auZ41pjiQ5WdoFl1yp8cQ tyObject_NimSeqPayload__a9auZ41pjiQ5WdoFl1yp8cQ;
typedef struct tySequence__9bnh9aVmYtKU19btQYqjGktpw tySequence__9bnh9aVmYtKU19btQYqjGktpw;
typedef struct tySequence__9bnh9aVmYtKU19btQYqjGktpw_Content tySequence__9bnh9aVmYtKU19btQYqjGktpw_Content;
typedef struct tyObject_CandidateError__f049c8Bs49cqj6FTSrUbSmlw tyObject_CandidateError__f049c8Bs49cqj6FTSrUbSmlw;
typedef struct tyObject_NimSeqV2__dA1wyhF6YAalw2FgXpZhDA tyObject_NimSeqV2__dA1wyhF6YAalw2FgXpZhDA;
typedef struct tyObject_NimSeqPayload__9cpmPeVfo2tmpvqIDmFkCqg tyObject_NimSeqPayload__9cpmPeVfo2tmpvqIDmFkCqg;
typedef struct tyObject_MismatchInfo__cZtjSeBU42Tc8gk2KTbArg tyObject_MismatchInfo__cZtjSeBU42Tc8gk2KTbArg;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content tySequence__E8pi9b5QNahsURYzXMjh3qw_Content;
typedef struct tyObject_NimSeqV2__sc8fuyIvxojcmS9bBvqLxng tyObject_NimSeqV2__sc8fuyIvxojcmS9bBvqLxng;
typedef struct tyObject_NimSeqPayload__B8Tj3xNm54sxzmyOvDK9buw tyObject_NimSeqPayload__B8Tj3xNm54sxzmyOvDK9buw;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ tySequence__KYLoGmc5aaHsSDjEH1FTxQ;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content;
typedef struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ;
typedef struct tyObject_NimSeqV2__Bu9cf9czC9bYB6tHrNlJa7NEw tyObject_NimSeqV2__Bu9cf9czC9bYB6tHrNlJa7NEw;
typedef struct tyObject_NimSeqPayload__i8t2GAhLNb8T7aVoeBs9coQ tyObject_NimSeqPayload__i8t2GAhLNb8T7aVoeBs9coQ;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w tySequence__3B6hFqG0Do0FxDvnNucL7w;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content tySequence__3B6hFqG0Do0FxDvnNucL7w_Content;
typedef struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw;
typedef struct tyObject_NimSeqV2__I17vTDmIw29a0CEB70d9cORg tyObject_NimSeqV2__I17vTDmIw29a0CEB70d9cORg;
typedef struct tyObject_NimSeqPayload__x9aM4VUlFe9b5WPkSKx1M5xw tyObject_NimSeqPayload__x9aM4VUlFe9b5WPkSKx1M5xw;
typedef struct tySequence__cLt1WK9c8DYlNqjYIVmv5sQ tySequence__cLt1WK9c8DYlNqjYIVmv5sQ;
typedef struct tySequence__cLt1WK9c8DYlNqjYIVmv5sQ_Content tySequence__cLt1WK9c8DYlNqjYIVmv5sQ_Content;
typedef struct tyTuple__c0qUCL3KxsVjGYwcv7lQbg tyTuple__c0qUCL3KxsVjGYwcv7lQbg;
typedef struct tyObject_NimSeqV2__RtCW0qtva9cK9bFzmU7PMOLg tyObject_NimSeqV2__RtCW0qtva9cK9bFzmU7PMOLg;
typedef struct tyObject_NimSeqPayload__rpimNUpF6ccwA7ypdSrQWw tyObject_NimSeqPayload__rpimNUpF6ccwA7ypdSrQWw;
typedef struct tySequence__bdNIx7Bah2llfuqeoTJEWQ tySequence__bdNIx7Bah2llfuqeoTJEWQ;
typedef struct tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content;
typedef struct tyTuple__kIcKc1aSJCixG4QCidyBAg tyTuple__kIcKc1aSJCixG4QCidyBAg;
typedef struct tyObject_NimSeqV2__dURlRCOu2lYEvQwyIoAgZA tyObject_NimSeqV2__dURlRCOu2lYEvQwyIoAgZA;
typedef struct tyObject_NimSeqPayload__QJ6YtTltEHLQKSZzLY9bfhw tyObject_NimSeqPayload__QJ6YtTltEHLQKSZzLY9bfhw;
typedef struct tySequence__Cw89anHgi6Xla7dgB7Unvmw tySequence__Cw89anHgi6Xla7dgB7Unvmw;
typedef struct tySequence__Cw89anHgi6Xla7dgB7Unvmw_Content tySequence__Cw89anHgi6Xla7dgB7Unvmw_Content;
typedef struct tyObject_NimSeqV2__XHKiD6lzOPT9aB4caeVEgLQ tyObject_NimSeqV2__XHKiD6lzOPT9aB4caeVEgLQ;
typedef struct tyObject_NimSeqPayload__kkWZaAriZFdnsJD9c6W9cA9cg tyObject_NimSeqPayload__kkWZaAriZFdnsJD9c6W9cA9cg;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyObject_NimSeqV2__GQxVYv6jCApzJGKP0DuOLw tyObject_NimSeqV2__GQxVYv6jCApzJGKP0DuOLw;
typedef struct tyObject_NimSeqPayload__Mei9cQiRsNTTJpKxjce4tmw tyObject_NimSeqPayload__Mei9cQiRsNTTJpKxjce4tmw;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
typedef struct tyObject_NimSeqV2__jk36KpuK5gnIkJBaojY7cw tyObject_NimSeqV2__jk36KpuK5gnIkJBaojY7cw;
typedef struct tyObject_NimSeqPayload__p3jFcjgXmywN1ZHZWKfD1g tyObject_NimSeqPayload__p3jFcjgXmywN1ZHZWKfD1g;
typedef struct tySequence__SyrQ8FqS1U0ZKpu8mJO6PQ tySequence__SyrQ8FqS1U0ZKpu8mJO6PQ;
typedef struct tySequence__SyrQ8FqS1U0ZKpu8mJO6PQ_Content tySequence__SyrQ8FqS1U0ZKpu8mJO6PQ_Content;
typedef struct tyObject_VarIndex__xDnEx9cq41ypm0l6yI8haPg tyObject_VarIndex__xDnEx9cq41ypm0l6yI8haPg;
typedef struct tyObject_NimSeqV2__w3p9aOA1mt9c9aAlQDg0rXtcA tyObject_NimSeqV2__w3p9aOA1mt9c9aAlQDg0rXtcA;
typedef struct tyObject_NimSeqPayload__N3A0BvLnhreSPuUndSdBQg tyObject_NimSeqPayload__N3A0BvLnhreSPuUndSdBQg;
typedef struct tyObject_Connection__msVk44inLNF9bGoW0TwTG0Q tyObject_Connection__msVk44inLNF9bGoW0TwTG0Q;
typedef struct tySequence__9aee2Loc4nE9bvjjGuhsI78w tySequence__9aee2Loc4nE9bvjjGuhsI78w;
typedef struct tySequence__9aee2Loc4nE9bvjjGuhsI78w_Content tySequence__9aee2Loc4nE9bvjjGuhsI78w_Content;
typedef struct tyObject_MutationInfo__PxsvdgDRugMnwwZP8bDvWA tyObject_MutationInfo__PxsvdgDRugMnwwZP8bDvWA;
typedef struct tyObject_NimSeqV2__MH13ExfdlzA45QmDNC3o6A tyObject_NimSeqV2__MH13ExfdlzA45QmDNC3o6A;
typedef struct tyObject_NimSeqPayload__V8SGPvr2NEEheXGIwTmAJw tyObject_NimSeqPayload__V8SGPvr2NEEheXGIwTmAJw;
typedef struct tyObject_NimSeqV2__7t9bU3EneK6dsyc6g2BJtmQ tyObject_NimSeqV2__7t9bU3EneK6dsyc6g2BJtmQ;
typedef struct tyObject_NimSeqPayload__qzrKbs9a7A8QyfauyMVqfVw tyObject_NimSeqPayload__qzrKbs9a7A8QyfauyMVqfVw;
typedef struct tySequence__dAjyAaabi52TN36Jp0fAXQ tySequence__dAjyAaabi52TN36Jp0fAXQ;
typedef struct tySequence__dAjyAaabi52TN36Jp0fAXQ_Content tySequence__dAjyAaabi52TN36Jp0fAXQ_Content;
typedef struct tyObject_NimSeqV2__8Ls8O4CloMJdhVQXyzD0RQ tyObject_NimSeqV2__8Ls8O4CloMJdhVQXyzD0RQ;
typedef struct tyObject_NimSeqPayload__pgWZugySAfNMGzNhuS9b5zw tyObject_NimSeqPayload__pgWZugySAfNMGzNhuS9b5zw;
typedef struct tyTuple__X9bWVAqRSgByRpQwn6owzEA tyTuple__X9bWVAqRSgByRpQwn6owzEA;
typedef struct tySequence__4SBkVvm2CCxNvzruVhJR5g tySequence__4SBkVvm2CCxNvzruVhJR5g;
typedef struct tySequence__4SBkVvm2CCxNvzruVhJR5g_Content tySequence__4SBkVvm2CCxNvzruVhJR5g_Content;
typedef struct tyObject_NimSeqV2__aXUYM59cElXn09cIUizjfk5w tyObject_NimSeqV2__aXUYM59cElXn09cIUizjfk5w;
typedef struct tyObject_NimSeqPayload__Dp9bVzDpNllghV0L9c9bLiBdQ tyObject_NimSeqPayload__Dp9bVzDpNllghV0L9c9bLiBdQ;
typedef struct tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg;
typedef struct tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg_Content tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg_Content;
typedef struct tyObject_NimSeqV2__X8EcnzlUu7HSxH3DvM59aWA tyObject_NimSeqV2__X8EcnzlUu7HSxH3DvM59aWA;
typedef struct tyObject_NimSeqPayload__8vZEjNj21w0FevtnLFKUZA tyObject_NimSeqPayload__8vZEjNj21w0FevtnLFKUZA;
typedef struct tySequence__xKcKU9c79cy1NlvTXGoOtyWg tySequence__xKcKU9c79cy1NlvTXGoOtyWg;
typedef struct tySequence__xKcKU9c79cy1NlvTXGoOtyWg_Content tySequence__xKcKU9c79cy1NlvTXGoOtyWg_Content;
typedef struct tySequence__tgZNpA9ayNCNeNkBBBthFtA tySequence__tgZNpA9ayNCNeNkBBBthFtA;
typedef struct tySequence__tgZNpA9ayNCNeNkBBBthFtA_Content tySequence__tgZNpA9ayNCNeNkBBBthFtA_Content;
typedef struct tyObject_NimSeqV2__iDl3hAQU2o8nEd0sv7D22w tyObject_NimSeqV2__iDl3hAQU2o8nEd0sv7D22w;
typedef struct tyObject_NimSeqPayload__FqetbPaJVPjS9cTFy00BByA tyObject_NimSeqPayload__FqetbPaJVPjS9cTFy00BByA;
typedef struct tyObject_NimSeqV2__d9aGqq8cRSUYOH2ZnoeagyQ tyObject_NimSeqV2__d9aGqq8cRSUYOH2ZnoeagyQ;
typedef struct tyObject_NimSeqPayload__eAiAVcRO27GDld9cTI4uQ5g tyObject_NimSeqPayload__eAiAVcRO27GDld9cTI4uQ5g;
typedef struct tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg;
typedef struct tyObject_NimSeqV2__5NIkFqw0MXPqP3gAo8VKkg tyObject_NimSeqV2__5NIkFqw0MXPqP3gAo8VKkg;
typedef struct tyObject_NimSeqPayload__lxJT9bkQbAv4qUaBg9biquXA tyObject_NimSeqPayload__lxJT9bkQbAv4qUaBg9biquXA;
typedef struct tySequence__XlRvVllIQIinot2wpb0XoA tySequence__XlRvVllIQIinot2wpb0XoA;
typedef struct tySequence__XlRvVllIQIinot2wpb0XoA_Content tySequence__XlRvVllIQIinot2wpb0XoA_Content;
typedef struct tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ;
typedef struct tyObject_NimSeqV2__BIZZLwYPl9bMX4kh49cOm8ug tyObject_NimSeqV2__BIZZLwYPl9bMX4kh49cOm8ug;
typedef struct tyObject_NimSeqPayload__f9aJ3DJ19bOybfz9csIEAlJmQ tyObject_NimSeqPayload__f9aJ3DJ19bOybfz9csIEAlJmQ;
typedef struct tySequence__1I4GqOPEtd9ark9cZ2UT20tw tySequence__1I4GqOPEtd9ark9cZ2UT20tw;
typedef struct tySequence__1I4GqOPEtd9ark9cZ2UT20tw_Content tySequence__1I4GqOPEtd9ark9cZ2UT20tw_Content;
typedef struct tyObject_NimSeqV2__cNovT9bfrplyGcQDd85WPvA tyObject_NimSeqV2__cNovT9bfrplyGcQDd85WPvA;
typedef struct tyObject_NimSeqPayload__cWSeCEBJE04j6OCqaWmaSA tyObject_NimSeqPayload__cWSeCEBJE04j6OCqaWmaSA;
typedef struct tyTuple__PijKblgFKtbdIstVEwjmCw tyTuple__PijKblgFKtbdIstVEwjmCw;
typedef struct tySequence__4j8aBmBZMD9chZMBaxw9bcbQ tySequence__4j8aBmBZMD9chZMBaxw9bcbQ;
typedef struct tySequence__4j8aBmBZMD9chZMBaxw9bcbQ_Content tySequence__4j8aBmBZMD9chZMBaxw9bcbQ_Content;
typedef struct tyTuple__IYAk6y4YHp5OEJgCALGjQw tyTuple__IYAk6y4YHp5OEJgCALGjQw;
typedef struct tyObject_NimSeqV2__mgt4xlAYkzCTQ2AEneHZUg tyObject_NimSeqV2__mgt4xlAYkzCTQ2AEneHZUg;
typedef struct tyObject_NimSeqPayload__RYHs8BhC4WIrAf3hAV2mZw tyObject_NimSeqPayload__RYHs8BhC4WIrAf3hAV2mZw;
typedef struct tySequence__yo9alHJGzX03OXpfmEsBjBQ tySequence__yo9alHJGzX03OXpfmEsBjBQ;
typedef struct tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content;
typedef struct tyTuple__R9cYIordoMujN7rycr4Y7kw tyTuple__R9cYIordoMujN7rycr4Y7kw;
typedef struct tyObject_NimSeqV2__x0llOOJlbc9a9bfR3yxGso7A tyObject_NimSeqV2__x0llOOJlbc9a9bfR3yxGso7A;
typedef struct tyObject_NimSeqPayload__zoa5ddi9cHbXBirfGRCnd9aQ tyObject_NimSeqPayload__zoa5ddi9cHbXBirfGRCnd9aQ;
typedef struct tySequence__SxRJJ9bayPyj0RYzIZTiohA tySequence__SxRJJ9bayPyj0RYzIZTiohA;
typedef struct tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content;
typedef struct tyObject_NimSeqV2__UytTSnla1kFXxGvp8gQ9aHw tyObject_NimSeqV2__UytTSnla1kFXxGvp8gQ9aHw;
typedef struct tyObject_NimSeqPayload__xAW5NovMwE9a9b1eN9cJ9b1a7g tyObject_NimSeqPayload__xAW5NovMwE9a9b1eN9cJ9b1a7g;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tyObject_NimSeqV2__9btI3rjW0aBVdnbJCkK3HwQ tyObject_NimSeqV2__9btI3rjW0aBVdnbJCkK3HwQ;
typedef struct tyObject_NimSeqPayload__cIDc6ijU1sfiv43zX9awuvw tyObject_NimSeqPayload__cIDc6ijU1sfiv43zX9awuvw;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw tySequence__AE2UIxl7EbPzzBnmYsjIcw;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content;
typedef struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw;
typedef struct tyObject_NimSeqV2__zQpJJUpO49adzwEvtl2krQA tyObject_NimSeqV2__zQpJJUpO49adzwEvtl2krQA;
typedef struct tyObject_NimSeqPayload__VJdFAAZtcNZ4cOMpSmdLHw tyObject_NimSeqPayload__VJdFAAZtcNZ4cOMpSmdLHw;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content;
typedef struct tyObject_NimSeqV2__AITKefZbNVuXMg9az9b5SUDw tyObject_NimSeqV2__AITKefZbNVuXMg9az9b5SUDw;
typedef struct tyObject_NimSeqPayload__8f5w800P5K7g04o5MnuJZg tyObject_NimSeqPayload__8f5w800P5K7g04o5MnuJZg;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tySequence__zpKGgayc1mFyemMGMuK9a2w tySequence__zpKGgayc1mFyemMGMuK9a2w;
typedef struct tySequence__zpKGgayc1mFyemMGMuK9a2w_Content tySequence__zpKGgayc1mFyemMGMuK9a2w_Content;
typedef struct tyTuple__DfjLoSEvFkvlneCb5GSa9cQ tyTuple__DfjLoSEvFkvlneCb5GSa9cQ;
typedef struct tyTuple__w31HlKXGH5QCPFggOmKfbQ tyTuple__w31HlKXGH5QCPFggOmKfbQ;
typedef struct tyObject_NimSeqV2__Tg51nuRTSn1RaKhJaazjFQ tyObject_NimSeqV2__Tg51nuRTSn1RaKhJaazjFQ;
typedef struct tyObject_NimSeqPayload__u9cIZq8cS7q3ggB6KdsCNVQ tyObject_NimSeqPayload__u9cIZq8cS7q3ggB6KdsCNVQ;
typedef struct tySequence__9cbEQVGky3gHl4QEC3q4Sow tySequence__9cbEQVGky3gHl4QEC3q4Sow;
typedef struct tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content;
typedef struct tyTuple__GhsGHTmri9bgdv8XapNtpTg tyTuple__GhsGHTmri9bgdv8XapNtpTg;
typedef struct tyObject_NimSeqV2__9asO9cshOF4y9cfdguzBg29a7A tyObject_NimSeqV2__9asO9cshOF4y9cfdguzBg29a7A;
typedef struct tyObject_NimSeqPayload__zNLeo3X29akF2Ap409cLy3lw tyObject_NimSeqPayload__zNLeo3X29akF2Ap409cLy3lw;
typedef struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg tySequence__9bRXJy1JXrQ4hWpStaKBpXg;
typedef struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content;
typedef struct tyObject_NimSeqV2__PtLz9bQbFWDN9aLSpHtqdEmA tyObject_NimSeqV2__PtLz9bQbFWDN9aLSpHtqdEmA;
typedef struct tyObject_NimSeqPayload__0KWqNVfFHBrBbvQ3rkt2qw tyObject_NimSeqPayload__0KWqNVfFHBrBbvQ3rkt2qw;
typedef struct tyTuple__9agFg9cuYsNvckAbTfHAsTSA tyTuple__9agFg9cuYsNvckAbTfHAsTSA;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw tySequence__jwzrUFjG9akTIJTBBFvvqxw;
typedef struct tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content;
typedef struct tyTuple__XOVT24GHXwqiEj5GCsEGCA tyTuple__XOVT24GHXwqiEj5GCsEGCA;
typedef struct tyObject_NimSeqV2__9bDpynnYoGERDv29b2zzrHBA tyObject_NimSeqV2__9bDpynnYoGERDv29b2zzrHBA;
typedef struct tyObject_NimSeqPayload__uxcJrKhywutDkyBihRCp8A tyObject_NimSeqPayload__uxcJrKhywutDkyBihRCp8A;
typedef struct tySequence__fVUhfWxkucMvZhVKGrAHuA tySequence__fVUhfWxkucMvZhVKGrAHuA;
typedef struct tySequence__fVUhfWxkucMvZhVKGrAHuA_Content tySequence__fVUhfWxkucMvZhVKGrAHuA_Content;
typedef struct tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA;
typedef struct tyObject_NimSeqV2__OxcAsbxTCnOB3tNBCMOKmQ tyObject_NimSeqV2__OxcAsbxTCnOB3tNBCMOKmQ;
typedef struct tyObject_NimSeqPayload__w8RH3U9c4N9cJ9a7RfqWxNKlQ tyObject_NimSeqPayload__w8RH3U9c4N9cJ9a7RfqWxNKlQ;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_Table__0Na0d2dQ8AYACjty2CqMPA tyObject_Table__0Na0d2dQ8AYACjty2CqMPA;
typedef struct tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg;
typedef struct tySequence__kq9c1GdJLvkYJeijBmsJ20A tySequence__kq9c1GdJLvkYJeijBmsJ20A;
typedef struct tySequence__kq9c1GdJLvkYJeijBmsJ20A_Content tySequence__kq9c1GdJLvkYJeijBmsJ20A_Content;
typedef struct tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A;
typedef struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g;
typedef struct tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA;
typedef struct tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g;
typedef struct tyObject_NimSeqV2__OgCJ17saq1nSO9as9agMdsCw tyObject_NimSeqV2__OgCJ17saq1nSO9as9agMdsCw;
typedef struct tyObject_NimSeqPayload__CvDo7kJ9bzhvslYp8QzYe5w tyObject_NimSeqPayload__CvDo7kJ9bzhvslYp8QzYe5w;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyObject_NimSeqV2__KfASkEYFzOb1wwm3izC5Qw tyObject_NimSeqV2__KfASkEYFzOb1wwm3izC5Qw;
typedef struct tyObject_NimSeqPayload__GKLkcFK9bXhhfQVfVIZSsjw tyObject_NimSeqPayload__GKLkcFK9bXhhfQVfVIZSsjw;
typedef struct tySequence__1xFov7v9c2rs44orw6d9bPmw tySequence__1xFov7v9c2rs44orw6d9bPmw;
typedef struct tySequence__1xFov7v9c2rs44orw6d9bPmw_Content tySequence__1xFov7v9c2rs44orw6d9bPmw_Content;
typedef struct tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g;
typedef struct tySequence__ASKXHf9aJJjLj0hSZ39ci19cA tySequence__ASKXHf9aJJjLj0hSZ39ci19cA;
typedef struct tySequence__ASKXHf9aJJjLj0hSZ39ci19cA_Content tySequence__ASKXHf9aJJjLj0hSZ39ci19cA_Content;
typedef struct tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q;
typedef struct tyObject_NimSeqV2__w2Yxjbp9cPR9axG5zMX2ZJDQ tyObject_NimSeqV2__w2Yxjbp9cPR9axG5zMX2ZJDQ;
typedef struct tyObject_NimSeqPayload__Z87I9cxqtjAbepz89aHXS7eg tyObject_NimSeqPayload__Z87I9cxqtjAbepz89aHXS7eg;
typedef struct tySequence__gGvy9cKEpHEX9cA4gF5mzkxA tySequence__gGvy9cKEpHEX9cA4gF5mzkxA;
typedef struct tySequence__gGvy9cKEpHEX9cA4gF5mzkxA_Content tySequence__gGvy9cKEpHEX9cA4gF5mzkxA_Content;
typedef struct tyObject_NimSeqV2__5ysMwE3bSaZW3caCX0Ttzg tyObject_NimSeqV2__5ysMwE3bSaZW3caCX0Ttzg;
typedef struct tyObject_NimSeqPayload__prYsw3adJsXiAStbTYEyUA tyObject_NimSeqPayload__prYsw3adJsXiAStbTYEyUA;
typedef struct tyObject_NimSeqV2__wt39cjGYh5Guxqsbc3o6hQA tyObject_NimSeqV2__wt39cjGYh5Guxqsbc3o6hQA;
typedef struct tyObject_NimSeqPayload__nDLEjClwgABDf30b81MZug tyObject_NimSeqPayload__nDLEjClwgABDf30b81MZug;
typedef struct tyTuple__MDblJIdBvEzk3cvDpORS3w tyTuple__MDblJIdBvEzk3cvDpORS3w;
typedef struct tyObject_NimSeqV2__Cbt9aJKw9bTRLyD7sNsbPszg tyObject_NimSeqV2__Cbt9aJKw9bTRLyD7sNsbPszg;
typedef struct tyObject_NimSeqPayload__mIMn1lPcHyJESWpGlGgV3w tyObject_NimSeqPayload__mIMn1lPcHyJESWpGlGgV3w;
typedef struct tySequence__W61O50MEQVwc9azCYWJekkw tySequence__W61O50MEQVwc9azCYWJekkw;
typedef struct tySequence__W61O50MEQVwc9azCYWJekkw_Content tySequence__W61O50MEQVwc9azCYWJekkw_Content;
typedef struct tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw;
typedef struct tyObject_NimSeqV2__S9b80pdJYZQPsS5N9b2kicxw tyObject_NimSeqV2__S9b80pdJYZQPsS5N9b2kicxw;
typedef struct tyObject_NimSeqPayload__U7B8DwB0W7xf9bVfVHA9aqrA tyObject_NimSeqPayload__U7B8DwB0W7xf9bVfVHA9aqrA;
typedef struct tyObject_NimSeqV2__weU9asdVHowsM0AixRsmNtw tyObject_NimSeqV2__weU9asdVHowsM0AixRsmNtw;
typedef struct tyObject_NimSeqPayload__i3atYjlhKLPEdlA9agEAgig tyObject_NimSeqPayload__i3atYjlhKLPEdlA9agEAgig;
typedef struct tyTuple__UGkfKgNvKJXAR6NX6Y5gaw tyTuple__UGkfKgNvKJXAR6NX6Y5gaw;
typedef struct tySequence__7Eqk7CViYtlAWKDoMfuEcw tySequence__7Eqk7CViYtlAWKDoMfuEcw;
typedef struct tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content;
typedef struct tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg;
typedef struct tyObject_NimSeqV2__AV5et9atQLnjtoDLFs9c0pqw tyObject_NimSeqV2__AV5et9atQLnjtoDLFs9c0pqw;
typedef struct tyObject_NimSeqPayload__wqnZx9am7Gry9bMI0mkOMvPQ tyObject_NimSeqPayload__wqnZx9am7Gry9bMI0mkOMvPQ;
typedef struct tySequence__jXZVXmhly1BClQDJpGni9ag tySequence__jXZVXmhly1BClQDJpGni9ag;
typedef struct tySequence__jXZVXmhly1BClQDJpGni9ag_Content tySequence__jXZVXmhly1BClQDJpGni9ag_Content;
typedef struct tyTuple__ILpLBib1l58GvVZ4BcToSg tyTuple__ILpLBib1l58GvVZ4BcToSg;
typedef struct tyObject_NimSeqV2__PDqM9andK9c3w9aDIGEcXk8UQ tyObject_NimSeqV2__PDqM9andK9c3w9aDIGEcXk8UQ;
typedef struct tyObject_NimSeqPayload__VvMimvmaTnYn8kKdk9c86lg tyObject_NimSeqPayload__VvMimvmaTnYn8kKdk9c86lg;
typedef struct tySequence__1cgZIGFge8OGY6Zlwa9aRnw tySequence__1cgZIGFge8OGY6Zlwa9aRnw;
typedef struct tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content;
typedef struct tyTuple__IGtaz2jo9ahodpWjWgc5c5A tyTuple__IGtaz2jo9ahodpWjWgc5c5A;
typedef struct tyObject_NimSeqV2__KnDsUGgx2yjp69b8gz0zSYg tyObject_NimSeqV2__KnDsUGgx2yjp69b8gz0zSYg;
typedef struct tyObject_NimSeqPayload__Qd9cKL9bcCjHwcgEfiPu7ZXw tyObject_NimSeqPayload__Qd9cKL9bcCjHwcgEfiPu7ZXw;
typedef struct tySequence__olcP618a61wlx6oJIT9b0sA tySequence__olcP618a61wlx6oJIT9b0sA;
typedef struct tySequence__olcP618a61wlx6oJIT9b0sA_Content tySequence__olcP618a61wlx6oJIT9b0sA_Content;
typedef struct tyTuple__P9bg2wlfPi4dSSTi3ICCeVA tyTuple__P9bg2wlfPi4dSSTi3ICCeVA;
typedef struct tyObject_NimSeqV2__YBTuIJlLxSm2mxe1w9cWFrA tyObject_NimSeqV2__YBTuIJlLxSm2mxe1w9cWFrA;
typedef struct tyObject_NimSeqPayload__D4LPGlBSP9aZMmMsu9cDwSuw tyObject_NimSeqPayload__D4LPGlBSP9aZMmMsu9cDwSuw;
typedef struct tySequence__P9aymq2R2Xa8At0XKJ6Bh1A tySequence__P9aymq2R2Xa8At0XKJ6Bh1A;
typedef struct tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content;
typedef struct tyObject_NimSeqV2__W5tAKfTFLQBWqzn4PRHD2A tyObject_NimSeqV2__W5tAKfTFLQBWqzn4PRHD2A;
typedef struct tyObject_NimSeqPayload__9cD5x9btaprZqa4nYXRlvtqw tyObject_NimSeqPayload__9cD5x9btaprZqa4nYXRlvtqw;
typedef struct tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw;
typedef struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ;
typedef struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content;
typedef struct tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ;
typedef struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA;
typedef struct tyObject_NimSeqV2__ZhzDsOEyq73Ti8kBnPUVAQ tyObject_NimSeqV2__ZhzDsOEyq73Ti8kBnPUVAQ;
typedef struct tyObject_NimSeqPayload__YsSBpIEgPJDz0K9aFZPtHFg tyObject_NimSeqPayload__YsSBpIEgPJDz0K9aFZPtHFg;
typedef struct tySequence__LqZapiAqCFeXPQZdoIAUew tySequence__LqZapiAqCFeXPQZdoIAUew;
typedef struct tySequence__LqZapiAqCFeXPQZdoIAUew_Content tySequence__LqZapiAqCFeXPQZdoIAUew_Content;
typedef struct tyObject_NimSeqV2__bbuzn26SpE2aMsRysMBtPw tyObject_NimSeqV2__bbuzn26SpE2aMsRysMBtPw;
typedef struct tyObject_NimSeqPayload__LiYZJx3MkkRTPACuQG4JSg tyObject_NimSeqPayload__LiYZJx3MkkRTPACuQG4JSg;
typedef struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA;
typedef struct tyObject_NimSeqV2__t78Q6fZVjKweNlSemiuCdA tyObject_NimSeqV2__t78Q6fZVjKweNlSemiuCdA;
typedef struct tyObject_NimSeqPayload__cRENl2YvyxBdbrl9a5PTnJQ tyObject_NimSeqPayload__cRENl2YvyxBdbrl9a5PTnJQ;
typedef struct tySequence__Ygtgme9cSsBUPbXwOprm43Q tySequence__Ygtgme9cSsBUPbXwOprm43Q;
typedef struct tySequence__Ygtgme9cSsBUPbXwOprm43Q_Content tySequence__Ygtgme9cSsBUPbXwOprm43Q_Content;
typedef struct tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg;
typedef struct tyObject_NimSeqV2__qdXEIeVz4ljISllV9a1mIOg tyObject_NimSeqV2__qdXEIeVz4ljISllV9a1mIOg;
typedef struct tyObject_NimSeqPayload__IxmSriPVaYy30PbJEUVJNw tyObject_NimSeqPayload__IxmSriPVaYy30PbJEUVJNw;
typedef struct tySequence__ib5UTyrs9aC6K60sNqKElQA tySequence__ib5UTyrs9aC6K60sNqKElQA;
typedef struct tySequence__ib5UTyrs9aC6K60sNqKElQA_Content tySequence__ib5UTyrs9aC6K60sNqKElQA_Content;
typedef struct tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA;
typedef struct tyObject_NimSeqV2__ogAkNBRuOEgem9ccQ23aWJA tyObject_NimSeqV2__ogAkNBRuOEgem9ccQ23aWJA;
typedef struct tyObject_NimSeqPayload__sNyYFNBvMgWzlPRT5RMxMA tyObject_NimSeqPayload__sNyYFNBvMgWzlPRT5RMxMA;
typedef struct tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw;
typedef struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw tySequence__O9a9cp2XDKWshwC0UDgFP6Pw;
typedef struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content;
typedef struct tyTuple__Na59bk2YQTCLBWTLyeMrWdA tyTuple__Na59bk2YQTCLBWTLyeMrWdA;
typedef struct tyObject_NimSeqV2__oV415pC8JzigLaE3Z8NmRA tyObject_NimSeqV2__oV415pC8JzigLaE3Z8NmRA;
typedef struct tyObject_NimSeqPayload__8rE9bP9aK9b2hbvymP6dkiK9ag tyObject_NimSeqPayload__8rE9bP9aK9b2hbvymP6dkiK9ag;
typedef struct tySequence__7kOUUrKwg6xKu7wOGcJDlQ tySequence__7kOUUrKwg6xKu7wOGcJDlQ;
typedef struct tySequence__7kOUUrKwg6xKu7wOGcJDlQ_Content tySequence__7kOUUrKwg6xKu7wOGcJDlQ_Content;
typedef struct tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg;
typedef struct tyObject_NimSeqV2__jq9bZNIPJ4qu7V4eHQtnzsA tyObject_NimSeqV2__jq9bZNIPJ4qu7V4eHQtnzsA;
typedef struct tyObject_NimSeqPayload__Hlj1rtYTbGj4Dqclc4DkRw tyObject_NimSeqPayload__Hlj1rtYTbGj4Dqclc4DkRw;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__vz9c2digtAnM8l0FZWLUAGg tySequence__vz9c2digtAnM8l0FZWLUAGg;
typedef struct tySequence__vz9c2digtAnM8l0FZWLUAGg_Content tySequence__vz9c2digtAnM8l0FZWLUAGg_Content;
typedef struct tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A;
typedef struct tyObject_NimSeqV2__14YjrtdnP0xUdYuun1A9aLA tyObject_NimSeqV2__14YjrtdnP0xUdYuun1A9aLA;
typedef struct tyObject_NimSeqPayload__yqjN9aCYTixKEQlArWvLUOA tyObject_NimSeqPayload__yqjN9aCYTixKEQlArWvLUOA;
typedef struct tySequence__jK2T9bFw5BWKL8ZZ854oXZg tySequence__jK2T9bFw5BWKL8ZZ854oXZg;
typedef struct tySequence__jK2T9bFw5BWKL8ZZ854oXZg_Content tySequence__jK2T9bFw5BWKL8ZZ854oXZg_Content;
typedef struct tyObject_NimSeqV2__0ZwVzMiBqWU9cqL9caiDoTLA tyObject_NimSeqV2__0ZwVzMiBqWU9cqL9caiDoTLA;
typedef struct tyObject_NimSeqPayload__ybmhgz79bSqWRiJKkQ8HQ7w tyObject_NimSeqPayload__ybmhgz79bSqWRiJKkQ8HQ7w;
typedef struct tySequence__lBgZ7a89beZGYPl8PiANMTA tySequence__lBgZ7a89beZGYPl8PiANMTA;
typedef struct tySequence__lBgZ7a89beZGYPl8PiANMTA_Content tySequence__lBgZ7a89beZGYPl8PiANMTA_Content;
typedef struct tyObject_NimSeqV2__I3X9al7nCO8sblSUazXxfYg tyObject_NimSeqV2__I3X9al7nCO8sblSUazXxfYg;
typedef struct tyObject_NimSeqPayload__Hr9bMo57N1qllFnm9aTT9a04A tyObject_NimSeqPayload__Hr9bMo57N1qllFnm9aTT9a04A;
typedef struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg;
typedef struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content;
typedef struct tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng;
typedef struct tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ;
typedef struct tyObject_NimSeqV2__lBNlEWaemNhEZQ6EiE0Fow tyObject_NimSeqV2__lBNlEWaemNhEZQ6EiE0Fow;
typedef struct tyObject_NimSeqPayload__asMbT9bP9ckVukoIEqEckgeg tyObject_NimSeqPayload__asMbT9bP9ckVukoIEqEckgeg;
typedef struct tySequence__vdmFdgox3dhDOMkkFi9ayfg tySequence__vdmFdgox3dhDOMkkFi9ayfg;
typedef struct tySequence__vdmFdgox3dhDOMkkFi9ayfg_Content tySequence__vdmFdgox3dhDOMkkFi9ayfg_Content;
typedef struct tyTuple__4Ywt2LYBMs9aMJ09cL7digow tyTuple__4Ywt2LYBMs9aMJ09cL7digow;
typedef struct tyObject_NimSeqV2__T1eqKrYZfdKyRHrCorPNEA tyObject_NimSeqV2__T1eqKrYZfdKyRHrCorPNEA;
typedef struct tyObject_NimSeqPayload__89cqvepx69ccuFWso2QMjj1w tyObject_NimSeqPayload__89cqvepx69ccuFWso2QMjj1w;
typedef struct tySequence__qagWYy9b8OIJNg9bWhIaAjyw tySequence__qagWYy9b8OIJNg9bWhIaAjyw;
typedef struct tySequence__qagWYy9b8OIJNg9bWhIaAjyw_Content tySequence__qagWYy9b8OIJNg9bWhIaAjyw_Content;
typedef struct tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ;
typedef struct tyObject_NimSeqV2__6Pxjw9bWB1WY3zh3hilV9cZg tyObject_NimSeqV2__6Pxjw9bWB1WY3zh3hilV9cZg;
typedef struct tyObject_NimSeqPayload__vCNTtuN37GkJiwKmwrWOyw tyObject_NimSeqPayload__vCNTtuN37GkJiwKmwrWOyw;
typedef struct tySequence__g9cc9ce4njfC9a8r1mQEl8mIg tySequence__g9cc9ce4njfC9a8r1mQEl8mIg;
typedef struct tySequence__g9cc9ce4njfC9a8r1mQEl8mIg_Content tySequence__g9cc9ce4njfC9a8r1mQEl8mIg_Content;
typedef struct tyObject_NimSeqV2__tjcRCxE1NDeNULoDZAR1Yg tyObject_NimSeqV2__tjcRCxE1NDeNULoDZAR1Yg;
typedef struct tyObject_NimSeqPayload__2ExJM0q52YdctDeHI5gngA tyObject_NimSeqPayload__2ExJM0q52YdctDeHI5gngA;
typedef struct tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ;
typedef struct tySequence__lCWXucMn9bU7PUqVDK7772w tySequence__lCWXucMn9bU7PUqVDK7772w;
typedef struct tySequence__lCWXucMn9bU7PUqVDK7772w_Content tySequence__lCWXucMn9bU7PUqVDK7772w_Content;
typedef struct tyTuple__kNIN44R9cL9cYoYzXmSW4y7w tyTuple__kNIN44R9cL9cYoYzXmSW4y7w;
typedef struct tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ;
typedef struct tyObject_NimSeqV2__UfbSPrjWq12UpEcQ5cvcpw tyObject_NimSeqV2__UfbSPrjWq12UpEcQ5cvcpw;
typedef struct tyObject_NimSeqPayload__JjOOUsaDCA9bnEfeAuP0f6g tyObject_NimSeqPayload__JjOOUsaDCA9bnEfeAuP0f6g;
typedef struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA tySequence__b9cVyuSHmrW80P0ZGgU2KHA;
typedef struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content;
typedef struct tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg;
typedef struct tyObject_NimSeqV2__yUtpZJvImTQo9bK5xz5kYJw tyObject_NimSeqV2__yUtpZJvImTQo9bK5xz5kYJw;
typedef struct tyObject_NimSeqPayload__6Of5sDwIeeQl9aHgrxiVQng tyObject_NimSeqPayload__6Of5sDwIeeQl9aHgrxiVQng;
typedef struct tySequence__uAwiTxV3boseSy9a9cSsXHEA tySequence__uAwiTxV3boseSy9a9cSsXHEA;
typedef struct tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content;
typedef struct tyTuple__30Ti2rm9aDSr5neUSZP6EVQ tyTuple__30Ti2rm9aDSr5neUSZP6EVQ;
typedef struct tyObject_NimSeqV2__1TKHLyyLNkNmpOAP9bh7GLA tyObject_NimSeqV2__1TKHLyyLNkNmpOAP9bh7GLA;
typedef struct tyObject_NimSeqPayload__hB9aHrhbUnNwHgNUQwrnGzQ tyObject_NimSeqPayload__hB9aHrhbUnNwHgNUQwrnGzQ;
typedef struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg;
typedef struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content;
typedef struct tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg;
typedef struct tyObject_NimSeqV2__D8j6RTfYMSkIst53FjTViA tyObject_NimSeqV2__D8j6RTfYMSkIst53FjTViA;
typedef struct tyObject_NimSeqPayload__hLNcDnR7bJ4wjvQz9ahH6JA tyObject_NimSeqPayload__hLNcDnR7bJ4wjvQz9ahH6JA;
typedef struct tySequence__9at3Cmn7xIajy679cMZSmybg tySequence__9at3Cmn7xIajy679cMZSmybg;
typedef struct tySequence__9at3Cmn7xIajy679cMZSmybg_Content tySequence__9at3Cmn7xIajy679cMZSmybg_Content;
typedef struct tyTuple__RrY3dT8dfTceE0s6Bv9bxJw tyTuple__RrY3dT8dfTceE0s6Bv9bxJw;
typedef struct tyObject_NimSeqV2__9aud9b4Q3q9cilO02NybLywdQ tyObject_NimSeqV2__9aud9b4Q3q9cilO02NybLywdQ;
typedef struct tyObject_NimSeqPayload__ute2TqMnJ0mHidshPkSn3w tyObject_NimSeqPayload__ute2TqMnJ0mHidshPkSn3w;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw tySequence__fXWXs2NlFKREhy9cn6vokJw;
typedef struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content tySequence__fXWXs2NlFKREhy9cn6vokJw_Content;
typedef struct tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g;
typedef struct tyObject_NimSeqPayload__JaTznDCkq35V9cuoM5WF0BA tyObject_NimSeqPayload__JaTznDCkq35V9cuoM5WF0BA;
typedef struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g;
typedef struct tySequence__eb7tUf9a8CR5sBO6O3AH67A tySequence__eb7tUf9a8CR5sBO6O3AH67A;
typedef struct tySequence__eb7tUf9a8CR5sBO6O3AH67A_Content tySequence__eb7tUf9a8CR5sBO6O3AH67A_Content;
typedef struct tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw;
typedef struct tyObject_NimSeqV2__iJtaCkDWWpRT1m7KgS5F7g tyObject_NimSeqV2__iJtaCkDWWpRT1m7KgS5F7g;
typedef struct tyObject_NimSeqPayload__VC9cBOrPM9bT6kBhZDcUa6CQ tyObject_NimSeqPayload__VC9cBOrPM9bT6kBhZDcUa6CQ;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA tySequence__m9axZwxFfhSNLcoofvKZJYA;
typedef struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content tySequence__m9axZwxFfhSNLcoofvKZJYA_Content;
typedef struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ;
typedef struct tyObject_NimSeqV2__WCVwWV7Hn7J7GPKWFg22mg tyObject_NimSeqV2__WCVwWV7Hn7J7GPKWFg22mg;
typedef struct tyObject_NimSeqPayload__WEyiXw9aq2uG9bJCsS9avRkLg tyObject_NimSeqPayload__WEyiXw9aq2uG9bJCsS9avRkLg;
typedef struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ;
typedef struct tySequence__NZB65egHQwAniMoFWKcFaw tySequence__NZB65egHQwAniMoFWKcFaw;
typedef struct tySequence__NZB65egHQwAniMoFWKcFaw_Content tySequence__NZB65egHQwAniMoFWKcFaw_Content;
typedef struct tyTuple__bPZu3GhfjP9cHscH3h9axT6w tyTuple__bPZu3GhfjP9cHscH3h9axT6w;
typedef struct tyObject_NimSeqV2__rK9bwjfXgSbEam9bKV1xYDUg tyObject_NimSeqV2__rK9bwjfXgSbEam9bKV1xYDUg;
typedef struct tyObject_NimSeqPayload__uz9aGs7pgMg2bRYB559byjng tyObject_NimSeqPayload__uz9aGs7pgMg2bRYB559byjng;
typedef struct tySequence__EHM5DWw09bc16yo24mdZPsw tySequence__EHM5DWw09bc16yo24mdZPsw;
typedef struct tySequence__EHM5DWw09bc16yo24mdZPsw_Content tySequence__EHM5DWw09bc16yo24mdZPsw_Content;
typedef struct tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw;
typedef struct tyObject_NimSeqV2__haf1g0PFMgrwcF57Pq0weA tyObject_NimSeqV2__haf1g0PFMgrwcF57Pq0weA;
typedef struct tyObject_NimSeqPayload__jrxRPd9cQJe05e2kdz2CuFA tyObject_NimSeqPayload__jrxRPd9cQJe05e2kdz2CuFA;
typedef struct tySequence__pN5ht9bYa9c1VQJ0Er2wvTuA tySequence__pN5ht9bYa9c1VQJ0Er2wvTuA;
typedef struct tySequence__pN5ht9bYa9c1VQJ0Er2wvTuA_Content tySequence__pN5ht9bYa9c1VQJ0Er2wvTuA_Content;
typedef struct tyObject_NimSeqV2__p2zAi8O7jv7NkThV7Wv7Jg tyObject_NimSeqV2__p2zAi8O7jv7NkThV7Wv7Jg;
typedef struct tyObject_NimSeqPayload__X2iaL9ber9aB6QN9bjTXUiXwA tyObject_NimSeqPayload__X2iaL9ber9aB6QN9bjTXUiXwA;
typedef struct tySequence__u440EGTDYOwkQLE9asdZ6OQ tySequence__u440EGTDYOwkQLE9asdZ6OQ;
typedef struct tySequence__u440EGTDYOwkQLE9asdZ6OQ_Content tySequence__u440EGTDYOwkQLE9asdZ6OQ_Content;
typedef struct tyObject_Mapping__5X9cm3giTN9aYJbVTF9clmk7A tyObject_Mapping__5X9cm3giTN9aYJbVTF9clmk7A;
typedef struct tyObject_NimSeqV2__ATMaGzUX9c9bDaC49cuJNExkg tyObject_NimSeqV2__ATMaGzUX9c9bDaC49cuJNExkg;
typedef struct tyObject_NimSeqPayload__aqsvVzVORlY4G59bckSb2fg tyObject_NimSeqPayload__aqsvVzVORlY4G59bckSb2fg;
typedef struct tySequence__IWLCUlc3h6FWY379alhl9aaQ tySequence__IWLCUlc3h6FWY379alhl9aaQ;
typedef struct tySequence__IWLCUlc3h6FWY379alhl9aaQ_Content tySequence__IWLCUlc3h6FWY379alhl9aaQ_Content;
typedef struct tyObject_Segment__9cSimljufAUmxKUYLJk2dhw tyObject_Segment__9cSimljufAUmxKUYLJk2dhw;
typedef struct tyObject_NimSeqV2__h9buKeygKKlRU5DBRAThO8w tyObject_NimSeqV2__h9buKeygKKlRU5DBRAThO8w;
typedef struct tyObject_NimSeqPayload__Lon6j0gkxPT8tK6CiffUWg tyObject_NimSeqPayload__Lon6j0gkxPT8tK6CiffUWg;
typedef struct tySequence__36jA1xDCIBAS29cySYLQ7kQ tySequence__36jA1xDCIBAS29cySYLQ7kQ;
typedef struct tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content;
typedef struct tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ;
typedef struct tyObject_NimSeqV2__It4LZ0xSvGXxrDnDyxiHAA tyObject_NimSeqV2__It4LZ0xSvGXxrDnDyxiHAA;
typedef struct tyObject_NimSeqPayload__DH8yJOdFxzJMqogBX6j0mg tyObject_NimSeqPayload__DH8yJOdFxzJMqogBX6j0mg;
typedef struct tySequence__ElKBSoViSyNazy7qD89atSA tySequence__ElKBSoViSyNazy7qD89atSA;
typedef struct tySequence__ElKBSoViSyNazy7qD89atSA_Content tySequence__ElKBSoViSyNazy7qD89atSA_Content;
typedef struct tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw;
typedef struct tyObject_NimSeqV2__9bRXa9c9az0Ao4W9aoamrTFXfw tyObject_NimSeqV2__9bRXa9c9az0Ao4W9aoamrTFXfw;
typedef struct tyObject_NimSeqPayload__9afNNooT7Cf9bhpARywaHHFg tyObject_NimSeqPayload__9afNNooT7Cf9bhpARywaHHFg;
typedef struct tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ;
typedef struct tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ_Content tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ_Content;
typedef struct tyTuple__fgn415DvsSyiHk3o9aIYr0w tyTuple__fgn415DvsSyiHk3o9aIYr0w;
typedef struct tyObject_NimSeqV2__r1EXHsatwZ6kMJ1o64DQpA tyObject_NimSeqV2__r1EXHsatwZ6kMJ1o64DQpA;
typedef struct tyObject_NimSeqPayload__U9aGDO66NJKBIUSmR7mvzJg tyObject_NimSeqPayload__U9aGDO66NJKBIUSmR7mvzJg;
typedef struct tyObject_ReraiseDefect__rf4J0hIl2XahwR8oH1IVPA tyObject_ReraiseDefect__rf4J0hIl2XahwR8oH1IVPA;
typedef struct tySequence__H9bHW2kkjp26MABVBZRr8Ig tySequence__H9bHW2kkjp26MABVBZRr8Ig;
typedef struct tySequence__H9bHW2kkjp26MABVBZRr8Ig_Content tySequence__H9bHW2kkjp26MABVBZRr8Ig_Content;
typedef struct tyObject_NimSeqV2__m0j9bkSujD9aJ8udATfNaPag tyObject_NimSeqV2__m0j9bkSujD9aJ8udATfNaPag;
typedef struct tyObject_NimSeqPayload__s0MwarqxvvP9a6pFjXy44sQ tyObject_NimSeqPayload__s0MwarqxvvP9a6pFjXy44sQ;
typedef struct tyTuple__EJOd8NnRbGOjqpW2d6uq2g tyTuple__EJOd8NnRbGOjqpW2d6uq2g;
typedef struct tySequence__MboA857W9b3olvEyCWLQeEg tySequence__MboA857W9b3olvEyCWLQeEg;
typedef struct tySequence__MboA857W9b3olvEyCWLQeEg_Content tySequence__MboA857W9b3olvEyCWLQeEg_Content;
typedef struct tyTuple__jYR27AKllNE6EvJCKQs1WA tyTuple__jYR27AKllNE6EvJCKQs1WA;
typedef struct tyObject_NimSeqV2__W7Plkq0qifudpOJp9bAjimg tyObject_NimSeqV2__W7Plkq0qifudpOJp9bAjimg;
typedef struct tyObject_NimSeqPayload__1ywxEbsXF8gcMuWhd04qPg tyObject_NimSeqPayload__1ywxEbsXF8gcMuWhd04qPg;
typedef struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w tySequence__UuiPn6QjIiUTdSVwX2PZ6w;
typedef struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content;
typedef struct tyTuple__9a3DhYVfcy14Fx42tD0lSEQ tyTuple__9a3DhYVfcy14Fx42tD0lSEQ;
typedef struct tyTuple__Ll5iolPASSzOEheeSNjmiw tyTuple__Ll5iolPASSzOEheeSNjmiw;
typedef struct tyObject_NimSeqV2__EExhi6yk44m40Ni00bMvSQ tyObject_NimSeqV2__EExhi6yk44m40Ni00bMvSQ;
typedef struct tyObject_NimSeqPayload__N3VLS9aKnwCnjctw22os8JA tyObject_NimSeqPayload__N3VLS9aKnwCnjctw22os8JA;
typedef struct tySequence__9aHwlozdspjDnjhtzDhmdVg tySequence__9aHwlozdspjDnjhtzDhmdVg;
typedef struct tySequence__9aHwlozdspjDnjhtzDhmdVg_Content tySequence__9aHwlozdspjDnjhtzDhmdVg_Content;
typedef struct tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ;
typedef struct tyObject_NimSeqV2__K0sypBe4BNGzcbvtFWY4Ew tyObject_NimSeqV2__K0sypBe4BNGzcbvtFWY4Ew;
typedef struct tyObject_NimSeqPayload__1BEfsOZcNYUjd4lXnbhEaQ tyObject_NimSeqPayload__1BEfsOZcNYUjd4lXnbhEaQ;
typedef struct tyObject_StreamObj__nX3kZRlh8Dq3gQ2cC6DE8w tyObject_StreamObj__nX3kZRlh8Dq3gQ2cC6DE8w;
typedef struct tySequence__mg32q50AXD9cQ6jovpBmgWA tySequence__mg32q50AXD9cQ6jovpBmgWA;
typedef struct tySequence__mg32q50AXD9cQ6jovpBmgWA_Content tySequence__mg32q50AXD9cQ6jovpBmgWA_Content;
typedef struct tyTuple__bvjw5f4vMpB9bESWLU7nvyA tyTuple__bvjw5f4vMpB9bESWLU7nvyA;
typedef struct tyObject_NimSeqV2__plyqYwuv3lTJaE7cjUyreg tyObject_NimSeqV2__plyqYwuv3lTJaE7cjUyreg;
typedef struct tyObject_NimSeqPayload__ceWjhV9bHVjDw9ckC1zzOXDQ tyObject_NimSeqPayload__ceWjhV9bHVjDw9ckC1zzOXDQ;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg {
	NI len;
	NI cap;
	tyTuple__DTRsWi2kgTewbhN2TT5mbA* d;
};
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__9axCnCRMUx32AHzFgBrzSMg) (Exception* e_p0);
typedef N_NIMCALL_PTR(void, tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ) (void);
typedef N_NIMCALL_PTR(void, tyProc__NFmM6mqUOVW3cJg4yvk8Fw) (Exception* e_p0);
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef N_NIMCALL_PTR(void, tyProc__W6IXMh2CA4X1rFYGjUb4yg) (NimStringV2 msg_p0);
typedef tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* tyArray__7d9atfPQJKvYbM69b9aVmm9c0Q[256];
typedef tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg* tyArray__7wP9cTAcwu9ahYQrm1CHQ3nQ[256];
typedef NU32 tyArray__Dua9a9cJZpECRDgCD41gwSOQ[24];
typedef tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* tyArray__e8UmqaZa8FMeRczCmDyc7Q[32];
typedef tyArray__e8UmqaZa8FMeRczCmDyc7Q tyArray__rSopfIruAx7W2QYVqODTAg[24];
typedef tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg* tyArray__9cVOxSh1z6C7Ag5dV9bpMtow[256];
struct tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ {
	tyArray__9cVOxSh1z6C7Ag5dV9bpMtow data;
};
struct tyTuple__4BgqD9cyRAp80fL3mrBT7yQ {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* Field0;
	NI Field1;
};
typedef tyTuple__4BgqD9cyRAp80fL3mrBT7yQ tyArray__wyyHYi8pzokMFSMETWHSUg[30];
struct tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA {
	NI len;
	tyArray__wyyHYi8pzokMFSMETWHSUg chunks;
	tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA* next;
};
struct tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ {
	tyArray__7d9atfPQJKvYbM69b9aVmm9c0Q freeSmallChunks;
	tyArray__7wP9cTAcwu9ahYQrm1CHQ3nQ sharedFreeLists;
	NU32 flBitmap;
	tyArray__Dua9a9cJZpECRDgCD41gwSOQ slBitmap;
	tyArray__rSopfIruAx7W2QYVqODTAg matrix;
	tyObject_LLChunk__9cg7LlyOeeb21wFGpiSg37g* llmem;
	NI currMem;
	NI maxMem;
	NI freeMem;
	NI occ;
	NI lastSize;
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* sharedFreeListBigChunks;
	tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ chunkStarts;
	NIM_BOOL lockActive;
	NIM_BOOL locked;
	NIM_BOOL blockChunkSizeIncrease;
	NI nextChunkSize;
	tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA heapLinks;
};
struct tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw {
	NI prevSize;
	NI size;
	tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* owner;
};
struct tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA {
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw Sup;
	tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* next;
	tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* prev;
	tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg* freeList;
	NI32 free;
	NU32 acc;
	NI32 foreignCells;
	NI32 chunkAlignOff;
	NIM_ALIGN(16) NU8 data[SEQ_DECL_SIZE];
};
typedef NI8 tyArray__mkmEeKAWtk2yS9bBb1lUWXA[256];
struct tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg {
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw Sup;
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* next;
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* prev;
	NIM_ALIGN(16) NU8 data[SEQ_DECL_SIZE];
};
struct tyObject_LLChunk__9cg7LlyOeeb21wFGpiSg37g {
	NI size;
	NI acc;
	tyObject_LLChunk__9cg7LlyOeeb21wFGpiSg37g* next;
};
typedef NU tyArray__KznKlIbW0OmA9ckg0NfmHVQ[8];
struct tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg {
	tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
	NI Field0;
	NI Field1;
};
struct tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg {
	tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg* next;
	NI alignment;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tyTuple__DTRsWi2kgTewbhN2TT5mbA {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* Field0;
	TNimTypeV2* Field1;
};
typedef tyTuple__DTRsWi2kgTewbhN2TT5mbA tyUncheckedArray__9bgQD9aO9ax2ibgJWZFYaxJ1w[1];
struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg {
	NI len;
	NI cap;
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q* d;
};
struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w {
	tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg traceStack;
	tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg toFree;
	NI freed;
	NI touched;
	NI edges;
	NI rcSum;
	NIM_BOOL keepThreshold;
};
struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q {
	void** Field0;
	TNimTypeV2* Field1;
};
typedef tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyUncheckedArray__72XmdLy0QAaMtx66AmNKfA[1];
typedef N_NIMCALL_PTR(void, tyProc__fhqfcnDhIcLpBpSTVsWEZg) (void* p_p0, void* env_p1);
typedef N_NIMCALL_PTR(void, tyProc__4SVlZZPmetqBimNsH9cHcOA) (void* p_p0);
typedef NIM_CHAR tyArray__kytxwwvkX5R7j4VwJUOu9cg[2001];
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
typedef N_NOCONV_PTR(void, tyProc__gx1DG571q2UZkCl7Jq3AOg) (int a_p0);
struct tySequence__9chP3SzkaldXzawWQCDsqqg {
  NI len; tySequence__9chP3SzkaldXzawWQCDsqqg_Content* p;
};
struct tyObject_NimSeqV2__CVB9ceqf7MuYQ50y33G2eMQ {
	NI len;
	tyObject_NimSeqPayload__jE9cmDq9bcUuOOKfQy6CBC1A* p;
};
struct tyTuple__aGv2fk9ceddvdC01ZJC2Q2g {
	NI Field0;
	void* Field1;
	NI Field2;
};
struct tyObject_NimSeqPayload__jE9cmDq9bcUuOOKfQy6CBC1A {
	NI cap;
	tyTuple__aGv2fk9ceddvdC01ZJC2Q2g data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g {
	NI cap;
};
struct tyObject_NimSeqV2__z16azg5dzFTHfo9azxutGNA {
	NI len;
	tyObject_NimSeqPayload__0nxC5OGQFE7jyMqWtYaR7A* p;
};
struct tyObject_NimSeqPayload__0nxC5OGQFE7jyMqWtYaR7A {
	NI cap;
	tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE];
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__xv3aaFd3JCw8NbmALHiezQ {
  NI len; tySequence__xv3aaFd3JCw8NbmALHiezQ_Content* p;
};
struct tyTuple__sPaDkVPSC0MkcoXCxPH9ccA {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NIM_BOOL Field2;
};
struct tyObject_NimSeqV2__cmhMldmnNRYydfu2BEkRCg {
	NI len;
	tyObject_NimSeqPayload__9aI6jznD9cwNqZ3317klA9bBQ* p;
};
struct tyObject_NimSeqPayload__9aI6jznD9cwNqZ3317klA9bBQ {
	NI cap;
	tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE];
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tyObject_NimSeqV2__zeIiXV75mf2Pfp9b3Cs5Wdg {
	NI len;
	tyObject_NimSeqPayload__Nsi2DL7cl1GFqRwjgk71Jw* p;
};
struct tyObject_NimSeqPayload__Nsi2DL7cl1GFqRwjgk71Jw {
	NI cap;
	tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tyObject_NimSeqV2__xYeauJM9bj9aY9caH55lM1nKA {
	NI len;
	tyObject_NimSeqPayload__5OkmQTkiYc9cnv9bZqKK9c19bA* p;
};
struct tyObject_NimSeqPayload__5OkmQTkiYc9cnv9bZqKK9c19bA {
	NI cap;
	tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE];
};
struct tySequence__FGxE1Nuen6pVDc58PZudJw {
  NI len; tySequence__FGxE1Nuen6pVDc58PZudJw_Content* p;
};
struct tyObject_NimSeqV2__Qnm9a1W1Vp9akt9cDxi9ajFnSQ {
	NI len;
	tyObject_NimSeqPayload__d4XM9c4jiz4O1hJ3ujtvgcw* p;
};
struct tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw {
	NF time;
	NI count;
};
struct tyTuple__7xc1P89akJWzo77UAKrb3aA {
	NI Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
	tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw Field2;
};
struct tyObject_NimSeqPayload__d4XM9c4jiz4O1hJ3ujtvgcw {
	NI cap;
	tyTuple__7xc1P89akJWzo77UAKrb3aA data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw {
	NI len;
	tyObject_NimSeqPayload__40TpIbQQfNQeMf0E9czzDBw* p;
};
struct tyObject_NimSeqPayload__40TpIbQQfNQeMf0E9czzDBw {
	NI cap;
	NimStringV2 data[SEQ_DECL_SIZE];
};
struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig {
	NI a;
	NI b;
};
struct tyObject_NimSeqV2__XHO6qbtQL6Yo0q1oajKWkw {
	NI len;
	tyObject_NimSeqPayload__381WimpkqKVRiIr1lhxEQA* p;
};
struct tyObject_NimSeqPayload__381WimpkqKVRiIr1lhxEQA {
	NI cap;
	NimStringV2 data[SEQ_DECL_SIZE];
};
struct tySequence__6j25whH7XTBoIXcM0x1T7A {
  NI len; tySequence__6j25whH7XTBoIXcM0x1T7A_Content* p;
};
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
struct tyTuple__9cdgeqdY7FRioNKBoD6G66A {
	NI Field0;
	NimStringV2 Field1;
	tyTuple__UV3llMMYFckfui8YMBuUZA Field2;
};
struct tyObject_NimSeqV2__mvS7yZmzkLtB9bhcvc9atD6A {
	NI len;
	tyObject_NimSeqPayload__bjUrAWkgJv530yQxlKTwkg* p;
};
struct tyObject_NimSeqPayload__bjUrAWkgJv530yQxlKTwkg {
	NI cap;
	tyTuple__9cdgeqdY7FRioNKBoD6G66A data[SEQ_DECL_SIZE];
};
struct tyObject_Defect__WFlDaIWu7hFOKoGSG7uH7g {
	Exception Sup;
};
struct tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg {
	tyObject_Defect__WFlDaIWu7hFOKoGSG7uH7g Sup;
};
typedef NU8 tyArray__9amPDC9cslxc3W1WNI8aK5gA[20];
struct tyObject_NimSeqV2__pqlDFC3CU9b7yhxYpu5zLhQ {
	NI len;
	tyObject_NimSeqPayload__Z5RrQYPm1Yz8sqF7utTx7Q* p;
};
struct tyObject_NimSeqPayload__Z5RrQYPm1Yz8sqF7utTx7Q {
	NI cap;
	tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__QnANZjr9bbFykJmClmY2b9cQ {
	NI len;
	tyObject_NimSeqPayload__ccVYQQMwnFZX6sMceS6iUw* p;
};
struct tyObject_NimSeqPayload__ccVYQQMwnFZX6sMceS6iUw {
	NI cap;
	tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE];
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tyObject_NimSeqV2__leUMr6KkmlAoo48M8CioZQ {
	NI len;
	tyObject_NimSeqPayload__ItQROW58gGeBOtCRbSJrPQ* p;
};
struct tyObject_NimSeqPayload__ItQROW58gGeBOtCRbSJrPQ {
	NI cap;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE];
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tyObject_NimSeqV2__q9boMy8mhBOdkslxyrVM05g {
	NI len;
	tyObject_NimSeqPayload__QsnCmrZp2km9cIOMZJvKjNg* p;
};
struct tyObject_NimSeqPayload__QsnCmrZp2km9cIOMZJvKjNg {
	NI cap;
	tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE];
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_NimSeqV2__XeVWWFuLkzmWdnv6Nxpo5w {
	NI len;
	tyObject_NimSeqPayload__aRseLOMn9c4JoSRmriNiugw* p;
};
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tyObject_NimSeqPayload__aRseLOMn9c4JoSRmriNiugw {
	NI cap;
	tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tyObject_NimSeqV2__tfNVrEviQRylDgr69bIF2PQ {
	NI len;
	tyObject_NimSeqPayload__y7oTNlyedm3Ce07Nr9cIzyg* p;
};
struct tyObject_NimSeqPayload__y7oTNlyedm3Ce07Nr9cIzyg {
	NI cap;
	tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE];
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tyObject_NimSeqV2__1l823tnWpfUy9cANEEejxPg {
	NI len;
	tyObject_NimSeqPayload__dJ2CxradV9adiIXkmHsG8Lw* p;
};
struct tyObject_NimSeqPayload__dJ2CxradV9adiIXkmHsG8Lw {
	NI cap;
	tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE];
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tyObject_NimSeqV2__4gA28oBPgxAGhj7tXEiiqw {
	NI len;
	tyObject_NimSeqPayload__08bsLIc9cknpzwJFrHSsc0w* p;
};
struct tyObject_NimSeqPayload__08bsLIc9cknpzwJFrHSsc0w {
	NI cap;
	tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE];
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tyObject_NimSeqV2__OH9acz2AtycIlvWRolvoaNA {
	NI len;
	tyObject_NimSeqPayload__lLVTTXn5ZKYsl9afpAy9ce4Q* p;
};
struct tyObject_NimSeqPayload__lLVTTXn5ZKYsl9afpAy9ce4Q {
	NI cap;
	tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE];
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tyObject_NimSeqV2__6bctsNj71c7TwckMfJfb1g {
	NI len;
	tyObject_NimSeqPayload__oE6qyrap71jgxNstzHAiQg* p;
};
struct tyObject_NimSeqPayload__oE6qyrap71jgxNstzHAiQg {
	NI cap;
	tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE];
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tyObject_NimSeqV2__c5hiGWTVLb0fIV9ae8w57Gw {
	NI len;
	tyObject_NimSeqPayload__aT4qJZQM9a6l4F5vjtFSZGQ* p;
};
struct tyObject_NimSeqPayload__aT4qJZQM9a6l4F5vjtFSZGQ {
	NI cap;
	tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE];
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_NimSeqV2__UVjWwOjJEIduaGR0AD4jzw {
	NI len;
	tyObject_NimSeqPayload__VRA8y5gOokZiYlpeofrQBQ* p;
};
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tyObject_NimSeqPayload__VRA8y5gOokZiYlpeofrQBQ {
	NI cap;
	tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE];
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw {
  NI len; tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content* p;
};
struct tyTuple__Oubp8LPEu86EPyDuc56AXg {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field0;
	NI Field1;
};
struct tyObject_NimSeqV2__Wzp3Ap879aFVENQEF8Qbb0A {
	NI len;
	tyObject_NimSeqPayload__Q9aTbDF780mmiKgw1sfNbag* p;
};
struct tyObject_NimSeqPayload__Q9aTbDF780mmiKgw1sfNbag {
	NI cap;
	tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA;
typedef NU8 tyEnum_NumericalBase__Ki1jCeoE9a08KI2ZuxsiYsQ;
typedef NU8 tySet_tyEnum_TokenSpacing__dJZPP3jSNSqIzHC3qEWRHg;
struct tyObject_Token__pst9a89bCqNyggpo6gRF7jhA {
	tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA tokType;
	tyEnum_NumericalBase__Ki1jCeoE9a08KI2ZuxsiYsQ base;
	tySet_tyEnum_TokenSpacing__dJZPP3jSNSqIzHC3qEWRHg spacing;
	NI indent;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
	NI64 iNumber;
	NF fNumber;
	NimStringV2 literal;
	NI line;
	NI col;
};
typedef NF tyArray__XxjPD9c5L6FNIAf8gnrQVdg[23];
typedef NIM_CHAR tyArray__zO5aBDTeiBNbpfX9cEBgeLA[500];
struct tySequence__shxop0zPIs5Ec3k71aCLuQ {
  NI len; tySequence__shxop0zPIs5Ec3k71aCLuQ_Content* p;
};
struct tyObject_NimSeqV2__zpIo9bPR9aKvxkrKqNdODGXQ {
	NI len;
	tyObject_NimSeqPayload__A5d1lLxIlLDjDoMqkeDyAA* p;
};
struct tyObject_NimSeqPayload__A5d1lLxIlLDjDoMqkeDyAA {
	NI cap;
	NIM_BOOL data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__rpt17CTZKhcmivfqWPh5Ng {
	NI len;
	tyObject_NimSeqPayload__YOjgUJccqS0z21apIzbjhw* p;
};
struct tyObject_NimSeqPayload__YOjgUJccqS0z21apIzbjhw {
	NI cap;
	NimStringV2 data[SEQ_DECL_SIZE];
};
struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ {
  NI len; tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content* p;
};
struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
};
struct tyObject_NimSeqV2__9b8Iun9akN0pmaswXV4xzNHw {
	NI len;
	tyObject_NimSeqPayload__NhGNL7A9cAki9adhGREqHjvQ* p;
};
struct tyObject_NimSeqPayload__NhGNL7A9cAki9adhGREqHjvQ {
	NI cap;
	tyTuple__kuMQ1fbjJlHtwKTmBGAe6g data[SEQ_DECL_SIZE];
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_NimSeqV2__hxkEoe2aqyVy2PvaqyFybw {
	NI len;
	tyObject_NimSeqPayload__huYzbmxw1CWqexrcdhCzVQ* p;
};
struct tyObject_NimSeqPayload__huYzbmxw1CWqexrcdhCzVQ {
	NI cap;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE];
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tySequence__T69aiRC686UsUPVrEM9awLDA {
  NI len; tySequence__T69aiRC686UsUPVrEM9awLDA_Content* p;
};
struct tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ {
	tyEnum_TokType__lTUY8lCIkO3nhCc7lqA4RA kind;
	NI32 length;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyObject_NimSeqV2__nzRDknQPEQ8tmY6MzxXfBA {
	NI len;
	tyObject_NimSeqPayload__B9ajNKqEmXQfFf759aVJOmDQ* p;
};
struct tyObject_NimSeqPayload__B9ajNKqEmXQfFf759aVJOmDQ {
	NI cap;
	tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__xawoyDHERXWhMB61uw9aFlw {
	NI len;
	tyObject_NimSeqPayload__1F9aVmKGgcmPPhU4J9cqdFeA* p;
};
struct tyObject_NimSeqPayload__1F9aVmKGgcmPPhU4J9cqdFeA {
	NI cap;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE];
};
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tyObject_NimSeqV2__zERsha2FLD27xkcyTtUe5w {
	NI len;
	tyObject_NimSeqPayload__4cPHQNh65eNeh02ZwhM4Vw* p;
};
struct tyObject_NimSeqPayload__4cPHQNh65eNeh02ZwhM4Vw {
	NI cap;
	tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE];
};
typedef NU8 tyArray__mXjDD1r0VWLRZmHnQfpVHA[8];
struct tyObject_NimSeqV2__wAKcmNV09bNcAakf5YD2A9aQ {
	NI len;
	tyObject_NimSeqPayload__J4VmartFf3o9c8SALClNLqQ* p;
};
struct tyObject_NimSeqPayload__J4VmartFf3o9c8SALClNLqQ {
	NI cap;
	NU32 data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__xirGUCq5Yeys036wjTr9a9ag {
	NI len;
	tyObject_NimSeqPayload__BvkI5Fb1Dely7cGpGug48w* p;
};
struct tyObject_NimSeqPayload__BvkI5Fb1Dely7cGpGug48w {
	NI cap;
	tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__O56sKEP9cSyEFKM0DbntvZg {
	NI len;
	tyObject_NimSeqPayload__CNYRHAW35ohZPTfy5ZiwWA* p;
};
struct tyObject_NimSeqPayload__CNYRHAW35ohZPTfy5ZiwWA {
	NI cap;
	NI64 data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__kwk4E3fMMEr4O39a8w9chcVQ {
	NI len;
	tyObject_NimSeqPayload__0uKoWoKwrj0zsXW2OSD9crg* p;
};
struct tyObject_NimSeqPayload__0uKoWoKwrj0zsXW2OSD9crg {
	NI cap;
	tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__G5wzdngs0i9cLnjn6UUm2QA {
	NI len;
	tyObject_NimSeqPayload__CiPf6Xv05KUQiXqTUxpsUA* p;
};
struct tyObject_NimSeqPayload__CiPf6Xv05KUQiXqTUxpsUA {
	NI cap;
	tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ {
	NI len;
	tyObject_NimSeqPayload__XiOLiKIdPX5U0AB70DNjbQ* p;
};
struct tyObject_NimSeqPayload__XiOLiKIdPX5U0AB70DNjbQ {
	NI cap;
	NI32 data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__d3fv9a69bbApweAbY7myMCAA {
	NI len;
	tyObject_NimSeqPayload__FxDYcVbzbzqu9bUx3WqGoTA* p;
};
struct tyObject_NimSeqPayload__FxDYcVbzbzqu9bUx3WqGoTA {
	NI cap;
	tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__ZAx4OSjx7H2DxJ9ad9avCPsg {
	NI len;
	tyObject_NimSeqPayload__fcGqxIwgjERIIBSj9aK2oxg* p;
};
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tyObject_NimSeqPayload__fcGqxIwgjERIIBSj9aK2oxg {
	NI cap;
	tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__tgxZ7KAKIYkBA1bom1fW8w {
	NI len;
	tyObject_NimSeqPayload__fjZ4qUgOZDh3YOPYb0LHnQ* p;
};
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tyObject_NimSeqPayload__fjZ4qUgOZDh3YOPYb0LHnQ {
	NI cap;
	tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__q7QzP045gko7DIG9ak9cJjvg {
	NI len;
	tyObject_NimSeqPayload__OlXaC6zsBmhDNWsqynhNbw* p;
};
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tyObject_NimSeqPayload__OlXaC6zsBmhDNWsqynhNbw {
	NI cap;
	tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tyObject_NimSeqV2__iXDsgW33GmsE2gY9cAOO11Q {
	NI len;
	tyObject_NimSeqPayload__YL9cEzDu8vsXEGN89csSy9crA* p;
};
struct tyObject_NimSeqPayload__YL9cEzDu8vsXEGN89csSy9crA {
	NI cap;
	tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__dCwFm7iJYKqQeZSIzKc0NA {
	NI len;
	tyObject_NimSeqPayload__mZuhNjviDK9b79bNVotwlwcw* p;
};
struct tyObject_NimSeqPayload__mZuhNjviDK9b79bNVotwlwcw {
	NI cap;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__gIwHLNdjfH4VRWhXpHypGA {
	NI len;
	tyObject_NimSeqPayload__5Z9a9aROEoDZcGRpcSYezyFg* p;
};
struct tyObject_NimSeqPayload__5Z9a9aROEoDZcGRpcSYezyFg {
	NI cap;
	tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__15maDR19bknK34amedd1PnQ {
	NI len;
	tyObject_NimSeqPayload__iyj5NYk2cU9bjed29aLoecBQ* p;
};
struct tyObject_NimSeqPayload__iyj5NYk2cU9bjed29aLoecBQ {
	NI cap;
	tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__eg19cQLnrM6yvo2xbN7Qm4g {
	NI len;
	tyObject_NimSeqPayload__3YPQ2gT1hEEt9cWshv20sYQ* p;
};
struct tyObject_NimSeqPayload__3YPQ2gT1hEEt9cWshv20sYQ {
	NI cap;
	tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__5K6YMLUzOBOQi9cm4I2oc9bg {
	NI len;
	tyObject_NimSeqPayload__u70jg4Sy9boIjAjNPaPSu6A* p;
};
struct tyObject_NimSeqPayload__u70jg4Sy9boIjAjNPaPSu6A {
	NI cap;
	tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__7j9aCEhtB2gWiMpaLpLmDAA {
	NI len;
	tyObject_NimSeqPayload__O4qEUBsg9a9aB9bssXf66dmrA* p;
};
struct tyObject_NimSeqPayload__O4qEUBsg9a9aB9bssXf66dmrA {
	NI cap;
	tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE];
};
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tyObject_NimSeqV2__ofH9blJDuzy7lLp0Nu79aa9cQ {
	NI len;
	tyObject_NimSeqPayload__OzmveoJODUPJyabeUsARrg* p;
};
struct tyObject_NimSeqPayload__OzmveoJODUPJyabeUsARrg {
	NI cap;
	tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__EnGyyCL9bP9bBkJIIw130JcA {
	NI len;
	tyObject_NimSeqPayload__xJHATr8XqGiTUvmTQdd1YA* p;
};
struct tyObject_NimSeqPayload__xJHATr8XqGiTUvmTQdd1YA {
	NI cap;
	NI32 data[SEQ_DECL_SIZE];
};
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tyObject_NimSeqV2__8dnVBQrNdN4aYbHrPCeE8Q {
	NI len;
	tyObject_NimSeqPayload__OkEdEJcYExex9clzIWp3Fcw* p;
};
struct tyObject_NimSeqPayload__OkEdEJcYExex9clzIWp3Fcw {
	NI cap;
	tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE];
};
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tyObject_NimSeqV2__whT1ft59bR5HcNlwxW9a1Sqw {
	NI len;
	tyObject_NimSeqPayload__wPuxrD4t1tdh9aWvKqI6vgg* p;
};
struct tyObject_NimSeqPayload__wPuxrD4t1tdh9aWvKqI6vgg {
	NI cap;
	tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE];
};
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_NimSeqV2__pxiTcguNzAbu0Rv0PQ7RSQ {
	NI len;
	tyObject_NimSeqPayload__3xRBpaE09cNEWepSBJ3qPrA* p;
};
struct tyObject_NimSeqPayload__3xRBpaE09cNEWepSBJ3qPrA {
	NI cap;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE];
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
struct tyObject_NimSeqV2__bvyB5GGuyrRUoSB3KTNeag {
	NI len;
	tyObject_NimSeqPayload__L1t9aLhHZkDv9c4TR4CmTx4A* p;
};
struct tyObject_NimSeqPayload__L1t9aLhHZkDv9c4TR4CmTx4A {
	NI cap;
	tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE];
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A {
  NI len; tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content* p;
};
struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* genericSym;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg concreteTypes;
	NI compilesId;
};
struct tySequence__lAikaRQvUF0uwNAz0U4FFA {
  NI len; tySequence__lAikaRQvUF0uwNAz0U4FFA_Content* p;
};
struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NimStringV2 name;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* path;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tyObject_NimSeqV2__9aXnq9c5fz5Q0hbWElxyLjIg {
	NI len;
	tyObject_NimSeqPayload__ZnfNx9cWQ79bKoiGpbxeUZ2w* p;
};
struct tyObject_NimSeqPayload__ZnfNx9cWQ79bKoiGpbxeUZ2w {
	NI cap;
	tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__C0nzvajqtOMam85eM9bZNSg {
	NI len;
	tyObject_NimSeqPayload__pOgCdk2AGTA5dRpCuIyXLw* p;
};
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tyObject_NimSeqPayload__pOgCdk2AGTA5dRpCuIyXLw {
	NI cap;
	tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__fIXSsXmSNpJjT79aD9b4Wj0Q {
	NI len;
	tyObject_NimSeqPayload__AtCLKjq0LXyy7Wjf5A3iug* p;
};
struct tyObject_NimSeqPayload__AtCLKjq0LXyy7Wjf5A3iug {
	NI cap;
	tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_PrefixMatch__ocee5pBJwvwPKYUp2SRA4g;
struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA {
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng section;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ qualifiedPath;
	NimStringV2* name;
	NimStringV2 filePath;
	NI line;
	NI column;
	NimStringV2 doc;
	NimStringV2 forth;
	NI quality;
	NIM_BOOL isGlobal;
	NIM_BOOL contextFits;
	tyEnum_PrefixMatch__ocee5pBJwvwPKYUp2SRA4g prefix;
	NU8 symkind;
	NI scope;
	NI localUsages;
	NI globalUsages;
	NI tokenLen;
	NI version;
	NU16 endLine;
	NI endCol;
	tyObject_SuggestInlayHintcolonObjectType___zpydc9br7HBXeBRDNSH9cTMw* inlayHintInfo;
};
struct tySequence__s3NGK5xFNK6fPmXupxoolA {
  NI len; tySequence__s3NGK5xFNK6fPmXupxoolA_Content* p;
};
struct tyObject_NimSeqV2__b1hMoRB6FiMpAnxWZ6XFFw {
	NI len;
	tyObject_NimSeqPayload__JA074cUO4pLwgRHNarz1Ag* p;
};
struct tyTuple__FFspgHRWev9aDuj0fEpj9bUw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NI Field1;
};
struct tyTuple__pX68bRYqY0ZF09cQ4s0LV9ag {
	NI Field0;
	tyTuple__FFspgHRWev9aDuj0fEpj9bUw Field1;
};
struct tyObject_NimSeqPayload__JA074cUO4pLwgRHNarz1Ag {
	NI cap;
	tyTuple__pX68bRYqY0ZF09cQ4s0LV9ag data[SEQ_DECL_SIZE];
};
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ {
  NI len; tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content* p;
};
struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val;
};
struct tyObject_NimSeqV2__e19bLuPKJ5Taf2cU0C9c19amQ {
	NI len;
	tyObject_NimSeqPayload__e9cx23BcmptS0R3g2j9cm8Ww* p;
};
struct tyObject_NimSeqPayload__e9cx23BcmptS0R3g2j9cm8Ww {
	NI cap;
	tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg data[SEQ_DECL_SIZE];
};
struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw {
  NI len; tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content* p;
};
struct tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* val;
};
struct tyObject_NimSeqV2__9bDdnwys3VzDJxw8wpw9aO7Q {
	NI len;
	tyObject_NimSeqPayload__7jYcYku9aPa9cFZyhvKlw7MA* p;
};
struct tyObject_NimSeqPayload__7jYcYku9aPa9cFZyhvKlw7MA {
	NI cap;
	tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__Ny5DgIVnJhWFNrwCKmbRfg {
	NI len;
	tyObject_NimSeqPayload__GaXw4OGVqFVkcJL41FVa2w* p;
};
struct tyObject_NimSeqPayload__GaXw4OGVqFVkcJL41FVa2w {
	NI cap;
	tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE];
};
struct tySequence__8Np6tlClE5az1CyqZdN19bQ {
  NI len; tySequence__8Np6tlClE5az1CyqZdN19bQ_Content* p;
};
struct tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q {
	NI len;
	tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw* p;
};
struct tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw {
	NI cap;
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ data[SEQ_DECL_SIZE];
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tyObject_NimSeqV2__zIWP3GSgEW4HknsQ2JyF0Q {
	NI len;
	tyObject_NimSeqPayload__tvrm3bhXgSCURMsqnwLaHg* p;
};
struct tyObject_NimSeqPayload__tvrm3bhXgSCURMsqnwLaHg {
	NI cap;
	tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE];
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tyObject_NimSeqV2__cULPdsW0S5F0FBVWVpLANw {
	NI len;
	tyObject_NimSeqPayload__9bmCK9aZILR9aqHJtn8GZl3zw* p;
};
struct tyObject_NimSeqPayload__9bmCK9aZILR9aqHJtn8GZl3zw {
	NI cap;
	tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE];
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tyObject_NimSeqV2__t9bcqkWC9bif6Sx19bvRvfOKQ {
	NI len;
	tyObject_NimSeqPayload__Ng0bSFZhIo7fHn3Ribr6KQ* p;
};
struct tyObject_NimSeqPayload__Ng0bSFZhIo7fHn3Ribr6KQ {
	NI cap;
	tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE];
};
struct tySequence__G9cHmkmNmy6ZlkFfXcex3Hw {
  NI len; tySequence__G9cHmkmNmy6ZlkFfXcex3Hw_Content* p;
};
struct tyObject_NimSeqV2__gU0kQm69bws9bBab8H9cxj9akg {
	NI len;
	tyObject_NimSeqPayload__h0EbKk00w6nXOIL0qL7dfw* p;
};
struct tyTuple__JqV0huqZNAHtnE3agKOyZg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
};
struct tyTuple__9ay7GjiPeMMFnmoYwk84apw {
	NI Field0;
	tyTuple__JqV0huqZNAHtnE3agKOyZg Field1;
};
struct tyObject_NimSeqPayload__h0EbKk00w6nXOIL0qL7dfw {
	NI cap;
	tyTuple__9ay7GjiPeMMFnmoYwk84apw data[SEQ_DECL_SIZE];
};
struct tySequence__GVxMaHC0xtgqjBZ8ubUwnA {
  NI len; tySequence__GVxMaHC0xtgqjBZ8ubUwnA_Content* p;
};
struct tyTuple__7SDQCf3TbPJf09bOXiapRgg {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tyObject_NimSeqV2__S1I41Ls1uuN23lNHHgFiYg {
	NI len;
	tyObject_NimSeqPayload__bJWoXcrO5IwDRDKMBghkbQ* p;
};
struct tyObject_NimSeqPayload__bJWoXcrO5IwDRDKMBghkbQ {
	NI cap;
	tyTuple__7SDQCf3TbPJf09bOXiapRgg data[SEQ_DECL_SIZE];
};
struct tySequence__3rs2HI7A9bn1iHmZchCo1lg {
  NI len; tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content* p;
};
struct tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	NimStringV2 Field1;
};
struct tyObject_NimSeqV2__QMj9cx3xUjX4pjRwTn9bDNzA {
	NI len;
	tyObject_NimSeqPayload__dYf6sGrYd9byl9b8o9cXNn7cA* p;
};
struct tyObject_NimSeqPayload__dYf6sGrYd9byl9b8o9cXNn7cA {
	NI cap;
	tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ data[SEQ_DECL_SIZE];
};
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q {
  NI len; tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content* p;
};
struct tyObject_NimSeqV2__ZBXm7zuh6K0BF7EzvKbK7A {
	NI len;
	tyObject_NimSeqPayload__sqb841zyAWqdT69cCiVqhTg* p;
};
struct tyObject_NimSeqPayload__sqb841zyAWqdT69cCiVqhTg {
	NI cap;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* data[SEQ_DECL_SIZE];
};
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ defaultCC;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* dynlib;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* otherPragmas;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
};
struct tySequence__9bffTLF0HkxjFCzZL8og4GA {
  NI len; tySequence__9bffTLF0HkxjFCzZL8og4GA_Content* p;
};
struct tyTuple__09aD69az7aYn14Gt61AHvLIA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
};
struct tyObject_NimSeqV2__TPbyeV159aGPhQnGwOLv0sQ {
	NI len;
	tyObject_NimSeqPayload__ejG43mfy2bZkAMGFTFM36Q* p;
};
struct tyObject_NimSeqPayload__ejG43mfy2bZkAMGFTFM36Q {
	NI cap;
	tyTuple__09aD69az7aYn14Gt61AHvLIA data[SEQ_DECL_SIZE];
};
struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ {
	NI len;
	void* p;
};
struct tyObject_NimSeqV2__nIHI3lsoB9bBOORuoqOEj7g {
	NI len;
	tyObject_NimSeqPayload__cNjQz1l4yr2UupmtFlt9b9aw* p;
};
struct tyObject_NimSeqPayload__cNjQz1l4yr2UupmtFlt9b9aw {
	NI cap;
	NI data[SEQ_DECL_SIZE];
};
struct tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ {
  NI len; tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ_Content* p;
};
struct tyObject_NimSeqV2__VMGr7rbYO7pG7IK2TH9bz7A {
	NI len;
	tyObject_NimSeqPayload__sdH682KR9csVt7Lylj9aZ3vQ* p;
};
struct tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q {
	NI dist;
	NI depth;
	NimStringV2 msg;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyObject_NimSeqPayload__sdH682KR9csVt7Lylj9aZ3vQ {
	NI cap;
	tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q data[SEQ_DECL_SIZE];
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyObject_NimSeqV2__U11gVpqEuLiRu2f9bIfVRAA {
	NI len;
	tyObject_NimSeqPayload__dDeJTSez5oo0HoO8Ee9cXRw* p;
};
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tyObject_NimSeqPayload__dDeJTSez5oo0HoO8Ee9cXRw {
	NI cap;
	tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE];
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tyObject_NimSeqV2__M1TtJBuzN40ZSG9a8yOFJFw {
	NI len;
	tyObject_NimSeqPayload__B9b0oZGG5UQ5nkTLq9c9ajIag* p;
};
struct tyObject_NimSeqPayload__B9b0oZGG5UQ5nkTLq9c9ajIag {
	NI cap;
	tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__9bQvx9cUUKun9bKhPG2a9bQj6Q {
	NI len;
	tyObject_NimSeqPayload__0fSGlyKGHqXGdDH314aZKg* p;
};
struct tyObject_NimSeqPayload__0fSGlyKGHqXGdDH314aZKg {
	NI cap;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__9aK7YX9bxlc8s2KV3wh8rdkA {
	NI len;
	tyObject_NimSeqPayload__5cCooviSXLEf9cwx1D5qZiA* p;
};
struct tyObject_NimSeqPayload__5cCooviSXLEf9cwx1D5qZiA {
	NI cap;
	tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw data[SEQ_DECL_SIZE];
};
struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA {
	NI a;
	NI b;
};
struct tyObject_NimSeqV2__bnJ5Yqhi12rJFQll9a29bK9aA {
	NI len;
	tyObject_NimSeqPayload__zg0c9cy2kBgbyKYkekGNBUw* p;
};
struct tyObject_NimSeqPayload__zg0c9cy2kBgbyKYkekGNBUw {
	NI cap;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* data[SEQ_DECL_SIZE];
};
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA {
  NI len; tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
void* ClE_0;
} tyProc__c9bXGQkBnyyGGVw063jrwZw;
struct tySequence__b9bG03Q6unwlMU0dM7uOPIA {
  NI len; tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content* p;
};
struct tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* label;
	tySequence__qwqHTkRvwhrRyENtudHQ7g fixups;
};
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA {
  NI len; tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content* p;
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  NI len; tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content* p;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  NI len; tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content* p;
};
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
	NI Field0;
	NimStringV2 Field1;
	NI Field2;
};
struct tyObject_NimSeqV2__qpKiDXWu1sjqjH7dOqAHZg {
	NI len;
	tyObject_NimSeqPayload__nJDGOm2EjMPf1emtsI5R8Q* p;
};
struct tyObject_NimSeqPayload__nJDGOm2EjMPf1emtsI5R8Q {
	NI cap;
	tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE];
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w {
  NI len; tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content* p;
};
struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ {
	NI h;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key;
	NI val;
};
struct tyObject_NimSeqV2__ZymipdgL8Pm9bmfGa9cwYJiQ {
	NI len;
	tyObject_NimSeqPayload__2Cej9bEoiMQ2LZffLyml1CQ* p;
};
struct tyObject_NimSeqPayload__2Cej9bEoiMQ2LZffLyml1CQ {
	NI cap;
	tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__dAgwP2JJ1PDwPMpu9bzwC0w {
	NI len;
	tyObject_NimSeqPayload__6xdpt2WgX9aW6Q639cRU5Rzw* p;
};
struct tyObject_NimSeqPayload__6xdpt2WgX9aW6Q639cRU5Rzw {
	NI cap;
	tyProc__c9bXGQkBnyyGGVw063jrwZw data[SEQ_DECL_SIZE];
};
typedef NCSTRING tyUncheckedArray__nvS6J9clHMUMHfoZd8Ad2zg[1];
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ {
  NI len; tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content* p;
};
struct tyObject_NimSeqV2__HCcpPoYfekFJRNu9c9bYZ9bsQ {
	NI len;
	tyObject_NimSeqPayload__6sY7wgvPGYvtAbG0tdSxiw* p;
};
struct tyObject_NimSeqPayload__6sY7wgvPGYvtAbG0tdSxiw {
	NI cap;
	NU8 data[SEQ_DECL_SIZE];
};
struct tySequence__4eQHGndY6XBYpFOH09apV8Q {
  NI len; tySequence__4eQHGndY6XBYpFOH09apV8Q_Content* p;
};
struct tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA {
	NI len;
	tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw* p;
};
struct tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw {
	NI cap;
	tyTuple__UV3llMMYFckfui8YMBuUZA data[SEQ_DECL_SIZE];
};
struct tySequence__e9ciFfeAg1p88UzCBnAPeVQ {
  NI len; tySequence__e9ciFfeAg1p88UzCBnAPeVQ_Content* p;
};
struct tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg {
	NI Field0;
	NI64 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tyObject_NimSeqV2__Zsjz8m9cC0NIjfk437Kkqag {
	NI len;
	tyObject_NimSeqPayload__Wh3Dn4q89bjoiLSTUCUOTew* p;
};
struct tyObject_NimSeqPayload__Wh3Dn4q89bjoiLSTUCUOTew {
	NI cap;
	tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg data[SEQ_DECL_SIZE];
};
struct tySequence__GyTgETkn69b26Etj2zBgjMw {
  NI len; tySequence__GyTgETkn69b26Etj2zBgjMw_Content* p;
};
typedef NU8 tyEnum_ParserState__0xxCjL29aD8tzUEg49aPYfOw;
struct tyObject_NimSeqV2__sXtLBbV79ah32PP02mMBiTQ {
	NI len;
	tyObject_NimSeqPayload__Ijs8YZfDA75rhEW1XeXk2w* p;
};
struct tyObject_NimSeqPayload__Ijs8YZfDA75rhEW1XeXk2w {
	NI cap;
	tyEnum_ParserState__0xxCjL29aD8tzUEg49aPYfOw data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__diajJmNo8grsMWW9cZq9bErQ {
	NI len;
	tyObject_NimSeqPayload__GkrJrbi1Vf8NOdxV9aOX4vA* p;
};
struct tyObject_NimSeqPayload__GkrJrbi1Vf8NOdxV9aOX4vA {
	NI cap;
	NU64 data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__y9bG85c5b3IiBNTnDEhDeCQ {
	NI len;
	tyObject_NimSeqPayload__8VWGiLi1AaEJ9bSMNLWx3Vw* p;
};
struct tyObject_NimSeqPayload__8VWGiLi1AaEJ9bSMNLWx3Vw {
	NI cap;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA data[SEQ_DECL_SIZE];
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q {
  NI len; tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content* p;
};
struct tyObject_NimSeqV2__J80ntPleGVJXp9bYXSkOm4g {
	NI len;
	tyObject_NimSeqPayload__OuLlEOw03e2DVzzSxes2OQ* p;
};
struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg {
	NI32 pc;
	NI32 usedRegisters;
};
struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g {
	NI Field0;
	NI Field1;
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg Field2;
};
struct tyObject_NimSeqPayload__OuLlEOw03e2DVzzSxes2OQ {
	NI cap;
	tyTuple__y6bKAf9a9aaVwun6lVDxSX7g data[SEQ_DECL_SIZE];
};
struct tySequence__mnb4N9bRCddoL53waHA7kHQ {
  NI len; tySequence__mnb4N9bRCddoL53waHA7kHQ_Content* p;
};
struct tyTuple__bxYrf1dnwYK6GanDNddhgQ {
	NI Field0;
	NI Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tyObject_NimSeqV2__o4fdV7x241MdiPUXNS1Raw {
	NI len;
	tyObject_NimSeqPayload__S9csvyUBElFwh9cdA9bfA79bNA* p;
};
struct tyObject_NimSeqPayload__S9csvyUBElFwh9cdA9bfA79bNA {
	NI cap;
	tyTuple__bxYrf1dnwYK6GanDNddhgQ data[SEQ_DECL_SIZE];
};
struct tySequence__R1mQMFmsdp1ChoJDXa9a0xQ {
  NI len; tySequence__R1mQMFmsdp1ChoJDXa9a0xQ_Content* p;
};
struct tyTuple__rczUtx07rG4YmHOEmcEUJw {
	NI Field0;
	NI Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tyObject_NimSeqV2__Lzxy9cA5Rb33mtr2JHP9brzg {
	NI len;
	tyObject_NimSeqPayload__b9bbw4QVkyKerVSGwvbdccQ* p;
};
struct tyObject_NimSeqPayload__b9bbw4QVkyKerVSGwvbdccQ {
	NI cap;
	tyTuple__rczUtx07rG4YmHOEmcEUJw data[SEQ_DECL_SIZE];
};
struct tySequence__tt8kXsbz31MUMFUF6Q9aQuQ {
  NI len; tySequence__tt8kXsbz31MUMFUF6Q9aQuQ_Content* p;
};
struct tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val;
};
struct tyObject_NimSeqV2__0LodDvQr7DY8VoMTmn0gQQ {
	NI len;
	tyObject_NimSeqPayload__oi8YBrQ80CA2zAfCI7jsQA* p;
};
struct tyObject_NimSeqPayload__oi8YBrQ80CA2zAfCI7jsQA {
	NI cap;
	tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg data[SEQ_DECL_SIZE];
};
struct tySequence__kQFByJmZecfF9a1LYqz7zYg {
  NI len; tySequence__kQFByJmZecfF9a1LYqz7zYg_Content* p;
};
struct tyObject_NimSeqV2__lC1hOTcTO87hw9bWuOAbM2g {
	NI len;
	tyObject_NimSeqPayload__k8khOtl7aYqusxo9bGR3rQA* p;
};
struct tyObject_State__HKH8xQquLWVVc5hqriE25Q {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* label;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* excLandingState;
	NIM_BOOL inlinable;
	NIM_BOOL deletable;
};
struct tyObject_NimSeqPayload__k8khOtl7aYqusxo9bGR3rQA {
	NI cap;
	tyObject_State__HKH8xQquLWVVc5hqriE25Q data[SEQ_DECL_SIZE];
};
struct tySequence__kP47rw9c8bgVA53QKWe9bp7g {
  NI len; tySequence__kP47rw9c8bgVA53QKWe9bp7g_Content* p;
};
struct tyObject_NimSeqV2__aKUzzy2BRdkBxUZZR9bCG8w {
	NI len;
	tyObject_NimSeqPayload__9bmbJLvM9bUDGfEL9aJJFJ2gg* p;
};
struct tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	NI Field2;
};
struct tyObject_NimSeqPayload__9bmbJLvM9bUDGfEL9aJJFJ2gg {
	NI cap;
	tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw data[SEQ_DECL_SIZE];
};
struct tySequence__qff4v1r3n1JKmy1NzJOChA {
  NI len; tySequence__qff4v1r3n1JKmy1NzJOChA_Content* p;
};
struct tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* label;
};
struct tyObject_NimSeqV2__JeoY27Pa9c4R0cGDrOzzfuw {
	NI len;
	tyObject_NimSeqPayload__u09cKovRhfBEvwzI8DLG51A* p;
};
struct tyObject_NimSeqPayload__u09cKovRhfBEvwzI8DLG51A {
	NI cap;
	tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw data[SEQ_DECL_SIZE];
};
struct tySequence__grdS5PdBBxkq9bxi4lFAdAw {
  NI len; tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content* p;
};
struct tyObject_NimSeqV2__Vd5JoD8wWcbD6k2tc9b28YA {
	NI len;
	tyObject_NimSeqPayload__zIcZNLCZJO9bK3dKATuA4aA* p;
};
typedef NU8 tyEnum_TSlotKind__oo9bgjIHoNBV9c9cKJRycJW4A;
struct tyTuple__9ap1MJ9bVBlP34AqrUq01n8w {
	NIM_BOOL Field0;
	tyEnum_TSlotKind__oo9bgjIHoNBV9c9cKJRycJW4A Field1;
};
struct tyObject_NimSeqPayload__zIcZNLCZJO9bK3dKATuA4aA {
	NI cap;
	tyTuple__9ap1MJ9bVBlP34AqrUq01n8w data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__SV7rrCQn9cRoWKHTGChlSgg {
	NI len;
	tyObject_NimSeqPayload__YkZ78cEwLiT49csnUl1ZM7Q* p;
};
struct tyObject_NimSeqPayload__YkZ78cEwLiT49csnUl1ZM7Q {
	NI cap;
	NI data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__IKAN89cMTsMj9cqIMW3TeGDQ {
	NI len;
	tyObject_NimSeqPayload__ny1pnHdrVxdJu0cxGMS9cUA* p;
};
struct tyObject_NimSeqPayload__ny1pnHdrVxdJu0cxGMS9cUA {
	NI cap;
	tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA data[SEQ_DECL_SIZE];
};
struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA {
  NI len; tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content* p;
};
typedef NU8 tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA;
struct tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A {
	tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA kind;
union{
	NI64 intVal;
	NF floatVal;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* regAddr;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** nodeAddr;
};
};
struct tyObject_NimSeqV2__RKcuYGEqMOT1amULBWqJ5w {
	NI len;
	tyObject_NimSeqPayload__PS0QbMt2xGKSjAh0h609cSw* p;
};
struct tyObject_NimSeqPayload__PS0QbMt2xGKSjAh0h609cSw {
	NI cap;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A data[SEQ_DECL_SIZE];
};
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw {
  NI len; tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content* p;
};
struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
};
struct tyObject_NimSeqV2__rxauo4ztHD3oKCBNw6YZdQ {
	NI len;
	tyObject_NimSeqPayload__Npgmi4jcd6ILOol9cT13nsA* p;
};
struct tyObject_NimSeqPayload__Npgmi4jcd6ILOol9cT13nsA {
	NI cap;
	tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ data[SEQ_DECL_SIZE];
};
struct tySequence__hMc5eJjVGjq6i857yHjTtg {
  NI len; tySequence__hMc5eJjVGjq6i857yHjTtg_Content* p;
};
struct tyTuple__Wipq1508vNWp3jwczem6TQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	NI Field1;
};
struct tyObject_NimSeqV2__8Rn9aEpI9bjowSiva9cw60GCA {
	NI len;
	tyObject_NimSeqPayload__EFYfInpTvq5UuayU59c5baw* p;
};
struct tyObject_NimSeqPayload__EFYfInpTvq5UuayU59c5baw {
	NI cap;
	tyTuple__Wipq1508vNWp3jwczem6TQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__ynMyB4FKj1HYwsLlDC7vBw {
	NI len;
	tyObject_NimSeqPayload__IucIGHa7Bf2A1RksuF5C6A* p;
};
struct tyObject_NimSeqPayload__IucIGHa7Bf2A1RksuF5C6A {
	NI cap;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE];
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tyObject_NimSeqV2__FfnYizxy8EW3T73hRy9bWzQ {
	NI len;
	tyObject_NimSeqPayload__1RCWgTQyEDGzZv39a0L0udg* p;
};
struct tyObject_NimSeqPayload__1RCWgTQyEDGzZv39a0L0udg {
	NI cap;
	tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE];
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tyObject_NimSeqV2__2xPIecK5aI1kPl45dNVVfg {
	NI len;
	tyObject_NimSeqPayload__Wj9bKru2STjGwpTlwyUrEVA* p;
};
struct tyObject_NimSeqPayload__Wj9bKru2STjGwpTlwyUrEVA {
	NI cap;
	tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE];
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyObject_NimSeqV2__P3nKlTxWcYJ29bn9aOCrEnFQ {
	NI len;
	tyObject_NimSeqPayload__qPCxF3TEe9c5GUYvcQEpaFw* p;
};
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tyObject_NimSeqPayload__qPCxF3TEe9c5GUYvcQEpaFw {
	NI cap;
	tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE];
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tyObject_NimSeqV2__h3xmmlVt9cH1Qr9a6iHd7FGw {
	NI len;
	tyObject_NimSeqPayload__rXin5DrZ8p5RYP2zMTAsqg* p;
};
struct tyObject_NimSeqPayload__rXin5DrZ8p5RYP2zMTAsqg {
	NI cap;
	tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE];
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_NimSeqV2__TFl78m7ywyQTyT4zs389bvg {
	NI len;
	tyObject_NimSeqPayload__6YewsLaF0A0PiS3nEaN55g* p;
};
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tyObject_NimSeqPayload__6YewsLaF0A0PiS3nEaN55g {
	NI cap;
	tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__WKgwRMN0CacAqOQYQOKBLA {
	NI len;
	tyObject_NimSeqPayload__a9auZ41pjiQ5WdoFl1yp8cQ* p;
};
struct tyObject_NimSeqPayload__a9auZ41pjiQ5WdoFl1yp8cQ {
	NI cap;
	tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE];
};
struct tySequence__9bnh9aVmYtKU19btQYqjGktpw {
  NI len; tySequence__9bnh9aVmYtKU19btQYqjGktpw_Content* p;
};
struct tyObject_NimSeqV2__dA1wyhF6YAalw2FgXpZhDA {
	NI len;
	tyObject_NimSeqPayload__9cpmPeVfo2tmpvqIDmFkCqg* p;
};
typedef NU8 tyEnum_MismatchKind__tCBkaULCeQ37WxmTYkr1fA;
struct tyObject_MismatchInfo__cZtjSeBU42Tc8gk2KTbArg {
	tyEnum_MismatchKind__tCBkaULCeQ37WxmTYkr1fA kind;
	NI arg;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* formal;
};
struct tyObject_CandidateError__f049c8Bs49cqj6FTSrUbSmlw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	tyObject_MismatchInfo__cZtjSeBU42Tc8gk2KTbArg firstMismatch;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ diagnostics;
	NIM_BOOL enabled;
};
struct tyObject_NimSeqPayload__9cpmPeVfo2tmpvqIDmFkCqg {
	NI cap;
	tyObject_CandidateError__f049c8Bs49cqj6FTSrUbSmlw data[SEQ_DECL_SIZE];
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  NI len; tySequence__E8pi9b5QNahsURYzXMjh3qw_Content* p;
};
struct tyObject_NimSeqV2__sc8fuyIvxojcmS9bBvqLxng {
	NI len;
	tyObject_NimSeqPayload__B8Tj3xNm54sxzmyOvDK9buw* p;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
	NI Field0;
	NI Field1;
	NI Field2;
};
struct tyObject_NimSeqPayload__B8Tj3xNm54sxzmyOvDK9buw {
	NI cap;
	tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE];
};
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ {
  NI len; tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content* p;
};
struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tyObject_NimSeqV2__Bu9cf9czC9bYB6tHrNlJa7NEw {
	NI len;
	tyObject_NimSeqPayload__i8t2GAhLNb8T7aVoeBs9coQ* p;
};
struct tyObject_NimSeqPayload__i8t2GAhLNb8T7aVoeBs9coQ {
	NI cap;
	tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ data[SEQ_DECL_SIZE];
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w {
  NI len; tySequence__3B6hFqG0Do0FxDvnNucL7w_Content* p;
};
struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw {
	NI Field0;
	NI Field1;
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ Field2;
};
struct tyObject_NimSeqV2__I17vTDmIw29a0CEB70d9cORg {
	NI len;
	tyObject_NimSeqPayload__x9aM4VUlFe9b5WPkSKx1M5xw* p;
};
struct tyObject_NimSeqPayload__x9aM4VUlFe9b5WPkSKx1M5xw {
	NI cap;
	tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw data[SEQ_DECL_SIZE];
};
struct tySequence__cLt1WK9c8DYlNqjYIVmv5sQ {
  NI len; tySequence__cLt1WK9c8DYlNqjYIVmv5sQ_Content* p;
};
struct tyTuple__c0qUCL3KxsVjGYwcv7lQbg {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
};
struct tyObject_NimSeqV2__RtCW0qtva9cK9bFzmU7PMOLg {
	NI len;
	tyObject_NimSeqPayload__rpimNUpF6ccwA7ypdSrQWw* p;
};
struct tyObject_NimSeqPayload__rpimNUpF6ccwA7ypdSrQWw {
	NI cap;
	tyTuple__c0qUCL3KxsVjGYwcv7lQbg data[SEQ_DECL_SIZE];
};
struct tySequence__bdNIx7Bah2llfuqeoTJEWQ {
  NI len; tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content* p;
};
struct tyTuple__kIcKc1aSJCixG4QCidyBAg {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ Field0;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw Field1;
};
struct tyObject_NimSeqV2__dURlRCOu2lYEvQwyIoAgZA {
	NI len;
	tyObject_NimSeqPayload__QJ6YtTltEHLQKSZzLY9bfhw* p;
};
struct tyObject_NimSeqPayload__QJ6YtTltEHLQKSZzLY9bfhw {
	NI cap;
	tyTuple__kIcKc1aSJCixG4QCidyBAg data[SEQ_DECL_SIZE];
};
struct tySequence__Cw89anHgi6Xla7dgB7Unvmw {
  NI len; tySequence__Cw89anHgi6Xla7dgB7Unvmw_Content* p;
};
struct tyObject_NimSeqV2__XHKiD6lzOPT9aB4caeVEgLQ {
	NI len;
	tyObject_NimSeqPayload__kkWZaAriZFdnsJD9c6W9cA9cg* p;
};
struct tyObject_NimSeqPayload__kkWZaAriZFdnsJD9c6W9cA9cg {
	NI cap;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA data[SEQ_DECL_SIZE];
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tyObject_NimSeqV2__GQxVYv6jCApzJGKP0DuOLw {
	NI len;
	tyObject_NimSeqPayload__Mei9cQiRsNTTJpKxjce4tmw* p;
};
struct tyObject_NimSeqPayload__Mei9cQiRsNTTJpKxjce4tmw {
	NI cap;
	tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE];
};
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tyObject_NimSeqV2__jk36KpuK5gnIkJBaojY7cw {
	NI len;
	tyObject_NimSeqPayload__p3jFcjgXmywN1ZHZWKfD1g* p;
};
struct tyObject_NimSeqPayload__p3jFcjgXmywN1ZHZWKfD1g {
	NI cap;
	tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE];
};
struct tySequence__SyrQ8FqS1U0ZKpu8mJO6PQ {
  NI len; tySequence__SyrQ8FqS1U0ZKpu8mJO6PQ_Content* p;
};
struct tyObject_NimSeqV2__w3p9aOA1mt9c9aAlQDg0rXtcA {
	NI len;
	tyObject_NimSeqPayload__N3A0BvLnhreSPuUndSdBQg* p;
};
typedef NU8 tyEnum_VarIndexKind__nDbuBc9bkPR0imwvpV80ARA;
struct tyObject_Connection__msVk44inLNF9bGoW0TwTG0Q {
	tyEnum_VarIndexKind__nDbuBc9bkPR0imwvpV80ARA kind;
union{
	NI parent;
	NI graphIndex;
};
};
typedef NU8 tySet_tyEnum_VarFlag__aOzmnZO0GBH6j9b7ZHYDeIQ;
struct tyObject_VarIndex__xDnEx9cq41ypm0l6yI8haPg {
	tyObject_Connection__msVk44inLNF9bGoW0TwTG0Q con;
	tySet_tyEnum_VarFlag__aOzmnZO0GBH6j9b7ZHYDeIQ flags;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI reassignedTo;
	NI aliveStart;
	NI aliveEnd;
	tySequence__qwqHTkRvwhrRyENtudHQ7g borrowsFrom;
};
struct tyObject_NimSeqPayload__N3A0BvLnhreSPuUndSdBQg {
	NI cap;
	tyObject_VarIndex__xDnEx9cq41ypm0l6yI8haPg data[SEQ_DECL_SIZE];
};
struct tySequence__9aee2Loc4nE9bvjjGuhsI78w {
  NI len; tySequence__9aee2Loc4nE9bvjjGuhsI78w_Content* p;
};
struct tyObject_NimSeqV2__MH13ExfdlzA45QmDNC3o6A {
	NI len;
	tyObject_NimSeqPayload__V8SGPvr2NEEheXGIwTmAJw* p;
};
typedef NU8 tySet_tyEnum_SubgraphFlag__P9bPHnAa9aKW9bv9ac9cLB19cWbA;
struct tyObject_MutationInfo__PxsvdgDRugMnwwZP8bDvWA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA mutatedHere;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA connectedVia;
	tySet_tyEnum_SubgraphFlag__P9bPHnAa9aKW9bv9ac9cLB19cWbA flags;
	NI maxMutation;
	NI minConnection;
	tySequence__qwqHTkRvwhrRyENtudHQ7g mutations;
};
struct tyObject_NimSeqPayload__V8SGPvr2NEEheXGIwTmAJw {
	NI cap;
	tyObject_MutationInfo__PxsvdgDRugMnwwZP8bDvWA data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__7t9bU3EneK6dsyc6g2BJtmQ {
	NI len;
	tyObject_NimSeqPayload__qzrKbs9a7A8QyfauyMVqfVw* p;
};
struct tyObject_NimSeqPayload__qzrKbs9a7A8QyfauyMVqfVw {
	NI cap;
	NI data[SEQ_DECL_SIZE];
};
struct tySequence__dAjyAaabi52TN36Jp0fAXQ {
  NI len; tySequence__dAjyAaabi52TN36Jp0fAXQ_Content* p;
};
struct tyObject_NimSeqV2__8Ls8O4CloMJdhVQXyzD0RQ {
	NI len;
	tyObject_NimSeqPayload__pgWZugySAfNMGzNhuS9b5zw* p;
};
struct tyTuple__X9bWVAqRSgByRpQwn6owzEA {
	NI Field0;
	NI Field1;
	NI16 Field2;
};
struct tyObject_NimSeqPayload__pgWZugySAfNMGzNhuS9b5zw {
	NI cap;
	tyTuple__X9bWVAqRSgByRpQwn6owzEA data[SEQ_DECL_SIZE];
};
struct tySequence__4SBkVvm2CCxNvzruVhJR5g {
  NI len; tySequence__4SBkVvm2CCxNvzruVhJR5g_Content* p;
};
struct tyObject_NimSeqV2__aXUYM59cElXn09cIUizjfk5w {
	NI len;
	tyObject_NimSeqPayload__Dp9bVzDpNllghV0L9c9bLiBdQ* p;
};
struct tyObject_NimSeqPayload__Dp9bVzDpNllghV0L9c9bLiBdQ {
	NI cap;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA data[SEQ_DECL_SIZE];
};
struct tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg {
  NI len; tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg_Content* p;
};
struct tyObject_NimSeqV2__X8EcnzlUu7HSxH3DvM59aWA {
	NI len;
	tyObject_NimSeqPayload__8vZEjNj21w0FevtnLFKUZA* p;
};
typedef NU8 tyEnum_Nilability__dSflzd1x9b2hnEWhJ29aqYgg;
struct tyObject_NimSeqPayload__8vZEjNj21w0FevtnLFKUZA {
	NI cap;
	tyEnum_Nilability__dSflzd1x9b2hnEWhJ29aqYgg data[SEQ_DECL_SIZE];
};
struct tySequence__xKcKU9c79cy1NlvTXGoOtyWg {
  NI len; tySequence__xKcKU9c79cy1NlvTXGoOtyWg_Content* p;
};
struct tySequence__tgZNpA9ayNCNeNkBBBthFtA {
  NI len; tySequence__tgZNpA9ayNCNeNkBBBthFtA_Content* p;
};
struct tyObject_NimSeqV2__iDl3hAQU2o8nEd0sv7D22w {
	NI len;
	tyObject_NimSeqPayload__FqetbPaJVPjS9cTFy00BByA* p;
};
struct tyObject_NimSeqPayload__FqetbPaJVPjS9cTFy00BByA {
	NI cap;
	tySequence__tgZNpA9ayNCNeNkBBBthFtA data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__d9aGqq8cRSUYOH2ZnoeagyQ {
	NI len;
	tyObject_NimSeqPayload__eAiAVcRO27GDld9cTI4uQ5g* p;
};
struct tyObject_NimSeqPayload__eAiAVcRO27GDld9cTI4uQ5g {
	NI cap;
	NI data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TransitionKind__9amM3JyQmWNhkq8kJSRGbPw;
struct tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyEnum_Nilability__dSflzd1x9b2hnEWhJ29aqYgg nilability;
	tyEnum_TransitionKind__9amM3JyQmWNhkq8kJSRGbPw kind;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node;
};
struct tyObject_NimSeqV2__5NIkFqw0MXPqP3gAo8VKkg {
	NI len;
	tyObject_NimSeqPayload__lxJT9bkQbAv4qUaBg9biquXA* p;
};
struct tyObject_NimSeqPayload__lxJT9bkQbAv4qUaBg9biquXA {
	NI cap;
	tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg data[SEQ_DECL_SIZE];
};
struct tySequence__XlRvVllIQIinot2wpb0XoA {
  NI len; tySequence__XlRvVllIQIinot2wpb0XoA_Content* p;
};
struct tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	tyEnum_Nilability__dSflzd1x9b2hnEWhJ29aqYgg Field1;
};
struct tyObject_NimSeqV2__BIZZLwYPl9bMX4kh49cOm8ug {
	NI len;
	tyObject_NimSeqPayload__f9aJ3DJ19bOybfz9csIEAlJmQ* p;
};
struct tyObject_NimSeqPayload__f9aJ3DJ19bOybfz9csIEAlJmQ {
	NI cap;
	tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ data[SEQ_DECL_SIZE];
};
struct tySequence__1I4GqOPEtd9ark9cZ2UT20tw {
  NI len; tySequence__1I4GqOPEtd9ark9cZ2UT20tw_Content* p;
};
struct tyObject_NimSeqV2__cNovT9bfrplyGcQDd85WPvA {
	NI len;
	tyObject_NimSeqPayload__cWSeCEBJE04j6OCqaWmaSA* p;
};
struct tyTuple__PijKblgFKtbdIstVEwjmCw {
	NI Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
};
struct tyObject_NimSeqPayload__cWSeCEBJE04j6OCqaWmaSA {
	NI cap;
	tyTuple__PijKblgFKtbdIstVEwjmCw data[SEQ_DECL_SIZE];
};
struct tySequence__4j8aBmBZMD9chZMBaxw9bcbQ {
  NI len; tySequence__4j8aBmBZMD9chZMBaxw9bcbQ_Content* p;
};
struct tyTuple__IYAk6y4YHp5OEJgCALGjQw {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tyObject_NimSeqV2__mgt4xlAYkzCTQ2AEneHZUg {
	NI len;
	tyObject_NimSeqPayload__RYHs8BhC4WIrAf3hAV2mZw* p;
};
struct tyObject_NimSeqPayload__RYHs8BhC4WIrAf3hAV2mZw {
	NI cap;
	tyTuple__IYAk6y4YHp5OEJgCALGjQw data[SEQ_DECL_SIZE];
};
struct tySequence__yo9alHJGzX03OXpfmEsBjBQ {
  NI len; tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content* p;
};
struct tyTuple__R9cYIordoMujN7rycr4Y7kw {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	NI Field1;
};
struct tyObject_NimSeqV2__x0llOOJlbc9a9bfR3yxGso7A {
	NI len;
	tyObject_NimSeqPayload__zoa5ddi9cHbXBirfGRCnd9aQ* p;
};
struct tyObject_NimSeqPayload__zoa5ddi9cHbXBirfGRCnd9aQ {
	NI cap;
	tyTuple__R9cYIordoMujN7rycr4Y7kw data[SEQ_DECL_SIZE];
};
struct tySequence__SxRJJ9bayPyj0RYzIZTiohA {
  NI len; tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content* p;
};
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
struct tyObject_NimSeqV2__UytTSnla1kFXxGvp8gQ9aHw {
	NI len;
	tyObject_NimSeqPayload__xAW5NovMwE9a9b1eN9cJ9b1a7g* p;
};
struct tyObject_NimSeqPayload__xAW5NovMwE9a9b1eN9cJ9b1a7g {
	NI cap;
	tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw data[SEQ_DECL_SIZE];
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  NI len; tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content* p;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
	NI Field0;
	NI Field1;
	tySequence__qwqHTkRvwhrRyENtudHQ7g Field2;
};
struct tyObject_NimSeqV2__9btI3rjW0aBVdnbJCkK3HwQ {
	NI len;
	tyObject_NimSeqPayload__cIDc6ijU1sfiv43zX9awuvw* p;
};
struct tyObject_NimSeqPayload__cIDc6ijU1sfiv43zX9awuvw {
	NI cap;
	tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE];
};
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw {
  NI len; tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content* p;
};
struct tyObject_NimSeqV2__zQpJJUpO49adzwEvtl2krQA {
	NI len;
	tyObject_NimSeqPayload__VJdFAAZtcNZ4cOMpSmdLHw* p;
};
typedef NU8 tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ;
struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m;
	tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ mode;
union{
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA imported;
} _mode_2;
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA exceptSet;
} _mode_3;
};
};
struct tyObject_NimSeqPayload__VJdFAAZtcNZ4cOMpSmdLHw {
	NI cap;
	tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw data[SEQ_DECL_SIZE];
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  NI len; tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content* p;
};
struct tyObject_NimSeqV2__AITKefZbNVuXMg9az9b5SUDw {
	NI len;
	tyObject_NimSeqPayload__8f5w800P5K7g04o5MnuJZg* p;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
	NI Field0;
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tyObject_NimSeqPayload__8f5w800P5K7g04o5MnuJZg {
	NI cap;
	tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE];
};
struct tySequence__zpKGgayc1mFyemMGMuK9a2w {
  NI len; tySequence__zpKGgayc1mFyemMGMuK9a2w_Content* p;
};
struct tyTuple__w31HlKXGH5QCPFggOmKfbQ {
	NimStringV2 Field0;
	NI32 Field1;
};
struct tyTuple__DfjLoSEvFkvlneCb5GSa9cQ {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyTuple__w31HlKXGH5QCPFggOmKfbQ Field2;
};
struct tyObject_NimSeqV2__Tg51nuRTSn1RaKhJaazjFQ {
	NI len;
	tyObject_NimSeqPayload__u9cIZq8cS7q3ggB6KdsCNVQ* p;
};
struct tyObject_NimSeqPayload__u9cIZq8cS7q3ggB6KdsCNVQ {
	NI cap;
	tyTuple__DfjLoSEvFkvlneCb5GSa9cQ data[SEQ_DECL_SIZE];
};
struct tySequence__9cbEQVGky3gHl4QEC3q4Sow {
  NI len; tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content* p;
};
struct tyTuple__GhsGHTmri9bgdv8XapNtpTg {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	NimStringV2 Field2;
};
struct tyObject_NimSeqV2__9asO9cshOF4y9cfdguzBg29a7A {
	NI len;
	tyObject_NimSeqPayload__zNLeo3X29akF2Ap409cLy3lw* p;
};
struct tyObject_NimSeqPayload__zNLeo3X29akF2Ap409cLy3lw {
	NI cap;
	tyTuple__GhsGHTmri9bgdv8XapNtpTg data[SEQ_DECL_SIZE];
};
struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg {
  NI len; tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content* p;
};
struct tyObject_NimSeqV2__PtLz9bQbFWDN9aLSpHtqdEmA {
	NI len;
	tyObject_NimSeqPayload__0KWqNVfFHBrBbvQ3rkt2qw* p;
};
struct tyTuple__9agFg9cuYsNvckAbTfHAsTSA {
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field0;
	NI Field1;
};
struct tyObject_NimSeqPayload__0KWqNVfFHBrBbvQ3rkt2qw {
	NI cap;
	tyTuple__9agFg9cuYsNvckAbTfHAsTSA data[SEQ_DECL_SIZE];
};
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw {
  NI len; tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content* p;
};
struct tyTuple__XOVT24GHXwqiEj5GCsEGCA {
	NimStringV2 Field0;
	NI Field1;
};
struct tyObject_NimSeqV2__9bDpynnYoGERDv29b2zzrHBA {
	NI len;
	tyObject_NimSeqPayload__uxcJrKhywutDkyBihRCp8A* p;
};
struct tyObject_NimSeqPayload__uxcJrKhywutDkyBihRCp8A {
	NI cap;
	tyTuple__XOVT24GHXwqiEj5GCsEGCA data[SEQ_DECL_SIZE];
};
struct tySequence__fVUhfWxkucMvZhVKGrAHuA {
  NI len; tySequence__fVUhfWxkucMvZhVKGrAHuA_Content* p;
};
struct tyObject_NimSeqV2__OxcAsbxTCnOB3tNBCMOKmQ {
	NI len;
	tyObject_NimSeqPayload__w8RH3U9c4N9cJ9a7RfqWxNKlQ* p;
};
struct tyObject_NimSeqPayload__w8RH3U9c4N9cJ9a7RfqWxNKlQ {
	NI cap;
	tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* data[SEQ_DECL_SIZE];
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
typedef NimStringV2 tyArray__WCl78mpHztMcuO2AmOcOQg[16];
typedef NU8 tySet_tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g;
struct tyObject_Table__0Na0d2dQ8AYACjty2CqMPA {
	tySequence__9cbEQVGky3gHl4QEC3q4Sow data;
	NI counter;
};
struct tySequence__kq9c1GdJLvkYJeijBmsJ20A {
  NI len; tySequence__kq9c1GdJLvkYJeijBmsJ20A_Content* p;
};
struct tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg {
	tySequence__kq9c1GdJLvkYJeijBmsJ20A data;
	NI counter;
};
struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g {
	NI counter;
	tySequence__GH1mmNKNA2QP4n1tnxJf1w data;
	NIM_BOOL ignoreTypes;
};
typedef NimStringV2 tyArray__ftd030ZQb0rgyFYIoQaqFA[10];
struct tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA {
	tySequence__9bRXJy1JXrQ4hWpStaKBpXg data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tyArray__WCl78mpHztMcuO2AmOcOQg s;
	tySet_tyEnum_CodegenFlag__n9cgzVCxaDJQgwxab9b9ao9a8g flags;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	NimStringV2 filename;
	NimStringV2 cfilename;
	NimStringV2 tmpBase;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA typeCache;
	tyObject_HashSet__0q39c5tNe10Ccqi9bymkXwEg typeABICache;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA forwTypeCache;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA declaredThings;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA declaredProtos;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA alive;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ headerFiles;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA typeInfoMarker;
	tyObject_Table__0Na0d2dQ8AYACjty2CqMPA typeInfoMarkerV2;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* initProc;
	tyObject_TCProc__qtjLoeN4t2OOlLAbQg1W1A* preInitProc;
	NimStringV2 hcrCreateTypeInfosProc;
	NIM_BOOL inHcrInitGuard;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg typeStack;
	tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g dataCache;
	NI typeNodes;
	NI nimTypes;
	NimStringV2 typeNodesName;
	NimStringV2 nimTypesName;
	NI labels;
	tyArray__ftd030ZQb0rgyFYIoQaqFA extensionLoaders;
	tyObject_CountTable__C4iAvBZYBHUgGQV1J30IiA sigConflicts;
	tyObject_BModuleListcolonObjectType___Wyiqpl2DzWQERbKVOCup4g* g;
};
struct tyObject_NimSeqV2__OgCJ17saq1nSO9as9agMdsCw {
	NI len;
	tyObject_NimSeqPayload__CvDo7kJ9bzhvslYp8QzYe5w* p;
};
struct tyObject_NimSeqPayload__CvDo7kJ9bzhvslYp8QzYe5w {
	NI cap;
	tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE];
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tyObject_NimSeqV2__KfASkEYFzOb1wwm3izC5Qw {
	NI len;
	tyObject_NimSeqPayload__GKLkcFK9bXhhfQVfVIZSsjw* p;
};
struct tyObject_NimSeqPayload__GKLkcFK9bXhhfQVfVIZSsjw {
	NI cap;
	tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE];
};
struct tySequence__1xFov7v9c2rs44orw6d9bPmw {
  NI len; tySequence__1xFov7v9c2rs44orw6d9bPmw_Content* p;
};
typedef NU8 tyEnum_InstrKind__xkE9c36M77yqw0WqXYKG9aAg;
struct tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g {
	tyEnum_InstrKind__xkE9c36M77yqw0WqXYKG9aAg kind;
union{
	NI dest;
	struct {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
} _kind_2;
};
};
struct tySequence__ASKXHf9aJJjLj0hSZ39ci19cA {
  NI len; tySequence__ASKXHf9aJJjLj0hSZ39ci19cA_Content* p;
};
struct tyObject_NimSeqV2__w2Yxjbp9cPR9axG5zMX2ZJDQ {
	NI len;
	tyObject_NimSeqPayload__Z87I9cxqtjAbepz89aHXS7eg* p;
};
struct tySequence__gGvy9cKEpHEX9cA4gF5mzkxA {
  NI len; tySequence__gGvy9cKEpHEX9cA4gF5mzkxA_Content* p;
};
struct tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q {
	NIM_BOOL isTryBlock;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* label;
	tySequence__gGvy9cKEpHEX9cA4gF5mzkxA breakFixups;
} _isTryBlock_1;
	struct {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* finale;
	tySequence__qwqHTkRvwhrRyENtudHQ7g raiseFixups;
} _isTryBlock_2;
};
};
struct tyObject_NimSeqPayload__Z87I9cxqtjAbepz89aHXS7eg {
	NI cap;
	tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__5ysMwE3bSaZW3caCX0Ttzg {
	NI len;
	tyObject_NimSeqPayload__prYsw3adJsXiAStbTYEyUA* p;
};
struct tyObject_NimSeqPayload__prYsw3adJsXiAStbTYEyUA {
	NI cap;
	tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__wt39cjGYh5Guxqsbc3o6hQA {
	NI len;
	tyObject_NimSeqPayload__nDLEjClwgABDf30b81MZug* p;
};
struct tyObject_NimSeqPayload__nDLEjClwgABDf30b81MZug {
	NI cap;
	NI data[SEQ_DECL_SIZE];
};
struct tyTuple__MDblJIdBvEzk3cvDpORS3w {
	NI Field0;
	tySequence__9ahcSjIErJohSBBFLwuF56Q Field1;
};
struct tyObject_NimSeqV2__Cbt9aJKw9bTRLyD7sNsbPszg {
	NI len;
	tyObject_NimSeqPayload__mIMn1lPcHyJESWpGlGgV3w* p;
};
struct tyObject_NimSeqPayload__mIMn1lPcHyJESWpGlGgV3w {
	NI cap;
	tyTuple__MDblJIdBvEzk3cvDpORS3w data[SEQ_DECL_SIZE];
};
struct tySequence__W61O50MEQVwc9azCYWJekkw {
  NI len; tySequence__W61O50MEQVwc9azCYWJekkw_Content* p;
};
typedef NimStringV2 tyArray__NOxIfV7vwG2iyabGkP0VWg[3];
struct tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw {
	NI id;
	NimStringV2 label;
	tyArray__NOxIfV7vwG2iyabGkP0VWg sections;
	NIM_BOOL isLoop;
	NI16 nestedTryStmts;
	NI16 nestedExceptStmts;
	NI16 frameLen;
};
struct tyObject_NimSeqV2__S9b80pdJYZQPsS5N9b2kicxw {
	NI len;
	tyObject_NimSeqPayload__U7B8DwB0W7xf9bVfVHA9aqrA* p;
};
struct tyObject_NimSeqPayload__U7B8DwB0W7xf9bVfVHA9aqrA {
	NI cap;
	tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqV2__weU9asdVHowsM0AixRsmNtw {
	NI len;
	tyObject_NimSeqPayload__i3atYjlhKLPEdlA9agEAgig* p;
};
struct tyTuple__UGkfKgNvKJXAR6NX6Y5gaw {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
};
struct tyObject_NimSeqPayload__i3atYjlhKLPEdlA9agEAgig {
	NI cap;
	tyTuple__UGkfKgNvKJXAR6NX6Y5gaw data[SEQ_DECL_SIZE];
};
struct tySequence__7Eqk7CViYtlAWKDoMfuEcw {
  NI len; tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content* p;
};
typedef NU8 tyEnum_TDirection__Pz9b8tDdgaM43b9cFTDRlyRg;
struct tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* v;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* alias;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lower;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* upper;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* stride;
	tyEnum_TDirection__Pz9b8tDdgaM43b9cFTDRlyRg dir;
	NIM_BOOL blacklisted;
};
struct tyObject_NimSeqV2__AV5et9atQLnjtoDLFs9c0pqw {
	NI len;
	tyObject_NimSeqPayload__wqnZx9am7Gry9bMI0mkOMvPQ* p;
};
struct tyObject_NimSeqPayload__wqnZx9am7Gry9bMI0mkOMvPQ {
	NI cap;
	tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg data[SEQ_DECL_SIZE];
};
struct tySequence__jXZVXmhly1BClQDJpGni9ag {
  NI len; tySequence__jXZVXmhly1BClQDJpGni9ag_Content* p;
};
struct tyObject_NimSeqV2__PDqM9andK9c3w9aDIGEcXk8UQ {
	NI len;
	tyObject_NimSeqPayload__VvMimvmaTnYn8kKdk9c86lg* p;
};
struct tyTuple__ILpLBib1l58GvVZ4BcToSg {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
	NI Field3;
	NIM_BOOL Field4;
};
struct tyObject_NimSeqPayload__VvMimvmaTnYn8kKdk9c86lg {
	NI cap;
	tyTuple__ILpLBib1l58GvVZ4BcToSg data[SEQ_DECL_SIZE];
};
struct tySequence__1cgZIGFge8OGY6Zlwa9aRnw {
  NI len; tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content* p;
};
struct tyTuple__IGtaz2jo9ahodpWjWgc5c5A {
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw Field0;
	NimStringV2 Field1;
};
struct tyObject_NimSeqV2__KnDsUGgx2yjp69b8gz0zSYg {
	NI len;
	tyObject_NimSeqPayload__Qd9cKL9bcCjHwcgEfiPu7ZXw* p;
};
struct tyObject_NimSeqPayload__Qd9cKL9bcCjHwcgEfiPu7ZXw {
	NI cap;
	tyTuple__IGtaz2jo9ahodpWjWgc5c5A data[SEQ_DECL_SIZE];
};
struct tySequence__olcP618a61wlx6oJIT9b0sA {
  NI len; tySequence__olcP618a61wlx6oJIT9b0sA_Content* p;
};
struct tyTuple__P9bg2wlfPi4dSSTi3ICCeVA {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	NIM_BOOL Field1;
	NI Field2;
};
struct tyObject_NimSeqV2__YBTuIJlLxSm2mxe1w9cWFrA {
	NI len;
	tyObject_NimSeqPayload__D4LPGlBSP9aZMmMsu9cDwSuw* p;
};
struct tyObject_NimSeqPayload__D4LPGlBSP9aZMmMsu9cDwSuw {
	NI cap;
	tyTuple__P9bg2wlfPi4dSSTi3ICCeVA data[SEQ_DECL_SIZE];
};
struct tySequence__P9aymq2R2Xa8At0XKJ6Bh1A {
  NI len; tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content* p;
};
struct tyObject_NimSeqV2__W5tAKfTFLQBWqzn4PRHD2A {
	NI len;
	tyObject_NimSeqPayload__9cD5x9btaprZqa4nYXRlvtqw* p;
};
struct tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw {
	NI id;
	NIM_BOOL isLoop;
};
struct tyObject_NimSeqPayload__9cD5x9btaprZqa4nYXRlvtqw {
	NI cap;
	tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg;
struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ {
  NI len; tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content* p;
};
struct tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ {
	NIM_BOOL isRst;
union{
	struct {
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* rst;
} _isRst_1;
	struct {
	NimStringV2 str;
} _isRst_2;
};
};
struct tyObject_NimSeqV2__ZhzDsOEyq73Ti8kBnPUVAQ {
	NI len;
	tyObject_NimSeqPayload__YsSBpIEgPJDz0K9aFZPtHFg* p;
};
struct tyObject_NimSeqPayload__YsSBpIEgPJDz0K9aFZPtHFg {
	NI cap;
	tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ data[SEQ_DECL_SIZE];
};
struct tySequence__LqZapiAqCFeXPQZdoIAUew {
  NI len; tySequence__LqZapiAqCFeXPQZdoIAUew_Content* p;
};
struct tyObject_NimSeqV2__bbuzn26SpE2aMsRysMBtPw {
	NI len;
	tyObject_NimSeqPayload__LiYZJx3MkkRTPACuQG4JSg* p;
};
struct tyObject_NimSeqPayload__LiYZJx3MkkRTPACuQG4JSg {
	NI cap;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w;
struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA {
	tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w kind;
union{
	struct {
	NimStringV2 text;
} _kind_1;
	struct {
	NimStringV2 labelFmt;
} _kind_2;
	struct {
	NimStringV2 lineIndent;
} _kind_3;
	struct {
	NimStringV2 adType;
} _kind_4;
	struct {
	NI level;
} _kind_5;
	struct {
	NI order;
} _kind_6;
	struct {
	NI quotationDepth;
} _kind_7;
	struct {
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
} _kind_8;
	struct {
	NimStringV2 tooltip;
} _kind_9;
	struct {
	NI colCount;
} _kind_10;
	struct {
	NIM_BOOL endsHeader;
} _kind_11;
	struct {
	NI span;
} _kind_12;
};
	NimStringV2 anchor;
	tySequence__LqZapiAqCFeXPQZdoIAUew sons;
};
struct tyObject_NimSeqV2__t78Q6fZVjKweNlSemiuCdA {
	NI len;
	tyObject_NimSeqPayload__cRENl2YvyxBdbrl9a5PTnJQ* p;
};
struct tyObject_NimSeqPayload__cRENl2YvyxBdbrl9a5PTnJQ {
	NI cap;
	tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE];
};
struct tySequence__Ygtgme9cSsBUPbXwOprm43Q {
  NI len; tySequence__Ygtgme9cSsBUPbXwOprm43Q_Content* p;
};
typedef NU8 tyEnum_TokType__k2ZtEdAsaWJ9cCxU8va6yzw;
struct tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg {
	tyEnum_TokType__k2ZtEdAsaWJ9cCxU8va6yzw kind;
	NI ival;
	NimStringV2 symbol;
	NI line;
	NI col;
};
struct tyObject_NimSeqV2__qdXEIeVz4ljISllV9a1mIOg {
	NI len;
	tyObject_NimSeqPayload__IxmSriPVaYy30PbJEUVJNw* p;
};
struct tyObject_NimSeqPayload__IxmSriPVaYy30PbJEUVJNw {
	NI cap;
	tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg data[SEQ_DECL_SIZE];
};
struct tySequence__ib5UTyrs9aC6K60sNqKElQA {
  NI len; tySequence__ib5UTyrs9aC6K60sNqKElQA_Content* p;
};
struct tyObject_NimSeqV2__ogAkNBRuOEgem9ccQ23aWJA {
	NI len;
	tyObject_NimSeqPayload__sNyYFNBvMgWzlPRT5RMxMA* p;
};
typedef NU8 tyEnum_AnchorRule__EbWqr3fy26ujwRNegmj44Q;
typedef NU8 tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ;
struct tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw {
	NimStringV2 symKind;
	NimStringV2 symTypeKind;
	NimStringV2 name;
	NimStringV2 generics;
	NIM_BOOL isGroup;
	NIM_BOOL parametersProvided;
	tySequence__4eQHGndY6XBYpFOH09apV8Q parameters;
	NimStringV2 outType;
};
struct tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA {
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
	NI priority;
	tyEnum_AnchorRule__EbWqr3fy26ujwRNegmj44Q kind;
union{
	struct {
	tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ anchorType;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* target;
} _kind_1;
	struct {
	tyEnum_RstAnchorKind__6dqsd3jPhvKlaTafW6ZmUQ anchorTypeExt;
	NimStringV2 refnameExt;
} _kind_2;
	struct {
	NI32 module;
	NimStringV2 tooltip;
	tyObject_LangSymbol__qzqOgOy0P9aJoI4TJXtpzXw langSym;
	NimStringV2 refname;
	NIM_BOOL external;
} _kind_3;
};
};
struct tyObject_NimSeqPayload__sNyYFNBvMgWzlPRT5RMxMA {
	NI cap;
	tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA data[SEQ_DECL_SIZE];
};
struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw {
  NI len; tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content* p;
};
struct tyTuple__Na59bk2YQTCLBWTLyeMrWdA {
	NI Field0;
	NimStringV2 Field1;
	tySequence__ib5UTyrs9aC6K60sNqKElQA Field2;
};
struct tyObject_NimSeqV2__oV415pC8JzigLaE3Z8NmRA {
	NI len;
	tyObject_NimSeqPayload__8rE9bP9aK9b2hbvymP6dkiK9ag* p;
};
struct tyObject_NimSeqPayload__8rE9bP9aK9b2hbvymP6dkiK9ag {
	NI cap;
	tyTuple__Na59bk2YQTCLBWTLyeMrWdA data[SEQ_DECL_SIZE];
};
struct tySequence__7kOUUrKwg6xKu7wOGcJDlQ {
  NI len; tySequence__7kOUUrKwg6xKu7wOGcJDlQ_Content* p;
};
struct tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg {
	NimStringV2 alias;
	NimStringV2 anchor;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
};
struct tyObject_NimSeqV2__jq9bZNIPJ4qu7V4eHQtnzsA {
	NI len;
	tyObject_NimSeqPayload__Hlj1rtYTbGj4Dqclc4DkRw* p;
};
struct tyObject_NimSeqPayload__Hlj1rtYTbGj4Dqclc4DkRw {
	NI cap;
	tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg data[SEQ_DECL_SIZE];
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
struct tySequence__vz9c2digtAnM8l0FZWLUAGg {
  NI len; tySequence__vz9c2digtAnM8l0FZWLUAGg_Content* p;
};
struct tyObject_NimSeqV2__14YjrtdnP0xUdYuun1A9aLA {
	NI len;
	tyObject_NimSeqPayload__yqjN9aCYTixKEQlArWvLUOA* p;
};
typedef NU8 tyEnum_SubstitutionKind__juwrhPkgYiHpJAKqmfpbPw;
struct tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A {
	tyEnum_SubstitutionKind__juwrhPkgYiHpJAKqmfpbPw kind;
	NimStringV2 key;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* value;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
};
struct tyObject_NimSeqPayload__yqjN9aCYTixKEQlArWvLUOA {
	NI cap;
	tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A data[SEQ_DECL_SIZE];
};
struct tySequence__jK2T9bFw5BWKL8ZZ854oXZg {
  NI len; tySequence__jK2T9bFw5BWKL8ZZ854oXZg_Content* p;
};
struct tyObject_NimSeqV2__0ZwVzMiBqWU9cqL9caiDoTLA {
	NI len;
	tyObject_NimSeqPayload__ybmhgz79bSqWRiJKkQ8HQ7w* p;
};
struct tyObject_NimSeqPayload__ybmhgz79bSqWRiJKkQ8HQ7w {
	NI cap;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA data[SEQ_DECL_SIZE];
};
struct tySequence__lBgZ7a89beZGYPl8PiANMTA {
  NI len; tySequence__lBgZ7a89beZGYPl8PiANMTA_Content* p;
};
struct tyObject_NimSeqV2__I3X9al7nCO8sblSUazXxfYg {
	NI len;
	tyObject_NimSeqPayload__Hr9bMo57N1qllFnm9aTT9a04A* p;
};
struct tyObject_NimSeqPayload__Hr9bMo57N1qllFnm9aTT9a04A {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg {
  NI len; tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content* p;
};
struct tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ {
	NIM_BOOL used;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA fromInfo;
	NimStringV2 idxPath;
	NimStringV2 linkRelPath;
	NimStringV2 title;
};
struct tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng {
	NI Field0;
	NimStringV2 Field1;
	tyObject_ImportdocInfo__uLPn7VRRbG3ecDOy0jvMyQ Field2;
};
struct tyObject_NimSeqV2__lBNlEWaemNhEZQ6EiE0Fow {
	NI len;
	tyObject_NimSeqPayload__asMbT9bP9ckVukoIEqEckgeg* p;
};
struct tyObject_NimSeqPayload__asMbT9bP9ckVukoIEqEckgeg {
	NI cap;
	tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng data[SEQ_DECL_SIZE];
};
struct tySequence__vdmFdgox3dhDOMkkFi9ayfg {
  NI len; tySequence__vdmFdgox3dhDOMkkFi9ayfg_Content* p;
};
struct tyObject_NimSeqV2__T1eqKrYZfdKyRHrCorPNEA {
	NI len;
	tyObject_NimSeqPayload__89cqvepx69ccuFWso2QMjj1w* p;
};
typedef NU8 tyEnum_FootnoteType__AwBNmZfS9azDCP9cRgTUCl6g;
struct tyTuple__4Ywt2LYBMs9aMJ09cL7digow {
	tyEnum_FootnoteType__AwBNmZfS9azDCP9cRgTUCl6g Field0;
	NI Field1;
	NI Field2;
	NI Field3;
	NimStringV2 Field4;
};
struct tyObject_NimSeqPayload__89cqvepx69ccuFWso2QMjj1w {
	NI cap;
	tyTuple__4Ywt2LYBMs9aMJ09cL7digow data[SEQ_DECL_SIZE];
};
struct tySequence__qagWYy9b8OIJNg9bWhIaAjyw {
  NI len; tySequence__qagWYy9b8OIJNg9bWhIaAjyw_Content* p;
};
struct tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ {
	NIM_CHAR symbol;
	NIM_BOOL hasOverline;
	NI line;
	NIM_BOOL hasPeers;
};
struct tyObject_NimSeqV2__6Pxjw9bWB1WY3zh3hilV9cZg {
	NI len;
	tyObject_NimSeqPayload__vCNTtuN37GkJiwKmwrWOyw* p;
};
struct tyObject_NimSeqPayload__vCNTtuN37GkJiwKmwrWOyw {
	NI cap;
	tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ data[SEQ_DECL_SIZE];
};
struct tySequence__g9cc9ce4njfC9a8r1mQEl8mIg {
  NI len; tySequence__g9cc9ce4njfC9a8r1mQEl8mIg_Content* p;
};
struct tyObject_NimSeqV2__tjcRCxE1NDeNULoDZAR1Yg {
	NI len;
	tyObject_NimSeqPayload__2ExJM0q52YdctDeHI5gngA* p;
};
struct tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ {
	NI start;
	NI stop;
};
struct tyObject_NimSeqPayload__2ExJM0q52YdctDeHI5gngA {
	NI cap;
	tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ data[SEQ_DECL_SIZE];
};
struct tySequence__lCWXucMn9bU7PUqVDK7772w {
  NI len; tySequence__lCWXucMn9bU7PUqVDK7772w_Content* p;
};
struct tyTuple__kNIN44R9cL9cYoYzXmSW4y7w {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_ExampleGroupcolonObjectType___z4m0EFt4A89aqk2CoU9c5IkQ* Field3;
};
struct tyObject_NimSeqV2__UfbSPrjWq12UpEcQ5cvcpw {
	NI len;
	tyObject_NimSeqPayload__JjOOUsaDCA9bnEfeAuP0f6g* p;
};
struct tyObject_NimSeqPayload__JjOOUsaDCA9bnEfeAuP0f6g {
	NI cap;
	tyTuple__kNIN44R9cL9cYoYzXmSW4y7w data[SEQ_DECL_SIZE];
};
struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA {
  NI len; tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content* p;
};
struct tyObject_NimSeqV2__yUtpZJvImTQo9bK5xz5kYJw {
	NI len;
	tyObject_NimSeqPayload__6Of5sDwIeeQl9aHgrxiVQng* p;
};
struct tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg {
	tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ descRst;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ substitutions;
	NimStringV2 sortName;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
	NimStringV2 anchor;
	NimStringV2 name;
	NimStringV2 detailedName;
};
struct tyObject_NimSeqPayload__6Of5sDwIeeQl9aHgrxiVQng {
	NI cap;
	tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg data[SEQ_DECL_SIZE];
};
struct tySequence__uAwiTxV3boseSy9a9cSsXHEA {
  NI len; tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content* p;
};
struct tyTuple__30Ti2rm9aDSr5neUSZP6EVQ {
	NI Field0;
	NimStringV2 Field1;
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA Field2;
};
struct tyObject_NimSeqV2__1TKHLyyLNkNmpOAP9bh7GLA {
	NI len;
	tyObject_NimSeqPayload__hB9aHrhbUnNwHgNUQwrnGzQ* p;
};
struct tyObject_NimSeqPayload__hB9aHrhbUnNwHgNUQwrnGzQ {
	NI cap;
	tyTuple__30Ti2rm9aDSr5neUSZP6EVQ data[SEQ_DECL_SIZE];
};
struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg {
  NI len; tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content* p;
};
struct tyObject_NimSeqV2__D8j6RTfYMSkIst53FjTViA {
	NI len;
	tyObject_NimSeqPayload__hLNcDnR7bJ4wjvQz9ahH6JA* p;
};
struct tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg {
	NimStringV2 content;
	NimStringV2 sortName;
};
struct tyObject_NimSeqPayload__hLNcDnR7bJ4wjvQz9ahH6JA {
	NI cap;
	tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg data[SEQ_DECL_SIZE];
};
struct tySequence__9at3Cmn7xIajy679cMZSmybg {
  NI len; tySequence__9at3Cmn7xIajy679cMZSmybg_Content* p;
};
struct tyTuple__RrY3dT8dfTceE0s6Bv9bxJw {
	NI Field0;
	NimStringV2 Field1;
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg Field2;
};
struct tyObject_NimSeqV2__9aud9b4Q3q9cilO02NybLywdQ {
	NI len;
	tyObject_NimSeqPayload__ute2TqMnJ0mHidshPkSn3w* p;
};
struct tyObject_NimSeqPayload__ute2TqMnJ0mHidshPkSn3w {
	NI cap;
	tyTuple__RrY3dT8dfTceE0s6Bv9bxJw data[SEQ_DECL_SIZE];
};
struct tySequence__fXWXs2NlFKREhy9cn6vokJw {
  NI len; tySequence__fXWXs2NlFKREhy9cn6vokJw_Content* p;
};
struct tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g {
	NI len;
	tyObject_NimSeqPayload__JaTznDCkq35V9cuoM5WF0BA* p;
};
struct tySequence__eb7tUf9a8CR5sBO6O3AH67A {
  NI len; tySequence__eb7tUf9a8CR5sBO6O3AH67A_Content* p;
};
struct tyObject_NimSeqV2__iJtaCkDWWpRT1m7KgS5F7g {
	NI len;
	tyObject_NimSeqPayload__VC9cBOrPM9bT6kBhZDcUa6CQ* p;
};
struct tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw {
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* json;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* rst;
	NimStringV2 rstField;
};
struct tyObject_NimSeqPayload__VC9cBOrPM9bT6kBhZDcUa6CQ {
	NI cap;
	tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw data[SEQ_DECL_SIZE];
};
struct tySequence__m9axZwxFfhSNLcoofvKZJYA {
  NI len; tySequence__m9axZwxFfhSNLcoofvKZJYA_Content* p;
};
struct tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* Field3;
};
struct tyObject_NimSeqV2__WCVwWV7Hn7J7GPKWFg22mg {
	NI len;
	tyObject_NimSeqPayload__WEyiXw9aq2uG9bJCsS9avRkLg* p;
};
struct tyObject_NimSeqPayload__WEyiXw9aq2uG9bJCsS9avRkLg {
	NI cap;
	tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ data[SEQ_DECL_SIZE];
};
struct tyObject_NimSeqPayload__JaTznDCkq35V9cuoM5WF0BA {
	NI cap;
	tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA;
struct tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ {
	tySequence__m9axZwxFfhSNLcoofvKZJYA data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g {
	NIM_BOOL isUnquoted;
	tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA kind;
union{
	struct {
	NimStringV2 str;
} _kind_1;
	struct {
	NI64 num;
} _kind_2;
	struct {
	NF fnum;
} _kind_3;
	struct {
	NIM_BOOL bval;
} _kind_4;
	struct {
	tyObject_OrderedTable__ASIVNBCKpz8qGZwzYCCBFQ fields;
} _kind_6;
	struct {
	tySequence__fXWXs2NlFKREhy9cn6vokJw elems;
} _kind_7;
};
};
struct tySequence__NZB65egHQwAniMoFWKcFaw {
  NI len; tySequence__NZB65egHQwAniMoFWKcFaw_Content* p;
};
struct tyTuple__bPZu3GhfjP9cHscH3h9axT6w {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA Field0;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA Field1;
};
struct tyObject_NimSeqV2__rK9bwjfXgSbEam9bKV1xYDUg {
	NI len;
	tyObject_NimSeqPayload__uz9aGs7pgMg2bRYB559byjng* p;
};
struct tyObject_NimSeqPayload__uz9aGs7pgMg2bRYB559byjng {
	NI cap;
	tyTuple__bPZu3GhfjP9cHscH3h9axT6w data[SEQ_DECL_SIZE];
};
struct tySequence__EHM5DWw09bc16yo24mdZPsw {
  NI len; tySequence__EHM5DWw09bc16yo24mdZPsw_Content* p;
};
struct tyObject_NimSeqV2__haf1g0PFMgrwcF57Pq0weA {
	NI len;
	tyObject_NimSeqPayload__jrxRPd9cQJe05e2kdz2CuFA* p;
};
struct tyObject_NimSeqPayload__jrxRPd9cQJe05e2kdz2CuFA {
	NI cap;
	tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw* data[SEQ_DECL_SIZE];
};
struct tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pnode;
	NI id;
	NI idx;
	NI lowLink;
	NIM_BOOL onStack;
	tySequence__EHM5DWw09bc16yo24mdZPsw kids;
	NI hAQ;
	NI hIS;
	NI hB;
	NI hCmd;
};
struct tySequence__pN5ht9bYa9c1VQJ0Er2wvTuA {
  NI len; tySequence__pN5ht9bYa9c1VQJ0Er2wvTuA_Content* p;
};
struct tyObject_NimSeqV2__p2zAi8O7jv7NkThV7Wv7Jg {
	NI len;
	tyObject_NimSeqPayload__X2iaL9ber9aB6QN9bjTXUiXwA* p;
};
struct tyObject_NimSeqPayload__X2iaL9ber9aB6QN9bjTXUiXwA {
	NI cap;
	tySequence__EHM5DWw09bc16yo24mdZPsw data[SEQ_DECL_SIZE];
};
struct tySequence__u440EGTDYOwkQLE9asdZ6OQ {
  NI len; tySequence__u440EGTDYOwkQLE9asdZ6OQ_Content* p;
};
struct tyObject_NimSeqV2__ATMaGzUX9c9bDaC49cuJNExkg {
	NI len;
	tyObject_NimSeqPayload__aqsvVzVORlY4G59bckSb2fg* p;
};
struct tySequence__IWLCUlc3h6FWY379alhl9aaQ {
  NI len; tySequence__IWLCUlc3h6FWY379alhl9aaQ_Content* p;
};
struct tyObject_Mapping__5X9cm3giTN9aYJbVTF9clmk7A {
	NIM_BOOL inSource;
union{
	struct {
	NI file;
	NI line;
	tySequence__IWLCUlc3h6FWY379alhl9aaQ segments;
} _inSource_1;
};
};
struct tyObject_NimSeqPayload__aqsvVzVORlY4G59bckSb2fg {
	NI cap;
	tyObject_Mapping__5X9cm3giTN9aYJbVTF9clmk7A data[SEQ_DECL_SIZE];
};
struct tyObject_Segment__9cSimljufAUmxKUYLJk2dhw {
	NI original;
	NI generated;
	NI name;
};
struct tyObject_NimSeqV2__h9buKeygKKlRU5DBRAThO8w {
	NI len;
	tyObject_NimSeqPayload__Lon6j0gkxPT8tK6CiffUWg* p;
};
struct tyObject_NimSeqPayload__Lon6j0gkxPT8tK6CiffUWg {
	NI cap;
	tyObject_Segment__9cSimljufAUmxKUYLJk2dhw data[SEQ_DECL_SIZE];
};
struct tySequence__36jA1xDCIBAS29cySYLQ7kQ {
  NI len; tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content* p;
};
typedef NU8 tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ;
struct tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ {
	tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ kind;
	NimStringV2 keyword;
	NimStringV2 link;
	NimStringV2 linkTitle;
	NimStringV2 linkDesc;
	NI line;
	NimStringV2 module;
	NimStringV2 aux;
};
struct tyObject_NimSeqV2__It4LZ0xSvGXxrDnDyxiHAA {
	NI len;
	tyObject_NimSeqPayload__DH8yJOdFxzJMqogBX6j0mg* p;
};
struct tyObject_NimSeqPayload__DH8yJOdFxzJMqogBX6j0mg {
	NI cap;
	tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ data[SEQ_DECL_SIZE];
};
struct tySequence__ElKBSoViSyNazy7qD89atSA {
  NI len; tySequence__ElKBSoViSyNazy7qD89atSA_Content* p;
};
struct tyObject_NimSeqV2__9bRXa9c9az0Ao4W9aoamrTFXfw {
	NI len;
	tyObject_NimSeqPayload__9afNNooT7Cf9bhpARywaHHFg* p;
};
typedef NU8 tyEnum_AnchorRule__2EJ03fugiw0bGfuZoUTntQ;
struct tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw {
	tyEnum_AnchorRule__2EJ03fugiw0bGfuZoUTntQ ar;
	NI priority;
	NimStringV2 tooltip;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* target;
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
	NimStringV2 externFilename;
	NIM_BOOL isTitle;
};
struct tyObject_NimSeqPayload__9afNNooT7Cf9bhpARywaHHFg {
	NI cap;
	tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw data[SEQ_DECL_SIZE];
};
struct tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ {
  NI len; tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ_Content* p;
};
struct tyTuple__fgn415DvsSyiHk3o9aIYr0w {
	NI Field0;
	tyTuple__UV3llMMYFckfui8YMBuUZA Field1;
	tySequence__ib5UTyrs9aC6K60sNqKElQA Field2;
};
struct tyObject_NimSeqV2__r1EXHsatwZ6kMJ1o64DQpA {
	NI len;
	tyObject_NimSeqPayload__U9aGDO66NJKBIUSmR7mvzJg* p;
};
struct tyObject_NimSeqPayload__U9aGDO66NJKBIUSmR7mvzJg {
	NI cap;
	tyTuple__fgn415DvsSyiHk3o9aIYr0w data[SEQ_DECL_SIZE];
};
typedef NU16 tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg;
typedef NU8 tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg;
struct tyObject_ReraiseDefect__rf4J0hIl2XahwR8oH1IVPA {
	tyObject_Defect__WFlDaIWu7hFOKoGSG7uH7g Sup;
};
struct tySequence__H9bHW2kkjp26MABVBZRr8Ig {
  NI len; tySequence__H9bHW2kkjp26MABVBZRr8Ig_Content* p;
};
struct tyObject_NimSeqV2__m0j9bkSujD9aJ8udATfNaPag {
	NI len;
	tyObject_NimSeqPayload__s0MwarqxvvP9a6pFjXy44sQ* p;
};
struct tyTuple__EJOd8NnRbGOjqpW2d6uq2g {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
};
struct tyObject_NimSeqPayload__s0MwarqxvvP9a6pFjXy44sQ {
	NI cap;
	tyTuple__EJOd8NnRbGOjqpW2d6uq2g data[SEQ_DECL_SIZE];
};
struct tySequence__MboA857W9b3olvEyCWLQeEg {
  NI len; tySequence__MboA857W9b3olvEyCWLQeEg_Content* p;
};
struct tyTuple__jYR27AKllNE6EvJCKQs1WA {
	NI Field0;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ Field1;
	NI Field2;
};
struct tyObject_NimSeqV2__W7Plkq0qifudpOJp9bAjimg {
	NI len;
	tyObject_NimSeqPayload__1ywxEbsXF8gcMuWhd04qPg* p;
};
struct tyObject_NimSeqPayload__1ywxEbsXF8gcMuWhd04qPg {
	NI cap;
	tyTuple__jYR27AKllNE6EvJCKQs1WA data[SEQ_DECL_SIZE];
};
struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w {
  NI len; tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content* p;
};
struct tyTuple__Ll5iolPASSzOEheeSNjmiw {
	NI Field0;
	NI32 Field1;
};
struct tyTuple__9a3DhYVfcy14Fx42tD0lSEQ {
	NI Field0;
	NimStringV2 Field1;
	tyTuple__Ll5iolPASSzOEheeSNjmiw Field2;
};
struct tyObject_NimSeqV2__EExhi6yk44m40Ni00bMvSQ {
	NI len;
	tyObject_NimSeqPayload__N3VLS9aKnwCnjctw22os8JA* p;
};
struct tyObject_NimSeqPayload__N3VLS9aKnwCnjctw22os8JA {
	NI cap;
	tyTuple__9a3DhYVfcy14Fx42tD0lSEQ data[SEQ_DECL_SIZE];
};
struct tySequence__9aHwlozdspjDnjhtzDhmdVg {
  NI len; tySequence__9aHwlozdspjDnjhtzDhmdVg_Content* p;
};
struct tyObject_NimSeqV2__K0sypBe4BNGzcbvtFWY4Ew {
	NI len;
	tyObject_NimSeqPayload__1BEfsOZcNYUjd4lXnbhEaQ* p;
};
struct tyObject_NimSeqPayload__1BEfsOZcNYUjd4lXnbhEaQ {
	NI cap;
	tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ* data[SEQ_DECL_SIZE];
};
typedef NU8 tySet_tyEnum_ProcessOption__f8zQPCJAq3Y51oMx2CR9cxw;
struct tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ {
	RootObj Sup;
	int inHandle;
	int outHandle;
	int errHandle;
	pid_t id;
	tyObject_StreamObj__nX3kZRlh8Dq3gQ2cC6DE8w* inStream;
	tyObject_StreamObj__nX3kZRlh8Dq3gQ2cC6DE8w* outStream;
	tyObject_StreamObj__nX3kZRlh8Dq3gQ2cC6DE8w* errStream;
	int exitStatus;
	NIM_BOOL exitFlag;
	tySet_tyEnum_ProcessOption__f8zQPCJAq3Y51oMx2CR9cxw options;
};
struct tySequence__mg32q50AXD9cQ6jovpBmgWA {
  NI len; tySequence__mg32q50AXD9cQ6jovpBmgWA_Content* p;
};
struct tyTuple__bvjw5f4vMpB9bESWLU7nvyA {
	NI Field0;
	tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ Field1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ Field2;
};
struct tyObject_NimSeqV2__plyqYwuv3lTJaE7cjUyreg {
	NI len;
	tyObject_NimSeqPayload__ceWjhV9bHVjDw9ckC1zzOXDQ* p;
};
struct tyObject_NimSeqPayload__ceWjhV9bHVjDw9ckC1zzOXDQ {
	NI cap;
	tyTuple__bvjw5f4vMpB9bESWLU7nvyA data[SEQ_DECL_SIZE];
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
struct tySequence__9chP3SzkaldXzawWQCDsqqg_Content { NI cap; tyTuple__aGv2fk9ceddvdC01ZJC2Q2g data[SEQ_DECL_SIZE]; };
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tySequence__xv3aaFd3JCw8NbmALHiezQ_Content { NI cap; tyTuple__sPaDkVPSC0MkcoXCxPH9ccA data[SEQ_DECL_SIZE]; };
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__FGxE1Nuen6pVDc58PZudJw_Content { NI cap; tyTuple__7xc1P89akJWzo77UAKrb3aA data[SEQ_DECL_SIZE]; };
struct tySequence__6j25whH7XTBoIXcM0x1T7A_Content { NI cap; tyTuple__9cdgeqdY7FRioNKBoD6G66A data[SEQ_DECL_SIZE]; };
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content { NI cap; tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE]; };
struct tySequence__shxop0zPIs5Ec3k71aCLuQ_Content { NI cap; NIM_BOOL data[SEQ_DECL_SIZE]; };
struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content { NI cap; tyTuple__kuMQ1fbjJlHtwKTmBGAe6g data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__T69aiRC686UsUPVrEM9awLDA_Content { NI cap; tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content { NI cap; tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw data[SEQ_DECL_SIZE]; };
struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content { NI cap; tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* data[SEQ_DECL_SIZE]; };
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tySequence__s3NGK5xFNK6fPmXupxoolA_Content { NI cap; tyTuple__pX68bRYqY0ZF09cQ4s0LV9ag data[SEQ_DECL_SIZE]; };
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content { NI cap; tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg data[SEQ_DECL_SIZE]; };
struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content { NI cap; tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A data[SEQ_DECL_SIZE]; };
struct tySequence__8Np6tlClE5az1CyqZdN19bQ_Content { NI cap; tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ data[SEQ_DECL_SIZE]; };
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__G9cHmkmNmy6ZlkFfXcex3Hw_Content { NI cap; tyTuple__9ay7GjiPeMMFnmoYwk84apw data[SEQ_DECL_SIZE]; };
struct tySequence__GVxMaHC0xtgqjBZ8ubUwnA_Content { NI cap; tyTuple__7SDQCf3TbPJf09bOXiapRgg data[SEQ_DECL_SIZE]; };
struct tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content { NI cap; tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ data[SEQ_DECL_SIZE]; };
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content { NI cap; tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* data[SEQ_DECL_SIZE]; };
struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content { NI cap; tyTuple__09aD69az7aYn14Gt61AHvLIA data[SEQ_DECL_SIZE]; };
struct tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ_Content { NI cap; tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content { NI cap; tyProc__c9bXGQkBnyyGGVw063jrwZw data[SEQ_DECL_SIZE]; };
struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg {
	NI ra;
	NI rb;
	NI rc;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* slots;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentException;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA currentLineInfo;
};
struct tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content { NI cap; tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA data[SEQ_DECL_SIZE]; };
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content { NI cap; tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA data[SEQ_DECL_SIZE]; };
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content { NI cap; NU64 data[SEQ_DECL_SIZE]; };
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content { NI cap; tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE]; };
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content { NI cap; tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ data[SEQ_DECL_SIZE]; };
struct tySequence__6H5Oh5UUvVCLiakt9aTwtUQ_Content { NI cap; NU8 data[SEQ_DECL_SIZE]; };
struct tySequence__4eQHGndY6XBYpFOH09apV8Q_Content { NI cap; tyTuple__UV3llMMYFckfui8YMBuUZA data[SEQ_DECL_SIZE]; };
struct tySequence__e9ciFfeAg1p88UzCBnAPeVQ_Content { NI cap; tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg data[SEQ_DECL_SIZE]; };
struct tySequence__GyTgETkn69b26Etj2zBgjMw_Content { NI cap; tyEnum_ParserState__0xxCjL29aD8tzUEg49aPYfOw data[SEQ_DECL_SIZE]; };
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content { NI cap; tyTuple__y6bKAf9a9aaVwun6lVDxSX7g data[SEQ_DECL_SIZE]; };
struct tySequence__mnb4N9bRCddoL53waHA7kHQ_Content { NI cap; tyTuple__bxYrf1dnwYK6GanDNddhgQ data[SEQ_DECL_SIZE]; };
struct tySequence__R1mQMFmsdp1ChoJDXa9a0xQ_Content { NI cap; tyTuple__rczUtx07rG4YmHOEmcEUJw data[SEQ_DECL_SIZE]; };
struct tySequence__tt8kXsbz31MUMFUF6Q9aQuQ_Content { NI cap; tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg data[SEQ_DECL_SIZE]; };
struct tySequence__kQFByJmZecfF9a1LYqz7zYg_Content { NI cap; tyObject_State__HKH8xQquLWVVc5hqriE25Q data[SEQ_DECL_SIZE]; };
struct tySequence__kP47rw9c8bgVA53QKWe9bp7g_Content { NI cap; tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw data[SEQ_DECL_SIZE]; };
struct tySequence__qff4v1r3n1JKmy1NzJOChA_Content { NI cap; tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw data[SEQ_DECL_SIZE]; };
struct tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content { NI cap; tyTuple__9ap1MJ9bVBlP34AqrUq01n8w data[SEQ_DECL_SIZE]; };
struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content { NI cap; tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A data[SEQ_DECL_SIZE]; };
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content { NI cap; tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ data[SEQ_DECL_SIZE]; };
struct tySequence__hMc5eJjVGjq6i857yHjTtg_Content { NI cap; tyTuple__Wipq1508vNWp3jwczem6TQ data[SEQ_DECL_SIZE]; };
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__9bnh9aVmYtKU19btQYqjGktpw_Content { NI cap; tyObject_CandidateError__f049c8Bs49cqj6FTSrUbSmlw data[SEQ_DECL_SIZE]; };
struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content { NI cap; tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE]; };
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content { NI cap; tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ data[SEQ_DECL_SIZE]; };
struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content { NI cap; tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw data[SEQ_DECL_SIZE]; };
struct tySequence__cLt1WK9c8DYlNqjYIVmv5sQ_Content { NI cap; tyTuple__c0qUCL3KxsVjGYwcv7lQbg data[SEQ_DECL_SIZE]; };
struct tySequence__bdNIx7Bah2llfuqeoTJEWQ_Content { NI cap; tyTuple__kIcKc1aSJCixG4QCidyBAg data[SEQ_DECL_SIZE]; };
struct tySequence__Cw89anHgi6Xla7dgB7Unvmw_Content { NI cap; tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA data[SEQ_DECL_SIZE]; };
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__SyrQ8FqS1U0ZKpu8mJO6PQ_Content { NI cap; tyObject_VarIndex__xDnEx9cq41ypm0l6yI8haPg data[SEQ_DECL_SIZE]; };
struct tySequence__9aee2Loc4nE9bvjjGuhsI78w_Content { NI cap; tyObject_MutationInfo__PxsvdgDRugMnwwZP8bDvWA data[SEQ_DECL_SIZE]; };
struct tySequence__dAjyAaabi52TN36Jp0fAXQ_Content { NI cap; tyTuple__X9bWVAqRSgByRpQwn6owzEA data[SEQ_DECL_SIZE]; };
struct tySequence__4SBkVvm2CCxNvzruVhJR5g_Content { NI cap; tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA data[SEQ_DECL_SIZE]; };
struct tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg_Content { NI cap; tyEnum_Nilability__dSflzd1x9b2hnEWhJ29aqYgg data[SEQ_DECL_SIZE]; };
struct tySequence__xKcKU9c79cy1NlvTXGoOtyWg_Content { NI cap; tySequence__tgZNpA9ayNCNeNkBBBthFtA data[SEQ_DECL_SIZE]; };
struct tySequence__tgZNpA9ayNCNeNkBBBthFtA_Content { NI cap; tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg data[SEQ_DECL_SIZE]; };
struct tySequence__XlRvVllIQIinot2wpb0XoA_Content { NI cap; tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ data[SEQ_DECL_SIZE]; };
struct tySequence__1I4GqOPEtd9ark9cZ2UT20tw_Content { NI cap; tyTuple__PijKblgFKtbdIstVEwjmCw data[SEQ_DECL_SIZE]; };
struct tySequence__4j8aBmBZMD9chZMBaxw9bcbQ_Content { NI cap; tyTuple__IYAk6y4YHp5OEJgCALGjQw data[SEQ_DECL_SIZE]; };
struct tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content { NI cap; tyTuple__R9cYIordoMujN7rycr4Y7kw data[SEQ_DECL_SIZE]; };
struct tySequence__SxRJJ9bayPyj0RYzIZTiohA_Content { NI cap; tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw data[SEQ_DECL_SIZE]; };
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content { NI cap; tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE]; };
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content { NI cap; tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw data[SEQ_DECL_SIZE]; };
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content { NI cap; tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE]; };
struct tySequence__zpKGgayc1mFyemMGMuK9a2w_Content { NI cap; tyTuple__DfjLoSEvFkvlneCb5GSa9cQ data[SEQ_DECL_SIZE]; };
struct tySequence__9cbEQVGky3gHl4QEC3q4Sow_Content { NI cap; tyTuple__GhsGHTmri9bgdv8XapNtpTg data[SEQ_DECL_SIZE]; };
struct tySequence__9bRXJy1JXrQ4hWpStaKBpXg_Content { NI cap; tyTuple__9agFg9cuYsNvckAbTfHAsTSA data[SEQ_DECL_SIZE]; };
struct tySequence__jwzrUFjG9akTIJTBBFvvqxw_Content { NI cap; tyTuple__XOVT24GHXwqiEj5GCsEGCA data[SEQ_DECL_SIZE]; };
struct tySequence__fVUhfWxkucMvZhVKGrAHuA_Content { NI cap; tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* data[SEQ_DECL_SIZE]; };
struct tySequence__kq9c1GdJLvkYJeijBmsJ20A_Content { NI cap; tyTuple__UGkfKgNvKJXAR6NX6Y5gaw data[SEQ_DECL_SIZE]; };
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__1xFov7v9c2rs44orw6d9bPmw_Content { NI cap; tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g data[SEQ_DECL_SIZE]; };
struct tySequence__ASKXHf9aJJjLj0hSZ39ci19cA_Content { NI cap; tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q data[SEQ_DECL_SIZE]; };
struct tySequence__gGvy9cKEpHEX9cA4gF5mzkxA_Content { NI cap; tyTuple__MDblJIdBvEzk3cvDpORS3w data[SEQ_DECL_SIZE]; };
struct tySequence__W61O50MEQVwc9azCYWJekkw_Content { NI cap; tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw data[SEQ_DECL_SIZE]; };
struct tySequence__7Eqk7CViYtlAWKDoMfuEcw_Content { NI cap; tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg data[SEQ_DECL_SIZE]; };
struct tySequence__jXZVXmhly1BClQDJpGni9ag_Content { NI cap; tyTuple__ILpLBib1l58GvVZ4BcToSg data[SEQ_DECL_SIZE]; };
struct tySequence__1cgZIGFge8OGY6Zlwa9aRnw_Content { NI cap; tyTuple__IGtaz2jo9ahodpWjWgc5c5A data[SEQ_DECL_SIZE]; };
struct tySequence__olcP618a61wlx6oJIT9b0sA_Content { NI cap; tyTuple__P9bg2wlfPi4dSSTi3ICCeVA data[SEQ_DECL_SIZE]; };
struct tySequence__P9aymq2R2Xa8At0XKJ6Bh1A_Content { NI cap; tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw data[SEQ_DECL_SIZE]; };
struct tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ_Content { NI cap; tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ data[SEQ_DECL_SIZE]; };
struct tySequence__LqZapiAqCFeXPQZdoIAUew_Content { NI cap; tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* data[SEQ_DECL_SIZE]; };
struct tySequence__Ygtgme9cSsBUPbXwOprm43Q_Content { NI cap; tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg data[SEQ_DECL_SIZE]; };
struct tySequence__ib5UTyrs9aC6K60sNqKElQA_Content { NI cap; tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA data[SEQ_DECL_SIZE]; };
struct tySequence__O9a9cp2XDKWshwC0UDgFP6Pw_Content { NI cap; tyTuple__Na59bk2YQTCLBWTLyeMrWdA data[SEQ_DECL_SIZE]; };
struct tySequence__7kOUUrKwg6xKu7wOGcJDlQ_Content { NI cap; tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg data[SEQ_DECL_SIZE]; };
struct tySequence__vz9c2digtAnM8l0FZWLUAGg_Content { NI cap; tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A data[SEQ_DECL_SIZE]; };
struct tySequence__jK2T9bFw5BWKL8ZZ854oXZg_Content { NI cap; tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA data[SEQ_DECL_SIZE]; };
struct tySequence__lBgZ7a89beZGYPl8PiANMTA_Content { NI cap; NIM_CHAR data[SEQ_DECL_SIZE]; };
struct tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg_Content { NI cap; tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng data[SEQ_DECL_SIZE]; };
struct tySequence__vdmFdgox3dhDOMkkFi9ayfg_Content { NI cap; tyTuple__4Ywt2LYBMs9aMJ09cL7digow data[SEQ_DECL_SIZE]; };
struct tySequence__qagWYy9b8OIJNg9bWhIaAjyw_Content { NI cap; tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ data[SEQ_DECL_SIZE]; };
struct tySequence__g9cc9ce4njfC9a8r1mQEl8mIg_Content { NI cap; tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ data[SEQ_DECL_SIZE]; };
struct tySequence__lCWXucMn9bU7PUqVDK7772w_Content { NI cap; tyTuple__kNIN44R9cL9cYoYzXmSW4y7w data[SEQ_DECL_SIZE]; };
struct tySequence__b9cVyuSHmrW80P0ZGgU2KHA_Content { NI cap; tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg data[SEQ_DECL_SIZE]; };
struct tySequence__uAwiTxV3boseSy9a9cSsXHEA_Content { NI cap; tyTuple__30Ti2rm9aDSr5neUSZP6EVQ data[SEQ_DECL_SIZE]; };
struct tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg_Content { NI cap; tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg data[SEQ_DECL_SIZE]; };
struct tySequence__9at3Cmn7xIajy679cMZSmybg_Content { NI cap; tyTuple__RrY3dT8dfTceE0s6Bv9bxJw data[SEQ_DECL_SIZE]; };
struct tySequence__fXWXs2NlFKREhy9cn6vokJw_Content { NI cap; tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* data[SEQ_DECL_SIZE]; };
struct tySequence__eb7tUf9a8CR5sBO6O3AH67A_Content { NI cap; tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw data[SEQ_DECL_SIZE]; };
struct tySequence__m9axZwxFfhSNLcoofvKZJYA_Content { NI cap; tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ data[SEQ_DECL_SIZE]; };
struct tySequence__NZB65egHQwAniMoFWKcFaw_Content { NI cap; tyTuple__bPZu3GhfjP9cHscH3h9axT6w data[SEQ_DECL_SIZE]; };
struct tySequence__EHM5DWw09bc16yo24mdZPsw_Content { NI cap; tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw* data[SEQ_DECL_SIZE]; };
struct tySequence__pN5ht9bYa9c1VQJ0Er2wvTuA_Content { NI cap; tySequence__EHM5DWw09bc16yo24mdZPsw data[SEQ_DECL_SIZE]; };
struct tySequence__u440EGTDYOwkQLE9asdZ6OQ_Content { NI cap; tyObject_Mapping__5X9cm3giTN9aYJbVTF9clmk7A data[SEQ_DECL_SIZE]; };
struct tySequence__IWLCUlc3h6FWY379alhl9aaQ_Content { NI cap; tyObject_Segment__9cSimljufAUmxKUYLJk2dhw data[SEQ_DECL_SIZE]; };
struct tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content { NI cap; tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ data[SEQ_DECL_SIZE]; };
struct tySequence__ElKBSoViSyNazy7qD89atSA_Content { NI cap; tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw data[SEQ_DECL_SIZE]; };
struct tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ_Content { NI cap; tyTuple__fgn415DvsSyiHk3o9aIYr0w data[SEQ_DECL_SIZE]; };
struct tySequence__H9bHW2kkjp26MABVBZRr8Ig_Content { NI cap; tyTuple__EJOd8NnRbGOjqpW2d6uq2g data[SEQ_DECL_SIZE]; };
struct tySequence__MboA857W9b3olvEyCWLQeEg_Content { NI cap; tyTuple__jYR27AKllNE6EvJCKQs1WA data[SEQ_DECL_SIZE]; };
struct tySequence__UuiPn6QjIiUTdSVwX2PZ6w_Content { NI cap; tyTuple__9a3DhYVfcy14Fx42tD0lSEQ data[SEQ_DECL_SIZE]; };
struct tySequence__9aHwlozdspjDnjhtzDhmdVg_Content { NI cap; tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ* data[SEQ_DECL_SIZE]; };
struct tySequence__mg32q50AXD9cQ6jovpBmgWA_Content { NI cap; tyTuple__bvjw5f4vMpB9bESWLU7nvyA data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NOCONV(void, signalHandler)(int sign_p0);
N_LIB_PRIVATE N_NIMCALL(void, showErrorMessage__system_u3603)(NCSTRING data_p0, NI length_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cstrToNimstr)(NCSTRING str_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toNimStr)(NCSTRING str_p0, NI len_p1);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NOCONV(void*, allocImpl__system_u1758)(NI size_p0);
N_LIB_PRIVATE N_NIMCALL(void*, alloc__system_u7115)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* allocator_p0, NI size_p1);
N_LIB_PRIVATE N_NIMCALL(void*, rawAlloc__system_u6870)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI requestedSize_p1, NI alignment_p2);
static N_INLINE(NI, roundup__system_u5860)(NI x_p0, NI v_p1);
static N_INLINE(NI, smallChunkAlignOffset__system_u6858)(NI alignment_p0);
N_LIB_PRIVATE N_NIMCALL(NI, align__system_u1639)(NI address_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*, getSmallChunk__system_u6740)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, getBigChunk__system_u6712)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1);
static N_INLINE(void, mappingSearch__system_u6018)(NI* r_p0, NI* fl_p1, NI* sl_p2);
static N_INLINE(NI, msbit__system_u5993)(NU32 x_p0);
static N_INLINE(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, findSuitableBlock__system_u6051)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI* fl_p1, NI* sl_p2);
static N_INLINE(NI, lsbit__system_u6001)(NU32 x_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, requestOsChunks__system_u6611)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1);
N_LIB_PRIVATE N_NIMCALL(void*, allocPages__system_u6187)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1);
static N_INLINE(void*, osAllocPages__system_u5880)(NI size_p0);
N_LIB_PRIVATE N_NOINLINE(void, raiseOutOfMem__system_u5855)(void);
static N_INLINE(void, rawWrite)(FILE* f_p0, NCSTRING s_p1);
N_LIB_PRIVATE N_NIMCALL(void*, tryAllocPages__system_u6191)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1);
static N_INLINE(void*, osTryAllocPages__system_u5883)(NI size_p0);
static N_INLINE(void, incCurrMem__system_u6167)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI bytes_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA*, addHeapLink__system_u6233)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* p_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void*, llAlloc__system_u6195)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1);
static N_INLINE(void, zeroMem__system_u1739)(void* p_p0, NI size_p1);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__system_u6377)(tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*, intSetGet__system_u6328)(tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* t_p0, NI key_p1);
static N_INLINE(NI, pageIndex__system_u6594)(tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* c_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, splitChunk__system_u6683)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, splitChunk2__system_u6659)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1, NI size_p2);
static N_INLINE(void, updatePrevSize__system_u6654)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1, NI prevSize_p2);
static N_INLINE(NIM_BOOL, isAccessible__system_u6636)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, void* p_p1);
static N_INLINE(NI, pageIndex__system_u6601)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, incl__system_u6418)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* s_p1, NI key_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*, intSetPut__system_u6360)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* t_p1, NI key_p2);
N_LIB_PRIVATE N_NIMCALL(void, addChunkToMatrix__system_u6157)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* b_p1);
static N_INLINE(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ, mappingInsert__system_u6036)(NI r_p0);
static N_INLINE(void, setBit__system_u6004)(NI nr_p0, NU32* dest_p1);
N_LIB_PRIVATE N_NIMCALL(void, removeChunkFromMatrix2__system_u6148)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* b_p1, NI fl_p2, NI sl_p3);
static N_INLINE(void, clearBit__system_u6011)(NI nr_p0, NU32* dest_p1);
N_LIB_PRIVATE N_NIMCALL(void, compensateCounters__system_u6800)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_p1, NI size_p2);
static N_INLINE(tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*, pageAddr__system_u6608)(void* p_p0);
static N_INLINE(void, listAdd__system_u6903)(tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA** head_p0, tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_p1);
static N_INLINE(void, listRemove__system_u6976)(tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA** head_p0, tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_p1);
N_LIB_PRIVATE N_NIMCALL(void, freeDeferredObjects__system_u6835)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* root_p1);
N_LIB_PRIVATE N_NIMCALL(void, deallocBigChunk__system_u6758)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1);
N_LIB_PRIVATE N_NIMCALL(void, freeHugeChunk__system_u6736)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1);
N_LIB_PRIVATE N_NIMCALL(void, excl__system_u6440)(tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* s_p0, NI key_p1);
static N_INLINE(void, decCurrMem__system_u6175)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI bytes_p1);
static N_INLINE(void, osDeallocPages__system_u5886)(void* p_p0, NI size_p1);
N_LIB_PRIVATE N_NIMCALL(void, freeBigChunk__system_u6688)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1);
static N_INLINE(NIM_BOOL, chunkUnused__system_u6516)(tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* c_p0);
static N_INLINE(NIM_BOOL, isSmallChunk__system_u6510)(tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, removeChunkFromMatrix__system_u6106)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* b_p1);
static N_INLINE(void, addToSharedFreeListBigChunks__system_u6769)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1);
static N_INLINE(NI, bigChunkAlignOffset__system_u6867)(NI alignment_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, getHugeChunk__system_u6732)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(NI, nimCStrLen)(NCSTRING a_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NOCONV(void, dealloc)(void* p_p0);
N_LIB_PRIVATE N_NOCONV(void, deallocImpl__system_u1762)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, dealloc__system_u7123)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* allocator_p0, void* p_p1);
N_LIB_PRIVATE N_NIMCALL(void, rawDealloc__system_u7040)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, void* p_p1);
static N_INLINE(void, addToSharedFreeList__system_u6776)(tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_p0, tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg* f_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, raiseDefect)(void);
static N_INLINE(Exception*, getCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3664)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2);
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3500)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3130)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, registerCycle__system_u3460)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NIMCALL(void, init__system_u3340)(tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg* s_p0, NI cap_p1);
static N_INLINE(NI, starpercent___system_u825)(NI x_p0, NI y_p1);
static N_INLINE(void, add__system_u3234)(tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg* s_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3242)(tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg* s_p0);
N_LIB_PRIVATE N_NOCONV(void*, reallocImpl__system_u1764)(void* p_p0, NI newSize_p1);
N_LIB_PRIVATE N_NIMCALL(void*, realloc__system_u7126)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* allocator_p0, void* p_p1, NI newsize_p2);
N_LIB_PRIVATE N_NIMCALL(NI, ptrSize__system_u7103)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, collectCycles__system_u3435)(void);
N_LIB_PRIVATE N_NIMCALL(void, init__system_u3387)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, NI cap_p1);
N_LIB_PRIVATE N_NIMCALL(void, collectCyclesBacon__system_u3293)(tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p0, NI lowMark_p1);
N_LIB_PRIVATE N_NIMCALL(void, markGray__system_u3175)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p2);
static N_INLINE(void, trace__system_u2949)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p2);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(tyTuple__N4J9cV4JZGem3ljqqj5rT0Q, pop__system_u3163)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, scan__system_u3201)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p2);
N_LIB_PRIVATE N_NIMCALL(void, scanBlack__system_u3155)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p2);
N_LIB_PRIVATE N_NIMCALL(void, collectColor__system_u3226)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, NI col_p2, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p3);
static N_INLINE(void, free__system_u3003)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, nimAlignedDealloc__system_u2760)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, deinit__system_u3374)(tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, deinit__system_u3399)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2);
N_LIB_PRIVATE N_NIMCALL(void, reportUnhandledError__system_u4140)(Exception* e_p0);
N_LIB_PRIVATE N_NIMCALL(void, reportUnhandledErrorAux__system_u4043)(Exception* e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___system_u3959)(tySequence__S89cE01OvNjsN9c71FKsSrqQ stackTraceEntries_p0);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
static N_INLINE(NI, resize__system_u2228)(NI old_p0);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NOCONV(void*, realloc0Impl__system_u1767)(void* p_p0, NI oldSize_p1, NI newSize_p2);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u3661)(Exception* dest_p0);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, writeToStdErr__system_u3596)(NCSTRING msg_p0, NI length_p1);
static N_INLINE(void, rawWriteString)(FILE* f_p0, NCSTRING s_p1, NI length_p2);
N_LIB_PRIVATE N_NIMCALL(void, registerSignalHandler__system_u4394)(void);
static N_INLINE(void, initStackBottom)(void);
N_LIB_PRIVATE N_NIMCALL(void, shrink__astalgo_u688)(tySequence__9chP3SzkaldXzawWQCDsqqg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__astalgo_u681)(tySequence__9chP3SzkaldXzawWQCDsqqg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void*, prepareSeqAddUninit)(NI len_p0, void* p_p1, NI addlen_p2, NI elemSize_p3, NI elemAlign_p4);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayloadUninit)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void*, alignedAlloc__system_u1915)(NI size_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void*, alignedRealloc__system_u1971)(void* p_p0, NI oldSize_p1, NI newSize_p2, NI align_p3);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void, nimAsgnStrV2)(NimStringV2* a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void*, nimAlignedAlloc0__system_u2754)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__system_u4194)(tySequence__S89cE01OvNjsN9c71FKsSrqQ* x_p0, tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA y_p1);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionAux__system_u4173)(Exception* e_p0);
static N_INLINE(void, pushCurrentException)(Exception* e_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u3672)(Exception** dest_p0, Exception* src_p1);
N_LIB_PRIVATE N_NOCONV(void*, alloc0Impl__system_u1760)(NI size_p0);
N_LIB_PRIVATE N_NIMCALL(void*, alloc0__system_u7119)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* allocator_p0, NI size_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, newStringUninit__system_u2684)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5509)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimAlignedAlloc__system_u2757)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZstrtabs_u422)(tySequence__xv3aaFd3JCw8NbmALHiezQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZstrtabs_u127)(tySequence__xv3aaFd3JCw8NbmALHiezQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZstrtabs_u147)(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZstrtabs_u164)(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZstrtabs_u161)(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZstrtabs_u119)(tySequence__xv3aaFd3JCw8NbmALHiezQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void*, alignedAlloc0__system_u1961)(NI size_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__lineinfos_u428)(tySequence__7lEisrXlQEzwtUKW5pzRCw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__lineinfos_u486)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u502)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lineinfos_u499)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__lineinfos_u432)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__options_u1085)(tySequence__4eRCaZmrYLLw2k30GPTiMw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__options_u1143)(tyTuple__QeWl6B6ffS4pU6WWrtcrDw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1159)(tyTuple__QeWl6B6ffS4pU6WWrtcrDw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___options_u1156)(tyTuple__QeWl6B6ffS4pU6WWrtcrDw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u1089)(tySequence__4eRCaZmrYLLw2k30GPTiMw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__options_u726)(tySequence__FGxE1Nuen6pVDc58PZudJw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u730)(tySequence__FGxE1Nuen6pVDc58PZudJw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__system_u5402)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__system_u5406)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__system_u5464)(NimStringV2* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__system_u5410)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8654)(NimStringV2 s_p0, NI first_p1, NI last_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(void, quit__system_u7978)(NI errorcode_p0);
static N_INLINE(void, showErrorMessage2__system_u3611)(NimStringV2 data_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u1391)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__options_u1399)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__options_u1419)(NimStringV2* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nimblecmd_u592)(tySequence__6j25whH7XTBoIXcM0x1T7A* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__nimblecmd_u612)(tyTuple__9cdgeqdY7FRioNKBoD6G66A* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nimblecmd_u629)(tyTuple__9cdgeqdY7FRioNKBoD6G66A* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___nimblecmd_u626)(tyTuple__9cdgeqdY7FRioNKBoD6G66A* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__nimblecmd_u585)(tySequence__6j25whH7XTBoIXcM0x1T7A* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4);
static N_INLINE(void, addEscapedChar__system_u8294)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u3941)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2823)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u4732)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u4752)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u4725)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u11235)(tySequence__fdmz6VkIf1ewwrssKYqRFg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u11293)(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11309)(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11306)(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u11239)(tySequence__fdmz6VkIf1ewwrssKYqRFg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13228)(tySequence__TfHJycarvNts8E4mVG4Mfg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u16091)(tySequence__48JTohSgTy339bRxHzUD8KA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u11451)(tySequence__kxu4GK0onha2t9bo86mdVAg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u11455)(tySequence__kxu4GK0onha2t9bo86mdVAg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__suggestsymdb_u1451)(tySequence__fz0REU1l0nYmKHXgMLRrIg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__suggestsymdb_u1508)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___suggestsymdb_u1524)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___suggestsymdb_u1521)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__suggestsymdb_u1455)(tySequence__fz0REU1l0nYmKHXgMLRrIg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u11667)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u11725)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11741)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11738)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u11671)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13327)(tySequence__kHjIdgrpmuSn9cUIIKpSiDg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u12111)(tySequence__R9c39btP6BwOBBPnbaNUtMQg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u12169)(tyTuple__OtlgAx3kBps9cOSMNDZSzBA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12185)(tyTuple__OtlgAx3kBps9cOSMNDZSzBA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u12182)(tyTuple__OtlgAx3kBps9cOSMNDZSzBA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u12115)(tySequence__R9c39btP6BwOBBPnbaNUtMQg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u12328)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u12386)(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12402)(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u12399)(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u12332)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u12538)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u12596)(tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12612)(tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u12609)(tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u12542)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u12862)(tySequence__vJcM7B74R2U5db9cxyXT9coA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u12920)(tyTuple__XrHNJHOzS3O7uwF9bvCySiA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u12936)(tyTuple__XrHNJHOzS3O7uwF9bvCySiA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u12933)(tyTuple__XrHNJHOzS3O7uwF9bvCySiA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u12866)(tySequence__vJcM7B74R2U5db9cxyXT9coA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u13078)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u13082)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___idents_u152)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u8095)(NI dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u8091)(NI* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u2885)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u2943)(tyTuple__Oubp8LPEu86EPyDuc56AXg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u2959)(tyTuple__Oubp8LPEu86EPyDuc56AXg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u2956)(tyTuple__Oubp8LPEu86EPyDuc56AXg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u2889)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lexer_u526)(tyObject_Token__pst9a89bCqNyggpo6gRF7jhA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lexer_u523)(tyObject_Token__pst9a89bCqNyggpo6gRF7jhA* dest_p0);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgen_u14890)(tySequence__shxop0zPIs5Ec3k71aCLuQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u1163)(tySequence__7s5HyddQ0f9bxMNILHrXwJQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u1183)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u1200)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u1197)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u1156)(tySequence__7s5HyddQ0f9bxMNILHrXwJQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u3725)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u3745)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u4100)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3718)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZcollectionsZintsets_u130)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZcollectionsZintsets_u150)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u48)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZcollectionsZintsets_u45)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZcollectionsZintsets_u122)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u12947)(tySequence__5reviU45axUMPQgL9aoENrg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u12967)(tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u12984)(tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u12981)(tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u1580)(tySequence__9bAGqSvkAaFL9bWjsEPslrFA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u1584)(tySequence__9bAGqSvkAaFL9bWjsEPslrFA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u1588)(tySequence__9bAGqSvkAaFL9bWjsEPslrFA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8071)(tySequence__PXIzfWocnrafGz5p3CP5LA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u7974)(tySequence__PXIzfWocnrafGz5p3CP5LA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u7978)(tySequence__PXIzfWocnrafGz5p3CP5LA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u8031)(tyTuple__0q9cmhneJEKnQERTpXXdz6Q* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u3031)(tyTuple__0q9cmhneJEKnQERTpXXdz6Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u3028)(tyTuple__0q9cmhneJEKnQERTpXXdz6Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u7982)(tySequence__PXIzfWocnrafGz5p3CP5LA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8253)(tySequence__IHUFRsFxZNv7YydiUO2esQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u8178)(tySequence__IHUFRsFxZNv7YydiUO2esQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u8182)(tySequence__IHUFRsFxZNv7YydiUO2esQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u8186)(tySequence__IHUFRsFxZNv7YydiUO2esQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8420)(tySequence__b89aLriiJnVTD186H6zNIgg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u8345)(tySequence__b89aLriiJnVTD186H6zNIgg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u8349)(tySequence__b89aLriiJnVTD186H6zNIgg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u8353)(tySequence__b89aLriiJnVTD186H6zNIgg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8606)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u8531)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u8535)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u8539)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8792)(tySequence__48JTohSgTy339bRxHzUD8KA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u8717)(tySequence__48JTohSgTy339bRxHzUD8KA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u8721)(tySequence__48JTohSgTy339bRxHzUD8KA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u8725)(tySequence__48JTohSgTy339bRxHzUD8KA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZpacked95ast_u123)(tySequence__OxRbUT0qZaZN5UjnqQjGPA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZpacked95ast_u1310)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZpacked95ast_u151)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZpacked95ast_u143)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZpacked95ast_u1395)(tySequence__ezS5mGPcRfBURJyMgqYVzA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZpacked95ast_u291)(tySequence__ezS5mGPcRfBURJyMgqYVzA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZpacked95ast_u283)(tySequence__ezS5mGPcRfBURJyMgqYVzA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZpacked95ast_u1480)(tySequence__wW7xkohjuUKO9aMaB0nt9cqA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZpacked95ast_u394)(tySequence__wW7xkohjuUKO9aMaB0nt9cqA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZpacked95ast_u386)(tySequence__wW7xkohjuUKO9aMaB0nt9cqA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u586)(tySequence__Vl1abU3gfp0RqCb1KKfmDA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u579)(tySequence__Vl1abU3gfp0RqCb1KKfmDA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u3843)(tySequence__qyyNkmlc4fzOzelC8spUkQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u3900)(tyTuple__anemVmHCFglLFt6LiEhFvg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u3916)(tyTuple__anemVmHCFglLFt6LiEhFvg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u3913)(tyTuple__anemVmHCFglLFt6LiEhFvg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u3847)(tySequence__qyyNkmlc4fzOzelC8spUkQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u7636)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u3968)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u3961)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u9558)(tySequence__YYy1721YAuPF0ajBYHd8Wg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u9483)(tySequence__YYy1721YAuPF0ajBYHd8Wg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u9487)(tySequence__YYy1721YAuPF0ajBYHd8Wg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u9491)(tySequence__YYy1721YAuPF0ajBYHd8Wg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u9762)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u9665)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u9669)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u9722)(tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u7685)(tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u7682)(tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u9673)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u9945)(tySequence__F1qNdU7m0Czu7Y2q0eksXw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u9870)(tySequence__F1qNdU7m0Czu7Y2q0eksXw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u9874)(tySequence__F1qNdU7m0Czu7Y2q0eksXw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u9878)(tySequence__F1qNdU7m0Czu7Y2q0eksXw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u10155)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u10052)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u10056)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u10060)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZiclineinfos_u369)(tySequence__orxtl6CusdjXleqrxi67gw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZiclineinfos_u294)(tySequence__orxtl6CusdjXleqrxi67gw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZiclineinfos_u298)(tySequence__orxtl6CusdjXleqrxi67gw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZiclineinfos_u302)(tySequence__orxtl6CusdjXleqrxi67gw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u13410)(tySequence__FmsTQiIcS9arxHxs3QY48vA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u13430)(tyTuple__MZVSn3SE3XUBJOaMu7ofRQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13447)(tyTuple__MZVSn3SE3XUBJOaMu7ofRQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u13444)(tyTuple__MZVSn3SE3XUBJOaMu7ofRQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u13402)(tySequence__FmsTQiIcS9arxHxs3QY48vA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u13246)(tySequence__UE4b6iUkm1b3zTPamTTkDw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u13266)(tyTuple__1xWeGeoNoZxaLhTUDDWYyA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13283)(tyTuple__1xWeGeoNoZxaLhTUDDWYyA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u13280)(tyTuple__1xWeGeoNoZxaLhTUDDWYyA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u13238)(tySequence__UE4b6iUkm1b3zTPamTTkDw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u13084)(tySequence__K0j67V58u5FW0dCC534FQw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u13104)(tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u13121)(tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u13118)(tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u13076)(tySequence__K0j67V58u5FW0dCC534FQw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u16266)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u3341)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u3361)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3375)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3333)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u10906)(tySequence__TfHJycarvNts8E4mVG4Mfg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u10926)(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u10943)(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u10940)(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1177)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3521)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u3031)(tySequence__dtr79aXjHrgHuH79ac55I2aw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u3051)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3068)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u3065)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u1420)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u1413)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__lookups_u839)(tySequence__s3NGK5xFNK6fPmXupxoolA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__lookups_u843)(tySequence__s3NGK5xFNK6fPmXupxoolA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_u1103)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA a_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA b_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__layeredtable_u24)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__layeredtable_u82)(tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___layeredtable_u98)(tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___layeredtable_u95)(tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__layeredtable_u28)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u778)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u798)(tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u815)(tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u812)(tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u770)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u5355)(tySequence__3vEEVfBECLN6NIRA3FIp5g* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u5375)(tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u5392)(tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u5389)(tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u5348)(tySequence__3vEEVfBECLN6NIRA3FIp5g* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u3962)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u3982)(tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3999)(tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u3996)(tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u3955)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u702)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u722)(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u739)(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u736)(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__lineinfos_u1870)(tySequence__E0kio2ZnplNTuln9bsnljSA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__lineinfos_u1890)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u1907)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lineinfos_u1904)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__concepts_u435)(tySequence__G9cHmkmNmy6ZlkFfXcex3Hw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__concepts_u428)(tySequence__G9cHmkmNmy6ZlkFfXcex3Hw* s_p0, NI newlen_p1);
static N_INLINE(NIM_BOOL, eqeq___ast_u617)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA a_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA b_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___concepts_u824)(tyTuple__JqV0huqZNAHtnE3agKOyZg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___concepts_u821)(tyTuple__JqV0huqZNAHtnE3agKOyZg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3288)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lookups_u2835)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__lookups_u2839)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__lookups_u2892)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u2775)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lookups_u2772)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__lookups_u2843)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u574)(tySequence__tsHRsYLyvTCPLlGRExqi7Q* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u594)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u611)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u608)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u3294)(tyTuple__09aD69az7aYn14Gt61AHvLIA* dest_p0, tyTuple__09aD69az7aYn14Gt61AHvLIA src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3282)(tyTuple__09aD69az7aYn14Gt61AHvLIA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3240)(tySequence__9bffTLF0HkxjFCzZL8og4GA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3248)(tySequence__9bffTLF0HkxjFCzZL8og4GA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u3268)(tyTuple__09aD69az7aYn14Gt61AHvLIA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3285)(tyTuple__09aD69az7aYn14Gt61AHvLIA dest_p0);
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZosproc_u403)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZosproc_u399)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1);
static N_INLINE(void, nimCopySeqPayload)(void* dest_p0, void* src_p1, NI elemSize_p2, NI elemAlign_p3);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sigmatch_u5945)(tySequence__nSO1ltijM4vhc0UrrXKEqA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u11868)(tySequence__nSO1ltijM4vhc0UrrXKEqA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u11888)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11905)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11902)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u11860)(tySequence__nSO1ltijM4vhc0UrrXKEqA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_u8247)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_u1563)(NimStringV2 x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__lookups_u3990)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u4007)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lookups_u4004)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3561)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u3558)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u4657)(tySequence__C2ivDnhTZ6IxAdui1rfuqw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u4677)(tyTuple__F1mMODXmKFMNQ5rLCtcv0Q* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u4694)(tyTuple__F1mMODXmKFMNQ5rLCtcv0Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u4691)(tyTuple__F1mMODXmKFMNQ5rLCtcv0Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u4650)(tySequence__C2ivDnhTZ6IxAdui1rfuqw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u1316)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u1336)(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1353)(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1350)(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u1234)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u883)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0);
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1);
static N_INLINE(void, add__system_u3021)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3029)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u439)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u497)(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u513)(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u510)(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u443)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u6404)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u6462)(tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6478)(tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6475)(tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u6408)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__bitsets_u59)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZtimes_u2647)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZtimes_u2640)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmmarshal_u651)(tySequence__e9ciFfeAg1p88UzCBnAPeVQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__vmmarshal_u671)(tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmmarshal_u688)(tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmmarshal_u685)(tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmmarshal_u644)(tySequence__e9ciFfeAg1p88UzCBnAPeVQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u648)(tySequence__YdLNCDKYeipzJx3I8Xw82Q* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u769)(tySequence__TLbZ2GqL3Zio1f8bNpj2NA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u2038)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u2030)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__lambdalifting_u357)(tySequence__mnb4N9bRCddoL53waHA7kHQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__lambdalifting_u415)(tyTuple__bxYrf1dnwYK6GanDNddhgQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u431)(tyTuple__bxYrf1dnwYK6GanDNddhgQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lambdalifting_u428)(tyTuple__bxYrf1dnwYK6GanDNddhgQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__lambdalifting_u361)(tySequence__mnb4N9bRCddoL53waHA7kHQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__lambdalifting_u2577)(tySequence__R1mQMFmsdp1ChoJDXa9a0xQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__lambdalifting_u2635)(tyTuple__rczUtx07rG4YmHOEmcEUJw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lambdalifting_u2651)(tyTuple__rczUtx07rG4YmHOEmcEUJw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lambdalifting_u2648)(tyTuple__rczUtx07rG4YmHOEmcEUJw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__lambdalifting_u2581)(tySequence__R1mQMFmsdp1ChoJDXa9a0xQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__transf_u106)(tySequence__tt8kXsbz31MUMFUF6Q9aQuQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__transf_u164)(tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___transf_u180)(tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___transf_u177)(tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__transf_u110)(tySequence__tt8kXsbz31MUMFUF6Q9aQuQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__closureiters_u779)(tySequence__kP47rw9c8bgVA53QKWe9bp7g* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__closureiters_u772)(tySequence__kP47rw9c8bgVA53QKWe9bp7g* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__closureiters_u2388)(tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___closureiters_u2405)(tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___closureiters_u2402)(tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___closureiters_u187)(tyObject_State__HKH8xQquLWVVc5hqriE25Q* dest_p0, tyObject_State__HKH8xQquLWVVc5hqriE25Q* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___closureiters_u175)(tyObject_State__HKH8xQquLWVVc5hqriE25Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__closureiters_u2848)(tySequence__kQFByJmZecfF9a1LYqz7zYg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__closureiters_u2855)(tySequence__kQFByJmZecfF9a1LYqz7zYg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__closureiters_u2875)(tyObject_State__HKH8xQquLWVVc5hqriE25Q* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___closureiters_u178)(tyObject_State__HKH8xQquLWVVc5hqriE25Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZosproc_u395)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u1214)(tySequence__grdS5PdBBxkq9bxi4lFAdAw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u6400)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u994)(tySequence__b9bG03Q6unwlMU0dM7uOPIA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u1014)(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1031)(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u1028)(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u1650)(tySequence__9c9aWmheGsuf9aHtY7gTnUcPA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u1670)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1706)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u1703)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u1642)(tySequence__9c9aWmheGsuf9aHtY7gTnUcPA* s_p0, NI newlen_p1);
static N_INLINE(void, nimIncRef)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___nodekinds_u168)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u182)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg e_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3267)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u6323)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u13681)(tySequence__N589c2UsUgqqOITU2JfIuAQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u13701)(tyTuple__bnJwOH0eJlAwCAMbr1inhw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13718)(tyTuple__bnJwOH0eJlAwCAMbr1inhw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u13715)(tyTuple__bnJwOH0eJlAwCAMbr1inhw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u13673)(tySequence__N589c2UsUgqqOITU2JfIuAQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u13834)(tySequence__GYDW6wGgERshoSd16jJ3eQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u13854)(tyTuple__YG7h1OUHzgfgTeH9cl0U0dw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13871)(tyTuple__YG7h1OUHzgfgTeH9cl0U0dw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u13868)(tyTuple__YG7h1OUHzgfgTeH9cl0U0dw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u13826)(tySequence__GYDW6wGgERshoSd16jJ3eQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u9158)(tySequence__9aSa87aKMiolq9a7z3kC0jTw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u9178)(tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u9195)(tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u9192)(tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u9151)(tySequence__9aSa87aKMiolq9a7z3kC0jTw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u2242)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u2262)(tyTuple__lGHLhAAUpxgfrnQkIzNrMw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2279)(tyTuple__lGHLhAAUpxgfrnQkIzNrMw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u2276)(tyTuple__lGHLhAAUpxgfrnQkIzNrMw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3151)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3148)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u14036)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u14028)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA* s_p0, NI newlen_p1);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(NI, cmpStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3509)(tySequence__E8pi9b5QNahsURYzXMjh3qw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3501)(tySequence__E8pi9b5QNahsURYzXMjh3qw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3775)(tySequence__3B6hFqG0Do0FxDvnNucL7w* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u3795)(tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3812)(tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3809)(tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3767)(tySequence__3B6hFqG0Do0FxDvnNucL7w* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3639)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u3659)(tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3676)(tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3673)(tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1293)(tySequence__bdNIx7Bah2llfuqeoTJEWQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sempass2_u167)(tySequence__Cw89anHgi6Xla7dgB7Unvmw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__sempass2_u171)(tySequence__Cw89anHgi6Xla7dgB7Unvmw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__sempass2_u175)(tySequence__Cw89anHgi6Xla7dgB7Unvmw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u14272)(tySequence__T7nNEWoEbKBa0G5Htr45Xw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u14292)(tyTuple__UbCNQED4XJUgxOgPHJUcAQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u14309)(tyTuple__UbCNQED4XJUgxOgPHJUcAQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u14306)(tyTuple__UbCNQED4XJUgxOgPHJUcAQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u14264)(tySequence__T7nNEWoEbKBa0G5Htr45Xw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__varpartitions_u292)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__varpartitions_u284)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u3901)(tySequence__dAjyAaabi52TN36Jp0fAXQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u3894)(tySequence__dAjyAaabi52TN36Jp0fAXQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u1455)(tySequence__4SBkVvm2CCxNvzruVhJR5g* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__nilcheck_u1475)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u230)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZcollectionsZintsets_u227)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u544)(tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u360)(tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u353)(tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u633)(tySequence__xKcKU9c79cy1NlvTXGoOtyWg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u637)(tySequence__xKcKU9c79cy1NlvTXGoOtyWg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__nilcheck_u695)(tySequence__tgZNpA9ayNCNeNkBBBthFtA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u711)(tySequence__tgZNpA9ayNCNeNkBBBthFtA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___nilcheck_u708)(tySequence__tgZNpA9ayNCNeNkBBBthFtA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u641)(tySequence__xKcKU9c79cy1NlvTXGoOtyWg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u1048)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u1052)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u1056)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u741)(tySequence__tgZNpA9ayNCNeNkBBBthFtA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__nilcheck_u761)(tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u778)(tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___nilcheck_u775)(tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u6003)(tySequence__XlRvVllIQIinot2wpb0XoA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__nilcheck_u6023)(tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u6040)(tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___nilcheck_u6037)(tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u6506)(tySequence__1I4GqOPEtd9ark9cZ2UT20tw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u6499)(tySequence__1I4GqOPEtd9ark9cZ2UT20tw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___varpartitions_u1284)(tySequence__hMc5eJjVGjq6i857yHjTtg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sem_u3608)(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__sem_u3612)(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__sem_u3670)(tyTuple__IYAk6y4YHp5OEJgCALGjQw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u5581)(tyTuple__IYAk6y4YHp5OEJgCALGjQw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u5578)(tyTuple__IYAk6y4YHp5OEJgCALGjQw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__sem_u3616)(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u2688)(tySequence__4zAALtm0xUbRlYWQ2V8K7A* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u2696)(tySequence__4zAALtm0xUbRlYWQ2V8K7A* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u2716)(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u382)(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u379)(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2665)(tySequence__4zAALtm0xUbRlYWQ2V8K7A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u956)(tyTuple__R9cYIordoMujN7rycr4Y7kw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u973)(tyTuple__R9cYIordoMujN7rycr4Y7kw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u970)(tyTuple__R9cYIordoMujN7rycr4Y7kw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___wordrecg_u307)(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw e_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3927)(tySequence__QqvaCqCpEE1QmQZbcZLi5A* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u3947)(tyTuple__EbsafWGli8bW2GRJQ9apsjA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3964)(tyTuple__EbsafWGli8bW2GRJQ9apsjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3961)(tyTuple__EbsafWGli8bW2GRJQ9apsjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3919)(tySequence__QqvaCqCpEE1QmQZbcZLi5A* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u474)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u16118)(tySequence__48JTohSgTy339bRxHzUD8KA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3405)(tySequence__Bis5AbpONWcIRrPyPJS8Yw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3397)(tySequence__Bis5AbpONWcIRrPyPJS8Yw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14408)(NI* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vm_u14405)(NI** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1704)(tySequence__zpKGgayc1mFyemMGMuK9a2w* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u1724)(tyTuple__DfjLoSEvFkvlneCb5GSa9cQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1741)(tyTuple__DfjLoSEvFkvlneCb5GSa9cQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u1738)(tyTuple__DfjLoSEvFkvlneCb5GSa9cQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1696)(tySequence__zpKGgayc1mFyemMGMuK9a2w* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u797)(tySequence__9cbEQVGky3gHl4QEC3q4Sow* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u817)(tyTuple__GhsGHTmri9bgdv8XapNtpTg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u834)(tyTuple__GhsGHTmri9bgdv8XapNtpTg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u831)(tyTuple__GhsGHTmri9bgdv8XapNtpTg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u789)(tySequence__9cbEQVGky3gHl4QEC3q4Sow* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1439)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1431)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u554)(tySequence__jwzrUFjG9akTIJTBBFvvqxw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u612)(tyTuple__XOVT24GHXwqiEj5GCsEGCA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u1951)(tyTuple__XOVT24GHXwqiEj5GCsEGCA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZosproc_u1948)(tyTuple__XOVT24GHXwqiEj5GCsEGCA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u558)(tySequence__jwzrUFjG9akTIJTBBFvvqxw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1568)(tySequence__fVUhfWxkucMvZhVKGrAHuA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u1588)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u718)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u715)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u1200)(tySequence__7lEisrXlQEzwtUKW5pzRCw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u1220)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u1237)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u1234)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u1193)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimBoolToStr)(NIM_BOOL x_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u7029)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u7086)(tyTuple__zExIg9bDTcVf2FHROUpzoow* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u7102)(tyTuple__zExIg9bDTcVf2FHROUpzoow* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u7099)(tyTuple__zExIg9bDTcVf2FHROUpzoow* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u7033)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vtables_u572)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u2422)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u1841)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1858)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1855)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u2414)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vtables_u716)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u14164)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u14184)(tyTuple__V6P73hvHy70PBBwharKjig* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u5812)(tyTuple__V6P73hvHy70PBBwharKjig dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u5809)(tyTuple__V6P73hvHy70PBBwharKjig* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u14156)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___dfa_u1525)(tySequence__1xFov7v9c2rs44orw6d9bPmw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__dfa_u884)(tySequence__1xFov7v9c2rs44orw6d9bPmw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__dfa_u904)(tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___dfa_u164)(tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___dfa_u161)(tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__dfa_u446)(tySequence__gGvy9cKEpHEX9cA4gF5mzkxA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__dfa_u466)(tyTuple__MDblJIdBvEzk3cvDpORS3w* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___dfa_u483)(tyTuple__MDblJIdBvEzk3cvDpORS3w dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___dfa_u480)(tyTuple__MDblJIdBvEzk3cvDpORS3w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__dfa_u381)(tySequence__ASKXHf9aJJjLj0hSZ39ci19cA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__dfa_u401)(tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___dfa_u565)(tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___dfa_u562)(tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__dfa_u616)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u319)(tySequence__W61O50MEQVwc9azCYWJekkw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u339)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u356)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u353)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___OOZdistZchecksumsZsrcZchecksumsZmd5_u244)(tyArray__dnD8kjh6rJ1Yy5jHvid0Ow dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___OOZdistZchecksumsZsrcZchecksumsZmd5_u241)(NU8* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u947)(tySequence__kq9c1GdJLvkYJeijBmsJ20A* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u939)(tySequence__kq9c1GdJLvkYJeijBmsJ20A* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgen_u14886)(tySequence__shxop0zPIs5Ec3k71aCLuQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgen_u14894)(tySequence__shxop0zPIs5Ec3k71aCLuQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semparallel_u100)(tySequence__7Eqk7CViYtlAWKDoMfuEcw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__semparallel_u120)(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u137)(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semparallel_u134)(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgen_u16326)(tySequence__olcP618a61wlx6oJIT9b0sA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1108)(tySequence__olcP618a61wlx6oJIT9b0sA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u1128)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgendata_u1158)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___cgendata_u1155)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1100)(tySequence__olcP618a61wlx6oJIT9b0sA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u309)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q e_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__jsgen_u346)(tySequence__P9aymq2R2Xa8At0XKJ6Bh1A* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___jsgen_u58)(tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg e_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrstast_u248)(tySequence__LqZapiAqCFeXPQZdoIAUew* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrstast_u268)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstast_u285)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstast_u282)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u546)(tySequence__kxu4GK0onha2t9bo86mdVAg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u539)(tySequence__kxu4GK0onha2t9bo86mdVAg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3922)(tySequence__Ygtgme9cSsBUPbXwOprm43Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u302)(tySequence__Ygtgme9cSsBUPbXwOprm43Q* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u322)(tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u339)(tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u336)(tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u3141)(tySequence__O9a9cp2XDKWshwC0UDgFP6Pw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u3161)(tyTuple__Na59bk2YQTCLBWTLyeMrWdA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3178)(tyTuple__Na59bk2YQTCLBWTLyeMrWdA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u3175)(tyTuple__Na59bk2YQTCLBWTLyeMrWdA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u3133)(tySequence__O9a9cp2XDKWshwC0UDgFP6Pw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u2907)(tySequence__ib5UTyrs9aC6K60sNqKElQA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u2927)(tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u2982)(tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u2979)(tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__stdZenvvars_u110)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__stdZenvvars_u130)(tyTuple__UV3llMMYFckfui8YMBuUZA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZprivateZospaths2_u306)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZprivateZospaths2_u303)(tyTuple__UV3llMMYFckfui8YMBuUZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u4273)(tySequence__ib5UTyrs9aC6K60sNqKElQA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u2899)(tySequence__ib5UTyrs9aC6K60sNqKElQA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u5660)(tySequence__7kOUUrKwg6xKu7wOGcJDlQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u5680)(tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u5697)(tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u5694)(tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZosproc_u1315)(tySequence__lBgZ7a89beZGYPl8PiANMTA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u3565)(tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u3585)(tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3602)(tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u3599)(tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u3557)(tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u295)(tySequence__Ygtgme9cSsBUPbXwOprm43Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u12796)(tySequence__g9cc9ce4njfC9a8r1mQEl8mIg* x_p0, NI newLen_p1);
static N_INLINE(void*, seqToPtr__packagesZdocutilsZrst_u13008)(tySequence__g9cc9ce4njfC9a8r1mQEl8mIg x_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrst_u13069)(tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ x_p0, tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ y_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u13452)(tySequence__8Np6tlClE5az1CyqZdN19bQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u3140)(tySequence__lCWXucMn9bU7PUqVDK7772w* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u3160)(tyTuple__kNIN44R9cL9cYoYzXmSW4y7w* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u3177)(tyTuple__kNIN44R9cL9cYoYzXmSW4y7w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u3174)(tyTuple__kNIN44R9cL9cYoYzXmSW4y7w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u3132)(tySequence__lCWXucMn9bU7PUqVDK7772w* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2452)(tySequence__uAwiTxV3boseSy9a9cSsXHEA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2472)(tyTuple__30Ti2rm9aDSr5neUSZP6EVQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2489)(tyTuple__30Ti2rm9aDSr5neUSZP6EVQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2486)(tyTuple__30Ti2rm9aDSr5neUSZP6EVQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2444)(tySequence__uAwiTxV3boseSy9a9cSsXHEA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2313)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2333)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2350)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2347)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2154)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2174)(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u160)(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u157)(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u6654)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2305)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLengthStrV2)(NimStringV2* s_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___int128_u881)(NIM_CHAR* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2761)(tySequence__9at3Cmn7xIajy679cMZSmybg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2781)(tyTuple__RrY3dT8dfTceE0s6Bv9bxJw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2798)(tyTuple__RrY3dT8dfTceE0s6Bv9bxJw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2795)(tyTuple__RrY3dT8dfTceE0s6Bv9bxJw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2753)(tySequence__9at3Cmn7xIajy679cMZSmybg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2608)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2628)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2645)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2642)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u8085)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2600)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2147)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___docgen_u163)(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* dest_p0, tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ src_p1);
static N_INLINE(void*, seqToPtr__pureZjson_u2465)(tySequence__fXWXs2NlFKREhy9cn6vokJw x_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___pureZjson_u2433)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* a_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* b_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZjson_u124)(tySequence__m9axZwxFfhSNLcoofvKZJYA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZjson_u144)(tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u161)(tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZjson_u158)(tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZjson_u116)(tySequence__m9axZwxFfhSNLcoofvKZJYA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__reorder_u1559)(tySequence__NZB65egHQwAniMoFWKcFaw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__reorder_u1563)(tySequence__NZB65egHQwAniMoFWKcFaw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__reorder_u1620)(tyTuple__bPZu3GhfjP9cHscH3h9axT6w* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___reorder_u1636)(tyTuple__bPZu3GhfjP9cHscH3h9axT6w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___reorder_u1633)(tyTuple__bPZu3GhfjP9cHscH3h9axT6w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__reorder_u1567)(tySequence__NZB65egHQwAniMoFWKcFaw* s_p0, NI newlen_p1);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___reorder_u59)(tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw* dest_p0);
static N_INLINE(void, nimTraceRef)(void* q_p0, TNimTypeV2* desc_p1, void* env_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__reorder_u719)(tySequence__EHM5DWw09bc16yo24mdZPsw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__reorder_u104)(tySequence__EHM5DWw09bc16yo24mdZPsw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__reorder_u124)(tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___reorder_u141)(tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___reorder_u138)(tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__reorder_u96)(tySequence__EHM5DWw09bc16yo24mdZPsw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u100)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u66)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u1875)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u1895)(tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1912)(tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u1909)(tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__sourcemap_u190)(tySequence__IWLCUlc3h6FWY379alhl9aaQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZjson_u287)(tySequence__fXWXs2NlFKREhy9cn6vokJw* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZjson_u307)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZjson_u324)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZjson_u321)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u8521)(tySequence__vdmFdgox3dhDOMkkFi9ayfg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u3401)(tySequence__vdmFdgox3dhDOMkkFi9ayfg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u3421)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3438)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u3435)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u3393)(tySequence__vdmFdgox3dhDOMkkFi9ayfg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrst_u8401)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* x_p0, tyTuple__4Ywt2LYBMs9aMJ09cL7digow* y_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___packagesZdocutilsZrst_u8415)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* x_p0, tyTuple__4Ywt2LYBMs9aMJ09cL7digow* y_p1);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__packagesZdocutilsZrst_u8425)(tyEnum_FootnoteType__AwBNmZfS9azDCP9cRgTUCl6g x_p0, tyEnum_FootnoteType__AwBNmZfS9azDCP9cRgTUCl6g y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrst_u3441)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* dest_p0, tyTuple__4Ywt2LYBMs9aMJ09cL7digow* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrstidx_u123)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrstidx_u181)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstidx_u197)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstidx_u194)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrstidx_u127)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u16131)(tySequence__LqZapiAqCFeXPQZdoIAUew* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrstast_u241)(tySequence__LqZapiAqCFeXPQZdoIAUew* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u6353)(tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u6410)(tyTuple__fgn415DvsSyiHk3o9aIYr0w* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u6426)(tyTuple__fgn415DvsSyiHk3o9aIYr0w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u6423)(tyTuple__fgn415DvsSyiHk3o9aIYr0w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u6357)(tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u16797)(tySequence__ElKBSoViSyNazy7qD89atSA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u16801)(tySequence__ElKBSoViSyNazy7qD89atSA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u16854)(tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u16870)(tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrst_u16867)(tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u16805)(tySequence__ElKBSoViSyNazy7qD89atSA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstast_u173)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___docgen_u2284)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___docgen_u2281)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZreplayer_u1644)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u1226)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZoserrors_u38)(NI32 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZoserrors_u34)(NI32* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___suggestsymdb_u1099)(tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___suggestsymdb_u1096)(tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u11761)(tySequence__nSO1ltijM4vhc0UrrXKEqA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u11758)(tySequence__nSO1ltijM4vhc0UrrXKEqA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u16111)(tySequence__48JTohSgTy339bRxHzUD8KA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___stdZprivateZosfiles_u244)(tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___stdZprivateZosfiles_u30)(tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg e_p0);
static N_INLINE(void, sysFatal__system_u4222)(NimStringV2 message_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__options_u1897)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__options_u1917)(NimStringV2* obj_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___pureZjson_u4831)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* node_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___pureZjson_u23)(tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA e_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__extccomp_u1949)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__extccomp_u2007)(tyTuple__UV3llMMYFckfui8YMBuUZA* obj_p0);
static N_INLINE(void*, seqToPtr__extccomp_u3141)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ x_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZintegrity_u142)(tySequence__H9bHW2kkjp26MABVBZRr8Ig* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZintegrity_u146)(tySequence__H9bHW2kkjp26MABVBZRr8Ig* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u672)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u669)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1156)(tySequence__apM9bRAO19cVjhWlxqd1PGeA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u1153)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u2212)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u2209)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u2820)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZdce_u2567)(tySequence__4SBkVvm2CCxNvzruVhJR5g* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u1448)(tySequence__4SBkVvm2CCxNvzruVhJR5g* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZdce_u268)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__icZdce_u325)(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u341)(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZdce_u338)(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZdce_u272)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w* s_p0, NI newlen_p1);
static N_INLINE(void*, seqToPtr__icZcbackend_u603)(tySequence__48JTohSgTy339bRxHzUD8KA x_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZosproc_u150)(tySequence__9aHwlozdspjDnjhtzDhmdVg* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZosproc_u154)(tySequence__9aHwlozdspjDnjhtzDhmdVg* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZosproc_u212)(tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ** obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u228)(tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZosproc_u225)(tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZosproc_u158)(tySequence__9aHwlozdspjDnjhtzDhmdVg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__extccomp_u1945)(tySequence__4eQHGndY6XBYpFOH09apV8Q* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__extccomp_u1953)(tySequence__4eQHGndY6XBYpFOH09apV8Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrstgen_u2351)(tySequence__mg32q50AXD9cQ6jovpBmgWA* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrstgen_u2404)(tyTuple__bvjw5f4vMpB9bESWLU7nvyA* obj_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u1264)(tyTuple__bvjw5f4vMpB9bESWLU7nvyA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstgen_u1261)(tyTuple__bvjw5f4vMpB9bESWLU7nvyA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrstgen_u2355)(tySequence__mg32q50AXD9cQ6jovpBmgWA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrstidx_u119)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u2031)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lineinfos_u2028)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmprofiler_u1185)(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmprofiler_u1182)(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NI, getMaxMem__system_u6183)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(NI, getTotalMem__system_u1986)(void);
N_LIB_PRIVATE N_NIMCALL(NI, getOccupiedMem__system_u1984)(void);
N_LIB_PRIVATE N_NIMCALL(void, nimTestErrorFlag)(void);
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_2 = { 17 | NIM_STRLIT_FLAG, "[[reraised from:\012" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_3 = {17, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_2};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_4 = { 3 | NIM_STRLIT_FLAG, "]]\012" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_5 = {3, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_4};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_6 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_7 = {1, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_6};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_8 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_9 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_8};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_10 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_11 = {1, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_10};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_12 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_13 = {1, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_12};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_14 = { 29 | NIM_STRLIT_FLAG, "No stack traceback available\012" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_15 = {29, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_14};
extern TNimTypeV2 NTIv2__9cIOj9cQBZH8lEZvCihI6Eyg_;
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_16 = { 22 | NIM_STRLIT_FLAG, "index out of bounds: \'" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_17 = {22, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_16};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_18 = { 5 | NIM_STRLIT_FLAG, "\' < \'" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_19 = {5, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_18};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_20 = { 8 | NIM_STRLIT_FLAG, "\' failed" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_21 = {8, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_20};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_22 = { 1 | NIM_STRLIT_FLAG, "\"" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_23 = {1, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_22};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_24 = { 2 | NIM_STRLIT_FLAG, "\\a" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_25 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_24};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_26 = { 2 | NIM_STRLIT_FLAG, "\\b" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_27 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_26};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_28 = { 2 | NIM_STRLIT_FLAG, "\\t" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_29 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_28};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_30 = { 2 | NIM_STRLIT_FLAG, "\\n" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_31 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_30};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_32 = { 2 | NIM_STRLIT_FLAG, "\\v" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_33 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_32};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_34 = { 2 | NIM_STRLIT_FLAG, "\\f" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_35 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_34};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_36 = { 2 | NIM_STRLIT_FLAG, "\\r" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_37 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_36};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_38 = { 2 | NIM_STRLIT_FLAG, "\\e" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_39 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_38};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_40 = { 2 | NIM_STRLIT_FLAG, "\\\\" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_41 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_40};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_42 = { 2 | NIM_STRLIT_FLAG, "\\\'" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_43 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_42};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_44 = { 2 | NIM_STRLIT_FLAG, "\\\"" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_45 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_44};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_46 = { 2 | NIM_STRLIT_FLAG, "\\x" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_47 = {2, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_46};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_48 = { 16 | NIM_STRLIT_FLAG, "0123456789ABCDEF" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_49 = {16, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_48};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_50 = {16, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_48};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_51 = {1, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_22};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_52 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_53 = {4, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_52};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_54 = { 5 | NIM_STRLIT_FLAG, "false" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_55 = {5, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_54};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_56 = {22, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_16};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_57 = {5, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_18};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_58 = {8, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_20};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_59 = { 1 | NIM_STRLIT_FLAG, "\'" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_60 = {1, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_59};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_61 = {1, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_59};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_62 = {22, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_16};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_63 = {5, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_18};
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_64 = {8, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_20};
extern TNimTypeV2 NTIv2__mjl9coa4es5lRGs5j7zUDHw_;
extern TNimTypeV2 NTIv2__rf4J0hIl2XahwR8oH1IVPA_;
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_65 = { 23 | NIM_STRLIT_FLAG, "no exception to reraise" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_66 = {23, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_65};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_67 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_68 = {0, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_67};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_69 = { 19 | NIM_STRLIT_FLAG, "[GC] total memory: " };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_70 = {19, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_69};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__Q5wkpxktOdTGvlSRo9bzt9aw_71 = { 23 | NIM_STRLIT_FLAG, "\012[GC] occupied memory: " };
static const NimStringV2 TM__Q5wkpxktOdTGvlSRo9bzt9aw_72 = {23, (NimStrPayload*)&TM__Q5wkpxktOdTGvlSRo9bzt9aw_71};
N_LIB_PRIVATE NIM_CONST NI nimStrVersion = ((NI)2);
N_LIB_PRIVATE NIM_CONST NI nimSeqVersion = ((NI)2);
N_LIB_PRIVATE NIM_CONST tyArray__mkmEeKAWtk2yS9bBb1lUWXA fsLookupTable__system_u5992 = {((NI8)-1),
((NI8)0),
((NI8)1),
((NI8)1),
((NI8)2),
((NI8)2),
((NI8)2),
((NI8)2),
((NI8)3),
((NI8)3),
((NI8)3),
((NI8)3),
((NI8)3),
((NI8)3),
((NI8)3),
((NI8)3),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)4),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)5),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)6),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7),
((NI8)7)}
;
N_LIB_PRIVATE NIM_CONST tyArray__XxjPD9c5L6FNIAf8gnrQVdg powtens__system_u7337 = {1.0,
10.0,
100.0,
1000.0,
10000.0,
100000.0,
1000000.0,
10000000.0,
100000000.0,
1000000000.0,
10000000000.0,
100000000000.0,
1000000000000.0,
10000000000000.0,
100000000000000.0,
1000000000000000.0,
10000000000000000.0,
1e+17,
1e+18,
1e+19,
1e+20,
1e+21,
1e+22}
;
N_LIB_PRIVATE Exception* currException__system_u3631;
N_LIB_PRIVATE NI nim_program_result;
N_LIB_PRIVATE TFrame* framePtr__system_u2733;
N_LIB_PRIVATE NI threadId__system_u2994;
N_LIB_PRIVATE tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg roots__system_u3129;
N_LIB_PRIVATE NI rootsThreshold__system_u3292;
N_LIB_PRIVATE tyProc__9axCnCRMUx32AHzFgBrzSMg globalRaiseHook__system_u3579;
N_LIB_PRIVATE tyProc__9axCnCRMUx32AHzFgBrzSMg localRaiseHook__system_u3582;
N_LIB_PRIVATE tyProc__T4eqaYlFJYZUv9aG9b1TV0bQ outOfMemHook__system_u3584;
N_LIB_PRIVATE tyProc__NFmM6mqUOVW3cJg4yvk8Fw unhandledExceptionHook__system_u3587;
N_LIB_PRIVATE tyProc__W6IXMh2CA4X1rFYGjUb4yg errorMessageWriter__system_u3593;
N_LIB_PRIVATE tyProc__W6IXMh2CA4X1rFYGjUb4yg onUnhandledException__system_u4042;
N_LIB_PRIVATE NIM_BOOL nimInErrorMode__system_u4146;
N_LIB_PRIVATE tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ allocator__system_u7164;
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(NI, roundup__system_u5860)(NI x_p0, NI v_p1) {
	NI result;
	result = (NI)((NI)(x_p0 + (NI)(v_p1 - ((NI)1))) & (NI)((NU64) ~((NI)(v_p1 - ((NI)1)))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, align__system_u1639)(NI address_p0, NI alignment_p1) {
	NI result;
	NI T1_;
	T1_ = (NI)0;
	{
		if (!(alignment_p1 == ((NI)0))) goto LA4_;
		result = address_p0;
	}
	goto LA2_;
LA4_: ;
	{
		NU address_2;
		NU alignment1_1;
		address_2 = ((NU) (address_p0));
		alignment1_1 = (NU)((NU64)(((NU) (alignment_p1))) - (NU64)(((NU)1)));
		result = ((NI) ((NU)((NU)((NU64)(address_2) + (NU64)(alignment1_1)) & (NU)((NU64) ~(alignment1_1)))));
	}
LA2_: ;
	return result;
}
static N_INLINE(NI, smallChunkAlignOffset__system_u6858)(NI alignment_p0) {
	NI result;
	{
		if (!(alignment_p0 <= ((NI)16))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		NI T6_;
		T6_ = (NI)0;
		T6_ = align__system_u1639(((NI)80), alignment_p0);
		result = (NI)((NI)(T6_ - ((NI)64)) - ((NI)16));
	}
LA1_: ;
	return result;
}
static N_INLINE(NI, msbit__system_u5993)(NU32 x_p0) {
	NI result;
	NI colontmpD_;
	NI colontmpD__2;
	NI a_1;
	result = (NI)0;
	colontmpD_ = (NI)0;
	colontmpD__2 = (NI)0;
	{
		NI colontmpD__3;
		NI colontmpD__4;
		if (!((NU32)(x_p0) <= (NU32)(((NU32)65535)))) goto LA3_;
		colontmpD__3 = (NI)0;
		colontmpD__4 = (NI)0;
		{
			if (!((NU32)(x_p0) <= (NU32)(((NU32)255)))) goto LA7_;
			colontmpD__3 = ((NI)0);
			colontmpD_ = colontmpD__3;
		}
		goto LA5_;
LA7_: ;
		{
			colontmpD__4 = ((NI)8);
			colontmpD_ = colontmpD__4;
		}
LA5_: ;
		a_1 = colontmpD_;
	}
	goto LA1_;
LA3_: ;
	{
		NI colontmpD__5;
		NI colontmpD__6;
		colontmpD__5 = (NI)0;
		colontmpD__6 = (NI)0;
		{
			if (!((NU32)(x_p0) <= (NU32)(((NU32)16777215)))) goto LA13_;
			colontmpD__5 = ((NI)16);
			colontmpD__2 = colontmpD__5;
		}
		goto LA11_;
LA13_: ;
		{
			colontmpD__6 = ((NI)24);
			colontmpD__2 = colontmpD__6;
		}
LA11_: ;
		a_1 = colontmpD__2;
	}
LA1_: ;
	result = (NI)(((NI) (fsLookupTable__system_u5992[(((NU8) ((NU32)((NU32)(x_p0) >> (NU64)(a_1 & (32 - 1))))))- 0])) + a_1);
	return result;
}
static N_INLINE(void, mappingSearch__system_u6018)(NI* r_p0, NI* fl_p1, NI* sl_p2) {
	NI t_1;
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = msbit__system_u5993(((NU32) ((*r_p0))));
	T2_ = (NI)0;
	T2_ = roundup__system_u5860((NI)((NU64)(((NI)1)) << (NU64)((NI)(T1_ - ((NI)5)) & (64 - 1))), ((NI)4096));
	t_1 = (NI)(T2_ - ((NI)1));
	(*r_p0) = (NI)((*r_p0) + t_1);
	(*r_p0) = (NI)((*r_p0) & (NI)((NU64) ~(t_1)));
	(*r_p0) = (((*r_p0) <= ((NI)1056964608)) ? (*r_p0) : ((NI)1056964608));
	(*fl_p1) = msbit__system_u5993(((NU32) ((*r_p0))));
	(*sl_p2) = (NI)((NI)((NI64)((*r_p0)) >> (NU64)((NI)((*fl_p1) - ((NI)5)) & (64 - 1))) - ((NI)32));
	(*fl_p1) -= ((NI)6);
}
static N_INLINE(NI, lsbit__system_u6001)(NU32 x_p0) {
	NI result;
	result = msbit__system_u5993((NU32)(x_p0 & (NU32)((NU32)((NU32)((NU32) ~(x_p0))) + (NU32)(((NU32)1)))));
	return result;
}
static N_INLINE(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, findSuitableBlock__system_u6051)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI* fl_p1, NI* sl_p2) {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* result;
	NU32 tmp_1;
	tmp_1 = (NU32)((*a_p0).slBitmap[((*fl_p1))- 0] & (NU32)((NU64)(((NU32)IL64(4294967295))) << (NU64)((*sl_p2) & (32 - 1))));
	result = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	{
		if (!!((tmp_1 == ((NU32)0)))) goto LA3_;
		(*sl_p2) = lsbit__system_u6001(tmp_1);
		result = (*a_p0).matrix[((*fl_p1))- 0][((*sl_p2))- 0];
	}
	goto LA1_;
LA3_: ;
	{
		(*fl_p1) = lsbit__system_u6001((NU32)((*a_p0).flBitmap & (NU32)((NU64)(((NU32)IL64(4294967295))) << (NU64)((NI)((*fl_p1) + ((NI)1)) & (32 - 1)))));
		{
			if (!(((NI)0) < (*fl_p1))) goto LA8_;
			(*sl_p2) = lsbit__system_u6001((*a_p0).slBitmap[((*fl_p1))- 0]);
			result = (*a_p0).matrix[((*fl_p1))- 0][((*sl_p2))- 0];
		}
LA8_: ;
	}
LA1_: ;
	return result;
}
static N_INLINE(void, rawWrite)(FILE* f_p0, NCSTRING s_p1) {
	size_t T1_;
	size_t T2_;
	int T3_;
	T1_ = (size_t)0;
	T1_ = strlen(s_p1);
	T2_ = (size_t)0;
	T2_ = fwrite(((void*) (s_p1)), ((size_t)1), T1_, f_p0);
	(void)(T2_);
	T3_ = (int)0;
	T3_ = fflush(f_p0);
	(void)(T3_);
}
N_LIB_PRIVATE N_NOINLINE(void, raiseOutOfMem__system_u5855)(void) {
	{
		if (!!((outOfMemHook__system_u3584 == NIM_NIL))) goto LA3_;
		outOfMemHook__system_u3584();
	}
LA3_: ;
	rawWrite(__stderrp, "out of memory\012");
	exit(((int)1));
}
static N_INLINE(void*, osAllocPages__system_u5880)(NI size_p0) {
	void* result;
	result = mmap(NIM_NIL, ((size_t) (size_p0)), ((int)3), ((int)4098), ((int)-1), ((NI)0));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (result == NIM_NIL);
		if (T3_) goto LA4_;
		T3_ = (result == ((void*) (((NI)-1))));
LA4_: ;
		if (!T3_) goto LA5_;
		raiseOutOfMem__system_u5855();
	}
LA5_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, allocPages__system_u6187)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1) {
	void* result;
	result = osAllocPages__system_u5880(size_p1);
	return result;
}
static N_INLINE(void*, osTryAllocPages__system_u5883)(NI size_p0) {
	void* result;
	result = mmap(NIM_NIL, ((size_t) (size_p0)), ((int)3), ((int)4098), ((int)-1), ((NI)0));
	{
		if (!(result == ((void*) (((NI)-1))))) goto LA3_;
		result = NIM_NIL;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, tryAllocPages__system_u6191)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1) {
	void* result;
	result = osTryAllocPages__system_u5883(size_p1);
	return result;
}
static N_INLINE(void, incCurrMem__system_u6167)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI bytes_p1) {
	(*a_p0).currMem += bytes_p1;
}
static N_INLINE(void, zeroMem__system_u1739)(void* p_p0, NI size_p1) {
	nimZeroMem(p_p0, size_p1);
}
N_LIB_PRIVATE N_NIMCALL(void*, llAlloc__system_u6195)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1) {
	void* result;
	{
		NIM_BOOL T3_;
		tyObject_LLChunk__9cg7LlyOeeb21wFGpiSg37g* old_1;
		void* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*a_p0).llmem == ((tyObject_LLChunk__9cg7LlyOeeb21wFGpiSg37g*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((*(*a_p0).llmem).size < size_p1);
LA4_: ;
		if (!T3_) goto LA5_;
		old_1 = (*a_p0).llmem;
		T7_ = (void*)0;
		T7_ = allocPages__system_u6187(a_p0, ((NI)4096));
		(*a_p0).llmem = ((tyObject_LLChunk__9cg7LlyOeeb21wFGpiSg37g*) (T7_));
		incCurrMem__system_u6167(a_p0, ((NI)4096));
		(*(*a_p0).llmem).size = ((NI)4072);
		(*(*a_p0).llmem).acc = ((NI)24);
		(*(*a_p0).llmem).next = old_1;
	}
LA5_: ;
	result = ((void*) ((NI)(((NI) (ptrdiff_t) ((*a_p0).llmem)) + (*(*a_p0).llmem).acc)));
	(*(*a_p0).llmem).size -= size_p1;
	(*(*a_p0).llmem).acc += size_p1;
	zeroMem__system_u1739(result, (size_p1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA*, addHeapLink__system_u6233)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* p_p1, NI size_p2) {
	tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA* result;
	tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA* it_1;
	it_1 = (&(*a_p0).heapLinks);
	{
		while (1) {
			NIM_BOOL T3_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((it_1 == ((tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = (((NI)30) <= (*it_1).len);
LA4_: ;
			if (!T3_) goto LA2;
			it_1 = (*it_1).next;
		} LA2: ;
	}
	{
		tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA* n_1;
		void* T9_;
		tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* colontmp_;
		NI colontmp__2;
		if (!(it_1 == ((tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA*) NIM_NIL))) goto LA7_;
		T9_ = (void*)0;
		T9_ = llAlloc__system_u6195(a_p0, ((NI)496));
		n_1 = ((tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA*) (T9_));
		(*n_1).next = (*a_p0).heapLinks.next;
		(*a_p0).heapLinks.next = n_1;
		colontmp_ = p_p1;
		colontmp__2 = size_p2;
		(*n_1).chunks[(((NI)0))- 0].Field0 = colontmp_;
		(*n_1).chunks[(((NI)0))- 0].Field1 = colontmp__2;
		(*n_1).len = ((NI)1);
		result = n_1;
	}
	goto LA5_;
LA7_: ;
	{
		NI L_1;
		tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* colontmp__3;
		NI colontmp__4;
		L_1 = (*it_1).len;
		colontmp__3 = p_p1;
		colontmp__4 = size_p2;
		(*it_1).chunks[(L_1)- 0].Field0 = colontmp__3;
		(*it_1).chunks[(L_1)- 0].Field1 = colontmp__4;
		(*it_1).len += ((NI)1);
		result = it_1;
	}
LA5_: ;
	return result;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*, intSetGet__system_u6328)(tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* t_p0, NI key_p1) {
	tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg* result;
	tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg* it_1;
{	it_1 = (*t_p0).data[((NI)(key_p1 & ((NI)255)))- 0];
	{
		while (1) {
			if (!!((it_1 == ((tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*) NIM_NIL)))) goto LA2;
			{
				if (!((*it_1).key == key_p1)) goto LA5_;
				result = it_1;
				goto BeforeRet_;
			}
LA5_: ;
			it_1 = (*it_1).next;
		} LA2: ;
	}
	result = ((tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*) NIM_NIL);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__system_u6377)(tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* s_p0, NI key_p1) {
	NIM_BOOL result;
	tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg* t_1;
	t_1 = intSetGet__system_u6328(s_p0, (NI)((NI64)(key_p1) >> (NU64)(((NI)9) & (64 - 1))));
	{
		NI u_1;
		if (!!((t_1 == ((tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*) NIM_NIL)))) goto LA3_;
		u_1 = (NI)(key_p1 & ((NI)511));
		result = !(((NU)((*t_1).bits[((NI)((NI64)(u_1) >> (NU64)(((NI)6) & (64 - 1))))- 0] & (NU)((NU64)(((NU)1)) << (NU64)((NI)(u_1 & ((NI)63)) & (64 - 1)))) == ((NU)0)));
	}
	goto LA1_;
LA3_: ;
	{
		result = NIM_FALSE;
	}
LA1_: ;
	return result;
}
static N_INLINE(NI, pageIndex__system_u6594)(tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* c_p0) {
	NI result;
	result = (NI)((NI64)(((NI) (ptrdiff_t) (c_p0))) >> (NU64)(((NI)12) & (64 - 1)));
	return result;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, requestOsChunks__system_u6611)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1) {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* result;
	NI colontmpD_;
	NI colontmpD__2;
	NI size_2;
	tyObject_HeapLinks__2zsaEJTkA5nNCaY9bo37lcA* heapLink_1;
	NI nxt_1;
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* next_1;
	NI lastSize_1;
	NI prv_1;
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* prev_1;
	colontmpD_ = (NI)0;
	colontmpD__2 = (NI)0;
	{
		NI usedMem_1;
		if (!!((*a_p0).blockChunkSizeIncrease)) goto LA3_;
		usedMem_1 = (*a_p0).occ;
		{
			if (!(usedMem_1 < ((NI)65536))) goto LA7_;
			(*a_p0).nextChunkSize = ((NI)16384);
		}
		goto LA5_;
LA7_: ;
		{
			NI T10_;
			T10_ = (NI)0;
			T10_ = roundup__system_u5860((NI)((NI64)(usedMem_1) >> (NU64)(((NI)2) & (64 - 1))), ((NI)4096));
			(*a_p0).nextChunkSize = ((T10_ <= (NI)((*a_p0).nextChunkSize * ((NI)2))) ? T10_ : (NI)((*a_p0).nextChunkSize * ((NI)2)));
			(*a_p0).nextChunkSize = (((*a_p0).nextChunkSize <= ((NI)1056964608)) ? (*a_p0).nextChunkSize : ((NI)1056964608));
		}
LA5_: ;
	}
LA3_: ;
	size_2 = size_p1;
	{
		void* T15_;
		if (!((*a_p0).nextChunkSize < size_2)) goto LA13_;
		T15_ = (void*)0;
		T15_ = allocPages__system_u6187(a_p0, size_2);
		result = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (T15_));
	}
	goto LA11_;
LA13_: ;
	{
		void* T17_;
		T17_ = (void*)0;
		T17_ = tryAllocPages__system_u6191(a_p0, (*a_p0).nextChunkSize);
		result = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (T17_));
		{
			void* T22_;
			if (!(result == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL))) goto LA20_;
			T22_ = (void*)0;
			T22_ = allocPages__system_u6187(a_p0, size_2);
			result = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (T22_));
			(*a_p0).blockChunkSizeIncrease = NIM_TRUE;
		}
		goto LA18_;
LA20_: ;
		{
			size_2 = (*a_p0).nextChunkSize;
		}
LA18_: ;
	}
LA11_: ;
	incCurrMem__system_u6167(a_p0, size_2);
	(*a_p0).freeMem += size_2;
	heapLink_1 = addHeapLink__system_u6233(a_p0, result, size_2);
	(*result).next = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*result).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*result).Sup.size = size_2;
	nxt_1 = pluspercent___system_u785(((NI) (ptrdiff_t) (result)), size_2);
	next_1 = ((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*) (nxt_1));
	{
		NI T26_;
		NIM_BOOL T27_;
		T26_ = (NI)0;
		T26_ = pageIndex__system_u6594(next_1);
		T27_ = (NIM_BOOL)0;
		T27_ = contains__system_u6377((&(*a_p0).chunkStarts), T26_);
		if (!T27_) goto LA28_;
		(*next_1).prevSize = (NI)(size_2 | (NI)((*next_1).prevSize & ((NI)1)));
	}
LA28_: ;
	{
		if (!!(((*a_p0).lastSize == ((NI)0)))) goto LA32_;
		colontmpD_ = (*a_p0).lastSize;
		lastSize_1 = colontmpD_;
	}
	goto LA30_;
LA32_: ;
	{
		colontmpD__2 = ((NI)4096);
		lastSize_1 = colontmpD__2;
	}
LA30_: ;
	prv_1 = minuspercent___system_u805(((NI) (ptrdiff_t) (result)), lastSize_1);
	prev_1 = ((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*) (prv_1));
	{
		NIM_BOOL T37_;
		NI T38_;
		T37_ = (NIM_BOOL)0;
		T38_ = (NI)0;
		T38_ = pageIndex__system_u6594(prev_1);
		T37_ = contains__system_u6377((&(*a_p0).chunkStarts), T38_);
		if (!(T37_)) goto LA39_;
		T37_ = ((*prev_1).size == lastSize_1);
LA39_: ;
		if (!T37_) goto LA40_;
		(*result).Sup.prevSize = (NI)(lastSize_1 | (NI)((*result).Sup.prevSize & ((NI)1)));
	}
	goto LA35_;
LA40_: ;
	{
		(*result).Sup.prevSize = (NI)(((NI)0) | (NI)((*result).Sup.prevSize & ((NI)1)));
	}
LA35_: ;
	(*a_p0).lastSize = size_2;
	return result;
}
static N_INLINE(NI, pageIndex__system_u6601)(void* p_p0) {
	NI result;
	result = (NI)((NI64)(((NI) (ptrdiff_t) (p_p0))) >> (NU64)(((NI)12) & (64 - 1)));
	return result;
}
static N_INLINE(NIM_BOOL, isAccessible__system_u6636)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, void* p_p1) {
	NIM_BOOL result;
	NI T1_;
	T1_ = (NI)0;
	T1_ = pageIndex__system_u6601(p_p1);
	result = contains__system_u6377((&(*a_p0).chunkStarts), T1_);
	return result;
}
static N_INLINE(void, updatePrevSize__system_u6654)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1, NI prevSize_p2) {
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* ri_1;
	NI T1_;
	T1_ = (NI)0;
	T1_ = pluspercent___system_u785(((NI) (ptrdiff_t) (c_p1)), (*c_p1).Sup.size);
	ri_1 = ((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*) (T1_));
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = isAccessible__system_u6636((&(*a_p0)), ((void*) (ri_1)));
		if (!T4_) goto LA5_;
		(*ri_1).prevSize = (NI)(prevSize_p2 | (NI)((*ri_1).prevSize & ((NI)1)));
	}
LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*, intSetPut__system_u6360)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* t_p1, NI key_p2) {
	tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg* result;
	result = intSetGet__system_u6328((&(*t_p1)), key_p2);
	{
		void* T5_;
		if (!(result == ((tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*) NIM_NIL))) goto LA3_;
		T5_ = (void*)0;
		T5_ = llAlloc__system_u6195(a_p0, ((NI)80));
		result = ((tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*) (T5_));
		(*result).next = (*t_p1).data[((NI)(key_p2 & ((NI)255)))- 0];
		(*t_p1).data[((NI)(key_p2 & ((NI)255)))- 0] = result;
		(*result).key = key_p2;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, incl__system_u6418)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* s_p1, NI key_p2) {
	tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg* t_1;
	NI u_1;
	t_1 = intSetPut__system_u6360(a_p0, s_p1, (NI)((NI64)(key_p2) >> (NU64)(((NI)9) & (64 - 1))));
	u_1 = (NI)(key_p2 & ((NI)511));
	(*t_1).bits[((NI)((NI64)(u_1) >> (NU64)(((NI)6) & (64 - 1))))- 0] = (NU)((*t_1).bits[((NI)((NI64)(u_1) >> (NU64)(((NI)6) & (64 - 1))))- 0] | (NU)((NU64)(((NU)1)) << (NU64)((NI)(u_1 & ((NI)63)) & (64 - 1))));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, splitChunk2__system_u6659)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1, NI size_p2) {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* result;
	NI T1_;
	tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* T2_;
	NI T3_;
	T1_ = (NI)0;
	T1_ = pluspercent___system_u785(((NI) (ptrdiff_t) (c_p1)), size_p2);
	result = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (T1_));
	(*result).Sup.size = (NI)((*c_p1).Sup.size - size_p2);
	(*result).next = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*result).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*result).Sup.prevSize = size_p2;
	(*result).Sup.owner = a_p0;
	updatePrevSize__system_u6654(a_p0, c_p1, (*result).Sup.size);
	(*c_p1).Sup.size = size_p2;
	T2_ = (tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ*)0;
	T2_ = a_p0;
	T3_ = (NI)0;
	T3_ = pageIndex__system_u6594((*((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw**) (&(result)))));
	incl__system_u6418(T2_, (&(*a_p0).chunkStarts), T3_);
	return result;
}
static N_INLINE(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ, mappingInsert__system_u6036)(NI r_p0) {
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ result;
	nimZeroMem((void*)(&result), sizeof(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ));
	result.Field0 = msbit__system_u5993(((NU32) (r_p0)));
	result.Field1 = (NI)((NI)((NI64)(r_p0) >> (NU64)((NI)(result.Field0 - ((NI)5)) & (64 - 1))) - ((NI)32));
	result.Field0 -= ((NI)6);
	return result;
}
static N_INLINE(void, setBit__system_u6004)(NI nr_p0, NU32* dest_p1) {
	(*dest_p1) = (NU32)((*dest_p1) | (NU32)((NU64)(((NU32)1)) << (NU64)((NI)(nr_p0 & ((NI)31)) & (32 - 1))));
}
N_LIB_PRIVATE N_NIMCALL(void, addChunkToMatrix__system_u6157)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* b_p1) {
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tmpTuple_1;
	NI fl_1;
	NI sl_1;
	tmpTuple_1 = mappingInsert__system_u6036((*b_p1).Sup.size);
	fl_1 = tmpTuple_1.Field0;
	sl_1 = tmpTuple_1.Field1;
	(*b_p1).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*b_p1).next = (*a_p0).matrix[(fl_1)- 0][(sl_1)- 0];
	{
		if (!!(((*a_p0).matrix[(fl_1)- 0][(sl_1)- 0] == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL)))) goto LA3_;
		(*(*a_p0).matrix[(fl_1)- 0][(sl_1)- 0]).prev = b_p1;
	}
LA3_: ;
	(*a_p0).matrix[(fl_1)- 0][(sl_1)- 0] = b_p1;
	setBit__system_u6004(sl_1, (&(*a_p0).slBitmap[(fl_1)- 0]));
	setBit__system_u6004(fl_1, (&(*a_p0).flBitmap));
}
N_LIB_PRIVATE N_NIMCALL(void, splitChunk__system_u6683)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1, NI size_p2) {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* rest_1;
	rest_1 = splitChunk2__system_u6659(a_p0, c_p1, size_p2);
	addChunkToMatrix__system_u6157(a_p0, rest_1);
}
static N_INLINE(void, clearBit__system_u6011)(NI nr_p0, NU32* dest_p1) {
	(*dest_p1) = (NU32)((*dest_p1) & (NU32)((NU32) ~((NU32)((NU64)(((NU32)1)) << (NU64)((NI)(nr_p0 & ((NI)31)) & (32 - 1))))));
}
N_LIB_PRIVATE N_NIMCALL(void, removeChunkFromMatrix2__system_u6148)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* b_p1, NI fl_p2, NI sl_p3) {
	(*a_p0).matrix[(fl_p2)- 0][(sl_p3)- 0] = (*b_p1).next;
	{
		if (!!(((*a_p0).matrix[(fl_p2)- 0][(sl_p3)- 0] == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL)))) goto LA3_;
		(*(*a_p0).matrix[(fl_p2)- 0][(sl_p3)- 0]).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	}
	goto LA1_;
LA3_: ;
	{
		clearBit__system_u6011(sl_p3, (&(*a_p0).slBitmap[(fl_p2)- 0]));
		{
			if (!((*a_p0).slBitmap[(fl_p2)- 0] == ((NU32)0))) goto LA8_;
			clearBit__system_u6011(fl_p2, (&(*a_p0).flBitmap));
		}
LA8_: ;
	}
LA1_: ;
	(*b_p1).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*b_p1).next = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, getBigChunk__system_u6712)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1) {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* result;
	NI size_2;
	NI fl_1;
	NI sl_1;
	tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* T19_;
	NI T20_;
	size_2 = size_p1;
	fl_1 = ((NI)0);
	sl_1 = ((NI)0);
	mappingSearch__system_u6018((&size_2), (&fl_1), (&sl_1));
	result = findSuitableBlock__system_u6051((&(*a_p0)), (&fl_1), (&sl_1));
	{
		if (!(result == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL))) goto LA3_;
		{
			if (!(size_2 < ((NI)524288))) goto LA7_;
			result = requestOsChunks__system_u6611(a_p0, ((NI)524288));
			splitChunk__system_u6683(a_p0, result, size_2);
		}
		goto LA5_;
LA7_: ;
		{
			result = requestOsChunks__system_u6611(a_p0, size_2);
			{
				if (!(size_2 < (*result).Sup.size)) goto LA12_;
				splitChunk__system_u6683(a_p0, result, size_2);
			}
LA12_: ;
		}
LA5_: ;
		(*result).Sup.owner = a_p0;
	}
	goto LA1_;
LA3_: ;
	{
		removeChunkFromMatrix2__system_u6148(a_p0, result, fl_1, sl_1);
		{
			if (!((NI)(size_2 + ((NI)4096)) <= (*result).Sup.size)) goto LA17_;
			splitChunk__system_u6683(a_p0, result, size_2);
		}
LA17_: ;
	}
LA1_: ;
	(*result).Sup.prevSize = ((NI)1);
	T19_ = (tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ*)0;
	T19_ = a_p0;
	T20_ = (NI)0;
	T20_ = pageIndex__system_u6594((*((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw**) (&(result)))));
	incl__system_u6418(T19_, (&(*a_p0).chunkStarts), T20_);
	(*a_p0).freeMem -= size_2;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*, getSmallChunk__system_u6740)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0) {
	tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* result;
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* res_1;
	res_1 = getBigChunk__system_u6712(a_p0, ((NI)4096));
	result = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) (res_1));
	return result;
}
static N_INLINE(tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*, pageAddr__system_u6608)(void* p_p0) {
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* result;
	result = ((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*) ((NI)(((NI) (ptrdiff_t) (p_p0)) & ((NI)-4096))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, compensateCounters__system_u6800)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_p1, NI size_p2) {
	tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg* it_1;
	NI total_1;
	it_1 = (*c_p1).freeList;
	total_1 = ((NI)0);
	{
		while (1) {
			tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* chunk_1;
			tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* T3_;
			if (!!((it_1 == ((tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg*) NIM_NIL)))) goto LA2;
			total_1 += size_p2;
			T3_ = (tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*)0;
			T3_ = pageAddr__system_u6608(((void*) (it_1)));
			chunk_1 = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) (T3_));
			{
				if (!!((c_p1 == chunk_1))) goto LA6_;
				(*c_p1).foreignCells += ((NI)1);
			}
LA6_: ;
			it_1 = (*it_1).next;
		} LA2: ;
	}
	(*c_p1).free += total_1;
	(*a_p0).occ -= total_1;
}
static N_INLINE(void, listAdd__system_u6903)(tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA** head_p0, tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_p1) {
	(*c_p1).next = (*head_p0);
	{
		if (!!(((*head_p0) == ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL)))) goto LA3_;
		(*(*head_p0)).prev = c_p1;
	}
LA3_: ;
	(*head_p0) = c_p1;
}
static N_INLINE(void, listRemove__system_u6976)(tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA** head_p0, tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_p1) {
	{
		if (!(c_p1 == (*head_p0))) goto LA3_;
		(*head_p0) = (*c_p1).next;
		{
			if (!!(((*head_p0) == ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL)))) goto LA7_;
			(*(*head_p0)).prev = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL);
		}
LA7_: ;
	}
	goto LA1_;
LA3_: ;
	{
		(*(*c_p1).prev).next = (*c_p1).next;
		{
			if (!!(((*c_p1).next == ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL)))) goto LA12_;
			(*(*c_p1).next).prev = (*c_p1).prev;
		}
LA12_: ;
	}
LA1_: ;
	(*c_p1).next = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL);
	(*c_p1).prev = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL);
}
N_LIB_PRIVATE N_NIMCALL(void, excl__system_u6440)(tyObject_IntSet__mqwwsepM2dILPw5g9b1rUzQ* s_p0, NI key_p1) {
	tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg* t_1;
	t_1 = intSetGet__system_u6328((&(*s_p0)), (NI)((NI64)(key_p1) >> (NU64)(((NI)9) & (64 - 1))));
	{
		NI u_1;
		if (!!((t_1 == ((tyObject_Trunk__YEca6W9ceJscClhmg1N7E9bg*) NIM_NIL)))) goto LA3_;
		u_1 = (NI)(key_p1 & ((NI)511));
		(*t_1).bits[((NI)((NI64)(u_1) >> (NU64)(((NI)6) & (64 - 1))))- 0] = (NU)((*t_1).bits[((NI)((NI64)(u_1) >> (NU64)(((NI)6) & (64 - 1))))- 0] & (NU)((NU64) ~((NU)((NU64)(((NU)1)) << (NU64)((NI)(u_1 & ((NI)63)) & (64 - 1))))));
	}
LA3_: ;
}
static N_INLINE(void, decCurrMem__system_u6175)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI bytes_p1) {
	(*a_p0).maxMem = (((*a_p0).maxMem >= (*a_p0).currMem) ? (*a_p0).maxMem : (*a_p0).currMem);
	(*a_p0).currMem -= bytes_p1;
}
static N_INLINE(void, osDeallocPages__system_u5886)(void* p_p0, NI size_p1) {
	int T1_;
	T1_ = (int)0;
	T1_ = munmap(p_p0, ((size_t) (size_p1)));
	(void)(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, freeHugeChunk__system_u6736)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1) {
	NI size_1;
	NI T1_;
	size_1 = (*c_p1).Sup.size;
	T1_ = (NI)0;
	T1_ = pageIndex__system_u6594(&c_p1->Sup);
	excl__system_u6440((&(*a_p0).chunkStarts), T1_);
	decCurrMem__system_u6175(a_p0, size_1);
	osDeallocPages__system_u5886(((void*) (c_p1)), size_1);
}
static N_INLINE(NIM_BOOL, chunkUnused__system_u6516)(tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* c_p0) {
	NIM_BOOL result;
	result = ((NI)((*c_p0).prevSize & ((NI)1)) == ((NI)0));
	return result;
}
static N_INLINE(NIM_BOOL, isSmallChunk__system_u6510)(tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* c_p0) {
	NIM_BOOL result;
	result = ((*c_p0).size <= ((NI)4032));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, removeChunkFromMatrix__system_u6106)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* b_p1) {
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tmpTuple_1;
	NI fl_1;
	NI sl_1;
	tmpTuple_1 = mappingInsert__system_u6036((*b_p1).Sup.size);
	fl_1 = tmpTuple_1.Field0;
	sl_1 = tmpTuple_1.Field1;
	{
		if (!!(((*b_p1).next == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL)))) goto LA3_;
		(*(*b_p1).next).prev = (*b_p1).prev;
	}
LA3_: ;
	{
		if (!!(((*b_p1).prev == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL)))) goto LA7_;
		(*(*b_p1).prev).next = (*b_p1).next;
	}
LA7_: ;
	{
		if (!((*a_p0).matrix[(fl_1)- 0][(sl_1)- 0] == b_p1)) goto LA11_;
		(*a_p0).matrix[(fl_1)- 0][(sl_1)- 0] = (*b_p1).next;
		{
			if (!((*a_p0).matrix[(fl_1)- 0][(sl_1)- 0] == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL))) goto LA15_;
			clearBit__system_u6011(sl_1, (&(*a_p0).slBitmap[(fl_1)- 0]));
			{
				if (!((*a_p0).slBitmap[(fl_1)- 0] == ((NU32)0))) goto LA19_;
				clearBit__system_u6011(fl_1, (&(*a_p0).flBitmap));
			}
LA19_: ;
		}
LA15_: ;
	}
LA11_: ;
	(*b_p1).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*b_p1).next = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
}
N_LIB_PRIVATE N_NIMCALL(void, freeBigChunk__system_u6688)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1) {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_2;
	NI prevSize_1;
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* ri_1;
	NI T24_;
	c_2 = c_p1;
	(*a_p0).freeMem += (*c_2).Sup.size;
	(*c_2).Sup.prevSize = (NI)((*c_2).Sup.prevSize & ((NI)-2));
	prevSize_1 = (*c_2).Sup.prevSize;
	{
		tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* le_1;
		NI T5_;
		if (!!((prevSize_1 == ((NI)0)))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (c_2)), prevSize_1);
		le_1 = ((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*) (T5_));
		{
			NIM_BOOL T8_;
			T8_ = (NIM_BOOL)0;
			T8_ = isAccessible__system_u6636((&(*a_p0)), ((void*) (le_1)));
			if (!(T8_)) goto LA9_;
			T8_ = chunkUnused__system_u6516(le_1);
LA9_: ;
			if (!T8_) goto LA10_;
			{
				NIM_BOOL T14_;
				NIM_BOOL T15_;
				NI T19_;
				T14_ = (NIM_BOOL)0;
				T15_ = (NIM_BOOL)0;
				T15_ = isSmallChunk__system_u6510(le_1);
				T14_ = !(T15_);
				if (!(T14_)) goto LA16_;
				T14_ = ((*le_1).size < ((NI)1056964608));
LA16_: ;
				if (!T14_) goto LA17_;
				removeChunkFromMatrix__system_u6106(a_p0, ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (le_1)));
				(*le_1).size += (*c_2).Sup.size;
				T19_ = (NI)0;
				T19_ = pageIndex__system_u6594((*((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw**) (&(c_2)))));
				excl__system_u6440((&(*a_p0).chunkStarts), T19_);
				c_2 = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (le_1));
				{
					tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* rest_1;
					if (!(((NI)1056964608) < (*c_2).Sup.size)) goto LA22_;
					rest_1 = splitChunk2__system_u6659(a_p0, c_2, ((NI)1056964608));
					addChunkToMatrix__system_u6157(a_p0, c_2);
					c_2 = rest_1;
				}
LA22_: ;
			}
LA17_: ;
		}
LA10_: ;
	}
LA3_: ;
	T24_ = (NI)0;
	T24_ = pluspercent___system_u785(((NI) (ptrdiff_t) (c_2)), (*c_2).Sup.size);
	ri_1 = ((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*) (T24_));
	{
		NIM_BOOL T27_;
		T27_ = (NIM_BOOL)0;
		T27_ = isAccessible__system_u6636((&(*a_p0)), ((void*) (ri_1)));
		if (!(T27_)) goto LA28_;
		T27_ = chunkUnused__system_u6516(ri_1);
LA28_: ;
		if (!T27_) goto LA29_;
		{
			NIM_BOOL T33_;
			NIM_BOOL T34_;
			NI T38_;
			T33_ = (NIM_BOOL)0;
			T34_ = (NIM_BOOL)0;
			T34_ = isSmallChunk__system_u6510(ri_1);
			T33_ = !(T34_);
			if (!(T33_)) goto LA35_;
			T33_ = ((*c_2).Sup.size < ((NI)1056964608));
LA35_: ;
			if (!T33_) goto LA36_;
			removeChunkFromMatrix__system_u6106(a_p0, ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (ri_1)));
			(*c_2).Sup.size += (*ri_1).size;
			T38_ = (NI)0;
			T38_ = pageIndex__system_u6594(ri_1);
			excl__system_u6440((&(*a_p0).chunkStarts), T38_);
			{
				tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* rest_2;
				if (!(((NI)1056964608) < (*c_2).Sup.size)) goto LA41_;
				rest_2 = splitChunk2__system_u6659(a_p0, c_2, ((NI)1056964608));
				addChunkToMatrix__system_u6157(a_p0, rest_2);
			}
LA41_: ;
		}
LA36_: ;
	}
LA29_: ;
	addChunkToMatrix__system_u6157(a_p0, c_2);
}
N_LIB_PRIVATE N_NIMCALL(void, deallocBigChunk__system_u6758)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1) {
	(*a_p0).occ -= (*c_p1).Sup.size;
	(*c_p1).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	{
		if (!(((NI)1056964609) <= (*c_p1).Sup.size)) goto LA3_;
		freeHugeChunk__system_u6736(a_p0, c_p1);
	}
	goto LA1_;
LA3_: ;
	{
		freeBigChunk__system_u6688(a_p0, c_p1);
	}
LA1_: ;
}
static N_INLINE(void, addToSharedFreeListBigChunks__system_u6769)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_p1) {
	(*c_p1).next = (*a_p0).sharedFreeListBigChunks;
	(*a_p0).sharedFreeListBigChunks = c_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, freeDeferredObjects__system_u6835)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* root_p1) {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* it_1;
	NI maxIters_1;
	it_1 = root_p1;
	maxIters_1 = ((NI)20);
	{
		while (1) {
			tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* rest_1;
			rest_1 = (*it_1).next;
			(*it_1).next = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
			deallocBigChunk__system_u6758(a_p0, ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (it_1)));
			{
				if (!(maxIters_1 == ((NI)0))) goto LA5_;
				{
					if (!!((rest_1 == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL)))) goto LA9_;
					addToSharedFreeListBigChunks__system_u6769(a_p0, rest_1);
				}
LA9_: ;
				goto LA1;
			}
LA5_: ;
			it_1 = rest_1;
			maxIters_1 -= ((NI)1);
			{
				if (!(it_1 == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL))) goto LA13_;
				goto LA1;
			}
LA13_: ;
		}
	} LA1: ;
}
static N_INLINE(NI, bigChunkAlignOffset__system_u6867)(NI alignment_p0) {
	NI result;
	{
		if (!(alignment_p0 == ((NI)0))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		NI T6_;
		T6_ = (NI)0;
		T6_ = align__system_u1639(((NI)64), alignment_p0);
		result = (NI)((NI)(T6_ - ((NI)48)) - ((NI)16));
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*, getHugeChunk__system_u6732)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI size_p1) {
	tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* result;
	void* T1_;
	tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* T2_;
	NI T3_;
	T1_ = (void*)0;
	T1_ = allocPages__system_u6187(a_p0, size_p1);
	result = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (T1_));
	incCurrMem__system_u6167(a_p0, size_p1);
	(*result).next = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*result).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
	(*result).Sup.size = size_p1;
	(*result).Sup.prevSize = ((NI)1);
	(*result).Sup.owner = a_p0;
	T2_ = (tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ*)0;
	T2_ = a_p0;
	T3_ = (NI)0;
	T3_ = pageIndex__system_u6594((*((tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw**) (&(result)))));
	incl__system_u6418(T2_, (&(*a_p0).chunkStarts), T3_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, rawAlloc__system_u6870)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, NI requestedSize_p1, NI alignment_p2) {
	void* result;
	NI size_1;
	NI alignOff_1;
	result = (void*)0;
	size_1 = roundup__system_u5860(requestedSize_p1, ((((NI)16) >= alignment_p2) ? ((NI)16) : alignment_p2));
	alignOff_1 = smallChunkAlignOffset__system_u6858(alignment_p2);
	{
		NI s_1;
		tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_1;
		if (!((NI)(size_1 + alignOff_1) <= ((NI)4032))) goto LA3_;
		s_1 = (NI)(size_1 / ((NI)16));
		c_1 = (*a_p0).freeSmallChunks[(s_1)- 0];
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = !((c_1 == ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL)));
			if (!(T7_)) goto LA8_;
			T7_ = !(((*c_1).chunkAlignOff == ((NI32) (alignOff_1))));
LA8_: ;
			if (!T7_) goto LA9_;
			c_1 = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL);
		}
LA9_: ;
		{
			if (!(c_1 == ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL))) goto LA13_;
			c_1 = getSmallChunk__system_u6740(a_p0);
			(*c_1).freeList = ((tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg*) NIM_NIL);
			(*c_1).foreignCells = ((NI32)0);
			(*c_1).chunkAlignOff = ((NI32) (alignOff_1));
			(*c_1).Sup.size = size_1;
			(*c_1).acc = ((NU32) ((NI)(alignOff_1 + size_1)));
			(*c_1).free = (NI32)((NI32)(((NI32)4032) - ((NI32) (alignOff_1))) - ((NI32) (size_1)));
			(*c_1).next = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL);
			(*c_1).prev = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL);
			{
				if (!((*c_1).freeList == ((tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg*) NIM_NIL))) goto LA17_;
				(*c_1).freeList = (*a_p0).sharedFreeLists[(s_1)- 0];
				(*a_p0).sharedFreeLists[(s_1)- 0] = ((tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg*) NIM_NIL);
				compensateCounters__system_u6800(a_p0, c_1, size_1);
			}
LA17_: ;
			{
				if (!(size_1 <= ((NI) ((*c_1).free)))) goto LA21_;
				listAdd__system_u6903(&(*a_p0).freeSmallChunks[(s_1)- 0], c_1);
			}
LA21_: ;
			result = ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) ((*c_1).data))) + (NU64)(((NU) (alignOff_1))))));
		}
		goto LA11_;
LA13_: ;
		{
			{
				NI T28_;
				if (!((*c_1).freeList == ((tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg*) NIM_NIL))) goto LA26_;
				T28_ = (NI)0;
				T28_ = pluspercent___system_u785(((NI) (ptrdiff_t) ((*c_1).data)), ((NI) ((*c_1).acc)));
				result = ((void*) (T28_));
				(*c_1).acc += size_1;
			}
			goto LA24_;
LA26_: ;
			{
				result = ((void*) ((*c_1).freeList));
				(*c_1).freeList = (*(*c_1).freeList).next;
				{
					tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* T32_;
					T32_ = (tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw*)0;
					T32_ = pageAddr__system_u6608(result);
					if (!!((((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) (T32_)) == c_1))) goto LA33_;
					(*c_1).foreignCells -= ((NI)1);
				}
				goto LA30_;
LA33_: ;
				{
				}
LA30_: ;
			}
LA24_: ;
			(*c_1).free -= size_1;
			{
				if (!((*c_1).freeList == ((tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg*) NIM_NIL))) goto LA38_;
				(*c_1).freeList = (*a_p0).sharedFreeLists[(s_1)- 0];
				(*a_p0).sharedFreeLists[(s_1)- 0] = ((tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg*) NIM_NIL);
				compensateCounters__system_u6800(a_p0, c_1, size_1);
			}
LA38_: ;
			{
				if (!(((NI) ((*c_1).free)) < size_1)) goto LA42_;
				listRemove__system_u6976(&(*a_p0).freeSmallChunks[(s_1)- 0], c_1);
			}
LA42_: ;
		}
LA11_: ;
		(*a_p0).occ += size_1;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* colontmpD_;
		tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* colontmpD__2;
		tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* deferredFrees_1;
		NI alignPad_1;
		tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg* c_2;
		colontmpD_ = (tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*)0;
		colontmpD__2 = (tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*)0;
		deferredFrees_1 = (*a_p0).sharedFreeListBigChunks;
		(*a_p0).sharedFreeListBigChunks = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL);
		{
			if (!!((deferredFrees_1 == ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) NIM_NIL)))) goto LA47_;
			freeDeferredObjects__system_u6835(a_p0, deferredFrees_1);
		}
LA47_: ;
		alignPad_1 = bigChunkAlignOffset__system_u6867(alignment_p2);
		size_1 = (NI)((NI)(requestedSize_p1 + ((NI)48)) + alignPad_1);
		{
			if (!(((NI)1056964609) <= size_1)) goto LA51_;
			colontmpD_ = getHugeChunk__system_u6732(a_p0, size_1);
			c_2 = colontmpD_;
		}
		goto LA49_;
LA51_: ;
		{
			colontmpD__2 = getBigChunk__system_u6712(a_p0, size_1);
			c_2 = colontmpD__2;
		}
LA49_: ;
		result = ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) ((*c_2).data))) + (NU64)(((NU) (alignPad_1))))));
		(*c_2).prev = ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (result));
		(*a_p0).occ += (*c_2).Sup.size;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, alloc__system_u7115)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* allocator_p0, NI size_p1) {
	void* result;
	result = rawAlloc__system_u6870(allocator_p0, size_p1, ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NOCONV(void*, allocImpl__system_u1758)(NI size_p0) {
	void* result;
	result = alloc__system_u7115((&allocator__system_u7164), size_p0);
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toNimStr)(NCSTRING str_p0, NI len_p1) {
	NimStringV2 result;
	nimZeroMem((void*)(&result), sizeof(NimStringV2));
	{
		if (!(len_p1 <= ((NI)0))) goto LA3_;
		result.len = ((NI)0);
		result.p = ((NimStrPayload*) NIM_NIL);
	}
	goto LA1_;
LA3_: ;
	{
		NimStrPayload* p_1;
		void* T6_;
		T6_ = (void*)0;
		T6_ = allocImpl__system_u1758(((NI)((NI)(len_p1 + ((NI)1)) + ((NI)8))));
		p_1 = ((NimStrPayload*) (T6_));
		(*p_1).cap = len_p1;
		copyMem__system_u1742(((void*) ((&(*p_1).data[((NI)0)]))), ((void*) (str_p0)), ((NI)(len_p1 + ((NI)1))));
		result.len = len_p1;
		result.p = p_1;
	}
LA1_: ;
	return result;
}
static N_INLINE(NI, nimCStrLen)(NCSTRING a_p0) {
	NI result;
	size_t T5_;
{	{
		if (!(a_p0 == 0)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	T5_ = (size_t)0;
	T5_ = strlen(a_p0);
	result = ((NI) (T5_));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cstrToNimstr)(NCSTRING str_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
	{
		if (!(((void*) (str_p0)) == NIM_NIL)) goto LA4_;
		result = toNimStr(str_p0, ((NI)0));
	}
	goto LA2_;
LA4_: ;
	{
		result = toNimStr(str_p0, nimCStrLen(str_p0));
	}
LA2_: ;
	return result;
}
static N_INLINE(void, addToSharedFreeList__system_u6776)(tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_p0, tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg* f_p1, NI size_p2) {
	(*f_p1).next = (*(*c_p0).Sup.owner).sharedFreeLists[(size_p2)- 0];
	(*(*c_p0).Sup.owner).sharedFreeLists[(size_p2)- 0] = f_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, rawDealloc__system_u7040)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0, void* p_p1) {
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* c_1;
	c_1 = pageAddr__system_u6608(p_p1);
	{
		NIM_BOOL T3_;
		tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* c_2;
		NI s_1;
		tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg* f_1;
		T3_ = (NIM_BOOL)0;
		T3_ = isSmallChunk__system_u6510(c_1);
		if (!T3_) goto LA4_;
		c_2 = ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) (c_1));
		s_1 = (*c_2).Sup.size;
		f_1 = ((tyObject_FreeCell__KX9cVlRwWf3SV8loeEIHzzg*) (p_p1));
		{
			tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA* activeChunk_1;
			if (!((*c_2).Sup.owner == a_p0)) goto LA8_;
			(*a_p0).occ -= s_1;
			activeChunk_1 = (*a_p0).freeSmallChunks[((NI)(s_1 / ((NI)16)))- 0];
			{
				NIM_BOOL T12_;
				NIM_BOOL T13_;
				T12_ = (NIM_BOOL)0;
				T13_ = (NIM_BOOL)0;
				T13_ = !((activeChunk_1 == ((tyObject_SmallChunk__pc9c3neQed0Sa8itAoPMhNA*) NIM_NIL)));
				if (!(T13_)) goto LA14_;
				T13_ = !((c_2 == activeChunk_1));
LA14_: ;
				T12_ = T13_;
				if (!(T12_)) goto LA15_;
				T12_ = ((*activeChunk_1).chunkAlignOff == (*c_2).chunkAlignOff);
LA15_: ;
				if (!T12_) goto LA16_;
				(*f_1).next = (*activeChunk_1).freeList;
				(*activeChunk_1).freeList = f_1;
				(*activeChunk_1).free += s_1;
				(*activeChunk_1).foreignCells += ((NI)1);
			}
			goto LA10_;
LA16_: ;
			{
				(*f_1).next = (*c_2).freeList;
				(*c_2).freeList = f_1;
				{
					if (!(((NI) ((*c_2).free)) < s_1)) goto LA21_;
					listAdd__system_u6903(&(*a_p0).freeSmallChunks[((NI)(s_1 / ((NI)16)))- 0], c_2);
					(*c_2).free += s_1;
				}
				goto LA19_;
LA21_: ;
				{
					(*c_2).free += s_1;
				}
LA19_: ;
			}
LA10_: ;
		}
		goto LA6_;
LA8_: ;
		{
			addToSharedFreeList__system_u6776(c_2, f_1, (NI)(s_1 / ((NI)16)));
		}
LA6_: ;
	}
	goto LA1_;
LA4_: ;
	{
		{
			if (!((*c_1).owner == a_p0)) goto LA28_;
			deallocBigChunk__system_u6758(a_p0, ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (c_1)));
		}
		goto LA26_;
LA28_: ;
		{
			addToSharedFreeListBigChunks__system_u6769((*c_1).owner, ((tyObject_BigChunk__UA3R11NDB1bQc0VdczS9c9bg*) (c_1)));
		}
LA26_: ;
	}
LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, dealloc__system_u7123)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* allocator_p0, void* p_p1) {
	rawDealloc__system_u7040(allocator_p0, p_p1);
}
N_LIB_PRIVATE N_NOCONV(void, deallocImpl__system_u1762)(void* p_p0) {
	dealloc__system_u7123((&allocator__system_u7164), p_p0);
}
N_LIB_PRIVATE N_NOCONV(void, dealloc)(void* p_p0) {
	deallocImpl__system_u1762(p_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 dealloc(dest_p0.p);
}
}
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1) {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* h_1;
	NI T1_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	h_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_));
	(*h_1).rc = pluspercent___system_u785((*h_1).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3130)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0) {
	NI rootIdx_1;
	NI idx_1;
	NI last_1;
	rootIdx_1 = (*s_p0).rootIdx;
	idx_1 = minuspercent___system_u805(rootIdx_1, ((NI)1));
	last_1 = minuspercent___system_u805(roots__system_u3129.len, ((NI)1));
	roots__system_u3129.d[idx_1] = roots__system_u3129.d[last_1];
	(*roots__system_u3129.d[idx_1].Field0).rootIdx = rootIdx_1;
	roots__system_u3129.len = last_1;
	(*s_p0).rootIdx = ((NI)0);
}
static N_INLINE(NI, starpercent___system_u825)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) * (NU64)(((NU) (y_p1))))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, init__system_u3340)(tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg* s_p0, NI cap_p1) {
	NI T1_;
	void* T2_;
	(*s_p0).len = ((NI)0);
	(*s_p0).cap = cap_p1;
	T1_ = (NI)0;
	T1_ = starpercent___system_u825((*s_p0).cap, ((NI)16));
	T2_ = (void*)0;
	T2_ = allocImpl__system_u1758(((NI) (T1_)));
	(*s_p0).d = ((tyTuple__DTRsWi2kgTewbhN2TT5mbA*) (T2_));
}
N_LIB_PRIVATE N_NIMCALL(NI, ptrSize__system_u7103)(void* p_p0) {
	NI result;
	tyObject_BaseChunk__p9cjd9cJS43x5ecdwwbM3Dkw* c_1;
	c_1 = pageAddr__system_u6608(p_p0);
	result = (*c_1).size;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isSmallChunk__system_u6510(c_1);
		if (!!(T3_)) goto LA4_;
		result -= ((NI)48);
	}
LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, realloc__system_u7126)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* allocator_p0, void* p_p1, NI newsize_p2) {
	void* result;
	result = NIM_NIL;
	{
		if (!(((NI)0) < newsize_p2)) goto LA3_;
		result = alloc__system_u7115(allocator_p0, newsize_p2);
		{
			NI T9_;
			if (!!((p_p1 == NIM_NIL))) goto LA7_;
			T9_ = (NI)0;
			T9_ = ptrSize__system_u7103(p_p1);
			copyMem__system_u1742(result, p_p1, (((T9_ <= newsize_p2) ? T9_ : newsize_p2)));
			dealloc__system_u7123(allocator_p0, p_p1);
		}
LA7_: ;
	}
	goto LA1_;
LA3_: ;
	{
		if (!!((p_p1 == NIM_NIL))) goto LA11_;
		dealloc__system_u7123(allocator_p0, p_p1);
	}
	goto LA1_;
LA11_: ;
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NOCONV(void*, reallocImpl__system_u1764)(void* p_p0, NI newSize_p1) {
	void* result;
	result = realloc__system_u7126((&allocator__system_u7164), p_p0, newSize_p1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3242)(tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg* s_p0) {
	NI newSize_1;
	void* T1_;
	(*s_p0).cap = pluspercent___system_u785((NI)((*s_p0).cap / ((NI)2)), (*s_p0).cap);
	newSize_1 = starpercent___system_u825((*s_p0).cap, ((NI)16));
	T1_ = (void*)0;
	T1_ = reallocImpl__system_u1764(((void*) ((*s_p0).d)), ((NI) (newSize_1)));
	(*s_p0).d = ((tyTuple__DTRsWi2kgTewbhN2TT5mbA*) (T1_));
}
static N_INLINE(void, add__system_u3234)(tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg* s_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* c_p1, TNimTypeV2* t_p2) {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3242(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
N_LIB_PRIVATE N_NIMCALL(void, init__system_u3387)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, NI cap_p1) {
	NI T1_;
	void* T2_;
	(*s_p0).len = ((NI)0);
	(*s_p0).cap = cap_p1;
	T1_ = (NI)0;
	T1_ = starpercent___system_u825((*s_p0).cap, ((NI)16));
	T2_ = (void*)0;
	T2_ = allocImpl__system_u1758(((NI) (T1_)));
	(*s_p0).d = ((tyTuple__N4J9cV4JZGem3ljqqj5rT0Q*) (T2_));
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4146);
	return result;
}
static N_INLINE(void, trace__system_u2949)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		void* p_1;
		if (!!(((*desc_p1).traceImpl == NIM_NIL))) goto LA3_;
		p_1 = ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (s_p0))) + (NU64)(((NU) (((NI)16)))))));
		((tyProc__fhqfcnDhIcLpBpSTVsWEZg) ((*desc_p1).traceImpl))(p_1, ((void*) (j_p2)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyTuple__N4J9cV4JZGem3ljqqj5rT0Q, pop__system_u3163)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0) {
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q result;
	NI last_1;
	last_1 = minuspercent___system_u805((*s_p0).len, ((NI)1));
	(*s_p0).len = last_1;
	result = (*s_p0).d[last_1];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, markGray__system_u3175)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p2) {
	{
		NI T5_;
		if (!!(((NI)((*s_p0).rc & ((NI)3)) == ((NI)1)))) goto LA3_;
		(*s_p0).rc = (NI)((NI)((*s_p0).rc & ((NI)-4)) | ((NI)1));
		(*j_p2).touched = pluspercent___system_u785((*j_p2).touched, ((NI)1));
		T5_ = (NI)0;
		T5_ = pluspercent___system_u785((*j_p2).rcSum, (NI)((NI64)((*s_p0).rc) >> (NU64)(((NI)4) & (64 - 1))));
		(*j_p2).rcSum = pluspercent___system_u785(T5_, ((NI)1));
		trace__system_u2949(s_p0, desc_p1, j_p2);
		{
			while (1) {
				tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tmpTuple_1;
				void** entry_1;
				TNimTypeV2* desc_2;
				tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* t_1;
				NI T8_;
				if (!(((NI)0) < (*j_p2).traceStack.len)) goto LA7;
				tmpTuple_1 = pop__system_u3163((&(*j_p2).traceStack));
				entry_1 = tmpTuple_1.Field0;
				desc_2 = tmpTuple_1.Field1;
				T8_ = (NI)0;
				T8_ = minuspercent___system_u805(((NI) (ptrdiff_t) ((*entry_1))), ((NI)16));
				t_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T8_));
				(*t_1).rc = minuspercent___system_u805((*t_1).rc, ((NI)16));
				(*j_p2).edges = pluspercent___system_u785((*j_p2).edges, ((NI)1));
				{
					NI T13_;
					if (!!(((NI)((*t_1).rc & ((NI)3)) == ((NI)1)))) goto LA11_;
					(*t_1).rc = (NI)((NI)((*t_1).rc & ((NI)-4)) | ((NI)1));
					(*j_p2).touched = pluspercent___system_u785((*j_p2).touched, ((NI)1));
					T13_ = (NI)0;
					T13_ = pluspercent___system_u785((*j_p2).rcSum, (NI)((NI64)((*t_1).rc) >> (NU64)(((NI)4) & (64 - 1))));
					(*j_p2).rcSum = pluspercent___system_u785(T13_, ((NI)2));
					trace__system_u2949(t_1, desc_2, j_p2);
				}
LA11_: ;
			} LA7: ;
		}
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, scanBlack__system_u3155)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p2) {
	NI until_1;
	(*s_p0).rc = (NI)((*s_p0).rc & ((NI)-4));
	until_1 = (*j_p2).traceStack.len;
	trace__system_u2949(s_p0, desc_p1, j_p2);
	{
		while (1) {
			tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tmpTuple_1;
			void** entry_1;
			TNimTypeV2* desc_2;
			tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* t_1;
			NI T3_;
			if (!(until_1 < (*j_p2).traceStack.len)) goto LA2;
			tmpTuple_1 = pop__system_u3163((&(*j_p2).traceStack));
			entry_1 = tmpTuple_1.Field0;
			desc_2 = tmpTuple_1.Field1;
			T3_ = (NI)0;
			T3_ = minuspercent___system_u805(((NI) (ptrdiff_t) ((*entry_1))), ((NI)16));
			t_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T3_));
			(*t_1).rc = pluspercent___system_u785((*t_1).rc, ((NI)16));
			{
				if (!!(((NI)((*t_1).rc & ((NI)3)) == ((NI)0)))) goto LA6_;
				(*t_1).rc = (NI)((*t_1).rc & ((NI)-4));
				trace__system_u2949(t_1, desc_2, j_p2);
			}
LA6_: ;
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, scan__system_u3201)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p2) {
	{
		if (!((NI)((*s_p0).rc & ((NI)3)) == ((NI)1))) goto LA3_;
		{
			if (!(((NI)0) <= (NI)((NI64)((*s_p0).rc) >> (NU64)(((NI)4) & (64 - 1))))) goto LA7_;
			scanBlack__system_u3155(s_p0, desc_p1, j_p2);
		}
		goto LA5_;
LA7_: ;
		{
			(*s_p0).rc = (NI)((NI)((*s_p0).rc & ((NI)-4)) | ((NI)2));
			trace__system_u2949(s_p0, desc_p1, j_p2);
			{
				while (1) {
					tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tmpTuple_1;
					void** entry_1;
					TNimTypeV2* desc_2;
					tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* t_1;
					NI T12_;
					if (!(((NI)0) < (*j_p2).traceStack.len)) goto LA11;
					tmpTuple_1 = pop__system_u3163((&(*j_p2).traceStack));
					entry_1 = tmpTuple_1.Field0;
					desc_2 = tmpTuple_1.Field1;
					T12_ = (NI)0;
					T12_ = minuspercent___system_u805(((NI) (ptrdiff_t) ((*entry_1))), ((NI)16));
					t_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T12_));
					{
						if (!((NI)((*t_1).rc & ((NI)3)) == ((NI)1))) goto LA15_;
						{
							if (!(((NI)0) <= (NI)((NI64)((*t_1).rc) >> (NU64)(((NI)4) & (64 - 1))))) goto LA19_;
							scanBlack__system_u3155(t_1, desc_2, j_p2);
						}
						goto LA17_;
LA19_: ;
						{
							(*t_1).rc = (NI)((NI)((*t_1).rc & ((NI)-4)) | ((NI)2));
							trace__system_u2949(t_1, desc_2, j_p2);
						}
LA17_: ;
					}
LA15_: ;
				} LA11: ;
			}
		}
LA5_: ;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, collectColor__system_u3226)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1, NI col_p2, tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p3) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((NI)((*s_p0).rc & ((NI)3)) == col_p2);
		if (!(T3_)) goto LA4_;
		T3_ = ((*s_p0).rootIdx == ((NI)0));
LA4_: ;
		if (!T3_) goto LA5_;
		(*s_p0).rc = (NI)((*s_p0).rc & ((NI)-4));
		add__system_u3234((&(*j_p3).toFree), s_p0, desc_p1);
		trace__system_u2949(s_p0, desc_p1, j_p3);
		{
			while (1) {
				tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tmpTuple_1;
				void** entry_1;
				TNimTypeV2* desc_2;
				tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* t_1;
				NI T9_;
				if (!(((NI)0) < (*j_p3).traceStack.len)) goto LA8;
				tmpTuple_1 = pop__system_u3163((&(*j_p3).traceStack));
				entry_1 = tmpTuple_1.Field0;
				desc_2 = tmpTuple_1.Field1;
				T9_ = (NI)0;
				T9_ = minuspercent___system_u805(((NI) (ptrdiff_t) ((*entry_1))), ((NI)16));
				t_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T9_));
				(*entry_1) = NIM_NIL;
				{
					NIM_BOOL T12_;
					T12_ = (NIM_BOOL)0;
					T12_ = ((NI)((*t_1).rc & ((NI)3)) == col_p2);
					if (!(T12_)) goto LA13_;
					T12_ = ((*t_1).rootIdx == ((NI)0));
LA13_: ;
					if (!T12_) goto LA14_;
					add__system_u3234((&(*j_p3).toFree), t_1, desc_2);
					(*t_1).rc = (NI)((*t_1).rc & ((NI)-4));
					trace__system_u2949(t_1, desc_2, j_p3);
				}
LA14_: ;
			} LA8: ;
		}
	}
LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, nimAlignedDealloc__system_u2760)(void* p_p0) {
	rawDealloc__system_u7040((&allocator__system_u7164), p_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1) {
	nimAlignedDealloc__system_u2760(((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (p_p0))) - (NU64)(((NU) (((NI)16))))))));
}
static N_INLINE(void, free__system_u3003)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1) {
	void* p_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	p_1 = ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (s_p0))) + (NU64)(((NU) (((NI)16)))))));
	{
		if (!!(((*desc_p1).destructor == NIM_NIL))) goto LA3_;
		((tyProc__4SVlZZPmetqBimNsH9cHcOA) ((*desc_p1).destructor))(p_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	nimRawDispose(p_1, ((NI) ((*desc_p1).align)));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, deinit__system_u3374)(tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg* s_p0) {
	{
		if (!!(((*s_p0).d == ((tyTuple__DTRsWi2kgTewbhN2TT5mbA*) NIM_NIL)))) goto LA3_;
		dealloc(((void*) ((*s_p0).d)));
		(*s_p0).d = ((tyTuple__DTRsWi2kgTewbhN2TT5mbA*) NIM_NIL);
	}
LA3_: ;
	(*s_p0).len = ((NI)0);
	(*s_p0).cap = ((NI)0);
}
N_LIB_PRIVATE N_NIMCALL(void, collectCyclesBacon__system_u3293)(tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_p0, NI lowMark_p1) {
	NI last_1;
	NI colToCollect_1;
	NI oldThreshold_1;
	last_1 = minuspercent___system_u805(roots__system_u3129.len, ((NI)1));
	{
		NI i_1;
		NI res_1;
		i_1 = (NI)0;
		res_1 = last_1;
		{
			while (1) {
				if (!(lowMark_p1 <= res_1)) goto LA3;
				i_1 = ((NI) (res_1));
				markGray__system_u3175(roots__system_u3129.d[i_1].Field0, roots__system_u3129.d[i_1].Field1, j_p0);
				res_1 -= ((NI)1);
			} LA3: ;
		}
	}
	colToCollect_1 = ((NI)2);
	{
		if (!((*j_p0).rcSum == (*j_p0).edges)) goto LA6_;
		colToCollect_1 = ((NI)1);
		(*j_p0).keepThreshold = NIM_TRUE;
	}
	goto LA4_;
LA6_: ;
	{
		{
			NI i_2;
			NI res_2;
			i_2 = (NI)0;
			res_2 = last_1;
			{
				while (1) {
					if (!(lowMark_p1 <= res_2)) goto LA11;
					i_2 = ((NI) (res_2));
					scan__system_u3201(roots__system_u3129.d[i_2].Field0, roots__system_u3129.d[i_2].Field1, j_p0);
					res_2 -= ((NI)1);
				} LA11: ;
			}
		}
	}
LA4_: ;
	init__system_u3340((&(*j_p0).toFree), ((NI)1024));
	{
		NI i_3;
		NI i_4;
		i_3 = (NI)0;
		i_4 = ((NI)0);
		{
			while (1) {
				tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_1;
				if (!(i_4 < roots__system_u3129.len)) goto LA14;
				i_3 = i_4;
				s_1 = roots__system_u3129.d[i_3].Field0;
				(*s_1).rootIdx = ((NI)0);
				collectColor__system_u3226(s_1, roots__system_u3129.d[i_3].Field1, colToCollect_1, j_p0);
				i_4 += ((NI)1);
			} LA14: ;
		}
	}
	oldThreshold_1 = rootsThreshold__system_u3292;
	rootsThreshold__system_u3292 = ((NI)IL64(9223372036854775807));
	roots__system_u3129.len = ((NI)0);
	{
		NI i_5;
		NI i_6;
		i_5 = (NI)0;
		i_6 = ((NI)0);
		{
			while (1) {
				if (!(i_6 < (*j_p0).toFree.len)) goto LA17;
				i_5 = i_6;
				free__system_u3003((*j_p0).toFree.d[i_5].Field0, (*j_p0).toFree.d[i_5].Field1);
				i_6 += ((NI)1);
			} LA17: ;
		}
	}
	rootsThreshold__system_u3292 = oldThreshold_1;
	(*j_p0).freed = pluspercent___system_u785((*j_p0).freed, (*j_p0).toFree.len);
	deinit__system_u3374((&(*j_p0).toFree));
}
N_LIB_PRIVATE N_NIMCALL(void, deinit__system_u3399)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0) {
	{
		if (!!(((*s_p0).d == ((tyTuple__N4J9cV4JZGem3ljqqj5rT0Q*) NIM_NIL)))) goto LA3_;
		dealloc(((void*) ((*s_p0).d)));
		(*s_p0).d = ((tyTuple__N4J9cV4JZGem3ljqqj5rT0Q*) NIM_NIL);
	}
LA3_: ;
	(*s_p0).len = ((NI)0);
	(*s_p0).cap = ((NI)0);
}
N_LIB_PRIVATE N_NIMCALL(void, collectCycles__system_u3435)(void) {
	tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w j_1;
	nimZeroMem((void*)(&j_1), sizeof(tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w));
	init__system_u3387((&j_1.traceStack), ((NI)1024));
	collectCyclesBacon__system_u3293((&j_1), ((NI)0));
	deinit__system_u3399((&j_1.traceStack));
	{
		if (!(roots__system_u3129.len == ((NI)0))) goto LA3_;
		deinit__system_u3374((&roots__system_u3129));
	}
LA3_: ;
	{
		if (!j_1.keepThreshold) goto LA7_;
	}
	goto LA5_;
LA7_: ;
	{
		NI T10_;
		NI T13_;
		T10_ = (NI)0;
		T10_ = starpercent___system_u825(j_1.freed, ((NI)2));
		if (!(j_1.touched <= T10_)) goto LA11_;
		T13_ = (NI)0;
		T13_ = starpercent___system_u825((NI)(rootsThreshold__system_u3292 / ((NI)3)), ((NI)2));
		rootsThreshold__system_u3292 = ((T13_ >= ((NI)16)) ? T13_ : ((NI)16));
	}
	goto LA5_;
LA11_: ;
	{
		NI T17_;
		if (!(rootsThreshold__system_u3292 < ((NI)IL64(2305843009213693951)))) goto LA15_;
		T17_ = (NI)0;
		{
			if (!(rootsThreshold__system_u3292 <= ((NI)0))) goto LA20_;
			rootsThreshold__system_u3292 = ((NI)128);
		}
		goto LA18_;
LA20_: ;
		{
			rootsThreshold__system_u3292 = rootsThreshold__system_u3292;
		}
LA18_: ;
		rootsThreshold__system_u3292 = pluspercent___system_u785((NI)(rootsThreshold__system_u3292 / ((NI)2)), rootsThreshold__system_u3292);
	}
	goto LA5_;
LA15_: ;
LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, registerCycle__system_u3460)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0, TNimTypeV2* desc_p1) {
	(*s_p0).rootIdx = pluspercent___system_u785(roots__system_u3129.len, ((NI)1));
	{
		if (!(roots__system_u3129.d == ((tyTuple__DTRsWi2kgTewbhN2TT5mbA*) NIM_NIL))) goto LA3_;
		init__system_u3340((&roots__system_u3129), ((NI)1024));
	}
LA3_: ;
	add__system_u3234((&roots__system_u3129), s_p0, desc_p1);
	{
		NI T7_;
		T7_ = (NI)0;
		T7_ = minuspercent___system_u805(roots__system_u3129.len, ((NI)128));
		if (!(rootsThreshold__system_u3292 <= T7_)) goto LA8_;
		collectCycles__system_u3435();
	}
LA8_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3500)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2) {
	{
		if (!isDestroyAction_p0) goto LA3_;
		{
			if (!(((NI)0) < (*s_p1).rootIdx)) goto LA7_;
			unregisterCycle__system_u3130(s_p1);
		}
LA7_: ;
	}
	goto LA1_;
LA3_: ;
	{
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = ((*s_p1).rootIdx == ((NI)0));
			if (!(T12_)) goto LA13_;
			T12_ = ((NI)((*desc_p2).flags & ((NI)1)) == ((NI)0));
LA13_: ;
			if (!T12_) goto LA14_;
			(*s_p1).rc = (NI)((*s_p1).rc & ((NI)-4));
			registerCycle__system_u3460(s_p1, desc_p2);
		}
LA14_: ;
	}
LA1_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3500(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0) {
	TNimTypeV2** rti_1;
	rti_1 = ((TNimTypeV2**) (p_p0));
	{
		if (!!(((*(*rti_1)).destructor == NIM_NIL))) goto LA3_;
		((tyProc__4SVlZZPmetqBimNsH9cHcOA) ((*(*rti_1)).destructor))(p_p0);
	}
LA3_: ;
	nimRawDispose(p_p0, ((NI) ((*(*rti_1)).align)));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3664)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2) {
	Exception* colontmp_;
	colontmp_ = (*dest_p0);
	{
		if (!src_p1) goto LA3_;
		nimIncRefCyclic(src_p1, cyclic_p2);
	}
LA3_: ;
	(*dest_p0) = src_p1;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T7_) goto LA8_;
		nimDestroyAndDispose(colontmp_);
	}
LA8_: ;
}
static N_INLINE(Exception*, getCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	eqcopy___system_u3664(&result, currException__system_u3631, NIM_FALSE);
	return result;
}
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (targetDepth_p1 <= (*source_p0).depth);
	if (!(T1_)) goto LA2_;
	T1_ = ((*source_p0).display[targetDepth_p1] == token_p2);
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0) {
	NimStringV2 result;
	nimZeroMem((void*)(&result), sizeof(NimStringV2));
	{
		if (!(space_p0 <= ((NI)0))) goto LA3_;
		result.len = ((NI)0);
		result.p = ((NimStrPayload*) NIM_NIL);
	}
	goto LA1_;
LA3_: ;
	{
		NimStrPayload* p_1;
		void* T6_;
		T6_ = (void*)0;
		T6_ = allocImpl__system_u1758(((NI)((NI)(space_p0 + ((NI)1)) + ((NI)8))));
		p_1 = ((NimStrPayload*) (T6_));
		(*p_1).cap = space_p0;
		(*p_1).data[((NI)0)] = 0;
		result.len = ((NI)0);
		result.p = p_1;
	}
LA1_: ;
	return result;
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(NI, resize__system_u2228)(NI old_p0) {
	NI result;
	{
		if (!(old_p0 <= ((NI)0))) goto LA3_;
		result = ((NI)4);
	}
	goto LA1_;
LA3_: ;
	{
		if (!(old_p0 <= ((NI)32767))) goto LA6_;
		result = (NI)(old_p0 * ((NI)2));
	}
	goto LA1_;
LA6_: ;
	{
		result = (NI)((NI)(old_p0 / ((NI)2)) + old_p0);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1) {
	NI newLen_1;
	newLen_1 = (NI)((*s_p0).len + addLen_p1);
	{
		NIM_BOOL T3_;
		NimStrPayload* oldP_1;
		void* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*s_p0).p == ((NimStrPayload*) NIM_NIL));
		if (T3_) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA4_: ;
		if (!T3_) goto LA5_;
		oldP_1 = (*s_p0).p;
		T7_ = (void*)0;
		T7_ = allocImpl__system_u1758(((NI)((NI)(newLen_1 + ((NI)1)) + ((NI)8))));
		(*s_p0).p = ((NimStrPayload*) (T7_));
		(*(*s_p0).p).cap = newLen_1;
		{
			if (!(((NI)0) < (*s_p0).len)) goto LA10_;
			copyMem__system_u1742(((void*) ((&(*(*s_p0).p).data[((NI)0)]))), ((void*) ((&(*oldP_1).data[((NI)0)]))), ((((*s_p0).len <= newLen_1) ? (*s_p0).len : newLen_1)));
		}
		goto LA8_;
LA10_: ;
		{
			if (!(oldP_1 == ((NimStrPayload*) NIM_NIL))) goto LA13_;
			(*(*s_p0).p).data[((NI)0)] = 0;
		}
		goto LA8_;
LA13_: ;
LA8_: ;
	}
	goto LA1_;
LA5_: ;
	{
		NI oldCap_1;
		oldCap_1 = (NI)((*(*s_p0).p).cap & ((NI)IL64(-4611686018427387905)));
		{
			NI newCap_1;
			NI T20_;
			void* T21_;
			if (!(oldCap_1 < newLen_1)) goto LA18_;
			T20_ = (NI)0;
			T20_ = resize__system_u2228(oldCap_1);
			newCap_1 = ((newLen_1 >= T20_) ? newLen_1 : T20_);
			T21_ = (void*)0;
			T21_ = reallocImpl__system_u1764(((void*) ((*s_p0).p)), ((NI)((NI)(newCap_1 + ((NI)1)) + ((NI)8))));
			(*s_p0).p = ((NimStrPayload*) (T21_));
			(*(*s_p0).p).cap = newCap_1;
			{
				if (!(newLen_1 < newCap_1)) goto LA24_;
				zeroMem__system_u1739(((void*) ((&(*(*s_p0).p).data[(NI)(newLen_1 + ((NI)1))]))), ((NI)(newCap_1 - newLen_1)));
			}
LA24_: ;
		}
LA18_: ;
	}
LA1_: ;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NOCONV(void*, realloc0Impl__system_u1767)(void* p_p0, NI oldSize_p1, NI newSize_p2) {
	void* result;
	result = realloc__system_u7126((&allocator__system_u7164), p_p0, newSize_p2);
	{
		if (!(oldSize_p1 < newSize_p2)) goto LA3_;
		zeroMem__system_u1739(((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (result))) + (NU64)(((NU) (oldSize_p1)))))), ((NI)(newSize_p2 - oldSize_p1)));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setLengthStrV2)(NimStringV2* s_p0, NI newLen_p1) {
	{
		if (!(newLen_p1 == ((NI)0))) goto LA3_;
	}
	goto LA1_;
LA3_: ;
	{
		{
			NIM_BOOL T8_;
			NimStrPayload* oldP_1;
			void* T12_;
			T8_ = (NIM_BOOL)0;
			T8_ = ((*s_p0).p == ((NimStrPayload*) NIM_NIL));
			if (T8_) goto LA9_;
			T8_ = ((NI)((*(*s_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA9_: ;
			if (!T8_) goto LA10_;
			oldP_1 = (*s_p0).p;
			T12_ = (void*)0;
			T12_ = allocImpl__system_u1758(((NI)((NI)(newLen_p1 + ((NI)1)) + ((NI)8))));
			(*s_p0).p = ((NimStrPayload*) (T12_));
			(*(*s_p0).p).cap = newLen_p1;
			{
				if (!(((NI)0) < (*s_p0).len)) goto LA15_;
				copyMem__system_u1742(((void*) ((&(*(*s_p0).p).data[((NI)0)]))), ((void*) ((&(*oldP_1).data[((NI)0)]))), ((((*s_p0).len <= newLen_p1) ? (*s_p0).len : newLen_p1)));
				{
					if (!((*s_p0).len < newLen_p1)) goto LA19_;
					zeroMem__system_u1739(((void*) ((&(*(*s_p0).p).data[(*s_p0).len]))), ((NI)((NI)(newLen_p1 - (*s_p0).len) + ((NI)1))));
				}
				goto LA17_;
LA19_: ;
				{
					(*(*s_p0).p).data[newLen_p1] = 0;
				}
LA17_: ;
			}
			goto LA13_;
LA15_: ;
			{
				zeroMem__system_u1739(((void*) ((&(*(*s_p0).p).data[((NI)0)]))), ((NI)(newLen_p1 + ((NI)1))));
			}
LA13_: ;
		}
		goto LA6_;
LA10_: ;
		{
			NI oldCap_1;
			if (!((*s_p0).len < newLen_p1)) goto LA24_;
			oldCap_1 = (NI)((*(*s_p0).p).cap & ((NI)IL64(-4611686018427387905)));
			{
				NI newCap_1;
				NI T30_;
				void* T31_;
				if (!(oldCap_1 < newLen_p1)) goto LA28_;
				T30_ = (NI)0;
				T30_ = resize__system_u2228(oldCap_1);
				newCap_1 = ((newLen_p1 >= T30_) ? newLen_p1 : T30_);
				T31_ = (void*)0;
				T31_ = realloc0Impl__system_u1767(((void*) ((*s_p0).p)), ((NI)((NI)(oldCap_1 + ((NI)1)) + ((NI)8))), ((NI)((NI)(newCap_1 + ((NI)1)) + ((NI)8))));
				(*s_p0).p = ((NimStrPayload*) (T31_));
				(*(*s_p0).p).cap = newCap_1;
			}
LA28_: ;
		}
		goto LA6_;
LA24_: ;
LA6_: ;
		(*(*s_p0).p).data[newLen_p1] = 0;
	}
LA1_: ;
	(*s_p0).len = newLen_p1;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___system_u3959)(tySequence__S89cE01OvNjsN9c71FKsSrqQ stackTraceEntries_p0) {
	NimStringV2 result;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ s_1;
	s_1.len = 0; s_1.p = NIM_NIL;
	s_1 = stackTraceEntries_p0;
	result = rawNewString(((NI)2000));
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = s_1.len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				{
					if (!(s_1.p->data[i_1].line == ((NI)-10))) goto LA7_;
					prepareAdd((&result), 17);
appendString((&result), TM__Q5wkpxktOdTGvlSRo9bzt9aw_3);
				}
				goto LA5_;
LA7_: ;
				{
					if (!(s_1.p->data[i_1].line == ((NI)-100))) goto LA10_;
					prepareAdd((&result), 3);
appendString((&result), TM__Q5wkpxktOdTGvlSRo9bzt9aw_5);
				}
				goto LA5_;
LA10_: ;
				{
					NI oldLenX60gensym209__1;
					NI iX60gensym210__1;
					NI iX60gensym209__1;
					oldLenX60gensym209__1 = result.len;
					iX60gensym210__1 = ((NI)0);
					{
						while (1) {
							if (!!(((NU8)(s_1.p->data[i_1].filename[iX60gensym210__1]) == (NU8)(0)))) goto LA14;
							nimAddCharV1((&result), s_1.p->data[i_1].filename[iX60gensym210__1]);
							iX60gensym210__1 += ((NI)1);
						} LA14: ;
					}
					{
						if (!(((NI)0) < s_1.p->data[i_1].line)) goto LA17_;
						prepareAdd((&result), 1);
appendString((&result), TM__Q5wkpxktOdTGvlSRo9bzt9aw_7);
						addInt__stdZprivateZdigitsutils_u204((&result), s_1.p->data[i_1].line);
						{
							if (!NIM_FALSE) goto LA21_;
							prepareAdd((&result), 2);
appendString((&result), TM__Q5wkpxktOdTGvlSRo9bzt9aw_9);
							addInt__stdZprivateZdigitsutils_u204((&result), ((NI)0));
						}
LA21_: ;
						prepareAdd((&result), 1);
appendString((&result), TM__Q5wkpxktOdTGvlSRo9bzt9aw_11);
					}
LA17_: ;
					{
						NI kX60gensym209__1;
						NI colontmp__2;
						NI res_2;
						kX60gensym209__1 = (NI)0;
						colontmp__2 = (NI)0;
						colontmp__2 = ((((NI)1) >= (NI)(((NI)25) - (NI)(result.len - oldLenX60gensym209__1))) ? ((NI)1) : (NI)(((NI)25) - (NI)(result.len - oldLenX60gensym209__1)));
						res_2 = ((NI)1);
						{
							while (1) {
								if (!(res_2 <= colontmp__2)) goto LA25;
								kX60gensym209__1 = ((NI) (res_2));
								nimAddCharV1((&result), 32);
								res_2 += ((NI)1);
							} LA25: ;
						}
					}
					iX60gensym209__1 = ((NI)0);
					{
						while (1) {
							if (!!(((NU8)(s_1.p->data[i_1].procname[iX60gensym209__1]) == (NU8)(0)))) goto LA27;
							nimAddCharV1((&result), s_1.p->data[i_1].procname[iX60gensym209__1]);
							iX60gensym209__1 += ((NI)1);
						} LA27: ;
					}
					prepareAdd((&result), 1);
appendString((&result), TM__Q5wkpxktOdTGvlSRo9bzt9aw_13);
				}
LA5_: ;
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0) {
	NCSTRING result;
	{
		if (!(s_p0.len == ((NI)0))) goto LA3_;
		result = "";
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NCSTRING) ((*s_p0.p).data));
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reportUnhandledErrorAux__system_u4043)(Exception* e_p0) {
	tyArray__kytxwwvkX5R7j4VwJUOu9cg buf_1;
	NI L_1;
	nimZeroMem((void*)buf_1, sizeof(tyArray__kytxwwvkX5R7j4VwJUOu9cg));
	L_1 = ((NI)0);
	{
		NI T3_;
		NimStringV2 trace_1;
		T3_ = (*e_p0).trace.len;
		if (!!((T3_ == ((NI)0)))) goto LA4_;
		trace_1 = dollar___system_u3959((*e_p0).trace);
		{
			if (!((NI)(L_1 + trace_1.len) < ((NI)2000))) goto LA8_;
			copyMem__system_u1742(((void*) ((&buf_1[(L_1)- 0]))), ((void*) (nimToCStringConv(trace_1))), (trace_1.len));
			L_1 += trace_1.len;
		}
LA8_: ;
		eqdestroy___system_u2691(trace_1);
	}
LA4_: ;
	{
		if (!((NI)(L_1 + ((NI)28)) < ((NI)2000))) goto LA12_;
		copyMem__system_u1742(((void*) ((&buf_1[(L_1)- 0]))), ((void*) ("Error: unhandled exception: ")), ((NI)28));
		L_1 += ((NI)28);
	}
LA12_: ;
	{
		if (!((NI)(L_1 + (*e_p0).message.len) < ((NI)2000))) goto LA16_;
		copyMem__system_u1742(((void*) ((&buf_1[(L_1)- 0]))), ((void*) (nimToCStringConv((*e_p0).message))), ((*e_p0).message.len));
		L_1 += (*e_p0).message.len;
	}
LA16_: ;
	{
		if (!((NI)(L_1 + ((NI)2)) < ((NI)2000))) goto LA20_;
		copyMem__system_u1742(((void*) ((&buf_1[(L_1)- 0]))), ((void*) (" [")), ((NI)2));
		L_1 += ((NI)2);
	}
LA20_: ;
	{
		if (!((NI)(L_1 + nimCStrLen((*e_p0).name)) < ((NI)2000))) goto LA24_;
		copyMem__system_u1742(((void*) ((&buf_1[(L_1)- 0]))), ((void*) ((*e_p0).name)), (nimCStrLen((*e_p0).name)));
		L_1 += nimCStrLen((*e_p0).name);
	}
LA24_: ;
	{
		if (!((NI)(L_1 + ((NI)2)) < ((NI)2000))) goto LA28_;
		copyMem__system_u1742(((void*) ((&buf_1[(L_1)- 0]))), ((void*) ("]\012")), ((NI)2));
		L_1 += ((NI)2);
	}
LA28_: ;
	{
		NimStringV2 T34_;
		if (!!((onUnhandledException__system_u4042 == NIM_NIL))) goto LA32_;
		T34_.len = 0; T34_.p = NIM_NIL;
		T34_ = cstrToNimstr(((NCSTRING) (buf_1)));
		onUnhandledException__system_u4042(T34_);
	}
	goto LA30_;
LA32_: ;
	{
		showErrorMessage__system_u3603(((NCSTRING) (buf_1)), L_1);
	}
LA30_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reportUnhandledError__system_u4140)(Exception* e_p0) {
	{
		if (!!((unhandledExceptionHook__system_u3587 == NIM_NIL))) goto LA3_;
		unhandledExceptionHook__system_u3587(e_p0);
	}
LA3_: ;
	reportUnhandledErrorAux__system_u4043(e_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u3661)(Exception* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, raiseDefect)(void) {
	Exception* e_1;
	e_1 = NIM_NIL;
	e_1 = getCurrentException();
	{
		if (!((e_1) && (isObjDisplayCheck((*e_1).Sup.m_type, 2, 1497589760)))) goto LA3_;
		reportUnhandledError__system_u4140(e_1);
		exit(((int)1));
	}
LA3_: ;
	eqdestroy___system_u3661(e_1);
}
static N_INLINE(void, popCurrentException)(void) {
	eqcopy___system_u3664(&currException__system_u3631, (*currException__system_u3631).up, NIM_FALSE);
}
static N_INLINE(void, rawWriteString)(FILE* f_p0, NCSTRING s_p1, NI length_p2) {
	size_t T1_;
	int T2_;
	T1_ = (size_t)0;
	T1_ = fwrite(((void*) (s_p1)), ((size_t)1), ((size_t) (length_p2)), f_p0);
	(void)(T1_);
	T2_ = (int)0;
	T2_ = fflush(f_p0);
	(void)(T2_);
}
N_LIB_PRIVATE N_NIMCALL(void, writeToStdErr__system_u3596)(NCSTRING msg_p0, NI length_p1) {
	rawWriteString(__stderrp, msg_p0, length_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, showErrorMessage__system_u3603)(NCSTRING data_p0, NI length_p1) {
	NIM_BOOL toWrite_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	toWrite_1 = NIM_TRUE;
	{
		NimStringV2 colontmpD_;
		if (!!((errorMessageWriter__system_u3593 == NIM_NIL))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = cstrToNimstr(data_p0);
		errorMessageWriter__system_u3593(colontmpD_);
		toWrite_1 = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) {
			LA5_:;
			{
				*nimErr_ = NIM_FALSE;
				raiseDefect();
				popCurrentException();
				LA7_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	{
		if (!toWrite_1) goto LA11_;
		writeToStdErr__system_u3596(data_p0, length_p1);
	}
LA11_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NOCONV(void, signalHandler)(int sign_p0) {
	NCSTRING msg_1;
	tyProc__gx1DG571q2UZkCl7Jq3AOg T26_;
	int T27_;
	msg_1 = (NCSTRING)0;
	{
		if (!(sign_p0 == ((int)2))) goto LA3_;
		msg_1 = "SIGINT: Interrupted by Ctrl-C.\012";
	}
	goto LA1_;
LA3_: ;
	{
		if (!(sign_p0 == ((int)11))) goto LA6_;
		msg_1 = "SIGSEGV: Illegal storage access. (Attempt to read from nil\?)\012";
	}
	goto LA1_;
LA6_: ;
	{
		if (!(sign_p0 == ((int)6))) goto LA9_;
		msg_1 = "SIGABRT: Abnormal termination.\012";
	}
	goto LA1_;
LA9_: ;
	{
		if (!(sign_p0 == ((int)8))) goto LA12_;
		msg_1 = "SIGFPE: Arithmetic error.\012";
	}
	goto LA1_;
LA12_: ;
	{
		if (!(sign_p0 == ((int)4))) goto LA15_;
		msg_1 = "SIGILL: Illegal operation.\012";
	}
	goto LA1_;
LA15_: ;
	{
		if (!NIM_FALSE) goto LA18_;
		msg_1 = "SIGBUS: Illegal storage access. (Attempt to read from nil\?)\012";
	}
	goto LA1_;
LA18_: ;
	{
		{
			{
				if (!(sign_p0 == ((int)13))) goto LA24_;
				msg_1 = "SIGPIPE: Pipe closed.\012";
				goto LA21;
			}
LA24_: ;
			msg_1 = "unknown signal\012";
		} LA21: ;
	}
LA1_: ;
	showErrorMessage__system_u3603(msg_1, nimCStrLen(msg_1));
	T26_ = (tyProc__gx1DG571q2UZkCl7Jq3AOg)0;
	T26_ = signal(sign_p0, NIM_NIL);
	(void)(T26_);
	T27_ = (int)0;
	T27_ = raise(sign_p0);
	(void)(T27_);
}
N_LIB_PRIVATE N_NIMCALL(void, registerSignalHandler__system_u4394)(void) {
	tyProc__gx1DG571q2UZkCl7Jq3AOg T1_;
	tyProc__gx1DG571q2UZkCl7Jq3AOg T2_;
	tyProc__gx1DG571q2UZkCl7Jq3AOg T3_;
	tyProc__gx1DG571q2UZkCl7Jq3AOg T4_;
	tyProc__gx1DG571q2UZkCl7Jq3AOg T5_;
	tyProc__gx1DG571q2UZkCl7Jq3AOg T6_;
	T1_ = (tyProc__gx1DG571q2UZkCl7Jq3AOg)0;
	T1_ = signal(((int)2), signalHandler);
	T2_ = (tyProc__gx1DG571q2UZkCl7Jq3AOg)0;
	T2_ = signal(((int)11), signalHandler);
	T3_ = (tyProc__gx1DG571q2UZkCl7Jq3AOg)0;
	T3_ = signal(((int)6), signalHandler);
	T4_ = (tyProc__gx1DG571q2UZkCl7Jq3AOg)0;
	T4_ = signal(((int)8), signalHandler);
	T5_ = (tyProc__gx1DG571q2UZkCl7Jq3AOg)0;
	T5_ = signal(((int)4), signalHandler);
	T6_ = (tyProc__gx1DG571q2UZkCl7Jq3AOg)0;
	T6_ = signal(((int)13), SIG_IGN);
}
static N_INLINE(void, initStackBottom)(void) {
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__astalgo_u688)(tySequence__9chP3SzkaldXzawWQCDsqqg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__CVB9ceqf7MuYQ50y33G2eMQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void*, alignedAlloc__system_u1915)(NI size_p0, NI align_p1) {
	void* result;
	{
		if (!(align_p1 <= ((NI)16))) goto LA3_;
		result = allocImpl__system_u1758(size_p0);
	}
	goto LA1_;
LA3_: ;
	{
		void* base_1;
		NI T6_;
		NI T7_;
		NI T8_;
		NI offset_1;
		NI T9_;
		T6_ = (NI)0;
		T6_ = pluspercent___system_u785(size_p0, align_p1);
		T7_ = (NI)0;
		T7_ = minuspercent___system_u805(T6_, ((NI)1));
		T8_ = (NI)0;
		T8_ = pluspercent___system_u785(T7_, ((NI)2));
		base_1 = allocImpl__system_u1758(((NI) (T8_)));
		T9_ = (NI)0;
		T9_ = minuspercent___system_u805(align_p1, ((NI)1));
		offset_1 = minuspercent___system_u805(align_p1, ((NI) ((NU)(((NU) (ptrdiff_t) (base_1)) & ((NU) (T9_))))));
		result = ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (base_1))) + (NU64)(((NU) (offset_1))))));
		(*((NU16*) (((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (result))) - (NU64)(((NU) (((NI)2)))))))))) = ((NU16) (offset_1));
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayloadUninit)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2) {
	void* result;
	result = (void*)0;
	{
		tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g* p_1;
		NI T5_;
		void* T6_;
		if (!(((NI)0) < cap_p0)) goto LA3_;
		T5_ = (NI)0;
		T5_ = align__system_u1639(((NI)8), elemAlign_p2);
		T6_ = (void*)0;
		T6_ = alignedAlloc__system_u1915(((NI)(T5_ + (NI)(cap_p0 * elemSize_p1))), (elemAlign_p2));
		p_1 = ((tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g*) (T6_));
		(*p_1).cap = cap_p0;
		result = ((void*) (p_1));
	}
	goto LA1_;
LA3_: ;
	{
		result = NIM_NIL;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1) {
	{
		if (!(align_p1 <= ((NI)16))) goto LA3_;
		dealloc(p_p0);
	}
	goto LA1_;
LA3_: ;
	{
		NU16 offset_1;
		offset_1 = (*((NU16*) (((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (p_p0))) - (NU64)(((NU) (((NI)2))))))))));
		dealloc(((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (p_p0))) - (NU64)(((NU) (offset_1)))))));
	}
LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void*, alignedRealloc__system_u1971)(void* p_p0, NI oldSize_p1, NI newSize_p2, NI align_p3) {
	void* result;
	{
		if (!(align_p3 <= ((NI)16))) goto LA3_;
		result = reallocImpl__system_u1764(p_p0, newSize_p2);
	}
	goto LA1_;
LA3_: ;
	{
		result = alignedAlloc__system_u1915(newSize_p2, align_p3);
		copyMem__system_u1742(result, p_p0, oldSize_p1);
		alignedDealloc(p_p0, align_p3);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, prepareSeqAddUninit)(NI len_p0, void* p_p1, NI addlen_p2, NI elemSize_p3, NI elemAlign_p4) {
	void* result;
	NI headerSize_1;
	result = (void*)0;
	headerSize_1 = align__system_u1639(((NI)8), elemAlign_p4);
	{
		if (!(addlen_p2 <= ((NI)0))) goto LA3_;
		result = p_p1;
	}
	goto LA1_;
LA3_: ;
	{
		if (!(p_p1 == NIM_NIL)) goto LA6_;
		result = newSeqPayloadUninit((NI)(len_p0 + addlen_p2), elemSize_p3, elemAlign_p4);
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g* p_2;
		NI oldCap_1;
		NI newCap_1;
		NI T9_;
		p_2 = ((tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g*) (p_p1));
		oldCap_1 = (NI)((*p_2).cap & ((NI)IL64(-4611686018427387905)));
		T9_ = (NI)0;
		T9_ = resize__system_u2228(oldCap_1);
		newCap_1 = ((T9_ >= (NI)(len_p0 + addlen_p2)) ? T9_ : (NI)(len_p0 + addlen_p2));
		{
			tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g* q_1;
			void* T14_;
			if (!((NI)((*p_2).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)))) goto LA12_;
			T14_ = (void*)0;
			T14_ = alignedAlloc__system_u1915(((NI)(headerSize_1 + (NI)(elemSize_p3 * newCap_1))), (elemAlign_p4));
			q_1 = ((tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g*) (T14_));
			copyMem__system_u1742(((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (q_1))) + (NU64)(((NU) (headerSize_1)))))), ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (p_2))) + (NU64)(((NU) (headerSize_1)))))), ((NI)(len_p0 * elemSize_p3)));
			(*q_1).cap = newCap_1;
			result = ((void*) (q_1));
		}
		goto LA10_;
LA12_: ;
		{
			NI oldSize_1;
			NI newSize_1;
			tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g* q_2;
			void* T16_;
			oldSize_1 = (NI)(headerSize_1 + (NI)(elemSize_p3 * oldCap_1));
			newSize_1 = (NI)(headerSize_1 + (NI)(elemSize_p3 * newCap_1));
			T16_ = (void*)0;
			T16_ = alignedRealloc__system_u1971(((void*) (p_2)), (oldSize_1), (newSize_1), (elemAlign_p4));
			q_2 = ((tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g*) (T16_));
			(*q_2).cap = newCap_1;
			result = ((void*) (q_2));
		}
LA10_: ;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__astalgo_u681)(tySequence__9chP3SzkaldXzawWQCDsqqg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__astalgo_u688(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__CVB9ceqf7MuYQ50y33G2eMQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__CVB9ceqf7MuYQ50y33G2eMQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__jE9cmDq9bcUuOOKfQy6CBC1A*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__jE9cmDq9bcUuOOKfQy6CBC1A*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__aGv2fk9ceddvdC01ZJC2Q2g));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__astalgo_u903)(tySequence__9chP3SzkaldXzawWQCDsqqg* s_p0, NI len_p1) {
	shrink__astalgo_u688(s_p0, ((NI)0));
	setLen__astalgo_u681((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u8091)(NI* dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, nimAsgnStrV2)(NimStringV2* a_p0, NimStringV2 b_p1) {
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*a_p0).p == b_p1.p);
		if (!(T3_)) goto LA4_;
		T3_ = ((*a_p0).len == b_p1.len);
LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
LA5_: ;
	{
		NIM_BOOL T9_;
		T9_ = (NIM_BOOL)0;
		T9_ = (b_p1.p == ((NimStrPayload*) NIM_NIL));
		if (T9_) goto LA10_;
		T9_ = ((NI)((*b_p1.p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA10_: ;
		if (!T9_) goto LA11_;
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = ((*a_p0).p == ((NimStrPayload*) NIM_NIL));
			if (T15_) goto LA16_;
			T15_ = ((NI)((*(*a_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA16_: ;
			if (!!(T15_)) goto LA17_;
			dealloc(((void*) ((*a_p0).p)));
		}
LA17_: ;
		(*a_p0).len = b_p1.len;
		(*a_p0).p = b_p1.p;
	}
	goto LA7_;
LA11_: ;
	{
		{
			NIM_BOOL T22_;
			NIM_BOOL T23_;
			void* T34_;
			T22_ = (NIM_BOOL)0;
			T23_ = (NIM_BOOL)0;
			T23_ = ((*a_p0).p == ((NimStrPayload*) NIM_NIL));
			if (T23_) goto LA24_;
			T23_ = ((NI)((*(*a_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA24_: ;
			T22_ = T23_;
			if (T22_) goto LA25_;
			T22_ = ((NI)((*(*a_p0).p).cap & ((NI)IL64(-4611686018427387905))) < b_p1.len);
LA25_: ;
			if (!T22_) goto LA26_;
			{
				NIM_BOOL T30_;
				T30_ = (NIM_BOOL)0;
				T30_ = ((*a_p0).p == ((NimStrPayload*) NIM_NIL));
				if (T30_) goto LA31_;
				T30_ = ((NI)((*(*a_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA31_: ;
				if (!!(T30_)) goto LA32_;
				dealloc(((void*) ((*a_p0).p)));
			}
LA32_: ;
			T34_ = (void*)0;
			T34_ = allocImpl__system_u1758(((NI)((NI)(b_p1.len + ((NI)1)) + ((NI)8))));
			(*a_p0).p = ((NimStrPayload*) (T34_));
			(*(*a_p0).p).cap = b_p1.len;
		}
LA26_: ;
		(*a_p0).len = b_p1.len;
		copyMem__system_u1742(((void*) ((&(*(*a_p0).p).data[((NI)0)]))), ((void*) ((&(*b_p1.p).data[((NI)0)]))), ((NI)(b_p1.len + ((NI)1))));
	}
LA7_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	nimAsgnStrV2(((NimStringV2*) (dest_p0)), src_p1);
}
N_LIB_PRIVATE N_NIMCALL(void*, nimAlignedAlloc0__system_u2754)(NI size_p0, NI alignment_p1) {
	void* result;
	result = rawAlloc__system_u6870((&allocator__system_u7164), size_p0, alignment_p1);
	zeroMem__system_u1739(result, size_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1) {
	void* result;
	NI s_1;
	void* T1_;
	result = (void*)0;
	s_1 = pluspercent___system_u785(size_p0, ((NI)16));
	T1_ = (void*)0;
	T1_ = nimAlignedAlloc0__system_u2754((s_1), alignment_p1);
	result = ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (T1_))) + (NU64)(((NU) (((NI)16)))))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u3702)(tySequence__S89cE01OvNjsN9c71FKsSrqQ dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3029)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0) {
	NI newSize_1;
	void* T1_;
	(*s_p0).cap = pluspercent___system_u785((NI)((*s_p0).cap / ((NI)2)), (*s_p0).cap);
	newSize_1 = starpercent___system_u825((*s_p0).cap, ((NI)16));
	T1_ = (void*)0;
	T1_ = reallocImpl__system_u1764(((void*) ((*s_p0).d)), ((NI) (newSize_1)));
	(*s_p0).d = ((tyTuple__N4J9cV4JZGem3ljqqj5rT0Q*) (T1_));
}
N_LIB_PRIVATE N_NIMCALL(void, add__system_u4194)(tySequence__S89cE01OvNjsN9c71FKsSrqQ* x_p0, tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__z16azg5dzFTHfo9azxutGNA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__z16azg5dzFTHfo9azxutGNA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__0nxC5OGQFE7jyMqWtYaR7A*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__0nxC5OGQFE7jyMqWtYaR7A*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u3672)(Exception** dest_p0, Exception* src_p1) {
	Exception* colontmp_;
	colontmp_ = (*dest_p0);
	(*dest_p0) = src_p1;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
static N_INLINE(void, pushCurrentException)(Exception* e_p0) {
	eqcopy___system_u3664(&(*e_p0).up, currException__system_u3631, NIM_TRUE);
	eqsink___system_u3672(&currException__system_u3631, e_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionAux__system_u4173)(Exception* e_p0) {
{	{
		if (!!((localRaiseHook__system_u3582 == NIM_NIL))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = localRaiseHook__system_u3582(e_p0);
			if (!!(T7_)) goto LA8_;
			goto BeforeRet_;
		}
LA8_: ;
	}
LA3_: ;
	{
		if (!!((globalRaiseHook__system_u3579 == NIM_NIL))) goto LA12_;
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = globalRaiseHook__system_u3579(e_p0);
			if (!!(T16_)) goto LA17_;
			goto BeforeRet_;
		}
LA17_: ;
	}
LA12_: ;
	pushCurrentException(e_p0);
	nimInErrorMode__system_u4146 += ((NI)1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4) {
	{
		if (!((*e_p0).name == 0)) goto LA3_;
		(*e_p0).name = ename_p1;
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA T11_;
		T7_ = (NIM_BOOL)0;
		T7_ = !((((void*) (procname_p2)) == NIM_NIL));
		if (!(T7_)) goto LA8_;
		T7_ = !((((void*) (filename_p3)) == NIM_NIL));
LA8_: ;
		if (!T7_) goto LA9_;
		T11_.procname = procname_p2;
		T11_.filename = filename_p3;
		T11_.line = line_p4;
		add__system_u4194((&(*e_p0).trace), T11_);
	}
LA9_: ;
	raiseExceptionAux__system_u4173(e_p0);
}
N_LIB_PRIVATE N_NIMCALL(void*, alloc0__system_u7119)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* allocator_p0, NI size_p1) {
	void* result;
	result = alloc__system_u7115(allocator_p0, size_p1);
	zeroMem__system_u1739(result, size_p1);
	return result;
}
N_LIB_PRIVATE N_NOCONV(void*, alloc0Impl__system_u1760)(NI size_p0) {
	void* result;
	result = alloc0__system_u7119((&allocator__system_u7164), size_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mnewString)(NI len_p0) {
	NimStringV2 result;
	nimZeroMem((void*)(&result), sizeof(NimStringV2));
	{
		if (!(len_p0 <= ((NI)0))) goto LA3_;
		result.len = ((NI)0);
		result.p = ((NimStrPayload*) NIM_NIL);
	}
	goto LA1_;
LA3_: ;
	{
		NimStrPayload* p_1;
		void* T6_;
		T6_ = (void*)0;
		T6_ = alloc0Impl__system_u1760(((NI)((NI)(len_p0 + ((NI)1)) + ((NI)8))));
		p_1 = ((NimStrPayload*) (T6_));
		(*p_1).cap = len_p0;
		result.len = len_p0;
		result.p = p_1;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0) {
	NimStrPayload* oldP_1;
	void* T1_;
	oldP_1 = (*s_p0).p;
	T1_ = (void*)0;
	T1_ = allocImpl__system_u1758(((NI)((NI)((*s_p0).len + ((NI)1)) + ((NI)8))));
	(*s_p0).p = ((NimStrPayload*) (T1_));
	(*(*s_p0).p).cap = (*s_p0).len;
	copyMem__system_u1742(((void*) ((&(*(*s_p0).p).data[((NI)0)]))), ((void*) ((&(*oldP_1).data[((NI)0)]))), ((NI)((*s_p0).len + ((NI)1))));
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, newStringUninit__system_u2684)(NI len_p0) {
	NimStringV2 result;
	NimStringV2* s_1;
	result.len = 0; result.p = NIM_NIL;
	result = rawNewString(len_p0);
	s_1 = ((NimStringV2*) ((&result)));
	{
		if (!(((NI)0) < len_p0)) goto LA3_;
		(*s_1).len = len_p0;
		(*(*s_1).p).data[len_p0] = 0;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8654)(NimStringV2 s_p0, NI first_p1, NI last_p2) {
	NimStringV2 result;
	NI first_2;
	NI last_2;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	first_2 = ((first_p1 >= ((NI)0)) ? first_p1 : ((NI)0));
	last_2 = ((last_p2 <= (s_p0.len-1)) ? last_p2 : (s_p0.len-1));
	L_1 = (((NI)((NI)(last_2 - first_2) + ((NI)1)) >= ((NI)0)) ? (NI)((NI)(last_2 - first_2) + ((NI)1)) : ((NI)0));
	result = newStringUninit__system_u2684((L_1));
	{
		if (!(((NI)0) < L_1)) goto LA3_;
		copyMem__system_u1742(((void*) ((&result.p->data[((NI)0)]))), ((void*) ((&s_p0.p->data[first_2]))), (L_1));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__astyaml_u173)(NimStringV2* s_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u204(s_p0, x_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, echoBinSafe)(NimStringV2* args_p0, NI args_p0Len_0) {
	size_t T5_;
	int T6_;
	{
		NimStringV2* s_1;
		NI i_1;
		s_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		{
			while (1) {
				size_t T4_;
				if (!(i_1 < args_p0Len_0)) goto LA3;
				s_1 = (&args_p0[i_1]);
				T4_ = (size_t)0;
				T4_ = fwrite(((void*) (nimToCStringConv((*s_1)))), ((size_t) ((*s_1).len)), ((size_t)1), __stdoutp);
				(void)(T4_);
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	T5_ = (size_t)0;
	T5_ = fwrite(((void*) ("\012")), ((size_t)1), ((size_t)1), __stdoutp);
	(void)(T5_);
	T6_ = (int)0;
	T6_ = fflush(__stdoutp);
	(void)(T6_);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1553)(tySequence__xOJ2kx2lq9bBfIm3IXnde3Q dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].customArgs);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].obj);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].cname);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].nimname);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5509)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_]);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NimStringV2));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1370)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_]);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NimStringV2));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u2052)(tySequence__hTEiKNj3evQAjIXUI21elA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].hash);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].dirtyFile);
			eqdestroy___system_u5509(dest_p0.p->data[colontmp_].lines);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].quotedFullName);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].quotedName);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].shortName);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].projPath);
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].fullPath);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u1841)(tySequence__E0kio2ZnplNTuln9bsnljSA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void*, nimAlignedAlloc__system_u2757)(NI size_p0, NI alignment_p1) {
	void* result;
	result = rawAlloc__system_u6870((&allocator__system_u7164), size_p0, alignment_p1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObjUninit)(NI size_p0, NI alignment_p1) {
	void* result;
	NI s_1;
	void* T1_;
	NI T2_;
	NI T3_;
	result = (void*)0;
	s_1 = (NI)(size_p0 + ((NI)16));
	T1_ = (void*)0;
	T1_ = nimAlignedAlloc__system_u2757((s_1), alignment_p1);
	result = ((void*) (((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (((void*) ((NU)((NU64)(((NU) (ptrdiff_t) (T1_))) + (NU64)(((NU) (((NI)16)))))))))));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (result)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc = ((NI)0);
	T3_ = (NI)0;
	T3_ = minuspercent___system_u805(((NI) (ptrdiff_t) (result)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T3_))).rootIdx = ((NI)0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZstrtabs_u147)(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA* obj_p0) {
	eqdestroy___pureZstrtabs_u164((&(*obj_p0)));
	eqwasMoved___pureZstrtabs_u161(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZstrtabs_u127)(tySequence__xv3aaFd3JCw8NbmALHiezQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__pureZstrtabs_u147((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__cmhMldmnNRYydfu2BEkRCg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZstrtabs_u119)(tySequence__xv3aaFd3JCw8NbmALHiezQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__pureZstrtabs_u127(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__cmhMldmnNRYydfu2BEkRCg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__cmhMldmnNRYydfu2BEkRCg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__9aI6jznD9cwNqZ3317klA9bBQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__9aI6jznD9cwNqZ3317klA9bBQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__sPaDkVPSC0MkcoXCxPH9ccA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZstrtabs_u422)(tySequence__xv3aaFd3JCw8NbmALHiezQ* s_p0, NI len_p1) {
	shrink__pureZstrtabs_u127(s_p0, ((NI)0));
	setLen__pureZstrtabs_u119((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__xv3aaFd3JCw8NbmALHiezQ, newSeq__pureZstrtabs_u485)(NI len_p0) {
	tySequence__xv3aaFd3JCw8NbmALHiezQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__pureZstrtabs_u422((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, alignedAlloc0__system_u1961)(NI size_p0, NI align_p1) {
	void* result;
	result = alignedAlloc__system_u1915(size_p0, align_p1);
	zeroMem__system_u1739(result, size_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2) {
	void* result;
	result = (void*)0;
	{
		tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g* p_1;
		NI T5_;
		void* T6_;
		if (!(((NI)0) < cap_p0)) goto LA3_;
		T5_ = (NI)0;
		T5_ = align__system_u1639(((NI)8), elemAlign_p2);
		T6_ = (void*)0;
		T6_ = alignedAlloc0__system_u1961(((NI)(T5_ + (NI)(cap_p0 * elemSize_p1))), (elemAlign_p2));
		p_1 = ((tyObject_NimSeqPayloadBase__FmjJENcSYJdyKkcp3piq6g*) (T6_));
		(*p_1).cap = cap_p0;
		result = ((void*) (p_1));
	}
	goto LA1_;
LA3_: ;
	{
		result = NIM_NIL;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__lineinfos_u486)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* obj_p0) {
	eqdestroy___lineinfos_u502((&(*obj_p0)));
	eqwasMoved___lineinfos_u499(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__lineinfos_u428)(tySequence__7lEisrXlQEzwtUKW5pzRCw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__lineinfos_u486((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__zeIiXV75mf2Pfp9b3Cs5Wdg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__lineinfos_u432)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__lineinfos_u428(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__zeIiXV75mf2Pfp9b3Cs5Wdg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__zeIiXV75mf2Pfp9b3Cs5Wdg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Nsi2DL7cl1GFqRwjgk71Jw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Nsi2DL7cl1GFqRwjgk71Jw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__xYhUhS7X82rKTqbT9bRfCnw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lineinfos_u424)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI len_p1) {
	shrink__lineinfos_u428(s_p0, ((NI)0));
	setLen__lineinfos_u432((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZoserrors_u34)(NI32* dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__options_u1143)(tyTuple__QeWl6B6ffS4pU6WWrtcrDw* obj_p0) {
	eqdestroy___options_u1159((*obj_p0));
	eqwasMoved___options_u1156(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__options_u1085)(tySequence__4eRCaZmrYLLw2k30GPTiMw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__options_u1143((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__xYeauJM9bj9aY9caH55lM1nKA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u1089)(tySequence__4eRCaZmrYLLw2k30GPTiMw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__options_u1085(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__xYeauJM9bj9aY9caH55lM1nKA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__xYeauJM9bj9aY9caH55lM1nKA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__5OkmQTkiYc9cnv9bZqKK9c19bA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__5OkmQTkiYc9cnv9bZqKK9c19bA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__QeWl6B6ffS4pU6WWrtcrDw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__options_u1081)(tySequence__4eRCaZmrYLLw2k30GPTiMw* s_p0, NI len_p1) {
	shrink__options_u1085(s_p0, ((NI)0));
	setLen__options_u1089((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__options_u726)(tySequence__FGxE1Nuen6pVDc58PZudJw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__Qnm9a1W1Vp9akt9cDxi9ajFnSQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u730)(tySequence__FGxE1Nuen6pVDc58PZudJw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__options_u726(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Qnm9a1W1Vp9akt9cDxi9ajFnSQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Qnm9a1W1Vp9akt9cDxi9ajFnSQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__d4XM9c4jiz4O1hJ3ujtvgcw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__d4XM9c4jiz4O1hJ3ujtvgcw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__7xc1P89akJWzo77UAKrb3aA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__options_u722)(tySequence__FGxE1Nuen6pVDc58PZudJw* s_p0, NI len_p1) {
	shrink__options_u726(s_p0, ((NI)0));
	setLen__options_u730((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__system_u5464)(NimStringV2* obj_p0) {
	eqdestroy___system_u2691((*obj_p0));
	eqwasMoved___system_u2688(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__system_u5406)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__system_u5464((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__system_u5410)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__system_u5406(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__40TpIbQQfNQeMf0E9czzDBw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__40TpIbQQfNQeMf0E9czzDBw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1].len = 0; (*(*xu_1).p).data[i_1].p = NIM_NIL;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__system_u5402)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI len_p1) {
	shrink__system_u5406(s_p0, ((NI)0));
	setLen__system_u5410((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, at___pureZparseopt_u127)(NimStringV2* a_p0, NI a_p0Len_0) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ result;
	NI sz_1;
	result.len = 0; result.p = NIM_NIL;
	sz_1 = a_p0Len_0;
	newSeq__system_u5402((&result), (sz_1));
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(sz_1 - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA3;
				i_1 = ((NI) (res_1));
				eqcopy___system_u2694((&result.p->data[i_1]), a_p0[i_1]);
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	nimAsgnStrV2(((NimStringV2*) ((&result))), src_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, eqdup___system_u5515)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p0) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__system_u5410((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_] = eqdup___system_u2697(src_p0.p->data[colontmp_]);
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u5518)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___system_u5509((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, newSeq__stdZsyncio_u571)(NI len_p0) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__system_u5402((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___system_u2691((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__40TpIbQQfNQeMf0E9czzDBw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__40TpIbQQfNQeMf0E9czzDBw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8667)(NimStringV2 s_p0, NI first_p1) {
	NimStringV2 result;
	result = substr__system_u8654(s_p0, first_p1, (s_p0.len-1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, X5BX5D___pureZparseopt_u489)(NimStringV2* s_p0, NI s_p0Len_0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ result;
	NI a_1;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)((NI)(s_p0Len_0 - x_p1.b) - a_1) + ((NI)1));
	newSeq__system_u5402((&result), (L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				eqcopy___system_u2694((&result.p->data[i_1]), s_p0[(NI)(i_1 + a_1)]);
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringV2 s_p0) {
	NI result;
	NU h_1;
	h_1 = ((NU)0);
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(s_p0.len - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA3;
				i_1 = ((NI) (res_1));
				h_1 = (NU)((NU64)(h_1) + (NU64)(((NU) (((NU8)(s_p0.p->data[i_1]))))));
				h_1 = (NU)((NU64)(h_1) + (NU64)((NU)((NU64)(h_1) << (NU64)(((NI)10) & (64 - 1)))));
				h_1 = (NU)(h_1 ^ (NU)((NU64)(h_1) >> (NU64)(((NI)6) & (64 - 1))));
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	h_1 = (NU)((NU64)(h_1) + (NU64)((NU)((NU64)(h_1) << (NU64)(((NI)3) & (64 - 1)))));
	h_1 = (NU)(h_1 ^ (NU)((NU64)(h_1) >> (NU64)(((NI)11) & (64 - 1))));
	h_1 = (NU)((NU64)(h_1) + (NU64)((NU)((NU64)(h_1) << (NU64)(((NI)15) & (64 - 1)))));
	result = ((NI) (h_1));
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_u1563)(NimStringV2 x_p0, NimStringV2 y_p1) {
	NI result;
	NI minlen_1;
	int T1_;
	result = (NI)0;
	minlen_1 = ((x_p0.len <= y_p1.len) ? x_p0.len : y_p1.len);
	T1_ = (int)0;
	T1_ = nimCmpMem(((void*) (nimToCStringConv(x_p0))), ((void*) (nimToCStringConv(y_p1))), ((NI) (((size_t) (minlen_1)))));
	result = ((NI) (T1_));
	{
		if (!(result == ((NI)0))) goto LA4_;
		result = (NI)(x_p0.len - y_p1.len);
	}
LA4_: ;
	return result;
}
static N_INLINE(void, quit__system_u7978)(NI errorcode_p0) {
	{
		if (!(errorcode_p0 < ((NI)-128))) goto LA3_;
		exit(((int)-128));
	}
	goto LA1_;
LA3_: ;
	{
		if (!(((NI)127) < errorcode_p0)) goto LA6_;
		exit(((int)127));
	}
	goto LA1_;
LA6_: ;
	{
		exit(((int) (errorcode_p0)));
	}
LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, quit__system_u7997)(NimStringV2 errormsg_p0, NI errorcode_p1) {
	rawWrite(__stderrp, nimToCStringConv(errormsg_p0));
	rawWrite(__stderrp, "\012");
	quit__system_u7978(errorcode_p1);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stackTraceAvailable__system_u4038)(void) {
	NIM_BOOL result;
	result = NIM_FALSE;
	return result;
}
static N_INLINE(void, showErrorMessage2__system_u3611)(NimStringV2 data_p0) {
	showErrorMessage__system_u3603(nimToCStringConv(data_p0), data_p0.len);
}
N_LIB_PRIVATE N_NIMCALL(void, writeStackTrace__system_u2709)(void) {
	NimStringV2 s_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1.len = 0; s_1.p = NIM_NIL;
	s_1 = TM__Q5wkpxktOdTGvlSRo9bzt9aw_15;
	((tyProc__W6IXMh2CA4X1rFYGjUb4yg) (showErrorMessage2__system_u3611))(s_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__options_u1419)(NimStringV2* obj_p0) {
	eqdestroy___system_u2691((*obj_p0));
	eqwasMoved___system_u2688(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__options_u1399)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__options_u1419((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__XHO6qbtQL6Yo0q1oajKWkw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u1391)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__options_u1399(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__XHO6qbtQL6Yo0q1oajKWkw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__XHO6qbtQL6Yo0q1oajKWkw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__381WimpkqKVRiIr1lhxEQA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__381WimpkqKVRiIr1lhxEQA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1].len = 0; (*(*xu_1).p).data[i_1].p = NIM_NIL;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, insert__nimblecmd_u51)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 item_p1, NI i_p2) {
	NI xlX60gensym2__1;
	NI T1_;
	NI jX60gensym2__1;
	T1_ = (*x_p0).len;
	xlX60gensym2__1 = T1_;
	setLen__options_u1391((&(*x_p0)), ((NI)(xlX60gensym2__1 + ((NI)1))));
	jX60gensym2__1 = (NI)(xlX60gensym2__1 - ((NI)1));
	{
		while (1) {
			NimStringV2 T4_;
			if (!(i_p2 <= jX60gensym2__1)) goto LA3;
			T4_.len = 0; T4_.p = NIM_NIL;
			T4_ = (*x_p0).p->data[jX60gensym2__1];
			eqwasMoved___system_u2688((&(*x_p0).p->data[jX60gensym2__1]));
			eqsink___system_u2700((&(*x_p0).p->data[(NI)(jX60gensym2__1 + ((NI)1))]), T4_);
			jX60gensym2__1 -= ((NI)1);
		} LA3: ;
	}
	eqsink___system_u2700((&(*x_p0).p->data[i_p2]), item_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__nimblecmd_u612)(tyTuple__9cdgeqdY7FRioNKBoD6G66A* obj_p0) {
	eqdestroy___nimblecmd_u629((&(*obj_p0)));
	eqwasMoved___nimblecmd_u626(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nimblecmd_u592)(tySequence__6j25whH7XTBoIXcM0x1T7A* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__nimblecmd_u612((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__mvS7yZmzkLtB9bhcvc9atD6A*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nimblecmd_u585)(tySequence__6j25whH7XTBoIXcM0x1T7A* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nimblecmd_u592(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__mvS7yZmzkLtB9bhcvc9atD6A* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__mvS7yZmzkLtB9bhcvc9atD6A*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__bjUrAWkgJv530yQxlKTwkg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)56), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__bjUrAWkgJv530yQxlKTwkg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__9cdgeqdY7FRioNKBoD6G66A));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nimblecmd_u898)(tySequence__6j25whH7XTBoIXcM0x1T7A* s_p0, NI len_p1) {
	shrink__nimblecmd_u592(s_p0, ((NI)0));
	setLen__nimblecmd_u585((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u5506)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, delete__nimblecmd_u2281)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI i_p1) {
	NI xlX60gensym51__1;
	NI T12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg* T7_;
		NimStringV2 T8_;
		NI T9_;
		T3_ = ((*x_p0).len-1);
		if (!(T3_ < i_p1)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T7_ = NIM_NIL;
		T7_ = (tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg*) nimNewObj(sizeof(tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg), NIM_ALIGNOF(tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg));
		(*T7_).Sup.Sup.Sup.m_type = (&NTIv2__9cIOj9cQBZH8lEZvCihI6Eyg_);
		(*T7_).Sup.Sup.name = "IndexDefect";
		T8_.len = 0; T8_.p = NIM_NIL;
		colontmpD_ = dollar___systemZdollars_u9(i_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T9_ = (*x_p0).len;
		colontmpD__2 = dollar___systemZdollars_u9(T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T8_ = rawNewString(colontmpD_.len + colontmpD__2.len + 35);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_17);
appendString((&T8_), colontmpD_);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_19);
appendString((&T8_), colontmpD__2);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_21);
		(*T7_).Sup.Sup.message = T8_;
		raiseExceptionEx((Exception*)T7_, "IndexDefect", "delete", "system.nim", 2127);
goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T12_ = (*x_p0).len;
	xlX60gensym51__1 = T12_;
	{
		NI jX60gensym51__1;
		NI colontmp_;
		NI res_1;
		jX60gensym51__1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(xlX60gensym51__1 - ((NI)2));
		res_1 = i_p1;
		{
			while (1) {
				NimStringV2 T16_;
				if (!(res_1 <= colontmp_)) goto LA15;
				jX60gensym51__1 = ((NI) (res_1));
				T16_.len = 0; T16_.p = NIM_NIL;
				T16_ = (*x_p0).p->data[(NI)(jX60gensym51__1 + ((NI)1))];
				eqwasMoved___system_u2688((&(*x_p0).p->data[(NI)(jX60gensym51__1 + ((NI)1))]));
				eqsink___system_u2700((&(*x_p0).p->data[jX60gensym51__1]), T16_);
				res_1 += ((NI)1);
			} LA15: ;
		}
	}
	setLen__options_u1391((&(*x_p0)), ((NI)(xlX60gensym51__1 - ((NI)1))));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___OOZdistZchecksumsZsrcZchecksumsZsha1_u981)(tyArray__9amPDC9cslxc3W1WNI8aK5gA x_p0, tyArray__9amPDC9cslxc3W1WNI8aK5gA y_p1) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI f_1;
		NI res_1;
		f_1 = (NI)0;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= ((NI)19))) goto LA3;
				f_1 = ((NI) (res_1));
				{
					if (!!((x_p0[(f_1)- 0] == y_p1[(f_1)- 0]))) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__extccomp_u941)(tySequence__xOJ2kx2lq9bBfIm3IXnde3Q* x_p0, tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__pqlDFC3CU9b7yhxYpu5zLhQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__pqlDFC3CU9b7yhxYpu5zLhQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Z5RrQYPm1Yz8sqF7utTx7Q*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)72), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__Z5RrQYPm1Yz8sqF7utTx7Q*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, insert__extccomp_u980)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 item_p1, NI i_p2) {
	NI xlX60gensym24__1;
	NI T1_;
	NI jX60gensym24__1;
	T1_ = (*x_p0).len;
	xlX60gensym24__1 = T1_;
	setLen__system_u5410((&(*x_p0)), ((NI)(xlX60gensym24__1 + ((NI)1))));
	jX60gensym24__1 = (NI)(xlX60gensym24__1 - ((NI)1));
	{
		while (1) {
			NimStringV2 T4_;
			if (!(i_p2 <= jX60gensym24__1)) goto LA3;
			T4_.len = 0; T4_.p = NIM_NIL;
			T4_ = (*x_p0).p->data[jX60gensym24__1];
			eqwasMoved___system_u2688((&(*x_p0).p->data[jX60gensym24__1]));
			eqsink___system_u2700((&(*x_p0).p->data[(NI)(jX60gensym24__1 + ((NI)1))]), T4_);
			jX60gensym24__1 -= ((NI)1);
		} LA3: ;
	}
	eqsink___system_u2700((&(*x_p0).p->data[i_p2]), item_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__commands_u1640)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__XHO6qbtQL6Yo0q1oajKWkw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__XHO6qbtQL6Yo0q1oajKWkw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__381WimpkqKVRiIr1lhxEQA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__381WimpkqKVRiIr1lhxEQA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
static N_INLINE(void, addEscapedChar__system_u8294)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	switch (((NU8)(c_p1))) {
	case 7:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_25);
	}
	break;
	case 8:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_27);
	}
	break;
	case 9:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_29);
	}
	break;
	case 10:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_31);
	}
	break;
	case 11:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_33);
	}
	break;
	case 12:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_35);
	}
	break;
	case 13:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_37);
	}
	break;
	case 27:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_39);
	}
	break;
	case 92:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_41);
	}
	break;
	case 39:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_43);
	}
	break;
	case 34:
	{
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_45);
	}
	break;
	case 32 ... 33:
	case 35 ... 38:
	case 40 ... 91:
	case 93 ... 126:
	{
		nimAddCharV1((&(*s_p0)), c_p1);
	}
	break;
	default:
	{
		NI n_1;
		prepareAdd((&(*s_p0)), 2);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_47);
		n_1 = ((NU8)(c_p1));
		nimAddCharV1((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_49.p->data[(NI)((NI64)((NI)(n_1 & ((NI)240))) >> (NU64)(((NI)4) & (64 - 1)))]);
		nimAddCharV1((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_50.p->data[(NI)(n_1 & ((NI)15))]);
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZprivateZoscommon_u120)(NimStringV2* s_p0, NimStringV2 x_p1) {
	prepareAdd((&(*s_p0)), 1);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_23);
	{
		NIM_CHAR c_1;
		NI i_1;
		NI L_1;
		c_1 = (NIM_CHAR)0;
		i_1 = ((NI)0);
		L_1 = x_p1.len;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA3;
				c_1 = x_p1.p->data[i_1];
				{
					if (!((NU8)(c_1) <= (NU8)(127))) goto LA6_;
					addEscapedChar__system_u8294(s_p0, c_1);
				}
				goto LA4_;
LA6_: ;
				{
					nimAddCharV1((&(*s_p0)), c_1);
				}
LA4_: ;
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	prepareAdd((&(*s_p0)), 1);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_51);
}
N_LIB_PRIVATE N_NIMCALL(void, add__msgs_u342)(tySequence__hTEiKNj3evQAjIXUI21elA* x_p0, tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__QnANZjr9bbFykJmClmY2b9cQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__QnANZjr9bbFykJmClmY2b9cQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ccVYQQMwnFZX6sMceS6iUw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)136), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__ccVYQQMwnFZX6sMceS6iUw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3130(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13327)(tySequence__kHjIdgrpmuSn9cUIIKpSiDg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___ast_u4848(dest_p0.p->data[colontmp_].Field0);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field1)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__CvjVmQeIfivirDme2r5MRw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u16091)(tySequence__48JTohSgTy339bRxHzUD8KA dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NI32));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZiclineinfos_u369)(tySequence__orxtl6CusdjXleqrxi67gw dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__MaWaKZwaGUqCXKsSK12rVg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8253)(tySequence__IHUFRsFxZNv7YydiUO2esQ dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NI64));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u9558)(tySequence__YYy1721YAuPF0ajBYHd8Wg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__qPXRCRNQuZLLKto7CIIEzw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u10155)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__TRK7rrwoha9bbDAdPWsqJMw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u9945)(tySequence__F1qNdU7m0Czu7Y2q0eksXw dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__6kG8KAxm9aXPdLdlxcxqJJw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u9762)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___icZic_u3941(dest_p0.p->data[colontmp_].concreteTypes);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8792)(tySequence__48JTohSgTy339bRxHzUD8KA dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NI32));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8420)(tySequence__b89aLriiJnVTD186H6zNIgg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8606)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__7rmdAMLZ8fDd79brQn2ixZA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZpacked95ast_u123)(tySequence__OxRbUT0qZaZN5UjnqQjGPA dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u8071)(tySequence__PXIzfWocnrafGz5p3CP5LA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__0q9cmhneJEKnQERTpXXdz6Q));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13228)(tySequence__TfHJycarvNts8E4mVG4Mfg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].uniqueName);
			eqdestroy___ast_u4848(dest_p0.p->data[colontmp_].interfHidden.data);
			eqdestroy___ast_u4848(dest_p0.p->data[colontmp_].interf.data);
			eqdestroy___modulegraphs_u2823(dest_p0.p->data[colontmp_].pureEnums);
			eqdestroy___modulegraphs_u2823(dest_p0.p->data[colontmp_].patterns);
			eqdestroy___modulegraphs_u2823(dest_p0.p->data[colontmp_].converters);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].module);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].module)));
				nimRawDispose(dest_p0.p->data[colontmp_].module, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow));
}
}
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u4752)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___ast_u4574((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u4571(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u4732)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__ast_u4752(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__leUMr6KkmlAoo48M8CioZQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u4725)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__ast_u4732(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__leUMr6KkmlAoo48M8CioZQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__leUMr6KkmlAoo48M8CioZQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ItQROW58gGeBOtCRbSJrPQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__ItQROW58gGeBOtCRbSJrPQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u6323)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0, NI len_p1) {
	shrink__ast_u4732(s_p0, ((NI)0));
	setLen__ast_u4725((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u11293)(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q* obj_p0) {
	eqdestroy___modulegraphs_u11309((&(*obj_p0)));
	eqwasMoved___modulegraphs_u11306(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u11235)(tySequence__fdmz6VkIf1ewwrssKYqRFg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u11293((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__q9boMy8mhBOdkslxyrVM05g*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u11239)(tySequence__fdmz6VkIf1ewwrssKYqRFg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u11235(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__q9boMy8mhBOdkslxyrVM05g* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__q9boMy8mhBOdkslxyrVM05g*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__QsnCmrZp2km9cIOMZJvKjNg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__QsnCmrZp2km9cIOMZJvKjNg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u11231)(tySequence__fdmz6VkIf1ewwrssKYqRFg* s_p0, NI len_p1) {
	shrink__modulegraphs_u11235(s_p0, ((NI)0));
	setLen__modulegraphs_u11239((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u13237)(tySequence__TfHJycarvNts8E4mVG4Mfg* dest_p0, tySequence__TfHJycarvNts8E4mVG4Mfg src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___modulegraphs_u13228((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u16100)(tySequence__48JTohSgTy339bRxHzUD8KA* dest_p0, tySequence__48JTohSgTy339bRxHzUD8KA src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u16091((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u11451)(tySequence__kxu4GK0onha2t9bo86mdVAg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__XeVWWFuLkzmWdnv6Nxpo5w*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u11455)(tySequence__kxu4GK0onha2t9bo86mdVAg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u11451(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__XeVWWFuLkzmWdnv6Nxpo5w* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__XeVWWFuLkzmWdnv6Nxpo5w*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__aRseLOMn9c4JoSRmriNiugw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__aRseLOMn9c4JoSRmriNiugw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u11447)(tySequence__kxu4GK0onha2t9bo86mdVAg* s_p0, NI len_p1) {
	shrink__modulegraphs_u11451(s_p0, ((NI)0));
	setLen__modulegraphs_u11455((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__suggestsymdb_u1508)(tyTuple__tG5yYi8DnD7bl00aT9cgctQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___suggestsymdb_u1524((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___suggestsymdb_u1521(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__suggestsymdb_u1451)(tySequence__fz0REU1l0nYmKHXgMLRrIg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__suggestsymdb_u1508((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__tfNVrEviQRylDgr69bIF2PQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__suggestsymdb_u1455)(tySequence__fz0REU1l0nYmKHXgMLRrIg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__suggestsymdb_u1451(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__tfNVrEviQRylDgr69bIF2PQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__tfNVrEviQRylDgr69bIF2PQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__y7oTNlyedm3Ce07Nr9cIzyg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)1056), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__y7oTNlyedm3Ce07Nr9cIzyg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__tG5yYi8DnD7bl00aT9cgctQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__suggestsymdb_u1447)(tySequence__fz0REU1l0nYmKHXgMLRrIg* s_p0, NI len_p1) {
	shrink__suggestsymdb_u1451(s_p0, ((NI)0));
	setLen__suggestsymdb_u1455((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u11725)(tyTuple__gnRkA1L4XiR4uByriyHW8Q* obj_p0) {
	eqdestroy___modulegraphs_u11741((&(*obj_p0)));
	eqwasMoved___modulegraphs_u11738(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u11667)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u11725((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__1l823tnWpfUy9cANEEejxPg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u11671)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u11667(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__1l823tnWpfUy9cANEEejxPg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__1l823tnWpfUy9cANEEejxPg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__dJ2CxradV9adiIXkmHsG8Lw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__dJ2CxradV9adiIXkmHsG8Lw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__gnRkA1L4XiR4uByriyHW8Q));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u11663)(tySequence__Ip9aV1IKO2gVdheNOM31DCQ* s_p0, NI len_p1) {
	shrink__modulegraphs_u11667(s_p0, ((NI)0));
	setLen__modulegraphs_u11671((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u13336)(tySequence__kHjIdgrpmuSn9cUIIKpSiDg* dest_p0, tySequence__kHjIdgrpmuSn9cUIIKpSiDg src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___modulegraphs_u13327((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u12169)(tyTuple__OtlgAx3kBps9cOSMNDZSzBA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u12185((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u12182(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u12111)(tySequence__R9c39btP6BwOBBPnbaNUtMQg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u12169((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__4gA28oBPgxAGhj7tXEiiqw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u12115)(tySequence__R9c39btP6BwOBBPnbaNUtMQg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u12111(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__4gA28oBPgxAGhj7tXEiiqw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__4gA28oBPgxAGhj7tXEiiqw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__08bsLIc9cknpzwJFrHSsc0w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__08bsLIc9cknpzwJFrHSsc0w*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__OtlgAx3kBps9cOSMNDZSzBA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u12107)(tySequence__R9c39btP6BwOBBPnbaNUtMQg* s_p0, NI len_p1) {
	shrink__modulegraphs_u12111(s_p0, ((NI)0));
	setLen__modulegraphs_u12115((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u12386)(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg* obj_p0) {
	eqdestroy___modulegraphs_u12402((&(*obj_p0)));
	eqwasMoved___modulegraphs_u12399(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u12328)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u12386((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__OH9acz2AtycIlvWRolvoaNA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u12332)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u12328(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__OH9acz2AtycIlvWRolvoaNA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__OH9acz2AtycIlvWRolvoaNA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__lLVTTXn5ZKYsl9afpAy9ce4Q*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__lLVTTXn5ZKYsl9afpAy9ce4Q*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__F3gkSrMB1qp2Tvf9bixVXwg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u12324)(tySequence__squ9b9bUH4OLHf6cEMrt6hVA* s_p0, NI len_p1) {
	shrink__modulegraphs_u12328(s_p0, ((NI)0));
	setLen__modulegraphs_u12332((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u12596)(tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u12612((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u12609(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u12538)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u12596((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__6bctsNj71c7TwckMfJfb1g*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u12542)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u12538(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__6bctsNj71c7TwckMfJfb1g* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__6bctsNj71c7TwckMfJfb1g*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__oE6qyrap71jgxNstzHAiQg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__oE6qyrap71jgxNstzHAiQg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u12534)(tySequence__3nALyQgqjnfK2Qjc6ny2Uw* s_p0, NI len_p1) {
	shrink__modulegraphs_u12538(s_p0, ((NI)0));
	setLen__modulegraphs_u12542((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u12920)(tyTuple__XrHNJHOzS3O7uwF9bvCySiA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u12936((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u12933(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u12862)(tySequence__vJcM7B74R2U5db9cxyXT9coA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u12920((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__c5hiGWTVLb0fIV9ae8w57Gw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u12866)(tySequence__vJcM7B74R2U5db9cxyXT9coA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u12862(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__c5hiGWTVLb0fIV9ae8w57Gw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__c5hiGWTVLb0fIV9ae8w57Gw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__aT4qJZQM9a6l4F5vjtFSZGQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__aT4qJZQM9a6l4F5vjtFSZGQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__XrHNJHOzS3O7uwF9bvCySiA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u12858)(tySequence__vJcM7B74R2U5db9cxyXT9coA* s_p0, NI len_p1) {
	shrink__modulegraphs_u12862(s_p0, ((NI)0));
	setLen__modulegraphs_u12866((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u13078)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__UVjWwOjJEIduaGR0AD4jzw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u13082)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u13078(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__UVjWwOjJEIduaGR0AD4jzw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__UVjWwOjJEIduaGR0AD4jzw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__VRA8y5gOokZiYlpeofrQBQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__VRA8y5gOokZiYlpeofrQBQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__EdLY4EJQ37VFgbAn5g5rXQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u13074)(tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg* s_p0, NI len_p1) {
	shrink__modulegraphs_u13078(s_p0, ((NI)0));
	setLen__modulegraphs_u13082((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u4392)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___idents_u155((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___idents_u152(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u8095)(NI dest_p0) {
}
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u2522)(NI* obj_p0) {
	eqdestroy___system_u8095((*obj_p0));
	eqwasMoved___system_u8091(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u2943)(tyTuple__Oubp8LPEu86EPyDuc56AXg* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___ast_u2959((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u2956(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u2885)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__ast_u2943((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__Wzp3Ap879aFVENQEF8Qbb0A*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u2889)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__ast_u2885(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Wzp3Ap879aFVENQEF8Qbb0A* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Wzp3Ap879aFVENQEF8Qbb0A*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Q9aTbDF780mmiKgw1sfNbag*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Q9aTbDF780mmiKgw1sfNbag*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__Oubp8LPEu86EPyDuc56AXg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u2881)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw* s_p0, NI len_p1) {
	shrink__ast_u2885(s_p0, ((NI)0));
	setLen__ast_u2889((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__lexer_u1922)(tyObject_Token__pst9a89bCqNyggpo6gRF7jhA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___lexer_u526((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___lexer_u523(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimCharToStr)(NIM_CHAR x_p0) {
	NimStringV2 result;
	result = mnewString(((NI)1));
	nimPrepareStrMutationV2((&result));
	result.p->data[((NI)0)] = x_p0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, nimParseBiggestFloat)(NIM_CHAR* s_p0, NI s_p0Len_0, NF* number_p1) {
	NI result;
	NI i_1;
	NF sign_1;
	NI kdigits_1;
	NI fdigits_1;
	NI exponent_1;
	NU64 integer_1;
	NI fracExponent_1;
	NI expSign_1;
	NI firstDigit_1;
	NIM_BOOL hasSign_1;
	NI realExponent_1;
	NIM_BOOL expNegative_1;
	NI absExponent_1;
	NI digits_1;
	tyArray__zO5aBDTeiBNbpfX9cEBgeLA t_1;
	NI ti_1;
	NI maxlen_1;
	NI endPos_1;
	NIM_CHAR T210_;
{	i_1 = ((NI)0);
	sign_1 = 1.0;
	kdigits_1 = ((NI)0);
	fdigits_1 = ((NI)0);
	exponent_1 = ((NI)0);
	integer_1 = 0ULL;
	fracExponent_1 = ((NI)0);
	expSign_1 = ((NI)1);
	firstDigit_1 = ((NI)-1);
	hasSign_1 = NIM_FALSE;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = (i_1 < s_p0Len_0);
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((NU8)(s_p0[i_1]) == (NU8)(43));
		if (T5_) goto LA6_;
		T5_ = ((NU8)(s_p0[i_1]) == (NU8)(45));
LA6_: ;
		T3_ = T5_;
LA4_: ;
		if (!T3_) goto LA7_;
		hasSign_1 = NIM_TRUE;
		{
			if (!((NU8)(s_p0[i_1]) == (NU8)(45))) goto LA11_;
			sign_1 = -1.0;
		}
LA11_: ;
		i_1 += ((NI)1);
	}
LA7_: ;
	{
		NIM_BOOL T15_;
		NIM_BOOL T17_;
		T15_ = (NIM_BOOL)0;
		T15_ = ((NI)(i_1 + ((NI)2)) < s_p0Len_0);
		if (!(T15_)) goto LA16_;
		T17_ = (NIM_BOOL)0;
		T17_ = ((NU8)(s_p0[i_1]) == (NU8)(78));
		if (T17_) goto LA18_;
		T17_ = ((NU8)(s_p0[i_1]) == (NU8)(110));
LA18_: ;
		T15_ = T17_;
LA16_: ;
		if (!T15_) goto LA19_;
		{
			NIM_BOOL T23_;
			T23_ = (NIM_BOOL)0;
			T23_ = ((NU8)(s_p0[(NI)(i_1 + ((NI)1))]) == (NU8)(65));
			if (T23_) goto LA24_;
			T23_ = ((NU8)(s_p0[(NI)(i_1 + ((NI)1))]) == (NU8)(97));
LA24_: ;
			if (!T23_) goto LA25_;
			{
				NIM_BOOL T29_;
				T29_ = (NIM_BOOL)0;
				T29_ = ((NU8)(s_p0[(NI)(i_1 + ((NI)2))]) == (NU8)(78));
				if (T29_) goto LA30_;
				T29_ = ((NU8)(s_p0[(NI)(i_1 + ((NI)2))]) == (NU8)(110));
LA30_: ;
				if (!T29_) goto LA31_;
				{
					NIM_BOOL T35_;
					NF T39_;
					T35_ = (NIM_BOOL)0;
					T35_ = (s_p0Len_0 <= (NI)(i_1 + ((NI)3)));
					if (T35_) goto LA36_;
					T35_ = !((((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) >= ((NU8)(97)) && ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) <= ((NU8)(122)) || ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) >= ((NU8)(65)) && ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) <= ((NU8)(90)) || ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) >= ((NU8)(48)) && ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) <= ((NU8)(57)) || ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) == ((NU8)(95))));
LA36_: ;
					if (!T35_) goto LA37_;
					T39_ = (NF)0;
					{
						if (!(sign_1 < 0.0)) goto LA42_;
						(*number_p1) = -NAN;
					}
					goto LA40_;
LA42_: ;
					{
						(*number_p1) = NAN;
					}
LA40_: ;
					result = (NI)(i_1 + ((NI)3));
					goto BeforeRet_;
				}
LA37_: ;
			}
LA31_: ;
		}
LA25_: ;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA19_: ;
	{
		NIM_BOOL T47_;
		NIM_BOOL T49_;
		T47_ = (NIM_BOOL)0;
		T47_ = ((NI)(i_1 + ((NI)2)) < s_p0Len_0);
		if (!(T47_)) goto LA48_;
		T49_ = (NIM_BOOL)0;
		T49_ = ((NU8)(s_p0[i_1]) == (NU8)(73));
		if (T49_) goto LA50_;
		T49_ = ((NU8)(s_p0[i_1]) == (NU8)(105));
LA50_: ;
		T47_ = T49_;
LA48_: ;
		if (!T47_) goto LA51_;
		{
			NIM_BOOL T55_;
			T55_ = (NIM_BOOL)0;
			T55_ = ((NU8)(s_p0[(NI)(i_1 + ((NI)1))]) == (NU8)(78));
			if (T55_) goto LA56_;
			T55_ = ((NU8)(s_p0[(NI)(i_1 + ((NI)1))]) == (NU8)(110));
LA56_: ;
			if (!T55_) goto LA57_;
			{
				NIM_BOOL T61_;
				T61_ = (NIM_BOOL)0;
				T61_ = ((NU8)(s_p0[(NI)(i_1 + ((NI)2))]) == (NU8)(70));
				if (T61_) goto LA62_;
				T61_ = ((NU8)(s_p0[(NI)(i_1 + ((NI)2))]) == (NU8)(102));
LA62_: ;
				if (!T61_) goto LA63_;
				{
					NIM_BOOL T67_;
					T67_ = (NIM_BOOL)0;
					T67_ = (s_p0Len_0 <= (NI)(i_1 + ((NI)3)));
					if (T67_) goto LA68_;
					T67_ = !((((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) >= ((NU8)(97)) && ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) <= ((NU8)(122)) || ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) >= ((NU8)(65)) && ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) <= ((NU8)(90)) || ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) >= ((NU8)(48)) && ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) <= ((NU8)(57)) || ((NU8)(s_p0[(NI)(i_1 + ((NI)3))])) == ((NU8)(95))));
LA68_: ;
					if (!T67_) goto LA69_;
					(*number_p1) = ((NF)(INF) * (NF)(sign_1));
					result = (NI)(i_1 + ((NI)3));
					goto BeforeRet_;
				}
LA69_: ;
			}
LA63_: ;
		}
LA57_: ;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA51_: ;
	{
		NIM_BOOL T73_;
		T73_ = (NIM_BOOL)0;
		T73_ = (i_1 < s_p0Len_0);
		if (!(T73_)) goto LA74_;
		T73_ = (((NU8)(s_p0[i_1])) >= ((NU8)(48)) && ((NU8)(s_p0[i_1])) <= ((NU8)(57)));
LA74_: ;
		if (!T73_) goto LA75_;
		firstDigit_1 = (NI)(((NU8)(s_p0[i_1])) - ((NI)48));
	}
LA75_: ;
	{
		while (1) {
			NIM_BOOL T79_;
			T79_ = (NIM_BOOL)0;
			T79_ = (i_1 < s_p0Len_0);
			if (!(T79_)) goto LA80_;
			T79_ = (((NU8)(s_p0[i_1])) >= ((NU8)(48)) && ((NU8)(s_p0[i_1])) <= ((NU8)(57)));
LA80_: ;
			if (!T79_) goto LA78;
			kdigits_1 += ((NI)1);
			integer_1 = (NU64)((NU64)((NU64)((NU64)(integer_1) * (NU64)(10ULL))) + (NU64)(((NU64) ((NI)(((NU8)(s_p0[i_1])) - ((NI)48))))));
			i_1 += ((NI)1);
			{
				while (1) {
					NIM_BOOL T83_;
					T83_ = (NIM_BOOL)0;
					T83_ = (i_1 < s_p0Len_0);
					if (!(T83_)) goto LA84_;
					T83_ = ((NU8)(s_p0[i_1]) == (NU8)(95));
LA84_: ;
					if (!T83_) goto LA82;
					i_1 += ((NI)1);
				} LA82: ;
			}
		} LA78: ;
	}
	{
		NIM_BOOL T87_;
		T87_ = (NIM_BOOL)0;
		T87_ = (i_1 < s_p0Len_0);
		if (!(T87_)) goto LA88_;
		T87_ = ((NU8)(s_p0[i_1]) == (NU8)(46));
LA88_: ;
		if (!T87_) goto LA89_;
		i_1 += ((NI)1);
		{
			if (!(kdigits_1 <= ((NI)0))) goto LA93_;
			{
				while (1) {
					NIM_BOOL T97_;
					T97_ = (NIM_BOOL)0;
					T97_ = (i_1 < s_p0Len_0);
					if (!(T97_)) goto LA98_;
					T97_ = ((NU8)(s_p0[i_1]) == (NU8)(48));
LA98_: ;
					if (!T97_) goto LA96;
					fracExponent_1 += ((NI)1);
					i_1 += ((NI)1);
					{
						while (1) {
							NIM_BOOL T101_;
							T101_ = (NIM_BOOL)0;
							T101_ = (i_1 < s_p0Len_0);
							if (!(T101_)) goto LA102_;
							T101_ = ((NU8)(s_p0[i_1]) == (NU8)(95));
LA102_: ;
							if (!T101_) goto LA100;
							i_1 += ((NI)1);
						} LA100: ;
					}
				} LA96: ;
			}
		}
LA93_: ;
		{
			NIM_BOOL T105_;
			NIM_BOOL T106_;
			T105_ = (NIM_BOOL)0;
			T106_ = (NIM_BOOL)0;
			T106_ = (firstDigit_1 == ((NI)-1));
			if (!(T106_)) goto LA107_;
			T106_ = (i_1 < s_p0Len_0);
LA107_: ;
			T105_ = T106_;
			if (!(T105_)) goto LA108_;
			T105_ = (((NU8)(s_p0[i_1])) >= ((NU8)(48)) && ((NU8)(s_p0[i_1])) <= ((NU8)(57)));
LA108_: ;
			if (!T105_) goto LA109_;
			firstDigit_1 = (NI)(((NU8)(s_p0[i_1])) - ((NI)48));
		}
LA109_: ;
		{
			while (1) {
				NIM_BOOL T113_;
				T113_ = (NIM_BOOL)0;
				T113_ = (i_1 < s_p0Len_0);
				if (!(T113_)) goto LA114_;
				T113_ = (((NU8)(s_p0[i_1])) >= ((NU8)(48)) && ((NU8)(s_p0[i_1])) <= ((NU8)(57)));
LA114_: ;
				if (!T113_) goto LA112;
				fdigits_1 += ((NI)1);
				fracExponent_1 += ((NI)1);
				integer_1 = (NU64)((NU64)((NU64)((NU64)(integer_1) * (NU64)(10ULL))) + (NU64)(((NU64) ((NI)(((NU8)(s_p0[i_1])) - ((NI)48))))));
				i_1 += ((NI)1);
				{
					while (1) {
						NIM_BOOL T117_;
						T117_ = (NIM_BOOL)0;
						T117_ = (i_1 < s_p0Len_0);
						if (!(T117_)) goto LA118_;
						T117_ = ((NU8)(s_p0[i_1]) == (NU8)(95));
LA118_: ;
						if (!T117_) goto LA116;
						i_1 += ((NI)1);
					} LA116: ;
				}
			} LA112: ;
		}
	}
LA89_: ;
	{
		NIM_BOOL T121_;
		NIM_BOOL T123_;
		NIM_BOOL T125_;
		T121_ = (NIM_BOOL)0;
		T121_ = ((NI)(kdigits_1 + fdigits_1) <= ((NI)0));
		if (!(T121_)) goto LA122_;
		T123_ = (NIM_BOOL)0;
		T123_ = (i_1 == ((NI)0));
		if (T123_) goto LA124_;
		T125_ = (NIM_BOOL)0;
		T125_ = (i_1 == ((NI)1));
		if (!(T125_)) goto LA126_;
		T125_ = hasSign_1;
LA126_: ;
		T123_ = T125_;
LA124_: ;
		T121_ = T123_;
LA122_: ;
		if (!T121_) goto LA127_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA127_: ;
	{
		NIM_BOOL T131_;
		T131_ = (NIM_BOOL)0;
		T131_ = ((NI)(i_1 + ((NI)1)) < s_p0Len_0);
		if (!(T131_)) goto LA132_;
		T131_ = (((NU8)(s_p0[i_1])) == ((NU8)(101)) || ((NU8)(s_p0[i_1])) == ((NU8)(69)));
LA132_: ;
		if (!T131_) goto LA133_;
		i_1 += ((NI)1);
		{
			NIM_BOOL T137_;
			T137_ = (NIM_BOOL)0;
			T137_ = ((NU8)(s_p0[i_1]) == (NU8)(43));
			if (T137_) goto LA138_;
			T137_ = ((NU8)(s_p0[i_1]) == (NU8)(45));
LA138_: ;
			if (!T137_) goto LA139_;
			{
				if (!((NU8)(s_p0[i_1]) == (NU8)(45))) goto LA143_;
				expSign_1 = ((NI)-1);
			}
LA143_: ;
			i_1 += ((NI)1);
		}
LA139_: ;
		{
			if (!!((((NU8)(s_p0[i_1])) >= ((NU8)(48)) && ((NU8)(s_p0[i_1])) <= ((NU8)(57))))) goto LA147_;
			result = ((NI)0);
			goto BeforeRet_;
		}
LA147_: ;
		{
			while (1) {
				NIM_BOOL T151_;
				T151_ = (NIM_BOOL)0;
				T151_ = (i_1 < s_p0Len_0);
				if (!(T151_)) goto LA152_;
				T151_ = (((NU8)(s_p0[i_1])) >= ((NU8)(48)) && ((NU8)(s_p0[i_1])) <= ((NU8)(57)));
LA152_: ;
				if (!T151_) goto LA150;
				exponent_1 = (NI)((NI)(exponent_1 * ((NI)10)) + (NI)(((NU8)(s_p0[i_1])) - ((NI)48)));
				i_1 += ((NI)1);
				{
					while (1) {
						NIM_BOOL T155_;
						T155_ = (NIM_BOOL)0;
						T155_ = (i_1 < s_p0Len_0);
						if (!(T155_)) goto LA156_;
						T155_ = ((NU8)(s_p0[i_1]) == (NU8)(95));
LA156_: ;
						if (!T155_) goto LA154;
						i_1 += ((NI)1);
					} LA154: ;
				}
			} LA150: ;
		}
	}
LA133_: ;
	realExponent_1 = (NI)((NI)(expSign_1 * exponent_1) - fracExponent_1);
	expNegative_1 = (realExponent_1 < ((NI)0));
	absExponent_1 = (realExponent_1 > 0? (realExponent_1) : -(realExponent_1));
	{
		if (!(((NI)999) < absExponent_1)) goto LA159_;
		{
			if (!(integer_1 == 0ULL)) goto LA163_;
			(*number_p1) = 0.0;
		}
		goto LA161_;
LA163_: ;
		{
			if (!expNegative_1) goto LA166_;
			(*number_p1) = ((NF)(0.0) * (NF)(sign_1));
		}
		goto LA161_;
LA166_: ;
		{
			(*number_p1) = ((NF)(INF) * (NF)(sign_1));
		}
LA161_: ;
		result = i_1;
		goto BeforeRet_;
	}
LA159_: ;
	digits_1 = (NI)(kdigits_1 + fdigits_1);
	{
		NIM_BOOL T171_;
		NIM_BOOL T173_;
		NI slop_1;
		T171_ = (NIM_BOOL)0;
		T171_ = (digits_1 <= ((NI)15));
		if (T171_) goto LA172_;
		T173_ = (NIM_BOOL)0;
		T173_ = (digits_1 <= ((NI)16));
		if (!(T173_)) goto LA174_;
		T173_ = (firstDigit_1 <= ((NI)8));
LA174_: ;
		T171_ = T173_;
LA172_: ;
		if (!T171_) goto LA175_;
		{
			if (!(absExponent_1 <= ((NI)22))) goto LA179_;
			{
				if (!expNegative_1) goto LA183_;
				(*number_p1) = ((NF)(((NF)(sign_1) * (NF)(((NF) (integer_1))))) / (NF)(powtens__system_u7337[(absExponent_1)- 0]));
			}
			goto LA181_;
LA183_: ;
			{
				(*number_p1) = ((NF)(((NF)(sign_1) * (NF)(((NF) (integer_1))))) * (NF)(powtens__system_u7337[(absExponent_1)- 0]));
			}
LA181_: ;
			result = i_1;
			goto BeforeRet_;
		}
LA179_: ;
		slop_1 = (NI)((NI)(((NI)15) - kdigits_1) - fdigits_1);
		{
			NIM_BOOL T188_;
			T188_ = (NIM_BOOL)0;
			T188_ = (absExponent_1 <= (NI)(((NI)22) + slop_1));
			if (!(T188_)) goto LA189_;
			T188_ = !(expNegative_1);
LA189_: ;
			if (!T188_) goto LA190_;
			(*number_p1) = ((NF)(((NF)(((NF)(sign_1) * (NF)(((NF) (integer_1))))) * (NF)(powtens__system_u7337[(slop_1)- 0]))) * (NF)(powtens__system_u7337[((NI)(absExponent_1 - slop_1))- 0]));
			result = i_1;
			goto BeforeRet_;
		}
LA190_: ;
	}
LA175_: ;
	nimZeroMem((void*)t_1, sizeof(tyArray__zO5aBDTeiBNbpfX9cEBgeLA));
	ti_1 = ((NI)0);
	maxlen_1 = ((NI)494);
	endPos_1 = i_1;
	result = endPos_1;
	i_1 = ((NI)0);
	{
		NIM_BOOL T194_;
		T194_ = (NIM_BOOL)0;
		T194_ = (i_1 < endPos_1);
		if (!(T194_)) goto LA195_;
		T194_ = ((NU8)(s_p0[i_1]) == (NU8)(46));
LA195_: ;
		if (!T194_) goto LA196_;
		i_1 += ((NI)1);
	}
LA196_: ;
	{
		while (1) {
			NIM_BOOL T200_;
			T200_ = (NIM_BOOL)0;
			T200_ = (i_1 < endPos_1);
			if (!(T200_)) goto LA201_;
			T200_ = (((NU8)(s_p0[i_1])) >= ((NU8)(48)) && ((NU8)(s_p0[i_1])) <= ((NU8)(57)) || ((NU8)(s_p0[i_1])) == ((NU8)(43)) || ((NU8)(s_p0[i_1])) == ((NU8)(45)));
LA201_: ;
			if (!T200_) goto LA199;
			{
				if (!(ti_1 < maxlen_1)) goto LA204_;
				t_1[(ti_1)- 0] = s_p0[i_1];
				ti_1 += ((NI)1);
			}
LA204_: ;
			i_1 += ((NI)1);
			{
				while (1) {
					NIM_BOOL T208_;
					T208_ = (NIM_BOOL)0;
					T208_ = (i_1 < endPos_1);
					if (!(T208_)) goto LA209_;
					T208_ = (((NU8)(s_p0[i_1])) == ((NU8)(46)) || ((NU8)(s_p0[i_1])) == ((NU8)(95)));
LA209_: ;
					if (!T208_) goto LA207;
					i_1 += ((NI)1);
				} LA207: ;
			}
		} LA199: ;
	}
	t_1[(ti_1)- 0] = 69;
	ti_1 += ((NI)1);
	T210_ = (NIM_CHAR)0;
	{
		if (!expNegative_1) goto LA213_;
		t_1[(ti_1)- 0] = 45;
	}
	goto LA211_;
LA213_: ;
	{
		t_1[(ti_1)- 0] = 43;
	}
LA211_: ;
	ti_1 += ((NI)4);
	t_1[((NI)(ti_1 - ((NI)1)))- 0] = ((NIM_CHAR) ((NI)(((NI)48) + (NI)(absExponent_1 % ((NI)10)))));
	absExponent_1 = (NI)(absExponent_1 / ((NI)10));
	t_1[((NI)(ti_1 - ((NI)2)))- 0] = ((NIM_CHAR) ((NI)(((NI)48) + (NI)(absExponent_1 % ((NI)10)))));
	absExponent_1 = (NI)(absExponent_1 / ((NI)10));
	t_1[((NI)(ti_1 - ((NI)3)))- 0] = ((NIM_CHAR) ((NI)(((NI)48) + (NI)(absExponent_1 % ((NI)10)))));
	(*number_p1) = strtod(((NCSTRING) (t_1)), ((NCSTRING*) NIM_NIL));
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgen_u14890)(tySequence__shxop0zPIs5Ec3k71aCLuQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__zpIo9bPR9aKvxkrKqNdODGXQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgen_u14894)(tySequence__shxop0zPIs5Ec3k71aCLuQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgen_u14890(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__zpIo9bPR9aKvxkrKqNdODGXQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__zpIo9bPR9aKvxkrKqNdODGXQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__A5d1lLxIlLDjDoMqkeDyAA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)1), ((NI)1));
			(*xu_1).p = ((tyObject_NimSeqPayload__A5d1lLxIlLDjDoMqkeDyAA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u14965)(tySequence__shxop0zPIs5Ec3k71aCLuQ dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NIM_BOOL));
}
}
N_LIB_PRIVATE N_NIMCALL(void, add__nimconf_u312)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__rpt17CTZKhcmivfqWPh5Ng* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__rpt17CTZKhcmivfqWPh5Ng*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__YOjgUJccqS0z21apIzbjhw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__YOjgUJccqS0z21apIzbjhw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u1183)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* obj_p0) {
	eqdestroy___ast_u1200((&(*obj_p0)));
	eqwasMoved___ast_u1197(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u1163)(tySequence__7s5HyddQ0f9bxMNILHrXwJQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__ast_u1183((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9b8Iun9akN0pmaswXV4xzNHw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u1156)(tySequence__7s5HyddQ0f9bxMNILHrXwJQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__ast_u1163(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9b8Iun9akN0pmaswXV4xzNHw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9b8Iun9akN0pmaswXV4xzNHw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__NhGNL7A9cAki9adhGREqHjvQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__NhGNL7A9cAki9adhGREqHjvQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u1429)(tySequence__7s5HyddQ0f9bxMNILHrXwJQ* s_p0, NI len_p1) {
	shrink__ast_u1163(s_p0, ((NI)0));
	setLen__ast_u1156((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3225)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__hxkEoe2aqyVy2PvaqyFybw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__hxkEoe2aqyVy2PvaqyFybw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__huYzbmxw1CWqexrcdhCzVQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__huYzbmxw1CWqexrcdhCzVQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u3745)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___ast_u3252((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u3249(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u3725)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__ast_u3745(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__hxkEoe2aqyVy2PvaqyFybw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3718)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__ast_u3725(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__hxkEoe2aqyVy2PvaqyFybw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__hxkEoe2aqyVy2PvaqyFybw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__huYzbmxw1CWqexrcdhCzVQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__huYzbmxw1CWqexrcdhCzVQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u4100)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI len_p1) {
	shrink__ast_u3725(s_p0, ((NI)0));
	setLen__ast_u3718((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9ahcSjIErJohSBBFLwuF56Q, at___ast_u4149)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** a_p0, NI a_p0Len_0) {
	tySequence__9ahcSjIErJohSBBFLwuF56Q result;
	NI sz_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	sz_1 = a_p0Len_0;
	newSeq__ast_u4100((&result), (sz_1));
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(sz_1 - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA3;
				i_1 = ((NI) (res_1));
				eqcopy___ast_u3255(&result.p->data[i_1], a_p0[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___renderer_u163)(tySequence__T69aiRC686UsUPVrEM9awLDA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].sym);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].sym)));
				nimRawDispose(dest_p0.p->data[colontmp_].sym, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, add__renderer_u449)(tySequence__T69aiRC686UsUPVrEM9awLDA* x_p0, tyObject_TRenderTok__4o9aub9bVAU9bRyM9aFMq9bqzyQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__nzRDknQPEQ8tmY6MzxXfBA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__nzRDknQPEQ8tmY6MzxXfBA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__B9ajNKqEmXQfFf759aVJOmDQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__B9ajNKqEmXQfFf759aVJOmDQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].kind = y_p1.kind;
	(*(*xu_1).p).data[oldLen_1].length = y_p1.length;
	(*(*xu_1).p).data[oldLen_1].sym = y_p1.sym;
}
N_LIB_PRIVATE N_NIMCALL(void, add__renderer_u83)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__leUMr6KkmlAoo48M8CioZQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__leUMr6KkmlAoo48M8CioZQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ItQROW58gGeBOtCRbSJrPQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__ItQROW58gGeBOtCRbSJrPQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZcollectionsZintsets_u150)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___pureZcollectionsZintsets_u48((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___pureZcollectionsZintsets_u45(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZcollectionsZintsets_u130)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__pureZcollectionsZintsets_u150(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__xawoyDHERXWhMB61uw9aFlw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZcollectionsZintsets_u122)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__pureZcollectionsZintsets_u130(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__xawoyDHERXWhMB61uw9aFlw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__xawoyDHERXWhMB61uw9aFlw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__1F9aVmKGgcmPPhU4J9cqdFeA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__1F9aVmKGgcmPPhU4J9cqdFeA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZcollectionsZintsets_u275)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA* s_p0, NI len_p1) {
	shrink__pureZcollectionsZintsets_u130(s_p0, ((NI)0));
	setLen__pureZcollectionsZintsets_u122((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u12967)(tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___icZic_u12984((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___icZic_u12981(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u12947)(tySequence__5reviU45axUMPQgL9aoENrg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__icZic_u12967((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__zERsha2FLD27xkcyTtUe5w*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u12940)(tySequence__5reviU45axUMPQgL9aoENrg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u12947(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__zERsha2FLD27xkcyTtUe5w* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__zERsha2FLD27xkcyTtUe5w*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__4cPHQNh65eNeh02ZwhM4Vw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)784), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__4cPHQNh65eNeh02ZwhM4Vw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___icZrodfiles_u472)(tyArray__mXjDD1r0VWLRZmHnQfpVHA x_p0, tyArray__mXjDD1r0VWLRZmHnQfpVHA y_p1) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		NI f_1;
		NI res_1;
		f_1 = (NI)0;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= ((NI)7))) goto LA3;
				f_1 = ((NI) (res_1));
				{
					if (!!((x_p0[(f_1)- 0] == y_p1[(f_1)- 0]))) goto LA6_;
					goto BeforeRet_;
				}
LA6_: ;
				res_1 += ((NI)1);
			} LA3: ;
		}
	}
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u1584)(tySequence__9bAGqSvkAaFL9bWjsEPslrFA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__wAKcmNV09bNcAakf5YD2A9aQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u1588)(tySequence__9bAGqSvkAaFL9bWjsEPslrFA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u1584(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__wAKcmNV09bNcAakf5YD2A9aQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__wAKcmNV09bNcAakf5YD2A9aQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__J4VmartFf3o9c8SALClNLqQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)4), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__J4VmartFf3o9c8SALClNLqQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u1580)(tySequence__9bAGqSvkAaFL9bWjsEPslrFA* s_p0, NI len_p1) {
	shrink__icZic_u1584(s_p0, ((NI)0));
	setLen__icZic_u1588((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9bAGqSvkAaFL9bWjsEPslrFA, newSeq__icZic_u7892)(NI len_p0) {
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u1580((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8080)(tySequence__PXIzfWocnrafGz5p3CP5LA* dest_p0, tySequence__PXIzfWocnrafGz5p3CP5LA src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u8071((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u8031)(tyTuple__0q9cmhneJEKnQERTpXXdz6Q* obj_p0) {
	eqdestroy___icZic_u3031((*obj_p0));
	eqwasMoved___icZic_u3028(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u7978)(tySequence__PXIzfWocnrafGz5p3CP5LA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__icZic_u8031((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__xirGUCq5Yeys036wjTr9a9ag*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u7982)(tySequence__PXIzfWocnrafGz5p3CP5LA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u7978(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__xirGUCq5Yeys036wjTr9a9ag* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__xirGUCq5Yeys036wjTr9a9ag*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__BvkI5Fb1Dely7cGpGug48w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__BvkI5Fb1Dely7cGpGug48w*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__0q9cmhneJEKnQERTpXXdz6Q));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u7974)(tySequence__PXIzfWocnrafGz5p3CP5LA* s_p0, NI len_p1) {
	shrink__icZic_u7978(s_p0, ((NI)0));
	setLen__icZic_u7982((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__PXIzfWocnrafGz5p3CP5LA, newSeq__icZic_u7969)(NI len_p0) {
	tySequence__PXIzfWocnrafGz5p3CP5LA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u7974((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8262)(tySequence__IHUFRsFxZNv7YydiUO2esQ* dest_p0, tySequence__IHUFRsFxZNv7YydiUO2esQ src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u8253((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u8182)(tySequence__IHUFRsFxZNv7YydiUO2esQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__O56sKEP9cSyEFKM0DbntvZg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u8186)(tySequence__IHUFRsFxZNv7YydiUO2esQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u8182(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__O56sKEP9cSyEFKM0DbntvZg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__O56sKEP9cSyEFKM0DbntvZg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__CNYRHAW35ohZPTfy5ZiwWA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__CNYRHAW35ohZPTfy5ZiwWA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u8178)(tySequence__IHUFRsFxZNv7YydiUO2esQ* s_p0, NI len_p1) {
	shrink__icZic_u8182(s_p0, ((NI)0));
	setLen__icZic_u8186((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__IHUFRsFxZNv7YydiUO2esQ, newSeq__icZic_u8173)(NI len_p0) {
	tySequence__IHUFRsFxZNv7YydiUO2esQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u8178((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8429)(tySequence__b89aLriiJnVTD186H6zNIgg* dest_p0, tySequence__b89aLriiJnVTD186H6zNIgg src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u8420((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u8349)(tySequence__b89aLriiJnVTD186H6zNIgg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__kwk4E3fMMEr4O39a8w9chcVQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u8353)(tySequence__b89aLriiJnVTD186H6zNIgg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u8349(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__kwk4E3fMMEr4O39a8w9chcVQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__kwk4E3fMMEr4O39a8w9chcVQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__0uKoWoKwrj0zsXW2OSD9crg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__0uKoWoKwrj0zsXW2OSD9crg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u8345)(tySequence__b89aLriiJnVTD186H6zNIgg* s_p0, NI len_p1) {
	shrink__icZic_u8349(s_p0, ((NI)0));
	setLen__icZic_u8353((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__b89aLriiJnVTD186H6zNIgg, newSeq__icZic_u8340)(NI len_p0) {
	tySequence__b89aLriiJnVTD186H6zNIgg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u8345((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8615)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* dest_p0, tySequence__hIPTk9aFdaMMVAOzEbnPyqg src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u8606((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u8535)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__G5wzdngs0i9cLnjn6UUm2QA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u8539)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u8535(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__G5wzdngs0i9cLnjn6UUm2QA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__G5wzdngs0i9cLnjn6UUm2QA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__CiPf6Xv05KUQiXqTUxpsUA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)12), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__CiPf6Xv05KUQiXqTUxpsUA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__7rmdAMLZ8fDd79brQn2ixZA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u8531)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* s_p0, NI len_p1) {
	shrink__icZic_u8535(s_p0, ((NI)0));
	setLen__icZic_u8539((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__hIPTk9aFdaMMVAOzEbnPyqg, newSeq__icZic_u8526)(NI len_p0) {
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u8531((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u8801)(tySequence__48JTohSgTy339bRxHzUD8KA* dest_p0, tySequence__48JTohSgTy339bRxHzUD8KA src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u8792((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u8721)(tySequence__48JTohSgTy339bRxHzUD8KA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u8725)(tySequence__48JTohSgTy339bRxHzUD8KA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u8721(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__XiOLiKIdPX5U0AB70DNjbQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)4), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__XiOLiKIdPX5U0AB70DNjbQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u8717)(tySequence__48JTohSgTy339bRxHzUD8KA* s_p0, NI len_p1) {
	shrink__icZic_u8721(s_p0, ((NI)0));
	setLen__icZic_u8725((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__48JTohSgTy339bRxHzUD8KA, newSeq__icZic_u8712)(NI len_p0) {
	tySequence__48JTohSgTy339bRxHzUD8KA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u8717((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZpacked95ast_u132)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* dest_p0, tySequence__OxRbUT0qZaZN5UjnqQjGPA src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZpacked95ast_u123((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZpacked95ast_u151)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__d3fv9a69bbApweAbY7myMCAA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZpacked95ast_u143)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZpacked95ast_u151(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__d3fv9a69bbApweAbY7myMCAA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__d3fv9a69bbApweAbY7myMCAA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__FxDYcVbzbzqu9bUx3WqGoTA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__FxDYcVbzbzqu9bUx3WqGoTA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZpacked95ast_u1310)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* s_p0, NI len_p1) {
	shrink__icZpacked95ast_u151(s_p0, ((NI)0));
	setLen__icZpacked95ast_u143((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__OxRbUT0qZaZN5UjnqQjGPA, newSeq__icZpacked95ast_u1305)(NI len_p0) {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZpacked95ast_u1310((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZpacked95ast_u291)(tySequence__ezS5mGPcRfBURJyMgqYVzA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__ZAx4OSjx7H2DxJ9ad9avCPsg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZpacked95ast_u283)(tySequence__ezS5mGPcRfBURJyMgqYVzA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZpacked95ast_u291(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__ZAx4OSjx7H2DxJ9ad9avCPsg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__ZAx4OSjx7H2DxJ9ad9avCPsg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__fcGqxIwgjERIIBSj9aK2oxg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__fcGqxIwgjERIIBSj9aK2oxg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__48iPM3yLBKU5nyEuYwJvuQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZpacked95ast_u1395)(tySequence__ezS5mGPcRfBURJyMgqYVzA* s_p0, NI len_p1) {
	shrink__icZpacked95ast_u291(s_p0, ((NI)0));
	setLen__icZpacked95ast_u283((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ezS5mGPcRfBURJyMgqYVzA, newSeq__icZpacked95ast_u1390)(NI len_p0) {
	tySequence__ezS5mGPcRfBURJyMgqYVzA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZpacked95ast_u1395((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZpacked95ast_u394)(tySequence__wW7xkohjuUKO9aMaB0nt9cqA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__tgxZ7KAKIYkBA1bom1fW8w*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZpacked95ast_u386)(tySequence__wW7xkohjuUKO9aMaB0nt9cqA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZpacked95ast_u394(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__tgxZ7KAKIYkBA1bom1fW8w* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__tgxZ7KAKIYkBA1bom1fW8w*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__fjZ4qUgOZDh3YOPYb0LHnQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)12), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__fjZ4qUgOZDh3YOPYb0LHnQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__R3ddFrA0G9buJY57Qhf9cTpg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZpacked95ast_u1480)(tySequence__wW7xkohjuUKO9aMaB0nt9cqA* s_p0, NI len_p1) {
	shrink__icZpacked95ast_u394(s_p0, ((NI)0));
	setLen__icZpacked95ast_u386((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__wW7xkohjuUKO9aMaB0nt9cqA, newSeq__icZpacked95ast_u1475)(NI len_p0) {
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZpacked95ast_u1480((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u586)(tySequence__Vl1abU3gfp0RqCb1KKfmDA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__q7QzP045gko7DIG9ak9cJjvg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u579)(tySequence__Vl1abU3gfp0RqCb1KKfmDA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u586(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__q7QzP045gko7DIG9ak9cJjvg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__q7QzP045gko7DIG9ak9cJjvg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__OlXaC6zsBmhDNWsqynhNbw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)160), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__OlXaC6zsBmhDNWsqynhNbw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__V1VWX9bHapuzCjpMfFfys5Q));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u5847)(tySequence__Vl1abU3gfp0RqCb1KKfmDA* s_p0, NI len_p1) {
	shrink__icZic_u586(s_p0, ((NI)0));
	setLen__icZic_u579((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u3900)(tyTuple__anemVmHCFglLFt6LiEhFvg* obj_p0) {
	eqdestroy___icZic_u3916((&(*obj_p0)));
	eqwasMoved___icZic_u3913(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u3843)(tySequence__qyyNkmlc4fzOzelC8spUkQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__icZic_u3900((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__iXDsgW33GmsE2gY9cAOO11Q*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u3847)(tySequence__qyyNkmlc4fzOzelC8spUkQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u3843(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__iXDsgW33GmsE2gY9cAOO11Q* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__iXDsgW33GmsE2gY9cAOO11Q*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__YL9cEzDu8vsXEGN89csSy9crA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)104), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__YL9cEzDu8vsXEGN89csSy9crA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__anemVmHCFglLFt6LiEhFvg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u3839)(tySequence__qyyNkmlc4fzOzelC8spUkQ* s_p0, NI len_p1) {
	shrink__icZic_u3843(s_p0, ((NI)0));
	setLen__icZic_u3847((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u3968)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__dCwFm7iJYKqQeZSIzKc0NA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u3961)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u3968(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__dCwFm7iJYKqQeZSIzKc0NA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__dCwFm7iJYKqQeZSIzKc0NA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__mZuhNjviDK9b79bNVotwlwcw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__mZuhNjviDK9b79bNVotwlwcw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u7636)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* s_p0, NI len_p1) {
	shrink__icZic_u3968(s_p0, ((NI)0));
	setLen__icZic_u3961((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qBes3XzcQQ9cyia9bRwnmbJw, newSeq__icZic_u7631)(NI len_p0) {
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u7636((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u9567)(tySequence__YYy1721YAuPF0ajBYHd8Wg* dest_p0, tySequence__YYy1721YAuPF0ajBYHd8Wg src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u9558((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u9487)(tySequence__YYy1721YAuPF0ajBYHd8Wg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__gIwHLNdjfH4VRWhXpHypGA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u9491)(tySequence__YYy1721YAuPF0ajBYHd8Wg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u9487(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__gIwHLNdjfH4VRWhXpHypGA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__gIwHLNdjfH4VRWhXpHypGA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__5Z9a9aROEoDZcGRpcSYezyFg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__5Z9a9aROEoDZcGRpcSYezyFg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__qPXRCRNQuZLLKto7CIIEzw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u9483)(tySequence__YYy1721YAuPF0ajBYHd8Wg* s_p0, NI len_p1) {
	shrink__icZic_u9487(s_p0, ((NI)0));
	setLen__icZic_u9491((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__YYy1721YAuPF0ajBYHd8Wg, newSeq__icZic_u9478)(NI len_p0) {
	tySequence__YYy1721YAuPF0ajBYHd8Wg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u9483((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u9771)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* dest_p0, tySequence__UODJbvzmu39c3Ho9cqhSk9agQ src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u9762((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u9722)(tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* obj_p0) {
	eqdestroy___icZic_u7685((&(*obj_p0)));
	eqwasMoved___icZic_u7682(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u9669)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__icZic_u9722((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__15maDR19bknK34amedd1PnQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u9673)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u9669(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__15maDR19bknK34amedd1PnQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__15maDR19bknK34amedd1PnQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__iyj5NYk2cU9bjed29aLoecBQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__iyj5NYk2cU9bjed29aLoecBQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u9665)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* s_p0, NI len_p1) {
	shrink__icZic_u9669(s_p0, ((NI)0));
	setLen__icZic_u9673((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ, newSeq__icZic_u9660)(NI len_p0) {
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u9665((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u9954)(tySequence__F1qNdU7m0Czu7Y2q0eksXw* dest_p0, tySequence__F1qNdU7m0Czu7Y2q0eksXw src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u9945((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u9874)(tySequence__F1qNdU7m0Czu7Y2q0eksXw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__eg19cQLnrM6yvo2xbN7Qm4g*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u9878)(tySequence__F1qNdU7m0Czu7Y2q0eksXw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u9874(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__eg19cQLnrM6yvo2xbN7Qm4g* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__eg19cQLnrM6yvo2xbN7Qm4g*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__3YPQ2gT1hEEt9cWshv20sYQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)20), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__3YPQ2gT1hEEt9cWshv20sYQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__6kG8KAxm9aXPdLdlxcxqJJw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u9870)(tySequence__F1qNdU7m0Czu7Y2q0eksXw* s_p0, NI len_p1) {
	shrink__icZic_u9874(s_p0, ((NI)0));
	setLen__icZic_u9878((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__F1qNdU7m0Czu7Y2q0eksXw, newSeq__icZic_u9865)(NI len_p0) {
	tySequence__F1qNdU7m0Czu7Y2q0eksXw result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u9870((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZic_u10164)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q* dest_p0, tySequence__r3Kz9breImOXyFFoJ29aBM8Q src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZic_u10155((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u10056)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__5K6YMLUzOBOQi9cm4I2oc9bg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u10060)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u10056(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__5K6YMLUzOBOQi9cm4I2oc9bg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__5K6YMLUzOBOQi9cm4I2oc9bg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__u70jg4Sy9boIjAjNPaPSu6A*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__u70jg4Sy9boIjAjNPaPSu6A*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__TRK7rrwoha9bbDAdPWsqJMw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u10052)(tySequence__r3Kz9breImOXyFFoJ29aBM8Q* s_p0, NI len_p1) {
	shrink__icZic_u10056(s_p0, ((NI)0));
	setLen__icZic_u10060((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__r3Kz9breImOXyFFoJ29aBM8Q, newSeq__icZic_u10047)(NI len_p0) {
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u10052((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___icZiclineinfos_u378)(tySequence__orxtl6CusdjXleqrxi67gw* dest_p0, tySequence__orxtl6CusdjXleqrxi67gw src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___icZiclineinfos_u369((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZiclineinfos_u298)(tySequence__orxtl6CusdjXleqrxi67gw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__7j9aCEhtB2gWiMpaLpLmDAA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZiclineinfos_u302)(tySequence__orxtl6CusdjXleqrxi67gw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZiclineinfos_u298(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__7j9aCEhtB2gWiMpaLpLmDAA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__7j9aCEhtB2gWiMpaLpLmDAA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__O4qEUBsg9a9aB9bssXf66dmrA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)12), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__O4qEUBsg9a9aB9bssXf66dmrA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__MaWaKZwaGUqCXKsSK12rVg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZiclineinfos_u294)(tySequence__orxtl6CusdjXleqrxi67gw* s_p0, NI len_p1) {
	shrink__icZiclineinfos_u298(s_p0, ((NI)0));
	setLen__icZiclineinfos_u302((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__orxtl6CusdjXleqrxi67gw, newSeq__icZiclineinfos_u289)(NI len_p0) {
	tySequence__orxtl6CusdjXleqrxi67gw result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZiclineinfos_u294((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u13430)(tyTuple__MZVSn3SE3XUBJOaMu7ofRQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___icZic_u13447((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___icZic_u13444(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u13410)(tySequence__FmsTQiIcS9arxHxs3QY48vA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__icZic_u13430((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__ofH9blJDuzy7lLp0Nu79aa9cQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u13402)(tySequence__FmsTQiIcS9arxHxs3QY48vA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u13410(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__ofH9blJDuzy7lLp0Nu79aa9cQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__ofH9blJDuzy7lLp0Nu79aa9cQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__OzmveoJODUPJyabeUsARrg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__OzmveoJODUPJyabeUsARrg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__MZVSn3SE3XUBJOaMu7ofRQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u18932)(tySequence__FmsTQiIcS9arxHxs3QY48vA* s_p0, NI len_p1) {
	shrink__icZic_u13410(s_p0, ((NI)0));
	setLen__icZic_u13402((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u3712)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* x_p0, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__dCwFm7iJYKqQeZSIzKc0NA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__dCwFm7iJYKqQeZSIzKc0NA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__mZuhNjviDK9b79bNVotwlwcw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__mZuhNjviDK9b79bNVotwlwcw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u21077)(tySequence__48JTohSgTy339bRxHzUD8KA* x_p0, NI32 y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__EnGyyCL9bP9bBkJIIw130JcA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__EnGyyCL9bP9bBkJIIw130JcA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__xJHATr8XqGiTUvmTQdd1YA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)4), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__xJHATr8XqGiTUvmTQdd1YA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___icZpacked95ast_u592)(tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig x_p0, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig y_p1) {
	NIM_BOOL result;
{	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!!((x_p0.module == y_p1.module))) goto LA7_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!!((x_p0.item == y_p1.item))) goto LA15_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA15_: ;
	}
LA11_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u13266)(tyTuple__1xWeGeoNoZxaLhTUDDWYyA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___icZic_u13283((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___icZic_u13280(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u13246)(tySequence__UE4b6iUkm1b3zTPamTTkDw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__icZic_u13266((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__8dnVBQrNdN4aYbHrPCeE8Q*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u13238)(tySequence__UE4b6iUkm1b3zTPamTTkDw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u13246(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__8dnVBQrNdN4aYbHrPCeE8Q* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__8dnVBQrNdN4aYbHrPCeE8Q*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__OkEdEJcYExex9clzIWp3Fcw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__OkEdEJcYExex9clzIWp3Fcw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__1xWeGeoNoZxaLhTUDDWYyA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u17189)(tySequence__UE4b6iUkm1b3zTPamTTkDw* s_p0, NI len_p1) {
	shrink__icZic_u13246(s_p0, ((NI)0));
	setLen__icZic_u13238((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__icZic_u13104)(tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___icZic_u13121((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___icZic_u13118(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u13084)(tySequence__K0j67V58u5FW0dCC534FQw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__icZic_u13104((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__whT1ft59bR5HcNlwxW9a1Sqw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u13076)(tySequence__K0j67V58u5FW0dCC534FQw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u13084(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__whT1ft59bR5HcNlwxW9a1Sqw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__whT1ft59bR5HcNlwxW9a1Sqw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__wPuxrD4t1tdh9aWvKqI6vgg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__wPuxrD4t1tdh9aWvKqI6vgg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u14358)(tySequence__K0j67V58u5FW0dCC534FQw* s_p0, NI len_p1) {
	shrink__icZic_u13084(s_p0, ((NI)0));
	setLen__icZic_u13076((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u3361)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___ast_u3378((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u3375(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u3341)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__ast_u3361(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__pxiTcguNzAbu0Rv0PQ7RSQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3333)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__ast_u3341(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__pxiTcguNzAbu0Rv0PQ7RSQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__pxiTcguNzAbu0Rv0PQ7RSQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__3xRBpaE09cNEWepSBJ3qPrA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__3xRBpaE09cNEWepSBJ3qPrA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u16266)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* s_p0, NI len_p1) {
	shrink__ast_u3341(s_p0, ((NI)0));
	setLen__ast_u3333((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg, newSeq__icZic_u16261)(NI len_p0) {
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZic_u16266((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3891)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* x_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__pxiTcguNzAbu0Rv0PQ7RSQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__pxiTcguNzAbu0Rv0PQ7RSQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__3xRBpaE09cNEWepSBJ3qPrA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__3xRBpaE09cNEWepSBJ3qPrA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u10926)(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u10943((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u10940(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u10906)(tySequence__TfHJycarvNts8E4mVG4Mfg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u10926((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__bvyB5GGuyrRUoSB3KTNeag*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u10899)(tySequence__TfHJycarvNts8E4mVG4Mfg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u10906(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__bvyB5GGuyrRUoSB3KTNeag* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__bvyB5GGuyrRUoSB3KTNeag*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__L1t9aLhHZkDv9c4TR4CmTx4A*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)120), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__L1t9aLhHZkDv9c4TR4CmTx4A*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u474)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NI));
}
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2665)(tySequence__4zAALtm0xUbRlYWQ2V8K7A dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLast(dest_p0.p->data[colontmp_].inst);
				if (!T6_) goto LA7_;
				eqdestroy___modulegraphs_u1177((&(*dest_p0.p->data[colontmp_].inst)));
				nimRawDispose(dest_p0.p->data[colontmp_].inst, ((NI)8));
			}
LA7_: ;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].genericSym);
				if (!T11_) goto LA12_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].genericSym)));
				nimRawDispose(dest_p0.p->data[colontmp_].genericSym, ((NI)8));
			}
LA12_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2451)(tySequence__lAikaRQvUF0uwNAz0U4FFA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLast(dest_p0.p->data[colontmp_]);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3521((&(*dest_p0.p->data[colontmp_])));
				nimRawDispose(dest_p0.p->data[colontmp_], ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*));
}
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u3051)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u3068((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u3065(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u3031)(tySequence__dtr79aXjHrgHuH79ac55I2aw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u3051((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9aXnq9c5fz5Q0hbWElxyLjIg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u3024)(tySequence__dtr79aXjHrgHuH79ac55I2aw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u3031(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9aXnq9c5fz5Q0hbWElxyLjIg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9aXnq9c5fz5Q0hbWElxyLjIg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ZnfNx9cWQ79bKoiGpbxeUZ2w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)720), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__ZnfNx9cWQ79bKoiGpbxeUZ2w*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u3004)(tySequence__PXIzfWocnrafGz5p3CP5LA* x_p0, tyTuple__0q9cmhneJEKnQERTpXXdz6Q y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__xirGUCq5Yeys036wjTr9a9ag* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__xirGUCq5Yeys036wjTr9a9ag*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__BvkI5Fb1Dely7cGpGug48w*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__BvkI5Fb1Dely7cGpGug48w*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZiclineinfos_u100)(NU32* dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u1420)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__C0nzvajqtOMam85eM9bZNSg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u1413)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u1420(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__C0nzvajqtOMam85eM9bZNSg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__C0nzvajqtOMam85eM9bZNSg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__pOgCdk2AGTA5dRpCuIyXLw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__pOgCdk2AGTA5dRpCuIyXLw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__UvldbCB6B9ayi9bGYW7vJNLA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZic_u1853)(tySequence__9cnx3zXnWzeclW8Ko4oUgAQ* s_p0, NI len_p1) {
	shrink__icZic_u1420(s_p0, ((NI)0));
	setLen__icZic_u1413((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__sigmatch_u6266)(tySequence__nSO1ltijM4vhc0UrrXKEqA* x_p0, tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__fIXSsXmSNpJjT79aD9b4Wj0Q* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__fIXSsXmSNpJjT79aD9b4Wj0Q*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__AtCLKjq0LXyy7Wjf5A3iug*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__AtCLKjq0LXyy7Wjf5A3iug*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u21880)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw* x_p0, tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig* y_p1, NI y_p1Len_0) {
	NI xl_1;
	NI T1_;
	T1_ = (*x_p0).len;
	xl_1 = T1_;
	setLen__icZic_u3961((&(*x_p0)), ((NI)(xl_1 + y_p1Len_0)));
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (y_p1Len_0-1);
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				(*x_p0).p->data[(NI)(xl_1 + i_1)] = y_p1[i_1];
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__lookups_u839)(tySequence__s3NGK5xFNK6fPmXupxoolA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__b1hMoRB6FiMpAnxWZ6XFFw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__lookups_u843)(tySequence__s3NGK5xFNK6fPmXupxoolA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__lookups_u839(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__b1hMoRB6FiMpAnxWZ6XFFw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__b1hMoRB6FiMpAnxWZ6XFFw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__JA074cUO4pLwgRHNarz1Ag*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__JA074cUO4pLwgRHNarz1Ag*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__pX68bRYqY0ZF09cQ4s0LV9ag));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lookups_u835)(tySequence__s3NGK5xFNK6fPmXupxoolA* s_p0, NI len_p1) {
	shrink__lookups_u839(s_p0, ((NI)0));
	setLen__lookups_u843((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___lookups_u1322)(tyTuple__FFspgHRWev9aDuj0fEpj9bUw x_p0, tyTuple__FFspgHRWev9aDuj0fEpj9bUw y_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!NIM_TRUE) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = eqeq___msgs_u1103(x_p0.Field0, y_p1.Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T7_)) goto LA8_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA8_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA12_;
		{
			if (!!((x_p0.Field1 == y_p1.Field1))) goto LA16_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA16_: ;
	}
LA12_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__layeredtable_u82)(tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___layeredtable_u98((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___layeredtable_u95(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__layeredtable_u24)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__layeredtable_u82((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__e19bLuPKJ5Taf2cU0C9c19amQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__layeredtable_u28)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__layeredtable_u24(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__e19bLuPKJ5Taf2cU0C9c19amQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__e19bLuPKJ5Taf2cU0C9c19amQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__e9cx23BcmptS0R3g2j9cm8Ww*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__e9cx23BcmptS0R3g2j9cm8Ww*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__layeredtable_u20)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ* s_p0, NI len_p1) {
	shrink__layeredtable_u24(s_p0, ((NI)0));
	setLen__layeredtable_u28((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u798)(tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semdata_u815((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___semdata_u812(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u778)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semdata_u798((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9bDdnwys3VzDJxw8wpw9aO7Q*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u770)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u778(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9bDdnwys3VzDJxw8wpw9aO7Q* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9bDdnwys3VzDJxw8wpw9aO7Q*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__7jYcYku9aPa9cFZyhvKlw7MA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__7jYcYku9aPa9cFZyhvKlw7MA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__semdata_u1100)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw* s_p0, NI len_p1) {
	shrink__semdata_u778(s_p0, ((NI)0));
	setLen__semdata_u770((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__msgs_u573)(tySequence__E0kio2ZnplNTuln9bsnljSA* x_p0, tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__Ny5DgIVnJhWFNrwCKmbRfg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__Ny5DgIVnJhWFNrwCKmbRfg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__GaXw4OGVqFVkcJL41FVa2w*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__GaXw4OGVqFVkcJL41FVa2w*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___types_u1719)(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ x_p0, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y_p1) {
	NIM_BOOL result;
{	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!!((x_p0.Field0 == y_p1.Field0))) goto LA7_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!!((x_p0.Field1 == y_p1.Field1))) goto LA15_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA15_: ;
	}
LA11_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__types_u1767)(tySequence__8Np6tlClE5az1CyqZdN19bQ* x_p0, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u5375)(tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u5392((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u5389(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u5355)(tySequence__3vEEVfBECLN6NIRA3FIp5g* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u5375((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__zIWP3GSgEW4HknsQ2JyF0Q*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u5348)(tySequence__3vEEVfBECLN6NIRA3FIp5g* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u5355(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__zIWP3GSgEW4HknsQ2JyF0Q* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__zIWP3GSgEW4HknsQ2JyF0Q*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__tvrm3bhXgSCURMsqnwLaHg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__tvrm3bhXgSCURMsqnwLaHg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u5732)(tySequence__3vEEVfBECLN6NIRA3FIp5g* s_p0, NI len_p1) {
	shrink__modulegraphs_u5355(s_p0, ((NI)0));
	setLen__modulegraphs_u5348((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u7226)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* x_p0, tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__cULPdsW0S5F0FBVWVpLANw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__cULPdsW0S5F0FBVWVpLANw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__9bmCK9aZILR9aqHJtn8GZl3zw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__9bmCK9aZILR9aqHJtn8GZl3zw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].id = y_p1.id;
	(*(*xu_1).p).data[oldLen_1].typ = y_p1.typ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u3982)(tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u3999((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u3996(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u3962)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u3982((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__t9bcqkWC9bif6Sx19bvRvfOKQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u3955)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u3962(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__t9bcqkWC9bif6Sx19bvRvfOKQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__t9bcqkWC9bif6Sx19bvRvfOKQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Ng0bSFZhIo7fHn3Ribr6KQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Ng0bSFZhIo7fHn3Ribr6KQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__semdata_u6154)(tySequence__8y0Gi4GwtXi2wk2mK1IOzw* s_p0, NI len_p1) {
	shrink__modulegraphs_u3962(s_p0, ((NI)0));
	setLen__modulegraphs_u3955((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u722)(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u739((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u736(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u702)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u722((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__cULPdsW0S5F0FBVWVpLANw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u694)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u702(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__cULPdsW0S5F0FBVWVpLANw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__cULPdsW0S5F0FBVWVpLANw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__9bmCK9aZILR9aqHJtn8GZl3zw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__9bmCK9aZILR9aqHJtn8GZl3zw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u7439)(tySequence__YYy1721YAuPF0ajBYHd8Wg* x_p0, tyTuple__qPXRCRNQuZLLKto7CIIEzw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__gIwHLNdjfH4VRWhXpHypGA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__gIwHLNdjfH4VRWhXpHypGA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__5Z9a9aROEoDZcGRpcSYezyFg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__5Z9a9aROEoDZcGRpcSYezyFg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__lineinfos_u1890)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ* obj_p0) {
	eqdestroy___lineinfos_u1907((*obj_p0));
	eqwasMoved___lineinfos_u1904(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__lineinfos_u1870)(tySequence__E0kio2ZnplNTuln9bsnljSA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__lineinfos_u1890((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__Ny5DgIVnJhWFNrwCKmbRfg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__lineinfos_u1862)(tySequence__E0kio2ZnplNTuln9bsnljSA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__lineinfos_u1870(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Ny5DgIVnJhWFNrwCKmbRfg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Ny5DgIVnJhWFNrwCKmbRfg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__GaXw4OGVqFVkcJL41FVa2w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__GaXw4OGVqFVkcJL41FVa2w*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__int128_u382)(NI32 x_p0, NI32 y_p1) {
	NI result;
{	{
		if (!(x_p0 == y_p1)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(x_p0 < y_p1)) goto LA7_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA7_: ;
	result = ((NI)1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__int128_u388)(NU32 x_p0, NU32 y_p1) {
	NI result;
{	{
		if (!(x_p0 == y_p1)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!((NU32)(x_p0) < (NU32)(y_p1))) goto LA7_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA7_: ;
	result = ((NI)1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__concepts_u435)(tySequence__G9cHmkmNmy6ZlkFfXcex3Hw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__gU0kQm69bws9bBab8H9cxj9akg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__concepts_u428)(tySequence__G9cHmkmNmy6ZlkFfXcex3Hw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__concepts_u435(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__gU0kQm69bws9bBab8H9cxj9akg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__gU0kQm69bws9bBab8H9cxj9akg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__h0EbKk00w6nXOIL0qL7dfw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__h0EbKk00w6nXOIL0qL7dfw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__9ay7GjiPeMMFnmoYwk84apw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__concepts_u560)(tySequence__G9cHmkmNmy6ZlkFfXcex3Hw* s_p0, NI len_p1) {
	shrink__concepts_u435(s_p0, ((NI)0));
	setLen__concepts_u428((&(*s_p0)), len_p1);
}
static N_INLINE(NIM_BOOL, eqeq___ast_u617)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA a_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA b_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (a_p0.item == b_p1.item);
	if (!(T1_)) goto LA2_;
	T1_ = (a_p0.module == b_p1.module);
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___concepts_u374)(tyTuple__JqV0huqZNAHtnE3agKOyZg x_p0, tyTuple__JqV0huqZNAHtnE3agKOyZg y_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!NIM_TRUE) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = eqeq___ast_u617(x_p0.Field0, y_p1.Field0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T7_)) goto LA8_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA8_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA12_;
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = eqeq___ast_u617(x_p0.Field1, y_p1.Field1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T16_)) goto LA17_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA17_: ;
	}
LA12_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__concepts_u939)(tyTuple__JqV0huqZNAHtnE3agKOyZg* obj_p0) {
	eqdestroy___concepts_u824((*obj_p0));
	eqwasMoved___concepts_u821(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, add__sigmatch_u1382)(tySequence__GVxMaHC0xtgqjBZ8ubUwnA* x_p0, tyTuple__7SDQCf3TbPJf09bOXiapRgg y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__S1I41Ls1uuN23lNHHgFiYg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__S1I41Ls1uuN23lNHHgFiYg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__bJWoXcrO5IwDRDKMBghkbQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__bJWoXcrO5IwDRDKMBghkbQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___sigmatch_u1509)(tySequence__GVxMaHC0xtgqjBZ8ubUwnA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)8));
			}
LA7_: ;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1);
				if (!T11_) goto LA12_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].Field1)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1, ((NI)8));
			}
LA12_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__7SDQCf3TbPJf09bOXiapRgg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, add__lookups_u2716)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* x_p0, tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__QMj9cx3xUjX4pjRwTn9bDNzA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__QMj9cx3xUjX4pjRwTn9bDNzA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__dYf6sGrYd9byl9b8o9cXNn7cA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__dYf6sGrYd9byl9b8o9cXNn7cA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__lookups_u2892)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___lookups_u2775((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___lookups_u2772(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__lookups_u2839)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__lookups_u2892((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__QMj9cx3xUjX4pjRwTn9bDNzA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__lookups_u2843)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__lookups_u2839(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__QMj9cx3xUjX4pjRwTn9bDNzA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__QMj9cx3xUjX4pjRwTn9bDNzA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__dYf6sGrYd9byl9b8o9cXNn7cA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__dYf6sGrYd9byl9b8o9cXNn7cA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lookups_u2835)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* s_p0, NI len_p1) {
	shrink__lookups_u2839(s_p0, ((NI)0));
	setLen__lookups_u2843((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__3rs2HI7A9bn1iHmZchCo1lg, newSeq__lookups_u2830)(NI len_p0) {
	tySequence__3rs2HI7A9bn1iHmZchCo1lg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__lookups_u2835((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u2932)(tySequence__3rs2HI7A9bn1iHmZchCo1lg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)8));
			}
LA7_: ;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lookups_u2929)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u594)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semdata_u611((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___semdata_u608(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u574)(tySequence__tsHRsYLyvTCPLlGRExqi7Q* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semdata_u594(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__ZBXm7zuh6K0BF7EzvKbK7A*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u566)(tySequence__tsHRsYLyvTCPLlGRExqi7Q* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u574(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__ZBXm7zuh6K0BF7EzvKbK7A* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__ZBXm7zuh6K0BF7EzvKbK7A*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__sqb841zyAWqdT69cCiVqhTg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__sqb841zyAWqdT69cCiVqhTg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___sigmatch_u7236)(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ x_p0, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y_p1) {
	NIM_BOOL result;
{	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!!((x_p0.Field0 == y_p1.Field0))) goto LA7_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!!((x_p0.Field1 == y_p1.Field1))) goto LA15_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA15_: ;
	}
LA11_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u3268)(tyTuple__09aD69az7aYn14Gt61AHvLIA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semdata_u3285((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___semdata_u3282(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3248)(tySequence__9bffTLF0HkxjFCzZL8og4GA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semdata_u3268((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__TPbyeV159aGPhQnGwOLv0sQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3240)(tySequence__9bffTLF0HkxjFCzZL8og4GA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u3248(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__TPbyeV159aGPhQnGwOLv0sQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__TPbyeV159aGPhQnGwOLv0sQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ejG43mfy2bZkAMGFTFM36Q*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__ejG43mfy2bZkAMGFTFM36Q*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__09aD69az7aYn14Gt61AHvLIA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, del__sigmatch_u7268)(tySequence__9bffTLF0HkxjFCzZL8og4GA* x_p0, NI i_p1) {
	NI xl_1;
	NI T1_;
	tyTuple__09aD69az7aYn14Gt61AHvLIA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (*x_p0).len;
	xl_1 = (NI)(T1_ - ((NI)1));
	nimZeroMem((void*)(&T2_), sizeof(tyTuple__09aD69az7aYn14Gt61AHvLIA));
	T2_.Field0 = (*x_p0).p->data[xl_1].Field0;
	T2_.Field1 = (*x_p0).p->data[xl_1].Field1;
	eqwasMoved___semdata_u3282((&(*x_p0).p->data[xl_1]));
	eqsink___semdata_u3294((&(*x_p0).p->data[i_p1]), T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setLen__semdata_u3240((&(*x_p0)), (xl_1));
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1) {
	NIM_BOOL result;
	result = ((*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (x_p0))).p == (*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (y_p1))).p);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u5512)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p1) {
	NI T6_;
	NI colontmp_;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__system_u5410((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_]), src_p1.p->data[colontmp_]);
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZosproc_u399)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__nIHI3lsoB9bBOORuoqOEj7g*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZosproc_u403)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__pureZosproc_u399(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__nIHI3lsoB9bBOORuoqOEj7g* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__nIHI3lsoB9bBOORuoqOEj7g*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__cNjQz1l4yr2UupmtFlt9b9aw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__cNjQz1l4yr2UupmtFlt9b9aw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, nimCopySeqPayload)(void* dest_p0, void* src_p1, NI elemSize_p2, NI elemAlign_p3) {
	tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ* d_1;
	tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ* s_1;
	d_1 = ((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (dest_p0));
	s_1 = ((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (src_p1));
	{
		NI headerSize_1;
		if (!(((NI)0) < (*s_1).len)) goto LA3_;
		headerSize_1 = align__system_u1639(((NI)8), elemAlign_p3);
		copyMem__system_u1742(((void*) ((NU)((NU64)(((NU) (ptrdiff_t) ((*d_1).p))) + (NU64)(((NU) (headerSize_1)))))), ((void*) ((NU)((NU64)(((NU) (ptrdiff_t) ((*s_1).p))) + (NU64)(((NU) (headerSize_1)))))), ((NI)((*s_1).len * elemSize_p2)));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZosproc_u477)(tySequence__qwqHTkRvwhrRyENtudHQ7g* dest_p0, tySequence__qwqHTkRvwhrRyENtudHQ7g src_p1) {
	NI T6_;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__pureZosproc_u403((&(*dest_p0)), T6_);
	nimCopySeqPayload(dest_p0, (&src_p1), ((NI)8), ((NI)8));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u3099)(tySequence__b89aLriiJnVTD186H6zNIgg* x_p0, tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__kwk4E3fMMEr4O39a8w9chcVQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__kwk4E3fMMEr4O39a8w9chcVQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__0uKoWoKwrj0zsXW2OSD9crg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__0uKoWoKwrj0zsXW2OSD9crg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_u1538)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__nIHI3lsoB9bBOORuoqOEj7g* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__nIHI3lsoB9bBOORuoqOEj7g*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__cNjQz1l4yr2UupmtFlt9b9aw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__cNjQz1l4yr2UupmtFlt9b9aw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u11888)(tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA** obj_p0) {
	eqdestroy___modulegraphs_u11905((*obj_p0));
	eqwasMoved___modulegraphs_u11902(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u11868)(tySequence__nSO1ltijM4vhc0UrrXKEqA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u11888(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__fIXSsXmSNpJjT79aD9b4Wj0Q*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u11860)(tySequence__nSO1ltijM4vhc0UrrXKEqA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u11868(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__fIXSsXmSNpJjT79aD9b4Wj0Q* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__fIXSsXmSNpJjT79aD9b4Wj0Q*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__AtCLKjq0LXyy7Wjf5A3iug*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__AtCLKjq0LXyy7Wjf5A3iug*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sigmatch_u5945)(tySequence__nSO1ltijM4vhc0UrrXKEqA* s_p0, NI len_p1) {
	shrink__modulegraphs_u11868(s_p0, ((NI)0));
	setLen__modulegraphs_u11860((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__nSO1ltijM4vhc0UrrXKEqA, newSeq__sigmatch_u5940)(NI len_p0) {
	tySequence__nSO1ltijM4vhc0UrrXKEqA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__sigmatch_u5945((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimBoolToStr)(NIM_BOOL x_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
{	T1_.len = 0; T1_.p = NIM_NIL;
	{
		if (!x_p0) goto LA4_;
		result = TM__Q5wkpxktOdTGvlSRo9bzt9aw_53;
	}
	goto LA2_;
LA4_: ;
	{
		result = TM__Q5wkpxktOdTGvlSRo9bzt9aw_55;
	}
LA2_: ;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__lookups_u5206)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** y_p1, NI y_p1Len_0) {
	NI xl_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (*x_p0).len;
	xl_1 = T1_;
	setLen__ast_u4725((&(*x_p0)), ((NI)(xl_1 + y_p1Len_0)));
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (y_p1Len_0-1);
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				eqcopy___ast_u4577(&(*x_p0).p->data[(NI)(xl_1 + i_1)], y_p1[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZosproc_u395)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI len_p1) {
	shrink__pureZosproc_u399(s_p0, ((NI)0));
	setLen__pureZosproc_u403((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__lookups_u4111)(tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ* x_p0, tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__VMGr7rbYO7pG7IK2TH9bz7A* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__VMGr7rbYO7pG7IK2TH9bz7A*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__sdH682KR9csVt7Lylj9aZ3vQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)40), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__sdH682KR9csVt7Lylj9aZ3vQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].dist = (*y_p1).dist;
	(*(*xu_1).p).data[oldLen_1].depth = (*y_p1).depth;
	(*(*xu_1).p).data[oldLen_1].msg = (*y_p1).msg;
	(*(*xu_1).p).data[oldLen_1].sym = (*y_p1).sym;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_u8247)(NI x_p0, NI y_p1) {
	NI result;
{	{
		if (!(x_p0 == y_p1)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(x_p0 < y_p1)) goto LA7_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA7_: ;
	result = ((NI)1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___lookups_u3875)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* x_p0, tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* y_p1) {
	NIM_BOOL result;
{	{
		NI c_1;
		if (!NIM_TRUE) goto LA3_;
		c_1 = cmp__system_u8247((*x_p0).Field0, (*y_p1).Field0);
		{
			if (!(c_1 < ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		{
			if (!(((NI)0) < c_1)) goto LA11_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA11_: ;
	}
LA3_: ;
	{
		NI c_2;
		if (!NIM_TRUE) goto LA15_;
		c_2 = cmp__system_u8247((*x_p0).Field1, (*y_p1).Field1);
		{
			if (!(c_2 < ((NI)0))) goto LA19_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA19_: ;
		{
			if (!(((NI)0) < c_2)) goto LA23_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA23_: ;
	}
LA15_: ;
	{
		NI c_3;
		if (!NIM_TRUE) goto LA27_;
		c_3 = cmp__system_u1563((*x_p0).Field2, (*y_p1).Field2);
		{
			if (!(c_3 < ((NI)0))) goto LA31_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA31_: ;
		{
			if (!(((NI)0) < c_3)) goto LA35_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA35_: ;
	}
LA27_: ;
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__lookups_u3990)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___lookups_u4007((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___lookups_u4004(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__lookups_u3970)(tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__lookups_u3990((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__VMGr7rbYO7pG7IK2TH9bz7A*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ*, new__sem_u1590)(void) {
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* result;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* r_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	r_1 = NIM_NIL;
	eqdestroy___modulegraphs_u3561(r_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	r_1 = (tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ*) nimNewObj(sizeof(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ), NIM_ALIGNOF(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ));
	result = r_1;
	eqwasMoved___modulegraphs_u3558(&r_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqdestroy___modulegraphs_u3561(r_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	goto BeforeRet_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___modulegraphs_u3561(r_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u6001)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* x_p0, tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__U11gVpqEuLiRu2f9bIfVRAA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__U11gVpqEuLiRu2f9bIfVRAA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__dDeJTSez5oo0HoO8Ee9cXRw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)48), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__dDeJTSez5oo0HoO8Ee9cXRw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].module = (*y_p1).module;
	(*(*xu_1).p).data[oldLen_1].sym = (*y_p1).sym;
	(*(*xu_1).p).data[oldLen_1].concreteTypes = (*y_p1).concreteTypes;
	(*(*xu_1).p).data[oldLen_1].inst = (*y_p1).inst;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u4677)(tyTuple__F1mMODXmKFMNQ5rLCtcv0Q* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u4694((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u4691(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u4657)(tySequence__C2ivDnhTZ6IxAdui1rfuqw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u4677((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__M1TtJBuzN40ZSG9a8yOFJFw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u4650)(tySequence__C2ivDnhTZ6IxAdui1rfuqw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u4657(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__M1TtJBuzN40ZSG9a8yOFJFw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__M1TtJBuzN40ZSG9a8yOFJFw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__B9b0oZGG5UQ5nkTLq9c9ajIag*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__B9b0oZGG5UQ5nkTLq9c9ajIag*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__F1mMODXmKFMNQ5rLCtcv0Q));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__semdata_u4929)(tySequence__C2ivDnhTZ6IxAdui1rfuqw* s_p0, NI len_p1) {
	shrink__modulegraphs_u4657(s_p0, ((NI)0));
	setLen__modulegraphs_u4650((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u1336)(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u1353((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u1350(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u1316)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u1336((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__U11gVpqEuLiRu2f9bIfVRAA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u1308)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u1316(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__U11gVpqEuLiRu2f9bIfVRAA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__U11gVpqEuLiRu2f9bIfVRAA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__dDeJTSez5oo0HoO8Ee9cXRw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)48), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__dDeJTSez5oo0HoO8Ee9cXRw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u1234)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__9bQvx9cUUKun9bKhPG2a9bQj6Q*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u1226)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u1234(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9bQvx9cUUKun9bKhPG2a9bQj6Q* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9bQvx9cUUKun9bKhPG2a9bQj6Q*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__0fSGlyKGHqXGdDH314aZKg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__0fSGlyKGHqXGdDH314aZKg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u7657)(tySequence__UODJbvzmu39c3Ho9cqhSk9agQ* x_p0, tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__15maDR19bknK34amedd1PnQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__15maDR19bknK34amedd1PnQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__iyj5NYk2cU9bjed29aLoecBQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__iyj5NYk2cU9bjed29aLoecBQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZiclineinfos_u58)(tySequence__orxtl6CusdjXleqrxi67gw* x_p0, tyTuple__MaWaKZwaGUqCXKsSK12rVg y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__7j9aCEhtB2gWiMpaLpLmDAA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__7j9aCEhtB2gWiMpaLpLmDAA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__O4qEUBsg9a9aB9bssXf66dmrA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)12), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__O4qEUBsg9a9aB9bssXf66dmrA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZpacked95ast_u477)(tySequence__OxRbUT0qZaZN5UjnqQjGPA* x_p0, tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__d3fv9a69bbApweAbY7myMCAA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__d3fv9a69bbApweAbY7myMCAA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__FxDYcVbzbzqu9bUx3WqGoTA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__FxDYcVbzbzqu9bUx3WqGoTA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZpacked95ast_u572)(tySequence__ezS5mGPcRfBURJyMgqYVzA* x_p0, tyTuple__48iPM3yLBKU5nyEuYwJvuQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__ZAx4OSjx7H2DxJ9ad9avCPsg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__ZAx4OSjx7H2DxJ9ad9avCPsg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__fcGqxIwgjERIIBSj9aK2oxg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__fcGqxIwgjERIIBSj9aK2oxg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZpacked95ast_u605)(tySequence__wW7xkohjuUKO9aMaB0nt9cqA* x_p0, tyTuple__R3ddFrA0G9buJY57Qhf9cTpg y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__tgxZ7KAKIYkBA1bom1fW8w* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__tgxZ7KAKIYkBA1bom1fW8w*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__fjZ4qUgOZDh3YOPYb0LHnQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)12), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__fjZ4qUgOZDh3YOPYb0LHnQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u3476)(tySequence__IHUFRsFxZNv7YydiUO2esQ* x_p0, NI64 y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__O56sKEP9cSyEFKM0DbntvZg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__O56sKEP9cSyEFKM0DbntvZg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__CNYRHAW35ohZPTfy5ZiwWA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__CNYRHAW35ohZPTfy5ZiwWA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__sem_u1631)(tySequence__4zAALtm0xUbRlYWQ2V8K7A* x_p0, tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__9aK7YX9bxlc8s2KV3wh8rdkA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__9aK7YX9bxlc8s2KV3wh8rdkA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__5cCooviSXLEf9cwx1D5qZiA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__5cCooviSXLEf9cwx1D5qZiA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].genericSym = y_p1.genericSym;
	(*(*xu_1).p).data[oldLen_1].inst = y_p1.inst;
}
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pragmas_u1583)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** b_p2, NI b_p2Len_0) {
	NI a_1;
	NI L_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	a_1 = x_p1.a;
	L_1 = (NI)((NI)(x_p1.b - a_1) + ((NI)1));
	{
		if (!(L_1 == b_p2Len_0)) goto LA3_;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < L_1)) goto LA7;
					i_1 = i_2;
					eqcopy___ast_u3255(&(*s_p0).p->data[(NI)(i_1 + a_1)], b_p2[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA7: ;
			}
		}
	}
	goto LA1_;
LA3_: ;
	{
		NI shiftX60gensym453__1;
		NI newLenX60gensym453__1;
		NI T9_;
		shiftX60gensym453__1 = (NI)(b_p2Len_0 - ((((NI)0) >= L_1) ? ((NI)0) : L_1));
		T9_ = (*s_p0).len;
		newLenX60gensym453__1 = (NI)(T9_ + shiftX60gensym453__1);
		{
			if (!(((NI)0) < shiftX60gensym453__1)) goto LA12_;
			setLen__ast_u3718((&(*s_p0)), (newLenX60gensym453__1));
			{
				NI iX60gensym453__1;
				NI colontmp_;
				NI colontmp__2;
				NI res_1;
				iX60gensym453__1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp__2 = (NI)0;
				colontmp_ = (NI)(newLenX60gensym453__1 - ((NI)1));
				colontmp__2 = (NI)(a_1 + b_p2Len_0);
				res_1 = colontmp_;
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T17_;
						if (!(colontmp__2 <= res_1)) goto LA16;
						iX60gensym453__1 = ((NI) (res_1));
						T17_ = NIM_NIL;
						T17_ = (*s_p0).p->data[(NI)(iX60gensym453__1 - shiftX60gensym453__1)];
						eqwasMoved___ast_u3249((&(*s_p0).p->data[(NI)(iX60gensym453__1 - shiftX60gensym453__1)]));
						eqsink___ast_u3261(&(*s_p0).p->data[iX60gensym453__1], T17_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						res_1 -= ((NI)1);
					} LA16: ;
				}
			}
		}
		goto LA10_;
LA12_: ;
		{
			{
				NI iX60gensym453__2;
				NI colontmp__3;
				NI colontmp__4;
				NI res_2;
				iX60gensym453__2 = (NI)0;
				colontmp__3 = (NI)0;
				colontmp__4 = (NI)0;
				colontmp__3 = (NI)(a_1 + b_p2Len_0);
				colontmp__4 = (NI)(newLenX60gensym453__1 - ((NI)1));
				res_2 = colontmp__3;
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T22_;
						if (!(res_2 <= colontmp__4)) goto LA21;
						iX60gensym453__2 = ((NI) (res_2));
						T22_ = NIM_NIL;
						T22_ = (*s_p0).p->data[(NI)(iX60gensym453__2 - shiftX60gensym453__1)];
						eqwasMoved___ast_u3249((&(*s_p0).p->data[(NI)(iX60gensym453__2 - shiftX60gensym453__1)]));
						eqsink___ast_u3261(&(*s_p0).p->data[iX60gensym453__2], T22_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						res_2 += ((NI)1);
					} LA21: ;
				}
			}
			setLen__ast_u3718((&(*s_p0)), (newLenX60gensym453__1));
		}
LA10_: ;
		{
			NI iX60gensym453__3;
			NI colontmp__5;
			NI i_3;
			iX60gensym453__3 = (NI)0;
			colontmp__5 = (NI)0;
			colontmp__5 = b_p2Len_0;
			i_3 = ((NI)0);
			{
				while (1) {
					if (!(i_3 < colontmp__5)) goto LA25;
					iX60gensym453__3 = i_3;
					eqcopy___ast_u3255(&(*s_p0).p->data[(NI)(a_1 + iX60gensym453__3)], b_p2[iX60gensym453__3]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_3 += ((NI)1);
				} LA25: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__pragmas_u541)(tySequence__lAikaRQvUF0uwNAz0U4FFA* x_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__bnJ5Yqhi12rJFQll9a29bK9aA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__bnJ5Yqhi12rJFQll9a29bK9aA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__zg0c9cy2kBgbyKYkekGNBUw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__zg0c9cy2kBgbyKYkekGNBUw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u2317)(tySequence__tsHRsYLyvTCPLlGRExqi7Q* x_p0, tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__ZBXm7zuh6K0BF7EzvKbK7A* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__ZBXm7zuh6K0BF7EzvKbK7A*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__sqb841zyAWqdT69cCiVqhTg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__sqb841zyAWqdT69cCiVqhTg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9ahcSjIErJohSBBFLwuF56Q, X5BX5D___pragmas_u1282)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1) {
	tySequence__9ahcSjIErJohSBBFLwuF56Q result;
	NI a_1;
	NI L_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)((NI)(s_p0Len_0 - x_p1.b) - a_1) + ((NI)1));
	newSeq__ast_u4100((&result), (L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				eqcopy___ast_u3255(&result.p->data[i_1], s_p0[(NI)(i_1 + a_1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4955)(RootObj** dest_p0, RootObj* src_p1) {
	RootObj* colontmp_;
	colontmp_ = (*dest_p0);
	(*dest_p0) = src_p1;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1321)(tySequence__TEgqV1E9aHqnwBUoeXjBI9aA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastCyclicDyn(dest_p0.p->data[colontmp_].ClE_0);
				if (!T6_) goto LA7_;
				nimDestroyAndDispose(dest_p0.p->data[colontmp_].ClE_0);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyProc__c9bXGQkBnyyGGVw063jrwZw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u862)(tySequence__b9bG03Q6unwlMU0dM7uOPIA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___vmdef_u883(dest_p0.p->data[colontmp_].fixups);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].label);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].label)));
				nimRawDispose(dest_p0.p->data[colontmp_].label, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u741)(tySequence__TLbZ2GqL3Zio1f8bNpj2NA dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u620)(tySequence__YdLNCDKYeipzJx3I8Xw82Q dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NU64));
}
}
static N_INLINE(void, add__system_u3021)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2) {
	void** colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3029(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p1));
		add__system_u3021((&(*j_1).traceStack), p_1, (*((TNimTypeV2**) ((*p_1)))));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___vmdef_u1333)(tySequence__TEgqV1E9aHqnwBUoeXjBI9aA* dest_p0, void* env_p1) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = (*dest_p0).len;
			if (!(colontmp_ < T3_)) goto LA2;
			nimTraceRefDyn((&(*dest_p0).p->data[colontmp_].ClE_0), env_p1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u497)(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ* obj_p0) {
	eqdestroy___vmdef_u513((&(*obj_p0)));
	eqwasMoved___vmdef_u510(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u439)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__vmdef_u497((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__qpKiDXWu1sjqjH7dOqAHZg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u443)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmdef_u439(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__qpKiDXWu1sjqjH7dOqAHZg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__qpKiDXWu1sjqjH7dOqAHZg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__nJDGOm2EjMPf1emtsI5R8Q*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__nJDGOm2EjMPf1emtsI5R8Q*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vmdef_u435)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og* s_p0, NI len_p1) {
	shrink__vmdef_u439(s_p0, ((NI)0));
	setLen__vmdef_u443((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__ast_u6462)(tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___ast_u6478((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u6475(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__ast_u6404)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__ast_u6462((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__ZymipdgL8Pm9bmfGa9cwYJiQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u6408)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__ast_u6404(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__ZymipdgL8Pm9bmfGa9cwYJiQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__ZymipdgL8Pm9bmfGa9cwYJiQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__2Cej9bEoiMQ2LZffLyml1CQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__2Cej9bEoiMQ2LZffLyml1CQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u6400)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* s_p0, NI len_p1) {
	shrink__ast_u6404(s_p0, ((NI)0));
	setLen__ast_u6408((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__vmdef_u2266)(tySequence__TEgqV1E9aHqnwBUoeXjBI9aA* x_p0, tyProc__c9bXGQkBnyyGGVw063jrwZw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__dAgwP2JJ1PDwPMpu9bzwC0w* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__dAgwP2JJ1PDwPMpu9bzwC0w*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__6xdpt2WgX9aW6Q639cRU5Rzw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__6xdpt2WgX9aW6Q639cRU5Rzw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].ClE_0 = y_p1.ClE_0;
	(*(*xu_1).p).data[oldLen_1].ClP_0 = y_p1.ClP_0;
}
N_LIB_PRIVATE N_NIMCALL(NCSTRING*, allocCStringArray__system_u5600)(NimStringV2* a_p0, NI a_p0Len_0) {
	NCSTRING* result;
	void* T1_;
	NimStringV2* x_1;
	result = (NCSTRING*)0;
	T1_ = (void*)0;
	T1_ = alloc0Impl__system_u1760(((NI)((NI)(a_p0Len_0 + ((NI)1)) * ((NI)8))));
	result = ((NCSTRING*) (T1_));
	x_1 = ((NimStringV2*) (a_p0));
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (a_p0Len_0-1);
		res_1 = ((NI)0);
		{
			while (1) {
				void* T5_;
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				T5_ = (void*)0;
				T5_ = alloc0Impl__system_u1760(((NI)(x_1[i_1].len + ((NI)1))));
				result[i_1] = ((NCSTRING) (T5_));
				copyMem__system_u1742(((void*) (result[i_1])), ((void*) (nimToCStringConv(x_1[i_1]))), (x_1[i_1].len));
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, deallocCStringArray__system_u5654)(NCSTRING* a_p0) {
	NI i_1;
	i_1 = ((NI)0);
	{
		while (1) {
			if (!!((((void*) (a_p0[i_1])) == NIM_NIL))) goto LA2;
			dealloc(((void*) (a_p0[i_1])));
			i_1 += ((NI)1);
		} LA2: ;
	}
	dealloc(((void*) (a_p0)));
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u8764)(tyObject_IOError__vBePDvr8fj01uTfaJy9aD3Q* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZtimes_u2647)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__HCcpPoYfekFJRNu9c9bYZ9bsQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZtimes_u2640)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__pureZtimes_u2647(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__HCcpPoYfekFJRNu9c9bYZ9bsQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__HCcpPoYfekFJRNu9c9bYZ9bsQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__6sY7wgvPGYvtAbG0tdSxiw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)1), ((NI)1));
			(*xu_1).p = ((tyObject_NimSeqPayload__6sY7wgvPGYvtAbG0tdSxiw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__bitsets_u59)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ* s_p0, NI len_p1) {
	shrink__pureZtimes_u2647(s_p0, ((NI)0));
	setLen__pureZtimes_u2640((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ, newSeq__vm_u13879)(NI len_p0) {
	tySequence__6H5Oh5UUvVCLiakt9aTwtUQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__bitsets_u59((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZtimes_u2620)(tySequence__6H5Oh5UUvVCLiakt9aTwtUQ dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NU8));
}
}
N_LIB_PRIVATE N_NIMCALL(void, add__vm_u14117)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__vmmarshal_u671)(tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___vmmarshal_u688((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___vmmarshal_u685(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmmarshal_u651)(tySequence__e9ciFfeAg1p88UzCBnAPeVQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__vmmarshal_u671((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__Zsjz8m9cC0NIjfk437Kkqag*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmmarshal_u644)(tySequence__e9ciFfeAg1p88UzCBnAPeVQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmmarshal_u651(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Zsjz8m9cC0NIjfk437Kkqag* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Zsjz8m9cC0NIjfk437Kkqag*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Wh3Dn4q89bjoiLSTUCUOTew*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Wh3Dn4q89bjoiLSTUCUOTew*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__3QzLy4wl9aTGQ4yaz9bbETxg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vmmarshal_u930)(tySequence__e9ciFfeAg1p88UzCBnAPeVQ* s_p0, NI len_p1) {
	shrink__vmmarshal_u651(s_p0, ((NI)0));
	setLen__vmmarshal_u644((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(NI, clamp__pureZstreams_u732)(NI x_p0, NI a_p1, NI b_p2) {
	NI result;
{	{
		if (!(x_p0 < a_p1)) goto LA3_;
		result = a_p1;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(b_p2 < x_p0)) goto LA7_;
		result = b_p2;
		goto BeforeRet_;
	}
LA7_: ;
	result = x_p0;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__pureZparsejson_u680)(tySequence__GyTgETkn69b26Etj2zBgjMw* x_p0, tyEnum_ParserState__0xxCjL29aD8tzUEg49aPYfOw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__sXtLBbV79ah32PP02mMBiTQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__sXtLBbV79ah32PP02mMBiTQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Ijs8YZfDA75rhEW1XeXk2w*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)1), ((NI)1));
		(*xu_1).p = ((tyObject_NimSeqPayload__Ijs8YZfDA75rhEW1XeXk2w*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZparsejson_u186)(tySequence__GyTgETkn69b26Etj2zBgjMw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__sXtLBbV79ah32PP02mMBiTQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(RootObj*, eqdup___ast_u4951)(RootObj* src_p0, NIM_BOOL cyclic_p1) {
	RootObj* result;
	RootObj* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u648)(tySequence__YdLNCDKYeipzJx3I8Xw82Q* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__diajJmNo8grsMWW9cZq9bErQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u640)(tySequence__YdLNCDKYeipzJx3I8Xw82Q* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmdef_u648(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__diajJmNo8grsMWW9cZq9bErQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__diajJmNo8grsMWW9cZq9bErQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__GkrJrbi1Vf8NOdxV9aOX4vA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__GkrJrbi1Vf8NOdxV9aOX4vA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u769)(tySequence__TLbZ2GqL3Zio1f8bNpj2NA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__y9bG85c5b3IiBNTnDEhDeCQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u761)(tySequence__TLbZ2GqL3Zio1f8bNpj2NA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmdef_u769(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__y9bG85c5b3IiBNTnDEhDeCQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__y9bG85c5b3IiBNTnDEhDeCQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8VWGiLi1AaEJ9bSMNLWx3Vw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__8VWGiLi1AaEJ9bSMNLWx3Vw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u2038)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__J80ntPleGVJXp9bYXSkOm4g*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u2030)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmdef_u2038(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__J80ntPleGVJXp9bYXSkOm4g* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__J80ntPleGVJXp9bYXSkOm4g*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__OuLlEOw03e2DVzzSxes2OQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__OuLlEOw03e2DVzzSxes2OQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__y6bKAf9a9aaVwun6lVDxSX7g));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vmgen_u4143)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q* s_p0, NI len_p1) {
	shrink__vmdef_u2038(s_p0, ((NI)0));
	setLen__vmdef_u2030((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__lambdalifting_u415)(tyTuple__bxYrf1dnwYK6GanDNddhgQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___lambdalifting_u431((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___lambdalifting_u428(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__lambdalifting_u357)(tySequence__mnb4N9bRCddoL53waHA7kHQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__lambdalifting_u415((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__o4fdV7x241MdiPUXNS1Raw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__lambdalifting_u361)(tySequence__mnb4N9bRCddoL53waHA7kHQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__lambdalifting_u357(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__o4fdV7x241MdiPUXNS1Raw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__o4fdV7x241MdiPUXNS1Raw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__S9csvyUBElFwh9cdA9bfA79bNA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__S9csvyUBElFwh9cdA9bfA79bNA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__bxYrf1dnwYK6GanDNddhgQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lambdalifting_u353)(tySequence__mnb4N9bRCddoL53waHA7kHQ* s_p0, NI len_p1) {
	shrink__lambdalifting_u357(s_p0, ((NI)0));
	setLen__lambdalifting_u361((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__lambdalifting_u2635)(tyTuple__rczUtx07rG4YmHOEmcEUJw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___lambdalifting_u2651((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___lambdalifting_u2648(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__lambdalifting_u2577)(tySequence__R1mQMFmsdp1ChoJDXa9a0xQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__lambdalifting_u2635((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__Lzxy9cA5Rb33mtr2JHP9brzg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__lambdalifting_u2581)(tySequence__R1mQMFmsdp1ChoJDXa9a0xQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__lambdalifting_u2577(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Lzxy9cA5Rb33mtr2JHP9brzg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Lzxy9cA5Rb33mtr2JHP9brzg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__b9bbw4QVkyKerVSGwvbdccQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__b9bbw4QVkyKerVSGwvbdccQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__rczUtx07rG4YmHOEmcEUJw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__lambdalifting_u2573)(tySequence__R1mQMFmsdp1ChoJDXa9a0xQ* s_p0, NI len_p1) {
	shrink__lambdalifting_u2577(s_p0, ((NI)0));
	setLen__lambdalifting_u2581((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, insert__liftdestructors_u1257)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* item_p1, NI i_p2) {
	NI xlX60gensym193__1;
	NI T1_;
	NI jX60gensym193__1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (*x_p0).len;
	xlX60gensym193__1 = T1_;
	setLen__ast_u3718((&(*x_p0)), ((NI)(xlX60gensym193__1 + ((NI)1))));
	jX60gensym193__1 = (NI)(xlX60gensym193__1 - ((NI)1));
	{
		while (1) {
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T4_;
			if (!(i_p2 <= jX60gensym193__1)) goto LA3;
			T4_ = NIM_NIL;
			T4_ = (*x_p0).p->data[jX60gensym193__1];
			eqwasMoved___ast_u3249((&(*x_p0).p->data[jX60gensym193__1]));
			eqsink___ast_u3261(&(*x_p0).p->data[(NI)(jX60gensym193__1 + ((NI)1))], T4_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			jX60gensym193__1 -= ((NI)1);
		} LA3: ;
	}
	eqsink___ast_u3261(&(*x_p0).p->data[i_p2], item_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__transf_u164)(tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___transf_u180((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___transf_u177(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__transf_u106)(tySequence__tt8kXsbz31MUMFUF6Q9aQuQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__transf_u164((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__0LodDvQr7DY8VoMTmn0gQQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__transf_u110)(tySequence__tt8kXsbz31MUMFUF6Q9aQuQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__transf_u106(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__0LodDvQr7DY8VoMTmn0gQQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__0LodDvQr7DY8VoMTmn0gQQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__oi8YBrQ80CA2zAfCI7jsQA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__oi8YBrQ80CA2zAfCI7jsQA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__transf_u102)(tySequence__tt8kXsbz31MUMFUF6Q9aQuQ* s_p0, NI len_p1) {
	shrink__transf_u106(s_p0, ((NI)0));
	setLen__transf_u110((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9ahcSjIErJohSBBFLwuF56Q, X5BX5D___transf_u3375)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1) {
	tySequence__9ahcSjIErJohSBBFLwuF56Q result;
	NI a_1;
	NI L_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)(x_p1.b - a_1) + ((NI)1));
	newSeq__ast_u4100((&result), (L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				eqcopy___ast_u3255(&result.p->data[i_1], s_p0[(NI)(i_1 + a_1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__closureiters_u150)(tySequence__kQFByJmZecfF9a1LYqz7zYg* x_p0, tyObject_State__HKH8xQquLWVVc5hqriE25Q* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__lC1hOTcTO87hw9bWuOAbM2g* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__lC1hOTcTO87hw9bWuOAbM2g*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__k8khOtl7aYqusxo9bGR3rQA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__k8khOtl7aYqusxo9bGR3rQA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__closureiters_u384)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** y_p1, NI y_p1Len_0) {
	NI xl_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (*x_p0).len;
	xl_1 = T1_;
	setLen__ast_u3718((&(*x_p0)), ((NI)(xl_1 + y_p1Len_0)));
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (y_p1Len_0-1);
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				eqcopy___ast_u3255(&(*x_p0).p->data[(NI)(xl_1 + i_1)], y_p1[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__closureiters_u779)(tySequence__kP47rw9c8bgVA53QKWe9bp7g* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__aKUzzy2BRdkBxUZZR9bCG8w*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__closureiters_u772)(tySequence__kP47rw9c8bgVA53QKWe9bp7g* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__closureiters_u779(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__aKUzzy2BRdkBxUZZR9bCG8w* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__aKUzzy2BRdkBxUZZR9bCG8w*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__9bmbJLvM9bUDGfEL9aJJFJ2gg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__9bmbJLvM9bUDGfEL9aJJFJ2gg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__bKt5Ux5pxrmB5Q8UH2eI9bw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__closureiters_u987)(tySequence__kP47rw9c8bgVA53QKWe9bp7g* s_p0, NI len_p1) {
	shrink__closureiters_u779(s_p0, ((NI)0));
	setLen__closureiters_u772((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9ahcSjIErJohSBBFLwuF56Q, newSeq__closureiters_u2254)(NI len_p0) {
	tySequence__9ahcSjIErJohSBBFLwuF56Q result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__ast_u4100((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__closureiters_u2614)(tySequence__qff4v1r3n1JKmy1NzJOChA* x_p0, tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__JeoY27Pa9c4R0cGDrOzzfuw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__JeoY27Pa9c4R0cGDrOzzfuw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__u09cKovRhfBEvwzI8DLG51A*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__u09cKovRhfBEvwzI8DLG51A*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].n = y_p1.n;
	(*(*xu_1).p).data[oldLen_1].label = y_p1.label;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__closureiters_u2388)(tyObject_FinallyTarget__BrN7u9cqgKagi0J9c3k833Yw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___closureiters_u2405((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___closureiters_u2402(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__closureiters_u2368)(tySequence__qff4v1r3n1JKmy1NzJOChA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__closureiters_u2388((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__JeoY27Pa9c4R0cGDrOzzfuw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__closureiters_u2875)(tyObject_State__HKH8xQquLWVVc5hqriE25Q* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___closureiters_u178((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___closureiters_u175(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__closureiters_u2855)(tySequence__kQFByJmZecfF9a1LYqz7zYg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__closureiters_u2875((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__lC1hOTcTO87hw9bWuOAbM2g*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__closureiters_u2848)(tySequence__kQFByJmZecfF9a1LYqz7zYg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__closureiters_u2855(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__lC1hOTcTO87hw9bWuOAbM2g* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__lC1hOTcTO87hw9bWuOAbM2g*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__k8khOtl7aYqusxo9bGR3rQA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__k8khOtl7aYqusxo9bGR3rQA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_State__HKH8xQquLWVVc5hqriE25Q));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, delete__closureiters_u3096)(tySequence__kQFByJmZecfF9a1LYqz7zYg* x_p0, NI i_p1) {
	NI xlX60gensym344__1;
	NI T12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg* T7_;
		NimStringV2 T8_;
		NI T9_;
		T3_ = ((*x_p0).len-1);
		if (!(T3_ < i_p1)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T7_ = NIM_NIL;
		T7_ = (tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg*) nimNewObj(sizeof(tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg), NIM_ALIGNOF(tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg));
		(*T7_).Sup.Sup.Sup.m_type = (&NTIv2__9cIOj9cQBZH8lEZvCihI6Eyg_);
		(*T7_).Sup.Sup.name = "IndexDefect";
		T8_.len = 0; T8_.p = NIM_NIL;
		colontmpD_ = dollar___systemZdollars_u9(i_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T9_ = (*x_p0).len;
		colontmpD__2 = dollar___systemZdollars_u9(T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T8_ = rawNewString(colontmpD_.len + colontmpD__2.len + 35);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_56);
appendString((&T8_), colontmpD_);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_57);
appendString((&T8_), colontmpD__2);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_58);
		(*T7_).Sup.Sup.message = T8_;
		raiseExceptionEx((Exception*)T7_, "IndexDefect", "delete", "system.nim", 2127);
goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T12_ = (*x_p0).len;
	xlX60gensym344__1 = T12_;
	{
		NI jX60gensym344__1;
		NI colontmp_;
		NI res_1;
		jX60gensym344__1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(xlX60gensym344__1 - ((NI)2));
		res_1 = i_p1;
		{
			while (1) {
				tyObject_State__HKH8xQquLWVVc5hqriE25Q T16_;
				if (!(res_1 <= colontmp_)) goto LA15;
				jX60gensym344__1 = ((NI) (res_1));
				nimZeroMem((void*)(&T16_), sizeof(tyObject_State__HKH8xQquLWVVc5hqriE25Q));
				T16_ = (*x_p0).p->data[(NI)(jX60gensym344__1 + ((NI)1))];
				eqwasMoved___closureiters_u175((&(*x_p0).p->data[(NI)(jX60gensym344__1 + ((NI)1))]));
				eqsink___closureiters_u187((&(*x_p0).p->data[jX60gensym344__1]), (&T16_));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 += ((NI)1);
			} LA15: ;
		}
	}
	setLen__closureiters_u2848((&(*x_p0)), ((NI)(xlX60gensym344__1 - ((NI)1))));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g, newSeq__pureZosproc_u390)(NI len_p0) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__pureZosproc_u395((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__vmgen_u381)(tySequence__YdLNCDKYeipzJx3I8Xw82Q* x_p0, NU64 y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__diajJmNo8grsMWW9cZq9bErQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__diajJmNo8grsMWW9cZq9bErQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__GkrJrbi1Vf8NOdxV9aOX4vA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__GkrJrbi1Vf8NOdxV9aOX4vA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__vmgen_u401)(tySequence__TLbZ2GqL3Zio1f8bNpj2NA* x_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__y9bG85c5b3IiBNTnDEhDeCQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__y9bG85c5b3IiBNTnDEhDeCQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8VWGiLi1AaEJ9bSMNLWx3Vw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__8VWGiLi1AaEJ9bSMNLWx3Vw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u1214)(tySequence__grdS5PdBBxkq9bxi4lFAdAw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__Vd5JoD8wWcbD6k2tc9b28YA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u1206)(tySequence__grdS5PdBBxkq9bxi4lFAdAw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmdef_u1214(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Vd5JoD8wWcbD6k2tc9b28YA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Vd5JoD8wWcbD6k2tc9b28YA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__zIcZNLCZJO9bK3dKATuA4aA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)2), ((NI)1));
			(*xu_1).p = ((tyObject_NimSeqPayload__zIcZNLCZJO9bK3dKATuA4aA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__9ap1MJ9bVBlP34AqrUq01n8w));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__vmgen_u5123)(tySequence__grdS5PdBBxkq9bxi4lFAdAw* x_p0, tyTuple__9ap1MJ9bVBlP34AqrUq01n8w y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__Vd5JoD8wWcbD6k2tc9b28YA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__Vd5JoD8wWcbD6k2tc9b28YA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__zIcZNLCZJO9bK3dKATuA4aA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)2), ((NI)1));
		(*xu_1).p = ((tyObject_NimSeqPayload__zIcZNLCZJO9bK3dKATuA4aA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__GH1mmNKNA2QP4n1tnxJf1w, newSeq__treetab_u191)(NI len_p0) {
	tySequence__GH1mmNKNA2QP4n1tnxJf1w result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__ast_u6400((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__vmgen_u968)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__SV7rrCQn9cRoWKHTGChlSgg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__SV7rrCQn9cRoWKHTGChlSgg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__YkZ78cEwLiT49csnUl1ZM7Q*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__YkZ78cEwLiT49csnUl1ZM7Q*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__vmgen_u874)(tySequence__b9bG03Q6unwlMU0dM7uOPIA* x_p0, tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__IKAN89cMTsMj9cqIMW3TeGDQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__IKAN89cMTsMj9cqIMW3TeGDQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ny1pnHdrVxdJu0cxGMS9cUA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__ny1pnHdrVxdJu0cxGMS9cUA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].label = y_p1.label;
	(*(*xu_1).p).data[oldLen_1].fixups = y_p1.fixups;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u1014)(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___vmdef_u1031((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___vmdef_u1028(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u994)(tySequence__b9bG03Q6unwlMU0dM7uOPIA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__vmdef_u1014((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__IKAN89cMTsMj9cqIMW3TeGDQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u986)(tySequence__b9bG03Q6unwlMU0dM7uOPIA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmdef_u994(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__IKAN89cMTsMj9cqIMW3TeGDQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__IKAN89cMTsMj9cqIMW3TeGDQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ny1pnHdrVxdJu0cxGMS9cUA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__ny1pnHdrVxdJu0cxGMS9cUA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u1670)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___vmdef_u1706((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___vmdef_u1703(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u1650)(tySequence__9c9aWmheGsuf9aHtY7gTnUcPA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__vmdef_u1670((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__RKcuYGEqMOT1amULBWqJ5w*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u1642)(tySequence__9c9aWmheGsuf9aHtY7gTnUcPA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmdef_u1650(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__RKcuYGEqMOT1amULBWqJ5w* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__RKcuYGEqMOT1amULBWqJ5w*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__PS0QbMt2xGKSjAh0h609cSw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__PS0QbMt2xGKSjAh0h609cSw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
					(*(*xu_1).p).data[i_1].kind = ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0);
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vm_u2972)(tySequence__9c9aWmheGsuf9aHtY7gTnUcPA* s_p0, NI len_p1) {
	shrink__vmdef_u1650(s_p0, ((NI)0));
	setLen__vmdef_u1642((&(*s_p0)), len_p1);
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, GC_ref__vm_u1333)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_p0) {
	{
		if (!!((x_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA3_;
		nimIncRef(((void*) (x_p0)));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__ast_u3977)(NimStringV2* s_p0, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw x_p1) {
	NimStringV2 colontmpD_;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___nodekinds_u168(x_p1);
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__vm_u1630)(NimStringV2* s_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u204(s_p0, x_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__vm_u1844)(NimStringV2* s_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg x_p1) {
	NimStringV2 colontmpD_;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___ast_u182(x_p1);
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
}
N_LIB_PRIVATE N_NIMCALL(void, add__macrocacheimpl_u7)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw* x_p0, tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__rxauo4ztHD3oKCBNw6YZdQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__rxauo4ztHD3oKCBNw6YZdQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Npgmi4jcd6ILOol9cT13nsA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__Npgmi4jcd6ILOol9cT13nsA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__sem_u7143)(NimStringV2* s_p0, NIM_CHAR x_p1) {
	prepareAdd((&(*s_p0)), 1);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_60);
	addEscapedChar__system_u8294(s_p0, x_p1);
	prepareAdd((&(*s_p0)), 1);
appendString((&(*s_p0)), TM__Q5wkpxktOdTGvlSRo9bzt9aw_61);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__sem_u9387)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___ast_u3270((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u3267(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, newSeq__lookups_u5124)(NI len_p0) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__ast_u6323((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__sem_u1737)(tySequence__hMc5eJjVGjq6i857yHjTtg* x_p0, tyTuple__Wipq1508vNWp3jwczem6TQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__8Rn9aEpI9bjowSiva9cw60GCA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__8Rn9aEpI9bjowSiva9cw60GCA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__EFYfInpTvq5UuayU59c5baw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__EFYfInpTvq5UuayU59c5baw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___varpartitions_u1284)(tySequence__hMc5eJjVGjq6i857yHjTtg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__Wipq1508vNWp3jwczem6TQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, add__modulegraphs_u6885)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* x_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__ynMyB4FKj1HYwsLlDC7vBw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__ynMyB4FKj1HYwsLlDC7vBw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__IucIGHa7Bf2A1RksuF5C6A*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__IucIGHa7Bf2A1RksuF5C6A*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].id = y_p1.id;
	(*(*xu_1).p).data[oldLen_1].sym = y_p1.sym;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u3179)(tySequence__48JTohSgTy339bRxHzUD8KA* x_p0, NI32 y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__XiOLiKIdPX5U0AB70DNjbQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)4), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__XiOLiKIdPX5U0AB70DNjbQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u13701)(tyTuple__bnJwOH0eJlAwCAMbr1inhw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u13718((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u13715(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u13681)(tySequence__N589c2UsUgqqOITU2JfIuAQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u13701((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__FfnYizxy8EW3T73hRy9bWzQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u13673)(tySequence__N589c2UsUgqqOITU2JfIuAQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u13681(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__FfnYizxy8EW3T73hRy9bWzQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__FfnYizxy8EW3T73hRy9bWzQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__1RCWgTQyEDGzZv39a0L0udg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__1RCWgTQyEDGzZv39a0L0udg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__bnJwOH0eJlAwCAMbr1inhw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sem_u18847)(tySequence__N589c2UsUgqqOITU2JfIuAQ* s_p0, NI len_p1) {
	shrink__modulegraphs_u13681(s_p0, ((NI)0));
	setLen__modulegraphs_u13673((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u13854)(tyTuple__YG7h1OUHzgfgTeH9cl0U0dw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u13871((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u13868(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u13834)(tySequence__GYDW6wGgERshoSd16jJ3eQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u13854((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__2xPIecK5aI1kPl45dNVVfg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u13826)(tySequence__GYDW6wGgERshoSd16jJ3eQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u13834(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__2xPIecK5aI1kPl45dNVVfg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__2xPIecK5aI1kPl45dNVVfg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Wj9bKru2STjGwpTlwyUrEVA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Wj9bKru2STjGwpTlwyUrEVA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__YG7h1OUHzgfgTeH9cl0U0dw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sem_u19995)(tySequence__GYDW6wGgERshoSd16jJ3eQ* s_p0, NI len_p1) {
	shrink__modulegraphs_u13834(s_p0, ((NI)0));
	setLen__modulegraphs_u13826((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__modulegraphs_u10641)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* x_p0, tyTuple__lGHLhAAUpxgfrnQkIzNrMw* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__P3nKlTxWcYJ29bn9aOCrEnFQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__P3nKlTxWcYJ29bn9aOCrEnFQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__qPCxF3TEe9c5GUYvcQEpaFw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__qPCxF3TEe9c5GUYvcQEpaFw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = (*y_p1).Field0;
	(*(*xu_1).p).data[oldLen_1].Field1.id = (*y_p1).Field1.id;
	(*(*xu_1).p).data[oldLen_1].Field1.sym = (*y_p1).Field1.sym;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u9178)(tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u9195((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u9192(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u9158)(tySequence__9aSa87aKMiolq9a7z3kC0jTw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u9178((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__h3xmmlVt9cH1Qr9a6iHd7FGw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u9151)(tySequence__9aSa87aKMiolq9a7z3kC0jTw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u9158(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__h3xmmlVt9cH1Qr9a6iHd7FGw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__h3xmmlVt9cH1Qr9a6iHd7FGw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__rXin5DrZ8p5RYP2zMTAsqg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__rXin5DrZ8p5RYP2zMTAsqg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u9607)(tySequence__9aSa87aKMiolq9a7z3kC0jTw* s_p0, NI len_p1) {
	shrink__modulegraphs_u9158(s_p0, ((NI)0));
	setLen__modulegraphs_u9151((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u2262)(tyTuple__lGHLhAAUpxgfrnQkIzNrMw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u2279((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u2276(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u2242)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u2262((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__P3nKlTxWcYJ29bn9aOCrEnFQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u2234)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u2242(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__P3nKlTxWcYJ29bn9aOCrEnFQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__P3nKlTxWcYJ29bn9aOCrEnFQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__qPCxF3TEe9c5GUYvcQEpaFw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__qPCxF3TEe9c5GUYvcQEpaFw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__lGHLhAAUpxgfrnQkIzNrMw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u592)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA* obj_p0) {
	eqdestroy___ast_u3151((*obj_p0));
	eqwasMoved___ast_u3148(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u14036)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__TFl78m7ywyQTyT4zs389bvg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u14028)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u14036(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__TFl78m7ywyQTyT4zs389bvg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__TFl78m7ywyQTyT4zs389bvg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__6YewsLaF0A0PiS3nEaN55g*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__6YewsLaF0A0PiS3nEaN55g*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__2QDyOgS51ZMPO0W1pWCY6g));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgmeth_u495)(tySequence__Wd0Vle6gxRCPPoSlNEvfTA* s_p0, NI len_p1) {
	shrink__modulegraphs_u14036(s_p0, ((NI)0));
	setLen__modulegraphs_u14028((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__cgmeth_u730)(tySequence__kHjIdgrpmuSn9cUIIKpSiDg* x_p0, tyTuple__CvjVmQeIfivirDme2r5MRw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__WKgwRMN0CacAqOQYQOKBLA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__WKgwRMN0CacAqOQYQOKBLA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__a9auZ41pjiQ5WdoFl1yp8cQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__a9auZ41pjiQ5WdoFl1yp8cQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__sem_u2016)(tySequence__9bnh9aVmYtKU19btQYqjGktpw* x_p0, tyObject_CandidateError__f049c8Bs49cqj6FTSrUbSmlw* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__dA1wyhF6YAalw2FgXpZhDA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__dA1wyhF6YAalw2FgXpZhDA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__9cpmPeVfo2tmpvqIDmFkCqg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)56), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__9cpmPeVfo2tmpvqIDmFkCqg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].sym = (*y_p1).sym;
	(*(*xu_1).p).data[oldLen_1].firstMismatch.kind = (*y_p1).firstMismatch.kind;
	(*(*xu_1).p).data[oldLen_1].firstMismatch.arg = (*y_p1).firstMismatch.arg;
	(*(*xu_1).p).data[oldLen_1].firstMismatch.formal = (*y_p1).firstMismatch.formal;
	(*(*xu_1).p).data[oldLen_1].diagnostics = (*y_p1).diagnostics;
	(*(*xu_1).p).data[oldLen_1].enabled = (*y_p1).enabled;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, cmpStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NI result;
	NI alen_1;
	NI blen_1;
	NI minlen_1;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	minlen_1 = ((alen_1 <= blen_1) ? alen_1 : blen_1);
	{
		int T5_;
		if (!(((NI)0) < minlen_1)) goto LA3_;
		T5_ = (int)0;
		T5_ = memcmp(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), ((size_t) (minlen_1)));
		result = ((NI) (T5_));
		{
			if (!(result == ((NI)0))) goto LA8_;
			result = (NI)(alen_1 - blen_1);
		}
LA8_: ;
	}
	goto LA1_;
LA3_: ;
	{
		result = (NI)(alen_1 - blen_1);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__sem_u2545)(NimStringV2 x_p0, NimStringV2 y_p1) {
	NI result;
{	{
		if (!eqStrings(x_p0, y_p1)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(cmpStrings(x_p0, y_p1) < 0)) goto LA7_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA7_: ;
	result = ((NI)1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3509)(tySequence__E8pi9b5QNahsURYzXMjh3qw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__sc8fuyIvxojcmS9bBvqLxng*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3501)(tySequence__E8pi9b5QNahsURYzXMjh3qw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u3509(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__sc8fuyIvxojcmS9bBvqLxng* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__sc8fuyIvxojcmS9bBvqLxng*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__B8Tj3xNm54sxzmyOvDK9buw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__B8Tj3xNm54sxzmyOvDK9buw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__47w2DboNEPf69aPgubZdd7Q));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sempass2_u2358)(tySequence__E8pi9b5QNahsURYzXMjh3qw* s_p0, NI len_p1) {
	shrink__semdata_u3509(s_p0, ((NI)0));
	setLen__semdata_u3501((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__sempass2_u5305)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* x_p0, tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__Bu9cf9czC9bYB6tHrNlJa7NEw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__Bu9cf9czC9bYB6tHrNlJa7NEw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__i8t2GAhLNb8T7aVoeBs9coQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__i8t2GAhLNb8T7aVoeBs9coQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u3795)(tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semdata_u3812((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___semdata_u3809(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3775)(tySequence__3B6hFqG0Do0FxDvnNucL7w* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semdata_u3795((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__I17vTDmIw29a0CEB70d9cORg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3767)(tySequence__3B6hFqG0Do0FxDvnNucL7w* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u3775(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__I17vTDmIw29a0CEB70d9cORg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__I17vTDmIw29a0CEB70d9cORg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__x9aM4VUlFe9b5WPkSKx1M5xw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__x9aM4VUlFe9b5WPkSKx1M5xw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sempass2_u4343)(tySequence__3B6hFqG0Do0FxDvnNucL7w* s_p0, NI len_p1) {
	shrink__semdata_u3775(s_p0, ((NI)0));
	setLen__semdata_u3767((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u3659)(tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semdata_u3676((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___semdata_u3673(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3639)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semdata_u3659((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__Bu9cf9czC9bYB6tHrNlJa7NEw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3631)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u3639(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Bu9cf9czC9bYB6tHrNlJa7NEw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Bu9cf9czC9bYB6tHrNlJa7NEw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__i8t2GAhLNb8T7aVoeBs9coQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__i8t2GAhLNb8T7aVoeBs9coQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__sempass2_u5950)(tySequence__9bffTLF0HkxjFCzZL8og4GA* x_p0, tyTuple__09aD69az7aYn14Gt61AHvLIA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__TPbyeV159aGPhQnGwOLv0sQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__TPbyeV159aGPhQnGwOLv0sQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ejG43mfy2bZkAMGFTFM36Q*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__ejG43mfy2bZkAMGFTFM36Q*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__guards_u1415)(tySequence__cLt1WK9c8DYlNqjYIVmv5sQ* x_p0, tyTuple__c0qUCL3KxsVjGYwcv7lQbg y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__RtCW0qtva9cK9bFzmU7PMOLg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__RtCW0qtva9cK9bFzmU7PMOLg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__rpimNUpF6ccwA7ypdSrQWw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__rpimNUpF6ccwA7ypdSrQWw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__sempass2_u5446)(tySequence__8Np6tlClE5az1CyqZdN19bQ* x_p0, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__pushpoppragmas_u190)(tySequence__bdNIx7Bah2llfuqeoTJEWQ* x_p0, tyTuple__kIcKc1aSJCixG4QCidyBAg y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__dURlRCOu2lYEvQwyIoAgZA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__dURlRCOu2lYEvQwyIoAgZA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__QJ6YtTltEHLQKSZzLY9bfhw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)20), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__QJ6YtTltEHLQKSZzLY9bfhw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1293)(tySequence__bdNIx7Bah2llfuqeoTJEWQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__dURlRCOu2lYEvQwyIoAgZA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1285)(tySequence__bdNIx7Bah2llfuqeoTJEWQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u1293(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__dURlRCOu2lYEvQwyIoAgZA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__dURlRCOu2lYEvQwyIoAgZA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__QJ6YtTltEHLQKSZzLY9bfhw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)20), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__QJ6YtTltEHLQKSZzLY9bfhw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__kIcKc1aSJCixG4QCidyBAg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__sempass2_u171)(tySequence__Cw89anHgi6Xla7dgB7Unvmw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__XHKiD6lzOPT9aB4caeVEgLQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__sempass2_u175)(tySequence__Cw89anHgi6Xla7dgB7Unvmw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__sempass2_u171(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__XHKiD6lzOPT9aB4caeVEgLQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__XHKiD6lzOPT9aB4caeVEgLQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__kkWZaAriZFdnsJD9c6W9cA9cg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__kkWZaAriZFdnsJD9c6W9cA9cg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sempass2_u167)(tySequence__Cw89anHgi6Xla7dgB7Unvmw* s_p0, NI len_p1) {
	shrink__sempass2_u171(s_p0, ((NI)0));
	setLen__sempass2_u175((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__Cw89anHgi6Xla7dgB7Unvmw, newSeq__sempass2_u162)(NI len_p0) {
	tySequence__Cw89anHgi6Xla7dgB7Unvmw result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__sempass2_u167((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___sempass2_u246)(tySequence__Cw89anHgi6Xla7dgB7Unvmw dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, add__sempass2_u293)(tySequence__Cw89anHgi6Xla7dgB7Unvmw* x_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__XHKiD6lzOPT9aB4caeVEgLQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__XHKiD6lzOPT9aB4caeVEgLQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__kkWZaAriZFdnsJD9c6W9cA9cg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__kkWZaAriZFdnsJD9c6W9cA9cg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u14292)(tyTuple__UbCNQED4XJUgxOgPHJUcAQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u14309((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u14306(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u14272)(tySequence__T7nNEWoEbKBa0G5Htr45Xw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u14292((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__GQxVYv6jCApzJGKP0DuOLw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u14264)(tySequence__T7nNEWoEbKBa0G5Htr45Xw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u14272(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__GQxVYv6jCApzJGKP0DuOLw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__GQxVYv6jCApzJGKP0DuOLw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Mei9cQiRsNTTJpKxjce4tmw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Mei9cQiRsNTTJpKxjce4tmw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__UbCNQED4XJUgxOgPHJUcAQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sempass2_u514)(tySequence__T7nNEWoEbKBa0G5Htr45Xw* s_p0, NI len_p1) {
	shrink__modulegraphs_u14272(s_p0, ((NI)0));
	setLen__modulegraphs_u14264((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__sempass2_u1966)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* x_p0, tyTuple__V6P73hvHy70PBBwharKjig y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__jk36KpuK5gnIkJBaojY7cw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__jk36KpuK5gnIkJBaojY7cw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__p3jFcjgXmywN1ZHZWKfD1g*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__p3jFcjgXmywN1ZHZWKfD1g*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_u396)(tySequence__SyrQ8FqS1U0ZKpu8mJO6PQ* x_p0, tyObject_VarIndex__xDnEx9cq41ypm0l6yI8haPg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__w3p9aOA1mt9c9aAlQDg0rXtcA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__w3p9aOA1mt9c9aAlQDg0rXtcA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__N3A0BvLnhreSPuUndSdBQg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)72), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__N3A0BvLnhreSPuUndSdBQg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_u557)(tySequence__9aee2Loc4nE9bvjjGuhsI78w* x_p0, tyObject_MutationInfo__PxsvdgDRugMnwwZP8bDvWA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__MH13ExfdlzA45QmDNC3o6A* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__MH13ExfdlzA45QmDNC3o6A*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__V8SGPvr2NEEheXGIwTmAJw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)64), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__V8SGPvr2NEEheXGIwTmAJw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_u981)(tySequence__hMc5eJjVGjq6i857yHjTtg* x_p0, tyTuple__Wipq1508vNWp3jwczem6TQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__8Rn9aEpI9bjowSiva9cw60GCA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__8Rn9aEpI9bjowSiva9cw60GCA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__EFYfInpTvq5UuayU59c5baw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__EFYfInpTvq5UuayU59c5baw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_u698)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__7t9bU3EneK6dsyc6g2BJtmQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__7t9bU3EneK6dsyc6g2BJtmQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__qzrKbs9a7A8QyfauyMVqfVw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__qzrKbs9a7A8QyfauyMVqfVw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__varpartitions_u292)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__7t9bU3EneK6dsyc6g2BJtmQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__varpartitions_u284)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__varpartitions_u292(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__7t9bU3EneK6dsyc6g2BJtmQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__7t9bU3EneK6dsyc6g2BJtmQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__qzrKbs9a7A8QyfauyMVqfVw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__qzrKbs9a7A8QyfauyMVqfVw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__varpartitions_u849)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI* y_p1, NI y_p1Len_0) {
	NI xl_1;
	NI T1_;
	T1_ = (*x_p0).len;
	xl_1 = T1_;
	setLen__varpartitions_u284((&(*x_p0)), ((NI)(xl_1 + y_p1Len_0)));
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (y_p1Len_0-1);
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				(*x_p0).p->data[(NI)(xl_1 + i_1)] = y_p1[i_1];
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u3901)(tySequence__dAjyAaabi52TN36Jp0fAXQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__8Ls8O4CloMJdhVQXyzD0RQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u3894)(tySequence__dAjyAaabi52TN36Jp0fAXQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nilcheck_u3901(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__8Ls8O4CloMJdhVQXyzD0RQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__8Ls8O4CloMJdhVQXyzD0RQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__pgWZugySAfNMGzNhuS9b5zw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__pgWZugySAfNMGzNhuS9b5zw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__X9bWVAqRSgByRpQwn6owzEA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u9279)(tySequence__dAjyAaabi52TN36Jp0fAXQ* s_p0, NI len_p1) {
	shrink__nilcheck_u3901(s_p0, ((NI)0));
	setLen__nilcheck_u3894((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZwidestrs_u81)(NI16* dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__nilcheck_u1475)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___pureZcollectionsZintsets_u230((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___pureZcollectionsZintsets_u227(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u1455)(tySequence__4SBkVvm2CCxNvzruVhJR5g* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__nilcheck_u1475((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__aXUYM59cElXn09cIUizjfk5w*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u1448)(tySequence__4SBkVvm2CCxNvzruVhJR5g* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nilcheck_u1455(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__aXUYM59cElXn09cIUizjfk5w* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__aXUYM59cElXn09cIUizjfk5w*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Dp9bVzDpNllghV0L9c9bLiBdQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)320), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Dp9bVzDpNllghV0L9c9bLiBdQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u360)(tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__X8EcnzlUu7HSxH3DvM59aWA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u353)(tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nilcheck_u360(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__X8EcnzlUu7HSxH3DvM59aWA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__X8EcnzlUu7HSxH3DvM59aWA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8vZEjNj21w0FevtnLFKUZA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)1), ((NI)1));
			(*xu_1).p = ((tyObject_NimSeqPayload__8vZEjNj21w0FevtnLFKUZA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u544)(tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg* s_p0, NI len_p1) {
	shrink__nilcheck_u360(s_p0, ((NI)0));
	setLen__nilcheck_u353((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg, newSeq__nilcheck_u539)(NI len_p0) {
	tySequence__Ztpn2oM9cgfTuhWpNNlH9ajg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__nilcheck_u544((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__nilcheck_u695)(tySequence__tgZNpA9ayNCNeNkBBBthFtA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___nilcheck_u711((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___nilcheck_u708(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u637)(tySequence__xKcKU9c79cy1NlvTXGoOtyWg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__nilcheck_u695((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__iDl3hAQU2o8nEd0sv7D22w*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u641)(tySequence__xKcKU9c79cy1NlvTXGoOtyWg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nilcheck_u637(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__iDl3hAQU2o8nEd0sv7D22w* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__iDl3hAQU2o8nEd0sv7D22w*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__FqetbPaJVPjS9cTFy00BByA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__FqetbPaJVPjS9cTFy00BByA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1].len = 0; (*(*xu_1).p).data[i_1].p = NIM_NIL;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u633)(tySequence__xKcKU9c79cy1NlvTXGoOtyWg* s_p0, NI len_p1) {
	shrink__nilcheck_u637(s_p0, ((NI)0));
	setLen__nilcheck_u641((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__xKcKU9c79cy1NlvTXGoOtyWg, newSeq__nilcheck_u628)(NI len_p0) {
	tySequence__xKcKU9c79cy1NlvTXGoOtyWg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__nilcheck_u633((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u1052)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__d9aGqq8cRSUYOH2ZnoeagyQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u1056)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nilcheck_u1052(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__d9aGqq8cRSUYOH2ZnoeagyQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__d9aGqq8cRSUYOH2ZnoeagyQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__eAiAVcRO27GDld9cTI4uQ5g*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__eAiAVcRO27GDld9cTI4uQ5g*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u1048)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI len_p1) {
	shrink__nilcheck_u1052(s_p0, ((NI)0));
	setLen__nilcheck_u1056((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g, newSeq__nilcheck_u1043)(NI len_p0) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__nilcheck_u1048((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__nilcheck_u1398)(tySequence__4SBkVvm2CCxNvzruVhJR5g* x_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__aXUYM59cElXn09cIUizjfk5w* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__aXUYM59cElXn09cIUizjfk5w*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Dp9bVzDpNllghV0L9c9bLiBdQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)320), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__Dp9bVzDpNllghV0L9c9bLiBdQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__nilcheck_u4485)(tySequence__tgZNpA9ayNCNeNkBBBthFtA* x_p0, tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__5NIkFqw0MXPqP3gAo8VKkg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__5NIkFqw0MXPqP3gAo8VKkg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__lxJT9bkQbAv4qUaBg9biquXA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__lxJT9bkQbAv4qUaBg9biquXA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].info = y_p1.info;
	(*(*xu_1).p).data[oldLen_1].nilability = y_p1.nilability;
	(*(*xu_1).p).data[oldLen_1].kind = y_p1.kind;
	(*(*xu_1).p).data[oldLen_1].node = y_p1.node;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__nilcheck_u761)(tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___nilcheck_u778((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___nilcheck_u775(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u741)(tySequence__tgZNpA9ayNCNeNkBBBthFtA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__nilcheck_u761((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__5NIkFqw0MXPqP3gAo8VKkg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u733)(tySequence__tgZNpA9ayNCNeNkBBBthFtA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nilcheck_u741(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__5NIkFqw0MXPqP3gAo8VKkg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__5NIkFqw0MXPqP3gAo8VKkg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__lxJT9bkQbAv4qUaBg9biquXA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__lxJT9bkQbAv4qUaBg9biquXA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_History__4bvV5E9b6p0voG0MTSK5Cwg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u1128)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NI));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___nilcheck_u895)(tySequence__xKcKU9c79cy1NlvTXGoOtyWg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___nilcheck_u711(dest_p0.p->data[colontmp_]);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tySequence__tgZNpA9ayNCNeNkBBBthFtA));
}
}
N_LIB_PRIVATE N_NIMCALL(void, add__nilcheck_u8961)(tySequence__XlRvVllIQIinot2wpb0XoA* x_p0, tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__BIZZLwYPl9bMX4kh49cOm8ug* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__BIZZLwYPl9bMX4kh49cOm8ug*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__f9aJ3DJ19bOybfz9csIEAlJmQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__f9aJ3DJ19bOybfz9csIEAlJmQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__nilcheck_u6023)(tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___nilcheck_u6040((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___nilcheck_u6037(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u6003)(tySequence__XlRvVllIQIinot2wpb0XoA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__nilcheck_u6023((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__BIZZLwYPl9bMX4kh49cOm8ug*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u5995)(tySequence__XlRvVllIQIinot2wpb0XoA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nilcheck_u6003(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__BIZZLwYPl9bMX4kh49cOm8ug* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__BIZZLwYPl9bMX4kh49cOm8ug*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__f9aJ3DJ19bOybfz9csIEAlJmQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__f9aJ3DJ19bOybfz9csIEAlJmQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__Amwoxm9cNbZUt5zCAFDHZTQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__nilcheck_u6506)(tySequence__1I4GqOPEtd9ark9cZ2UT20tw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__cNovT9bfrplyGcQDd85WPvA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__nilcheck_u6499)(tySequence__1I4GqOPEtd9ark9cZ2UT20tw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__nilcheck_u6506(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__cNovT9bfrplyGcQDd85WPvA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__cNovT9bfrplyGcQDd85WPvA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__cWSeCEBJE04j6OCqaWmaSA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__cWSeCEBJE04j6OCqaWmaSA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__PijKblgFKtbdIstVEwjmCw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__nilcheck_u6685)(tySequence__1I4GqOPEtd9ark9cZ2UT20tw* s_p0, NI len_p1) {
	shrink__nilcheck_u6506(s_p0, ((NI)0));
	setLen__nilcheck_u6499((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___varpartitions_u1293)(tySequence__hMc5eJjVGjq6i857yHjTtg* dest_p0, tySequence__hMc5eJjVGjq6i857yHjTtg src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___varpartitions_u1284((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, delete__sem_u3227)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, NI i_p1) {
	NI xlX60gensym517__1;
	NI T12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg* T7_;
		NimStringV2 T8_;
		NI T9_;
		T3_ = ((*x_p0).len-1);
		if (!(T3_ < i_p1)) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T7_ = NIM_NIL;
		T7_ = (tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg*) nimNewObj(sizeof(tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg), NIM_ALIGNOF(tyObject_IndexDefect__9cIOj9cQBZH8lEZvCihI6Eyg));
		(*T7_).Sup.Sup.Sup.m_type = (&NTIv2__9cIOj9cQBZH8lEZvCihI6Eyg_);
		(*T7_).Sup.Sup.name = "IndexDefect";
		T8_.len = 0; T8_.p = NIM_NIL;
		colontmpD_ = dollar___systemZdollars_u9(i_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T9_ = (*x_p0).len;
		colontmpD__2 = dollar___systemZdollars_u9(T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T8_ = rawNewString(colontmpD_.len + colontmpD__2.len + 35);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_62);
appendString((&T8_), colontmpD_);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_63);
appendString((&T8_), colontmpD__2);
appendString((&T8_), TM__Q5wkpxktOdTGvlSRo9bzt9aw_64);
		(*T7_).Sup.Sup.message = T8_;
		raiseExceptionEx((Exception*)T7_, "IndexDefect", "delete", "system.nim", 2127);
goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	T12_ = (*x_p0).len;
	xlX60gensym517__1 = T12_;
	{
		NI jX60gensym517__1;
		NI colontmp_;
		NI res_1;
		jX60gensym517__1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (NI)(xlX60gensym517__1 - ((NI)2));
		res_1 = i_p1;
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
				if (!(res_1 <= colontmp_)) goto LA15;
				jX60gensym517__1 = ((NI) (res_1));
				T16_ = NIM_NIL;
				T16_ = (*x_p0).p->data[(NI)(jX60gensym517__1 + ((NI)1))];
				eqwasMoved___ast_u3249((&(*x_p0).p->data[(NI)(jX60gensym517__1 + ((NI)1))]));
				eqsink___ast_u3261(&(*x_p0).p->data[jX60gensym517__1], T16_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 += ((NI)1);
			} LA15: ;
		}
	}
	setLen__ast_u3718((&(*x_p0)), ((NI)(xlX60gensym517__1 - ((NI)1))));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___sem_u3710)(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)8));
			}
LA7_: ;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1);
				if (!T11_) goto LA12_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].Field1)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1, ((NI)8));
			}
LA12_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__IYAk6y4YHp5OEJgCALGjQw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, reset__sem_u3670)(tyTuple__IYAk6y4YHp5OEJgCALGjQw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___ast_u5581((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u5578(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__sem_u3612)(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__sem_u3670((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__mgt4xlAYkzCTQ2AEneHZUg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__sem_u3616)(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__sem_u3612(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__mgt4xlAYkzCTQ2AEneHZUg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__mgt4xlAYkzCTQ2AEneHZUg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__RYHs8BhC4WIrAf3hAV2mZw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__RYHs8BhC4WIrAf3hAV2mZw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__IYAk6y4YHp5OEJgCALGjQw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sem_u3608)(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ* s_p0, NI len_p1) {
	shrink__sem_u3612(s_p0, ((NI)0));
	setLen__sem_u3616((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ, newSeq__sem_u3603)(NI len_p0) {
	tySequence__4j8aBmBZMD9chZMBaxw9bcbQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__sem_u3608((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__sem_u3770)(tySequence__4j8aBmBZMD9chZMBaxw9bcbQ* x_p0, tyTuple__IYAk6y4YHp5OEJgCALGjQw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__mgt4xlAYkzCTQ2AEneHZUg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__mgt4xlAYkzCTQ2AEneHZUg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__RYHs8BhC4WIrAf3hAV2mZw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__RYHs8BhC4WIrAf3hAV2mZw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u2716)(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semdata_u382((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___semdata_u379(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u2696)(tySequence__4zAALtm0xUbRlYWQ2V8K7A* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semdata_u2716((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9aK7YX9bxlc8s2KV3wh8rdkA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u2688)(tySequence__4zAALtm0xUbRlYWQ2V8K7A* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u2696(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9aK7YX9bxlc8s2KV3wh8rdkA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9aK7YX9bxlc8s2KV3wh8rdkA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__5cCooviSXLEf9cwx1D5qZiA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__5cCooviSXLEf9cwx1D5qZiA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semdata_u2668)(tySequence__4zAALtm0xUbRlYWQ2V8K7A* dest_p0, tySequence__4zAALtm0xUbRlYWQ2V8K7A src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__semdata_u2688((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			{
				if (!src_p1.p->data[colontmp_].genericSym) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_].genericSym);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_].genericSym);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3469((&(*(*dest_p0).p->data[colontmp_].genericSym)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_].genericSym, ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_].genericSym = src_p1.p->data[colontmp_].genericSym;
			{
				if (!src_p1.p->data[colontmp_].inst) goto LA21_;
				nimIncRef(src_p1.p->data[colontmp_].inst);
			}
LA21_: ;
			{
				NIM_BOOL T25_;
				T25_ = (NIM_BOOL)0;
				T25_ = nimDecRefIsLast((*dest_p0).p->data[colontmp_].inst);
				if (!T25_) goto LA26_;
				eqdestroy___modulegraphs_u1177((&(*(*dest_p0).p->data[colontmp_].inst)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_].inst, ((NI)8));
			}
LA26_: ;
			(*dest_p0).p->data[colontmp_].inst = src_p1.p->data[colontmp_].inst;
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u2674)(tySequence__4zAALtm0xUbRlYWQ2V8K7A* dest_p0, tySequence__4zAALtm0xUbRlYWQ2V8K7A src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___semdata_u2665((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u2662)(tySequence__4zAALtm0xUbRlYWQ2V8K7A* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u4696)(tySequence__yo9alHJGzX03OXpfmEsBjBQ* x_p0, tyTuple__R9cYIordoMujN7rycr4Y7kw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__x0llOOJlbc9a9bfR3yxGso7A* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__x0llOOJlbc9a9bfR3yxGso7A*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__zoa5ddi9cHbXBirfGRCnd9aQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__zoa5ddi9cHbXBirfGRCnd9aQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u956)(tyTuple__R9cYIordoMujN7rycr4Y7kw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semdata_u973((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___semdata_u970(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u936)(tySequence__yo9alHJGzX03OXpfmEsBjBQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semdata_u956((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__x0llOOJlbc9a9bfR3yxGso7A*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__importer_u1431)(tySequence__SxRJJ9bayPyj0RYzIZTiohA* x_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__UytTSnla1kFXxGvp8gQ9aHw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__UytTSnla1kFXxGvp8gQ9aHw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__xAW5NovMwE9a9b1eN9cJ9b1a7g*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)2), ((NI)2));
		(*xu_1).p = ((tyObject_NimSeqPayload__xAW5NovMwE9a9b1eN9cJ9b1a7g*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__importer_u3610)(NimStringV2* s_p0, tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw x_p1) {
	NimStringV2 colontmpD_;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___wordrecg_u307(x_p1);
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u3061)(tySequence__9bAGqSvkAaFL9bWjsEPslrFA* x_p0, NU32 y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__wAKcmNV09bNcAakf5YD2A9aQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__wAKcmNV09bNcAakf5YD2A9aQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__J4VmartFf3o9c8SALClNLqQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)4), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__J4VmartFf3o9c8SALClNLqQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___stdZenumutils_u116)(NI* dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semdata_u3947)(tyTuple__EbsafWGli8bW2GRJQ9apsjA* obj_p0) {
	eqdestroy___semdata_u3964((&(*obj_p0)));
	eqwasMoved___semdata_u3961(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3927)(tySequence__QqvaCqCpEE1QmQZbcZLi5A* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semdata_u3947((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9btI3rjW0aBVdnbJCkK3HwQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3919)(tySequence__QqvaCqCpEE1QmQZbcZLi5A* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u3927(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9btI3rjW0aBVdnbJCkK3HwQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9btI3rjW0aBVdnbJCkK3HwQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__cIDc6ijU1sfiv43zX9awuvw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__cIDc6ijU1sfiv43zX9awuvw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__EbsafWGli8bW2GRJQ9apsjA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__importer_u2416)(tySequence__QqvaCqCpEE1QmQZbcZLi5A* s_p0, NI len_p1) {
	shrink__semdata_u3927(s_p0, ((NI)0));
	setLen__semdata_u3919((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZosproc_u483)(tySequence__qwqHTkRvwhrRyENtudHQ7g* dest_p0, tySequence__qwqHTkRvwhrRyENtudHQ7g src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___pureZosproc_u474((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___pureZosproc_u471)(tySequence__qwqHTkRvwhrRyENtudHQ7g* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g, eqdup___pureZosproc_u480)(tySequence__qwqHTkRvwhrRyENtudHQ7g src_p0) {
	tySequence__qwqHTkRvwhrRyENtudHQ7g result;
	NI T1_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__pureZosproc_u403((&result), T1_);
	nimCopySeqPayload((&result), (&src_p0), ((NI)8), ((NI)8));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZic_u16118)(tySequence__48JTohSgTy339bRxHzUD8KA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__EnGyyCL9bP9bBkJIIw130JcA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZic_u16111)(tySequence__48JTohSgTy339bRxHzUD8KA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZic_u16118(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__EnGyyCL9bP9bBkJIIw130JcA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__EnGyyCL9bP9bBkJIIw130JcA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__xJHATr8XqGiTUvmTQdd1YA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)4), ((NI)4));
			(*xu_1).p = ((tyObject_NimSeqPayload__xJHATr8XqGiTUvmTQdd1YA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__importer_u1828)(tySequence__AE2UIxl7EbPzzBnmYsjIcw* x_p0, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__zQpJJUpO49adzwEvtl2krQA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__zQpJJUpO49adzwEvtl2krQA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__VJdFAAZtcNZ4cOMpSmdLHw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)336), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__VJdFAAZtcNZ4cOMpSmdLHw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u3405)(tySequence__Bis5AbpONWcIRrPyPJS8Yw* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__AITKefZbNVuXMg9az9b5SUDw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3397)(tySequence__Bis5AbpONWcIRrPyPJS8Yw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semdata_u3405(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__AITKefZbNVuXMg9az9b5SUDw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__AITKefZbNVuXMg9az9b5SUDw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8f5w800P5K7g04o5MnuJZg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__8f5w800P5K7g04o5MnuJZg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__NAaJgGVgNmlGoqmiWxdOHQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__importer_u377)(tySequence__Bis5AbpONWcIRrPyPJS8Yw* s_p0, NI len_p1) {
	shrink__semdata_u3405(s_p0, ((NI)0));
	setLen__semdata_u3397((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZic_u3257)(tySequence__hIPTk9aFdaMMVAOzEbnPyqg* x_p0, tyTuple__7rmdAMLZ8fDd79brQn2ixZA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__G5wzdngs0i9cLnjn6UUm2QA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__G5wzdngs0i9cLnjn6UUm2QA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__CiPf6Xv05KUQiXqTUxpsUA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)12), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__CiPf6Xv05KUQiXqTUxpsUA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(NI*, new__sem_u29364)(void) {
	NI* result;
	NI* r_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	r_1 = NIM_NIL;
	eqdestroy___vm_u14408(r_1);
	r_1 = (NI*) nimNewObj(sizeof(NI), NIM_ALIGNOF(NI));
	result = r_1;
	eqwasMoved___vm_u14405(&r_1);
	eqdestroy___vm_u14408(r_1);
	goto BeforeRet_;
	{
		LA1_:;
	}
	{
		eqdestroy___vm_u14408(r_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u1724)(tyTuple__DfjLoSEvFkvlneCb5GSa9cQ* obj_p0) {
	eqdestroy___cgendata_u1741((&(*obj_p0)));
	eqwasMoved___cgendata_u1738(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1704)(tySequence__zpKGgayc1mFyemMGMuK9a2w* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__cgendata_u1724((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__Tg51nuRTSn1RaKhJaazjFQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1696)(tySequence__zpKGgayc1mFyemMGMuK9a2w* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u1704(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Tg51nuRTSn1RaKhJaazjFQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Tg51nuRTSn1RaKhJaazjFQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__u9cIZq8cS7q3ggB6KdsCNVQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)48), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__u9cIZq8cS7q3ggB6KdsCNVQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__DfjLoSEvFkvlneCb5GSa9cQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgendata_u2155)(tySequence__zpKGgayc1mFyemMGMuK9a2w* s_p0, NI len_p1) {
	shrink__cgendata_u1704(s_p0, ((NI)0));
	setLen__cgendata_u1696((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u817)(tyTuple__GhsGHTmri9bgdv8XapNtpTg* obj_p0) {
	eqdestroy___cgendata_u834((&(*obj_p0)));
	eqwasMoved___cgendata_u831(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u797)(tySequence__9cbEQVGky3gHl4QEC3q4Sow* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__cgendata_u817((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9asO9cshOF4y9cfdguzBg29a7A*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u789)(tySequence__9cbEQVGky3gHl4QEC3q4Sow* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u797(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9asO9cshOF4y9cfdguzBg29a7A* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9asO9cshOF4y9cfdguzBg29a7A*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__zNLeo3X29akF2Ap409cLy3lw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__zNLeo3X29akF2Ap409cLy3lw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__GhsGHTmri9bgdv8XapNtpTg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgen_u2035)(tySequence__9cbEQVGky3gHl4QEC3q4Sow* s_p0, NI len_p1) {
	shrink__cgendata_u797(s_p0, ((NI)0));
	setLen__cgendata_u789((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1439)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__PtLz9bQbFWDN9aLSpHtqdEmA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1431)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u1439(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__PtLz9bQbFWDN9aLSpHtqdEmA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__PtLz9bQbFWDN9aLSpHtqdEmA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__0KWqNVfFHBrBbvQ3rkt2qw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__0KWqNVfFHBrBbvQ3rkt2qw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__9agFg9cuYsNvckAbTfHAsTSA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__sighashes_u2239)(tySequence__9bRXJy1JXrQ4hWpStaKBpXg* s_p0, NI len_p1) {
	shrink__cgendata_u1439(s_p0, ((NI)0));
	setLen__cgendata_u1431((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u612)(tyTuple__XOVT24GHXwqiEj5GCsEGCA* obj_p0) {
	eqdestroy___pureZosproc_u1951((*obj_p0));
	eqwasMoved___pureZosproc_u1948(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u554)(tySequence__jwzrUFjG9akTIJTBBFvvqxw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__cgendata_u612((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9bDpynnYoGERDv29b2zzrHBA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u558)(tySequence__jwzrUFjG9akTIJTBBFvvqxw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u554(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9bDpynnYoGERDv29b2zzrHBA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9bDpynnYoGERDv29b2zzrHBA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__uxcJrKhywutDkyBihRCp8A*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__uxcJrKhywutDkyBihRCp8A*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__XOVT24GHXwqiEj5GCsEGCA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgendata_u550)(tySequence__jwzrUFjG9akTIJTBBFvvqxw* s_p0, NI len_p1) {
	shrink__cgendata_u554(s_p0, ((NI)0));
	setLen__cgendata_u558((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u1588)(tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___cgendata_u718((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___cgendata_u715(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1568)(tySequence__fVUhfWxkucMvZhVKGrAHuA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__cgendata_u1588(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__OxcAsbxTCnOB3tNBCMOKmQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1560)(tySequence__fVUhfWxkucMvZhVKGrAHuA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u1568(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__OxcAsbxTCnOB3tNBCMOKmQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__OxcAsbxTCnOB3tNBCMOKmQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__w8RH3U9c4N9cJ9a7RfqWxNKlQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__w8RH3U9c4N9cJ9a7RfqWxNKlQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u1220)(tyTuple__xYhUhS7X82rKTqbT9bRfCnw* obj_p0) {
	eqdestroy___packagesZdocutilsZrst_u1237((&(*obj_p0)));
	eqwasMoved___packagesZdocutilsZrst_u1234(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u1200)(tySequence__7lEisrXlQEzwtUKW5pzRCw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u1220((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__OgCJ17saq1nSO9as9agMdsCw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u1193)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u1200(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__OgCJ17saq1nSO9as9agMdsCw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__OgCJ17saq1nSO9as9agMdsCw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__CvDo7kJ9bzhvslYp8QzYe5w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__CvDo7kJ9bzhvslYp8QzYe5w*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__xYhUhS7X82rKTqbT9bRfCnw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u1472)(tySequence__7lEisrXlQEzwtUKW5pzRCw* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrst_u1200(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrst_u1193((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__icZic_u18754)(NimStringV2* s_p0, NI32 x_p1) {
	addInt__stdZprivateZdigitsutils_u204(s_p0, ((NI) (x_p1)));
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pipelines_u144)(NimStringV2* s_p0, NIM_BOOL x_p1) {
	NimStringV2 colontmpD_;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = nimBoolToStr(x_p1);
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u7086)(tyTuple__zExIg9bDTcVf2FHROUpzoow* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u7102((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u7099(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u7029)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u7086((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__KfASkEYFzOb1wwm3izC5Qw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u7033)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u7029(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__KfASkEYFzOb1wwm3izC5Qw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__KfASkEYFzOb1wwm3izC5Qw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__GKLkcFK9bXhhfQVfVIZSsjw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__GKLkcFK9bXhhfQVfVIZSsjw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__zExIg9bDTcVf2FHROUpzoow));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__modulegraphs_u7025)(tySequence__q9cHvMDDxYU1hSCdG4YwIhA* s_p0, NI len_p1) {
	shrink__modulegraphs_u7029(s_p0, ((NI)0));
	setLen__modulegraphs_u7033((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u1841)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u1858((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u1855(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u2422)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u1841((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__ynMyB4FKj1HYwsLlDC7vBw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u2414)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u2422(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__ynMyB4FKj1HYwsLlDC7vBw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__ynMyB4FKj1HYwsLlDC7vBw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__IucIGHa7Bf2A1RksuF5C6A*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__IucIGHa7Bf2A1RksuF5C6A*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vtables_u572)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* s_p0, NI len_p1) {
	shrink__modulegraphs_u2422(s_p0, ((NI)0));
	setLen__modulegraphs_u2414((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__olFOFaYzOJN9aV5BWqK4b9bA, newSeq__vtables_u567)(NI len_p0) {
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__vtables_u572((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u14184)(tyTuple__V6P73hvHy70PBBwharKjig* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___ast_u5812((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u5809(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__modulegraphs_u14164)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__modulegraphs_u14184((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__jk36KpuK5gnIkJBaojY7cw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__modulegraphs_u14156)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__modulegraphs_u14164(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__jk36KpuK5gnIkJBaojY7cw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__jk36KpuK5gnIkJBaojY7cw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__p3jFcjgXmywN1ZHZWKfD1g*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__p3jFcjgXmywN1ZHZWKfD1g*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__V6P73hvHy70PBBwharKjig));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__vtables_u716)(tySequence__juxPMVNF1FoR2ltzeQu8NQ* s_p0, NI len_p1) {
	shrink__modulegraphs_u14164(s_p0, ((NI)0));
	setLen__modulegraphs_u14156((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__juxPMVNF1FoR2ltzeQu8NQ, newSeq__vtables_u711)(NI len_p0) {
	tySequence__juxPMVNF1FoR2ltzeQu8NQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__vtables_u716((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___dfa_u1525)(tySequence__1xFov7v9c2rs44orw6d9bPmw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			switch (dest_p0.p->data[colontmp_].kind) {
			case ((tyEnum_InstrKind__xkE9c36M77yqw0WqXYKG9aAg)0):
			case ((tyEnum_InstrKind__xkE9c36M77yqw0WqXYKG9aAg)2):
			case ((tyEnum_InstrKind__xkE9c36M77yqw0WqXYKG9aAg)1):
			{
			}
			break;
			case ((tyEnum_InstrKind__xkE9c36M77yqw0WqXYKG9aAg)3):
			case ((tyEnum_InstrKind__xkE9c36M77yqw0WqXYKG9aAg)4):
			{
				{
					NIM_BOOL T8_;
					T8_ = (NIM_BOOL)0;
					T8_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_]._kind_2.n);
					if (!T8_) goto LA9_;
					eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_]._kind_2.n)));
					nimRawDispose(dest_p0.p->data[colontmp_]._kind_2.n, ((NI)8));
				}
LA9_: ;
			}
			break;
			default: __builtin_unreachable();
			}
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___dfa_u1534)(tySequence__1xFov7v9c2rs44orw6d9bPmw* dest_p0, tySequence__1xFov7v9c2rs44orw6d9bPmw src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___dfa_u1525((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, add__dfa_u830)(tySequence__ASKXHf9aJJjLj0hSZ39ci19cA* x_p0, tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__w2Yxjbp9cPR9axG5zMX2ZJDQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__w2Yxjbp9cPR9axG5zMX2ZJDQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Z87I9cxqtjAbepz89aHXS7eg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__Z87I9cxqtjAbepz89aHXS7eg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__dfa_u119)(tySequence__1xFov7v9c2rs44orw6d9bPmw* x_p0, tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__5ysMwE3bSaZW3caCX0Ttzg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__5ysMwE3bSaZW3caCX0Ttzg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__prYsw3adJsXiAStbTYEyUA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__prYsw3adJsXiAStbTYEyUA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__dfa_u299)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__wt39cjGYh5Guxqsbc3o6hQA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__wt39cjGYh5Guxqsbc3o6hQA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__nDLEjClwgABDf30b81MZug*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__nDLEjClwgABDf30b81MZug*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__dfa_u1081)(tySequence__gGvy9cKEpHEX9cA4gF5mzkxA* x_p0, tyTuple__MDblJIdBvEzk3cvDpORS3w y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__Cbt9aJKw9bTRLyD7sNsbPszg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__Cbt9aJKw9bTRLyD7sNsbPszg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__mIMn1lPcHyJESWpGlGgV3w*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__mIMn1lPcHyJESWpGlGgV3w*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__dfa_u904)(tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___dfa_u164((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___dfa_u161(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__dfa_u884)(tySequence__1xFov7v9c2rs44orw6d9bPmw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__dfa_u904((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__5ysMwE3bSaZW3caCX0Ttzg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__dfa_u877)(tySequence__1xFov7v9c2rs44orw6d9bPmw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__dfa_u884(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__5ysMwE3bSaZW3caCX0Ttzg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__5ysMwE3bSaZW3caCX0Ttzg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__prYsw3adJsXiAStbTYEyUA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__prYsw3adJsXiAStbTYEyUA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_Instr__q6FqGagLCvmrvQAVu3oy4g));
					(*(*xu_1).p).data[i_1].kind = ((tyEnum_InstrKind__xkE9c36M77yqw0WqXYKG9aAg)0);
					(*(*xu_1).p).data[i_1].dest = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__dfa_u466)(tyTuple__MDblJIdBvEzk3cvDpORS3w* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___dfa_u483((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___dfa_u480(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__dfa_u446)(tySequence__gGvy9cKEpHEX9cA4gF5mzkxA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__dfa_u466((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__Cbt9aJKw9bTRLyD7sNsbPszg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__dfa_u439)(tySequence__gGvy9cKEpHEX9cA4gF5mzkxA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__dfa_u446(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__Cbt9aJKw9bTRLyD7sNsbPszg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__Cbt9aJKw9bTRLyD7sNsbPszg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__mIMn1lPcHyJESWpGlGgV3w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__mIMn1lPcHyJESWpGlGgV3w*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__MDblJIdBvEzk3cvDpORS3w));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__dfa_u401)(tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___dfa_u565((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___dfa_u562(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__dfa_u381)(tySequence__ASKXHf9aJJjLj0hSZ39ci19cA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__dfa_u401((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__w2Yxjbp9cPR9axG5zMX2ZJDQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__dfa_u373)(tySequence__ASKXHf9aJJjLj0hSZ39ci19cA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__dfa_u381(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__w2Yxjbp9cPR9axG5zMX2ZJDQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__w2Yxjbp9cPR9axG5zMX2ZJDQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Z87I9cxqtjAbepz89aHXS7eg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Z87I9cxqtjAbepz89aHXS7eg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TBlock__LegQi0ajkTVtggrD9avD75Q));
					(*(*xu_1).p).data[i_1].isTryBlock = NIM_FALSE;
					(*(*xu_1).p).data[i_1]._isTryBlock_1.label = 0;
					(*(*xu_1).p).data[i_1]._isTryBlock_1.breakFixups.len = 0; (*(*xu_1).p).data[i_1]._isTryBlock_1.breakFixups.p = NIM_NIL;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__dfa_u616)(tySequence__qwqHTkRvwhrRyENtudHQ7g* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__wt39cjGYh5Guxqsbc3o6hQA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__dfa_u609)(tySequence__qwqHTkRvwhrRyENtudHQ7g* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__dfa_u616(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__wt39cjGYh5Guxqsbc3o6hQA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__wt39cjGYh5Guxqsbc3o6hQA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__nDLEjClwgABDf30b81MZug*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__nDLEjClwgABDf30b81MZug*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___dfa_u1522)(tySequence__1xFov7v9c2rs44orw6d9bPmw* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, del__optimizer_u173)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, NI i_p1) {
	NI xl_1;
	NI T1_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (*x_p0).len;
	xl_1 = (NI)(T1_ - ((NI)1));
	T2_ = NIM_NIL;
	T2_ = (*x_p0).p->data[xl_1];
	eqwasMoved___ast_u3249((&(*x_p0).p->data[xl_1]));
	eqsink___ast_u3261(&(*x_p0).p->data[i_p1], T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setLen__ast_u3718((&(*x_p0)), (xl_1));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u339)(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* obj_p0) {
	eqdestroy___cgendata_u356((&(*obj_p0)));
	eqwasMoved___cgendata_u353(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u319)(tySequence__W61O50MEQVwc9azCYWJekkw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__cgendata_u339((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__S9b80pdJYZQPsS5N9b2kicxw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u311)(tySequence__W61O50MEQVwc9azCYWJekkw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u319(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__S9b80pdJYZQPsS5N9b2kicxw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__S9b80pdJYZQPsS5N9b2kicxw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__U7B8DwB0W7xf9bVfVHA9aqrA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)80), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__U7B8DwB0W7xf9bVfVHA9aqrA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__cgen_u15740)(tySequence__W61O50MEQVwc9azCYWJekkw* x_p0, tyObject_TBlock__fDCbVpSqONoLX2rTM9b0Stw* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__S9b80pdJYZQPsS5N9b2kicxw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__S9b80pdJYZQPsS5N9b2kicxw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__U7B8DwB0W7xf9bVfVHA9aqrA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)80), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__U7B8DwB0W7xf9bVfVHA9aqrA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__sighashes_u2191)(NU8* obj_p0) {
	eqdestroy___OOZdistZchecksumsZsrcZchecksumsZmd5_u244(obj_p0);
	eqwasMoved___OOZdistZchecksumsZsrcZchecksumsZmd5_u241(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u947)(tySequence__kq9c1GdJLvkYJeijBmsJ20A* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__weU9asdVHowsM0AixRsmNtw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u939)(tySequence__kq9c1GdJLvkYJeijBmsJ20A* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u947(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__weU9asdVHowsM0AixRsmNtw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__weU9asdVHowsM0AixRsmNtw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__i3atYjlhKLPEdlA9agEAgig*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__i3atYjlhKLPEdlA9agEAgig*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__UGkfKgNvKJXAR6NX6Y5gaw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgen_u6335)(tySequence__kq9c1GdJLvkYJeijBmsJ20A* s_p0, NI len_p1) {
	shrink__cgendata_u947(s_p0, ((NI)0));
	setLen__cgendata_u939((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgen_u14886)(tySequence__shxop0zPIs5Ec3k71aCLuQ* s_p0, NI len_p1) {
	shrink__cgen_u14890(s_p0, ((NI)0));
	setLen__cgen_u14894((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__shxop0zPIs5Ec3k71aCLuQ, newSeq__cgen_u14881)(NI len_p0) {
	tySequence__shxop0zPIs5Ec3k71aCLuQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__cgen_u14886((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__semparallel_u120)(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semparallel_u137((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___semparallel_u134(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__semparallel_u100)(tySequence__7Eqk7CViYtlAWKDoMfuEcw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__semparallel_u120((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__AV5et9atQLnjtoDLFs9c0pqw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__semparallel_u92)(tySequence__7Eqk7CViYtlAWKDoMfuEcw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__semparallel_u100(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__AV5et9atQLnjtoDLFs9c0pqw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__AV5et9atQLnjtoDLFs9c0pqw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__wqnZx9am7Gry9bMI0mkOMvPQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)48), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__wqnZx9am7Gry9bMI0mkOMvPQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__semparallel_u866)(tySequence__jXZVXmhly1BClQDJpGni9ag* x_p0, tyTuple__ILpLBib1l58GvVZ4BcToSg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__PDqM9andK9c3w9aDIGEcXk8UQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__PDqM9andK9c3w9aDIGEcXk8UQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__VvMimvmaTnYn8kKdk9c86lg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)40), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__VvMimvmaTnYn8kKdk9c86lg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u335)(tySequence__jXZVXmhly1BClQDJpGni9ag dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)8));
			}
LA7_: ;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1);
				if (!T11_) goto LA12_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field1)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1, ((NI)8));
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field2);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field2)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field2, ((NI)8));
			}
LA17_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__ILpLBib1l58GvVZ4BcToSg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semparallel_u66)(tySequence__7Eqk7CViYtlAWKDoMfuEcw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].stride);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].stride)));
				nimRawDispose(dest_p0.p->data[colontmp_].stride, ((NI)8));
			}
LA7_: ;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].upper);
				if (!T11_) goto LA12_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].upper)));
				nimRawDispose(dest_p0.p->data[colontmp_].upper, ((NI)8));
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].lower);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].lower)));
				nimRawDispose(dest_p0.p->data[colontmp_].lower, ((NI)8));
			}
LA17_: ;
			{
				NIM_BOOL T21_;
				T21_ = (NIM_BOOL)0;
				T21_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].alias);
				if (!T21_) goto LA22_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].alias)));
				nimRawDispose(dest_p0.p->data[colontmp_].alias, ((NI)8));
			}
LA22_: ;
			{
				NIM_BOOL T26_;
				T26_ = (NIM_BOOL)0;
				T26_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].v);
				if (!T26_) goto LA27_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].v)));
				nimRawDispose(dest_p0.p->data[colontmp_].v, ((NI)8));
			}
LA27_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_MonotonicVar__9cEiSSh9bas9a2sLNOBWfqtZg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u15931)(tySequence__1cgZIGFge8OGY6Zlwa9aRnw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field0.snippet);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0.lode);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field0.lode)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0.lode, ((NI)8));
			}
LA7_: ;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].Field1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__IGtaz2jo9ahodpWjWgc5c5A));
}
}
N_LIB_PRIVATE N_NIMCALL(void, add__cgen_u15861)(tySequence__1cgZIGFge8OGY6Zlwa9aRnw* x_p0, tyTuple__IGtaz2jo9ahodpWjWgc5c5A* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__KnDsUGgx2yjp69b8gz0zSYg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__KnDsUGgx2yjp69b8gz0zSYg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Qd9cKL9bcCjHwcgEfiPu7ZXw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)48), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__Qd9cKL9bcCjHwcgEfiPu7ZXw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = (*y_p1).Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = (*y_p1).Field1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__cgendata_u1128)(tyTuple__P9bg2wlfPi4dSSTi3ICCeVA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___cgendata_u1158((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___cgendata_u1155(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__cgendata_u1108)(tySequence__olcP618a61wlx6oJIT9b0sA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__cgendata_u1128((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__YBTuIJlLxSm2mxe1w9cWFrA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__cgendata_u1100)(tySequence__olcP618a61wlx6oJIT9b0sA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__cgendata_u1108(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__YBTuIJlLxSm2mxe1w9cWFrA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__YBTuIJlLxSm2mxe1w9cWFrA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__D4LPGlBSP9aZMmMsu9cDwSuw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__D4LPGlBSP9aZMmMsu9cDwSuw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmp_;
					NIM_BOOL colontmp__2;
					NI colontmp__3;
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					colontmp_ = 0;
					colontmp__2 = 0;
					colontmp__3 = ((NI)0);
					(*(*xu_1).p).data[i_1].Field0 = colontmp_;
					(*(*xu_1).p).data[i_1].Field1 = colontmp__2;
					(*(*xu_1).p).data[i_1].Field2 = colontmp__3;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__cgen_u16326)(tySequence__olcP618a61wlx6oJIT9b0sA* s_p0, NI len_p1) {
	shrink__cgendata_u1108(s_p0, ((NI)0));
	setLen__cgendata_u1100((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__olcP618a61wlx6oJIT9b0sA, newSeq__cgen_u16321)(NI len_p0) {
	tySequence__olcP618a61wlx6oJIT9b0sA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__cgen_u16326((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__cgen_u16386)(tySequence__olcP618a61wlx6oJIT9b0sA* x_p0, tyTuple__P9bg2wlfPi4dSSTi3ICCeVA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__YBTuIJlLxSm2mxe1w9cWFrA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__YBTuIJlLxSm2mxe1w9cWFrA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__D4LPGlBSP9aZMmMsu9cDwSuw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__D4LPGlBSP9aZMmMsu9cDwSuw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].Field0 = y_p1.Field0;
	(*(*xu_1).p).data[oldLen_1].Field1 = y_p1.Field1;
	(*(*xu_1).p).data[oldLen_1].Field2 = y_p1.Field2;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__jsgen_u4028)(NimStringV2* s_p0, tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q x_p1) {
	NimStringV2 colontmpD_;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___ast_u309(x_p1);
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__jsgen_u346)(tySequence__P9aymq2R2Xa8At0XKJ6Bh1A* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__W5tAKfTFLQBWqzn4PRHD2A*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__jsgen_u339)(tySequence__P9aymq2R2Xa8At0XKJ6Bh1A* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__jsgen_u346(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__W5tAKfTFLQBWqzn4PRHD2A* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__W5tAKfTFLQBWqzn4PRHD2A*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__9cD5x9btaprZqa4nYXRlvtqw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__9cD5x9btaprZqa4nYXRlvtqw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TBlock__e4aohBvIZbqlrYGhrE9cgpw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__jsgen_u3587)(NimStringV2* s_p0, tyEnum_TJSTypeKind__U9cmBOKBrf9bpo9coDvm2txBg x_p1) {
	NimStringV2 colontmpD_;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___jsgen_u58(x_p1);
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u132)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* x_p0, tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__ZhzDsOEyq73Ti8kBnPUVAQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__ZhzDsOEyq73Ti8kBnPUVAQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__YsSBpIEgPJDz0K9aFZPtHFg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__YsSBpIEgPJDz0K9aFZPtHFg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrstast_u268)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___packagesZdocutilsZrstast_u285((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___packagesZdocutilsZrstast_u282(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrstast_u248)(tySequence__LqZapiAqCFeXPQZdoIAUew* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrstast_u268(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__bbuzn26SpE2aMsRysMBtPw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrstast_u241)(tySequence__LqZapiAqCFeXPQZdoIAUew* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrstast_u248(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__bbuzn26SpE2aMsRysMBtPw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__bbuzn26SpE2aMsRysMBtPw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__LiYZJx3MkkRTPACuQG4JSg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__LiYZJx3MkkRTPACuQG4JSg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u546)(tySequence__kxu4GK0onha2t9bo86mdVAg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__t78Q6fZVjKweNlSemiuCdA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u539)(tySequence__kxu4GK0onha2t9bo86mdVAg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__docgen_u546(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__t78Q6fZVjKweNlSemiuCdA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__t78Q6fZVjKweNlSemiuCdA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__cRENl2YvyxBdbrl9a5PTnJQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__cRENl2YvyxBdbrl9a5PTnJQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__xDU9bZmv1ZbZkJDaATBekIQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u765)(tySequence__kxu4GK0onha2t9bo86mdVAg* s_p0, NI len_p1) {
	shrink__docgen_u546(s_p0, ((NI)0));
	setLen__docgen_u539((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u3922)(tySequence__Ygtgme9cSsBUPbXwOprm43Q dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].symbol);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrst_u3931)(tySequence__Ygtgme9cSsBUPbXwOprm43Q* dest_p0, tySequence__Ygtgme9cSsBUPbXwOprm43Q src_p1) {
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___packagesZdocutilsZrst_u3922((*dest_p0));
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u322)(tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg* obj_p0) {
	eqdestroy___packagesZdocutilsZrst_u339((&(*obj_p0)));
	eqwasMoved___packagesZdocutilsZrst_u336(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u302)(tySequence__Ygtgme9cSsBUPbXwOprm43Q* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u322((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__qdXEIeVz4ljISllV9a1mIOg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u295)(tySequence__Ygtgme9cSsBUPbXwOprm43Q* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u302(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__qdXEIeVz4ljISllV9a1mIOg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__qdXEIeVz4ljISllV9a1mIOg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__IxmSriPVaYy30PbJEUVJNw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)48), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__IxmSriPVaYy30PbJEUVJNw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrstast_u466)(tySequence__LqZapiAqCFeXPQZdoIAUew* x_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__bbuzn26SpE2aMsRysMBtPw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__bbuzn26SpE2aMsRysMBtPw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__LiYZJx3MkkRTPACuQG4JSg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__LiYZJx3MkkRTPACuQG4JSg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u5551)(tySequence__ib5UTyrs9aC6K60sNqKElQA* x_p0, tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__ogAkNBRuOEgem9ccQ23aWJA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__ogAkNBRuOEgem9ccQ23aWJA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__sNyYFNBvMgWzlPRT5RMxMA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)176), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__sNyYFNBvMgWzlPRT5RMxMA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u3161)(tyTuple__Na59bk2YQTCLBWTLyeMrWdA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___packagesZdocutilsZrst_u3178((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___packagesZdocutilsZrst_u3175(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u3141)(tySequence__O9a9cp2XDKWshwC0UDgFP6Pw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u3161((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__oV415pC8JzigLaE3Z8NmRA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u3133)(tySequence__O9a9cp2XDKWshwC0UDgFP6Pw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u3141(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__oV415pC8JzigLaE3Z8NmRA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__oV415pC8JzigLaE3Z8NmRA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8rE9bP9aK9b2hbvymP6dkiK9ag*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__8rE9bP9aK9b2hbvymP6dkiK9ag*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__Na59bk2YQTCLBWTLyeMrWdA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u4384)(tySequence__O9a9cp2XDKWshwC0UDgFP6Pw* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrst_u3141(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrst_u3133((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u2927)(tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___packagesZdocutilsZrst_u2982((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___packagesZdocutilsZrst_u2979(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u2907)(tySequence__ib5UTyrs9aC6K60sNqKElQA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u2927((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__ogAkNBRuOEgem9ccQ23aWJA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u2899)(tySequence__ib5UTyrs9aC6K60sNqKElQA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u2907(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__ogAkNBRuOEgem9ccQ23aWJA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__ogAkNBRuOEgem9ccQ23aWJA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__sNyYFNBvMgWzlPRT5RMxMA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)176), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__sNyYFNBvMgWzlPRT5RMxMA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_AnchorSubst__QbfzsLi5G600g872mHdMoA));
					(*(*xu_1).p).data[i_1].kind = ((tyEnum_AnchorRule__EbWqr3fy26ujwRNegmj44Q)0);
					(*(*xu_1).p).data[i_1]._kind_1.anchorType = 0;
					(*(*xu_1).p).data[i_1]._kind_1.target = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__stdZenvvars_u130)(tyTuple__UV3llMMYFckfui8YMBuUZA* obj_p0) {
	eqdestroy___stdZprivateZospaths2_u306((&(*obj_p0)));
	eqwasMoved___stdZprivateZospaths2_u303(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__stdZenvvars_u110)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__stdZenvvars_u130((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__stdZenvvars_u103)(tySequence__4eQHGndY6XBYpFOH09apV8Q* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__stdZenvvars_u110(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u4273)(tySequence__ib5UTyrs9aC6K60sNqKElQA* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrst_u2907(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrst_u2899((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ib5UTyrs9aC6K60sNqKElQA, newSeq__packagesZdocutilsZrst_u4268)(NI len_p0) {
	tySequence__ib5UTyrs9aC6K60sNqKElQA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__packagesZdocutilsZrst_u4273((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u5680)(tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg* obj_p0) {
	eqdestroy___packagesZdocutilsZrst_u5697((&(*obj_p0)));
	eqwasMoved___packagesZdocutilsZrst_u5694(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u5660)(tySequence__7kOUUrKwg6xKu7wOGcJDlQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u5680((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__jq9bZNIPJ4qu7V4eHQtnzsA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u5653)(tySequence__7kOUUrKwg6xKu7wOGcJDlQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u5660(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__jq9bZNIPJ4qu7V4eHQtnzsA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__jq9bZNIPJ4qu7V4eHQtnzsA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Hlj1rtYTbGj4Dqclc4DkRw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Hlj1rtYTbGj4Dqclc4DkRw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___msgs_u1579)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).Field0);
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u12388)(tySequence__Ygtgme9cSsBUPbXwOprm43Q* x_p0, tyObject_Token__HwlbnU8nwBNhIh4LCAOeTg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__qdXEIeVz4ljISllV9a1mIOg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__qdXEIeVz4ljISllV9a1mIOg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__IxmSriPVaYy30PbJEUVJNw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)48), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__IxmSriPVaYy30PbJEUVJNw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8626)(NIM_CHAR* a_p0, NI a_p0Len_0) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	result = newStringUninit__system_u2684((a_p0Len_0));
	{
		if (!(((NI)0) < a_p0Len_0)) goto LA3_;
		copyMem__system_u1742(((void*) ((&result.p->data[((NI)0)]))), ((void*) ((&a_p0[((NI)0)]))), (a_p0Len_0));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u4127)(tySequence__vz9c2digtAnM8l0FZWLUAGg* x_p0, tyObject_Substitution__zxvFpYuhEMgBV9cBUEcAI0A* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__14YjrtdnP0xUdYuun1A9aLA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__14YjrtdnP0xUdYuun1A9aLA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__yqjN9aCYTixKEQlArWvLUOA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)40), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__yqjN9aCYTixKEQlArWvLUOA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].kind = (*y_p1).kind;
	(*(*xu_1).p).data[oldLen_1].key = (*y_p1).key;
	(*(*xu_1).p).data[oldLen_1].value = (*y_p1).value;
	(*(*xu_1).p).data[oldLen_1].info = (*y_p1).info;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u8213)(tySequence__jK2T9bFw5BWKL8ZZ854oXZg* x_p0, tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__0ZwVzMiBqWU9cqL9caiDoTLA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__0ZwVzMiBqWU9cqL9caiDoTLA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ybmhgz79bSqWRiJKkQ8HQ7w*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)4));
		(*xu_1).p = ((tyObject_NimSeqPayload__ybmhgz79bSqWRiJKkQ8HQ7w*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZosproc_u1315)(tySequence__lBgZ7a89beZGYPl8PiANMTA* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__I3X9al7nCO8sblSUazXxfYg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZosproc_u1308)(tySequence__lBgZ7a89beZGYPl8PiANMTA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__pureZosproc_u1315(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__I3X9al7nCO8sblSUazXxfYg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__I3X9al7nCO8sblSUazXxfYg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Hr9bMo57N1qllFnm9aTT9a04A*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)1), ((NI)1));
			(*xu_1).p = ((tyObject_NimSeqPayload__Hr9bMo57N1qllFnm9aTT9a04A*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u10742)(tySequence__lBgZ7a89beZGYPl8PiANMTA* x_p0, NIM_CHAR y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__I3X9al7nCO8sblSUazXxfYg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__I3X9al7nCO8sblSUazXxfYg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Hr9bMo57N1qllFnm9aTT9a04A*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)1), ((NI)1));
		(*xu_1).p = ((tyObject_NimSeqPayload__Hr9bMo57N1qllFnm9aTT9a04A*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u3585)(tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng* obj_p0) {
	eqdestroy___packagesZdocutilsZrst_u3602((&(*obj_p0)));
	eqwasMoved___packagesZdocutilsZrst_u3599(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u3565)(tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u3585((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__lBNlEWaemNhEZQ6EiE0Fow*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u3557)(tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u3565(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__lBNlEWaemNhEZQ6EiE0Fow* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__lBNlEWaemNhEZQ6EiE0Fow*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__asMbT9bP9ckVukoIEqEckgeg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)88), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__asMbT9bP9ckVukoIEqEckgeg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__zRV1q8K3MINNVxW2Z9aU7Ng));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u14254)(tySequence__mQLVW9aAdq9aAi9aGNi0iC9chg* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrst_u3565(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrst_u3557((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u15535)(tySequence__7kOUUrKwg6xKu7wOGcJDlQ* x_p0, tyObject_ManualAnchor__9c44pyIS9bU9azHBLM69b4CmQg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__jq9bZNIPJ4qu7V4eHQtnzsA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__jq9bZNIPJ4qu7V4eHQtnzsA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Hlj1rtYTbGj4Dqclc4DkRw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)40), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__Hlj1rtYTbGj4Dqclc4DkRw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u8152)(tySequence__vdmFdgox3dhDOMkkFi9ayfg* x_p0, tyTuple__4Ywt2LYBMs9aMJ09cL7digow* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__T1eqKrYZfdKyRHrCorPNEA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__T1eqKrYZfdKyRHrCorPNEA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__89cqvepx69ccuFWso2QMjj1w*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)48), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__89cqvepx69ccuFWso2QMjj1w*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u11899)(tySequence__qagWYy9b8OIJNg9bWhIaAjyw* x_p0, tyObject_LevelInfo__KZjTutWfS3RhxSg89cxkiqQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__6Pxjw9bWB1WY3zh3hilV9cZg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__6Pxjw9bWB1WY3zh3hilV9cZg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__vCNTtuN37GkJiwKmwrWOyw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__vCNTtuN37GkJiwKmwrWOyw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrst_u3925)(tySequence__Ygtgme9cSsBUPbXwOprm43Q* dest_p0, tySequence__Ygtgme9cSsBUPbXwOprm43Q src_p1) {
	NI T6_;
	NI colontmp_;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__packagesZdocutilsZrst_u295((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			(*dest_p0).p->data[colontmp_].kind = src_p1.p->data[colontmp_].kind;
			(*dest_p0).p->data[colontmp_].ival = src_p1.p->data[colontmp_].ival;
			eqcopy___system_u2694((&(*dest_p0).p->data[colontmp_].symbol), src_p1.p->data[colontmp_].symbol);
			(*dest_p0).p->data[colontmp_].line = src_p1.p->data[colontmp_].line;
			(*dest_p0).p->data[colontmp_].col = src_p1.p->data[colontmp_].col;
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u12796)(tySequence__g9cc9ce4njfC9a8r1mQEl8mIg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__tjcRCxE1NDeNULoDZAR1Yg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u12788)(tySequence__g9cc9ce4njfC9a8r1mQEl8mIg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u12796(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__tjcRCxE1NDeNULoDZAR1Yg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__tjcRCxE1NDeNULoDZAR1Yg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__2ExJM0q52YdctDeHI5gngA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__2ExJM0q52YdctDeHI5gngA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(void*, seqToPtr__packagesZdocutilsZrst_u13008)(tySequence__g9cc9ce4njfC9a8r1mQEl8mIg x_p0) {
	void* result;
	union { tySequence__g9cc9ce4njfC9a8r1mQEl8mIg source; tyObject_NimSeqV2__tjcRCxE1NDeNULoDZAR1Yg dest; } LOC1;
	LOC1.source = x_p0;
	result = ((void*) (LOC1.dest.p));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrst_u13069)(tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ x_p0, tyObject_ColSpec__Pj5Kd9cksSnFDEYTQgs0HeQ y_p1) {
	NIM_BOOL result;
{	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!!((x_p0.start == y_p1.start))) goto LA7_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!!((x_p0.stop == y_p1.stop))) goto LA15_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA15_: ;
	}
LA11_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrst_u12993)(tySequence__g9cc9ce4njfC9a8r1mQEl8mIg x_p0, tySequence__g9cc9ce4njfC9a8r1mQEl8mIg y_p1) {
	NIM_BOOL result;
{	{
		void* T3_;
		void* T4_;
		T3_ = (void*)0;
		T3_ = seqToPtr__packagesZdocutilsZrst_u13008(x_p0);
		T4_ = (void*)0;
		T4_ = seqToPtr__packagesZdocutilsZrst_u13008(y_p1);
		if (!(T3_ == T4_)) goto LA5_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
LA5_: ;
	{
		NI T9_;
		NI T10_;
		T9_ = x_p0.len;
		T10_ = y_p1.len;
		if (!!((T9_ == T10_))) goto LA11_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA11_: ;
	{
		NI i_1;
		NI colontmp_;
		NI T14_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T14_ = x_p0.len;
		colontmp_ = (NI)(T14_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA16;
				i_1 = ((NI) (res_1));
				{
					NIM_BOOL T19_;
					T19_ = (NIM_BOOL)0;
					T19_ = eqeq___packagesZdocutilsZrst_u13069(x_p0.p->data[i_1], y_p1.p->data[i_1]);
					if (!!(T19_)) goto LA20_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
LA20_: ;
				res_1 += ((NI)1);
			} LA16: ;
		}
	}
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u13356)(tySequence__8Np6tlClE5az1CyqZdN19bQ* x_p0, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u13452)(tySequence__8Np6tlClE5az1CyqZdN19bQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u13445)(tySequence__8Np6tlClE5az1CyqZdN19bQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u13452(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u3160)(tyTuple__kNIN44R9cL9cYoYzXmSW4y7w* obj_p0) {
	eqdestroy___docgen_u3177((&(*obj_p0)));
	eqwasMoved___docgen_u3174(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u3140)(tySequence__lCWXucMn9bU7PUqVDK7772w* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__docgen_u3160((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__UfbSPrjWq12UpEcQ5cvcpw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u3132)(tySequence__lCWXucMn9bU7PUqVDK7772w* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__docgen_u3140(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__UfbSPrjWq12UpEcQ5cvcpw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__UfbSPrjWq12UpEcQ5cvcpw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__JjOOUsaDCA9bnEfeAuP0f6g*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__JjOOUsaDCA9bnEfeAuP0f6g*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__kNIN44R9cL9cYoYzXmSW4y7w));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u4680)(tySequence__lCWXucMn9bU7PUqVDK7772w* s_p0, NI len_p1) {
	shrink__docgen_u3140(s_p0, ((NI)0));
	setLen__docgen_u3132((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZdochelpers_u247)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u7984)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* x_p0, tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__yUtpZJvImTQo9bK5xz5kYJw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__yUtpZJvImTQo9bK5xz5kYJw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__6Of5sDwIeeQl9aHgrxiVQng*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)104), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__6Of5sDwIeeQl9aHgrxiVQng*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2472)(tyTuple__30Ti2rm9aDSr5neUSZP6EVQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___docgen_u2489((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___docgen_u2486(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2452)(tySequence__uAwiTxV3boseSy9a9cSsXHEA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__docgen_u2472((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__1TKHLyyLNkNmpOAP9bh7GLA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2444)(tySequence__uAwiTxV3boseSy9a9cSsXHEA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__docgen_u2452(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__1TKHLyyLNkNmpOAP9bh7GLA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__1TKHLyyLNkNmpOAP9bh7GLA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__hB9aHrhbUnNwHgNUQwrnGzQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__hB9aHrhbUnNwHgNUQwrnGzQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__30Ti2rm9aDSr5neUSZP6EVQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u6771)(tySequence__uAwiTxV3boseSy9a9cSsXHEA* s_p0, NI len_p1) {
	shrink__docgen_u2452(s_p0, ((NI)0));
	setLen__docgen_u2444((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2333)(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___docgen_u2350((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___docgen_u2347(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2313)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__docgen_u2333((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__yUtpZJvImTQo9bK5xz5kYJw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2305)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__docgen_u2313(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__yUtpZJvImTQo9bK5xz5kYJw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__yUtpZJvImTQo9bK5xz5kYJw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__6Of5sDwIeeQl9aHgrxiVQng*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)104), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__6Of5sDwIeeQl9aHgrxiVQng*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_Item__6YT6w3nuWvd9a2fq9adrqT9cg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2174)(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___docgen_u160((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___docgen_u157(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2154)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__docgen_u2174((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__ZhzDsOEyq73Ti8kBnPUVAQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2147)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__docgen_u2154(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__ZhzDsOEyq73Ti8kBnPUVAQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__ZhzDsOEyq73Ti8kBnPUVAQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__YsSBpIEgPJDz0K9aFZPtHFg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__YsSBpIEgPJDz0K9aFZPtHFg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ));
					(*(*xu_1).p).data[i_1].isRst = NIM_FALSE;
					(*(*xu_1).p).data[i_1]._isRst_2.str.len = 0; (*(*xu_1).p).data[i_1]._isRst_2.str.p = NIM_NIL;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u6654)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* s_p0, NI len_p1) {
	shrink__docgen_u2313(s_p0, ((NI)0));
	setLen__docgen_u2305((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__b9cVyuSHmrW80P0ZGgU2KHA, newSeq__docgen_u6649)(NI len_p0) {
	tySequence__b9cVyuSHmrW80P0ZGgU2KHA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__docgen_u6654((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___int128_u881)(NIM_CHAR* dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, insert__system_u8271)(NimStringV2* x_p0, NimStringV2 item_p1, NI i_p2) {
	NI xl_1;
	NI j_1;
{	{
		if (!(item_p1.len == ((NI)0))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	xl_1 = (*x_p0).len;
	setLengthStrV2((&(*x_p0)), ((NI)(xl_1 + item_p1.len)));
	j_1 = (NI)(xl_1 - ((NI)1));
	{
		while (1) {
			if (!(i_p2 <= j_1)) goto LA6;
			nimPrepareStrMutationV2((&(*x_p0)));
			(*x_p0).p->data[(NI)(j_1 + item_p1.len)] = (*x_p0).p->data[j_1];
			eqwasMoved___int128_u881((&(*x_p0).p->data[j_1]));
			j_1 -= ((NI)1);
		} LA6: ;
	}
	j_1 = ((NI)0);
	{
		while (1) {
			if (!(j_1 < item_p1.len)) goto LA8;
			nimPrepareStrMutationV2((&(*x_p0)));
			(*x_p0).p->data[(NI)(j_1 + i_p2)] = item_p1.p->data[j_1];
			j_1 += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u8039)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* x_p0, tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__D8j6RTfYMSkIst53FjTViA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__D8j6RTfYMSkIst53FjTViA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__hLNcDnR7bJ4wjvQz9ahH6JA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__hLNcDnR7bJ4wjvQz9ahH6JA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2781)(tyTuple__RrY3dT8dfTceE0s6Bv9bxJw* obj_p0) {
	eqdestroy___docgen_u2798((&(*obj_p0)));
	eqwasMoved___docgen_u2795(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2761)(tySequence__9at3Cmn7xIajy679cMZSmybg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__docgen_u2781((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9aud9b4Q3q9cilO02NybLywdQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2753)(tySequence__9at3Cmn7xIajy679cMZSmybg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__docgen_u2761(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9aud9b4Q3q9cilO02NybLywdQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9aud9b4Q3q9cilO02NybLywdQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ute2TqMnJ0mHidshPkSn3w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__ute2TqMnJ0mHidshPkSn3w*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__RrY3dT8dfTceE0s6Bv9bxJw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u8202)(tySequence__9at3Cmn7xIajy679cMZSmybg* s_p0, NI len_p1) {
	shrink__docgen_u2761(s_p0, ((NI)0));
	setLen__docgen_u2753((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u2628)(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg* obj_p0) {
	eqdestroy___docgen_u2645((&(*obj_p0)));
	eqwasMoved___docgen_u2642(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__docgen_u2608)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__docgen_u2628((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__D8j6RTfYMSkIst53FjTViA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__docgen_u2600)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__docgen_u2608(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__D8j6RTfYMSkIst53FjTViA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__D8j6RTfYMSkIst53FjTViA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__hLNcDnR7bJ4wjvQz9ahH6JA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__hLNcDnR7bJ4wjvQz9ahH6JA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_TocItem__oSW9aGqIJWbEhkEFiqAKSSg));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__docgen_u8085)(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg* s_p0, NI len_p1) {
	shrink__docgen_u2608(s_p0, ((NI)0));
	setLen__docgen_u2600((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg, newSeq__docgen_u8080)(NI len_p0) {
	tySequence__zeOxdfG9c9aPaJ9cyA0OkEmQg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__docgen_u8085((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u9972)(tySequence__zR5BJ0RqjaJ2JwWCRI3XSQ* x_p0, tyObject_ItemFragment__9cKkh5afVY29bucZKa5Y0qcQ* y_p1, NI y_p1Len_0) {
	NI xl_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (*x_p0).len;
	xl_1 = T1_;
	setLen__docgen_u2147((&(*x_p0)), ((NI)(xl_1 + y_p1Len_0)));
	{
		NI i_1;
		NI colontmp_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = (y_p1Len_0-1);
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				eqcopy___docgen_u163((&(*x_p0).p->data[(NI)(xl_1 + i_1)]), y_p1[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
static N_INLINE(void*, seqToPtr__pureZjson_u2465)(tySequence__fXWXs2NlFKREhy9cn6vokJw x_p0) {
	void* result;
	union { tySequence__fXWXs2NlFKREhy9cn6vokJw source; tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g dest; } LOC1;
	LOC1.source = x_p0;
	result = ((void*) (LOC1.dest.p));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___pureZjson_u2450)(tySequence__fXWXs2NlFKREhy9cn6vokJw x_p0, tySequence__fXWXs2NlFKREhy9cn6vokJw y_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		void* T3_;
		void* T4_;
		T3_ = (void*)0;
		T3_ = seqToPtr__pureZjson_u2465(x_p0);
		T4_ = (void*)0;
		T4_ = seqToPtr__pureZjson_u2465(y_p1);
		if (!(T3_ == T4_)) goto LA5_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
LA5_: ;
	{
		NI T9_;
		NI T10_;
		T9_ = x_p0.len;
		T10_ = y_p1.len;
		if (!!((T9_ == T10_))) goto LA11_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA11_: ;
	{
		NI i_1;
		NI colontmp_;
		NI T14_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T14_ = x_p0.len;
		colontmp_ = (NI)(T14_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA16;
				i_1 = ((NI) (res_1));
				{
					NIM_BOOL T19_;
					T19_ = (NIM_BOOL)0;
					T19_ = eqeq___pureZjson_u2433(x_p0.p->data[i_1], y_p1.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!!(T19_)) goto LA20_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
LA20_: ;
				res_1 += ((NI)1);
			} LA16: ;
		}
	}
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__docgen_u11759)(tySequence__eb7tUf9a8CR5sBO6O3AH67A* x_p0, tyObject_JsonItem__fKtDafNxSWh3S54uQq2Tmw* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__iJtaCkDWWpRT1m7KgS5F7g* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__iJtaCkDWWpRT1m7KgS5F7g*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__VC9cBOrPM9bT6kBhZDcUa6CQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__VC9cBOrPM9bT6kBhZDcUa6CQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1].json = (*y_p1).json;
	(*(*xu_1).p).data[oldLen_1].rst = (*y_p1).rst;
	(*(*xu_1).p).data[oldLen_1].rstField = (*y_p1).rstField;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZjson_u144)(tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___pureZjson_u161((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___pureZjson_u158(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZjson_u124)(tySequence__m9axZwxFfhSNLcoofvKZJYA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__pureZjson_u144((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__WCVwWV7Hn7J7GPKWFg22mg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZjson_u116)(tySequence__m9axZwxFfhSNLcoofvKZJYA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__pureZjson_u124(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__WCVwWV7Hn7J7GPKWFg22mg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__WCVwWV7Hn7J7GPKWFg22mg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__WEyiXw9aq2uG9bJCsS9avRkLg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__WEyiXw9aq2uG9bJCsS9avRkLg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__eR5B9b9c9coYBbO09chTvuMqNQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZjson_u471)(tySequence__m9axZwxFfhSNLcoofvKZJYA* s_p0, NI len_p1) {
	shrink__pureZjson_u124(s_p0, ((NI)0));
	setLen__pureZjson_u116((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__pureZjson_u672)(tySequence__fXWXs2NlFKREhy9cn6vokJw* x_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__JaTznDCkq35V9cuoM5WF0BA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__JaTznDCkq35V9cuoM5WF0BA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__reorder_u1620)(tyTuple__bPZu3GhfjP9cHscH3h9axT6w* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___reorder_u1636((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___reorder_u1633(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__reorder_u1563)(tySequence__NZB65egHQwAniMoFWKcFaw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__reorder_u1620((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__rK9bwjfXgSbEam9bKV1xYDUg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__reorder_u1567)(tySequence__NZB65egHQwAniMoFWKcFaw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__reorder_u1563(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__rK9bwjfXgSbEam9bKV1xYDUg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__rK9bwjfXgSbEam9bKV1xYDUg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__uz9aGs7pgMg2bRYB559byjng*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)640), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__uz9aGs7pgMg2bRYB559byjng*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__bPZu3GhfjP9cHscH3h9axT6w));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__reorder_u1559)(tySequence__NZB65egHQwAniMoFWKcFaw* s_p0, NI len_p1) {
	shrink__reorder_u1563(s_p0, ((NI)0));
	setLen__reorder_u1567((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__NZB65egHQwAniMoFWKcFaw, newSeq__reorder_u1554)(NI len_p0) {
	tySequence__NZB65egHQwAniMoFWKcFaw result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__reorder_u1559((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__reorder_u1244)(tySequence__EHM5DWw09bc16yo24mdZPsw* x_p0, tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__haf1g0PFMgrwcF57Pq0weA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__haf1g0PFMgrwcF57Pq0weA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__jrxRPd9cQJe05e2kdz2CuFA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__jrxRPd9cQJe05e2kdz2CuFA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicStatic)(void* p_p0, TNimTypeV2* desc_p1) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3500(result, cell_1, desc_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___reorder_u38)(tySequence__EHM5DWw09bc16yo24mdZPsw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastCyclicStatic(dest_p0.p->data[colontmp_], ((TNimTypeV2*) ((&NTIv2__mjl9coa4es5lRGs5j7zUDHw_))));
				if (!T6_) goto LA7_;
				eqdestroy___reorder_u59((&(*dest_p0.p->data[colontmp_])));
				nimRawDispose(dest_p0.p->data[colontmp_], ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw*));
}
}
static N_INLINE(void, nimTraceRef)(void* q_p0, TNimTypeV2* desc_p1, void* env_p2) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p2));
		add__system_u3021((&(*j_1).traceStack), p_1, desc_p1);
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___reorder_u50)(tySequence__EHM5DWw09bc16yo24mdZPsw* dest_p0, void* env_p1) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = (*dest_p0).len;
			if (!(colontmp_ < T3_)) goto LA2;
			nimTraceRef(&(*dest_p0).p->data[colontmp_], ((TNimTypeV2*) ((&NTIv2__mjl9coa4es5lRGs5j7zUDHw_))), env_p1);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, reset__reorder_u124)(tyObject_DepNcolonObjectType___mjl9coa4es5lRGs5j7zUDHw** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___reorder_u141((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___reorder_u138(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__reorder_u104)(tySequence__EHM5DWw09bc16yo24mdZPsw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__reorder_u124(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__haf1g0PFMgrwcF57Pq0weA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__reorder_u96)(tySequence__EHM5DWw09bc16yo24mdZPsw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__reorder_u104(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__haf1g0PFMgrwcF57Pq0weA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__haf1g0PFMgrwcF57Pq0weA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__jrxRPd9cQJe05e2kdz2CuFA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__jrxRPd9cQJe05e2kdz2CuFA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__reorder_u719)(tySequence__EHM5DWw09bc16yo24mdZPsw* s_p0, NI len_p1) {
	shrink__reorder_u104(s_p0, ((NI)0));
	setLen__reorder_u96((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__EHM5DWw09bc16yo24mdZPsw, newSeq__reorder_u714)(NI len_p0) {
	tySequence__EHM5DWw09bc16yo24mdZPsw result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__reorder_u719((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__reorder_u1405)(tySequence__pN5ht9bYa9c1VQJ0Er2wvTuA* x_p0, tySequence__EHM5DWw09bc16yo24mdZPsw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__p2zAi8O7jv7NkThV7Wv7Jg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__p2zAi8O7jv7NkThV7Wv7Jg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__X2iaL9ber9aB6QN9bjTXUiXwA*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__X2iaL9ber9aB6QN9bjTXUiXwA*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___reorder_u35)(tySequence__EHM5DWw09bc16yo24mdZPsw* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___reorder_u1700)(tySequence__NZB65egHQwAniMoFWKcFaw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_].Field0.data);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0.head);
				if (!T6_) goto LA7_;
				eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_].Field0.head)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0.head, ((NI)8));
			}
LA7_: ;
			eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_].Field1.data);
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1.head);
				if (!T11_) goto LA12_;
				eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_].Field1.head)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1.head, ((NI)8));
			}
LA12_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__bPZu3GhfjP9cHscH3h9axT6w));
}
}
N_LIB_PRIVATE N_NIMCALL(void, reset__vmdef_u1895)(tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___vmdef_u1912((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___vmdef_u1909(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__vmdef_u1875)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__vmdef_u1895((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__rxauo4ztHD3oKCBNw6YZdQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u1867)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__vmdef_u1875(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__rxauo4ztHD3oKCBNw6YZdQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__rxauo4ztHD3oKCBNw6YZdQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Npgmi4jcd6ILOol9cT13nsA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Npgmi4jcd6ILOol9cT13nsA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, add__cgen_u31308)(tySequence__fVUhfWxkucMvZhVKGrAHuA* x_p0, tyObject_TCGen__GJ2TTG82D4z6i8QsbkLlYA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__OxcAsbxTCnOB3tNBCMOKmQ* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__OxcAsbxTCnOB3tNBCMOKmQ*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__w8RH3U9c4N9cJ9a7RfqWxNKlQ*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)8), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__w8RH3U9c4N9cJ9a7RfqWxNKlQ*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__sourcemap_u424)(tySequence__u440EGTDYOwkQLE9asdZ6OQ* x_p0, tyObject_Mapping__5X9cm3giTN9aYJbVTF9clmk7A* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__ATMaGzUX9c9bDaC49cuJNExkg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__ATMaGzUX9c9bDaC49cuJNExkg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__aqsvVzVORlY4G59bckSb2fg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)40), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__aqsvVzVORlY4G59bckSb2fg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, add__sourcemap_u94)(tySequence__IWLCUlc3h6FWY379alhl9aaQ* x_p0, tyObject_Segment__9cSimljufAUmxKUYLJk2dhw y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__h9buKeygKKlRU5DBRAThO8w* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__h9buKeygKKlRU5DBRAThO8w*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Lon6j0gkxPT8tK6CiffUWg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__Lon6j0gkxPT8tK6CiffUWg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__sourcemap_u190)(tySequence__IWLCUlc3h6FWY379alhl9aaQ* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__h9buKeygKKlRU5DBRAThO8w*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__sourcemap_u183)(tySequence__IWLCUlc3h6FWY379alhl9aaQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__sourcemap_u190(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__h9buKeygKKlRU5DBRAThO8w* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__h9buKeygKKlRU5DBRAThO8w*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__Lon6j0gkxPT8tK6CiffUWg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)24), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__Lon6j0gkxPT8tK6CiffUWg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_Segment__9cSimljufAUmxKUYLJk2dhw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZjson_u307)(tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g** obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___pureZjson_u324((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___pureZjson_u321(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZjson_u287)(tySequence__fXWXs2NlFKREhy9cn6vokJw* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__pureZjson_u307(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZjson_u279)(tySequence__fXWXs2NlFKREhy9cn6vokJw* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__pureZjson_u287(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__5mAAWSzJuLLVB3cj9ahtK6g*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__JaTznDCkq35V9cuoM5WF0BA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__JaTznDCkq35V9cuoM5WF0BA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u3421)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* obj_p0) {
	eqdestroy___packagesZdocutilsZrst_u3438((&(*obj_p0)));
	eqwasMoved___packagesZdocutilsZrst_u3435(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u3401)(tySequence__vdmFdgox3dhDOMkkFi9ayfg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u3421((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__T1eqKrYZfdKyRHrCorPNEA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u3393)(tySequence__vdmFdgox3dhDOMkkFi9ayfg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u3401(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__T1eqKrYZfdKyRHrCorPNEA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__T1eqKrYZfdKyRHrCorPNEA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__89cqvepx69ccuFWso2QMjj1w*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)48), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__89cqvepx69ccuFWso2QMjj1w*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__4Ywt2LYBMs9aMJ09cL7digow));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u8521)(tySequence__vdmFdgox3dhDOMkkFi9ayfg* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrst_u3401(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrst_u3393((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__vdmFdgox3dhDOMkkFi9ayfg, newSeq__packagesZdocutilsZrst_u8516)(NI len_p0) {
	tySequence__vdmFdgox3dhDOMkkFi9ayfg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__packagesZdocutilsZrst_u8521((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrst_u8401)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* x_p0, tyTuple__4Ywt2LYBMs9aMJ09cL7digow* y_p1) {
	NIM_BOOL result;
{	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!!(((*x_p0).Field0 == (*y_p1).Field0))) goto LA7_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!!(((*x_p0).Field1 == (*y_p1).Field1))) goto LA15_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA15_: ;
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA19_;
		{
			if (!!(((*x_p0).Field2 == (*y_p1).Field2))) goto LA23_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA23_: ;
	}
LA19_: ;
	{
		if (!NIM_TRUE) goto LA27_;
		{
			if (!!(((*x_p0).Field3 == (*y_p1).Field3))) goto LA31_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA31_: ;
	}
LA27_: ;
	{
		if (!NIM_TRUE) goto LA35_;
		{
			if (!!(eqStrings((*x_p0).Field4, (*y_p1).Field4))) goto LA39_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA39_: ;
	}
LA35_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__packagesZdocutilsZrst_u8425)(tyEnum_FootnoteType__AwBNmZfS9azDCP9cRgTUCl6g x_p0, tyEnum_FootnoteType__AwBNmZfS9azDCP9cRgTUCl6g y_p1) {
	NI result;
{	{
		if (!(x_p0 == y_p1)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(x_p0 < y_p1)) goto LA7_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA7_: ;
	result = ((NI)1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___packagesZdocutilsZrst_u8415)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* x_p0, tyTuple__4Ywt2LYBMs9aMJ09cL7digow* y_p1) {
	NIM_BOOL result;
{	{
		NI c_1;
		if (!NIM_TRUE) goto LA3_;
		c_1 = cmp__packagesZdocutilsZrst_u8425((*x_p0).Field0, (*y_p1).Field0);
		{
			if (!(c_1 < ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		{
			if (!(((NI)0) < c_1)) goto LA11_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA11_: ;
	}
LA3_: ;
	{
		NI c_2;
		if (!NIM_TRUE) goto LA15_;
		c_2 = cmp__system_u8247((*x_p0).Field1, (*y_p1).Field1);
		{
			if (!(c_2 < ((NI)0))) goto LA19_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA19_: ;
		{
			if (!(((NI)0) < c_2)) goto LA23_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA23_: ;
	}
LA15_: ;
	{
		NI c_3;
		if (!NIM_TRUE) goto LA27_;
		c_3 = cmp__system_u8247((*x_p0).Field2, (*y_p1).Field2);
		{
			if (!(c_3 < ((NI)0))) goto LA31_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA31_: ;
		{
			if (!(((NI)0) < c_3)) goto LA35_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA35_: ;
	}
LA27_: ;
	{
		NI c_4;
		if (!NIM_TRUE) goto LA39_;
		c_4 = cmp__system_u8247((*x_p0).Field3, (*y_p1).Field3);
		{
			if (!(c_4 < ((NI)0))) goto LA43_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA43_: ;
		{
			if (!(((NI)0) < c_4)) goto LA47_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA47_: ;
	}
LA39_: ;
	{
		NI c_5;
		if (!NIM_TRUE) goto LA51_;
		c_5 = cmp__system_u1563((*x_p0).Field4, (*y_p1).Field4);
		{
			if (!(c_5 < ((NI)0))) goto LA55_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA55_: ;
		{
			if (!(((NI)0) < c_5)) goto LA59_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA59_: ;
	}
LA51_: ;
	result = NIM_FALSE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__packagesZdocutilsZrst_u8396)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* x_p0, tyTuple__4Ywt2LYBMs9aMJ09cL7digow* y_p1) {
	NI result;
{	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___packagesZdocutilsZrst_u8401(x_p0, y_p1);
		if (!T3_) goto LA4_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = lt___packagesZdocutilsZrst_u8415(x_p0, y_p1);
		if (!T8_) goto LA9_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA9_: ;
	result = ((NI)1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__vdmFdgox3dhDOMkkFi9ayfg, X5BX5D___packagesZdocutilsZrst_u9265)(tyTuple__4Ywt2LYBMs9aMJ09cL7digow* s_p0, NI s_p0Len_0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1) {
	tySequence__vdmFdgox3dhDOMkkFi9ayfg result;
	NI a_1;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)((NI)(s_p0Len_0 - x_p1.b) - a_1) + ((NI)1));
	newSeq__packagesZdocutilsZrst_u8521((&result), (L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				eqcopy___packagesZdocutilsZrst_u3441((&result.p->data[i_1]), (&s_p0[(NI)(i_1 + a_1)]));
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrstidx_u181)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* obj_p0) {
	eqdestroy___packagesZdocutilsZrstidx_u197((&(*obj_p0)));
	eqwasMoved___packagesZdocutilsZrstidx_u194(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrstidx_u123)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrstidx_u181((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__It4LZ0xSvGXxrDnDyxiHAA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrstidx_u127)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrstidx_u123(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__It4LZ0xSvGXxrDnDyxiHAA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__It4LZ0xSvGXxrDnDyxiHAA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__DH8yJOdFxzJMqogBX6j0mg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)112), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__DH8yJOdFxzJMqogBX6j0mg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrstidx_u119)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrstidx_u123(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrstidx_u127((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u16131)(tySequence__LqZapiAqCFeXPQZdoIAUew* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrstast_u248(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrstast_u241((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__LqZapiAqCFeXPQZdoIAUew, newSeq__packagesZdocutilsZrst_u16126)(NI len_p0) {
	tySequence__LqZapiAqCFeXPQZdoIAUew result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__packagesZdocutilsZrst_u16131((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrstgen_u4087)(tySequence__8Np6tlClE5az1CyqZdN19bQ* x_p0, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__auVqhVQpDIkuvh2TjBOU3Q*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)16), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__grFdoktzKGu9aVvO5kA0IJw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrst_u16561)(tySequence__ElKBSoViSyNazy7qD89atSA* x_p0, tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__9bRXa9c9az0Ao4W9aoamrTFXfw* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__9bRXa9c9az0Ao4W9aoamrTFXfw*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__9afNNooT7Cf9bhpARywaHHFg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)72), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__9afNNooT7Cf9bhpARywaHHFg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u6410)(tyTuple__fgn415DvsSyiHk3o9aIYr0w* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___packagesZdocutilsZrst_u6426((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___packagesZdocutilsZrst_u6423(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u6353)(tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u6410((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__r1EXHsatwZ6kMJ1o64DQpA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u6357)(tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u6353(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__r1EXHsatwZ6kMJ1o64DQpA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__r1EXHsatwZ6kMJ1o64DQpA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__U9aGDO66NJKBIUSmR7mvzJg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)56), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__U9aGDO66NJKBIUSmR7mvzJg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__fgn415DvsSyiHk3o9aIYr0w));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u6349)(tySequence__pdOdj3OjB4RCTgPEeNVJ9bQ* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrst_u6353(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrst_u6357((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrst_u6689)(tyTuple__UV3llMMYFckfui8YMBuUZA* x_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* y_p1) {
	NIM_BOOL result;
{	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!!(eqStrings((*x_p0).Field0, (*y_p1).Field0))) goto LA7_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!!(eqStrings((*x_p0).Field1, (*y_p1).Field1))) goto LA15_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA15_: ;
	}
LA11_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrst_u16854)(tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___packagesZdocutilsZrst_u16870((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___packagesZdocutilsZrst_u16867(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrst_u16801)(tySequence__ElKBSoViSyNazy7qD89atSA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrst_u16854((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__9bRXa9c9az0Ao4W9aoamrTFXfw*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrst_u16805)(tySequence__ElKBSoViSyNazy7qD89atSA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrst_u16801(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__9bRXa9c9az0Ao4W9aoamrTFXfw* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__9bRXa9c9az0Ao4W9aoamrTFXfw*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__9afNNooT7Cf9bhpARywaHHFg*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)72), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__9afNNooT7Cf9bhpARywaHHFg*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrst_u16797)(tySequence__ElKBSoViSyNazy7qD89atSA* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrst_u16801(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrst_u16805((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ElKBSoViSyNazy7qD89atSA, newSeq__packagesZdocutilsZrst_u16792)(NI len_p0) {
	tySequence__ElKBSoViSyNazy7qD89atSA result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__packagesZdocutilsZrst_u16797((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u16929)(tySequence__ElKBSoViSyNazy7qD89atSA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].externFilename);
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].target);
				if (!T6_) goto LA7_;
				eqdestroy___packagesZdocutilsZrstast_u173((&(*dest_p0.p->data[colontmp_].target)));
				nimRawDispose(dest_p0.p->data[colontmp_].target, ((NI)8));
			}
LA7_: ;
			eqdestroy___system_u2691(dest_p0.p->data[colontmp_].tooltip);
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_LinkDef__dKiLfAF6nJg4qkLA6rlltw));
}
}
N_LIB_PRIVATE N_NIMCALL(NI, cmp__packagesZdocutilsZrst_u16522)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* x_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* y_p1) {
	NI result;
{	{
		if (!(x_p0 == y_p1)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(x_p0 < y_p1)) goto LA7_;
		result = ((NI)-1);
		goto BeforeRet_;
	}
LA7_: ;
	result = ((NI)1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, amp___docgen_u11262)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ x_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ y_p1) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ result;
	NI T1_;
	NI T2_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = x_p0.len;
	T2_ = y_p1.len;
	newSeq__system_u5402((&result), ((NI)(T1_ + T2_)));
	{
		NI i_1;
		NI colontmp_;
		NI T4_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T4_ = x_p0.len;
		colontmp_ = (NI)(T4_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				NimStringV2 T7_;
				if (!(res_1 <= colontmp_)) goto LA6;
				i_1 = ((NI) (res_1));
				T7_.len = 0; T7_.p = NIM_NIL;
				T7_ = x_p0.p->data[i_1];
				eqwasMoved___system_u2688((&x_p0.p->data[i_1]));
				eqsink___system_u2700((&result.p->data[i_1]), T7_);
				res_1 += ((NI)1);
			} LA6: ;
		}
	}
	{
		NI i_2;
		NI colontmp__2;
		NI T9_;
		NI res_2;
		i_2 = (NI)0;
		colontmp__2 = (NI)0;
		T9_ = y_p1.len;
		colontmp__2 = (NI)(T9_ - ((NI)1));
		res_2 = ((NI)0);
		{
			while (1) {
				NI T12_;
				NimStringV2 T13_;
				if (!(res_2 <= colontmp__2)) goto LA11;
				i_2 = ((NI) (res_2));
				T12_ = x_p0.len;
				T13_.len = 0; T13_.p = NIM_NIL;
				T13_ = y_p1.p->data[i_2];
				eqwasMoved___system_u2688((&y_p1.p->data[i_2]));
				eqsink___system_u2700((&result.p->data[(NI)(i_2 + T12_)]), T13_);
				res_2 += ((NI)1);
			} LA11: ;
		}
	}
	eqdestroy___system_u5509(y_p1);
	eqdestroy___system_u5509(x_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__docgen_u11611)(tySequence__b9cVyuSHmrW80P0ZGgU2KHA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___docgen_u2284((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___docgen_u2281(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZreplayer_u1644)(tySequence__YxH9cgSorHRI8ZPzHf47NNQ* s_p0, NI len_p1) {
	shrink__modulegraphs_u1234(s_p0, ((NI)0));
	setLen__modulegraphs_u1226((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__YxH9cgSorHRI8ZPzHf47NNQ, newSeq__icZreplayer_u1639)(NI len_p0) {
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZreplayer_u1644((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___stdZoserrors_u38)(NI32 dest_p0) {
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u16760)(NI32* obj_p0) {
	eqdestroy___stdZoserrors_u38((*obj_p0));
	eqwasMoved___stdZoserrors_u34(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u16822)(tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___suggestsymdb_u1099((&(*obj_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___suggestsymdb_u1096(obj_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u17481)(tySequence__nSO1ltijM4vhc0UrrXKEqA* obj_p0) {
	eqdestroy___modulegraphs_u11761((*obj_p0));
	eqwasMoved___modulegraphs_u11758(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___icZic_u16088)(tySequence__48JTohSgTy339bRxHzUD8KA* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__48JTohSgTy339bRxHzUD8KA, eqdup___icZic_u16097)(tySequence__48JTohSgTy339bRxHzUD8KA src_p0) {
	tySequence__48JTohSgTy339bRxHzUD8KA result;
	NI T1_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__icZic_u16111((&result), T1_);
	nimCopySeqPayload((&result), (&src_p0), ((NI)4), ((NI)4));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZprivateZosfiles_u282)(NimStringV2* s_p0, tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg x_p1) {
	NimStringV2 colontmpD_;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___stdZprivateZosfiles_u30(x_p1);
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZprivateZosfiles_u238)(NimStringV2* s_p0, tySet_tyEnum_FilePermission__gpXj3SqAxcWRbUz4RaRDEg x_p1) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___stdZprivateZosfiles_u244(x_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
static N_INLINE(void, sysFatal__system_u4222)(NimStringV2 message_p1) {
	NimStringV2 colontmpD_;
	tyObject_ReraiseDefect__rf4J0hIl2XahwR8oH1IVPA* T1_;
{	T1_ = NIM_NIL;
	T1_ = (tyObject_ReraiseDefect__rf4J0hIl2XahwR8oH1IVPA*) nimNewObj(sizeof(tyObject_ReraiseDefect__rf4J0hIl2XahwR8oH1IVPA), NIM_ALIGNOF(tyObject_ReraiseDefect__rf4J0hIl2XahwR8oH1IVPA));
	(*T1_).Sup.Sup.Sup.m_type = (&NTIv2__rf4J0hIl2XahwR8oH1IVPA_);
	(*T1_).Sup.Sup.name = "ReraiseDefect";
	colontmpD_ = eqdup___system_u2697(message_p1);
	(*T1_).Sup.Sup.message = colontmpD_;
	raiseExceptionEx((Exception*)T1_, "ReraiseDefect", "sysFatal", "fatal.nim", 62);
goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void) {
	{
		if (!(currException__system_u3631 == ((Exception*) NIM_NIL))) goto LA3_;
		sysFatal__system_u4222(TM__Q5wkpxktOdTGvlSRo9bzt9aw_66);
	}
	goto LA1_;
LA3_: ;
	{
		nimInErrorMode__system_u4146 += ((NI)1);
	}
LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__options_u1917)(NimStringV2* obj_p0) {
	eqdestroy___system_u2691((*obj_p0));
	eqwasMoved___system_u2688(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__options_u1897)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__options_u1917((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__rpt17CTZKhcmivfqWPh5Ng*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__options_u1889)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__options_u1897(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__rpt17CTZKhcmivfqWPh5Ng* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__rpt17CTZKhcmivfqWPh5Ng*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__YOjgUJccqS0z21apIzbjhw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__YOjgUJccqS0z21apIzbjhw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1].len = 0; (*(*xu_1).p).data[i_1].p = NIM_NIL;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__stdZjsonutils_u491)(NimStringV2* s_p0, tyObject_JsonNodeObj__LZt4ndWMfGQOyH1zUmYA3g* x_p1) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___pureZjson_u4831(x_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addQuoted__pureZjson_u5744)(NimStringV2* s_p0, tyEnum_JsonNodeKind__qvXp5fGPKV9a8zGGwjrKjDA x_p1) {
	NimStringV2 colontmpD_;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = dollar___pureZjson_u23(x_p1);
	prepareAdd((&(*s_p0)), colontmpD_.len + 0);
appendString((&(*s_p0)), colontmpD_);
	eqdestroy___system_u2691(colontmpD_);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__extccomp_u2007)(tyTuple__UV3llMMYFckfui8YMBuUZA* obj_p0) {
	eqdestroy___stdZprivateZospaths2_u306((&(*obj_p0)));
	eqwasMoved___stdZprivateZospaths2_u303(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__extccomp_u1949)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__extccomp_u2007((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__extccomp_u1953)(tySequence__4eQHGndY6XBYpFOH09apV8Q* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__extccomp_u1949(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)32), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(void*, seqToPtr__extccomp_u3141)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ x_p0) {
	void* result;
	union { tySequence__sM4lkSb7zS6F7OVMvW9cffQ source; tyObject_NimSeqV2__u4hnfO1A7zV8BfROqkjUYw dest; } LOC1;
	LOC1.source = x_p0;
	result = ((void*) (LOC1.dest.p));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___extccomp_u3126)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ x_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ y_p1) {
	NIM_BOOL result;
{	{
		void* T3_;
		void* T4_;
		T3_ = (void*)0;
		T3_ = seqToPtr__extccomp_u3141(x_p0);
		T4_ = (void*)0;
		T4_ = seqToPtr__extccomp_u3141(y_p1);
		if (!(T3_ == T4_)) goto LA5_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
LA5_: ;
	{
		NI T9_;
		NI T10_;
		T9_ = x_p0.len;
		T10_ = y_p1.len;
		if (!!((T9_ == T10_))) goto LA11_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA11_: ;
	{
		NI i_1;
		NI colontmp_;
		NI T14_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T14_ = x_p0.len;
		colontmp_ = (NI)(T14_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA16;
				i_1 = ((NI) (res_1));
				{
					if (!!(eqStrings(x_p0.p->data[i_1], y_p1.p->data[i_1]))) goto LA19_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
LA19_: ;
				res_1 += ((NI)1);
			} LA16: ;
		}
	}
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI64, clamp__pureZtimes_u1922)(NI64 x_p0, NI64 a_p1, NI64 b_p2) {
	NI64 result;
{	{
		if (!(x_p0 < a_p1)) goto LA3_;
		result = a_p1;
		goto BeforeRet_;
	}
LA3_: ;
	{
		if (!(b_p2 < x_p0)) goto LA7_;
		result = b_p2;
		goto BeforeRet_;
	}
LA7_: ;
	result = x_p0;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZintegrity_u142)(tySequence__H9bHW2kkjp26MABVBZRr8Ig* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__m0j9bkSujD9aJ8udATfNaPag*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZintegrity_u146)(tySequence__H9bHW2kkjp26MABVBZRr8Ig* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZintegrity_u142(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__m0j9bkSujD9aJ8udATfNaPag* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__m0j9bkSujD9aJ8udATfNaPag*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__s0MwarqxvvP9a6pFjXy44sQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)16), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__s0MwarqxvvP9a6pFjXy44sQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__EJOd8NnRbGOjqpW2d6uq2g));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZintegrity_u138)(tySequence__H9bHW2kkjp26MABVBZRr8Ig* s_p0, NI len_p1) {
	shrink__icZintegrity_u142(s_p0, ((NI)0));
	setLen__icZintegrity_u146((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u655)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u672((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u669(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u1139)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u1156((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u1153(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u2195)(tySequence__9bW2eTK9b7vXE70Sx5VPH1mw* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u2212((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u2209(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__modulegraphs_u2806)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* obj_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___modulegraphs_u2823((*obj_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___modulegraphs_u2820(obj_p0);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZdce_u2567)(tySequence__4SBkVvm2CCxNvzruVhJR5g* s_p0, NI len_p1) {
	shrink__nilcheck_u1455(s_p0, ((NI)0));
	setLen__nilcheck_u1448((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__4SBkVvm2CCxNvzruVhJR5g, newSeq__icZdce_u2562)(NI len_p0) {
	tySequence__4SBkVvm2CCxNvzruVhJR5g result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__icZdce_u2567((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__icZdce_u1890)(tySequence__MboA857W9b3olvEyCWLQeEg* x_p0, tyTuple__jYR27AKllNE6EvJCKQs1WA y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__W7Plkq0qifudpOJp9bAjimg* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__W7Plkq0qifudpOJp9bAjimg*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__1ywxEbsXF8gcMuWhd04qPg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)24), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__1ywxEbsXF8gcMuWhd04qPg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = y_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__icZdce_u325)(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ* obj_p0) {
	eqdestroy___icZdce_u341((&(*obj_p0)));
	eqwasMoved___icZdce_u338(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZdce_u268)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__icZdce_u325((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__EExhi6yk44m40Ni00bMvSQ*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__icZdce_u272)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__icZdce_u268(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__EExhi6yk44m40Ni00bMvSQ* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__EExhi6yk44m40Ni00bMvSQ*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__N3VLS9aKnwCnjctw22os8JA*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)40), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__N3VLS9aKnwCnjctw22os8JA*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__9a3DhYVfcy14Fx42tD0lSEQ));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__icZdce_u264)(tySequence__UuiPn6QjIiUTdSVwX2PZ6w* s_p0, NI len_p1) {
	shrink__icZdce_u268(s_p0, ((NI)0));
	setLen__icZdce_u272((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__icZdce_u2467)(tySequence__MboA857W9b3olvEyCWLQeEg* x_p0, NI newLen_p1) {
	(*((tyObject_NimSeqV2__W7Plkq0qifudpOJp9bAjimg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZdce_u2604)(tySequence__MboA857W9b3olvEyCWLQeEg dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__jYR27AKllNE6EvJCKQs1WA));
}
}
static N_INLINE(void*, seqToPtr__icZcbackend_u603)(tySequence__48JTohSgTy339bRxHzUD8KA x_p0) {
	void* result;
	union { tySequence__48JTohSgTy339bRxHzUD8KA source; tyObject_NimSeqV2__djG3GUuliH4we1JJ7v9aTWQ dest; } LOC1;
	LOC1.source = x_p0;
	result = ((void*) (LOC1.dest.p));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___icZcbackend_u588)(tySequence__48JTohSgTy339bRxHzUD8KA x_p0, tySequence__48JTohSgTy339bRxHzUD8KA y_p1) {
	NIM_BOOL result;
{	{
		void* T3_;
		void* T4_;
		T3_ = (void*)0;
		T3_ = seqToPtr__icZcbackend_u603(x_p0);
		T4_ = (void*)0;
		T4_ = seqToPtr__icZcbackend_u603(y_p1);
		if (!(T3_ == T4_)) goto LA5_;
		result = NIM_TRUE;
		goto BeforeRet_;
	}
LA5_: ;
	{
		NI T9_;
		NI T10_;
		T9_ = x_p0.len;
		T10_ = y_p1.len;
		if (!!((T9_ == T10_))) goto LA11_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
LA11_: ;
	{
		NI i_1;
		NI colontmp_;
		NI T14_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T14_ = x_p0.len;
		colontmp_ = (NI)(T14_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA16;
				i_1 = ((NI) (res_1));
				{
					if (!!((x_p0.p->data[i_1] == y_p1.p->data[i_1]))) goto LA19_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
LA19_: ;
				res_1 += ((NI)1);
			} LA16: ;
		}
	}
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__pureZosproc_u212)(tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ** obj_p0) {
	eqdestroy___pureZosproc_u228((*obj_p0));
	eqwasMoved___pureZosproc_u225(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__pureZosproc_u154)(tySequence__9aHwlozdspjDnjhtzDhmdVg* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__pureZosproc_u212(&(*x_p0).p->data[i_1]);
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__K0sypBe4BNGzcbvtFWY4Ew*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__pureZosproc_u158)(tySequence__9aHwlozdspjDnjhtzDhmdVg* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__pureZosproc_u154(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__K0sypBe4BNGzcbvtFWY4Ew* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__K0sypBe4BNGzcbvtFWY4Ew*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__1BEfsOZcNYUjd4lXnbhEaQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)8), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__1BEfsOZcNYUjd4lXnbhEaQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					(*(*xu_1).p).data[i_1] = 0;
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__pureZosproc_u150)(tySequence__9aHwlozdspjDnjhtzDhmdVg* s_p0, NI len_p1) {
	shrink__pureZosproc_u154(s_p0, ((NI)0));
	setLen__pureZosproc_u158((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__9aHwlozdspjDnjhtzDhmdVg, newSeq__pureZosproc_u145)(NI len_p0) {
	tySequence__9aHwlozdspjDnjhtzDhmdVg result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__pureZosproc_u150((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u319)(tySequence__9aHwlozdspjDnjhtzDhmdVg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastCyclicDyn(dest_p0.p->data[colontmp_]);
				if (!T6_) goto LA7_;
				nimDestroyAndDispose(dest_p0.p->data[colontmp_]);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_ProcessObj__KkmVhVBIhdGPRUKkZJq9cLQ*));
}
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__extccomp_u1945)(tySequence__4eQHGndY6XBYpFOH09apV8Q* s_p0, NI len_p1) {
	shrink__extccomp_u1949(s_p0, ((NI)0));
	setLen__extccomp_u1953((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__4eQHGndY6XBYpFOH09apV8Q, newSeq__extccomp_u1940)(NI len_p0) {
	tySequence__4eQHGndY6XBYpFOH09apV8Q result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__extccomp_u1945((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__extccomp_u2036)(tySequence__4eQHGndY6XBYpFOH09apV8Q* x_p0, tyTuple__UV3llMMYFckfui8YMBuUZA* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__TEYiD4CRlH6QMoR216opmA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)32), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__8tWX2zHcVxDQ9cwFLqH3Mxw*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__packagesZdocutilsZrstgen_u2404)(tyTuple__bvjw5f4vMpB9bESWLU7nvyA* obj_p0) {
	eqdestroy___packagesZdocutilsZrstgen_u1264((&(*obj_p0)));
	eqwasMoved___packagesZdocutilsZrstgen_u1261(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, shrink__packagesZdocutilsZrstgen_u2351)(tySequence__mg32q50AXD9cQ6jovpBmgWA* x_p0, NI newLen_p1) {
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*x_p0).len;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = colontmp_;
		{
			while (1) {
				if (!(newLen_p1 <= res_1)) goto LA4;
				i_1 = ((NI) (res_1));
				reset__packagesZdocutilsZrstgen_u2404((&(*x_p0).p->data[i_1]));
				res_1 -= ((NI)1);
			} LA4: ;
		}
	}
	(*((tyObject_NimSeqV2__plyqYwuv3lTJaE7cjUyreg*) (x_p0))).len = newLen_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrstgen_u2355)(tySequence__mg32q50AXD9cQ6jovpBmgWA* s_p0, NI newlen_p1) {
{	{
		NI T3_;
		T3_ = (*s_p0).len;
		if (!(newlen_p1 < T3_)) goto LA4_;
		shrink__packagesZdocutilsZrstgen_u2351(s_p0, newlen_p1);
	}
	goto LA1_;
LA4_: ;
	{
		NI oldLen_1;
		NI T7_;
		tyObject_NimSeqV2__plyqYwuv3lTJaE7cjUyreg* xu_1;
		T7_ = (*s_p0).len;
		oldLen_1 = T7_;
		{
			if (!(newlen_p1 <= oldLen_1)) goto LA10_;
			goto BeforeRet_;
		}
LA10_: ;
		xu_1 = ((tyObject_NimSeqV2__plyqYwuv3lTJaE7cjUyreg*) (s_p0));
		{
			NIM_BOOL T14_;
			void* T18_;
			T14_ = (NIM_BOOL)0;
			T14_ = ((*xu_1).p == ((tyObject_NimSeqPayload__ceWjhV9bHVjDw9ckC1zzOXDQ*) NIM_NIL));
			if (T14_) goto LA15_;
			T14_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < newlen_p1);
LA15_: ;
			if (!T14_) goto LA16_;
			T18_ = (void*)0;
			T18_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), (NI)(newlen_p1 - oldLen_1), ((NI)136), ((NI)8));
			(*xu_1).p = ((tyObject_NimSeqPayload__ceWjhV9bHVjDw9ckC1zzOXDQ*) (T18_));
		}
LA16_: ;
		(*xu_1).len = newlen_p1;
		{
			NI i_1;
			NI i_2;
			i_1 = (NI)0;
			i_2 = oldLen_1;
			{
				while (1) {
					if (!(i_2 < newlen_p1)) goto LA21;
					i_1 = i_2;
					nimZeroMem((void*)(&(*(*xu_1).p).data[i_1]), sizeof(tyTuple__bvjw5f4vMpB9bESWLU7nvyA));
					i_2 += ((NI)1);
				} LA21: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrstgen_u2347)(tySequence__mg32q50AXD9cQ6jovpBmgWA* s_p0, NI len_p1) {
	shrink__packagesZdocutilsZrstgen_u2351(s_p0, ((NI)0));
	setLen__packagesZdocutilsZrstgen_u2355((&(*s_p0)), len_p1);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___packagesZdocutilsZrstgen_u2085)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* x_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* y_p1) {
	NIM_BOOL result;
{	{
		if (!NIM_TRUE) goto LA3_;
		{
			if (!!(((*x_p0).kind == (*y_p1).kind))) goto LA7_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA7_: ;
	}
LA3_: ;
	{
		if (!NIM_TRUE) goto LA11_;
		{
			if (!!(eqStrings((*x_p0).keyword, (*y_p1).keyword))) goto LA15_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA15_: ;
	}
LA11_: ;
	{
		if (!NIM_TRUE) goto LA19_;
		{
			if (!!(eqStrings((*x_p0).link, (*y_p1).link))) goto LA23_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA23_: ;
	}
LA19_: ;
	{
		if (!NIM_TRUE) goto LA27_;
		{
			if (!!(eqStrings((*x_p0).linkTitle, (*y_p1).linkTitle))) goto LA31_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA31_: ;
	}
LA27_: ;
	{
		if (!NIM_TRUE) goto LA35_;
		{
			if (!!(eqStrings((*x_p0).linkDesc, (*y_p1).linkDesc))) goto LA39_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA39_: ;
	}
LA35_: ;
	{
		if (!NIM_TRUE) goto LA43_;
		{
			if (!!(((*x_p0).line == (*y_p1).line))) goto LA47_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA47_: ;
	}
LA43_: ;
	{
		if (!NIM_TRUE) goto LA51_;
		{
			if (!!(eqStrings((*x_p0).module, (*y_p1).module))) goto LA55_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA55_: ;
	}
LA51_: ;
	{
		if (!NIM_TRUE) goto LA59_;
		{
			if (!!(eqStrings((*x_p0).aux, (*y_p1).aux))) goto LA63_;
			result = NIM_FALSE;
			goto BeforeRet_;
		}
LA63_: ;
	}
LA59_: ;
	result = NIM_TRUE;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrstgen_u1602)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* x_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* y_p1) {
	NI oldLen_1;
	NI T1_;
	tyObject_NimSeqV2__It4LZ0xSvGXxrDnDyxiHAA* xu_1;
	T1_ = (*x_p0).len;
	oldLen_1 = T1_;
	xu_1 = ((tyObject_NimSeqV2__It4LZ0xSvGXxrDnDyxiHAA*) (x_p0));
	{
		NIM_BOOL T4_;
		void* T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = ((*xu_1).p == ((tyObject_NimSeqPayload__DH8yJOdFxzJMqogBX6j0mg*) NIM_NIL));
		if (T4_) goto LA5_;
		T4_ = ((NI)((*(*xu_1).p).cap & ((NI)IL64(-4611686018427387905))) < (NI)(oldLen_1 + ((NI)1)));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_ = (void*)0;
		T8_ = prepareSeqAddUninit(oldLen_1, ((void*) ((*xu_1).p)), ((NI)1), ((NI)112), ((NI)8));
		(*xu_1).p = ((tyObject_NimSeqPayload__DH8yJOdFxzJMqogBX6j0mg*) (T8_));
	}
LA6_: ;
	(*xu_1).len = (NI)(oldLen_1 + ((NI)1));
	(*(*xu_1).p).data[oldLen_1] = (*y_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__36jA1xDCIBAS29cySYLQ7kQ, newSeq__packagesZdocutilsZrstgen_u1665)(NI len_p0) {
	tySequence__36jA1xDCIBAS29cySYLQ7kQ result;
	result.len = 0; result.p = NIM_NIL;
	newSeq__packagesZdocutilsZrstidx_u119((&result), len_p0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getStackTrace__system_u3575)(Exception* e_p0) {
	NimStringV2 result;
	{
		if (!!((e_p0 == 0))) goto LA3_;
		result = dollar___system_u3959((*e_p0).trace);
	}
	goto LA1_;
LA3_: ;
	{
		result = TM__Q5wkpxktOdTGvlSRo9bzt9aw_68;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, reset__vmprofiler_u2442)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA* obj_p0) {
	eqdestroy___lineinfos_u2031((*obj_p0));
	eqwasMoved___lineinfos_u2028(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(void, reset__vmprofiler_u2504)(tyObject_ProfileInfo__RQcB2XBA7ZMf3l5GNRevKw* obj_p0) {
	eqdestroy___vmprofiler_u1185((*obj_p0));
	eqwasMoved___vmprofiler_u1182(obj_p0);
}
N_LIB_PRIVATE N_NIMCALL(NI, getMaxMem__system_u6183)(tyObject_MemRegion__geQtdNZBzEHwnQVqiw9bCeQ* a_p0) {
	NI result;
	result = (((*a_p0).currMem >= (*a_p0).maxMem) ? (*a_p0).currMem : (*a_p0).maxMem);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getMaxMem__system_u7199)(void) {
	NI result;
	result = getMaxMem__system_u6183((&allocator__system_u7164));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getTotalMem__system_u1986)(void) {
	NI result;
	result = allocator__system_u7164.currMem;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getOccupiedMem__system_u1984)(void) {
	NI result;
	result = allocator__system_u7164.occ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, GC_getStatistics__system_u7673)(void) {
	NimStringV2 result;
	NI T1_;
	NI T2_;
	result = TM__Q5wkpxktOdTGvlSRo9bzt9aw_70;
	T1_ = (NI)0;
	T1_ = getTotalMem__system_u1986();
	addInt__stdZprivateZdigitsutils_u204((&result), T1_);
	prepareAdd((&result), 23);
appendString((&result), TM__Q5wkpxktOdTGvlSRo9bzt9aw_72);
	T2_ = (NI)0;
	T2_ = getOccupiedMem__system_u1984();
	addInt__stdZprivateZdigitsutils_u204((&result), T2_);
	nimAddCharV1((&result), 10);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, nimTestErrorFlag)(void) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimInErrorMode__system_u4146;
		if (!(T3_)) goto LA4_;
		T3_ = !((currException__system_u3631 == ((Exception*) NIM_NIL)));
LA4_: ;
		if (!T3_) goto LA5_;
		reportUnhandledError__system_u4140(currException__system_u3631);
		eqsink___system_u3672(&currException__system_u3631, ((Exception*) NIM_NIL));
		exit(((int)1));
	}
LA5_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, atpsystemdotnim_Init000)(void) {
{
	registerSignalHandler__system_u4394();
	initStackBottom();
	nimTestErrorFlag();
}
}

