/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct RootObj RootObj;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw tySequence__AE2UIxl7EbPzzBnmYsjIcw;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content;
typedef struct tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ;
typedef struct tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q tySequence__tsHRsYLyvTCPLlGRExqi7Q;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA tySequence__lAikaRQvUF0uwNAz0U4FFA;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content tySequence__lAikaRQvUF0uwNAz0U4FFA_Content;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A tySequence__4zAALtm0xUbRlYWQ2V8K7A;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA tySequence__9bffTLF0HkxjFCzZL8og4GA;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content tySequence__9bffTLF0HkxjFCzZL8og4GA_Content;
typedef struct tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content;
typedef struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content tySequence__E8pi9b5QNahsURYzXMjh3qw_Content;
typedef struct tyObject_Table__g77QNejuRRKraNk8K2YkoA tyObject_Table__g77QNejuRRKraNk8K2YkoA;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w tySequence__3B6hFqG0Do0FxDvnNucL7w;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content tySequence__3B6hFqG0Do0FxDvnNucL7w_Content;
typedef struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg tyObject_Table__toCaB3NxiVHPRVLgcez0Xg;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ tySequence__KYLoGmc5aaHsSDjEH1FTxQ;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content;
typedef struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyTuple__09aD69az7aYn14Gt61AHvLIA tyTuple__09aD69az7aYn14Gt61AHvLIA;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA;
typedef struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw tySequence__ZUeR9b415wicThQ9cBWO9aYMw;
typedef struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content;
typedef struct tySequence__yo9alHJGzX03OXpfmEsBjBQ tySequence__yo9alHJGzX03OXpfmEsBjBQ;
typedef struct tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content;
typedef struct tyTuple__R9cYIordoMujN7rycr4Y7kw tyTuple__R9cYIordoMujN7rycr4Y7kw;
typedef struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw;
typedef struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw tySequence__hRbbzIynOoxrYjHTIKZ3Gw;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content;
typedef struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w;
typedef struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg;
typedef struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyTuple__N4J9cV4JZGem3ljqqj5rT0Q;
typedef struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg;
typedef struct tyTuple__DTRsWi2kgTewbhN2TT5mbA tyTuple__DTRsWi2kgTewbhN2TT5mbA;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw tySequence__fnH5Zt4fsGx0AgDTOw8pKw;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA tySequence__TLbZ2GqL3Zio1f8bNpj2NA;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content;
typedef struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w tySequence__GH1mmNKNA2QP4n1tnxJf1w;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content;
typedef struct tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA tySequence__TEgqV1E9aHqnwBUoeXjBI9aA;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content;
typedef struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ tyObject_Table__tro5f9chxPVpES1mQpDwZtQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content;
typedef struct tyObject_Profiler__YI4zs2CaXXndlYireD0I8A tyObject_Profiler__YI4zs2CaXXndlYireD0I8A;
typedef struct tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ;
typedef struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ tyObject_Table__lPs28yjGTxD0LzUoPspSBQ;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q tySequence__Fc8Q26tsngy2yxcpyrnT4Q;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content;
typedef struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ;
typedef struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ tySequence__7OXYQ6bHRkhJpRaiS7kiwQ;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A;
typedef struct tyTuple__Oubp8LPEu86EPyDuc56AXg tyTuple__Oubp8LPEu86EPyDuc56AXg;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ;
typedef struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g tyTuple__y6bKAf9a9aaVwun6lVDxSX7g;
typedef struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg;
typedef struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
typedef struct tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A;
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw {
  NI len; tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__uJvLVbod8mnHGzJkQj89bWg[38];
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q {
  NI len; tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content* p;
};
struct tySequence__lAikaRQvUF0uwNAz0U4FFA {
  NI len; tySequence__lAikaRQvUF0uwNAz0U4FFA_Content* p;
};
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__Yik7hgYZHhPeLJ5RsXTPqg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p2);
typedef NU32 tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__JIyBW5s9ba7hfYBnWxDVvgg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p3);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__iXlRd9cBAN0CQpA5dkyhRvw) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__7FLV9alRQFu6LOhr9bksExQQ) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, void* ClE_0);
void* ClE_0;
} tyProc__0qHBYUhlP28E2DV7mVNNAg;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__1nD4dBuhjTAOzMZJo9bmgog) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
typedef NU32 tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__209aOewTLBT6nbWmyvOQFiw) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nOrig_p2, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p3, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p4, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p5);
typedef N_NIMCALL_PTR(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, tyProc__D9aXgBooMpgLrPTmha6q31w) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* prev_p2);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A pt_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, void* ClE_0);
void* ClE_0;
} tyProc__GbPSPD9bjvt0RIJnnVTczJA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fn_p1, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A pt_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, void* ClE_0);
void* ClE_0;
} tyProc__iDJMP540ifFac3zJ49bj2cA;
typedef struct {
N_NIMCALL_PTR(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A pt_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, void* ClE_0);
void* ClE_0;
} tyProc__gq9a76bauTeymgreaiTI9cmg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p2, void* ClE_0);
void* ClE_0;
} tyProc__Gji0NjiFFDU49aJiF3QZF8A;
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A {
  NI len; tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content* p;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__UAj9bGJLVN9cwAsTcRZFyWmg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dc_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p4, NI col_p5);
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
struct tySequence__9bffTLF0HkxjFCzZL8og4GA {
  NI len; tySequence__9bffTLF0HkxjFCzZL8og4GA_Content* p;
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  NI len; tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content* p;
};
struct tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ {
	tySequence__Bis5AbpONWcIRrPyPJS8Yw data;
	NI counter;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  NI len; tySequence__E8pi9b5QNahsURYzXMjh3qw_Content* p;
};
struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw {
	tySequence__E8pi9b5QNahsURYzXMjh3qw data;
	NI counter;
};
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w {
  NI len; tySequence__3B6hFqG0Do0FxDvnNucL7w_Content* p;
};
struct tyObject_Table__g77QNejuRRKraNk8K2YkoA {
	tySequence__3B6hFqG0Do0FxDvnNucL7w data;
	NI counter;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  NI len; tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content* p;
};
struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg {
	tySequence__QqvaCqCpEE1QmQZbcZLi5A data;
	NI counter;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__bvRec9bo79ajqrJt3Bkg9c33w) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw k_p2);
struct tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* enforceVoidContext;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* voidType;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* currentScope;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* moduleScope;
	tySequence__AE2UIxl7EbPzzBnmYsjIcw imports;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* topLevelScope;
	tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* p;
	tyArray__uJvLVbod8mnHGzJkQj89bWg intTypeCache;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* nilTypeCache;
	tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg* matchedConcept;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA friendModules;
	NI instCounter;
	NI* templInstCounter;
	NI inGenericContext;
	NI inStaticContext;
	NI inUnrolledContext;
	NI compilesContextId;
	NI compilesContextIdGenerator;
	NI inGenericInst;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA converters;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA patterns;
	tySequence__tsHRsYLyvTCPLlGRExqi7Q optionStack;
	tySequence__lAikaRQvUF0uwNAz0U4FFA libs;
	tyProc__Yik7hgYZHhPeLJ5RsXTPqg semConstExpr;
	tyProc__JIyBW5s9ba7hfYBnWxDVvgg semExpr;
	tyProc__JIyBW5s9ba7hfYBnWxDVvgg semExprWithType;
	tyProc__iXlRd9cBAN0CQpA5dkyhRvw semTryExpr;
	tyProc__Yik7hgYZHhPeLJ5RsXTPqg semTryConstExpr;
	tyProc__7FLV9alRQFu6LOhr9bksExQQ computeRequiresInit;
	tyProc__0qHBYUhlP28E2DV7mVNNAg hasUnresolvedArgs;
	tyProc__iXlRd9cBAN0CQpA5dkyhRvw semOperand;
	tyProc__1nD4dBuhjTAOzMZJo9bmgog semConstBoolExpr;
	tyProc__209aOewTLBT6nbWmyvOQFiw semOverloadedCall;
	tyProc__D9aXgBooMpgLrPTmha6q31w semTypeNode;
	tyProc__GbPSPD9bjvt0RIJnnVTczJA semInferredLambda;
	tyProc__iDJMP540ifFac3zJ49bj2cA semGenerateInstance;
	tyProc__gq9a76bauTeymgreaiTI9cmg instantiateOnlyProcType;
	tyProc__Gji0NjiFFDU49aJiF3QZF8A fitDefaultNode;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA includedFiles;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg pureEnumFields;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg userPragmas;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* evalContext;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA unknownIdents;
	tySequence__4zAALtm0xUbRlYWQ2V8K7A generics;
	NI topStmts;
	NI lastGenericIdx;
	NI inParallelStmt;
	tyProc__UAj9bGJLVN9cwAsTcRZFyWmg instTypeBoundOp;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg signatures;
	NimStringV2 recursiveDep;
	NIM_BOOL suggestionsMade;
	NIM_BOOL isAmbiguous;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	NI inTypeContext;
	NI inConceptDecl;
	tySequence__9bffTLF0HkxjFCzZL8og4GA unusedImports;
	tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ exportIndirections;
	tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw importModuleMap;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastTLineInfo;
	tyObject_Table__g77QNejuRRKraNk8K2YkoA sideEffects;
	NI inUncheckedAssignSection;
	tyObject_Table__toCaB3NxiVHPRVLgcez0Xg importModuleLookup;
	tySequence__9ahcSjIErJohSBBFLwuF56Q skipTypes;
	NI inTypeofContext;
	tyProc__bvRec9bo79ajqrJt3Bkg9c33w semAsgnOpr;
};
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ {
  NI len; tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content* p;
};
struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
struct tyTuple__09aD69az7aYn14Gt61AHvLIA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
typedef tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* tyArray__s9a2jZbmN9cnqFaNnzUrYEjg[8192];
struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA {
	tyArray__s9a2jZbmN9cnqFaNnzUrYEjg buckets;
	NI wordCounter;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idAnon;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idDelegator;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* emptyIdent;
};
typedef NU tyArray__yYbpDJlxVAahcZb4EP3s9cA[16];
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__yYbpDJlxVAahcZb4EP3s9cA bits;
};
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg {
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ defaultCC;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* dynlib;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* otherPragmas;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NimStringV2 name;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* path;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw {
  NI len; tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content* p;
};
struct tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA {
	NI counter;
	tySequence__ZUeR9b415wicThQ9cBWO9aYMw data;
};
struct tySequence__yo9alHJGzX03OXpfmEsBjBQ {
  NI len; tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content* p;
};
struct tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* resultSym;
	NI nestedLoopCounter;
	NI nestedBlockCounter;
	NIM_BOOL breakInLoop;
	tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* next;
	NIM_BOOL mappingExists;
	tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA mapping;
	tySequence__yo9alHJGzX03OXpfmEsBjBQ caseContext;
	tySequence__9ahcSjIErJohSBBFLwuF56Q localBindStmts;
};
struct tyTuple__R9cYIordoMujN7rycr4Y7kw {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field0;
	NI Field1;
};
struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww {
	NI depthLevel;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg symbols;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* parent;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA allowPrivateAccess;
	NI optionStackLen;
};
typedef NU8 tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ;
struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m;
	tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ mode;
union{
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA imported;
} _mode_2;
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA exceptSet;
} _mode_3;
};
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw {
  NI len; tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content* p;
};
struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ {
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug {
	NI32 module;
	NI32 symId;
	NI32 typeId_0;
	NIM_BOOL sealed;
	tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ disambTable;
};
struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg {
	NI len;
	NI cap;
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q* d;
};
struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg {
	NI len;
	NI cap;
	tyTuple__DTRsWi2kgTewbhN2TT5mbA* d;
};
struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w {
	tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg traceStack;
	tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg toFree;
	NI freed;
	NI touched;
	NI edges;
	NI rcSum;
	NIM_BOOL keepThreshold;
};
struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q {
	void** Field0;
	TNimTypeV2* Field1;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* genericSym;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef NU16 tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* candidateType;
	tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg* prev;
	NI depth;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg concreteTypes;
	NI compilesId;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
typedef tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tyArray__al2p7ldDMvbBVYNFCuu4Rw[2];
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
typedef NU8 tySet_tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg[35];
typedef NU8 tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA;
typedef NU8 tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q;
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw {
  NI len; tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content* p;
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  NI len; tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content* p;
};
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA {
  NI len; tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content* p;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w {
  NI len; tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content* p;
};
struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g {
	NI counter;
	tySequence__GH1mmNKNA2QP4n1tnxJf1w data;
	NIM_BOOL ignoreTypes;
};
typedef NU8 tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg;
typedef NU8 tySet_tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g;
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA {
  NI len; tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content* p;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  NI len; tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content* p;
};
struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og data;
	NI counter;
};
struct tyObject_Profiler__YI4zs2CaXXndlYireD0I8A {
	NF tEnter;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q {
  NI len; tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content* p;
};
struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ {
	tySequence__Fc8Q26tsngy2yxcpyrnT4Q data;
	NI counter;
};
struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tySequence__YdLNCDKYeipzJx3I8Xw82Q code;
	tySequence__TLbZ2GqL3Zio1f8bNpj2NA debug;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* globals;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constants;
	tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g contstantTab;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg types;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentExceptionA;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentExceptionB;
	NI exceptionInstr;
	tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* prc;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* callsite;
	tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg mode;
	tySet_tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g features;
	NIM_BOOL traceActive;
	NI loopIterations;
	NI callDepth;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA comesFromHeuristic;
	tySequence__TEgqV1E9aHqnwBUoeXjBI9aA callbacks;
	tyObject_Table__tro5f9chxPVpES1mQpDwZtQ callbackIndex;
	NimStringV2 errorFlag;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	NI oldErrorCount;
	tyObject_Profiler__YI4zs2CaXXndlYireD0I8A profiler;
	NI* templInstCounter;
	tySequence__fnH5Zt4fsGx0AgDTOw8pKw vmstateDiff;
	tyObject_Table__lPs28yjGTxD0LzUoPspSBQ procToCodePos;
	NIM_BOOL cannotEval;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA locals;
};
struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
};
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content { NI cap; tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content { NI cap; tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* data[SEQ_DECL_SIZE]; };
struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content { NI cap; tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* data[SEQ_DECL_SIZE]; };
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ {
  NI len; tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content* p;
};
struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA {
	NI counter;
	tySequence__7OXYQ6bHRkhJpRaiS7kiwQ data;
};
struct tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A {
	tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA topLayer;
	tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* nextLayer;
	NI previousLen;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content { NI cap; tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw data[SEQ_DECL_SIZE]; };
struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content { NI cap; tyTuple__09aD69az7aYn14Gt61AHvLIA data[SEQ_DECL_SIZE]; };
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
	NI Field0;
	NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
	NI Field0;
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content { NI cap; tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE]; };
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
	NI Field0;
	NI Field1;
	NI Field2;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content { NI cap; tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw {
	NI Field0;
	NI Field1;
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ Field2;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content { NI cap; tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
	NI Field0;
	NI Field1;
	tySequence__qwqHTkRvwhrRyENtudHQ7g Field2;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content { NI cap; tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content { NI cap; tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ data[SEQ_DECL_SIZE]; };
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* val;
};
struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content { NI cap; tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A data[SEQ_DECL_SIZE]; };
struct tySequence__yo9alHJGzX03OXpfmEsBjBQ_Content { NI cap; tyTuple__R9cYIordoMujN7rycr4Y7kw data[SEQ_DECL_SIZE]; };
struct tyTuple__Oubp8LPEu86EPyDuc56AXg {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field0;
	NI Field1;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content { NI cap; tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content { NI cap; tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ data[SEQ_DECL_SIZE]; };
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content { NI cap; NU64 data[SEQ_DECL_SIZE]; };
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content { NI cap; tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA data[SEQ_DECL_SIZE]; };
struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ {
	NI h;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key;
	NI val;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content { NI cap; tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ data[SEQ_DECL_SIZE]; };
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
void* ClE_0;
} tyProc__c9bXGQkBnyyGGVw063jrwZw;
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content { NI cap; tyProc__c9bXGQkBnyyGGVw063jrwZw data[SEQ_DECL_SIZE]; };
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
	NI Field0;
	NimStringV2 Field1;
	NI Field2;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content { NI cap; tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE]; };
struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg {
	NI32 pc;
	NI32 usedRegisters;
};
struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g {
	NI Field0;
	NI Field1;
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg Field2;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content { NI cap; tyTuple__y6bKAf9a9aaVwun6lVDxSX7g data[SEQ_DECL_SIZE]; };
struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val;
};
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content { NI cap; tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg {
	NI ra;
	NI rb;
	NI rc;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* slots;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentException;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA currentLineInfo;
};
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__semdata_u7614)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2847)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3696)(tySequence__9ahcSjIErJohSBBFLwuF56Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3898)(tySequence__QqvaCqCpEE1QmQZbcZLi5A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3588)(tySequence__3B6hFqG0Do0FxDvnNucL7w dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3481)(tySequence__E8pi9b5QNahsURYzXMjh3qw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3377)(tySequence__Bis5AbpONWcIRrPyPJS8Yw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3218)(tySequence__9bffTLF0HkxjFCzZL8og4GA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13532)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u274)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2665)(tySequence__4zAALtm0xUbRlYWQ2V8K7A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u100)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u66)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2451)(tySequence__lAikaRQvUF0uwNAz0U4FFA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u544)(tySequence__tsHRsYLyvTCPLlGRExqi7Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u505)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3521)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u8083)(NI dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3288)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u719)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u906)(tySequence__yo9alHJGzX03OXpfmEsBjBQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u748)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2873)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2909)(tySequence__AE2UIxl7EbPzzBnmYsjIcw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3074)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___semdata_u2859)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* dest_p0, void* env_p1);
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1);
static N_INLINE(void, add__system_u3018)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3026)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*, newOptionEntry__semdata_u2306)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u611)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_u37)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg, initStrTable__ast_u6321)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA*, eqdup___idents_u344)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw*, eqdup___modulegraphs_u14759)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, initEncoder__modulegraphs_u3016)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderTree__renderer_u59)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p1);
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newTypeS__semdata_u4368)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newType__ast_u5900)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getCurrOwner__semdata_u425)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**, X5BX5D___semfold_u23)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u7226)(tySequence__vb3AGHvMJTxdOSSwMmBmTQ* x_p0, tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__vb3AGHvMJTxdOSSwMmBmTQ*, mgetOrPut__semdata_u6085)(tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__vb3AGHvMJTxdOSSwMmBmTQ val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, eqdup___ast_u3384)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, storeTypeInst__icZic_u7434)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* inst_p3);
static N_INLINE(NIM_BOOL, isSelf__semdata_u4610)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipIntLit__magicsys_u120)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* id_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, copyType__ast_u6238)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, illFormedAst__semdata_u4665)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3705)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, eqdup___ast_u3258)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getSysType__magicsys_u55)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntTypeNode__ast_u5387)(NI64 intVal_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__magicsys_u135)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* id_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdds__modulegraphs_u2993)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, addExported__icZic_u3147)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getGenSym__semdata_u2268)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u701)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semdata_u704)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ** dest_p0, tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* src_p1);
static N_INLINE(void, nimIncRef)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, get__semdata_u2121)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getOrDefault__semdata_u2191)(tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__semdata_u2285)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__renderer_u83)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, errorType__semdata_u4564)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u6001)(tySequence__apM9bRAO19cVjhWlxqd1PGeA* x_p0, tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA* y_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__apM9bRAO19cVjhWlxqd1PGeA*, mgetOrPut__semdata_u4860)(tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w* t_p0, tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key_p1, tySequence__apM9bRAO19cVjhWlxqd1PGeA val_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ*, eqdup___modulegraphs_u3567)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, storeInstantiation__icZic_u7607)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* i_p3);
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__icZic_u7486)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u6219)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semdata_u614)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** dest_p0, tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* src_p1);
static N_INLINE(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**, X5BX5D___semdata_u454)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*, eqdup___ast_u6222)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u2317)(tySequence__tsHRsYLyvTCPLlGRExqi7Q* x_p0, tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*, eqdup___semdata_u617)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u566)(tySequence__tsHRsYLyvTCPLlGRExqi7Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, storeExpansion__icZic_u7706)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p3);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_u6706)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1, NIM_BOOL propagateHasAsgn_p2);
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__ast_u6637)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* owner_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* elem_p1, NIM_BOOL propagateHasAsgn_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTreeI__ast_u4180)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p2, NI children_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, makeStaticExpr__semdata_u4441)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, nMinusOne__semdata_u4541)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5168)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getSysMagic__magicsys_u26)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 name_p2, tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inclSym__semdata_u4261)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* sq_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__modulegraphs_u6885)(tySequence__olFOFaYzOJN9aV5BWqK4b9bA* x_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdup___modulegraphs_u1864)(tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA src_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA* Result);
N_LIB_PRIVATE N_NIMCALL(void, addTrmacro__icZic_u3204)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u4725)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p3);
N_LIB_PRIVATE N_NIMCALL(void, checkMinSonsLen__semdata_u4675)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NI length_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1);
static N_INLINE(NI, len__ast_u5502)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA, isAssignable__semdata_u7330)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA, isAssignable__parampatterns_u315)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___renderer_u2166)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, analyseIfAddressTakenInCall__semdata_u7430)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConverter_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, analyseIfAddressTaken__semdata_u7377)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isOutParam_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newHiddenAddrTaken__semdata_u7334)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isOutParam_p2);
N_LIB_PRIVATE N_NIMCALL(void, checkSonsLen__semdata_u4671)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NI length_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeIT__ast_u4112)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeVarType__semdata_u4402)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* baseType_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getRoot__trees_u373)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderNotLValue__semdata_u7314)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeToString__types_u54)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q prefer_p1);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipAddr__trees_u429)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(NIM_BOOL, isOutParam__ast_u7655)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makePtrType__semdata_u4373)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* baseType_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5171)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, symFromType__semdata_u4633)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeTypeDesc__semdata_u4621)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getAttachedOp__modulegraphs_u4987)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p2);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, firstParamType__ast_u5363)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, genDeref__lowerings_u426)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw k_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntLit__lowerings_u465)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NI64 value_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3609)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u3631)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, addPureEnum__icZic_u3212)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getIntLitType__semdata_u279)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* literal_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1177)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ dest_p0);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info_p0);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, linkTo__ast_u4644)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__semdata_u4696)(tySequence__yo9alHJGzX03OXpfmEsBjBQ* x_p0, tyTuple__R9cYIordoMujN7rycr4Y7kw y_p1);
static N_INLINE(void, pop__semdata_u4718)(tySequence__yo9alHJGzX03OXpfmEsBjBQ* s_p0, tyTuple__R9cYIordoMujN7rycr4Y7kw* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u970)(tyTuple__R9cYIordoMujN7rycr4Y7kw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__semdata_u936)(tySequence__yo9alHJGzX03OXpfmEsBjBQ* x_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u973)(tyTuple__R9cYIordoMujN7rycr4Y7kw dest_p0);
static N_INLINE(tyTuple__R9cYIordoMujN7rycr4Y7kw*, X5BX5D___semdata_u4740)(tyTuple__R9cYIordoMujN7rycr4Y7kw* s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, addConverter__semdata_u4291)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA conv_p1);
N_LIB_PRIVATE N_NIMCALL(void, addConverter__icZic_u3172)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, addImportFileDep__icZic_u3057)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, NI32 f_p2);
N_LIB_PRIVATE N_NIMCALL(void, addIncludeFileDep__icZic_u3049)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, NI32 f_p2);
N_LIB_PRIVATE N_NIMCALL(void, addReexport__icZic_u3235)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, toPackedNodeTopLevel__icZic_u7507)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* encoder_p1, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u1847)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw* dest_p0, tySequence__fnH5Zt4fsGx0AgDTOw8pKw src_p1);
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__semdata_u4254)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1844)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw dest_p0);
N_LIB_PRIVATE TNimTypeV2 NTIv2__4jZ5gUwIaqnMfIYix46Hpw_;
static const struct {
  NI cap; NIM_CHAR data[62+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_4 = { 62 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/semdata.nim" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_6 = { 8 | NIM_STRLIT_FLAG, "AnonType" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_7 = {8, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_6};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_8 = { 4 | NIM_STRLIT_FLAG, "pred" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_9 = {4, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_8};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_10 = { 8 | NIM_STRLIT_FLAG, "popOwner" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_11 = {8, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_10};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__oylmf9cXfpJWZ2cwj9b09bJaw_13 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg TM__oylmf9cXfpJWZ2cwj9b09bJaw_14 = {
0x00, 0x00, 0x20, 0x60, 0x07, 0x03, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x8e, 0x23, 0x50, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__oylmf9cXfpJWZ2cwj9b09bJaw_15 = {
0x10, 0xa8, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[69+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_16 = { 69 | NIM_STRLIT_FLAG, "for a \'var\' type a variable needs to be passed; but \'$1\' is immutable" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_17 = {69, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_16};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__oylmf9cXfpJWZ2cwj9b09bJaw_19 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_20 = { 46 | NIM_STRLIT_FLAG, "address of \'$1\' may not escape its stack frame" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_21 = {46, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_20};
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_23 = {69, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_16};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_24 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_25 = {1, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_24};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_26 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_27 = {1, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_26};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__oylmf9cXfpJWZ2cwj9b09bJaw_28 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_29 = {1, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_24};
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_30 = {1, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_26};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_32 = { 21 | NIM_STRLIT_FLAG, "analyseIfAddressTaken" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_33 = {21, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_32};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__oylmf9cXfpJWZ2cwj9b09bJaw_35 = {
0x10, 0x00, 0x80, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_36 = { 16 | NIM_STRLIT_FLAG, "invalid int size" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_37 = {16, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_36};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_39 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_40 = {0, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_39};
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_41 = {1, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_24};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__oylmf9cXfpJWZ2cwj9b09bJaw_42 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_43 = {2, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_42};
static const NimStringV2 TM__oylmf9cXfpJWZ2cwj9b09bJaw_44 = {1, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_26};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_3 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)592),
((NI)13)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_5 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)595),
((NI)12)}
;
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_12 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)262),
((NI)21)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_18 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)746),
((NI)24)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_22 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)755),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_31 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)687),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_34 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)701),
((NI)19)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_38 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)237),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__oylmf9cXfpJWZ2cwj9b09bJaw_45 = {{62, (NimStrPayload*)&TM__oylmf9cXfpJWZ2cwj9b09bJaw_4},
((NI)446),
((NI)16)}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static NIM_CONST NU32 TM__oylmf9cXfpJWZ2cwj9b09bJaw_2[3] = {3701606400, 62025216, 913932544};
N_LIB_PRIVATE TNimTypeV2 NTIv2__4jZ5gUwIaqnMfIYix46Hpw_ = {.destructor = (void*)rttiDestroy__semdata_u7614, .size = sizeof(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw), .align = (NI16) NIM_ALIGNOF(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw), .depth = 2, .display = TM__oylmf9cXfpJWZ2cwj9b09bJaw_2, .traceImpl = (void*)eqtrace___semdata_u2859, .flags = 0};
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) - (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u4215)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0);
	}
LA4_: ;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3609)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field1)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1, ((NI)4));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3218)(tySequence__9bffTLF0HkxjFCzZL8og4GA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)4));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__09aD69az7aYn14Gt61AHvLIA));
}
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI32)((*cell_1).rc) >> (NU32)(((NI)4) & (32 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u505)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).otherPragmas);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0).otherPragmas)));
		nimRawDispose((*dest_p0).otherPragmas, ((NI)4));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLast((*dest_p0).dynlib);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3521((*(*dest_p0).dynlib));
		nimRawDispose((*dest_p0).dynlib, ((NI)4));
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u544)(tySequence__tsHRsYLyvTCPLlGRExqi7Q dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLast(dest_p0.p->data[colontmp_]);
				if (!T6_) goto LA7_;
				eqdestroy___semdata_u505((&(*dest_p0.p->data[colontmp_])));
				nimRawDispose(dest_p0.p->data[colontmp_], ((NI)4));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u906)(tySequence__yo9alHJGzX03OXpfmEsBjBQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)4));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__R9cYIordoMujN7rycr4Y7kw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u719)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* dest_p0) {
	eqdestroy___ast_u3696((*dest_p0).localBindStmts);
	eqdestroy___semdata_u906((*dest_p0).caseContext);
	eqdestroy___semdata_u748((*dest_p0).mapping.data);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).next);
		if (!T3_) goto LA4_;
		eqdestroy___semdata_u719((&(*(*dest_p0).next)));
		nimRawDispose((*dest_p0).next, ((NI)4));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).resultSym);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3469((&(*(*dest_p0).resultSym)));
		nimRawDispose((*dest_p0).resultSym, ((NI)4));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).owner);
		if (!T13_) goto LA14_;
		eqdestroy___ast_u3469((&(*(*dest_p0).owner)));
		nimRawDispose((*dest_p0).owner, ((NI)4));
	}
LA14_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2909)(tySequence__AE2UIxl7EbPzzBnmYsjIcw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			switch (dest_p0.p->data[colontmp_].mode) {
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
			{
			}
			break;
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
			{
				eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_]._mode_2.imported.data);
				{
					NIM_BOOL T8_;
					T8_ = (NIM_BOOL)0;
					T8_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_]._mode_2.imported.head);
					if (!T8_) goto LA9_;
					eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_]._mode_2.imported.head)));
					nimRawDispose(dest_p0.p->data[colontmp_]._mode_2.imported.head, ((NI)4));
				}
LA9_: ;
			}
			break;
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
			{
				eqdestroy___pureZcollectionsZintsets_u100(dest_p0.p->data[colontmp_]._mode_3.exceptSet.data);
				{
					NIM_BOOL T14_;
					T14_ = (NIM_BOOL)0;
					T14_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_]._mode_3.exceptSet.head);
					if (!T14_) goto LA15_;
					eqdestroy___pureZcollectionsZintsets_u66((&(*dest_p0.p->data[colontmp_]._mode_3.exceptSet.head)));
					nimRawDispose(dest_p0.p->data[colontmp_]._mode_3.exceptSet.head, ((NI)4));
				}
LA15_: ;
			}
			break;
			default: __builtin_unreachable();
			}
			{
				NIM_BOOL T19_;
				T19_ = (NIM_BOOL)0;
				T19_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].m);
				if (!T19_) goto LA20_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].m)));
				nimRawDispose(dest_p0.p->data[colontmp_].m, ((NI)4));
			}
LA20_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2847)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* dest_p0) {
	NI colontmp_;
	eqdestroy___ast_u3696((*dest_p0).skipTypes);
	eqdestroy___semdata_u3898((*dest_p0).importModuleLookup.data);
	eqdestroy___semdata_u3588((*dest_p0).sideEffects.data);
	eqdestroy___semdata_u3481((*dest_p0).importModuleMap.data);
	eqdestroy___semdata_u3377((*dest_p0).exportIndirections.data);
	eqdestroy___semdata_u3218((*dest_p0).unusedImports);
	eqdestroy___system_u2691((*dest_p0).recursiveDep);
	eqdestroy___ast_u4848((*dest_p0).signatures.data);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).graph);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0).graph)));
		nimRawDispose((*dest_p0).graph, ((NI)4));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLast((*dest_p0).cache);
		if (!T8_) goto LA9_;
		eqdestroy___idents_u274((&(*(*dest_p0).cache)));
		nimRawDispose((*dest_p0).cache, ((NI)4));
	}
LA9_: ;
	eqdestroy___semdata_u2665((*dest_p0).generics);
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).unknownIdents.data);
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).unknownIdents.head);
		if (!T13_) goto LA14_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).unknownIdents.head)));
		nimRawDispose((*dest_p0).unknownIdents.head, ((NI)4));
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastCyclicDyn((*dest_p0).evalContext);
		if (!T18_) goto LA19_;
		nimDestroyAndDispose((*dest_p0).evalContext);
	}
LA19_: ;
	eqdestroy___ast_u4848((*dest_p0).userPragmas.data);
	eqdestroy___ast_u4848((*dest_p0).pureEnumFields.data);
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).includedFiles.data);
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).includedFiles.head);
		if (!T23_) goto LA24_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).includedFiles.head)));
		nimRawDispose((*dest_p0).includedFiles.head, ((NI)4));
	}
LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLastCyclicDyn((*dest_p0).fitDefaultNode.ClE_0);
		if (!T28_) goto LA29_;
		nimDestroyAndDispose((*dest_p0).fitDefaultNode.ClE_0);
	}
LA29_: ;
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = nimDecRefIsLastCyclicDyn((*dest_p0).instantiateOnlyProcType.ClE_0);
		if (!T33_) goto LA34_;
		nimDestroyAndDispose((*dest_p0).instantiateOnlyProcType.ClE_0);
	}
LA34_: ;
	{
		NIM_BOOL T38_;
		T38_ = (NIM_BOOL)0;
		T38_ = nimDecRefIsLastCyclicDyn((*dest_p0).semGenerateInstance.ClE_0);
		if (!T38_) goto LA39_;
		nimDestroyAndDispose((*dest_p0).semGenerateInstance.ClE_0);
	}
LA39_: ;
	{
		NIM_BOOL T43_;
		T43_ = (NIM_BOOL)0;
		T43_ = nimDecRefIsLastCyclicDyn((*dest_p0).semInferredLambda.ClE_0);
		if (!T43_) goto LA44_;
		nimDestroyAndDispose((*dest_p0).semInferredLambda.ClE_0);
	}
LA44_: ;
	{
		NIM_BOOL T48_;
		T48_ = (NIM_BOOL)0;
		T48_ = nimDecRefIsLastCyclicDyn((*dest_p0).hasUnresolvedArgs.ClE_0);
		if (!T48_) goto LA49_;
		nimDestroyAndDispose((*dest_p0).hasUnresolvedArgs.ClE_0);
	}
LA49_: ;
	eqdestroy___semdata_u2451((*dest_p0).libs);
	eqdestroy___semdata_u544((*dest_p0).optionStack);
	eqdestroy___ast_u4848((*dest_p0).patterns);
	eqdestroy___ast_u4848((*dest_p0).converters);
	{
		NIM_BOOL T53_;
		T53_ = (NIM_BOOL)0;
		T53_ = nimDecRefIsLast((*dest_p0).templInstCounter);
		if (!T53_) goto LA54_;
		eqdestroy___system_u8083((*(*dest_p0).templInstCounter));
		nimRawDispose((*dest_p0).templInstCounter, ((NI)4));
	}
LA54_: ;
	eqdestroy___ast_u4848((*dest_p0).friendModules);
	{
		NIM_BOOL T58_;
		T58_ = (NIM_BOOL)0;
		T58_ = nimDecRefIsLastDyn((*dest_p0).nilTypeCache);
		if (!T58_) goto LA59_;
		eqdestroy___ast_u3288((&(*(*dest_p0).nilTypeCache)));
		nimRawDispose((*dest_p0).nilTypeCache, ((NI)4));
	}
LA59_: ;
	colontmp_ = ((NI)-5);
	{
		while (1) {
			if (!(colontmp_ < ((NI)33))) goto LA62;
			{
				NIM_BOOL T65_;
				T65_ = (NIM_BOOL)0;
				T65_ = nimDecRefIsLastDyn((*dest_p0).intTypeCache[(colontmp_)- -5]);
				if (!T65_) goto LA66_;
				eqdestroy___ast_u3288((&(*(*dest_p0).intTypeCache[(colontmp_)- -5])));
				nimRawDispose((*dest_p0).intTypeCache[(colontmp_)- -5], ((NI)4));
			}
LA66_: ;
			colontmp_ += ((NI)1);
		} LA62: ;
	}
	{
		NIM_BOOL T70_;
		T70_ = (NIM_BOOL)0;
		T70_ = nimDecRefIsLastDyn((*dest_p0).p);
		if (!T70_) goto LA71_;
		eqdestroy___semdata_u719((&(*(*dest_p0).p)));
		nimRawDispose((*dest_p0).p, ((NI)4));
	}
LA71_: ;
	{
		NIM_BOOL T75_;
		T75_ = (NIM_BOOL)0;
		T75_ = nimDecRefIsLastDyn((*dest_p0).topLevelScope);
		if (!T75_) goto LA76_;
		eqdestroy___semdata_u2873((&(*(*dest_p0).topLevelScope)));
		nimRawDispose((*dest_p0).topLevelScope, ((NI)4));
	}
LA76_: ;
	eqdestroy___semdata_u2909((*dest_p0).imports);
	{
		NIM_BOOL T80_;
		T80_ = (NIM_BOOL)0;
		T80_ = nimDecRefIsLastDyn((*dest_p0).moduleScope);
		if (!T80_) goto LA81_;
		eqdestroy___semdata_u2873((&(*(*dest_p0).moduleScope)));
		nimRawDispose((*dest_p0).moduleScope, ((NI)4));
	}
LA81_: ;
	{
		NIM_BOOL T85_;
		T85_ = (NIM_BOOL)0;
		T85_ = nimDecRefIsLastDyn((*dest_p0).currentScope);
		if (!T85_) goto LA86_;
		eqdestroy___semdata_u2873((&(*(*dest_p0).currentScope)));
		nimRawDispose((*dest_p0).currentScope, ((NI)4));
	}
LA86_: ;
	{
		NIM_BOOL T90_;
		T90_ = (NIM_BOOL)0;
		T90_ = nimDecRefIsLastDyn((*dest_p0).module);
		if (!T90_) goto LA91_;
		eqdestroy___ast_u3469((&(*(*dest_p0).module)));
		nimRawDispose((*dest_p0).module, ((NI)4));
	}
LA91_: ;
	{
		NIM_BOOL T95_;
		T95_ = (NIM_BOOL)0;
		T95_ = nimDecRefIsLastDyn((*dest_p0).voidType);
		if (!T95_) goto LA96_;
		eqdestroy___ast_u3288((&(*(*dest_p0).voidType)));
		nimRawDispose((*dest_p0).voidType, ((NI)4));
	}
LA96_: ;
	{
		NIM_BOOL T100_;
		T100_ = (NIM_BOOL)0;
		T100_ = nimDecRefIsLastDyn((*dest_p0).enforceVoidContext);
		if (!T100_) goto LA101_;
		eqdestroy___ast_u3288((&(*(*dest_p0).enforceVoidContext)));
		nimRawDispose((*dest_p0).enforceVoidContext, ((NI)4));
	}
LA101_: ;
	{
		NIM_BOOL T105_;
		T105_ = (NIM_BOOL)0;
		T105_ = nimDecRefIsLast((*dest_p0).Sup.idgen);
		if (!T105_) goto LA106_;
		eqdestroy___ast_u3074((&(*(*dest_p0).Sup.idgen)));
		nimRawDispose((*dest_p0).Sup.idgen, ((NI)4));
	}
LA106_: ;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__semdata_u7614)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___semdata_u2847((&(*((tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) + (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, add__system_u3018)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2) {
	void** colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3026(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p1));
		add__system_u3018((&(*j_1).traceStack), p_1, (*((TNimTypeV2**) ((*p_1)))));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___semdata_u2859)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* dest_p0, void* env_p1) {
	nimTraceRefDyn((&(*dest_p0).hasUnresolvedArgs.ClE_0), env_p1);
	nimTraceRefDyn((&(*dest_p0).semInferredLambda.ClE_0), env_p1);
	nimTraceRefDyn((&(*dest_p0).semGenerateInstance.ClE_0), env_p1);
	nimTraceRefDyn((&(*dest_p0).instantiateOnlyProcType.ClE_0), env_p1);
	nimTraceRefDyn((&(*dest_p0).fitDefaultNode.ClE_0), env_p1);
	nimTraceRefDyn(&(*dest_p0).evalContext, env_p1);
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*, newOptionEntry__semdata_u2306)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* result;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*) nimNewObj(sizeof(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg), NIM_ALIGNOF(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg));
	(*T1_).options = (*conf_p0).options;
	(*T1_).defaultCC = ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0);
	(*T1_).dynlib = ((tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*) NIM_NIL);
	nimCopyMem((void*)(*T1_).notes, (NIM_CONST void*)(*conf_p0).notes, 13);
	nimCopyMem((void*)(*T1_).warningAsErrors, (NIM_CONST void*)(*conf_p0).warningAsErrors, 13);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u611)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___semdata_u505((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initPackedSet__pureZcollectionsZintsets_u37(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw*, newContext__semdata_u2362)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1) {
	tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* colontmpD__3;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* colontmpD__4;
	tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* T1_;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw*) nimNewObj(sizeof(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw), NIM_ALIGNOF(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw));
	(*T1_).Sup.Sup.m_type = (&NTIv2__4jZ5gUwIaqnMfIYix46Hpw_);
	(*T1_).optionStack.len = 1; (*T1_).optionStack.p = (tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content*) newSeqPayload(1, sizeof(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*), NIM_ALIGNOF(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*));
	T2_ = NIM_NIL;
	T2_ = newOptionEntry__semdata_u2306((*graph_p0).config);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___semdata_u611(T2_); goto BeforeRet_;}
	(*T1_).optionStack.p->data[0] = T2_;
	(*T1_).libs.len = 0; (*T1_).libs.p = (tySequence__lAikaRQvUF0uwNAz0U4FFA_Content*) newSeqPayload(0, sizeof(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*), NIM_ALIGNOF(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*));
	colontmpD_ = eqdup___ast_u4580(module_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).module = colontmpD_;
	(*T1_).friendModules.len = 1; (*T1_).friendModules.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(1, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	colontmpD__2 = eqdup___ast_u4580(module_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).friendModules.p->data[0] = colontmpD__2;
	(*T1_).converters.len = 0; (*T1_).converters.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	(*T1_).patterns.len = 0; (*T1_).patterns.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	initIntSet__pureZcollectionsZintsets_u598((&(*T1_).includedFiles));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).pureEnumFields = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).userPragmas = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).generics.len = 0; (*T1_).generics.p = (tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content*) newSeqPayload(0, sizeof(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw), NIM_ALIGNOF(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw));
	initIntSet__pureZcollectionsZintsets_u598((&(*T1_).unknownIdents));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__3 = eqdup___idents_u344((*graph_p0).cache);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).cache = colontmpD__3;
	colontmpD__4 = eqdup___modulegraphs_u14759(graph_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).graph = colontmpD__4;
	(*T1_).signatures = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).features = (*(*graph_p0).config).features;
	result = T1_;
	{
		NI id_1;
		if (!!(((*(*graph_p0).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA5_;
		id_1 = (*module_p1).position;
		{
			if (!!(((*(*graph_p0).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)9)))) goto LA9_;
		}
LA9_: ;
		(*graph_p0).packed_0.pm.p->data[id_1].status = ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)1);
		eqcopy___ast_u4577(&(*graph_p0).packed_0.pm.p->data[id_1].module, module_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		initEncoder__modulegraphs_u3016(graph_p0, module_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA5_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, illFormedAst__semdata_u4665)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = renderTree__renderer_u59(n_p0, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	liMessage__msgs_u1227(conf_p1, (*n_p0).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)3), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2), TM__oylmf9cXfpJWZ2cwj9b09bJaw_3, NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1) {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* h_1;
	NI T1_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
	h_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_));
	(*h_1).rc = pluspercent___system_u785((*h_1).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw*, eqdup___semdata_u4222)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* src_p0, NIM_BOOL cyclic_p1) {
	tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* result;
	tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semdata_u4218)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw** dest_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* src_p1, NIM_BOOL cyclic_p2) {
	tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* colontmp_;
	colontmp_ = (*dest_p0);
	{
		if (!src_p1) goto LA3_;
		nimIncRefCyclic(src_p1, cyclic_p2);
	}
LA3_: ;
	(*dest_p0) = src_p1;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T7_) goto LA8_;
		nimDestroyAndDispose(colontmp_);
	}
LA8_: ;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**, X5BX5D___semfold_u23)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getCurrOwner__semdata_u425)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
	T1_ = X5BX5D___semfold_u23((((*(*c_p0).graph).owners).p) ? ((*(*c_p0).graph).owners.p->data) : NIM_NIL, (*(*c_p0).graph).owners.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u4577(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newTypeS__semdata_u4368)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* blitTmp_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getCurrOwner__semdata_u425(c_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	blitTmp_1 = son_p2;
	result = newType__ast_u5900(kind_p0, (*c_p1).Sup.idgen, colontmpD_, blitTmp_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeTypeFromExpr__semdata_u4430)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)61), c_p0, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&(*result).n, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, errorType__semdata_u4564)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)50), c_p0, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)38))) & 63);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToGenericCache__semdata_u6025)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* inst_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ T1_;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ* T2_;
	tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_.len = 0; T1_.p = (tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content*) newSeqPayload(0, sizeof(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA), NIM_ALIGNOF(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA));
	T2_ = (tySequence__vb3AGHvMJTxdOSSwMmBmTQ*)0;
	T2_ = mgetOrPut__semdata_u6085((&(*(*c_p0).graph).typeInstCache), (*s_p1).itemId, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA));
	nimZeroMem((void*)(&T3_), sizeof(tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA));
	colontmpD_ = eqdup___ast_u3384(inst_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_.typ = colontmpD_;
	add__semdata_u7226((&(*T2_)), T3_);
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T8_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA6_;
		T8_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T8_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		storeTypeInst__icZic_u7434(T8_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), s_p1, inst_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA6_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isSelf__semdata_u4610)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8));
	if (!(T1_)) goto LA2_;
	T1_ = (((*t_p0).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23)))&63U)))!=0);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipIntLit__magicsys_u120)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* id_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t_p0).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36));
LA4_: ;
		if (!T3_) goto LA5_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = owner__ast_u6246(t_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = copyType__ast_u6238(t_p0, id_p1, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqsink___ast_u3261(&(*result).n, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		eqcopy___ast_u3381(&result, t_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeTypeDesc__semdata_u4621)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*typ_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = isSelf__semdata_u4610(typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !(T5_);
LA4_: ;
		if (!T3_) goto LA6_;
		eqcopy___ast_u3381(&result, typ_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T9_;
		T9_ = NIM_NIL;
		T9_ = skipIntLit__magicsys_u120(typ_p1, (*c_p0).Sup.idgen);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T9_); goto BeforeRet_;}
		result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8), c_p0, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)38))) & 63);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkSonsLen__semdata_u4671)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NI length_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!((T3_ == length_p1))) goto LA4_;
		illFormedAst__semdata_u4665(n_p0, conf_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___sigmatch_u1463)(tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.candidateType);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*dest_p0.candidateType)));
		nimRawDispose(dest_p0.candidateType, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u608)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, makeStaticExpr__semdata_u4441)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tySequence__9ahcSjIErJohSBBFLwuF56Q T1_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)62), (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_.len = 1; T1_.p = (tySequence__9ahcSjIErJohSBBFLwuF56Q_Content*) newSeqPayload(1, sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
	colontmpD_ = eqdup___ast_u3258(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.p->data[0] = colontmpD_;
	eqsink___ast_u3705((&(*result)._kind_6.sons), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = NIM_NIL;
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*n_p1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T5_)) goto LA6_;
		T5_ = ((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60));
LA6_: ;
		if (!T5_) goto LA7_;
		eqcopy___ast_u3381(&(*result).typField, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA3_;
LA7_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T10_;
		colontmpD__2 = eqdup___ast_u3384((*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T10_ = NIM_NIL;
		T10_ = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60), c_p0, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T10_); goto BeforeRet_;}
		eqsink___ast_u3387(&(*result).typField, T10_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u3294)(tyTuple__09aD69az7aYn14Gt61AHvLIA* dest_p0, tyTuple__09aD69az7aYn14Gt61AHvLIA src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)4));
	}
LA4_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	(*dest_p0).Field1.line = src_p1.Field1.line;
	(*dest_p0).Field1.col = src_p1.Field1.col;
	(*dest_p0).Field1.fileIndex = src_p1.Field1.fileIndex;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3282)(tyTuple__09aD69az7aYn14Gt61AHvLIA* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.line = 0;
	(*dest_p0).Field1.col = 0;
	(*dest_p0).Field1.fileIndex = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3285)(tyTuple__09aD69az7aYn14Gt61AHvLIA dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeRangeType__semdata_u4597)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, NI64 first_p1, NI64 last_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* intType_p4) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* intType_2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	intType_2 = NIM_NIL;
	n_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	T2_ = NIM_NIL;
	{
		if (!!((intType_p4 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA5_;
		eqcopy___ast_u3381(&intType_2, intType_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		intType_2 = getSysType__magicsys_u55((*c_p0).graph, info_p3, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	n_1 = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44), info_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = newIntTypeNode__ast_u5387(first_p1, intType_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3215(n_1, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = newIntTypeNode__ast_u5387(last_p2, intType_2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	add__ast_u3215(n_1, colontmpD__2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20), c_p0, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqsink___ast_u3261(&(*result).n, n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqwasMoved___ast_u3249(&n_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	addSonSkipIntLit__magicsys_u135(result, intType_2, (*c_p0).Sup.idgen);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(intType_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, exportSym__semdata_u4348)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	strTableAdds__modulegraphs_u2993((*c_p0).graph, (*c_p0).module, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addExported__icZic_u3147(T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u701)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___semdata_u719((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semdata_u704)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ** dest_p0, tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___semdata_u719((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, get__semdata_u2121)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* p_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* key_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!!((*p_p0).mappingExists)) goto LA3_;
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		goto BeforeRet_;
	}
LA3_: ;
	result = getOrDefault__semdata_u2191((*p_p0).mapping, (*key_p1).itemId);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getGenSym__semdata_u2268)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* it_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	it_1 = NIM_NIL;
	{
		if (!!((((*s_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)37)))&63U)))!=0))) goto LA4_;
		eqcopy___ast_u4577(&result, s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___semdata_u701(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	eqcopy___semdata_u704(&it_1, (*c_p0).p);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T8_;
			if (!!((it_1 == ((tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ*) NIM_NIL)))) goto LA7;
			T8_ = NIM_NIL;
			T8_ = get__semdata_u2121(it_1, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T8_); goto LA1_;}
			eqsink___ast_u4583(&result, T8_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA11_;
				eqdestroy___semdata_u701(it_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
LA11_: ;
			eqcopy___semdata_u704(&it_1, (*it_1).next);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA7: ;
	}
	eqcopy___ast_u4577(&result, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___semdata_u701(it_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, considerGenSyms__semdata_u2285)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(n_p1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA6_;
		s_1 = NIM_NIL;
		s_1 = getGenSym__semdata_u2268(c_p0, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!!(((*n_p1)._kind_4.sym == s_1))) goto LA10_;
			eqsink___ast_u4583(&(*n_p1)._kind_4.sym, s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqwasMoved___ast_u4571(&s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA10_: ;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA15;
					i_1 = i_2;
					considerGenSyms__semdata_u2285(c_p0, (*n_p1)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA15: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, pushOwner__semdata_u432)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___ast_u4580(owner_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__renderer_u83((&(*(*c_p0).graph).owners), colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u710)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ** dest_p0, tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___semdata_u719((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ*, eqdup___semdata_u707)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* src_p0) {
	tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, errorNode__semdata_u4571)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1), (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	T1_ = errorType__semdata_u4564(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T1_); goto BeforeRet_;}
	eqsink___ast_u3387(&(*result).typField, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToGenericProcCache__semdata_u4800)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst_p2) {
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* colontmpD_;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA T1_;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA* T2_;
	tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_.len = 0; T1_.p = (tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content*) newSeqPayload(0, sizeof(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA), NIM_ALIGNOF(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA));
	T2_ = (tySequence__apM9bRAO19cVjhWlxqd1PGeA*)0;
	T2_ = mgetOrPut__semdata_u4860((&(*(*c_p0).graph).procInstCache), (*s_p1).itemId, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA));
	nimZeroMem((void*)(&T3_), sizeof(tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA));
	T3_.module = (*(*c_p0).module).position;
	colontmpD_ = eqdup___modulegraphs_u3567(inst_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T3_.inst = colontmpD_;
	add__semdata_u6001((&(*T2_)), (&T3_));
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T8_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA6_;
		T8_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T8_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		storeInstantiation__icZic_u7607(T8_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), s_p1, inst_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA6_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, makeInstPair__semdata_u375)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst_p1, tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw* Result) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw));
	colontmpD_ = eqdup___ast_u4580(s_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).genericSym = colontmpD_;
	colontmpD__2 = eqdup___modulegraphs_u3567(inst_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*Result).inst = colontmpD__2;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addPragmaComputation__semdata_u4254)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addPragmaComputation__icZic_u7486(T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*, newLib__semdata_u4362)(tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind_p0) {
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* result;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*) nimNewObj(sizeof(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig), NIM_ALIGNOF(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig));
	(*T1_).kind = kind_p0;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addToLib__semdata_u4365)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* lib_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___ast_u6219(&(*sym_p1).annex, lib_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semdata_u614)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** dest_p0, tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLast((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___semdata_u505((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**, X5BX5D___semdata_u454)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*, eqdup___semdata_u617)(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* src_p0) {
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*, pushOptionEntry__semdata_u2309)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* result;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* prev_1;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* colontmpD_;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* colontmpD__2;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T1_;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	prev_1 = NIM_NIL;
	T1_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
	T1_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___semdata_u614(&prev_1, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = NIM_NIL;
	T2_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*) nimNewObj(sizeof(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg), NIM_ALIGNOF(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg));
	(*T2_).options = (*(*(*c_p0).graph).config).options;
	(*T2_).defaultCC = (*prev_1).defaultCC;
	colontmpD_ = eqdup___ast_u6222((*prev_1).dynlib);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T2_).dynlib = colontmpD_;
	nimCopyMem((void*)(*T2_).notes, (NIM_CONST void*)(*(*(*c_p0).graph).config).notes, 13);
	nimCopyMem((void*)(*T2_).warningAsErrors, (NIM_CONST void*)(*(*(*c_p0).graph).config).warningAsErrors, 13);
	(*T2_).features = (*c_p0).features;
	result = T2_;
	colontmpD__2 = eqdup___semdata_u617(result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__semdata_u2317((&(*c_p0).optionStack), colontmpD__2);
	eqdestroy___semdata_u611(prev_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, popOptionEntry__semdata_u2337)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T1_;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T2_;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T3_;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T4_;
	NI T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
	T1_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*(*(*c_p0).graph).config).options = (*(*T1_)).options;
	T2_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
	T2_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimCopyMem((void*)(*(*(*c_p0).graph).config).notes, (NIM_CONST void*)(*(*T2_)).notes, 13);
	T3_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
	T3_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimCopyMem((void*)(*(*(*c_p0).graph).config).warningAsErrors, (NIM_CONST void*)(*(*T3_)).warningAsErrors, 13);
	T4_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
	T4_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*c_p0).features = (*(*T4_)).features;
	T5_ = (*c_p0).optionStack.len;
	setLen__semdata_u566((&(*c_p0).optionStack), ((NI)(T5_ - ((NI)1))));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, illFormedAstLocal__semdata_u4668)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = renderTree__renderer_u59(n_p0, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	liMessage__msgs_u1227(conf_p1, (*n_p0).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)3), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__oylmf9cXfpJWZ2cwj9b09bJaw_5, NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rememberExpansion__semdata_u7304)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* expandedSym_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		storeExpansion__icZic_u7706(T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), info_p1, expandedSym_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makePtrType__semdata_u4373)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* baseType_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = skipIntLit__magicsys_u120(baseType_p1, idgen_p2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T1_); goto BeforeRet_;}
	result = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21), idgen_p2, owner_p0, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeAndType__semdata_u4457)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t1_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t2_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)56), c_p0, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	rawAddSon__ast_u6706(result, t1_p1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	rawAddSon__ast_u6706(result, t2_p2, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	propagateToOwner__ast_u6637(result, t1_p1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	propagateToOwner__ast_u6637(result, t2_p2, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).flags = ((*result).flags | (((*t1_p1).flags | (*t2_p2).flags) & 16777216));
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)21))) & 63);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeOrType__semdata_u4479)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t1_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t2_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*t1_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57)));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*t2_p2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57)));
LA4_: ;
		if (!T3_) goto LA5_;
		result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57), c_p0, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawAddSon__ast_u6706(result, t1_p1, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		rawAddSon__ast_u6706(result, t2_p2, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57), c_p0, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!((*t1_p1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57))) goto LA10_;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* xX60gensym142__1;
				xX60gensym142__1 = NIM_NIL;
				{
					NI i_1;
					NI colontmp_;
					NI T14_;
					NI i_2;
					i_1 = (NI)0;
					colontmp_ = (NI)0;
					T14_ = (*t1_p1).sons.len;
					colontmp_ = T14_;
					i_2 = ((NI)0);
					{
						while (1) {
							if (!(i_2 < colontmp_)) goto LA16;
							i_1 = i_2;
							eqcopy___ast_u3381(&xX60gensym142__1, (*t1_p1).sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							rawAddSon__ast_u6706(result, xX60gensym142__1, NIM_TRUE);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							i_2 += ((NI)1);
						} LA16: ;
					}
				}
				eqdestroy___ast_u3378(xX60gensym142__1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
		}
		goto LA8_;
LA10_: ;
		{
			rawAddSon__ast_u6706(result, t1_p1, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA8_: ;
		{
			if (!((*t2_p2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57))) goto LA20_;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* xX60gensym143__1;
				xX60gensym143__1 = NIM_NIL;
				{
					NI i_3;
					NI colontmp__2;
					NI T24_;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					T24_ = (*t2_p2).sons.len;
					colontmp__2 = T24_;
					i_4 = ((NI)0);
					{
						while (1) {
							if (!(i_4 < colontmp__2)) goto LA26;
							i_3 = i_4;
							eqcopy___ast_u3381(&xX60gensym143__1, (*t2_p2).sons.p->data[i_3]);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							rawAddSon__ast_u6706(result, xX60gensym143__1, NIM_TRUE);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							i_4 += ((NI)1);
						} LA26: ;
					}
				}
				eqdestroy___ast_u3378(xX60gensym143__1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
		}
		goto LA18_;
LA20_: ;
		{
			rawAddSon__ast_u6706(result, t2_p2, NIM_TRUE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA18_: ;
	}
LA1_: ;
	propagateToOwner__ast_u6637(result, t1_p1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	propagateToOwner__ast_u6637(result, t2_p2, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).flags = ((*result).flags | (((*t1_p1).flags | (*t2_p2).flags) & 16777216));
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)21))) & 63);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeNotType__semdata_u4524)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t1_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = eqdup___ast_u3384(t1_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)58), c_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	propagateToOwner__ast_u6637(result, t1_p1, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).flags = ((*result).flags | ((*t1_p1).flags & 16777216));
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)21))) & 63);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, checkMinSonsLen__semdata_u4675)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NI length_p1, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T3_ < length_p1)) goto LA4_;
		illFormedAst__semdata_u4665(n_p0, conf_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___semdata_u976)(tyTuple__R9cYIordoMujN7rycr4Y7kw* dest_p0, tyTuple__R9cYIordoMujN7rycr4Y7kw src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1.Field0) goto LA3_;
		nimIncRef(src_p1.Field0);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3270((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)4));
	}
LA8_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	(*dest_p0).Field1 = src_p1.Field1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u982)(tyTuple__R9cYIordoMujN7rycr4Y7kw* dest_p0, tyTuple__R9cYIordoMujN7rycr4Y7kw src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)4));
	}
LA4_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	(*dest_p0).Field1 = src_p1.Field1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u973)(tyTuple__R9cYIordoMujN7rycr4Y7kw dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, symFromType__semdata_u4633)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	{
		if (!!(((*t_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA4_;
		eqcopy___ast_u4577(&result, (*t_p1).sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___ast_u4574(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	colontmpD_ = getIdent__idents_u206((*c_p0).cache, TM__oylmf9cXfpJWZ2cwj9b09bJaw_7);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = owner__ast_u6246(t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = 0;
	result = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7), colontmpD_, (*c_p0).Sup.idgen, colontmpD__2, info_p2, T6_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)60))) & 63);
	eqcopy___ast_u3381(&(*result).typ, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___idents_u155(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, nMinusOne__semdata_u4541)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
	tyArray__al2p7ldDMvbBVYNFCuu4Rw T2_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	nimZeroMem((void*)T2_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
	colontmpD_ = getSysMagic__magicsys_u26((*c_p0).graph, (*n_p1).info, TM__oylmf9cXfpJWZ2cwj9b09bJaw_9, ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)52));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = newSymNode__ast_u5168(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = colontmpD__2;
	T2_[1] = n_p1;
	result = newTreeI__ast_u4180(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27), (*n_p1).info, T2_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeRangeWithStaticExpr__semdata_u4545)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* intType_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
	tyArray__al2p7ldDMvbBVYNFCuu4Rw T8_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	intType_1 = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	colontmpD__3 = NIM_NIL;
	colontmpD__4 = NIM_NIL;
	intType_1 = getSysType__magicsys_u55((*c_p0).graph, (*n_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___ast_u3384(intType_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20), c_p0, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*n_p1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*n_p1).typField).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA5_: ;
		if (!T4_) goto LA6_;
		(*result).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)9))) & 63);
	}
LA6_: ;
	nimZeroMem((void*)T8_, sizeof(tyArray__al2p7ldDMvbBVYNFCuu4Rw));
	colontmpD__2 = newIntTypeNode__ast_u5387(IL64(0), intType_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_[0] = colontmpD__2;
	colontmpD__3 = nMinusOne__semdata_u4541(c_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = makeStaticExpr__semdata_u4441(c_p0, colontmpD__3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T8_[1] = colontmpD__4;
	T9_ = NIM_NIL;
	T9_ = newTreeI__ast_u4180(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44), (*n_p1).info, T8_, 2);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto LA1_;}
	eqsink___ast_u3261(&(*result).n, T9_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(colontmpD__4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(intType_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeTypeWithModifier__semdata_u4382)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg modifier_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* baseType_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (modifier_p1 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || modifier_p1 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47) || modifier_p1 == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8));
		if (!(T3_)) goto LA4_;
		T3_ = ((*baseType_p2).kind == modifier_p1);
LA4_: ;
		if (!T3_) goto LA5_;
		eqcopy___ast_u3381(&result, baseType_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T8_;
		T8_ = NIM_NIL;
		T8_ = skipIntLit__magicsys_u120(baseType_p2, (*c_p0).Sup.idgen);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T8_); goto BeforeRet_;}
		result = newTypeS__semdata_u4368(modifier_p1, c_p0, T8_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg*, lastOptionEntry__semdata_u451)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* result;
	tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg**)0;
	T1_ = X5BX5D___semdata_u454((((*c_p0).optionStack).p) ? ((*c_p0).optionStack.p->data) : NIM_NIL, (*c_p0).optionStack.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___semdata_u614(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inclSym__semdata_u4261)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* sq_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NIM_BOOL result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*sq_p0).len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				{
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym84__1;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym86__1;
					xX60gensym84__1 = (*(*sq_p0).p->data[i_1]).itemId;
					xX60gensym86__1 = (*s_p1).itemId;
					if (!((NI)((NI)((NU32)(((NI) (xX60gensym84__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym84__1.item))) == (NI)((NI)((NU32)(((NI) (xX60gensym86__1.module))) << (NU32)(((NI)20) & (32 - 1))) + ((NI) (xX60gensym86__1.item))))) goto LA7_;
					result = NIM_FALSE;
					goto BeforeRet_;
				}
LA7_: ;
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	colontmpD_ = eqdup___ast_u4580(s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__renderer_u83((&(*sq_p0)), colontmpD_);
	result = NIM_TRUE;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addPattern__semdata_u4330)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA p_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = inclSym__semdata_u4261((&(*c_p0).patterns), p_p1.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		eqdup___modulegraphs_u1864(p_p1, (&colontmpD_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__modulegraphs_u6885((&(*(*c_p0).graph).ifaces.p->data[(*(*c_p0).module).position].patterns), colontmpD_);
	}
LA4_: ;
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T10_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA8_;
		T10_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T10_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addTrmacro__icZic_u3204(T10_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), p_p1.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, popOwner__semdata_u439)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		NI T6_;
		T3_ = (*(*c_p0).graph).owners.len;
		if (!(((NI)0) < T3_)) goto LA4_;
		T6_ = (*(*c_p0).graph).owners.len;
		setLen__ast_u4725((&(*(*c_p0).graph).owners), ((NI)(T6_ - ((NI)1))));
	}
	goto LA1_;
LA4_: ;
	{
		internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, unknownLineInfo__lineinfos_u364, TM__oylmf9cXfpJWZ2cwj9b09bJaw_11, TM__oylmf9cXfpJWZ2cwj9b09bJaw_12);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
static N_INLINE(NI, len__ast_u5502)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0).sons.len;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA, isAssignable__semdata_u7330)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA)0;
	result = isAssignable__parampatterns_u315((*(*c_p0).p).owner, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makeVarType__semdata_u4402)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* baseType_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*baseType_p1).kind == kind_p2)) goto LA3_;
		eqcopy___ast_u3381(&result, baseType_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T6_;
		T6_ = NIM_NIL;
		T6_ = skipIntLit__magicsys_u120(baseType_p1, (*c_p0).Sup.idgen);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T6_); goto BeforeRet_;}
		result = newTypeS__semdata_u4368(kind_p2, c_p0, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderNotLValue__semdata_u7314)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NimStringV2 result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T2_;
NIM_BOOL oldNimErrFin25_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	n_2 = NIM_NIL;
	result = dollar___renderer_u2166(n_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = NIM_NIL;
	{
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65))) goto LA5_;
		eqcopy___ast_u3255(&n_2, (*n_p0)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA3_;
LA5_: ;
	{
		eqcopy___ast_u3255(&n_2, n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA3_: ;
	{
		NIM_BOOL T10_;
		NI T12_;
		NimStringV2 colontmpD_;
		NimStringV2 T16_;
		T10_ = (NIM_BOOL)0;
		T10_ = ((*n_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
		if (!(T10_)) goto LA11_;
		T12_ = (NI)0;
		T12_ = len__ast_u3190(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T10_ = (((NI)1) < T12_);
LA11_: ;
		if (!T10_) goto LA13_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T16_.len = 0; T16_.p = NIM_NIL;
		colontmpD_ = dollar___renderer_u2166((*n_2)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
		T16_ = rawNewString(colontmpD_.len + result.len + 2);
appendString((&T16_), colontmpD_);
appendString((&T16_), TM__oylmf9cXfpJWZ2cwj9b09bJaw_25);
appendString((&T16_), result);
appendString((&T16_), TM__oylmf9cXfpJWZ2cwj9b09bJaw_27);
		eqsink___system_u2700((&result), T16_);
		{
			LA15_:;
		}
		{
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA13_: ;
	{
		NIM_BOOL T20_;
		NI T22_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T26_;
		T20_ = (NIM_BOOL)0;
		T20_ = ((*n_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58) || (*n_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59));
		if (!(T20_)) goto LA21_;
		T22_ = (NI)0;
		T22_ = len__ast_u3190(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T20_ = (T22_ == ((NI)2));
LA21_: ;
		if (!T20_) goto LA23_;
		colontmpD__2 = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T26_.len = 0; T26_.p = NIM_NIL;
		colontmpD__2 = skipTypes__ast_u5379((*n_2).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_28);
		if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		colontmpD__3 = typeToString__types_u54(colontmpD__2, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		T26_ = rawNewString(colontmpD__3.len + result.len + 2);
appendString((&T26_), colontmpD__3);
appendString((&T26_), TM__oylmf9cXfpJWZ2cwj9b09bJaw_29);
appendString((&T26_), result);
appendString((&T26_), TM__oylmf9cXfpJWZ2cwj9b09bJaw_30);
		eqsink___system_u2700((&result), T26_);
		{
			LA25_:;
		}
		{
			oldNimErrFin25_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin25_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
LA23_: ;
LA8_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(n_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newHiddenAddrTaken__semdata_u7334)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isOutParam_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*(*(*c_p0).graph).config).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)2));
		if (T5_) goto LA6_;
		T5_ = (((*(*c_p0).module).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32)))&63U)))!=0);
LA6_: ;
		T3_ = !(T5_);
LA4_: ;
		if (!T3_) goto LA7_;
		checkSonsLen__semdata_u4671(n_p1, ((NI)1), (*(*c_p0).graph).config);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___ast_u3255(&result, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA7_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
		tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA aa_1;
		colontmpD_ = NIM_NIL;
		sym_1 = NIM_NIL;
		colontmpD_ = makeVarType__semdata_u4402(c_p0, (*n_p1).typField, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		result = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64), (*n_p1).info, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		add__ast_u3215(result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		aa_1 = isAssignable__semdata_u7330(c_p0, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		sym_1 = getRoot__trees_u373(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			if (!!((aa_1 == ((tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA)1) || aa_1 == ((tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA)2)))) goto LA13_;
			{
				NIM_BOOL T17_;
				T17_ = (NIM_BOOL)0;
				T17_ = (aa_1 == ((tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA)3));
				if (!(T17_)) goto LA18_;
				T17_ = (((NI)0) < (*c_p0).inUncheckedAssignSection);
LA18_: ;
				if (!T17_) goto LA19_;
			}
			goto LA15_;
LA19_: ;
			{
				NIM_BOOL T22_;
				NIM_BOOL T23_;
				NIM_BOOL T24_;
				NIM_BOOL T25_;
				T22_ = (NIM_BOOL)0;
				T23_ = (NIM_BOOL)0;
				T24_ = (NIM_BOOL)0;
				T25_ = (NIM_BOOL)0;
				T25_ = (((*c_p0).features &((NU32)1<<((NU)((((tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ)18)))&31U)))!=0);
				if (!(T25_)) goto LA26_;
				T25_ = (aa_1 == ((tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA)4));
LA26_: ;
				T24_ = T25_;
				if (!(T24_)) goto LA27_;
				T24_ = !((sym_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA27_: ;
				T23_ = T24_;
				if (!(T23_)) goto LA28_;
				T23_ = ((*sym_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9));
LA28_: ;
				T22_ = T23_;
				if (!(T22_)) goto LA29_;
				T22_ = isOutParam_p2;
LA29_: ;
				if (!T22_) goto LA30_;
			}
			goto LA15_;
LA30_: ;
			{
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__2 = renderNotLValue__semdata_u7314(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				colontmpD__3 = nsuFormatSingleElem(TM__oylmf9cXfpJWZ2cwj9b09bJaw_23, colontmpD__2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__oylmf9cXfpJWZ2cwj9b09bJaw_31, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
				{
					LA33_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
			}
LA15_: ;
		}
LA13_: ;
		{
			LA10_:;
		}
		{
			oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(sym_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin10_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, analyseIfAddressTaken__semdata_u7377)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isOutParam_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin26_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3255(&result, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
		colontmpD_ = NIM_NIL;
		{
			NIM_BOOL T5_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
			T5_ = (NIM_BOOL)0;
			T5_ = !(((*(*n_p1)._kind_4.sym).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
			if (!(T5_)) goto LA6_;
			colontmpD_ = skipTypes__ast_u5379((*(*n_p1)._kind_4.sym).typ, TM__oylmf9cXfpJWZ2cwj9b09bJaw_15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			T5_ = !(((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47)));
LA6_: ;
			if (!T5_) goto LA7_;
			(*(*n_p1)._kind_4.sym).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)17))) & 63);
			T9_ = NIM_NIL;
			T9_ = newHiddenAddrTaken__semdata_u7334(c_p0, n_p1, isOutParam_p2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto LA2_;}
			eqsink___ast_u3261(&result, T9_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
LA7_: ;
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		colontmpD__2 = NIM_NIL;
		checkSonsLen__semdata_u4671(n_p1, ((NI)2), (*(*c_p0).graph).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		{
			if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA16_;
			internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*n_p1).info, TM__oylmf9cXfpJWZ2cwj9b09bJaw_33, TM__oylmf9cXfpJWZ2cwj9b09bJaw_34);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA16_: ;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T22_;
			colontmpD__2 = skipTypes__ast_u5379((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym).typ, TM__oylmf9cXfpJWZ2cwj9b09bJaw_15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
			if (!!(((*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD__2).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47)))) goto LA20_;
			(*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)17))) & 63);
			T22_ = NIM_NIL;
			T22_ = newHiddenAddrTaken__semdata_u7334(c_p0, n_p1, isOutParam_p2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T22_); goto LA13_;}
			eqsink___ast_u3261(&result, T22_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		}
LA20_: ;
		{
			LA13_:;
		}
		{
			oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin13_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		colontmpD__3 = NIM_NIL;
		checkMinSonsLen__semdata_u4675(n_p1, ((NI)1), (*(*c_p0).graph).config);
		if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T35_;
			colontmpD__3 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_15);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
			if (!!(((*colontmpD__3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD__3).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47)))) goto LA29_;
			{
				if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA33_;
				(*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)17))) & 63);
			}
LA33_: ;
			T35_ = NIM_NIL;
			T35_ = newHiddenAddrTaken__semdata_u7334(c_p0, n_p1, isOutParam_p2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T35_); goto LA26_;}
			eqsink___ast_u3261(&result, T35_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
		}
LA29_: ;
		{
			LA26_:;
		}
		{
			oldNimErrFin26_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin26_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T39_;
		T39_ = NIM_NIL;
		T39_ = newHiddenAddrTaken__semdata_u7334(c_p0, n_p1, isOutParam_p2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T39_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T39_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipAddr__trees_u429)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	{
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64))) goto LA4_;
		eqcopy___ast_u3255(&result, (*n_p0)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA4_: ;
	{
		eqcopy___ast_u3255(&result, n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isOutParam__ast_u7655)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	result = (((*t_p0).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)45)))&63U)))!=0);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, analyseIfAddressTakenInCall__semdata_u7430)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, NIM_BOOL isConverter_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
NIM_BOOL oldNimErrFin25_;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL oldNimErrFin62_;
NIM_BOOL oldNimErrFin113_;
NIM_BOOL oldNimErrFin83_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	t_1 = NIM_NIL;
	checkMinSonsLen__semdata_u4675(n_p1, ((NI)1), (*(*c_p0).graph).config);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA4_;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	t_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_13);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T8_)) goto LA9_;
		T8_ = ((TM__oylmf9cXfpJWZ2cwj9b09bJaw_14[(NU)(((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic))>>3] &(1U<<((NU)(((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic))&7U)))!=0);
LA9_: ;
		if (!T8_) goto LA10_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)1);
			{
				while (1) {
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
					if (!(i_2 < colontmp_)) goto LA14;
					colontmpD_ = NIM_NIL;
					i_1 = i_2;
					{
						NIM_BOOL T18_;
						NIM_BOOL T19_;
						NI T20_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nodeX60gensym265__1;
						tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA aa_1;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T44_;
						T18_ = (NIM_BOOL)0;
						T19_ = (NIM_BOOL)0;
						T20_ = (NI)0;
						T20_ = len__ast_u5502(t_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						T19_ = (i_1 < T20_);
						if (!(T19_)) goto LA21_;
						T19_ = !(((*t_1).sons.p->data[i_1] == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA21_: ;
						T18_ = T19_;
						if (!(T18_)) goto LA22_;
						colontmpD_ = skipTypes__ast_u5379((*t_1).sons.p->data[i_1], TM__oylmf9cXfpJWZ2cwj9b09bJaw_15);
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
						T18_ = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
LA22_: ;
						if (!T18_) goto LA23_;
						it_1 = NIM_NIL;
						nodeX60gensym265__1 = NIM_NIL;
						eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
						aa_1 = isAssignable__semdata_u7330(c_p0, it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
						{
							if (!!((aa_1 == ((tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA)1) || aa_1 == ((tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA)2)))) goto LA28_;
							{
								if (!!(((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64)))) goto LA32_;
								{
									NIM_BOOL T36_;
									T36_ = (NIM_BOOL)0;
									T36_ = (aa_1 == ((tyEnum_TAssignableResult__3ybZZK771F9azx9ccTLKswSA)3));
									if (!(T36_)) goto LA37_;
									T36_ = (((NI)0) < (*c_p0).inUncheckedAssignSection);
LA37_: ;
									if (!T36_) goto LA38_;
								}
								goto LA34_;
LA38_: ;
								{
									NimStringV2 colontmpD__2;
									NimStringV2 colontmpD__3;
									colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
									colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
									colontmpD__2 = dollar___renderer_u2166(it_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
									colontmpD__3 = nsuFormatSingleElem(TM__oylmf9cXfpJWZ2cwj9b09bJaw_17, colontmpD__2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
									liMessage__msgs_u1227((*(*c_p0).graph).config, (*it_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__oylmf9cXfpJWZ2cwj9b09bJaw_18, NIM_FALSE, NIM_FALSE);
									if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
									{
										LA41_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__3);
										eqdestroy___system_u2691(colontmpD__2);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
								}
LA34_: ;
							}
LA32_: ;
						}
LA28_: ;
						T44_ = NIM_NIL;
						{
							if (!((*(*n_p1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65))) goto LA47_;
							eqcopy___ast_u3255(&nodeX60gensym265__1, (*(*n_p1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)0)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
						}
						goto LA45_;
LA47_: ;
						{
							eqcopy___ast_u3255(&nodeX60gensym265__1, (*n_p1)._kind_6.sons.p->data[i_1]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
						}
LA45_: ;
						{
							if (!((*nodeX60gensym265__1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32))) goto LA52_;
							analyseIfAddressTakenInCall__semdata_u7430(c_p0, nodeX60gensym265__1, NIM_TRUE);
							if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
						}
LA52_: ;
						{
							LA25_:;
						}
						{
							oldNimErrFin25_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(nodeX60gensym265__1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							eqdestroy___ast_u3252(it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
							*nimErr_ = oldNimErrFin25_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					}
LA23_: ;
					i_2 += ((NI)1);
					{
						LA15_:;
					}
					{
						oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin15_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				} LA14: ;
			}
		}
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* arg_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__4;
			if (!((*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)32) || (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)33) || (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)34))) goto LA60_;
			arg_1 = NIM_NIL;
			colontmpD__4 = NIM_NIL;
			arg_1 = (*n_p1)._kind_6.sons.p->data[((NI)1)];
			{
				if (!((*arg_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65))) goto LA65_;
				arg_1 = (*arg_1)._kind_6.sons.p->data[((NI)0)];
			}
LA65_: ;
			{
				NIM_BOOL T69_;
				NIM_BOOL T70_;
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				T69_ = (NIM_BOOL)0;
				T70_ = (NIM_BOOL)0;
				T70_ = ((*arg_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
				if (!(T70_)) goto LA71_;
				T70_ = ((*(*arg_1)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11));
LA71_: ;
				T69_ = T70_;
				if (!(T69_)) goto LA72_;
				colontmpD__4 = skipTypes__ast_u5379((*arg_1).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_19);
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
				T69_ = ((*colontmpD__4).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23) || (*colontmpD__4).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47));
LA72_: ;
				if (!T69_) goto LA73_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__5 = renderTree__renderer_u59((*n_p1)._kind_6.sons.p->data[((NI)1)], 4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				colontmpD__6 = nsuFormatSingleElem(TM__oylmf9cXfpJWZ2cwj9b09bJaw_21, colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__6, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__oylmf9cXfpJWZ2cwj9b09bJaw_22, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA75_;
				{
					LA75_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA62_;
			}
LA73_: ;
			{
				LA62_:;
			}
			{
				oldNimErrFin62_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin62_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA60_: ;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA10_: ;
	{
		NI i_3;
		NI colontmp__2;
		NI i_4;
		i_3 = (NI)0;
		colontmp__2 = (NI)0;
		colontmp__2 = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_4 = ((NI)1);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nodeX60gensym279__1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T84_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T90_;
				if (!(i_4 < colontmp__2)) goto LA82;
				n_2 = NIM_NIL;
				nodeX60gensym279__1 = NIM_NIL;
				colontmpD__7 = NIM_NIL;
				i_3 = i_4;
				T84_ = NIM_NIL;
				{
					if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65))) goto LA87_;
					eqcopy___ast_u3255(&n_2, (*n_p1)._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				}
				goto LA85_;
LA87_: ;
				{
					eqcopy___ast_u3255(&n_2, n_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				}
LA85_: ;
				T90_ = NIM_NIL;
				{
					if (!((*(*n_2)._kind_6.sons.p->data[i_3]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65))) goto LA93_;
					eqcopy___ast_u3255(&nodeX60gensym279__1, (*(*n_2)._kind_6.sons.p->data[i_3])._kind_6.sons.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				}
				goto LA91_;
LA93_: ;
				{
					eqcopy___ast_u3255(&nodeX60gensym279__1, (*n_2)._kind_6.sons.p->data[i_3]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				}
LA91_: ;
				{
					if (!((*nodeX60gensym279__1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32))) goto LA98_;
					analyseIfAddressTakenInCall__semdata_u7430(c_p0, nodeX60gensym279__1, NIM_TRUE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				}
LA98_: ;
				{
					NIM_BOOL T102_;
					NI T103_;
					T102_ = (NIM_BOOL)0;
					T103_ = (NI)0;
					T103_ = len__ast_u5502(t_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
					T102_ = (i_3 < T103_);
					if (!(T102_)) goto LA104_;
					colontmpD__7 = skipTypes__ast_u5379((*t_1).sons.p->data[i_3], TM__oylmf9cXfpJWZ2cwj9b09bJaw_15);
					if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
					T102_ = ((*colontmpD__7).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
LA104_: ;
					if (!T102_) goto LA105_;
					{
						NIM_BOOL T109_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__8;
						tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
						NIM_BOOL T114_;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T115_;
						T109_ = (NIM_BOOL)0;
						T109_ = !(((*(*n_2)._kind_6.sons.p->data[i_3]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)64)));
						if (T109_) goto LA110_;
						T109_ = isConverter_p2;
LA110_: ;
						if (!T109_) goto LA111_;
						colontmpD__8 = NIM_NIL;
						colontmpD__9 = NIM_NIL;
						colontmpD__8 = skipAddr__trees_u429((*n_2)._kind_6.sons.p->data[i_3]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
						colontmpD__9 = skipTypes__ast_u5379((*t_1).sons.p->data[i_3], TM__oylmf9cXfpJWZ2cwj9b09bJaw_15);
						if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
						T114_ = (NIM_BOOL)0;
						T114_ = isOutParam__ast_u7655(colontmpD__9);
						if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
						T115_ = NIM_NIL;
						T115_ = analyseIfAddressTaken__semdata_u7377(c_p0, colontmpD__8, T114_);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T115_); goto LA113_;}
						eqsink___ast_u3261(&(*n_2)._kind_6.sons.p->data[i_3], T115_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA113_;
						{
							LA113_:;
						}
						{
							oldNimErrFin113_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3378(colontmpD__9);
							if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
							eqdestroy___ast_u3252(colontmpD__8);
							if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
							*nimErr_ = oldNimErrFin113_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
					}
LA111_: ;
				}
LA105_: ;
				i_4 += ((NI)1);
				{
					LA83_:;
				}
				{
					oldNimErrFin83_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(nodeX60gensym279__1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___ast_u3252(n_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin83_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA82: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, makePtrType__semdata_u4378)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* baseType_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getCurrOwner__semdata_u425(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = makePtrType__semdata_u4373(colontmpD_, baseType_p1, (*c_p0).Sup.idgen);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, symNodeFromType__semdata_u4649)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = symFromType__semdata_u4633(c_p0, t_p1, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newSymNode__ast_u5171(colontmpD_, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	T1_ = makeTypeDesc__semdata_u4621(c_p0, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T1_); goto BeforeRet_;}
	eqsink___ast_u3387(&(*result).typField, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, firstParamType__ast_u5363)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*n_p0).sons.p->data[((NI)1)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, replaceHookMagic__semdata_u7550)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q kind_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL oldNimErrFin31_;
NIM_BOOL oldNimErrFin51_;
NIM_BOOL oldNimErrFin40_;
NIM_BOOL oldNimErrFin58_;
NIM_BOOL oldNimErrFin69_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	switch (kind_p2) {
	case ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_1;
		t_1 = NIM_NIL;
		op_1 = NIM_NIL;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		t_1 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		op_1 = getAttachedOp__modulegraphs_u4987((*c_p0).graph, t_1, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T7_;
			if (!!((op_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA5_;
			colontmpD_ = NIM_NIL;
			T7_ = NIM_NIL;
			T7_ = newSymNode__ast_u5168(op_1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T7_); goto LA2_;}
			eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[((NI)0)], T7_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			{
				NIM_BOOL T10_;
				NIM_BOOL T11_;
				NI T13_;
				T10_ = (NIM_BOOL)0;
				T11_ = (NIM_BOOL)0;
				T11_ = !(((*op_1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
				if (!(T11_)) goto LA12_;
				T13_ = (NI)0;
				T13_ = len__ast_u5502((*op_1).typ);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T11_ = (T13_ == ((NI)2));
LA12_: ;
				T10_ = T11_;
				if (!(T10_)) goto LA14_;
				colontmpD_ = firstParamType__ast_u5363((*op_1).typ);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T10_ = !(((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23)));
LA14_: ;
				if (!T10_) goto LA15_;
				{
					NIM_BOOL T19_;
					NIM_BOOL T20_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T25_;
					T19_ = (NIM_BOOL)0;
					T20_ = (NIM_BOOL)0;
					T20_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
					if (!(T20_)) goto LA21_;
					T20_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3));
LA21_: ;
					T19_ = T20_;
					if (!(T19_)) goto LA22_;
					T19_ = ((*(*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23));
LA22_: ;
					if (!T19_) goto LA23_;
					T25_ = NIM_NIL;
					T25_ = genDeref__lowerings_u426((*n_p1)._kind_6.sons.p->data[((NI)1)], ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65));
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T25_); goto LA2_;}
					eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[((NI)1)], T25_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				}
				goto LA17_;
LA23_: ;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T27_;
					T27_ = NIM_NIL;
					T27_ = skipAddr__trees_u429((*n_p1)._kind_6.sons.p->data[((NI)1)]);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T27_); goto LA2_;}
					eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[((NI)1)], T27_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				}
LA17_: ;
			}
LA15_: ;
			eqdestroy___ast_u3378(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
LA5_: ;
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(op_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)5):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_2;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_2;
		t_2 = NIM_NIL;
		op_2 = NIM_NIL;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		t_2 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		op_2 = getAttachedOp__modulegraphs_u4987((*c_p0).graph, t_2, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)5));
		if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T36_;
			if (!!((op_2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA34_;
			T36_ = NIM_NIL;
			T36_ = newSymNode__ast_u5168(op_2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T36_); goto LA31_;}
			eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[((NI)0)], T36_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
		}
LA34_: ;
		{
			LA31_:;
		}
		{
			oldNimErrFin31_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(op_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin31_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)3):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_3;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_3;
		t_3 = NIM_NIL;
		op_3 = NIM_NIL;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		t_3 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		op_3 = getAttachedOp__modulegraphs_u4987((*c_p0).graph, t_3, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T45_;
			if (!!((op_3 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA43_;
			T45_ = NIM_NIL;
			T45_ = newSymNode__ast_u5168(op_3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T45_); goto LA40_;}
			eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[((NI)0)], T45_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			{
				NI T48_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* boolLit_1;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T52_;
				T48_ = (NI)0;
				T48_ = len__ast_u5502((*op_3).typ);
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
				if (!(T48_ == ((NI)3))) goto LA49_;
				boolLit_1 = NIM_NIL;
				boolLit_1 = newIntLit__lowerings_u465((*c_p0).graph, (*n_p1).info, IL64(1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				T52_ = NIM_NIL;
				T52_ = getSysType__magicsys_u55((*c_p0).graph, (*n_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T52_); goto LA51_;}
				eqsink___ast_u3387(&(*boolLit_1).typField, T52_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				add__ast_u3215(result, boolLit_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA51_;
				{
					LA51_:;
				}
				{
					oldNimErrFin51_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(boolLit_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					*nimErr_ = oldNimErrFin51_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
			}
LA49_: ;
		}
LA43_: ;
		{
			LA40_:;
		}
		{
			oldNimErrFin40_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(op_3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin40_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)0):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_4;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_4;
		t_4 = NIM_NIL;
		op_4 = NIM_NIL;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		t_4 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		op_4 = getAttachedOp__modulegraphs_u4987((*c_p0).graph, t_4, ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T63_;
			if (!!((op_4 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA61_;
			T63_ = NIM_NIL;
			T63_ = newSymNode__ast_u5168(op_4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T63_); goto LA58_;}
			eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[((NI)0)], T63_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
			analyseIfAddressTakenInCall__semdata_u7430(c_p0, result, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA58_;
		}
LA61_: ;
		{
			LA58_:;
		}
		{
			oldNimErrFin58_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(op_4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin58_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)4):
	{
		result = (*c_p0).semAsgnOpr(c_p0, n_p1, ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)149));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)2):
	{
		result = (*c_p0).semAsgnOpr(c_p0, n_p1, ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)73));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q)6):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_5;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* op_5;
		t_5 = NIM_NIL;
		op_5 = NIM_NIL;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
		t_5 = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__oylmf9cXfpJWZ2cwj9b09bJaw_35);
		if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
		op_5 = getAttachedOp__modulegraphs_u4987((*c_p0).graph, t_5, kind_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T74_;
			if (!!((op_5 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA72_;
			T74_ = NIM_NIL;
			T74_ = newSymNode__ast_u5168(op_5);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T74_); goto LA69_;}
			eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[((NI)0)], T74_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA69_;
		}
LA72_: ;
		{
			LA69_:;
		}
		{
			oldNimErrFin69_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(op_5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(t_5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin69_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u3618)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* dest_p0, tySequence__KYLoGmc5aaHsSDjEH1FTxQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___semdata_u3609((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3606)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u3676)(tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field1);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.Field1)));
		nimRawDispose(dest_p0.Field1, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u3673)(tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ* dest_p0) {
	(*dest_p0).Field0.line = 0;
	(*dest_p0).Field0.col = 0;
	(*dest_p0).Field0.fileIndex = 0;
	(*dest_p0).Field1 = 0;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__KYLoGmc5aaHsSDjEH1FTxQ, eqdup___semdata_u3615)(tySequence__KYLoGmc5aaHsSDjEH1FTxQ src_p0) {
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__semdata_u3631((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_].Field0.line = src_p0.p->data[colontmp_].Field0.line;
			result.p->data[colontmp_].Field0.col = src_p0.p->data[colontmp_].Field0.col;
			result.p->data[colontmp_].Field0.fileIndex = src_p0.p->data[colontmp_].Field0.fileIndex;
			result.p->data[colontmp_].Field1 = src_p0.p->data[colontmp_].Field1;
			{
				if (!src_p0.p->data[colontmp_].Field1) goto LA7_;
				nimIncRef(src_p0.p->data[colontmp_].Field1);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addPureEnum__semdata_u4312)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA e_p1) {
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdup___modulegraphs_u1864(e_p1, (&colontmpD_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__modulegraphs_u6885((&(*(*c_p0).graph).ifaces.p->data[(*(*c_p0).module).position].pureEnums), colontmpD_);
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addPureEnum__icZic_u3212(T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), e_p1.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getIntLitType__semdata_u279)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* literal_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	NI64 value_1;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin16_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	value_1 = (*literal_p1)._kind_1.intVal;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (IL64(-5) <= value_1);
		if (!(T3_)) goto LA4_;
		T3_ = (value_1 <= IL64(32));
LA4_: ;
		if (!T3_) goto LA5_;
		eqcopy___ast_u3381(&result, (*c_p0).intTypeCache[(((NI) (value_1)))- -5]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ti_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T12_;
			if (!(result == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))) goto LA9_;
			ti_1 = NIM_NIL;
			colontmpD_ = NIM_NIL;
			ti_1 = getSysType__magicsys_u55((*c_p0).graph, (*literal_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			colontmpD_ = owner__ast_u6246(ti_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			T12_ = NIM_NIL;
			T12_ = copyType__ast_u6238(ti_1, (*c_p0).Sup.idgen, colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T12_); goto LA11_;}
			eqsink___ast_u3387(&result, T12_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			eqcopy___ast_u3255(&(*result).n, literal_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			eqcopy___ast_u3381(&(*c_p0).intTypeCache[(((NI) (value_1)))- -5], result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			{
				LA11_:;
			}
			{
				oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4574(colontmpD_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u3378(ti_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin11_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA9_: ;
	}
	goto LA1_;
LA5_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ti_2;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
		ti_2 = NIM_NIL;
		colontmpD__2 = NIM_NIL;
		ti_2 = getSysType__magicsys_u55((*c_p0).graph, (*literal_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		colontmpD__2 = owner__ast_u6246(ti_2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		result = copyType__ast_u6238(ti_2, (*c_p0).Sup.idgen, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		eqcopy___ast_u3255(&(*result).n, literal_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
		{
			LA16_:;
		}
		{
			oldNimErrFin16_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(colontmpD__2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3378(ti_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin16_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setIntLitType__semdata_u323)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result_p1) {
	NI64 i_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	i_1 = (*result_p1)._kind_1.intVal;
	switch ((*(*(*c_p0).graph).config).target.intSize) {
	case ((NI)8):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T2_;
		T2_ = NIM_NIL;
		T2_ = getIntLitType__semdata_u279(c_p0, result_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T2_); goto BeforeRet_;}
		eqsink___ast_u3387(&(*result_p1).typField, T2_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((NI)4):
	{
		{
			NIM_BOOL T6_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T10_;
			T6_ = (NIM_BOOL)0;
			T6_ = (IL64(-2147483648) <= i_1);
			if (!(T6_)) goto LA7_;
			T6_ = (i_1 <= IL64(2147483647));
LA7_: ;
			if (!T6_) goto LA8_;
			T10_ = NIM_NIL;
			T10_ = getIntLitType__semdata_u279(c_p0, result_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T10_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T10_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA4_;
LA8_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T12_;
			T12_ = NIM_NIL;
			T12_ = getSysType__magicsys_u55((*c_p0).graph, (*result_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T12_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T12_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA4_: ;
	}
	break;
	case ((NI)2):
	{
		{
			NIM_BOOL T16_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T20_;
			T16_ = (NIM_BOOL)0;
			T16_ = (IL64(-32768) <= i_1);
			if (!(T16_)) goto LA17_;
			T16_ = (i_1 <= IL64(32767));
LA17_: ;
			if (!T16_) goto LA18_;
			T20_ = NIM_NIL;
			T20_ = getIntLitType__semdata_u279(c_p0, result_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T20_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T20_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA14_;
LA18_: ;
		{
			NIM_BOOL T22_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T26_;
			T22_ = (NIM_BOOL)0;
			T22_ = (IL64(-2147483648) <= i_1);
			if (!(T22_)) goto LA23_;
			T22_ = (i_1 <= IL64(2147483647));
LA23_: ;
			if (!T22_) goto LA24_;
			T26_ = NIM_NIL;
			T26_ = getSysType__magicsys_u55((*c_p0).graph, (*result_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T26_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T26_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA14_;
LA24_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T28_;
			T28_ = NIM_NIL;
			T28_ = getSysType__magicsys_u55((*c_p0).graph, (*result_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T28_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T28_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA14_: ;
	}
	break;
	case ((NI)1):
	{
		{
			NIM_BOOL T32_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T36_;
			T32_ = (NIM_BOOL)0;
			T32_ = (IL64(-128) <= i_1);
			if (!(T32_)) goto LA33_;
			T32_ = (i_1 <= IL64(127));
LA33_: ;
			if (!T32_) goto LA34_;
			T36_ = NIM_NIL;
			T36_ = getIntLitType__semdata_u279(c_p0, result_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T36_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T36_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA30_;
LA34_: ;
		{
			NIM_BOOL T38_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T42_;
			T38_ = (NIM_BOOL)0;
			T38_ = (IL64(-32768) <= i_1);
			if (!(T38_)) goto LA39_;
			T38_ = (i_1 <= IL64(32767));
LA39_: ;
			if (!T38_) goto LA40_;
			T42_ = NIM_NIL;
			T42_ = getSysType__magicsys_u55((*c_p0).graph, (*result_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T42_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T42_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA30_;
LA40_: ;
		{
			NIM_BOOL T44_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T48_;
			T44_ = (NIM_BOOL)0;
			T44_ = (IL64(-2147483648) <= i_1);
			if (!(T44_)) goto LA45_;
			T44_ = (i_1 <= IL64(2147483647));
LA45_: ;
			if (!T44_) goto LA46_;
			T48_ = NIM_NIL;
			T48_ = getSysType__magicsys_u55((*c_p0).graph, (*result_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T48_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T48_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA30_;
LA46_: ;
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T50_;
			T50_ = NIM_NIL;
			T50_ = getSysType__magicsys_u55((*c_p0).graph, (*result_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T50_); goto BeforeRet_;}
			eqsink___ast_u3387(&(*result_p1).typField, T50_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA30_: ;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*result_p1).info, TM__oylmf9cXfpJWZ2cwj9b09bJaw_37, TM__oylmf9cXfpJWZ2cwj9b09bJaw_38);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u382)(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0.inst);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u1177((*dest_p0.inst));
		nimRawDispose(dest_p0.inst, ((NI)4));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn(dest_p0.genericSym);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3469((&(*dest_p0.genericSym)));
		nimRawDispose(dest_p0.genericSym, ((NI)4));
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u379)(tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw* dest_p0) {
	(*dest_p0).genericSym = 0;
	(*dest_p0).inst = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u698)(tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ** dest_p0) {
	(*dest_p0) = 0;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w info_p0) {
	NimStringV2 result;
	result = TM__oylmf9cXfpJWZ2cwj9b09bJaw_40;
	prepareAdd((&result), info_p0.Field0.len + 0);
appendString((&result), info_p0.Field0);
	{
		if (!(((NI)0) < info_p0.Field1)) goto LA3_;
		prepareAdd((&result), 1);
appendString((&result), TM__oylmf9cXfpJWZ2cwj9b09bJaw_41);
		addInt__stdZprivateZdigitsutils_u204((&result), info_p0.Field1);
		{
			if (!(((NI)0) < (NI)(info_p0.Field2 + ((NI)1)))) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__oylmf9cXfpJWZ2cwj9b09bJaw_43);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)(info_p0.Field2 + ((NI)1)));
		}
LA7_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__oylmf9cXfpJWZ2cwj9b09bJaw_44);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, makeTypeSymNode__semdata_u4411)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typedesc_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	typedesc_1 = NIM_NIL;
	sym_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD__2 = NIM_NIL;
	typedesc_1 = newTypeS__semdata_u4368(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8), c_p0, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*typedesc_1).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)38))) & 63);
	{
		NimStringV2 argX60gensym127__1;
		if (!!(!((typ_p1 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL))))) goto LA4_;
		argX60gensym127__1.len = 0; argX60gensym127__1.p = NIM_NIL;
		argX60gensym127__1 = toFileLineCol__msgs_u701(TM__oylmf9cXfpJWZ2cwj9b09bJaw_45);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, unknownLineInfo__lineinfos_u364, argX60gensym127__1, TM__oylmf9cXfpJWZ2cwj9b09bJaw_45);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(argX60gensym127__1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	addSonSkipIntLit__magicsys_u135(typedesc_1, typ_p1, (*c_p0).Sup.idgen);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getCurrOwner__semdata_u425(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7), (*(*c_p0).cache).idAnon, (*c_p0).Sup.idgen, colontmpD_, info_p2, (*(*(*c_p0).graph).config).options);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	sym_1 = linkTo__ast_u4644(colontmpD__2, typedesc_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = newSymNode__ast_u5171(sym_1, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(sym_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(typedesc_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushCaseContext__semdata_u4693)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* caseNode_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyTuple__R9cYIordoMujN7rycr4Y7kw T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&T1_), sizeof(tyTuple__R9cYIordoMujN7rycr4Y7kw));
	colontmpD_ = eqdup___ast_u3258(caseNode_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.Field0 = colontmpD_;
	T1_.Field1 = ((NI)0);
	add__semdata_u4696((&(*(*c_p0).p).caseContext), T1_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u970)(tyTuple__R9cYIordoMujN7rycr4Y7kw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
}
static N_INLINE(void, pop__semdata_u4718)(tySequence__yo9alHJGzX03OXpfmEsBjBQ* s_p0, tyTuple__R9cYIordoMujN7rycr4Y7kw* Result) {
	NI L_1;
	NI T1_;
	T1_ = (*s_p0).len;
	L_1 = (NI)(T1_ - ((NI)1));
	(*Result).Field0 = (*s_p0).p->data[L_1].Field0;
	(*Result).Field1 = (*s_p0).p->data[L_1].Field1;
	eqwasMoved___semdata_u970((&(*s_p0).p->data[L_1]));
	shrink__semdata_u936(s_p0, (L_1));
}
N_LIB_PRIVATE N_NIMCALL(void, popCaseContext__semdata_u4716)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyTuple__R9cYIordoMujN7rycr4Y7kw colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&colontmpD_), sizeof(tyTuple__R9cYIordoMujN7rycr4Y7kw));
	pop__semdata_u4718((&(*(*c_p0).p).caseContext), (&colontmpD_));
	(void)(colontmpD_);
	eqdestroy___semdata_u973(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyTuple__R9cYIordoMujN7rycr4Y7kw*, X5BX5D___semdata_u4740)(tyTuple__R9cYIordoMujN7rycr4Y7kw* s_p0, NI s_p0Len_0, NI i_p1) {
	tyTuple__R9cYIordoMujN7rycr4Y7kw* result;
	result = (&s_p0[(NI)(s_p0Len_0 - i_p1)]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setCaseContextIdx__semdata_u4737)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, NI idx_p1) {
	tyTuple__R9cYIordoMujN7rycr4Y7kw* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (tyTuple__R9cYIordoMujN7rycr4Y7kw*)0;
	T1_ = X5BX5D___semdata_u4740((((*(*c_p0).p).caseContext).p) ? ((*(*c_p0).p).caseContext.p->data) : NIM_NIL, (*(*c_p0).p).caseContext.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).Field1 = idx_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addConverter__semdata_u4291)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA conv_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = inclSym__semdata_u4261((&(*c_p0).converters), conv_p1.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		eqdup___modulegraphs_u1864(conv_p1, (&colontmpD_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__modulegraphs_u6885((&(*(*c_p0).graph).ifaces.p->data[(*(*c_p0).module).position].converters), colontmpD_);
	}
LA4_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addConverterDef__semdata_u4305)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA conv_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addConverter__semdata_u4291(c_p0, conv_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addConverter__icZic_u3172(T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), conv_p1.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addImportFileDep__semdata_u4247)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, NI32 f_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addImportFileDep__icZic_u3057(T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), f_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___semdata_u3006)(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* dest_p0, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).m);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).m)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).m, ((NI)4));
	}
LA4_: ;
	(*dest_p0).m = (*src_p1).m;
	switch ((*dest_p0).mode) {
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
	{
	}
	break;
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
	{
		nimZeroMem((void*)(*dest_p0)._mode_2.imported.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
		eqdestroy___pureZcollectionsZintsets_u100((*dest_p0)._mode_2.imported.data);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*dest_p0)._mode_2.imported.data.len = 0; (*dest_p0)._mode_2.imported.data.p = NIM_NIL;
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = nimDecRefIsLastDyn((*dest_p0)._mode_2.imported.head);
			if (!T10_) goto LA11_;
			eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0)._mode_2.imported.head)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimZeroMem((void*)(&(*(*dest_p0)._mode_2.imported.head)), sizeof(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA));
			nimRawDispose((*dest_p0)._mode_2.imported.head, ((NI)4));
		}
LA11_: ;
		(*dest_p0)._mode_2.imported.max = 0;
		(*dest_p0)._mode_2.imported.counter = 0;
		(*dest_p0)._mode_2.imported.elems = 0;
	}
	break;
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
	{
		nimZeroMem((void*)(*dest_p0)._mode_3.exceptSet.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
		eqdestroy___pureZcollectionsZintsets_u100((*dest_p0)._mode_3.exceptSet.data);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*dest_p0)._mode_3.exceptSet.data.len = 0; (*dest_p0)._mode_3.exceptSet.data.p = NIM_NIL;
		{
			NIM_BOOL T16_;
			T16_ = (NIM_BOOL)0;
			T16_ = nimDecRefIsLastDyn((*dest_p0)._mode_3.exceptSet.head);
			if (!T16_) goto LA17_;
			eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0)._mode_3.exceptSet.head)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimZeroMem((void*)(&(*(*dest_p0)._mode_3.exceptSet.head)), sizeof(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA));
			nimRawDispose((*dest_p0)._mode_3.exceptSet.head, ((NI)4));
		}
LA17_: ;
		(*dest_p0)._mode_3.exceptSet.max = 0;
		(*dest_p0)._mode_3.exceptSet.counter = 0;
		(*dest_p0)._mode_3.exceptSet.elems = 0;
	}
	break;
	default: __builtin_unreachable();
	}
	(*dest_p0).mode = 0;
	(*dest_p0).mode = (*src_p1).mode;
	switch ((*dest_p0).mode) {
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
	{
	}
	break;
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
	{
		(*dest_p0)._mode_2.imported = (*src_p1)._mode_2.imported;
	}
	break;
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
	{
		(*dest_p0)._mode_3.exceptSet = (*src_p1)._mode_3.exceptSet;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u2994)(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* dest_p0) {
	(*dest_p0).m = 0;
	(*dest_p0).mode = 0;
	switch ((*dest_p0).mode) {
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
	{
	}
	break;
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
	{
		(*dest_p0)._mode_2.imported.elems = 0;
		(*dest_p0)._mode_2.imported.counter = 0;
		(*dest_p0)._mode_2.imported.max = 0;
		(*dest_p0)._mode_2.imported.head = 0;
		(*dest_p0)._mode_2.imported.data.len = 0; (*dest_p0)._mode_2.imported.data.p = NIM_NIL;
		nimZeroMem((void*)(*dest_p0)._mode_2.imported.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
	}
	break;
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
	{
		(*dest_p0)._mode_3.exceptSet.elems = 0;
		(*dest_p0)._mode_3.exceptSet.counter = 0;
		(*dest_p0)._mode_3.exceptSet.max = 0;
		(*dest_p0)._mode_3.exceptSet.head = 0;
		(*dest_p0)._mode_3.exceptSet.data.len = 0; (*dest_p0)._mode_3.exceptSet.data.p = NIM_NIL;
		nimZeroMem((void*)(*dest_p0)._mode_3.exceptSet.a, sizeof(tyArray__k7D0lwfLmYccbQxUd49bbcQ));
	}
	break;
	default: __builtin_unreachable();
	}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2997)(tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* dest_p0) {
	switch ((*dest_p0).mode) {
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
	{
	}
	break;
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
	{
		eqdestroy___pureZcollectionsZintsets_u100((*dest_p0)._mode_2.imported.data);
		{
			NIM_BOOL T5_;
			T5_ = (NIM_BOOL)0;
			T5_ = nimDecRefIsLastDyn((*dest_p0)._mode_2.imported.head);
			if (!T5_) goto LA6_;
			eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0)._mode_2.imported.head)));
			nimRawDispose((*dest_p0)._mode_2.imported.head, ((NI)4));
		}
LA6_: ;
	}
	break;
	case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
	{
		eqdestroy___pureZcollectionsZintsets_u100((*dest_p0)._mode_3.exceptSet.data);
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = nimDecRefIsLastDyn((*dest_p0)._mode_3.exceptSet.head);
			if (!T11_) goto LA12_;
			eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0)._mode_3.exceptSet.head)));
			nimRawDispose((*dest_p0)._mode_3.exceptSet.head, ((NI)4));
		}
LA12_: ;
	}
	break;
	default: __builtin_unreachable();
	}
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = nimDecRefIsLastDyn((*dest_p0).m);
		if (!T16_) goto LA17_;
		eqdestroy___ast_u3469((&(*(*dest_p0).m)));
		nimRawDispose((*dest_p0).m, ((NI)4));
	}
LA17_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addIncludeFileDep__semdata_u4240)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, NI32 f_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addIncludeFileDep__icZic_u3049(T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), f_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, reexportSym__semdata_u4355)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	strTableAdds__modulegraphs_u2993((*c_p0).graph, (*c_p0).module, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		addReexport__icZic_u3235(T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___sem_u29486)(tyProc__GbPSPD9bjvt0RIJnnVTczJA* dest_p0, tyProc__GbPSPD9bjvt0RIJnnVTczJA src_p1) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___sem_u29537)(tyProc__iDJMP540ifFac3zJ49bj2cA* dest_p0, tyProc__iDJMP540ifFac3zJ49bj2cA src_p1) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___sem_u29588)(tyProc__gq9a76bauTeymgreaiTI9cmg* dest_p0, tyProc__gq9a76bauTeymgreaiTI9cmg src_p1) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___sem_u29639)(tyProc__Gji0NjiFFDU49aJiF3QZF8A* dest_p0, tyProc__Gji0NjiFFDU49aJiF3QZF8A src_p1) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___sem_u29728)(tyProc__0qHBYUhlP28E2DV7mVNNAg* dest_p0, tyProc__0qHBYUhlP28E2DV7mVNNAg src_p1) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, storeRodNode__semdata_u4793)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T5_;
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		T5_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
		T5_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
		toPackedNodeTopLevel__icZic_u7507(n_p1, T5_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, sealRodFile__semdata_u7250)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA3_;
		{
			if (!!(((*(*c_p0).graph).vm == ((RootObj*) NIM_NIL)))) goto LA7_;
			{
				tySequence__fnH5Zt4fsGx0AgDTOw8pKw colontmp_;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** m_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_1;
				NI i_1;
				NI L_1;
				NI T10_;
				colontmp_.len = 0; colontmp_.p = NIM_NIL;
				m_1 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
				n_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
				eqcopy___vmdef_u1847((&colontmp_), (*(*((tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew**) (&((*(*c_p0).graph).vm))))).vmstateDiff);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_1 = ((NI)0);
				T10_ = colontmp_.len;
				L_1 = T10_;
				{
					while (1) {
						if (!(i_1 < L_1)) goto LA12;
						m_1 = &colontmp_.p->data[i_1].Field0;
						n_1 = &colontmp_.p->data[i_1].Field1;
						{
							if (!((*m_1) == (*c_p0).module)) goto LA15_;
							addPragmaComputation__semdata_u4254(c_p0, (*n_1));
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						}
LA15_: ;
						i_1 += ((NI)1);
					} LA12: ;
				}
				eqdestroy___vmdef_u1844(colontmp_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
		}
LA7_: ;
		(*(*c_p0).Sup.idgen).sealed = NIM_TRUE;
	}
LA3_: ;
	}BeforeRet_: ;
}
