/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyTuple__WIyQ4Cfp4shlBOyEpagHMw tyTuple__WIyQ4Cfp4shlBOyEpagHMw;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw tySequence__AE2UIxl7EbPzzBnmYsjIcw;
typedef struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content;
typedef struct tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ;
typedef struct tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q tySequence__tsHRsYLyvTCPLlGRExqi7Q;
typedef struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA tySequence__lAikaRQvUF0uwNAz0U4FFA;
typedef struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content tySequence__lAikaRQvUF0uwNAz0U4FFA_Content;
typedef struct tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A tySequence__4zAALtm0xUbRlYWQ2V8K7A;
typedef struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA tySequence__9bffTLF0HkxjFCzZL8og4GA;
typedef struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content tySequence__9bffTLF0HkxjFCzZL8og4GA_Content;
typedef struct tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw tySequence__Bis5AbpONWcIRrPyPJS8Yw;
typedef struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content;
typedef struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw tySequence__E8pi9b5QNahsURYzXMjh3qw;
typedef struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content tySequence__E8pi9b5QNahsURYzXMjh3qw_Content;
typedef struct tyObject_Table__g77QNejuRRKraNk8K2YkoA tyObject_Table__g77QNejuRRKraNk8K2YkoA;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w tySequence__3B6hFqG0Do0FxDvnNucL7w;
typedef struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content tySequence__3B6hFqG0Do0FxDvnNucL7w_Content;
typedef struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg tyObject_Table__toCaB3NxiVHPRVLgcez0Xg;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A tySequence__QqvaCqCpEE1QmQZbcZLi5A;
typedef struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag;
typedef struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw;
typedef struct tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ;
typedef struct tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ;
typedef struct tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tySequence__3rs2HI7A9bn1iHmZchCo1lg tySequence__3rs2HI7A9bn1iHmZchCo1lg;
typedef struct tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content;
typedef struct tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw;
typedef struct tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw;
typedef struct tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ;
typedef struct tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ_Content tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ_Content;
typedef struct tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q;
typedef struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g tyTuple__kuMQ1fbjJlHtwKTmBGAe6g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
typedef struct tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w;
typedef struct tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg;
typedef struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ tySequence__7OXYQ6bHRkhJpRaiS7kiwQ;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content;
typedef struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__09aD69az7aYn14Gt61AHvLIA tyTuple__09aD69az7aYn14Gt61AHvLIA;
typedef struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ tyTuple__NAaJgGVgNmlGoqmiWxdOHQ;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ tySequence__KYLoGmc5aaHsSDjEH1FTxQ;
typedef struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content;
typedef struct tyTuple__EbsafWGli8bW2GRJQ9apsjA tyTuple__EbsafWGli8bW2GRJQ9apsjA;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg;
typedef struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct tyTuple__WIyQ4Cfp4shlBOyEpagHMw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	NI Field1;
	NIM_BOOL Field2;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
typedef NU16 tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw {
  NI len; tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__uJvLVbod8mnHGzJkQj89bWg[38];
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q {
  NI len; tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content* p;
};
struct tySequence__lAikaRQvUF0uwNAz0U4FFA {
  NI len; tySequence__lAikaRQvUF0uwNAz0U4FFA_Content* p;
};
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__Yik7hgYZHhPeLJ5RsXTPqg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p2);
typedef NU32 tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__JIyBW5s9ba7hfYBnWxDVvgg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p3);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__iXlRd9cBAN0CQpA5dkyhRvw) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__7FLV9alRQFu6LOhr9bksExQQ) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, void* ClE_0);
void* ClE_0;
} tyProc__0qHBYUhlP28E2DV7mVNNAg;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__1nD4dBuhjTAOzMZJo9bmgog) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
typedef NU32 tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__209aOewTLBT6nbWmyvOQFiw) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nOrig_p2, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p3, tySet_tyEnum_TExprFlag__LJ8tOeZrTQZuHS9cNbj1XCg flags_p4, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p5);
typedef N_NIMCALL_PTR(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, tyProc__D9aXgBooMpgLrPTmha6q31w) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* prev_p2);
typedef struct {
N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, void* ClE_0);
void* ClE_0;
} tyProc__GbPSPD9bjvt0RIJnnVTczJA;
typedef struct {
N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fn_p1, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, void* ClE_0);
void* ClE_0;
} tyProc__iDJMP540ifFac3zJ49bj2cA;
typedef struct {
N_NIMCALL_PTR(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* pt_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, void* ClE_0);
void* ClE_0;
} tyProc__gq9a76bauTeymgreaiTI9cmg;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* expectedType_p2, void* ClE_0);
void* ClE_0;
} tyProc__Gji0NjiFFDU49aJiF3QZF8A;
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A {
  NI len; tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content* p;
};
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__UAj9bGJLVN9cwAsTcRZFyWmg) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dc_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q op_p4, NI col_p5);
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
struct tySequence__9bffTLF0HkxjFCzZL8og4GA {
  NI len; tySequence__9bffTLF0HkxjFCzZL8og4GA_Content* p;
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw {
  NI len; tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content* p;
};
struct tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ {
	tySequence__Bis5AbpONWcIRrPyPJS8Yw data;
	NI counter;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw {
  NI len; tySequence__E8pi9b5QNahsURYzXMjh3qw_Content* p;
};
struct tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw {
	tySequence__E8pi9b5QNahsURYzXMjh3qw data;
	NI counter;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w {
  NI len; tySequence__3B6hFqG0Do0FxDvnNucL7w_Content* p;
};
struct tyObject_Table__g77QNejuRRKraNk8K2YkoA {
	tySequence__3B6hFqG0Do0FxDvnNucL7w data;
	NI counter;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A {
  NI len; tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content* p;
};
struct tyObject_Table__toCaB3NxiVHPRVLgcez0Xg {
	tySequence__QqvaCqCpEE1QmQZbcZLi5A data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__bvRec9bo79ajqrJt3Bkg9c33w) (tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw k_p2);
struct tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* enforceVoidContext;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* voidType;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* currentScope;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* moduleScope;
	tySequence__AE2UIxl7EbPzzBnmYsjIcw imports;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* topLevelScope;
	tyObject_TProcCon__ftBtv4UEhPouLts4uXXNLQ* p;
	tyArray__uJvLVbod8mnHGzJkQj89bWg intTypeCache;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* nilTypeCache;
	tyObject_TMatchedConcept__tvh59a8SIGC9ccJV9atmyb8kg* matchedConcept;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA friendModules;
	NI instCounter;
	NI* templInstCounter;
	NI inGenericContext;
	NI inStaticContext;
	NI inUnrolledContext;
	NI compilesContextId;
	NI compilesContextIdGenerator;
	NI inGenericInst;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA converters;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA patterns;
	tySequence__tsHRsYLyvTCPLlGRExqi7Q optionStack;
	tySequence__lAikaRQvUF0uwNAz0U4FFA libs;
	tyProc__Yik7hgYZHhPeLJ5RsXTPqg semConstExpr;
	tyProc__JIyBW5s9ba7hfYBnWxDVvgg semExpr;
	tyProc__JIyBW5s9ba7hfYBnWxDVvgg semExprWithType;
	tyProc__iXlRd9cBAN0CQpA5dkyhRvw semTryExpr;
	tyProc__Yik7hgYZHhPeLJ5RsXTPqg semTryConstExpr;
	tyProc__7FLV9alRQFu6LOhr9bksExQQ computeRequiresInit;
	tyProc__0qHBYUhlP28E2DV7mVNNAg hasUnresolvedArgs;
	tyProc__iXlRd9cBAN0CQpA5dkyhRvw semOperand;
	tyProc__1nD4dBuhjTAOzMZJo9bmgog semConstBoolExpr;
	tyProc__209aOewTLBT6nbWmyvOQFiw semOverloadedCall;
	tyProc__D9aXgBooMpgLrPTmha6q31w semTypeNode;
	tyProc__GbPSPD9bjvt0RIJnnVTczJA semInferredLambda;
	tyProc__iDJMP540ifFac3zJ49bj2cA semGenerateInstance;
	tyProc__gq9a76bauTeymgreaiTI9cmg instantiateOnlyProcType;
	tyProc__Gji0NjiFFDU49aJiF3QZF8A fitDefaultNode;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA includedFiles;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg pureEnumFields;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg userPragmas;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* evalContext;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA unknownIdents;
	tySequence__4zAALtm0xUbRlYWQ2V8K7A generics;
	NI topStmts;
	NI lastGenericIdx;
	NI inParallelStmt;
	tyProc__UAj9bGJLVN9cwAsTcRZFyWmg instTypeBoundOp;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg signatures;
	NimStringV2 recursiveDep;
	NIM_BOOL suggestionsMade;
	NIM_BOOL isAmbiguous;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	NI inTypeContext;
	NI inConceptDecl;
	tySequence__9bffTLF0HkxjFCzZL8og4GA unusedImports;
	tyObject_HashSet__cx4zJRA9aTCfmpbY2J9bKwnQ exportIndirections;
	tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw importModuleMap;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastTLineInfo;
	tyObject_Table__g77QNejuRRKraNk8K2YkoA sideEffects;
	NI inUncheckedAssignSection;
	tyObject_Table__toCaB3NxiVHPRVLgcez0Xg importModuleLookup;
	tySequence__9ahcSjIErJohSBBFLwuF56Q skipTypes;
	NI inTypeofContext;
	tyProc__bvRec9bo79ajqrJt3Bkg9c33w semAsgnOpr;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww {
	NI depthLevel;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg symbols;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* parent;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA allowPrivateAccess;
	NI optionStackLen;
};
struct tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag {
	NI h;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
};
typedef NU8 tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ;
struct tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m;
	tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ mode;
union{
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA imported;
} _mode_2;
	struct {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA exceptSet;
} _mode_3;
};
};
struct tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA {
	NI lastModule;
	NU32 lastLit;
	NI32 lastFile;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
struct tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ {
	tyObject_PackedDecoder__mXpMPUjuhwIS5ssrGM9bHWA decoder;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw values;
	NI i;
	NI module;
};
struct tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ {
	NIM_BOOL fromRod;
	NI modIndex;
	tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti;
	tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ rodIt;
	NIM_BOOL importHidden;
};
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tySequence__3rs2HI7A9bn1iHmZchCo1lg {
  NI len; tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content* p;
};
struct tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw {
	NI h;
};
struct tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	NimStringV2 Field1;
};
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q;
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ x_p0, tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ y_p1, void* ClE_0);
void* ClE_0;
} tyProc__xz7yk0BhBUJaxr9crW1hYpQ;
typedef NU8 tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA;
typedef N_CLOSURE_PTR(NI, TM__3uzV357076dKeFHtnMZm2A_41) (tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ x_p0, tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ y_p1, void* ClE_0);
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ {
  NI len; tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ_Content* p;
};
struct tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw {
	tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ data;
};
struct tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q {
	NI dist;
	NI depth;
	NimStringV2 msg;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
};
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tySet_tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ;
typedef NU8 tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ;
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
typedef NU8 tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A;
struct tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w {
	tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag it;
	tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ mit;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m;
	tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A mode;
	NI symChoiceIndex;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* currentScope;
	NI importIdx;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA marked;
};
typedef NU tyArray__KznKlIbW0OmA9ckg0NfmHVQ[8];
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
typedef tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* tyArray__s9a2jZbmN9cnqFaNnzUrYEjg[8192];
struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA {
	tyArray__s9a2jZbmN9cnqFaNnzUrYEjg buckets;
	NI wordCounter;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idAnon;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idDelegator;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* emptyIdent;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__AE2UIxl7EbPzzBnmYsjIcw_Content { NI cap; tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__tsHRsYLyvTCPLlGRExqi7Q_Content { NI cap; tyObject_TOptionEntry__KeABxBvAlGa1KroFfkcqAg* data[SEQ_DECL_SIZE]; };
struct tySequence__lAikaRQvUF0uwNAz0U4FFA_Content { NI cap; tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* data[SEQ_DECL_SIZE]; };
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ {
  NI len; tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content* p;
};
struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA {
	NI counter;
	tySequence__7OXYQ6bHRkhJpRaiS7kiwQ data;
};
struct tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A {
	tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA topLayer;
	tyObject_LayeredIdTableObj__PbmRWgwPdgBZOtiSK65Q7A* nextLayer;
	NI previousLen;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* genericSym;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__4zAALtm0xUbRlYWQ2V8K7A_Content { NI cap; tyObject_TInstantiationPair__bS87nlCVAcAYxO9aJequmYw data[SEQ_DECL_SIZE]; };
struct tyTuple__09aD69az7aYn14Gt61AHvLIA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field1;
};
struct tySequence__9bffTLF0HkxjFCzZL8og4GA_Content { NI cap; tyTuple__09aD69az7aYn14Gt61AHvLIA data[SEQ_DECL_SIZE]; };
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
	NI Field0;
	NI Field1;
};
struct tyTuple__NAaJgGVgNmlGoqmiWxdOHQ {
	NI Field0;
	tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ Field1;
};
struct tySequence__Bis5AbpONWcIRrPyPJS8Yw_Content { NI cap; tyTuple__NAaJgGVgNmlGoqmiWxdOHQ data[SEQ_DECL_SIZE]; };
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
	NI Field0;
	NI Field1;
	NI Field2;
};
struct tySequence__E8pi9b5QNahsURYzXMjh3qw_Content { NI cap; tyTuple__47w2DboNEPf69aPgubZdd7Q data[SEQ_DECL_SIZE]; };
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ {
  NI len; tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content* p;
};
struct tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw {
	NI Field0;
	NI Field1;
	tySequence__KYLoGmc5aaHsSDjEH1FTxQ Field2;
};
struct tySequence__3B6hFqG0Do0FxDvnNucL7w_Content { NI cap; tyTuple__CH9a39cWKma9c9c9cYqCyX1wBsw data[SEQ_DECL_SIZE]; };
struct tyTuple__EbsafWGli8bW2GRJQ9apsjA {
	NI Field0;
	NI Field1;
	tySequence__qwqHTkRvwhrRyENtudHQ7g Field2;
};
struct tySequence__QqvaCqCpEE1QmQZbcZLi5A_Content { NI cap; tyTuple__EbsafWGli8bW2GRJQ9apsjA data[SEQ_DECL_SIZE]; };
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content { NI cap; tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tySequence__m2cY0Y5fsG9a9cgxBvApyTZQ_Content { NI cap; tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val;
};
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content { NI cap; tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg data[SEQ_DECL_SIZE]; };
struct tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__KYLoGmc5aaHsSDjEH1FTxQ_Content { NI cap; tyTuple__ZUrTP7BFWWFkSv3xO9crp9aQ data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___idents_u158)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* src_p1);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, noidentError__lookups_u22)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* origin_p2);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderTree__renderer_u59)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, considerQuotedIdent__lookups_u31)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* origin_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___idents_u164)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___lookups_u77)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww** dest_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initIdentIter__astalgo_u2768)(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag* ti_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tab_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__renderer_u83)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextIdentIter__astalgo_u2744)(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag* ti_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tab_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3391)(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u74)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* dest_p0);
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(void, initPackedSet__pureZcollectionsZintsets_u37)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initIdentIter__lookups_u135)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* ti_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* marked_p1, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_p2, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initModuleIter__modulegraphs_u3177)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* mi_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p2, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__astalgo_u2846)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsOrIncl__astyaml_u223)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextModuleIter__modulegraphs_u3222)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* mi_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextIdentIter__lookups_u350)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* ti_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* marked_p1, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3435)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u230)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*, eqdup___lookups_u80)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg, initStrTable__ast_u6321)(void);
static N_INLINE(NI, scopeDepth__semdata_u418)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, addUniqueSym__lookups_u61)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, strTableInclReportConflict__astalgo_u2677)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* t_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* n_p1, NIM_BOOL onConflictKeepOld_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(NI*, X5BX5D___lookups_u3355)(tyObject_Table__nBRoNCTSfpfbfAeK9bNW1qw* t_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___msgs_u714)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, wrongRedefinition__lookups_u3243)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 s_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA conflictsWith_p3, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA note_p4);
N_LIB_PRIVATE N_NIMCALL(void, ensureNoMissingOrUnusedSymbols__lookups_u19)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initTabIter__astalgo_u3137)(tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw* ti_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tab_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSymRepr__lookups_u2653)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NIM_BOOL getDeclarationPath_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getProcHeader__types_u219)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1, tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q prefer_p2, NIM_BOOL getDeclarationPath_p3);
N_LIB_PRIVATE N_NIMCALL(void, addDeclaredLoc__astmsgs_u16)(NimStringV2* result_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__lookups_u2716)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* x_p0, tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u707)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toMsgFilename__msgs_u688)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextIter__astalgo_u3121)(tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw* ti_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tab_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__3rs2HI7A9bn1iHmZchCo1lg, sorted__lookups_u2801)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ* a_p0, NI a_p0Len_0, tyProc__xz7yk0BhBUJaxr9crW1hYpQ cmp_p1, tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA order_p2);
static N_INLINE(void, nimIncRef)(void* p_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NI, colonanonymous___lookups_u2746)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ xX60gensym87__p0, tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ yX60gensym87__p1);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_u1563)(NimStringV2 x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lookups_u2929)(tySequence__3rs2HI7A9bn1iHmZchCo1lg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u2932)(tySequence__3rs2HI7A9bn1iHmZchCo1lg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawCloseScope__lookups_u96)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u566)(tySequence__tsHRsYLyvTCPLlGRExqi7Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, originatingModule__ast_u7142)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, skipGenericOwner__ast_u7111)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___lookups_u83)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww** dest_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceOverloadableSymAt__lookups_u3846)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(void, addOverloadableSymAt__lookups_u3826)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fn_p2);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, strTableGet__astalgo_u2726)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1);
N_LIB_PRIVATE N_NIMCALL(void, strTableAdd__astalgo_u2666)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* t_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* n_p1);
static N_INLINE(NIM_BOOL, isShadowScope__lookups_u119)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAux__lookups_u3796)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, exportSym__semdata_u4348)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1);
static N_INLINE(NIM_BOOL, isTopLevelInsideDeclaration__semdata_u4682)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, addHidden__icZic_u3081)(tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* c_p0, tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ* m_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2);
static N_INLINE(void, addInterfaceDecl__lookups_u3823)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAt__lookups_u3819)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
static N_INLINE(void, addDeclAt__lookups_u3781)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2);
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_u3253)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, selectFromScopesElseAll__lookups_u2523)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2);
N_LIB_PRIVATE N_NIMCALL(void, searchImportsAll__lookups_u2468)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2, tySequence__ZCZaCk14bTmSb6LMW9aWPVA* holding_p3);
N_LIB_PRIVATE N_NIMCALL(void, add__lookups_u5206)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* x_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** y_p1, NI y_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, allPureEnumFields__lookups_u709)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
static N_INLINE(NIM_BOOL, mustFixSpelling__lookups_u3896)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, fixSpelling__lookups_u3899)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw, initHeapQueue__lookups_u3910)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimIdentNormalize__pureZstrutils_u124)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NI, editDistance__stdZeditdistance_u2)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(void, push__lookups_u4107)(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw* heap_p0, tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* item_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___lookups_u3875)(tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* x_p0, tyTuple__kuMQ1fbjJlHtwKTmBGAe6g* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u3008)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1);
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u2997)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initRodIterAllSyms__icZic_u21632)(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ* it_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p1, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p2, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p3, NI32 module_p4, NIM_BOOL importHidden_p5);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextRodIter__icZic_u21968)(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ* it_p0, tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg* g_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3288)(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4851)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0, tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p1);
static N_INLINE(NI, len__lookups_u4190)(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw heap_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u4007)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u3922)(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___lookups_u4010)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* dest_p0, tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* src_p1);
static N_INLINE(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q*, X5BX5D___lookups_u4257)(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw* heap_p0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, pop__lookups_u4575)(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw* heap_p0, tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* Result);
static N_INLINE(NIM_BOOL, eqeq___idents_u366)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* a_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* b_p1);
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__lookups_u5145)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 name_p2, NimStringV2 extra_p3);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, contains__pureZstrutils_u1833)(NimStringV2 s_p0, NimStringV2 sub_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, errorSym__lookups_u2607)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, getCurrOwner__semdata_u425)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, errorType__semdata_u4564)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, ambiguousIdentifierMsg__lookups_u5072)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA candidates_p0, NimStringV2 prefix_p1, NI indent_p2);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeToString__types_u54)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q prefer_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, someSymFromImportTable__lookups_u2381)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, NIM_BOOL* ambiguous_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, searchInScopes__lookups_u2425)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, NIM_BOOL* ambiguous_p2);
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__lookups_u5100)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tySequence__ZCZaCk14bTmSb6LMW9aWPVA candidates_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, lookUpCandidates__lookups_u5193)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2, NIM_BOOL includePureEnum_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, errorUndeclaredIdentifierHint__lookups_u5151)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, errorUseQualifier__lookups_u5040)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, NIM_BOOL* amb_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, qualifiedLookUp__lookups_u5229)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ flags_p2);
static N_INLINE(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getPIdent__ast_u2825)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__qwqHTkRvwhrRyENtudHQ7g, getOrDefault__lookups_u5391)(tyObject_Table__toCaB3NxiVHPRVLgcez0Xg t_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, someSymAmb__modulegraphs_u3342)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p2, NIM_BOOL* amb_p3);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u474)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, errorSym__lookups_u2620)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initOverloadIter__lookups_u5784)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___pureZcollectionsZintsets_u236)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* dest_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lookups_u71)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, incl__pureZcollectionsZintsets_u366)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* s_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextOverloadIterImports__lookups_u5937)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, firstIdentExcluding__astalgo_u3113)(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag* ti_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tab_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p2, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* excluding_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, symChoiceExtension__lookups_u5965)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextIdentExcluding__astalgo_u2773)(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag* ti_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tab_p1, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* excluding_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u100)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u66)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2873)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___icZic_u3941)(tySequence__qBes3XzcQQ9cyia9bRwnmbJw dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u274)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u173)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u6249)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextOverloadIter__lookups_u5989)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, newSeq__lookups_u5124)(NI len_p0);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, searchScopes__lookups_u2487)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, ambiguousIdentifierMsg__lookups_u5104)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* choices_p0, NI indent_p1);
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__3uzV357076dKeFHtnMZm2A_2 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_3 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__3uzV357076dKeFHtnMZm2A_4 = { 15 | NIM_STRLIT_FLAG, "in expression \'" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_5 = {15, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_4};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__3uzV357076dKeFHtnMZm2A_6 = { 3 | NIM_STRLIT_FLAG, "\': " };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_7 = {3, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_6};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__3uzV357076dKeFHtnMZm2A_8 = { 32 | NIM_STRLIT_FLAG, "identifier expected, but found \'" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_9 = {32, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_8};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__3uzV357076dKeFHtnMZm2A_10 = { 1 | NIM_STRLIT_FLAG, "\'" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_11 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_10};
static const struct {
  NI cap; NIM_CHAR data[62+1];
} TM__3uzV357076dKeFHtnMZm2A_13 = { 62 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/lookups.nim" };
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__3uzV357076dKeFHtnMZm2A_14 = { 7 | NIM_STRLIT_FLAG, "<Error>" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_15 = {7, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_14};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_16 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_17 = {7, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_14};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_18 = {7, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_14};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_19 = {7, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_14};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_20 = {7, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_14};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__3uzV357076dKeFHtnMZm2A_21 = { 30 | NIM_STRLIT_FLAG, "nimPreviewDuplicateModuleError" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_22 = {30, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_21};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__3uzV357076dKeFHtnMZm2A_23 = { 50 | NIM_STRLIT_FLAG, "duplicate import of \'$1\'; previous import here: $2" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_24 = {50, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_23};
static const struct {
  NI cap; NIM_CHAR data[51+1];
} TM__3uzV357076dKeFHtnMZm2A_26 = { 51 | NIM_STRLIT_FLAG, "redefinition of \'$1\'; previous declaration here: $2" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_27 = {51, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_26};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__3uzV357076dKeFHtnMZm2A_29 = { 31 | NIM_STRLIT_FLAG, "implementation of \'$1\' expected" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_30 = {31, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_29};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__3uzV357076dKeFHtnMZm2A_31 = { 4 | NIM_STRLIT_FLAG, "\'$1\'" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_32 = {4, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_31};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_34 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__3uzV357076dKeFHtnMZm2A_35 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_36 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_35};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__3uzV357076dKeFHtnMZm2A_37 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_38 = {2, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_37};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__3uzV357076dKeFHtnMZm2A_39 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_40 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_39};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__3uzV357076dKeFHtnMZm2A_43 = { 20 | NIM_STRLIT_FLAG, "addOverloadableSymAt" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_44 = {20, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_43};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__3uzV357076dKeFHtnMZm2A_46 = { 19 | NIM_STRLIT_FLAG, "addInterfaceDeclAux" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_47 = {19, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_46};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_49 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_50 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__3uzV357076dKeFHtnMZm2A_51 = { 16 | NIM_STRLIT_FLAG, "\012 ($1, $2): \'$3\'" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_52 = {16, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_51};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_53 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_54 = {16, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_51};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_55 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_56 = {16, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_51};
static const struct {
  NI cap; NIM_CHAR data[67+1];
} TM__3uzV357076dKeFHtnMZm2A_57 = { 67 | NIM_STRLIT_FLAG, "\012candidates (edit distance, scope distance); see \'--spellSuggest\': " };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_58 = {67, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_57};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__3uzV357076dKeFHtnMZm2A_59 = { 1 | NIM_STRLIT_FLAG, "_" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_60 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_59};
static const struct {
  NI cap; NIM_CHAR data[72+1];
} TM__3uzV357076dKeFHtnMZm2A_61 = { 72 | NIM_STRLIT_FLAG, "the special identifier \'_\' is ignored in declarations and cannot be used" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_62 = {72, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_61};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__3uzV357076dKeFHtnMZm2A_63 = { 24 | NIM_STRLIT_FLAG, "undeclared identifier: \'" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_64 = {24, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_63};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_65 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_10};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__3uzV357076dKeFHtnMZm2A_66 = { 7 | NIM_STRLIT_FLAG, "`gensym" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_67 = {7, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_66};
static const struct {
  NI cap; NIM_CHAR data[90+1];
} TM__3uzV357076dKeFHtnMZm2A_68 = { 90 | NIM_STRLIT_FLAG, "; if declared in a template, this identifier may be inconsistently marked inject or gensym" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_69 = {90, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_68};
static const struct {
  NI cap; NIM_CHAR data[56+1];
} TM__3uzV357076dKeFHtnMZm2A_70 = { 56 | NIM_STRLIT_FLAG, "\012This might be caused by a recursive module dependency:\012" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_71 = {56, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_70};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_72 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_74 = {0, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_2};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__3uzV357076dKeFHtnMZm2A_75 = { 23 | NIM_STRLIT_FLAG, "ambiguous identifier: \'" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_76 = {23, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_75};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_77 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_10};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__3uzV357076dKeFHtnMZm2A_78 = { 22 | NIM_STRLIT_FLAG, " -- $1 the following:\012" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_79 = {22, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_78};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__3uzV357076dKeFHtnMZm2A_80 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_81 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_80};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__3uzV357076dKeFHtnMZm2A_82 = { 2 | NIM_STRLIT_FLAG, "  " };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_83 = {2, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_82};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__3uzV357076dKeFHtnMZm2A_84 = { 1 | NIM_STRLIT_FLAG, "." };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_85 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_84};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__3uzV357076dKeFHtnMZm2A_86 = { 2 | NIM_STRLIT_FLAG, ": " };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_87 = {2, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_86};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__3uzV357076dKeFHtnMZm2A_88 = { 10 | NIM_STRLIT_FLAG, "use one of" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_89 = {10, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_88};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_91 = {23, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_75};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_92 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_10};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__3uzV357076dKeFHtnMZm2A_93 = { 30 | NIM_STRLIT_FLAG, " -- use one of the following:\012" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_94 = {30, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_93};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_95 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_80};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_96 = {2, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_82};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_97 = {1, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_84};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_98 = {2, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_86};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__3uzV357076dKeFHtnMZm2A_100 = { 30 | NIM_STRLIT_FLAG, "identifier expected, but got: " };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_101 = {30, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_100};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__3uzV357076dKeFHtnMZm2A_103 = { 4 | NIM_STRLIT_FLAG, "err:" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_104 = {4, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_103};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__3uzV357076dKeFHtnMZm2A_105 = { 6 | NIM_STRLIT_FLAG, "lookUp" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_106 = {6, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_105};
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_108 = {10, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_88};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__3uzV357076dKeFHtnMZm2A_109 = { 38 | NIM_STRLIT_FLAG, "you need a helper proc to disambiguate" };
static const NimStringV2 TM__3uzV357076dKeFHtnMZm2A_110 = {38, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_109};
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_12 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)29),
((NI)12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_25 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)397),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_28 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)381),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_33 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)363),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_42 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)375),
((NI)11)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_45 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)443),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_48 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)422),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_73 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)611),
((NI)12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_90 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)584),
((NI)12)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_99 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)559),
((NI)14)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_102 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)719),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_107 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)633),
((NI)17)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__3uzV357076dKeFHtnMZm2A_111 = {{62, (NimStrPayload*)&TM__3uzV357076dKeFHtnMZm2A_13},
((NI)594),
((NI)12)}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___lookups_u775)(tyTuple__WIyQ4Cfp4shlBOyEpagHMw* dest_p0, tyTuple__WIyQ4Cfp4shlBOyEpagHMw src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)8));
	}
LA4_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	(*dest_p0).Field1 = src_p1.Field1;
	(*dest_p0).Field2 = src_p1.Field2;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u766)(tyTuple__WIyQ4Cfp4shlBOyEpagHMw dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, noidentError__lookups_u22)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* origin_p2) {
	NimStringV2 m_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T11_;
	tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	m_1.len = 0; m_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	m_1 = TM__3uzV357076dKeFHtnMZm2A_3;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 T7_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T8_;
		if (!!((origin_p2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA4_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T7_.len = 0; T7_.p = NIM_NIL;
		T8_ = 0;
		colontmpD__3 = renderTree__renderer_u59(origin_p2, T8_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_ = rawNewString(colontmpD__3.len + 18);
appendString((&T7_), TM__3uzV357076dKeFHtnMZm2A_5);
appendString((&T7_), colontmpD__3);
appendString((&T7_), TM__3uzV357076dKeFHtnMZm2A_7);
		colontmpD__4 = T7_;
		prepareAdd((&m_1), colontmpD__4.len + 0);
appendString((&m_1), colontmpD__4);
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	T11_.len = 0; T11_.p = NIM_NIL;
	T12_ = 0;
	colontmpD_ = renderTree__renderer_u59(n_p1, T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_ = rawNewString(colontmpD_.len + 33);
appendString((&T11_), TM__3uzV357076dKeFHtnMZm2A_9);
appendString((&T11_), colontmpD_);
appendString((&T11_), TM__3uzV357076dKeFHtnMZm2A_11);
	colontmpD__2 = T11_;
	prepareAdd((&m_1), colontmpD__2.len + 0);
appendString((&m_1), colontmpD__2);
	liMessage__msgs_u1227(conf_p0, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), m_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_12), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(m_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, considerQuotedIdent__lookups_u31)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* origin_p2) {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* result;
NIM_BOOL oldNimErrFin12_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		eqcopy___idents_u158(&result, (*n_p1)._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___idents_u158(&result, (*(*n_p1)._kind_4.sym).name);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53):
	{
		NI T4_;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		switch (T4_) {
		case ((NI)0):
		{
			noidentError__lookups_u22((*(*c_p0).graph).config, n_p1, origin_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = getIdent__idents_u206((*c_p0).cache, TM__3uzV357076dKeFHtnMZm2A_15);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((NI)1):
		{
			result = considerQuotedIdent__lookups_u31(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], origin_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		default:
		{
			NimStringV2 id_1;
			id_1.len = 0; id_1.p = NIM_NIL;
			id_1 = TM__3uzV357076dKeFHtnMZm2A_16;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = len__ast_u3190(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				i_2 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
						if (!(i_2 < colontmp_)) goto LA11;
						x_1 = NIM_NIL;
						i_1 = i_2;
						eqcopy___ast_u3255(&x_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						switch ((*x_1).kind) {
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
						{
							prepareAdd((&id_1), (*(*x_1)._kind_5.ident).s.len + 0);
appendString((&id_1), (*(*x_1)._kind_5.ident).s);
						}
						break;
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
						{
							prepareAdd((&id_1), (*(*(*x_1)._kind_4.sym).name).s.len + 0);
appendString((&id_1), (*(*(*x_1)._kind_4.sym).name).s);
						}
						break;
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
						{
							{
								if (!((*(*x_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA18_;
								prepareAdd((&id_1), (*(*(*(*x_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s.len + 0);
appendString((&id_1), (*(*(*(*x_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).s);
							}
							goto LA16_;
LA18_: ;
							{
								tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T21_;
								noidentError__lookups_u22((*(*c_p0).graph).config, n_p1, origin_p2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
								T21_ = NIM_NIL;
								T21_ = getIdent__idents_u206((*c_p0).cache, TM__3uzV357076dKeFHtnMZm2A_17);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___idents_u155(T21_); goto LA12_;}
								eqsink___idents_u164(&result, T21_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
							}
LA16_: ;
						}
						break;
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
						case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
						{
							NimStringV2 colontmpD_;
							tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T24_;
							colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
							T24_ = 0;
							colontmpD_ = renderTree__renderer_u59(x_1, T24_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA23_;
							prepareAdd((&id_1), colontmpD_.len + 0);
appendString((&id_1), colontmpD_);
							{
								LA23_:;
							}
							{
								eqdestroy___system_u2691(colontmpD_);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						}
						break;
						default:
						{
							tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T28_;
							noidentError__lookups_u22((*(*c_p0).graph).config, n_p1, origin_p2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
							T28_ = NIM_NIL;
							T28_ = getIdent__idents_u206((*c_p0).cache, TM__3uzV357076dKeFHtnMZm2A_18);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___idents_u155(T28_); goto LA12_;}
							eqsink___idents_u164(&result, T28_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
						}
						break;
						}
						i_2 += ((NI)1);
						{
							LA12_:;
						}
						{
							oldNimErrFin12_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(x_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
							*nimErr_ = oldNimErrFin12_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
					} LA11: ;
				}
			}
			result = getIdent__idents_u206((*c_p0).cache, id_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			{
				LA8_:;
			}
			{
				eqdestroy___system_u2691(id_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
	{
		{
			if (!((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA36_;
			eqcopy___idents_u158(&result, (*(*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA34_;
LA36_: ;
		{
			noidentError__lookups_u22((*(*c_p0).graph).config, n_p1, origin_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = getIdent__idents_u206((*c_p0).cache, TM__3uzV357076dKeFHtnMZm2A_19);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA34_: ;
	}
	break;
	default:
	{
		noidentError__lookups_u22((*(*c_p0).graph).config, n_p1, origin_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = getIdent__idents_u206((*c_p0).cache, TM__3uzV357076dKeFHtnMZm2A_20);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, searchScopes__lookups_u2487)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	{
		tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_1;
		tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* current_1;
		scope_1 = NIM_NIL;
		current_1 = NIM_NIL;
		current_1 = (*c_p0).currentScope;
		{
			while (1) {
				tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti_1;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_1;
				if (!!((current_1 == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA3;
				nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
				candidate_1 = NIM_NIL;
				eqcopy___lookups_u77(&scope_1, current_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
				candidate_1 = initIdentIter__astalgo_u2768((&ti_1), (*scope_1).symbols, s_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					while (1) {
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T10_;
						if (!!((candidate_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA5;
						{
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
							if (!((filter_p2 &((NU32)1<<((NU)(((*candidate_1).kind))&31U)))!=0)) goto LA8_;
							blitTmp_1 = candidate_1;
							eqwasMoved___ast_u4571(&candidate_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							add__renderer_u83((&result), blitTmp_1);
						}
LA8_: ;
						T10_ = NIM_NIL;
						T10_ = nextIdentIter__astalgo_u2744((&ti_1), (*scope_1).symbols);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T10_); goto BeforeRet_;}
						eqsink___ast_u4583(&candidate_1, T10_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					} LA5: ;
				}
				current_1 = (*current_1).parent;
				eqdestroy___ast_u4574(candidate_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___modulegraphs_u3391(ti_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
		eqdestroy___lookups_u74(scope_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, initIntSet__pureZcollectionsZintsets_u598)(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* Result) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initPackedSet__pureZcollectionsZintsets_u37(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initIdentIter__lookups_u135)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* ti_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* marked_p1, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_p2, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = initModuleIter__modulegraphs_u3177(ti_p0, g_p4, (*im_p2).m, name_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			NIM_BOOL colontmpD_;
			NIM_BOOL colontmpD__2;
			NIM_BOOL colontmpD__3;
			NIM_BOOL b_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T14_;
			if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA2;
			colontmpD_ = (NIM_BOOL)0;
			colontmpD__2 = (NIM_BOOL)0;
			colontmpD__3 = (NIM_BOOL)0;
			switch ((*im_p2).mode) {
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
			{
				colontmpD_ = NIM_TRUE;
				b_1 = colontmpD_;
			}
			break;
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
			{
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym25__1;
				xX60gensym25__1 = (*result).itemId;
				colontmpD__2 = contains__astalgo_u2846((&(*im_p2)._mode_2.imported), (NI)((NI)((NU64)(((NI) (xX60gensym25__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym25__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				b_1 = colontmpD__2;
			}
			break;
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = contains__astalgo_u2846((&(*im_p2)._mode_3.exceptSet), (*name_p3).id);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				colontmpD__3 = !(T6_);
				b_1 = colontmpD__3;
			}
			break;
			default: __builtin_unreachable();
			}
			{
				NIM_BOOL T9_;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym28__1;
				NIM_BOOL T11_;
				T9_ = (NIM_BOOL)0;
				T9_ = b_1;
				if (!(T9_)) goto LA10_;
				xX60gensym28__1 = (*result).itemId;
				T11_ = (NIM_BOOL)0;
				T11_ = containsOrIncl__astyaml_u223(marked_p1, (NI)((NI)((NU64)(((NI) (xX60gensym28__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym28__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T9_ = !(T11_);
LA10_: ;
				if (!T9_) goto LA12_;
				goto BeforeRet_;
			}
LA12_: ;
			T14_ = NIM_NIL;
			T14_ = nextModuleIter__modulegraphs_u3222(ti_p0, g_p4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T14_); goto BeforeRet_;}
			eqsink___ast_u4583(&result, T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextIdentIter__lookups_u350)(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* ti_p0, tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA* marked_p1, tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		while (1) {
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T3_;
			T3_ = NIM_NIL;
			T3_ = nextModuleIter__modulegraphs_u3222(ti_p0, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T3_); goto BeforeRet_;}
			eqsink___ast_u4583(&result, T3_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA6_;
				result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
				goto BeforeRet_;
			}
LA6_: ;
			switch ((*im_p2).mode) {
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)0):
			{
				{
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym30__1;
					NIM_BOOL T11_;
					xX60gensym30__1 = (*result).itemId;
					T11_ = (NIM_BOOL)0;
					T11_ = containsOrIncl__astyaml_u223(marked_p1, (NI)((NI)((NU64)(((NI) (xX60gensym30__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym30__1.item))));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!!(T11_)) goto LA12_;
					goto BeforeRet_;
				}
LA12_: ;
			}
			break;
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)1):
			{
				{
					NIM_BOOL T17_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym33__1;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym35__1;
					NIM_BOOL T19_;
					T17_ = (NIM_BOOL)0;
					xX60gensym33__1 = (*result).itemId;
					T17_ = contains__astalgo_u2846((&(*im_p2)._mode_2.imported), (NI)((NI)((NU64)(((NI) (xX60gensym33__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym33__1.item))));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					if (!(T17_)) goto LA18_;
					xX60gensym35__1 = (*result).itemId;
					T19_ = (NIM_BOOL)0;
					T19_ = containsOrIncl__astyaml_u223(marked_p1, (NI)((NI)((NU64)(((NI) (xX60gensym35__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym35__1.item))));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T17_ = !(T19_);
LA18_: ;
					if (!T17_) goto LA20_;
					goto BeforeRet_;
				}
LA20_: ;
			}
			break;
			case ((tyEnum_ImportMode__rHuf2PYQqUqEBlVu227wVQ)2):
			{
				{
					NIM_BOOL T25_;
					NIM_BOOL T26_;
					tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym38__1;
					NIM_BOOL T28_;
					T25_ = (NIM_BOOL)0;
					T26_ = (NIM_BOOL)0;
					T26_ = contains__astalgo_u2846((&(*im_p2)._mode_3.exceptSet), (*(*result).name).id);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T25_ = !(T26_);
					if (!(T25_)) goto LA27_;
					xX60gensym38__1 = (*result).itemId;
					T28_ = (NIM_BOOL)0;
					T28_ = containsOrIncl__astyaml_u223(marked_p1, (NI)((NI)((NU64)(((NI) (xX60gensym38__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym38__1.item))));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					T25_ = !(T28_);
LA27_: ;
					if (!T25_) goto LA29_;
					goto BeforeRet_;
				}
LA29_: ;
			}
			break;
			default: __builtin_unreachable();
			}
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, searchImportsAll__lookups_u2468)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2, tySequence__ZCZaCk14bTmSb6LMW9aWPVA* holding_p3) {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA marked_1;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&marked_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&marked_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_1;
		NI i_1;
		NI L_1;
		NI T3_;
		im_1 = (tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw*)0;
		i_1 = ((NI)0);
		T3_ = (*c_p0).imports.len;
		L_1 = T3_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA5;
				im_1 = (&(*c_p0).imports.p->data[i_1]);
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
					tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ ti_1;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_1;
					s_2 = NIM_NIL;
					nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
					candidate_1 = NIM_NIL;
					s_2 = 0;
					nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
					candidate_1 = initIdentIter__lookups_u135((&ti_1), (&marked_1), (&(*im_1)), s_p1, (*c_p0).graph);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					{
						while (1) {
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T14_;
							if (!!((candidate_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA9;
							eqsink___ast_u4583(&s_2, candidate_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
							eqwasMoved___ast_u4571(&candidate_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
							{
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
								if (!((filter_p2 &((NU32)1<<((NU)(((*s_2).kind))&31U)))!=0)) goto LA12_;
								blitTmp_1 = s_2;
								eqwasMoved___ast_u4571(&s_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
								add__renderer_u83((&(*holding_p3)), blitTmp_1);
							}
LA12_: ;
							T14_ = NIM_NIL;
							T14_ = nextIdentIter__lookups_u350((&ti_1), (&marked_1), (&(*im_1)), (*c_p0).graph);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T14_); goto LA7_;}
							eqsink___ast_u4583(&candidate_1, T14_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						} LA9: ;
					}
					{
						LA7_:;
					}
					{
						oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(candidate_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___modulegraphs_u3435((&ti_1));
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u4574(s_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin7_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				i_1 += ((NI)1);
			} LA5: ;
		}
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, scopeDepth__semdata_u418)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	NI result;
	NI T1_;
	T1_ = (NI)0;
	{
		if (!!(((*c_p0).currentScope == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA4_;
		result = (*(*c_p0).currentScope).depthLevel;
	}
	goto LA2_;
LA4_: ;
	{
		result = ((NI)0);
	}
LA2_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*, openScope__lookups_u65)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* result;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* colontmpD_;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* T1_;
	NI T2_;
	NI T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) nimNewObj(sizeof(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww), NIM_ALIGNOF(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww));
	colontmpD_ = eqdup___lookups_u80((*c_p0).currentScope);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).parent = colontmpD_;
	(*T1_).symbols = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NI)0;
	T2_ = scopeDepth__semdata_u418(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).depthLevel = (NI)(T2_ + ((NI)1));
	T3_ = (*c_p0).optionStack.len;
	(*T1_).optionStackLen = T3_;
	result = T1_;
	eqcopy___lookups_u77(&(*c_p0).currentScope, result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, addUniqueSym__lookups_u61)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = strTableInclReportConflict__astalgo_u2677((&(*scope_p0).symbols), s_p1, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, wrongRedefinition__lookups_u3243)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 s_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA conflictsWith_p3, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA note_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T6_;
		if (!!(((*(*(*c_p0).graph).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)27)))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T6_[0] = s_p2;
		colontmpD_ = dollar___msgs_u714((*(*c_p0).graph).config, conflictsWith_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T6_[1] = colontmpD_;
		colontmpD__2 = nsuFormatOpenArray(TM__3uzV357076dKeFHtnMZm2A_27, T6_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, info_p1, note_p4, colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_28), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addDeclAt__lookups_u3253)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* conflict_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	conflict_1 = NIM_NIL;
	{
		if (!((*(*sym_p2).name).id == ((NI)74))) goto LA4_;
		eqdestroy___ast_u4574(conflict_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	conflict_1 = addUniqueSym__lookups_u61(scope_p1, sym_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((conflict_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA8_;
		{
			NIM_BOOL T12_;
			NIM_BOOL T13_;
			NIM_BOOL T16_;
			T12_ = (NIM_BOOL)0;
			T13_ = (NIM_BOOL)0;
			T13_ = ((*sym_p2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
			if (!(T13_)) goto LA14_;
			T13_ = ((*conflict_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
LA14_: ;
			T12_ = T13_;
			if (!(T12_)) goto LA15_;
			T16_ = (NIM_BOOL)0;
			T16_ = isDefined__options_u959((*(*c_p0).graph).config, TM__3uzV357076dKeFHtnMZm2A_22);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T12_ = !(T16_);
LA15_: ;
			if (!T12_) goto LA17_;
			{
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym104__1;
				NI* T21_;
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym108__1;
				NI* T22_;
				NimStringV2 colontmpD_;
				NimStringV2 colontmpD__2;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T26_;
				xX60gensym104__1 = (*sym_p2).itemId;
				T21_ = (NI*)0;
				T21_ = X5BX5D___lookups_u3355((&(*c_p0).importModuleMap), (NI)((NI)((NU64)(((NI) (xX60gensym104__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym104__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				xX60gensym108__1 = (*conflict_1).itemId;
				T22_ = (NI*)0;
				T22_ = X5BX5D___lookups_u3355((&(*c_p0).importModuleMap), (NI)((NI)((NU64)(((NI) (xX60gensym108__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym108__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!((*T21_) == (*T22_))) goto LA23_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				T26_[0] = (*(*sym_p2).name).s;
				colontmpD_ = dollar___msgs_u714((*(*c_p0).graph).config, (*conflict_1).info);
				if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
				T26_[1] = colontmpD_;
				colontmpD__2 = nsuFormatOpenArray(TM__3uzV357076dKeFHtnMZm2A_24, T26_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, info_p3, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)93), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_25), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
				{
					LA25_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA23_: ;
		}
		goto LA10_;
LA17_: ;
		{
			wrongRedefinition__lookups_u3243(c_p0, info_p3, (*(*sym_p2).name).s, (*conflict_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA10_: ;
	}
LA8_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(conflict_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSymRepr__lookups_u2653)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, NIM_BOOL getDeclarationPath_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	switch ((*s_p1).kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) ... ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7):
	{
		result = getProcHeader__types_u219(conf_p0, s_p1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0), getDeclarationPath_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		result = nsuFormatSingleElem(TM__3uzV357076dKeFHtnMZm2A_32, (*(*s_p1).name).s);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!getDeclarationPath_p2) goto LA5_;
			addDeclaredLoc__astmsgs_u16((&result), conf_p0, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA5_: ;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u707)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = TM__3uzV357076dKeFHtnMZm2A_34;
	colontmpD_ = toMsgFilename__msgs_u688(conf_p0, info_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
	{
		if (!(((NI)0) < ((NI) (info_p1.line)))) goto LA4_;
		prepareAdd((&result), 1);
appendString((&result), TM__3uzV357076dKeFHtnMZm2A_36);
		addInt__stdZprivateZdigitsutils_u204((&result), ((NI) (info_p1.line)));
		{
			if (!(((NI)0) < (NI)(((NI) (info_p1.col)) + ((NI)1)))) goto LA8_;
			prepareAdd((&result), 2);
appendString((&result), TM__3uzV357076dKeFHtnMZm2A_38);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)(((NI) (info_p1.col)) + ((NI)1)));
		}
LA8_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__3uzV357076dKeFHtnMZm2A_40);
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u2775)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)8));
	}
LA4_: ;
	eqdestroy___system_u2691(dest_p0.Field1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lookups_u2772)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___lookups_u2778)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ* dest_p0, tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1.Field0) goto LA3_;
		nimIncRef(src_p1.Field0);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3469((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)8));
	}
LA8_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	eqcopy___system_u2694((&(*dest_p0).Field1), src_p1.Field1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___lookups_u2784)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ* dest_p0, tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).Field0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field0, ((NI)8));
	}
LA4_: ;
	(*dest_p0).Field0 = src_p1.Field0;
	if ((*dest_p0).Field1.p != src_p1.Field1.p) {	eqdestroy___system_u2691((*dest_p0).Field1);
	}
(*dest_p0).Field1.len = src_p1.Field1.len; (*dest_p0).Field1.p = src_p1.Field1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, colonanonymous___lookups_u2746)(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ xX60gensym87__p0, tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ yX60gensym87__p1) {
	NI result;
	tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ it_1;
	NimStringV2 aX60gensym87__1;
	NimStringV2 bX60gensym87__1;
	nimZeroMem((void*)(&it_1), sizeof(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ));
	aX60gensym87__1.len = 0; aX60gensym87__1.p = NIM_NIL;
	bX60gensym87__1.len = 0; bX60gensym87__1.p = NIM_NIL;
	it_1.Field0 = xX60gensym87__p0.Field0;
	it_1.Field1 = xX60gensym87__p0.Field1;
	eqcopy___system_u2694((&aX60gensym87__1), it_1.Field1);
	it_1.Field0 = yX60gensym87__p1.Field0;
	it_1.Field1 = yX60gensym87__p1.Field1;
	eqcopy___system_u2694((&bX60gensym87__1), it_1.Field1);
	result = cmp__system_u1563(aX60gensym87__1, bX60gensym87__1);
	eqdestroy___system_u2691(bX60gensym87__1);
	eqdestroy___system_u2691(aX60gensym87__1);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, ensureNoMissingOrUnusedSymbols__lookups_u19)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
	tySequence__3rs2HI7A9bn1iHmZchCo1lg unusedSyms_1;
	tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw it_1;
	NI missingImpls_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	s_1 = NIM_NIL;
	unusedSyms_1.len = 0; unusedSyms_1.p = NIM_NIL;
	nimZeroMem((void*)(&it_1), sizeof(tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw));
	s_1 = initTabIter__astalgo_u3137((&it_1), (*scope_p1).symbols);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	missingImpls_1 = ((NI)0);
	unusedSyms_1.len = 0; unusedSyms_1.p = (tySequence__3rs2HI7A9bn1iHmZchCo1lg_Content*) newSeqPayload(0, sizeof(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ), NIM_ALIGNOF(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ));
	{
		while (1) {
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T35_;
			if (!!((s_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA3;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = (((*s_1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4)))&63U)))!=0);
				if (!(T6_)) goto LA7_;
				T6_ = !(((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6)));
LA7_: ;
				if (!T6_) goto LA8_;
				{
					NimStringV2 colontmpD_;
					NimStringV2 colontmpD__2;
					if (!(missingImpls_1 == ((NI)0))) goto LA12_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					colontmpD_ = getSymRepr__lookups_u2653((*(*c_p0).graph).config, s_1, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					colontmpD__2 = nsuFormatSingleElem(TM__3uzV357076dKeFHtnMZm2A_30, colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					liMessage__msgs_u1227((*(*c_p0).graph).config, (*s_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_33), NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
					{
						LA14_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
						eqdestroy___system_u2691(colontmpD_);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA12_: ;
				missingImpls_1 += ((NI)1);
			}
			goto LA4_;
LA8_: ;
			{
				tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T18_;
				T18_ = 0;
				if (!((3 & (*s_1).flags) == T18_)) goto LA19_;
				{
					if (!!(((*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)4) || (*s_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20)))) goto LA23_;
					{
						NIM_BOOL T27_;
						NIM_BOOL T28_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
						tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ T33_;
						NimStringV2 T34_;
						T27_ = (NIM_BOOL)0;
						T28_ = (NIM_BOOL)0;
						T28_ = !(((*s_1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
						if (!(T28_)) goto LA29_;
						T28_ = !((((*(*s_1).typ).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)26)))&63U)))!=0));
LA29_: ;
						T27_ = T28_;
						if (!(T27_)) goto LA30_;
						T27_ = !(((*(*s_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12)));
LA30_: ;
						if (!T27_) goto LA31_;
						nimZeroMem((void*)(&T33_), sizeof(tyTuple__7lGUWvuwbQfT9aC9a1FBbHLQ));
						colontmpD__3 = eqdup___ast_u4580(s_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						T33_.Field0 = colontmpD__3;
						T34_.len = 0; T34_.p = NIM_NIL;
						T34_ = toFileLineCol__msgs_u707((*(*c_p0).graph).config, (*s_1).info);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T34_); goto LA1_;}
						T33_.Field1 = T34_;
						add__lookups_u2716((&unusedSyms_1), T33_);
					}
LA31_: ;
				}
LA23_: ;
			}
			goto LA4_;
LA19_: ;
LA4_: ;
			T35_ = NIM_NIL;
			T35_ = nextIter__astalgo_u3121((&it_1), (*scope_p1).symbols);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T35_); goto LA1_;}
			eqsink___ast_u4583(&s_1, T35_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA3: ;
	}
	{
		tySequence__3rs2HI7A9bn1iHmZchCo1lg colontmp_;
		tySequence__3rs2HI7A9bn1iHmZchCo1lg resultX60gensym87__1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** s_2;
		NimStringV2* __1;
		tyProc__xz7yk0BhBUJaxr9crW1hYpQ T38_;
		NI i_1;
		NI L_1;
		NI T39_;
		colontmp_.len = 0; colontmp_.p = NIM_NIL;
		resultX60gensym87__1.len = 0; resultX60gensym87__1.p = NIM_NIL;
		s_2 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
		__1 = (NimStringV2*)0;
		nimZeroMem((void*)(&T38_), sizeof(tyProc__xz7yk0BhBUJaxr9crW1hYpQ));
		T38_.ClP_0 = ((TM__3uzV357076dKeFHtnMZm2A_41) (colonanonymous___lookups_u2746)); T38_.ClE_0 = NIM_NIL;
		resultX60gensym87__1 = sorted__lookups_u2801(((unusedSyms_1).p) ? (unusedSyms_1.p->data) : NIM_NIL, unusedSyms_1.len, T38_, ((tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
		colontmp_ = resultX60gensym87__1;
		eqwasMoved___lookups_u2929((&resultX60gensym87__1));
		i_1 = ((NI)0);
		T39_ = colontmp_.len;
		L_1 = T39_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA41;
				s_2 = &colontmp_.p->data[i_1].Field0;
				__1 = (&colontmp_.p->data[i_1].Field1);
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*(*s_2)).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)92), (*(*(*s_2)).name).s, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_42), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
				i_1 += ((NI)1);
			} LA41: ;
		}
		{
			LA37_:;
		}
		{
			eqdestroy___lookups_u2932(resultX60gensym87__1);
			eqdestroy___lookups_u2932(colontmp_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___lookups_u2932(unusedSyms_1);
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rawCloseScope__lookups_u96)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(((NI)1) <= (*(*c_p0).currentScope).optionStackLen)) goto LA3_;
		setLen__semdata_u566((&(*c_p0).optionStack), ((*(*c_p0).currentScope).optionStackLen));
	}
LA3_: ;
	eqcopy___lookups_u77(&(*c_p0).currentScope, (*(*c_p0).currentScope).parent);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, closeScope__lookups_u102)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	ensureNoMissingOrUnusedSymbols__lookups_u19(c_p0, (*c_p0).currentScope);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	rawCloseScope__lookups_u96(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, cmpScopes__lookups_u2555)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* ctx_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1) {
	NI result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	colontmpD_ = NIM_NIL;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_1;
		colontmpD_ = originatingModule__ast_u7142(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(colontmpD_ == (*ctx_p0).module)) goto LA4_;
		owner_1 = NIM_NIL;
		result = ((NI)2);
		eqcopy___ast_u4577(&owner_1, s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T9_;
				T9_ = NIM_NIL;
				T9_ = skipGenericOwner__ast_u7111(owner_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T9_); goto LA6_;}
				eqsink___ast_u4583(&owner_1, T9_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				{
					if (!((*owner_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6))) goto LA12_;
					goto LA7;
				}
LA12_: ;
				result += ((NI)1);
			}
		} LA7: ;
		{
			LA6_:;
		}
		{
			oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(owner_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		result = ((NI)1);
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, openShadowScope__lookups_u3850)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* colontmpD_;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = NIM_NIL;
	T1_ = (tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) nimNewObj(sizeof(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww), NIM_ALIGNOF(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww));
	colontmpD_ = eqdup___lookups_u80((*c_p0).currentScope);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).parent = colontmpD_;
	(*T1_).symbols = initStrTable__ast_u6321();
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).depthLevel = scopeDepth__semdata_u418(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___lookups_u83(&(*c_p0).currentScope, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addOverloadableSymAt__lookups_u3826)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* fn_p2) {
NIM_BOOL oldNimErrFin9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!(((1568832 &((NU32)1<<((NU)(((*fn_p2).kind))&31U)))!=0))) goto LA3_;
		internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*fn_p2).info, TM__3uzV357076dKeFHtnMZm2A_44, (&TM__3uzV357076dKeFHtnMZm2A_45));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA3_: ;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* check_1;
		if (!!(((*(*fn_p2).name).id == ((NI)74)))) goto LA7_;
		check_1 = NIM_NIL;
		check_1 = strTableGet__astalgo_u2726((*scope_p1).symbols, (*fn_p2).name);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = !((check_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
			if (!(T12_)) goto LA13_;
			T12_ = !(((1568832 &((NU32)1<<((NU)(((*check_1).kind))&31U)))!=0));
LA13_: ;
			if (!T12_) goto LA14_;
			wrongRedefinition__lookups_u3243(c_p0, (*fn_p2).info, (*(*fn_p2).name).s, (*check_1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17));
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
		goto LA10_;
LA14_: ;
		{
			strTableAdd__astalgo_u2666((&(*scope_p1).symbols), fn_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA10_: ;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(check_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isShadowScope__lookups_u119)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* s_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*s_p0).parent == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*(*s_p0).parent).depthLevel == (*s_p0).depthLevel);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isTopLevelInsideDeclaration__semdata_u4682)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
	NIM_BOOL result;
	result = ((*(*c_p0).currentScope).depthLevel <= (NI)(((NI)2) + ((*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAux__lookups_u3796)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(((*sym_p1).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1)))&63U)))!=0)) goto LA3_;
		{
			if (!!(((*c_p0).module == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA7_;
			exportSym__semdata_u4348(c_p0, sym_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA5_;
LA7_: ;
		{
			internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*sym_p1).info, TM__3uzV357076dKeFHtnMZm2A_47, (&TM__3uzV357076dKeFHtnMZm2A_48));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA5_: ;
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL T11_;
		NIM_BOOL T12_;
		T11_ = (NIM_BOOL)0;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*sym_p1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) && (*sym_p1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10) || (*sym_p1).kind >= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) && (*sym_p1).kind <= ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20) || (*sym_p1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)23));
		if (!(T12_)) goto LA13_;
		T12_ = !(((*c_p0).module == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA13_: ;
		T11_ = T12_;
		if (!(T11_)) goto LA14_;
		T11_ = isTopLevelInsideDeclaration__semdata_u4682(c_p0, sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA14_: ;
		if (!T11_) goto LA15_;
		strTableAdd__astalgo_u2666((&(*(*c_p0).graph).ifaces.p->data[(*(*c_p0).module).position].interfHidden), sym_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ* T21_;
			if (!!(((*(*(*c_p0).graph).config).symbolFiles == ((tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA)0)))) goto LA19_;
			T21_ = (tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ*)0;
			T21_ = (&(*(*c_p0).graph).encoders.p->data[(*(*c_p0).module).position]);
			addHidden__icZic_u3081(T21_, (&(*(*c_p0).graph).packed_0.pm.p->data[(*(*c_p0).module).position].fromDisk), sym_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
	}
	goto LA1_;
LA15_: ;
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceOverloadableSymAt__lookups_u3846)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addOverloadableSymAt__lookups_u3826(c_p0, scope_p1, sym_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isShadowScope__lookups_u119(scope_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		addInterfaceDeclAux__lookups_u3796(c_p0, sym_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, addDeclAt__lookups_u3781)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addDeclAt__lookups_u3253(c_p0, scope_p1, sym_p2, (*sym_p2).info);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, addInterfaceDeclAt__lookups_u3819)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addDeclAt__lookups_u3781(c_p0, scope_p1, sym_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isShadowScope__lookups_u119(scope_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T3_)) goto LA4_;
		addInterfaceDeclAux__lookups_u3796(c_p0, sym_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, addInterfaceDecl__lookups_u3823)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	addInterfaceDeclAt__lookups_u3819(c_p0, (*c_p0).currentScope, sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeShadowScope__lookups_u3854)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* shadowScope_1;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	shadowScope_1 = NIM_NIL;
	eqcopy___lookups_u77(&shadowScope_1, (*c_p0).currentScope);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	rawCloseScope__lookups_u96(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
		tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw it_1;
		sym_1 = NIM_NIL;
		s_1 = NIM_NIL;
		nimZeroMem((void*)(&it_1), sizeof(tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw));
		s_1 = initTabIter__astalgo_u3137((&it_1), (*shadowScope_1).symbols);
		if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T11_;
				if (!!((s_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA5;
				eqsink___ast_u4583(&sym_1, s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				eqwasMoved___ast_u4571(&s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				{
					if (!((1568832 &((NU32)1<<((NU)(((*sym_1).kind))&31U)))!=0)) goto LA8_;
					addInterfaceOverloadableSymAt__lookups_u3846(c_p0, (*c_p0).currentScope, sym_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				}
				goto LA6_;
LA8_: ;
				{
					addInterfaceDecl__lookups_u3823(c_p0, sym_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				}
LA6_: ;
				T11_ = NIM_NIL;
				T11_ = nextIter__astalgo_u3121((&it_1), (*shadowScope_1).symbols);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T11_); goto LA3_;}
				eqsink___ast_u4583(&s_1, T11_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
			} LA5: ;
		}
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u4574(sym_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___lookups_u74(shadowScope_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, closeShadowScope__lookups_u3852)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	rawCloseScope__lookups_u96(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, selectFromScopesElseAll__lookups_u2523)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA result;
NIM_BOOL oldNimErrFin6_;
NIM_BOOL oldNimErrFin3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	{
		{
			tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_1;
			tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* current_1;
			scope_1 = NIM_NIL;
			current_1 = NIM_NIL;
			current_1 = (*c_p0).currentScope;
			{
				while (1) {
					tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti_1;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_1;
					if (!!((current_1 == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA5;
					nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
					candidate_1 = NIM_NIL;
					eqcopy___lookups_u77(&scope_1, current_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
					candidate_1 = initIdentIter__astalgo_u2768((&ti_1), (*scope_1).symbols, s_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
					{
						while (1) {
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T13_;
							if (!!((candidate_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA8;
							{
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
								if (!((filter_p2 &((NU32)1<<((NU)(((*candidate_1).kind))&31U)))!=0)) goto LA11_;
								blitTmp_1 = candidate_1;
								eqwasMoved___ast_u4571(&candidate_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
								add__renderer_u83((&result), blitTmp_1);
								eqdestroy___ast_u4574(candidate_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
								eqdestroy___modulegraphs_u3391(ti_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
								eqdestroy___lookups_u74(scope_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto LA1;
							}
LA11_: ;
							T13_ = NIM_NIL;
							T13_ = nextIdentIter__astalgo_u2744((&ti_1), (*scope_1).symbols);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T13_); goto LA6_;}
							eqsink___ast_u4583(&candidate_1, T13_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
						} LA8: ;
					}
					current_1 = (*current_1).parent;
					{
						LA6_:;
					}
					{
						oldNimErrFin6_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(candidate_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						eqdestroy___modulegraphs_u3391(ti_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
						*nimErr_ = oldNimErrFin6_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				} LA5: ;
			}
			{
				LA3_:;
			}
			{
				oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___lookups_u74(scope_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin3_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
	} LA1: ;
	{
		NI T20_;
		T20_ = result.len;
		if (!(T20_ == ((NI)0))) goto LA21_;
		searchImportsAll__lookups_u2468(c_p0, s_p1, filter_p2, (&result));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA21_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, allPureEnumFields__lookups_u709)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA result;
	tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* res_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
	res_1 = NIM_NIL;
	nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
	result.len = 0; result.p = (tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content*) newSeqPayload(0, sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
	res_1 = initIdentIter__astalgo_u2768((&ti_1), (*c_p0).pureEnumFields, name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T3_;
			if (!!((res_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA2;
			blitTmp_1 = res_1;
			eqwasMoved___ast_u4571(&res_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			add__renderer_u83((&result), blitTmp_1);
			T3_ = NIM_NIL;
			T3_ = nextIdentIter__astalgo_u2744((&ti_1), (*c_p0).pureEnumFields);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T3_); goto BeforeRet_;}
			eqsink___ast_u4583(&res_1, T3_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	eqdestroy___ast_u4574(res_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___modulegraphs_u3391(ti_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, lookUpCandidates__lookups_u5193)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2, NIM_BOOL includePureEnum_p3) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = selectFromScopesElseAll__lookups_u2523(c_p0, ident_p1, filter_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NI T6_;
		tySequence__ZCZaCk14bTmSb6LMW9aWPVA colontmpD_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((filter_p2 &((NU32)1<<((NU)((((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20)))&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T6_ = result.len;
		T5_ = (T6_ == ((NI)0));
		if (T5_) goto LA7_;
		T5_ = includePureEnum_p3;
LA7_: ;
		T3_ = T5_;
LA4_: ;
		if (!T3_) goto LA8_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = allPureEnumFields__lookups_u709(c_p0, ident_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__lookups_u5206((&result), ((colontmpD_).p) ? (colontmpD_.p->data) : NIM_NIL, colontmpD_.len);
		eqdestroy___ast_u4848(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA8_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, mustFixSpelling__lookups_u3896)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = !(((*(*(*c_p0).graph).config).spellSuggestMax == ((NI)0)));
	if (!(T1_)) goto LA2_;
	T1_ = ((*c_p0).compilesContextId == ((NI)0));
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___lookups_u4010)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* dest_p0, tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).dist = (*src_p1).dist;
	(*dest_p0).depth = (*src_p1).depth;
	eqcopy___system_u2694((&(*dest_p0).msg), (*src_p1).msg);
	{
		if (!(*src_p1).sym) goto LA3_;
		nimIncRef((*src_p1).sym);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0).sym);
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3469((&(*(*dest_p0).sym)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).sym, ((NI)8));
	}
LA8_: ;
	(*dest_p0).sym = (*src_p1).sym;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___lookups_u3871)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* a_p0, tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* b_p1) {
	NIM_BOOL result;
	tyTuple__kuMQ1fbjJlHtwKTmBGAe6g T1_;
	tyTuple__kuMQ1fbjJlHtwKTmBGAe6g T2_;
	T1_.Field0 = (*a_p0).dist;
	T1_.Field1 = (*a_p0).depth;
	T1_.Field2 = (*a_p0).msg;
	T2_.Field0 = (*b_p1).dist;
	T2_.Field1 = (*b_p1).depth;
	T2_.Field2 = (*b_p1).msg;
	result = lt___lookups_u3875((&T1_), (&T2_));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___lookups_u4016)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* dest_p0, tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).dist = (*src_p1).dist;
	(*dest_p0).depth = (*src_p1).depth;
	if ((*dest_p0).msg.p != (*src_p1).msg.p) {	eqdestroy___system_u2691((*dest_p0).msg);
	}
(*dest_p0).msg.len = (*src_p1).msg.len; (*dest_p0).msg.p = (*src_p1).msg.p;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).sym);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).sym)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).sym, ((NI)8));
	}
LA4_: ;
	(*dest_p0).sym = (*src_p1).sym;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lookups_u4004)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* dest_p0) {
	(*dest_p0).dist = 0;
	(*dest_p0).depth = 0;
	(*dest_p0).msg.len = 0; (*dest_p0).msg.p = NIM_NIL;
	(*dest_p0).sym = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u4007)(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).sym);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).sym)));
		nimRawDispose((*dest_p0).sym, ((NI)8));
	}
LA4_: ;
	eqdestroy___system_u2691((*dest_p0).msg);
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u2997)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, NI module_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NI T2_;
	T1_ = (NIM_BOOL)0;
	T2_ = (*g_p0).packed_0.pm.len;
	T1_ = (module_p1 < T2_);
	if (!(T1_)) goto LA3_;
	T1_ = ((*g_p0).packed_0.pm.p->data[module_p1].status == ((tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ)3));
LA3_: ;
	result = T1_;
	return result;
}
static N_INLINE(NIM_BOOL, isCachedModule__modulegraphs_u3008)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	result = isCachedModule__modulegraphs_u2997(g_p0, (*m_p1).position);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__lookups_u4190)(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw heap_p0) {
	NI result;
	NI T1_;
	T1_ = heap_p0.data.len;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q*, X5BX5D___lookups_u4257)(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw* heap_p0, NI i_p1) {
	tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* result;
	result = (&(*heap_p0).data.p->data[i_p1]);
	return result;
}
static N_INLINE(NIM_BOOL, eqeq___idents_u366)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* a_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* b_p1) {
	NIM_BOOL result;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (a_p0 == 0);
		if (T3_) goto LA4_;
		T3_ = (b_p1 == 0);
LA4_: ;
		if (!T3_) goto LA5_;
		result = (a_p0 == b_p1);
	}
	goto LA1_;
LA5_: ;
	{
		result = ((*a_p0).id == (*b_p1).id);
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, fixSpelling__lookups_u3899)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p1, NimStringV2* result_p2) {
	tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw list_1;
	NimStringV2 name0_1;
	tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q e0_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* last_1;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin37_;
NIM_BOOL oldNimErrFin52_;
NIM_BOOL oldNimErrFin31_;
NIM_BOOL oldNimErrFin3_;
	tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q* T80_;
	NI count_1;
NIM_BOOL oldNimErrFin83_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&list_1), sizeof(tyObject_HeapQueue__9aOHerBv0an5tP1z30X2SCw));
	name0_1.len = 0; name0_1.p = NIM_NIL;
	nimZeroMem((void*)(&e0_1), sizeof(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q));
	last_1 = NIM_NIL;
	list_1 = initHeapQueue__lookups_u3910();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	name0_1 = nimIdentNormalize__pureZstrutils_u124((*ident_p1).s);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_1;
		NI depth_1;
		NIM_BOOL isLocal_1;
		NIM_BOOL isLocal_2;
		NI scopeN_1;
		sym_1 = NIM_NIL;
		depth_1 = (NI)0;
		isLocal_1 = (NIM_BOOL)0;
		isLocal_2 = NIM_TRUE;
		scopeN_1 = ((NI)0);
		{
			tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_1;
			tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* current_1;
			scope_1 = NIM_NIL;
			current_1 = NIM_NIL;
			eqcopy___lookups_u77(&current_1, (*c_p0).currentScope);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			{
				while (1) {
					if (!!((current_1 == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA7;
					eqcopy___lookups_u77(&scope_1, current_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					{
						if (!(scope_1 == (*c_p0).topLevelScope)) goto LA10_;
						isLocal_2 = NIM_FALSE;
					}
LA10_: ;
					scopeN_1 -= ((NI)1);
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* item_1;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
						tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw it_1;
						item_1 = NIM_NIL;
						s_1 = NIM_NIL;
						item_1 = 0;
						nimZeroMem((void*)(&it_1), sizeof(tyObject_TTabIter__tBHHtIwJDg4f2qPThAL9ctw));
						s_1 = initTabIter__astalgo_u3137((&it_1), (*scope_1).symbols);
						if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
						{
							while (1) {
								tyTuple__WIyQ4Cfp4shlBOyEpagHMw colontmp_;
								NimStringV2 colontmpD_;
								NimStringV2 msg_1;
								NimStringV2 colontmpD__2;
								NimStringV2 colontmpD__3;
								NimStringV2 colontmpD__4;
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_1;
								NI depth_2;
								NI dist_1;
								tyArray__dyW7vpmfeTYw8kX3EXuaJA T17_;
								tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q T18_;
								NimStringV2 blitTmp_2;
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_3;
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T19_;
								if (!!((s_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA15;
								nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__WIyQ4Cfp4shlBOyEpagHMw));
								colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
								msg_1.len = 0; msg_1.p = NIM_NIL;
								colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
								colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
								colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
								eqsink___ast_u4583(&item_1, s_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								eqwasMoved___ast_u4571(&s_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								nimZeroMem((void*)(&colontmp_), sizeof(tyTuple__WIyQ4Cfp4shlBOyEpagHMw));
								blitTmp_1 = item_1;
								eqwasMoved___ast_u4571(&item_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								colontmp_.Field0 = blitTmp_1;
								colontmp_.Field1 = scopeN_1;
								colontmp_.Field2 = isLocal_2;
								eqsink___ast_u4583(&sym_1, colontmp_.Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								depth_1 = colontmp_.Field1;
								isLocal_1 = colontmp_.Field2;
								depth_2 = (NI)(((NI64)-(depth_1)) - ((NI)1));
								colontmpD_ = nimIdentNormalize__pureZstrutils_u124((*(*sym_1).name).s);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								dist_1 = editDistance__stdZeditdistance_u2(name0_1, colontmpD_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								msg_1 = TM__3uzV357076dKeFHtnMZm2A_50;
								colontmpD__2 = dollar___systemZdollars_u9(dist_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								T17_[0] = colontmpD__2;
								colontmpD__3 = dollar___systemZdollars_u9(depth_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								T17_[1] = colontmpD__3;
								T17_[2] = (*(*sym_1).name).s;
								colontmpD__4 = nsuFormatOpenArray(TM__3uzV357076dKeFHtnMZm2A_52, T17_, 3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								prepareAdd((&msg_1), colontmpD__4.len + 0);
appendString((&msg_1), colontmpD__4);
								nimZeroMem((void*)(&T18_), sizeof(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q));
								T18_.dist = dist_1;
								T18_.depth = depth_2;
								blitTmp_2 = msg_1;
								eqwasMoved___system_u2688((&msg_1));
								T18_.msg = blitTmp_2;
								blitTmp_3 = sym_1;
								eqwasMoved___ast_u4571(&sym_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								T18_.sym = blitTmp_3;
								push__lookups_u4107((&list_1), (&T18_));
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								T19_ = NIM_NIL;
								T19_ = nextIter__astalgo_u3121((&it_1), (*scope_1).symbols);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T19_); goto LA16_;}
								eqsink___ast_u4583(&s_1, T19_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA16_;
								{
									LA16_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__4);
									eqdestroy___system_u2691(colontmpD__3);
									eqdestroy___system_u2691(colontmpD__2);
									eqdestroy___system_u2691(msg_1);
									eqdestroy___system_u2691(colontmpD_);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
							} LA15: ;
						}
						{
							LA13_:;
						}
						{
							oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u4574(s_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
							eqdestroy___ast_u4574(item_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
							*nimErr_ = oldNimErrFin13_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					}
					eqcopy___lookups_u77(&current_1, (*current_1).parent);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				} LA7: ;
			}
			{
				LA5_:;
			}
			{
				oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___lookups_u74(current_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				eqdestroy___lookups_u74(scope_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
				*nimErr_ = oldNimErrFin5_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
		}
		scopeN_1 -= ((NI)1);
		isLocal_2 = NIM_FALSE;
		{
			tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_1;
			NI i_1;
			NI L_1;
			NI T27_;
			im_1 = (tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw*)0;
			i_1 = ((NI)0);
			T27_ = (*c_p0).imports.len;
			L_1 = T27_;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA29;
					im_1 = (&(*c_p0).imports.p->data[i_1]);
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
						NIM_BOOL importHidden_1;
						s_2 = NIM_NIL;
						s_2 = 0;
						importHidden_1 = (((*(*im_1).m).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)27)))&31U)))!=0);
						{
							NIM_BOOL T34_;
							tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ rodIt_1;
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* r_1;
							tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* T38_;
							tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* T39_;
							T34_ = (NIM_BOOL)0;
							T34_ = isCachedModule__modulegraphs_u3008((*c_p0).graph, (*im_1).m);
							if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
							if (!T34_) goto LA35_;
							nimZeroMem((void*)(&rodIt_1), sizeof(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ));
							r_1 = NIM_NIL;
							nimZeroMem((void*)(&rodIt_1), sizeof(tyObject_RodIter__6N3dhucH9ae3pEqcrhPOBMQ));
							T38_ = NIM_NIL;
							T38_ = (*(*c_p0).graph).config;
							T39_ = NIM_NIL;
							T39_ = (*(*c_p0).graph).cache;
							r_1 = initRodIterAllSyms__icZic_u21632((&rodIt_1), T38_, T39_, (&(*(*c_p0).graph).packed_0), ((NI32) ((*(*im_1).m).position)), importHidden_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
							{
								while (1) {
									tyTuple__WIyQ4Cfp4shlBOyEpagHMw colontmp__2;
									NimStringV2 colontmpD__5;
									NimStringV2 msg_2;
									NimStringV2 colontmpD__6;
									NimStringV2 colontmpD__7;
									NimStringV2 colontmpD__8;
									tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_4;
									NI depth_3;
									NI dist_2;
									tyArray__dyW7vpmfeTYw8kX3EXuaJA T43_;
									tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q T44_;
									NimStringV2 blitTmp_5;
									tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_6;
									tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T45_;
									if (!!((r_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA41;
									nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__WIyQ4Cfp4shlBOyEpagHMw));
									colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
									msg_2.len = 0; msg_2.p = NIM_NIL;
									colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
									colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
									colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
									eqsink___ast_u4583(&s_2, r_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									eqwasMoved___ast_u4571(&r_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									nimZeroMem((void*)(&colontmp__2), sizeof(tyTuple__WIyQ4Cfp4shlBOyEpagHMw));
									blitTmp_4 = s_2;
									eqwasMoved___ast_u4571(&s_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									colontmp__2.Field0 = blitTmp_4;
									colontmp__2.Field1 = scopeN_1;
									colontmp__2.Field2 = isLocal_2;
									eqsink___ast_u4583(&sym_1, colontmp__2.Field0);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									depth_1 = colontmp__2.Field1;
									isLocal_1 = colontmp__2.Field2;
									depth_3 = (NI)(((NI64)-(depth_1)) - ((NI)1));
									colontmpD__5 = nimIdentNormalize__pureZstrutils_u124((*(*sym_1).name).s);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									dist_2 = editDistance__stdZeditdistance_u2(name0_1, colontmpD__5);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									msg_2 = TM__3uzV357076dKeFHtnMZm2A_53;
									colontmpD__6 = dollar___systemZdollars_u9(dist_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									T43_[0] = colontmpD__6;
									colontmpD__7 = dollar___systemZdollars_u9(depth_3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									T43_[1] = colontmpD__7;
									T43_[2] = (*(*sym_1).name).s;
									colontmpD__8 = nsuFormatOpenArray(TM__3uzV357076dKeFHtnMZm2A_54, T43_, 3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									prepareAdd((&msg_2), colontmpD__8.len + 0);
appendString((&msg_2), colontmpD__8);
									nimZeroMem((void*)(&T44_), sizeof(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q));
									T44_.dist = dist_2;
									T44_.depth = depth_3;
									blitTmp_5 = msg_2;
									eqwasMoved___system_u2688((&msg_2));
									T44_.msg = blitTmp_5;
									blitTmp_6 = sym_1;
									eqwasMoved___ast_u4571(&sym_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									T44_.sym = blitTmp_6;
									push__lookups_u4107((&list_1), (&T44_));
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									T45_ = NIM_NIL;
									T45_ = nextRodIter__icZic_u21968((&rodIt_1), (&(*(*c_p0).graph).packed_0));
									if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T45_); goto LA42_;}
									eqsink___ast_u4583(&r_1, T45_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
									{
										LA42_:;
									}
									{
										eqdestroy___system_u2691(colontmpD__8);
										eqdestroy___system_u2691(colontmpD__7);
										eqdestroy___system_u2691(colontmpD__6);
										eqdestroy___system_u2691(msg_2);
										eqdestroy___system_u2691(colontmpD__5);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
								} LA41: ;
							}
							{
								LA37_:;
							}
							{
								oldNimErrFin37_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u4574(r_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
								eqdestroy___modulegraphs_u3288((&rodIt_1));
								if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
								*nimErr_ = oldNimErrFin37_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
						}
						goto LA32_;
LA35_: ;
						{
							{
								tySequence__ZCZaCk14bTmSb6LMW9aWPVA colontmp__3;
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** s_3;
								tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* retX60gensym20__1;
								NI i_2;
								NI L_2;
								NI T57_;
								colontmp__3.len = 0; colontmp__3.p = NIM_NIL;
								s_3 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
								colontmp__3.len = 0; colontmp__3.p = NIM_NIL;
								retX60gensym20__1 = (&(*(*c_p0).graph).ifaces.p->data[(*(*im_1).m).position].interf);
								{
									if (!importHidden_1) goto LA55_;
									retX60gensym20__1 = (&(*(*c_p0).graph).ifaces.p->data[(*(*im_1).m).position].interfHidden);
								}
LA55_: ;
								eqcopy___ast_u4851((&colontmp__3), (*retX60gensym20__1).data);
								if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
								i_2 = ((NI)0);
								T57_ = colontmp__3.len;
								L_2 = T57_;
								{
									while (1) {
										if (!(i_2 < L_2)) goto LA59;
										s_3 = &colontmp__3.p->data[i_2];
										{
											tyTuple__WIyQ4Cfp4shlBOyEpagHMw colontmp__4;
											NimStringV2 colontmpD__9;
											NimStringV2 msg_3;
											NimStringV2 colontmpD__10;
											NimStringV2 colontmpD__11;
											NimStringV2 colontmpD__12;
											tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_7;
											NI depth_4;
											NI dist_3;
											tyArray__dyW7vpmfeTYw8kX3EXuaJA T65_;
											tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q T66_;
											NimStringV2 blitTmp_8;
											tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_9;
											if (!!(((*s_3) == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA62_;
											nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__WIyQ4Cfp4shlBOyEpagHMw));
											colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
											msg_3.len = 0; msg_3.p = NIM_NIL;
											colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
											colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
											colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
											eqcopy___ast_u4577(&s_2, (*s_3));
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											nimZeroMem((void*)(&colontmp__4), sizeof(tyTuple__WIyQ4Cfp4shlBOyEpagHMw));
											blitTmp_7 = s_2;
											eqwasMoved___ast_u4571(&s_2);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											colontmp__4.Field0 = blitTmp_7;
											colontmp__4.Field1 = scopeN_1;
											colontmp__4.Field2 = isLocal_2;
											eqsink___ast_u4583(&sym_1, colontmp__4.Field0);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											depth_1 = colontmp__4.Field1;
											isLocal_1 = colontmp__4.Field2;
											depth_4 = (NI)(((NI64)-(depth_1)) - ((NI)1));
											colontmpD__9 = nimIdentNormalize__pureZstrutils_u124((*(*sym_1).name).s);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											dist_3 = editDistance__stdZeditdistance_u2(name0_1, colontmpD__9);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											msg_3 = TM__3uzV357076dKeFHtnMZm2A_55;
											colontmpD__10 = dollar___systemZdollars_u9(dist_3);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											T65_[0] = colontmpD__10;
											colontmpD__11 = dollar___systemZdollars_u9(depth_4);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											T65_[1] = colontmpD__11;
											T65_[2] = (*(*sym_1).name).s;
											colontmpD__12 = nsuFormatOpenArray(TM__3uzV357076dKeFHtnMZm2A_56, T65_, 3);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											prepareAdd((&msg_3), colontmpD__12.len + 0);
appendString((&msg_3), colontmpD__12);
											nimZeroMem((void*)(&T66_), sizeof(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q));
											T66_.dist = dist_3;
											T66_.depth = depth_4;
											blitTmp_8 = msg_3;
											eqwasMoved___system_u2688((&msg_3));
											T66_.msg = blitTmp_8;
											blitTmp_9 = sym_1;
											eqwasMoved___ast_u4571(&sym_1);
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											T66_.sym = blitTmp_9;
											push__lookups_u4107((&list_1), (&T66_));
											if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
											{
												LA64_:;
											}
											{
												eqdestroy___system_u2691(colontmpD__12);
												eqdestroy___system_u2691(colontmpD__11);
												eqdestroy___system_u2691(colontmpD__10);
												eqdestroy___system_u2691(msg_3);
												eqdestroy___system_u2691(colontmpD__9);
											}
											if (NIM_UNLIKELY(*nimErr_)) goto LA52_;
										}
LA62_: ;
										i_2 += ((NI)1);
									} LA59: ;
								}
								{
									LA52_:;
								}
								{
									oldNimErrFin52_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___ast_u4848(colontmp__3);
									if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
									*nimErr_ = oldNimErrFin52_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
							}
						}
LA32_: ;
						{
							LA31_:;
						}
						{
							oldNimErrFin31_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u4574(s_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
							*nimErr_ = oldNimErrFin31_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA3_;
					}
					i_1 += ((NI)1);
				} LA29: ;
			}
		}
		{
			LA3_:;
		}
		{
			oldNimErrFin3_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(sym_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin3_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		NI T77_;
		T77_ = (NI)0;
		T77_ = len__lookups_u4190(list_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T77_ == ((NI)0))) goto LA78_;
		eqdestroy___idents_u155(last_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___lookups_u4007((&e0_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(name0_1);
		eqdestroy___lookups_u3922(list_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA78_: ;
	T80_ = (tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q*)0;
	T80_ = X5BX5D___lookups_u4257((&list_1), ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___lookups_u4010((&e0_1), (&(*T80_)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	count_1 = ((NI)0);
	last_1 = ((tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*) NIM_NIL);
	{
		while (1) {
			tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q e_1;
			nimZeroMem((void*)(&e_1), sizeof(tyObject_SpellCandidate__ITFLWGoi3Tc29brFQatc9a8Q));
			{
				NI T86_;
				T86_ = (NI)0;
				T86_ = len__lookups_u4190(list_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				if (!(T86_ == ((NI)0))) goto LA87_;
				eqdestroy___lookups_u4007((&e_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				goto LA81;
			}
LA87_: ;
			pop__lookups_u4575((&list_1), (&e_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			{
				if (!((*(*(*c_p0).graph).config).spellSuggestMax == ((NI)-1))) goto LA91_;
				{
					NIM_BOOL T95_;
					NIM_BOOL T96_;
					T95_ = (NIM_BOOL)0;
					T96_ = (NIM_BOOL)0;
					T96_ = (e0_1.dist < e_1.dist);
					if (T96_) goto LA97_;
					T96_ = (((NI)3) <= count_1);
LA97_: ;
					T95_ = T96_;
					if (T95_) goto LA98_;
					T95_ = (name0_1.len < ((NI)4));
LA98_: ;
					if (!T95_) goto LA99_;
					eqdestroy___lookups_u4007((&e_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					goto LA81;
				}
LA99_: ;
			}
			goto LA89_;
LA91_: ;
			{
				if (!((*(*(*c_p0).graph).config).spellSuggestMax <= count_1)) goto LA102_;
				eqdestroy___lookups_u4007((&e_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				goto LA81;
			}
			goto LA89_;
LA102_: ;
LA89_: ;
			{
				if (!(count_1 == ((NI)0))) goto LA106_;
				prepareAdd((&(*result_p2)), 67);
appendString((&(*result_p2)), TM__3uzV357076dKeFHtnMZm2A_58);
			}
LA106_: ;
			{
				NIM_BOOL T110_;
				T110_ = (NIM_BOOL)0;
				T110_ = eqeq___idents_u366((*e_1.sym).name, last_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
				if (!!(T110_)) goto LA111_;
				prepareAdd((&(*result_p2)), e_1.msg.len + 0);
appendString((&(*result_p2)), e_1.msg);
				count_1 += ((NI)1);
				eqcopy___idents_u158(&last_1, (*e_1.sym).name);
				if (NIM_UNLIKELY(*nimErr_)) goto LA83_;
			}
LA111_: ;
			{
				LA83_:;
			}
			{
				oldNimErrFin83_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___lookups_u4007((&e_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin83_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	} LA81: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___idents_u155(last_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___lookups_u4007((&e0_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(name0_1);
		eqdestroy___lookups_u3922(list_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUndeclaredIdentifier__lookups_u5145)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 name_p2, NimStringV2 extra_p3) {
	NimStringV2 err_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	err_1.len = 0; err_1.p = NIM_NIL;
	{
		if (!eqStrings(name_p2, TM__3uzV357076dKeFHtnMZm2A_60)) goto LA4_;
		err_1 = TM__3uzV357076dKeFHtnMZm2A_62;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 T7_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = rawNewString(name_p2.len + 25);
appendString((&T7_), TM__3uzV357076dKeFHtnMZm2A_64);
appendString((&T7_), name_p2);
appendString((&T7_), TM__3uzV357076dKeFHtnMZm2A_65);
		err_1 = T7_;
		{
			NIM_BOOL T10_;
			T10_ = (NIM_BOOL)0;
			T10_ = contains__pureZstrutils_u1833(name_p2, TM__3uzV357076dKeFHtnMZm2A_67);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T10_) goto LA11_;
			prepareAdd((&err_1), 90);
appendString((&err_1), TM__3uzV357076dKeFHtnMZm2A_69);
		}
LA11_: ;
		{
			if (!!((extra_p3.len == ((NI)0)))) goto LA15_;
			prepareAdd((&err_1), extra_p3.len + 0);
appendString((&err_1), extra_p3);
		}
LA15_: ;
		{
			if (!(((NI)0) < (*c_p0).recursiveDep.len)) goto LA19_;
			prepareAdd((&err_1), 56);
appendString((&err_1), TM__3uzV357076dKeFHtnMZm2A_71);
			prepareAdd((&err_1), (*c_p0).recursiveDep.len + 0);
appendString((&err_1), (*c_p0).recursiveDep);
			eqsink___system_u2700((&(*c_p0).recursiveDep), TM__3uzV357076dKeFHtnMZm2A_72);
		}
LA19_: ;
	}
LA2_: ;
	liMessage__msgs_u1227((*(*c_p0).graph).config, info_p1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), err_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_73), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(err_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, errorSym__lookups_u2607)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ T1_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = getCurrOwner__semdata_u425(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = 0;
	result = newSym__ast_u4205(((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0), ident_p1, (*c_p0).Sup.idgen, colontmpD_, info_p2, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = NIM_NIL;
	T2_ = errorType__semdata_u4564(c_p0);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T2_); goto BeforeRet_;}
	eqsink___ast_u3387(&(*result).typ, T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).flags |= ((NU64)1)<<(((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)34))) & 63);
	{
		NIM_BOOL T5_;
		T5_ = (NIM_BOOL)0;
		T5_ = !(((*(*(*c_p0).graph).config).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)27)));
		if (!(T5_)) goto LA6_;
		T5_ = ((*c_p0).compilesContextId == ((NI)0));
LA6_: ;
		if (!T5_) goto LA7_;
		strTableAdd__astalgo_u2666((&(*(*c_p0).moduleScope).symbols), result);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, errorUndeclaredIdentifierHint__lookups_u5151)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NimStringV2 extra_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	extra_1.len = 0; extra_1.p = NIM_NIL;
	extra_1 = TM__3uzV357076dKeFHtnMZm2A_49;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = mustFixSpelling__lookups_u3896(c_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		fixSpelling__lookups_u3899(c_p0, ident_p1, (&extra_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	errorUndeclaredIdentifier__lookups_u5145(c_p0, info_p2, (*ident_p1).s, extra_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = errorSym__lookups_u2607(c_p0, ident_p1, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(extra_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, ambiguousIdentifierMsg__lookups_u5072)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA candidates_p0, NimStringV2 prefix_p1, NI indent_p2) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 T5_;
	NI i_3;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = TM__3uzV357076dKeFHtnMZm2A_74;
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < indent_p2)) goto LA4;
				i_1 = i_2;
				nimAddCharV1((&result), 32);
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	T5_.len = 0; T5_.p = NIM_NIL;
	T5_ = rawNewString((*(*candidates_p0.p->data[((NI)0)]).name).s.len + 24);
appendString((&T5_), TM__3uzV357076dKeFHtnMZm2A_76);
appendString((&T5_), (*(*candidates_p0.p->data[((NI)0)]).name).s);
appendString((&T5_), TM__3uzV357076dKeFHtnMZm2A_77);
	colontmpD_ = T5_;
	prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
	i_3 = ((NI)0);
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** candidate_1;
		NI i_4;
		NI L_1;
		NI T7_;
		candidate_1 = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg**)0;
		i_4 = ((NI)0);
		T7_ = candidates_p0.len;
		L_1 = T7_;
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				NimStringV2 T22_;
				NimStringV2 T23_;
				if (!(i_4 < L_1)) goto LA9;
				colontmpD__2 = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				candidate_1 = &candidates_p0.p->data[i_4];
				{
					NimStringV2 colontmpD__6;
					if (!(i_3 == ((NI)0))) goto LA13_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__6 = nsuFormatSingleElem(TM__3uzV357076dKeFHtnMZm2A_79, prefix_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
					prepareAdd((&result), colontmpD__6.len + 0);
appendString((&result), colontmpD__6);
					{
						LA15_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__6);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				}
				goto LA11_;
LA13_: ;
				{
					prepareAdd((&result), 1);
appendString((&result), TM__3uzV357076dKeFHtnMZm2A_81);
				}
LA11_: ;
				{
					NI i_5;
					NI i_6;
					i_5 = (NI)0;
					i_6 = ((NI)0);
					{
						while (1) {
							if (!(i_6 < indent_p2)) goto LA21;
							i_5 = i_6;
							nimAddCharV1((&result), 32);
							i_6 += ((NI)1);
						} LA21: ;
					}
				}
				T22_.len = 0; T22_.p = NIM_NIL;
				colontmpD__2 = owner__ast_u6254((*candidate_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				T22_ = rawNewString((*(*colontmpD__2).name).s.len + (*(*(*candidate_1)).name).s.len + 3);
appendString((&T22_), TM__3uzV357076dKeFHtnMZm2A_83);
appendString((&T22_), (*(*colontmpD__2).name).s);
appendString((&T22_), TM__3uzV357076dKeFHtnMZm2A_85);
appendString((&T22_), (*(*(*candidate_1)).name).s);
				colontmpD__3 = T22_;
				prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
				T23_.len = 0; T23_.p = NIM_NIL;
				colontmpD__4 = typeToString__types_u54((*(*candidate_1)).typ, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
				T23_ = rawNewString(colontmpD__4.len + 2);
appendString((&T23_), TM__3uzV357076dKeFHtnMZm2A_87);
appendString((&T23_), colontmpD__4);
				colontmpD__5 = T23_;
				prepareAdd((&result), colontmpD__5.len + 0);
appendString((&result), colontmpD__5);
				i_3 += ((NI)1);
				i_4 += ((NI)1);
				{
					LA10_:;
				}
				{
					oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___ast_u4574(colontmpD__2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					*nimErr_ = oldNimErrFin10_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA9: ;
		}
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__lookups_u5100)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tySequence__ZCZaCk14bTmSb6LMW9aWPVA candidates_p2) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = ambiguousIdentifierMsg__lookups_u5072(candidates_p2, TM__3uzV357076dKeFHtnMZm2A_89, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	liMessage__msgs_u1227((*(*c_p0).graph).config, info_p1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_90), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, someSymFromImportTable__lookups_u2381)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, NIM_BOOL* ambiguous_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA marked_1;
	tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symSet_1;
NIM_BOOL oldNimErrFin8_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	nimZeroMem((void*)(&marked_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&marked_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	symSet_1 = 1568832;
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	{
		{
			tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_1;
			NI i_1;
			NI L_1;
			NI T4_;
			im_1 = (tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw*)0;
			i_1 = ((NI)0);
			T4_ = (*c_p0).imports.len;
			L_1 = T4_;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA6;
					im_1 = (&(*c_p0).imports.p->data[i_1]);
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
						tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ ti_1;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_1;
						s_1 = NIM_NIL;
						nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
						candidate_1 = NIM_NIL;
						s_1 = 0;
						nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
						candidate_1 = initIdentIter__lookups_u135((&ti_1), (&marked_1), (&(*im_1)), name_p1, (*c_p0).graph);
						if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
						{
							while (1) {
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T20_;
								if (!!((candidate_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA10;
								eqsink___ast_u4583(&s_1, candidate_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
								eqwasMoved___ast_u4571(&candidate_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
								{
									if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA13_;
									eqsink___ast_u4583(&result, s_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
									eqwasMoved___ast_u4571(&s_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
								}
								goto LA11_;
LA13_: ;
								{
									NIM_BOOL T16_;
									T16_ = (NIM_BOOL)0;
									T16_ = !(((symSet_1 &((NU32)1<<((NU)(((*s_1).kind))&31U)))!=0));
									if (T16_) goto LA17_;
									T16_ = !(((symSet_1 &((NU32)1<<((NU)(((*result).kind))&31U)))!=0));
LA17_: ;
									if (!T16_) goto LA18_;
									(*ambiguous_p2) = NIM_TRUE;
									eqdestroy___ast_u4574(candidate_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									eqdestroy___modulegraphs_u3435((&ti_1));
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									eqdestroy___ast_u4574(s_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									goto LA2;
								}
								goto LA11_;
LA18_: ;
LA11_: ;
								T20_ = NIM_NIL;
								T20_ = nextIdentIter__lookups_u350((&ti_1), (&marked_1), (&(*im_1)), (*c_p0).graph);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T20_); goto LA8_;}
								eqsink___ast_u4583(&candidate_1, T20_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
							} LA10: ;
						}
						{
							LA8_:;
						}
						{
							oldNimErrFin8_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u4574(candidate_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___modulegraphs_u3435((&ti_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___ast_u4574(s_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							*nimErr_ = oldNimErrFin8_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
					i_1 += ((NI)1);
				} LA6: ;
			}
		}
	} LA2: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, searchInScopes__lookups_u2425)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, NIM_BOOL* ambiguous_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_1;
		tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* current_1;
		scope_1 = NIM_NIL;
		current_1 = NIM_NIL;
		current_1 = (*c_p0).currentScope;
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T5_;
				if (!!((current_1 == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA4;
				eqcopy___lookups_u77(&scope_1, current_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T5_ = NIM_NIL;
				T5_ = strTableGet__astalgo_u2726((*scope_1).symbols, s_p1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T5_); goto LA2_;}
				eqsink___ast_u4583(&result, T5_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				{
					if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA8_;
					eqdestroy___lookups_u74(scope_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA8_: ;
				current_1 = (*current_1).parent;
			} LA4: ;
		}
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___lookups_u74(scope_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	result = someSymFromImportTable__lookups_u2381(c_p0, s_p1, ambiguous_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, errorUseQualifier__lookups_u5040)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2, NIM_BOOL* amb_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NimStringV2 err_1;
	NimStringV2 T2_;
	NI i_1;
	NI ignoredModules_1;
NIM_BOOL oldNimErrFin13_;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	err_1.len = 0; err_1.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = rawNewString((*(*s_p2).name).s.len + 24);
appendString((&T2_), TM__3uzV357076dKeFHtnMZm2A_91);
appendString((&T2_), (*(*s_p2).name).s);
appendString((&T2_), TM__3uzV357076dKeFHtnMZm2A_92);
	err_1 = T2_;
	i_1 = ((NI)0);
	ignoredModules_1 = ((NI)0);
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_1;
		tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA marked_1;
		candidate_1 = NIM_NIL;
		nimZeroMem((void*)(&marked_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
		initIntSet__pureZcollectionsZintsets_u598((&marked_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		{
			tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_1;
			NI i_2;
			NI L_1;
			NI T6_;
			im_1 = (tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw*)0;
			i_2 = ((NI)0);
			T6_ = (*c_p0).imports.len;
			L_1 = T6_;
			{
				while (1) {
					if (!(i_2 < L_1)) goto LA8;
					im_1 = (&(*c_p0).imports.p->data[i_2]);
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
						tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ ti_1;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_2;
						s_2 = NIM_NIL;
						nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
						candidate_2 = NIM_NIL;
						s_2 = 0;
						nimZeroMem((void*)(&ti_1), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
						candidate_2 = initIdentIter__lookups_u135((&ti_1), (&marked_1), (&(*im_1)), (*s_p2).name, (*c_p0).graph);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						{
							while (1) {
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
								NimStringV2 colontmpD__2;
								NimStringV2 colontmpD__3;
								NimStringV2 colontmpD__4;
								NimStringV2 T19_;
								NimStringV2 T20_;
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T26_;
								if (!!((candidate_2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA12;
								colontmpD_ = NIM_NIL;
								colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
								colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
								colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
								eqsink___ast_u4583(&s_2, candidate_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								eqwasMoved___ast_u4571(&candidate_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								eqsink___ast_u4583(&candidate_1, s_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								eqwasMoved___ast_u4571(&s_2);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								{
									if (!(i_1 == ((NI)0))) goto LA16_;
									prepareAdd((&err_1), 30);
appendString((&err_1), TM__3uzV357076dKeFHtnMZm2A_94);
								}
								goto LA14_;
LA16_: ;
								{
									prepareAdd((&err_1), 1);
appendString((&err_1), TM__3uzV357076dKeFHtnMZm2A_95);
								}
LA14_: ;
								T19_.len = 0; T19_.p = NIM_NIL;
								colontmpD_ = owner__ast_u6254(candidate_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								T19_ = rawNewString((*(*colontmpD_).name).s.len + (*(*candidate_1).name).s.len + 3);
appendString((&T19_), TM__3uzV357076dKeFHtnMZm2A_96);
appendString((&T19_), (*(*colontmpD_).name).s);
appendString((&T19_), TM__3uzV357076dKeFHtnMZm2A_97);
appendString((&T19_), (*(*candidate_1).name).s);
								colontmpD__2 = T19_;
								prepareAdd((&err_1), colontmpD__2.len + 0);
appendString((&err_1), colontmpD__2);
								T20_.len = 0; T20_.p = NIM_NIL;
								colontmpD__3 = typeToString__types_u54((*candidate_1).typ, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								T20_ = rawNewString(colontmpD__3.len + 2);
appendString((&T20_), TM__3uzV357076dKeFHtnMZm2A_98);
appendString((&T20_), colontmpD__3);
								colontmpD__4 = T20_;
								prepareAdd((&err_1), colontmpD__4.len + 0);
appendString((&err_1), colontmpD__4);
								{
									if (!((*candidate_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6))) goto LA23_;
									ignoredModules_1 += ((NI)1);
								}
								goto LA21_;
LA23_: ;
								{
									eqsink___ast_u4583(&result, candidate_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
									eqwasMoved___ast_u4571(&candidate_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								}
LA21_: ;
								i_1 += ((NI)1);
								T26_ = NIM_NIL;
								T26_ = nextIdentIter__lookups_u350((&ti_1), (&marked_1), (&(*im_1)), (*c_p0).graph);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T26_); goto LA13_;}
								eqsink___ast_u4583(&candidate_2, T26_);
								if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
								{
									LA13_:;
								}
								{
									oldNimErrFin13_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___system_u2691(colontmpD__4);
									eqdestroy___system_u2691(colontmpD__3);
									eqdestroy___system_u2691(colontmpD__2);
									eqdestroy___ast_u4574(colontmpD_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
									*nimErr_ = oldNimErrFin13_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
							} LA12: ;
						}
						{
							LA10_:;
						}
						{
							oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u4574(candidate_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
							eqdestroy___modulegraphs_u3435((&ti_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
							eqdestroy___ast_u4574(s_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
							*nimErr_ = oldNimErrFin10_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
					}
					i_2 += ((NI)1);
				} LA8: ;
			}
		}
		{
			LA4_:;
		}
		{
			oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___ast_u4574(candidate_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin4_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	{
		if (!!((ignoredModules_1 == (NI)(i_1 - ((NI)1))))) goto LA35_;
		liMessage__msgs_u1227((*(*c_p0).graph).config, info_p1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), err_1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_99), NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqsink___ast_u4583(&result, ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA33_;
LA35_: ;
	{
		(*amb_p3) = NIM_FALSE;
	}
LA33_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(err_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getPIdent__ast_u2825)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0) {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* result;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	switch ((*a_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___idents_u158(&result, (*(*a_p0)._kind_4.sym).name);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		eqcopy___idents_u158(&result, (*a_p0)._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
	{
		eqcopy___idents_u158(&result, (*(*(*a_p0)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		result = ((tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*) NIM_NIL);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, errorSym__lookups_u2620)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* m_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T6_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	m_1 = NIM_NIL;
	ident_1 = NIM_NIL;
	eqcopy___ast_u3255(&m_1, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*m_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45))) goto LA4_;
		eqcopy___ast_u3255(&m_1, (*m_1)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	T6_ = NIM_NIL;
	{
		if (!((*m_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2) || (*m_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3) || (*m_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53))) goto LA9_;
		ident_1 = considerQuotedIdent__lookups_u31(c_p0, m_1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA7_;
LA9_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 T13_;
		tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T14_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T13_.len = 0; T13_.p = NIM_NIL;
		T14_ = 0;
		colontmpD_ = renderTree__renderer_u59(m_1, T14_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		T13_ = rawNewString(colontmpD_.len + 4);
appendString((&T13_), TM__3uzV357076dKeFHtnMZm2A_104);
appendString((&T13_), colontmpD_);
		colontmpD__2 = T13_;
		ident_1 = getIdent__idents_u206((*c_p0).cache, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
		{
			LA12_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	result = errorSym__lookups_u2607(c_p0, ident_1, (*n_p1).info);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___idents_u155(ident_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(m_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, qualifiedLookUp__lookups_u5229)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ flags_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL oldNimErrFin27_;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL oldNimErrFin120_;
NIM_BOOL oldNimErrFin70_;
NIM_BOOL oldNimErrFin63_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53):
	{
		tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
		NIM_BOOL amb_1;
		ident_1 = NIM_NIL;
		amb_1 = NIM_FALSE;
		ident_1 = considerQuotedIdent__lookups_u31(c_p0, n_p1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		{
			if (!((flags_p2 &((NU8)1<<((NU)((((tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ)2)))&7U)))!=0)) goto LA5_;
			result = searchInScopes__lookups_u2425(c_p0, ident_1, (&amb_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			{
				tySequence__ZCZaCk14bTmSb6LMW9aWPVA candidates_1;
				if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA9_;
				candidates_1.len = 0; candidates_1.p = NIM_NIL;
				candidates_1 = allPureEnumFields__lookups_u709(c_p0, ident_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
				{
					NI T14_;
					NI T17_;
					T14_ = candidates_1.len;
					if (!(((NI)0) < T14_)) goto LA15_;
					eqcopy___ast_u4577(&result, candidates_1.p->data[((NI)0)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					T17_ = candidates_1.len;
					amb_1 = (((NI)1) < T17_);
					{
						NIM_BOOL T20_;
						T20_ = (NIM_BOOL)0;
						T20_ = amb_1;
						if (!(T20_)) goto LA21_;
						T20_ = ((flags_p2 &((NU8)1<<((NU)((((tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ)0)))&7U)))!=0);
LA21_: ;
						if (!T20_) goto LA22_;
						errorUseQualifier__lookups_u5100(c_p0, (*n_p1).info, candidates_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					}
LA22_: ;
				}
LA15_: ;
				{
					LA11_:;
				}
				{
					oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4848(candidates_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					*nimErr_ = oldNimErrFin11_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA9_: ;
		}
		goto LA3_;
LA5_: ;
		{
			tySequence__ZCZaCk14bTmSb6LMW9aWPVA candidates_2;
			candidates_2.len = 0; candidates_2.p = NIM_NIL;
			candidates_2 = lookUpCandidates__lookups_u5193(c_p0, ident_1, 16777151, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			{
				NI T30_;
				NI T33_;
				T30_ = candidates_2.len;
				if (!(((NI)0) < T30_)) goto LA31_;
				eqcopy___ast_u4577(&result, candidates_2.p->data[((NI)0)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				T33_ = candidates_2.len;
				amb_1 = (((NI)1) < T33_);
				{
					NIM_BOOL T36_;
					T36_ = (NIM_BOOL)0;
					T36_ = amb_1;
					if (!(T36_)) goto LA37_;
					T36_ = ((flags_p2 &((NU8)1<<((NU)((((tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ)0)))&7U)))!=0);
LA37_: ;
					if (!T36_) goto LA38_;
					errorUseQualifier__lookups_u5100(c_p0, (*n_p1).info, candidates_2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				}
LA38_: ;
			}
			goto LA28_;
LA31_: ;
			{
				result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
			}
LA28_: ;
			{
				LA27_:;
			}
			{
				oldNimErrFin27_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u4848(candidates_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				*nimErr_ = oldNimErrFin27_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
LA3_: ;
		{
			NIM_BOOL T45_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T49_;
			T45_ = (NIM_BOOL)0;
			T45_ = (result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
			if (!(T45_)) goto LA46_;
			T45_ = ((flags_p2 &((NU8)1<<((NU)((((tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ)1)))&7U)))!=0);
LA46_: ;
			if (!T45_) goto LA47_;
			T49_ = NIM_NIL;
			T49_ = errorUndeclaredIdentifierHint__lookups_u5151(c_p0, ident_1, (*n_p1).info);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T49_); goto LA2_;}
			eqsink___ast_u4583(&result, T49_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		goto LA43_;
LA47_: ;
		{
			NIM_BOOL T51_;
			NIM_BOOL T52_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T57_;
			T51_ = (NIM_BOOL)0;
			T52_ = (NIM_BOOL)0;
			T52_ = ((flags_p2 &((NU8)1<<((NU)((((tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ)0)))&7U)))!=0);
			if (!(T52_)) goto LA53_;
			T52_ = !((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA53_: ;
			T51_ = T52_;
			if (!(T51_)) goto LA54_;
			T51_ = amb_1;
LA54_: ;
			if (!T51_) goto LA55_;
			T57_ = NIM_NIL;
			T57_ = errorUseQualifier__lookups_u5040(c_p0, (*n_p1).info, result, (&amb_1));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T57_); goto LA2_;}
			eqsink___ast_u4583(&result, T57_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		goto LA43_;
LA55_: ;
LA43_: ;
		(*c_p0).isAmbiguous = amb_1;
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___idents_u155(ident_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___ast_u4577(&result, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165):
	{
		result = qualifiedLookUp__lookups_u5229(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], flags_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_1;
		m_1 = NIM_NIL;
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		m_1 = qualifiedLookUp__lookups_u5229(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], ((flags_p2 & 2) | 4));
		if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		{
			NIM_BOOL T66_;
			tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_2;
			T66_ = (NIM_BOOL)0;
			T66_ = !((m_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
			if (!(T66_)) goto LA67_;
			T66_ = ((*m_1).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
LA67_: ;
			if (!T66_) goto LA68_;
			ident_2 = NIM_NIL;
			ident_2 = ((tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*) NIM_NIL);
			{
				tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T75_;
				if (!((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53))) goto LA73_;
				T75_ = NIM_NIL;
				T75_ = considerQuotedIdent__lookups_u31(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___idents_u155(T75_); goto LA70_;}
				eqsink___idents_u164(&ident_2, T75_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
			}
			goto LA71_;
LA73_: ;
			{
				tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T77_;
				T77_ = NIM_NIL;
				T77_ = getPIdent__ast_u2825((*n_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___idents_u155(T77_); goto LA70_;}
				eqsink___idents_u164(&ident_2, T77_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
			}
LA71_: ;
			{
				NIM_BOOL T80_;
				T80_ = (NIM_BOOL)0;
				T80_ = eqeq___idents_u366(ident_2, ((tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*) NIM_NIL));
				if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
				if (!!(T80_)) goto LA81_;
				{
					tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti_1;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T87_;
					if (!(m_1 == (*c_p0).module)) goto LA85_;
					nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
					colontmpD_ = NIM_NIL;
					nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
					T87_ = NIM_NIL;
					T87_ = initIdentIter__astalgo_u2768((&ti_1), (*(*c_p0).topLevelScope).symbols, ident_2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T87_); goto LA70_;}
					eqsink___ast_u4583(&result, T87_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
					{
						NIM_BOOL T90_;
						T90_ = (NIM_BOOL)0;
						T90_ = !((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
						if (!(T90_)) goto LA91_;
						colontmpD_ = nextIdentIter__astalgo_u2744((&ti_1), (*(*c_p0).topLevelScope).symbols);
						if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
						T90_ = !((colontmpD_ == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
LA91_: ;
						if (!T90_) goto LA92_;
						(*c_p0).isAmbiguous = NIM_TRUE;
					}
LA92_: ;
					eqdestroy___ast_u4574(colontmpD_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
					eqdestroy___modulegraphs_u3391(ti_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
				}
				goto LA83_;
LA85_: ;
				{
					tySequence__qwqHTkRvwhrRyENtudHQ7g colontmpD__2;
					NIM_BOOL amb_2;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					amb_2 = NIM_FALSE;
					{
						NI T98_;
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T101_;
						colontmpD__2 = getOrDefault__lookups_u5391((*c_p0).importModuleLookup, (*(*m_1).name).id);
						if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
						T98_ = colontmpD__2.len;
						if (!(((NI)1) < T98_)) goto LA99_;
						T101_ = NIM_NIL;
						T101_ = errorUseQualifier__lookups_u5040(c_p0, (*n_p1).info, m_1, (&amb_2));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T101_); goto LA95_;}
						eqsink___ast_u4583(&result, T101_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
					}
					goto LA96_;
LA99_: ;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T103_;
						T103_ = NIM_NIL;
						T103_ = someSymAmb__modulegraphs_u3342((*c_p0).graph, m_1, ident_2, (&amb_2));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T103_); goto LA95_;}
						eqsink___ast_u4583(&result, T103_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA95_;
						{
							if (!amb_2) goto LA106_;
							(*c_p0).isAmbiguous = NIM_TRUE;
						}
LA106_: ;
					}
LA96_: ;
					{
						LA95_:;
					}
					{
						eqdestroy___pureZosproc_u474(colontmpD__2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
				}
LA83_: ;
				{
					NIM_BOOL T112_;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T116_;
					T112_ = (NIM_BOOL)0;
					T112_ = (result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
					if (!(T112_)) goto LA113_;
					T112_ = ((flags_p2 &((NU8)1<<((NU)((((tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ)1)))&7U)))!=0);
LA113_: ;
					if (!T112_) goto LA114_;
					T116_ = NIM_NIL;
					T116_ = errorUndeclaredIdentifierHint__lookups_u5151(c_p0, ident_2, (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).info);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T116_); goto LA70_;}
					eqsink___ast_u4583(&result, T116_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
				}
LA114_: ;
			}
			goto LA78_;
LA81_: ;
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__4;
				if (!((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA118_;
				colontmpD__3 = NIM_NIL;
				colontmpD__4 = NIM_NIL;
				eqcopy___ast_u4577(&result, (*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
				if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
				{
					NIM_BOOL T123_;
					NIM_BOOL T124_;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T129_;
					T123_ = (NIM_BOOL)0;
					T124_ = (NIM_BOOL)0;
					colontmpD__3 = owner__ast_u6254(result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
					T124_ = !((colontmpD__3 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
					if (!(T124_)) goto LA125_;
					colontmpD__4 = owner__ast_u6254(result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
					T124_ = !((colontmpD__4 == m_1));
LA125_: ;
					T123_ = T124_;
					if (!(T123_)) goto LA126_;
					T123_ = ((flags_p2 &((NU8)1<<((NU)((((tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ)1)))&7U)))!=0);
LA126_: ;
					if (!T123_) goto LA127_;
					T129_ = NIM_NIL;
					T129_ = errorUndeclaredIdentifierHint__lookups_u5151(c_p0, (*result).name, (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).info);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T129_); goto LA120_;}
					eqsink___ast_u4583(&result, T129_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA120_;
				}
LA127_: ;
				{
					LA120_:;
				}
				{
					oldNimErrFin120_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u4574(colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
					eqdestroy___ast_u4574(colontmpD__3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
					*nimErr_ = oldNimErrFin120_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
			}
			goto LA78_;
LA118_: ;
			{
				NIM_BOOL T133_;
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				NimStringV2 T138_;
				tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg T139_;
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T140_;
				T133_ = (NIM_BOOL)0;
				T133_ = ((flags_p2 &((NU8)1<<((NU)((((tyEnum_TLookupFlag__l9bvZMRwOrEZawdhQi29c5PQ)1)))&7U)))!=0);
				if (!(T133_)) goto LA134_;
				T133_ = !(((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57) || (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56)));
LA134_: ;
				if (!T133_) goto LA135_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				T138_.len = 0; T138_.p = NIM_NIL;
				T139_ = 0;
				colontmpD__5 = renderTree__renderer_u59((*n_p1)._kind_6.sons.p->data[((NI)1)], T139_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
				T138_ = rawNewString(colontmpD__5.len + 30);
appendString((&T138_), TM__3uzV357076dKeFHtnMZm2A_101);
appendString((&T138_), colontmpD__5);
				colontmpD__6 = T138_;
				liMessage__msgs_u1227((*(*c_p0).graph).config, (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__6, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_102), NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
				T140_ = NIM_NIL;
				T140_ = errorSym__lookups_u2620(c_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T140_); goto LA137_;}
				eqsink___ast_u4583(&result, T140_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA137_;
				{
					LA137_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA70_;
			}
			goto LA78_;
LA135_: ;
LA78_: ;
			{
				LA70_:;
			}
			{
				oldNimErrFin70_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___idents_u155(ident_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				*nimErr_ = oldNimErrFin70_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
		}
LA68_: ;
		{
			LA63_:;
		}
		{
			oldNimErrFin63_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(m_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin63_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, initOverloadIter__lookups_u5784)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA T5_;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin41_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)165))) goto LA3_;
		result = initOverloadIter__lookups_u5784(o_p0, c_p1, (*n_p2)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA3_: ;
	(*o_p0).importIdx = ((NI)-1);
	nimZeroMem((void*)(&T5_), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	initIntSet__pureZcollectionsZintsets_u598((&T5_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___pureZcollectionsZintsets_u236((&(*o_p0).marked), (&T5_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	switch ((*n_p2).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53):
	{
		tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
		tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_1;
		ident_1 = NIM_NIL;
		scope_1 = NIM_NIL;
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		ident_1 = considerQuotedIdent__lookups_u31(c_p1, n_p2, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		eqcopy___lookups_u77(&scope_1, (*c_p1).currentScope);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		(*o_p0).mode = ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)1);
		{
			while (1) {
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T10_;
				T10_ = NIM_NIL;
				T10_ = initIdentIter__astalgo_u2768((&(*o_p0).it), (*scope_1).symbols, ident_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T10_); goto LA7_;}
				eqsink___ast_u4583(&result, T10_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
				{
					if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA13_;
					eqsink___lookups_u83(&(*o_p0).currentScope, scope_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					eqwasMoved___lookups_u71(&scope_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					goto LA8;
				}
				goto LA11_;
LA13_: ;
				{
					eqcopy___lookups_u77(&scope_1, (*scope_1).parent);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					{
						if (!(scope_1 == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL))) goto LA18_;
						{
							NI i_1;
							NI colontmp_;
							NI T21_;
							NI res_1;
							i_1 = (NI)0;
							colontmp_ = (NI)0;
							T21_ = ((*c_p1).imports.len-1);
							colontmp_ = T21_;
							res_1 = ((NI)0);
							{
								while (1) {
									tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* T24_;
									tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T25_;
									if (!(res_1 <= colontmp_)) goto LA23;
									i_1 = ((NI) (res_1));
									T24_ = (tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ*)0;
									T24_ = (&(*o_p0).mit);
									T25_ = NIM_NIL;
									T25_ = initIdentIter__lookups_u135(T24_, (&(*o_p0).marked), (&(*c_p1).imports.p->data[i_1]), ident_1, (*c_p1).graph);
									if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T25_); goto LA7_;}
									eqsink___ast_u4583(&result, T25_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
									{
										if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA28_;
										eqsink___lookups_u83(&(*o_p0).currentScope, ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL));
										if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
										(*o_p0).importIdx = i_1;
										eqdestroy___lookups_u74(scope_1);
										if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
										eqdestroy___idents_u155(ident_1);
										if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
										goto BeforeRet_;
									}
LA28_: ;
									res_1 += ((NI)1);
								} LA23: ;
							}
						}
						result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
						eqdestroy___lookups_u74(scope_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						eqdestroy___idents_u155(ident_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA18_: ;
				}
LA11_: ;
			}
		} LA8: ;
		{
			LA7_:;
		}
		{
			oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___lookups_u74(scope_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___idents_u155(ident_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin7_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___ast_u4577(&result, (*n_p2)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*o_p0).mode = ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)0);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T34_;
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		(*o_p0).mode = ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)3);
		T34_ = NIM_NIL;
		T34_ = qualifiedLookUp__lookups_u5229(c_p1, (*n_p2)._kind_6.sons.p->data[((NI)0)], 6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T34_); goto BeforeRet_;}
		eqsink___ast_u4583(&(*o_p0).m, T34_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T37_;
			tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_2;
			T37_ = (NIM_BOOL)0;
			T37_ = !(((*o_p0).m == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
			if (!(T37_)) goto LA38_;
			T37_ = ((*(*o_p0).m).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6));
LA38_: ;
			if (!T37_) goto LA39_;
			ident_2 = NIM_NIL;
			ident_2 = ((tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*) NIM_NIL);
			{
				if (!((*(*n_p2)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2))) goto LA44_;
				eqcopy___idents_u158(&ident_2, (*(*n_p2)._kind_6.sons.p->data[((NI)1)])._kind_5.ident);
				if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
			}
			goto LA42_;
LA44_: ;
			{
				tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T49_;
				if (!((*(*n_p2)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53))) goto LA47_;
				T49_ = NIM_NIL;
				T49_ = considerQuotedIdent__lookups_u31(c_p1, (*n_p2)._kind_6.sons.p->data[((NI)1)], n_p2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___idents_u155(T49_); goto LA41_;}
				eqsink___idents_u164(&ident_2, T49_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
			}
			goto LA42_;
LA47_: ;
LA42_: ;
			{
				NIM_BOOL T52_;
				T52_ = (NIM_BOOL)0;
				T52_ = eqeq___idents_u366(ident_2, ((tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*) NIM_NIL));
				if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
				if (!!(T52_)) goto LA53_;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T59_;
					if (!((*o_p0).m == (*c_p1).module)) goto LA57_;
					T59_ = NIM_NIL;
					T59_ = initIdentIter__astalgo_u2768((&(*o_p0).it), (*(*c_p1).topLevelScope).symbols, ident_2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T59_); goto LA41_;}
					eqsink___ast_u4583(&result, T59_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
					(*o_p0).mode = ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)2);
				}
				goto LA55_;
LA57_: ;
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T61_;
					T61_ = NIM_NIL;
					T61_ = initModuleIter__modulegraphs_u3177((&(*o_p0).mit), (*c_p1).graph, (*o_p0).m, ident_2);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T61_); goto LA41_;}
					eqsink___ast_u4583(&result, T61_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
				}
LA55_: ;
			}
			goto LA50_;
LA53_: ;
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T63_;
				noidentError__lookups_u22((*(*c_p1).graph).config, (*n_p2)._kind_6.sons.p->data[((NI)1)], n_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
				T63_ = NIM_NIL;
				T63_ = errorSym__lookups_u2620(c_p1, (*n_p2)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T63_); goto LA41_;}
				eqsink___ast_u4583(&result, T63_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA41_;
			}
LA50_: ;
			{
				LA41_:;
			}
			{
				oldNimErrFin41_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___idents_u155(ident_2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin41_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA39_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)56):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57):
	{
		tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA T72_;
		tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym225__1;
		(*o_p0).mode = ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)4);
		{
			if (!((*(*n_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA69_;
			eqcopy___ast_u4577(&result, (*(*n_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA67_;
LA69_: ;
		{
			(*o_p0).mode = ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)0);
			result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
			goto BeforeRet_;
		}
LA67_: ;
		(*o_p0).symChoiceIndex = ((NI)1);
		nimZeroMem((void*)(&T72_), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
		initIntSet__pureZcollectionsZintsets_u598((&T72_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqsink___pureZcollectionsZintsets_u236((&(*o_p0).marked), (&T72_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		xX60gensym225__1 = (*result).itemId;
		incl__pureZcollectionsZintsets_u366((&(*o_p0).marked), (NI)((NI)((NU64)(((NI) (xX60gensym225__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym225__1.item))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextOverloadIterImports__lookups_u5937)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NI idx_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	idx_1 = (NI)((*o_p0).importIdx + ((NI)1));
	T1_ = (*c_p1).imports.len;
	(*o_p0).importIdx = T1_;
	{
		while (1) {
			NI T4_;
			tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* T5_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T6_;
			T4_ = (*c_p1).imports.len;
			if (!(idx_1 < T4_)) goto LA3;
			T5_ = (tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ*)0;
			T5_ = (&(*o_p0).mit);
			T6_ = NIM_NIL;
			T6_ = initIdentIter__lookups_u135(T5_, (&(*o_p0).marked), (&(*c_p1).imports.p->data[idx_1]), (*o_p0).it.name, (*c_p1).graph);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T6_); goto BeforeRet_;}
			eqsink___ast_u4583(&result, T6_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA9_;
				(*o_p0).importIdx = idx_1;
				goto LA2;
			}
LA9_: ;
			idx_1 += ((NI)1);
		} LA3: ;
	} LA2: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, symChoiceExtension__lookups_u5965)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	{
		while (1) {
			NI T3_;
			tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* T4_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T5_;
			T3_ = (*c_p1).imports.len;
			if (!((*o_p0).importIdx < T3_)) goto LA2;
			T4_ = (tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ*)0;
			T4_ = (&(*o_p0).mit);
			T5_ = NIM_NIL;
			T5_ = initIdentIter__lookups_u135(T4_, (&(*o_p0).marked), (&(*c_p1).imports.p->data[(*o_p0).importIdx]), (*o_p0).it.name, (*c_p1).graph);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T5_); goto BeforeRet_;}
			eqsink___ast_u4583(&result, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA8_;
				goto BeforeRet_;
			}
LA8_: ;
			(*o_p0).importIdx += ((NI)1);
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, nextOverloadIter__lookups_u5989)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0, tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	switch ((*o_p0).mode) {
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)0):
	{
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	}
	break;
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)1):
	{
		{
			if (!!(((*o_p0).currentScope == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA5_;
			result = nextIdentIter__astalgo_u2744((&(*o_p0).it), (*(*o_p0).currentScope).symbols);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				while (1) {
					if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA8;
					eqcopy___lookups_u77(&(*o_p0).currentScope, (*(*o_p0).currentScope).parent);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T13_;
						if (!!(((*o_p0).currentScope == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA11_;
						T13_ = NIM_NIL;
						T13_ = initIdentIter__astalgo_u2768((&(*o_p0).it), (*(*o_p0).currentScope).symbols, (*o_p0).it.name);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T13_); goto BeforeRet_;}
						eqsink___ast_u4583(&result, T13_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
					goto LA9_;
LA11_: ;
					{
						(*o_p0).importIdx = ((NI)0);
						{
							NI T17_;
							tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* T20_;
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T21_;
							T17_ = (*c_p1).imports.len;
							if (!(((NI)0) < T17_)) goto LA18_;
							T20_ = (tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ*)0;
							T20_ = (&(*o_p0).mit);
							T21_ = NIM_NIL;
							T21_ = initIdentIter__lookups_u135(T20_, (&(*o_p0).marked), (&(*c_p1).imports.p->data[(*o_p0).importIdx]), (*o_p0).it.name, (*c_p1).graph);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T21_); goto BeforeRet_;}
							eqsink___ast_u4583(&result, T21_);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							{
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T26_;
								if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA24_;
								T26_ = NIM_NIL;
								T26_ = nextOverloadIterImports__lookups_u5937(o_p0, c_p1, n_p2);
								if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T26_); goto BeforeRet_;}
								eqsink___ast_u4583(&result, T26_);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							}
LA24_: ;
						}
LA18_: ;
						goto LA7;
					}
LA9_: ;
				} LA8: ;
			} LA7: ;
		}
		goto LA3_;
LA5_: ;
		{
			NI T28_;
			tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* T31_;
			T28_ = (*c_p1).imports.len;
			if (!((*o_p0).importIdx < T28_)) goto LA29_;
			T31_ = (tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ*)0;
			T31_ = (&(*o_p0).mit);
			result = nextIdentIter__lookups_u350(T31_, (&(*o_p0).marked), (&(*c_p1).imports.p->data[(*o_p0).importIdx]), (*c_p1).graph);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T36_;
				if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA34_;
				T36_ = NIM_NIL;
				T36_ = nextOverloadIterImports__lookups_u5937(o_p0, c_p1, n_p2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T36_); goto BeforeRet_;}
				eqsink___ast_u4583(&result, T36_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA34_: ;
		}
		goto LA3_;
LA29_: ;
		{
			result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		}
LA3_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)2):
	{
		result = nextIdentIter__astalgo_u2744((&(*o_p0).it), (*(*c_p1).topLevelScope).symbols);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)3):
	{
		result = nextModuleIter__modulegraphs_u3222((&(*o_p0).mit), (*c_p1).graph);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)4):
	{
		{
			NI T43_;
			tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym240__1;
			T43_ = (NI)0;
			T43_ = len__ast_u3190(n_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!((*o_p0).symChoiceIndex < T43_)) goto LA44_;
			eqcopy___ast_u4577(&result, (*(*n_p2)._kind_6.sons.p->data[(*o_p0).symChoiceIndex])._kind_4.sym);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			xX60gensym240__1 = (*result).itemId;
			incl__pureZcollectionsZintsets_u366((&(*o_p0).marked), (NI)((NI)((NU64)(((NI) (xX60gensym240__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym240__1.item))));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			(*o_p0).symChoiceIndex += ((NI)1);
		}
		goto LA41_;
LA44_: ;
		{
			if (!((*n_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)57))) goto LA47_;
			(*o_p0).mode = ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)5);
			eqcopy___lookups_u77(&(*o_p0).currentScope, (*c_p1).currentScope);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = firstIdentExcluding__astalgo_u3113((&(*o_p0).it), (*(*o_p0).currentScope).symbols, (*(*(*n_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name, (&(*o_p0).marked));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				while (1) {
					if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA50;
					eqcopy___lookups_u77(&(*o_p0).currentScope, (*(*o_p0).currentScope).parent);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T55_;
						if (!!(((*o_p0).currentScope == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA53_;
						T55_ = NIM_NIL;
						T55_ = firstIdentExcluding__astalgo_u3113((&(*o_p0).it), (*(*o_p0).currentScope).symbols, (*(*(*n_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name, (&(*o_p0).marked));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T55_); goto BeforeRet_;}
						eqsink___ast_u4583(&result, T55_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
					goto LA51_;
LA53_: ;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T57_;
						(*o_p0).importIdx = ((NI)0);
						T57_ = NIM_NIL;
						T57_ = symChoiceExtension__lookups_u5965(o_p0, c_p1, n_p2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T57_); goto BeforeRet_;}
						eqsink___ast_u4583(&result, T57_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto LA49;
					}
LA51_: ;
				} LA50: ;
			} LA49: ;
			{
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym246__1;
				if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA60_;
				xX60gensym246__1 = (*result).itemId;
				incl__pureZcollectionsZintsets_u366((&(*o_p0).marked), (NI)((NI)((NU64)(((NI) (xX60gensym246__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym246__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA60_: ;
		}
		goto LA41_;
LA47_: ;
		{
			result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		}
LA41_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)5):
	{
		{
			if (!!(((*o_p0).currentScope == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA66_;
			result = nextIdentExcluding__astalgo_u2773((&(*o_p0).it), (*(*o_p0).currentScope).symbols, (&(*o_p0).marked));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				while (1) {
					if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA69;
					eqcopy___lookups_u77(&(*o_p0).currentScope, (*(*o_p0).currentScope).parent);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T74_;
						if (!!(((*o_p0).currentScope == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA72_;
						T74_ = NIM_NIL;
						T74_ = firstIdentExcluding__astalgo_u3113((&(*o_p0).it), (*(*o_p0).currentScope).symbols, (*(*(*n_p2)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name, (&(*o_p0).marked));
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T74_); goto BeforeRet_;}
						eqsink___ast_u4583(&result, T74_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					}
					goto LA70_;
LA72_: ;
					{
						tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T76_;
						(*o_p0).importIdx = ((NI)0);
						T76_ = NIM_NIL;
						T76_ = symChoiceExtension__lookups_u5965(o_p0, c_p1, n_p2);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T76_); goto BeforeRet_;}
						eqsink___ast_u4583(&result, T76_);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto LA68;
					}
LA70_: ;
				} LA69: ;
			} LA68: ;
			{
				tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA xX60gensym252__1;
				if (!!((result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA79_;
				xX60gensym252__1 = (*result).itemId;
				incl__pureZcollectionsZintsets_u366((&(*o_p0).marked), (NI)((NI)((NU64)(((NI) (xX60gensym252__1.module))) << (NU64)(((NI)24) & (64 - 1))) + ((NI) (xX60gensym252__1.item))));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA79_: ;
		}
		goto LA64_;
LA66_: ;
		{
			NI T82_;
			tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ* T85_;
			T82_ = (*c_p1).imports.len;
			if (!((*o_p0).importIdx < T82_)) goto LA83_;
			T85_ = (tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ*)0;
			T85_ = (&(*o_p0).mit);
			result = nextIdentIter__lookups_u350(T85_, (&(*o_p0).marked), (&(*c_p1).imports.p->data[(*o_p0).importIdx]), (*c_p1).graph);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			{
				tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T90_;
				if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA88_;
				(*o_p0).importIdx += ((NI)1);
				T90_ = NIM_NIL;
				T90_ = symChoiceExtension__lookups_u5965(o_p0, c_p1, n_p2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T90_); goto BeforeRet_;}
				eqsink___ast_u4583(&result, T90_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA88_: ;
		}
		goto LA64_;
LA83_: ;
		{
			result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		}
LA64_: ;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u6249)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* dest_p0) {
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).marked.data);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).marked.head);
		if (!T3_) goto LA4_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).marked.head)));
		nimRawDispose((*dest_p0).marked.head, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).currentScope);
		if (!T8_) goto LA9_;
		eqdestroy___semdata_u2873((&(*(*dest_p0).currentScope)));
		nimRawDispose((*dest_p0).currentScope, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).m);
		if (!T13_) goto LA14_;
		eqdestroy___ast_u3469((&(*(*dest_p0).m)));
		nimRawDispose((*dest_p0).m, ((NI)8));
	}
LA14_: ;
	eqdestroy___icZic_u3941((*dest_p0).mit.rodIt.values);
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLast((*dest_p0).mit.rodIt.decoder.cache);
		if (!T18_) goto LA19_;
		eqdestroy___idents_u274((&(*(*dest_p0).mit.rodIt.decoder.cache)));
		nimRawDispose((*dest_p0).mit.rodIt.decoder.cache, ((NI)8));
	}
LA19_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).mit.rodIt.decoder.config);
		if (!T23_) goto LA24_;
		eqdestroy___options_u1751((&(*(*dest_p0).mit.rodIt.decoder.config)));
		nimRawDispose((*dest_p0).mit.rodIt.decoder.config, ((NI)8));
	}
LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLastDyn((*dest_p0).mit.ti.name);
		if (!T28_) goto LA29_;
		eqdestroy___idents_u173((&(*(*dest_p0).mit.ti.name)));
		nimRawDispose((*dest_p0).mit.ti.name, ((NI)8));
	}
LA29_: ;
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = nimDecRefIsLastDyn((*dest_p0).it.name);
		if (!T33_) goto LA34_;
		eqdestroy___idents_u173((&(*(*dest_p0).it.name)));
		nimRawDispose((*dest_p0).it.name, ((NI)8));
	}
LA34_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, lookUp__lookups_u5157)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	NIM_BOOL amb_1;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	amb_1 = NIM_FALSE;
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		result = searchInScopes__lookups_u2425(c_p0, (*n_p1)._kind_5.ident, (&amb_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T6_;
			if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA4_;
			T6_ = NIM_NIL;
			T6_ = errorUndeclaredIdentifierHint__lookups_u5151(c_p0, (*n_p1)._kind_5.ident, (*n_p1).info);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T6_); goto BeforeRet_;}
			eqsink___ast_u4583(&result, T6_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA4_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___ast_u4577(&result, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)53):
	{
		tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
		ident_1 = NIM_NIL;
		ident_1 = considerQuotedIdent__lookups_u31(c_p0, n_p1, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		result = searchInScopes__lookups_u2425(c_p0, ident_1, (&amb_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T14_;
			if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA12_;
			T14_ = NIM_NIL;
			T14_ = errorUndeclaredIdentifierHint__lookups_u5151(c_p0, ident_1, (*n_p1).info);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T14_); goto LA9_;}
			eqsink___ast_u4583(&result, T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		}
LA12_: ;
		{
			LA9_:;
		}
		{
			oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___idents_u155(ident_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin9_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		internalErrorImpl__msgs_u1598((*(*c_p0).graph).config, (*n_p1).info, TM__3uzV357076dKeFHtnMZm2A_106, (&TM__3uzV357076dKeFHtnMZm2A_107));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
		goto BeforeRet_;
	}
	break;
	}
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T22_;
		if (!amb_1) goto LA20_;
		T22_ = NIM_NIL;
		T22_ = errorUseQualifier__lookups_u5040(c_p0, (*n_p1).info, result, (&amb_1));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T22_); goto BeforeRet_;}
		eqsink___ast_u4583(&result, T22_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA20_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addPrelimDecl__lookups_u3792)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	colontmpD_ = addUniqueSym__lookups_u61((*c_p0).currentScope, sym_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(void)(colontmpD_);
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, pickSym__lookups_u6216)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kinds_p2, tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags_p3) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w o_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* a_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	nimZeroMem((void*)(&o_1), sizeof(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w));
	a_1 = NIM_NIL;
	result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
	nimZeroMem((void*)(&o_1), sizeof(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w));
	a_1 = initOverloadIter__lookups_u5784((&o_1), c_p0, n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		while (1) {
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T15_;
			if (!!((a_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA3;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = ((kinds_p2 &((NU32)1<<((NU)(((*a_1).kind))&31U)))!=0);
				if (!(T6_)) goto LA7_;
				T6_ = ((flags_p3 & ~ (*a_1).flags)==0);
LA7_: ;
				if (!T6_) goto LA8_;
				{
					if (!(result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL))) goto LA12_;
					eqsink___ast_u4583(&result, a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqwasMoved___ast_u4571(&a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				goto LA10_;
LA12_: ;
				{
					result = ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL);
					eqdestroy___ast_u4574(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___lookups_u6249((&o_1));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA10_: ;
			}
LA8_: ;
			T15_ = NIM_NIL;
			T15_ = nextOverloadIter__lookups_u5989((&o_1), c_p0, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T15_); goto LA1_;}
			eqsink___ast_u4583(&a_1, T15_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		} LA3: ;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___lookups_u6249((&o_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, ambiguousIdentifierMsg__lookups_u5104)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* choices_p0, NI indent_p1) {
	NimStringV2 result;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA candidates_1;
	NimStringV2 prefix_1;
	NI T2_;
	NimStringV2 T3_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	candidates_1.len = 0; candidates_1.p = NIM_NIL;
	prefix_1.len = 0; prefix_1.p = NIM_NIL;
	T2_ = (NI)0;
	T2_ = len__ast_u3190(choices_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	candidates_1 = newSeq__lookups_u5124((T2_));
	T3_.len = 0; T3_.p = NIM_NIL;
	{
		if (!!(((*(*(*choices_p0)._kind_6.sons.p->data[((NI)0)]).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25)))) goto LA6_;
		prefix_1 = TM__3uzV357076dKeFHtnMZm2A_108;
	}
	goto LA4_;
LA6_: ;
	{
		prefix_1 = TM__3uzV357076dKeFHtnMZm2A_110;
	}
LA4_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
		NI i_1;
		n_1 = NIM_NIL;
		i_1 = (NI)0;
		{
			NI i_2;
			NI colontmp_;
			NI i_3;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(choices_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_3 = ((NI)0);
			{
				while (1) {
					if (!(i_3 < colontmp_)) goto LA12;
					i_2 = i_3;
					i_1 = i_2;
					eqcopy___ast_u3255(&n_1, (*choices_p0)._kind_6.sons.p->data[i_2]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqcopy___ast_u4577(&candidates_1.p->data[i_1], (*n_1)._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					i_3 += ((NI)1);
				} LA12: ;
			}
		}
		eqdestroy___ast_u3252(n_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	result = ambiguousIdentifierMsg__lookups_u5072(candidates_1, prefix_1, indent_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4848(candidates_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, lastOverloadScope__lookups_u5931)(tyObject_TOverloadIter__fS1pvm52pQY9bUqdmxGpq0w* o_p0) {
	NI result;
	switch ((*o_p0).mode) {
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)1):
	{
		NI T2_;
		T2_ = (NI)0;
		{
			if (!(((NI)0) <= (*o_p0).importIdx)) goto LA5_;
			result = ((NI)0);
		}
		goto LA3_;
LA5_: ;
		{
			if (!((*o_p0).currentScope == 0)) goto LA8_;
			result = ((NI)-1);
		}
		goto LA3_;
LA8_: ;
		{
			result = (*(*o_p0).currentScope).depthLevel;
		}
LA3_: ;
	}
	break;
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)2):
	{
		result = ((NI)1);
	}
	break;
	case ((tyEnum_TOverloadIterMode__82mZgW9axskN9bBh3QmzqR4A)3):
	{
		result = ((NI)0);
	}
	break;
	default:
	{
		result = ((NI)-1);
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, searchScopesAll__lookups_u2515)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = searchScopes__lookups_u2487(c_p0, s_p1, filter_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI T3_;
		T3_ = result.len;
		if (!(T3_ == ((NI)0))) goto LA4_;
		searchImportsAll__lookups_u2468(c_p0, s_p1, filter_p2, (&result));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isAmbiguous__lookups_u2573)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1, tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q filter_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** sym_p3) {
	NIM_BOOL result;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA marked_1;
NIM_BOOL oldNimErrFin7_;
NIM_BOOL oldNimErrFin4_;
	NIM_BOOL importsHaveCandidate_1;
NIM_BOOL oldNimErrFin33_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	nimZeroMem((void*)(&marked_1), sizeof(tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA));
	result = NIM_FALSE;
	{
		{
			tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_1;
			tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* current_1;
			scope_1 = NIM_NIL;
			current_1 = NIM_NIL;
			current_1 = (*c_p0).currentScope;
			{
				while (1) {
					tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag ti_1;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_1;
					NIM_BOOL scopeHasCandidate_1;
					if (!!((current_1 == ((tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*) NIM_NIL)))) goto LA6;
					nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
					candidate_1 = NIM_NIL;
					eqcopy___lookups_u77(&scope_1, current_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					nimZeroMem((void*)(&ti_1), sizeof(tyObject_TIdentIter__y9aVr7t8eNqaJxlweeGSP9ag));
					candidate_1 = initIdentIter__astalgo_u2768((&ti_1), (*scope_1).symbols, s_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
					scopeHasCandidate_1 = NIM_FALSE;
					{
						while (1) {
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T19_;
							if (!!((candidate_1 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA9;
							{
								if (!((filter_p2 &((NU32)1<<((NU)(((*candidate_1).kind))&31U)))!=0)) goto LA12_;
								{
									if (!scopeHasCandidate_1) goto LA16_;
									result = NIM_TRUE;
									eqdestroy___ast_u4574(candidate_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
									eqdestroy___modulegraphs_u3391(ti_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
									eqdestroy___lookups_u74(scope_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
									if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
									goto BeforeRet_;
								}
								goto LA14_;
LA16_: ;
								{
									scopeHasCandidate_1 = NIM_TRUE;
									eqsink___ast_u4583(&(*sym_p3), candidate_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
									eqwasMoved___ast_u4571(&candidate_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
								}
LA14_: ;
							}
LA12_: ;
							T19_ = NIM_NIL;
							T19_ = nextIdentIter__astalgo_u2744((&ti_1), (*scope_1).symbols);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T19_); goto LA7_;}
							eqsink___ast_u4583(&candidate_1, T19_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
						} LA9: ;
					}
					{
						if (!scopeHasCandidate_1) goto LA22_;
						result = NIM_FALSE;
						eqdestroy___ast_u4574(candidate_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						eqdestroy___modulegraphs_u3391(ti_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						eqdestroy___lookups_u74(scope_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA22_: ;
					current_1 = (*current_1).parent;
					{
						LA7_:;
					}
					{
						oldNimErrFin7_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(candidate_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						eqdestroy___modulegraphs_u3391(ti_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						*nimErr_ = oldNimErrFin7_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				} LA6: ;
			}
			{
				LA4_:;
			}
			{
				oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___lookups_u74(scope_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin4_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
	importsHaveCandidate_1 = NIM_FALSE;
	initIntSet__pureZcollectionsZintsets_u598((&marked_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw* im_1;
		NI i_1;
		NI L_1;
		NI T29_;
		im_1 = (tyObject_ImportedModule__NhRLdOPUbh9bmcDLjImMKWw*)0;
		i_1 = ((NI)0);
		T29_ = (*c_p0).imports.len;
		L_1 = T29_;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA31;
				im_1 = (&(*c_p0).imports.p->data[i_1]);
				{
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
					tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ ti_2;
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* candidate_2;
					s_2 = NIM_NIL;
					nimZeroMem((void*)(&ti_2), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
					candidate_2 = NIM_NIL;
					s_2 = 0;
					nimZeroMem((void*)(&ti_2), sizeof(tyObject_ModuleIter__BjSuRc9aFArudmeEMVvMToQ));
					candidate_2 = initIdentIter__lookups_u135((&ti_2), (&marked_1), (&(*im_1)), s_p1, (*c_p0).graph);
					if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
					{
						while (1) {
							tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T45_;
							if (!!((candidate_2 == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA35;
							eqsink___ast_u4583(&s_2, candidate_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
							eqwasMoved___ast_u4571(&candidate_2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
							{
								if (!((filter_p2 &((NU32)1<<((NU)(((*s_2).kind))&31U)))!=0)) goto LA38_;
								{
									if (!importsHaveCandidate_1) goto LA42_;
									result = NIM_TRUE;
									eqdestroy___ast_u4574(candidate_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									eqdestroy___modulegraphs_u3435((&ti_2));
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									eqdestroy___ast_u4574(s_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
									eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
									if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
									goto BeforeRet_;
								}
								goto LA40_;
LA42_: ;
								{
									importsHaveCandidate_1 = NIM_TRUE;
									eqsink___ast_u4583(&(*sym_p3), s_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
									eqwasMoved___ast_u4571(&s_2);
									if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
								}
LA40_: ;
							}
LA38_: ;
							T45_ = NIM_NIL;
							T45_ = nextIdentIter__lookups_u350((&ti_2), (&marked_1), (&(*im_1)), (*c_p0).graph);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T45_); goto LA33_;}
							eqsink___ast_u4583(&candidate_2, T45_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
						} LA35: ;
					}
					{
						LA33_:;
					}
					{
						oldNimErrFin33_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(candidate_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___modulegraphs_u3435((&ti_2));
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						eqdestroy___ast_u4574(s_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						*nimErr_ = oldNimErrFin33_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
				i_1 += ((NI)1);
			} LA31: ;
		}
	}
	{
		if (!importsHaveCandidate_1) goto LA50_;
		result = NIM_FALSE;
		eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA50_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___pureZcollectionsZintsets_u230((&marked_1));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__lookups_u5067)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p2) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	NIM_BOOL amb_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	amb_1 = NIM_FALSE;
	colontmpD_ = errorUseQualifier__lookups_u5040(c_p0, info_p1, s_p2, (&amb_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, localSearchInScope__lookups_u126)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* s_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* scope_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	scope_1 = NIM_NIL;
	eqcopy___lookups_u77(&scope_1, (*c_p0).currentScope);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = strTableGet__astalgo_u2726((*scope_1).symbols, s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			NIM_BOOL T3_;
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T5_;
			T3_ = (NIM_BOOL)0;
			T3_ = (result == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL));
			if (!(T3_)) goto LA4_;
			T3_ = isShadowScope__lookups_u119(scope_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA4_: ;
			if (!T3_) goto LA2;
			eqcopy___lookups_u77(&scope_1, (*scope_1).parent);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T5_ = NIM_NIL;
			T5_ = strTableGet__astalgo_u2726((*scope_1).symbols, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T5_); goto BeforeRet_;}
			eqsink___ast_u4583(&result, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	eqdestroy___lookups_u74(scope_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, errorUseQualifier__lookups_u5141)(tyObject_TContext__4jZ5gUwIaqnMfIYix46Hpw* c_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* choices_p2) {
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = ambiguousIdentifierMsg__lookups_u5104(choices_p2, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	liMessage__msgs_u1227((*(*c_p0).graph).config, info_p1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), (&TM__3uzV357076dKeFHtnMZm2A_111), NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
