/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32

#include "nimbase.h"
#include <string.h>
#include <math.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct RootObj RootObj;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyTuple__odFiRrDKhZPQ2taWAayfYw tyTuple__odFiRrDKhZPQ2taWAayfYw;
typedef struct tyTuple__8TaWyfF78pGKQc2T027bVA tyTuple__8TaWyfF78pGKQc2T027bVA;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct Exception Exception;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA;
typedef struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg;
typedef struct tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
typedef NU32 tyArray__PPSU5X9aizf5OJq0lL4Og7A[4];
struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg {
	tyArray__PPSU5X9aizf5OJq0lL4Og7A udata;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
struct tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA {
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef NU8 tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q;
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ;
struct tyTuple__odFiRrDKhZPQ2taWAayfYw {
	NimStringV2 Field0;
	NI Field1;
	tyEnum_Endianness__9btYWoZrpVc3PDom9cGvsMAQ Field2;
	NI Field3;
	NI Field4;
};
typedef tyTuple__odFiRrDKhZPQ2taWAayfYw tyArray__BJ38CrWfGxMtyd3CSynibg[29];
typedef NU8 tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg;
struct tyTuple__8TaWyfF78pGKQc2T027bVA {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
	NimStringV2 Field3;
	NimStringV2 Field4;
	NimStringV2 Field5;
	NimStringV2 Field6;
	NimStringV2 Field7;
	NimStringV2 Field8;
	NimStringV2 Field9;
	NimStringV2 Field10;
	NimStringV2 Field11;
	tySet_tyEnum_TInfoOSProp__5b6NqsPwwsBH1DpW70xRSg Field12;
};
typedef tyTuple__8TaWyfF78pGKQc2T027bVA tyArray__RQFn3NKTp5P7VzZ9bksPIyA[34];
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU16 tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw;
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg {
	Exception Sup;
};
struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA {
	tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg Sup;
};
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww {
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg a;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg b;
};
typedef NU16 tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg;
typedef NU8 tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__Vj1MpVCa7BBwvA5h87QXag;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5171)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newType__ast_u5900)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p3);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, addSonSkipIntLit__magicsys_u135)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* id_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntNodeT__semfold_u44)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg intVal_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntTypeNode__ast_u5414)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg intVal_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getIntLitTypeG__semfold_u35)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* literal_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getSysType__magicsys_u55)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, copyType__ast_u6238)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getOrdValue__types_u167)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getInt__ast_u7046)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldUnarySub__semfold_u141)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int128_u412)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, firstOrd__types_u1182)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, minus___int128_u638)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newFloatNodeT__semfold_u54)(NF floatVal_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newFloatNode__ast_u5418)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NF floatVal_p1);
N_LIB_PRIVATE N_NIMCALL(NF, getFloat__ast_u7061)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, minus___int128_u641)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__int128_u937)(NI64 arg_p0);
N_LIB_PRIVATE N_NIMCALL(NI64, cardSet__nimsets_u191)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isUnsigned__types_u141)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, maskBytes__int128_u1074)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0, NI numbytes_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, bitnot__int128_u416)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0);
N_LIB_PRIVATE N_NIMCALL(NI64, getSize__types_u3397)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, lengthOrd__types_u1491)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__types_u1207)(NI arg_p0);
static N_INLINE(NI, nimCStrLen)(NCSTRING a_p0);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldAbs__semfold_u147)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, abs__int128_u648)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldAdd__semfold_u125)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, plus___int128_u615)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkInRange__semfold_u81)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg res_p2);
static N_INLINE(NIM_BOOL, contains__semfold_u118)(tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA* s_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg value_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lteq___int128_u408)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
static N_INLINE(void, dotdot___semfold_u86)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1, tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA* Result);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, lastOrd__types_u1298)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldSub__semfold_u133)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldMul__semfold_u153)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, star___int128_u709)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg lhs_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg rhs_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, lt___int128_u404)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, toInt64__int128_u53)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__semfold_u257)(NI8 arg_p0);
N_LIB_PRIVATE N_NIMCALL(NI8, toInt8__int128_u212)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__semfold_u281)(NI16 arg_p0);
N_LIB_PRIVATE N_NIMCALL(NI16, toInt16__int128_u167)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__semfold_u305)(NI32 arg_p0);
N_LIB_PRIVATE N_NIMCALL(NI32, toInt32__int128_u122)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__semfold_u350)(NU8 arg_p0);
N_LIB_PRIVATE N_NIMCALL(NU8, toUInt8__int128_u293)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__semfold_u362)(NU16 arg_p0);
N_LIB_PRIVATE N_NIMCALL(NU16, toUInt16__int128_u281)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__semfold_u374)(NU32 arg_p0);
N_LIB_PRIVATE N_NIMCALL(NU32, toUInt32__int128_u269)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__int128_u717)(NU64 arg_p0);
N_LIB_PRIVATE N_NIMCALL(NU64, toUInt64__int128_u260)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, div__int128_u809)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, mod__int128_u815)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getStr__ast_u7064)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0);
static N_INLINE(NI, cmpStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(NIM_BOOL, ltpercent___system_u1108)(NI64 x_p0, NI64 y_p1);
static N_INLINE(NIM_BOOL, lteqpercent___system_u1088)(NI64 x_p0, NI64 y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, bitand__int128_u438)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, bitor__int128_u442)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, bitxor__int128_u446)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsSets__nimsets_u159)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, equalSets__nimsets_u166)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, intersectSets__nimsets_u145)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, unionSets__nimsets_u131)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, diffSets__nimsets_u138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, symdiffSets__nimsets_u152)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNodeT__semfold_u63)(NimStringV2 strVal_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5422)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NimStringV2 strVal_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getStrOrChar__ast_u7067)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, inSet__nimsets_u8)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* s_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* elem_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int128_u980)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, NI64 b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, ordinalValToString__semfold_u161)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimCharToStr)(NIM_CHAR x_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___int128_u987)(NI64 a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, typeToString__types_u54)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q prefer_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___int128_u36)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyTree__ast_u6891)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOption__commands_u930)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, testCompileOptionArg__commands_u783)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 switch_p1, NimStringV2 arg_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exprStructuralEquivalent__trees_u63)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1, NIM_BOOL strictSymEquality_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getDateStr__options_u643)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getClockStr__options_u651)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuToLowerAsciiStr)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getAppType__semfold_u647)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldDefine__semfold_u832)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, extractPragma__ast_u4008)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw, whichKeyword__idents_u360)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* id_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2*, nstTake)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringV2 s_p0);
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3662)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, parseBool__pureZstrutils_u1108)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NI64, nsuParseBiggestInt)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, rangeCheck__semfold_u663)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg value_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2);
N_LIB_PRIVATE N_NIMCALL(NU64, nsuParseBiggestUInt)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, getIdent__idents_u206)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* ic_p0, NimStringV2 identifier_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u155)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4);
static N_INLINE(Exception*, getCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZparseutils_u367)(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, astdef__ast_u4596)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNodeTypeDesc__semfold_u820)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, base__ast_u5351)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
static N_INLINE(NIM_BOOL, isIntLit__types_u179)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyNode__ast_u6736)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getConstIfExpr__semfold_u592)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getConstExpr__semfold_u68)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
static N_INLINE(NIM_BOOL, contains__semfold_u1019)(tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww s_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg value_p1);
static N_INLINE(tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww, dotdot___semfold_u987)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg a_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg b_p1);
N_LIB_PRIVATE N_NIMCALL(NF, firstFloat__types_u1268)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(NF, lastFloat__types_u1400)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getArrayConstr__semfold_u717)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, magicCall__semfold_u625)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalOp__semfold_u73)(tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* c_p4, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p5, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p6);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___options_u2138)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg** dest_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, computeSizeAlign__types_u3070)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntNode__ast_u5200)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NI64 intVal_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u2135)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderTree__renderer_u59)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TRenderFlag__Il2q467fyuki59ci9aspexFg renderFlags_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldConStrStr__semfold_u804)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeIT__ast_u4112)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValueConv__semfold_u621)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(NF, toFloat64__int128_u1022)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldConv__semfold_u674)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3, NIM_BOOL check_p4);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__semfold_u691)(NIM_BOOL arg_p0);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u182)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg e_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__int128_u1039)(NF arg_p0);
N_LIB_PRIVATE N_NIMCALL(void, transitionIntKind__ast_u6792)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__Vj1MpVCa7BBwvA5h87QXag kind_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldArrayAccess__semfold_u731)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldFieldAccess__semfold_u763)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3);
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__JtgqXuJaW0Uz9aqyNPWIZsw_2 = {
0x10, 0xa9, 0x00, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__JtgqXuJaW0Uz9aqyNPWIZsw_3 = {
0x10, 0xa9, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_4 = { 24 | NIM_STRLIT_FLAG, "constant folding for shl" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_5 = {24, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_4};
static const struct {
  NI cap; NIM_CHAR data[62+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_7 = { 62 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/semfold.nim" };
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_8 = { 25 | NIM_STRLIT_FLAG, "constant folding for ashr" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_9 = {25, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_8};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_11 = { 5 | NIM_STRLIT_FLAG, "false" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_12 = {5, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_11};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_13 = { 4 | NIM_STRLIT_FLAG, "true" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_14 = {4, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_13};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_15 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_16 = {0, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_15};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_17 = { 18 | NIM_STRLIT_FLAG, "ordinalValToString" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_18 = {18, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_17};
static const struct {
  NI cap; NIM_CHAR data[55+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_20 = { 55 | NIM_STRLIT_FLAG, "Cannot convert int literal to $1. The value is invalid." };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_21 = {55, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_20};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_23 = { 3 | NIM_STRLIT_FLAG, "lib" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_24 = {3, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_23};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_25 = { 9 | NIM_STRLIT_FLAG, "staticlib" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_26 = {9, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_25};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_27 = { 3 | NIM_STRLIT_FLAG, "gui" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_28 = {3, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_27};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_29 = { 7 | NIM_STRLIT_FLAG, "console" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_30 = {7, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_29};
static const struct {
  NI cap; NIM_CHAR data[52+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_31 = { 52 | NIM_STRLIT_FLAG, "{.intdefine.} const was set to an invalid integer: \'" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_32 = {52, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_31};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_33 = { 1 | NIM_STRLIT_FLAG, "\'" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_34 = {1, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_33};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_36 = { 50 | NIM_STRLIT_FLAG, "{.booldefine.} const was set to an invalid bool: \'" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_37 = {50, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_36};
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_38 = {1, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_33};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__JtgqXuJaW0Uz9aqyNPWIZsw_40 = {
0x10, 0x89, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_41 = { 15 | NIM_STRLIT_FLAG, "cannot convert " };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_42 = {15, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_41};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_43 = { 4 | NIM_STRLIT_FLAG, " to " };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_44 = {4, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_43};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_46 = { 19 | NIM_STRLIT_FLAG, "foldDefine for enum" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_47 = {19, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_46};
extern TNimTypeV2 NTIv2__S29bKZF4TUS33IR7ZXb7fFA_;
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_49 = { 20 | NIM_STRLIT_FLAG, "invalid enum value: " };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_50 = {20, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_49};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_51 = { 35 | NIM_STRLIT_FLAG, "unsupported type $1 for define \'$2\'" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_52 = {35, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_51};
static const struct {
  NI cap; NIM_CHAR data[44+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_54 = { 44 | NIM_STRLIT_FLAG, "could not process define \'$1\' of type $2; $3" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_55 = {44, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_54};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_57 = { 16 | NIM_STRLIT_FLAG, "getConstIfExpr()" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_58 = {16, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_57};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__JtgqXuJaW0Uz9aqyNPWIZsw_60 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__JtgqXuJaW0Uz9aqyNPWIZsw_61 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0xa0, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__JtgqXuJaW0Uz9aqyNPWIZsw_62 = {
0x10, 0xa9, 0x80, 0x00, 0x00, 0xe0, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_63 = { 34 | NIM_STRLIT_FLAG, "can\'t compute offsetof on this ast" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_64 = {34, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_63};
static const struct {
  NI cap; NIM_CHAR data[74+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_66 = { 74 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/sizealignoffsetimpl.nim" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_67 = {0, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_15};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_68 = { 18 | NIM_STRLIT_FLAG, "over- or underflow" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_69 = {18, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_68};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_71 = { 16 | NIM_STRLIT_FLAG, "division by zero" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_72 = {16, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_71};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_74 = { 35 | NIM_STRLIT_FLAG, "conversion from $1 to $2 is invalid" };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_75 = {35, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_74};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__JtgqXuJaW0Uz9aqyNPWIZsw_77 = {
0x10, 0xa8, 0x10, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__JtgqXuJaW0Uz9aqyNPWIZsw_78 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__JtgqXuJaW0Uz9aqyNPWIZsw_79 = { 17 | NIM_STRLIT_FLAG, "field not found: " };
static const NimStringV2 TM__JtgqXuJaW0Uz9aqyNPWIZsw_80 = {17, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_79};
extern NIM_CONST tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg One__int128_u9;
extern NIM_CONST tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg Zero__int128_u8;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_6 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)202),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_10 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)231),
((NI)23)}
;
extern NIM_CONST tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg NegOne__int128_u29;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_19 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)111),
((NI)42)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_22 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)118),
((NI)14)}
;
extern NIM_CONST tyArray__BJ38CrWfGxMtyd3CSynibg CPU__platform_u740;
extern NIM_CONST tyArray__RQFn3NKTp5P7VzZ9bksPIyA OS__platform_u534;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_35 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)547),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_39 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)556),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_45 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)392),
((NI)14)}
;
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_48 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)581),
((NI)45)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_53 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)594),
((NI)20)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_56 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)597),
((NI)18)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_59 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)348),
((NI)23)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_65 = {{74, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_66},
((NI)512),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_70 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)709),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_73 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)711),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_76 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)762),
((NI)16)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__JtgqXuJaW0Uz9aqyNPWIZsw_81 = {{62, (NimStrPayload*)&TM__JtgqXuJaW0Uz9aqyNPWIZsw_7},
((NI)510),
((NI)12)}
;
extern NIM_BOOL nimInErrorMode__system_u4144;
extern Exception* currException__system_u3629;
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4144);
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNodeTypeDesc__semfold_u820)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newSymNode__ast_u5171(s_p0, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T5_;
		if (!!(((*(*s_p0).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8)))) goto LA3_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = owner__ast_u6254(s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T5_ = NIM_NIL;
		T5_ = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8), idgen_p1, colontmpD_, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T5_); goto BeforeRet_;}
		eqsink___ast_u3387(&(*result).typField, T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		addSonSkipIntLit__magicsys_u135((*result).typField, (*s_p0).typ, idgen_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		eqcopy___ast_u3381(&(*result).typField, (*s_p0).typ);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, getIntLitTypeG__semfold_u35)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* literal_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* ti_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	ti_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	ti_1 = getSysType__magicsys_u55(g_p0, (*literal_p1).info, ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = owner__ast_u6246(ti_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = copyType__ast_u6238(ti_1, idgen_p2, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	eqcopy___ast_u3255(&(*result).n, literal_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(ti_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntNodeT__semfold_u44)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg intVal_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newIntTypeNode__ast_u5414(intVal_p0, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T5_;
		if (!((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = getIntLitTypeG__semfold_u35(g_p3, result, idgen_p2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T5_); goto BeforeRet_;}
		eqsink___ast_u3387(&(*result).typField, T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	(*result).info = (*n_p1).info;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldUnarySub__semfold_u141)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T3_;
		NIM_BOOL T4_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T7_;
		T3_ = firstOrd__types_u1182((*g_p3).config, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___int128_u412(a_p0, T3_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T4_)) goto LA5_;
		T7_ = minus___int128_u638(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = newIntNodeT__semfold_u44(T7_, n_p1, idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newFloatNodeT__semfold_u54)(NF floatVal_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	{
		colontmpD_ = skipTypes__ast_u5379((*n_p1).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)37))) goto LA3_;
		result = newFloatNode__ast_u5418(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)17), floatVal_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = newFloatNode__ast_u5418(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16), floatVal_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	eqcopy___ast_u3381(&(*result).typField, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).info = (*n_p1).info;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, nimCStrLen)(NCSTRING a_p0) {
	NI result;
	size_t T5_;
{	{
		if (!(a_p0 == 0)) goto LA3_;
		result = ((NI)0);
		goto BeforeRet_;
	}
LA3_: ;
	T5_ = (size_t)0;
	T5_ = strlen(a_p0);
	result = ((NI) (T5_));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0) {
	NCSTRING result;
	{
		if (!(s_p0.len == ((NI)0))) goto LA3_;
		result = "";
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NCSTRING) ((*s_p0.p).data));
	}
LA1_: ;
	return result;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldAbs__semfold_u147)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T3_;
		NIM_BOOL T4_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T7_;
		T3_ = firstOrd__types_u1182((*g_p3).config, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T4_ = (NIM_BOOL)0;
		T4_ = eqeq___int128_u412(a_p0, T3_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T4_)) goto LA5_;
		T7_ = abs__int128_u648(a_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = newIntNodeT__semfold_u44(T7_, n_p1, idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA5_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__semfold_u118)(tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA* s_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg value_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = (NIM_BOOL)0;
	T1_ = lteq___int128_u408((*s_p0).a, value_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	if (!(T1_)) goto LA2_;
	T1_ = lteq___int128_u408(value_p1, (*s_p0).b);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA2_: ;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, dotdot___semfold_u86)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1, tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA* Result) {
	(*Result).a = a_p0;
	(*Result).b = b_p1;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, checkInRange__semfold_u81)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg res_p2) {
	NIM_BOOL result;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T1_;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T2_;
	tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	T1_ = firstOrd__types_u1182(conf_p0, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = lastOrd__types_u1298(conf_p0, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T3_), sizeof(tyObject_HSlice__fa1AtMAy14PwYiDGMJbFOA));
	dotdot___semfold_u86(T1_, T2_, (&T3_));
	result = contains__semfold_u118((&T3_), res_p2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldAdd__semfold_u125)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg res_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	res_1 = plus___int128_u615(a_p0, b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__semfold_u81((*g_p4).config, n_p2, res_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		result = newIntNodeT__semfold_u44(res_1, n_p2, idgen_p3, g_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldSub__semfold_u133)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg res_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	res_1 = minus___int128_u641(a_p0, b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__semfold_u81((*g_p4).config, n_p2, res_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		result = newIntNodeT__semfold_u44(res_1, n_p2, idgen_p3, g_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldMul__semfold_u153)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg a_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg b_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg res_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	res_1 = star___int128_u709(a_p0, b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = checkInRange__semfold_u81((*g_p4).config, n_p2, res_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		result = newIntNodeT__semfold_u44(res_1, n_p2, idgen_p3, g_p4);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
	goto LA1_;
LA4_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, cmpStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NI result;
	NI alen_1;
	NI blen_1;
	NI minlen_1;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	minlen_1 = ((alen_1 <= blen_1) ? alen_1 : blen_1);
	{
		int T5_;
		if (!(((NI)0) < minlen_1)) goto LA3_;
		T5_ = (int)0;
		T5_ = memcmp(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), ((size_t) (minlen_1)));
		result = ((NI) (T5_));
		{
			if (!(result == ((NI)0))) goto LA8_;
			result = (NI)(alen_1 - blen_1);
		}
LA8_: ;
	}
	goto LA1_;
LA3_: ;
	{
		result = (NI)(alen_1 - blen_1);
	}
LA1_: ;
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_u1108)(NI64 x_p0, NI64 y_p1) {
	NIM_BOOL result;
	result = ((NU64)(((NU64) (x_p0))) < (NU64)(((NU64) (y_p1))));
	return result;
}
static N_INLINE(NIM_BOOL, lteqpercent___system_u1088)(NI64 x_p0, NI64 y_p1) {
	NIM_BOOL result;
	result = ((NU64)(((NU64) (x_p0))) <= (NU64)(((NU64) (y_p1))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNodeT__semfold_u63)(NimStringV2 strVal_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newStrNode__ast_u5422(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), strVal_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&(*result).typField, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).info = (*n_p1).info;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, ordinalValToString__semfold_u161)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1) {
	NimStringV2 result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg x_1;
NIM_BOOL oldNimErrFin9_;
NIM_BOOL oldNimErrFin5_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	t_1 = NIM_NIL;
	x_1 = getInt__ast_u7046(a_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	t_1 = skipTypes__ast_u5379((*a_p0).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*t_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		NI64 T3_;
		T3_ = (NI64)0;
		T3_ = toInt64__int128_u53(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		result = nimCharToStr(((NIM_CHAR) (((NI) ((NI64)(T3_ & IL64(255)))))));
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T26_;
		n_1 = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		result = TM__JtgqXuJaW0Uz9aqyNPWIZsw_16;
		eqcopy___ast_u3255(&n_1, (*t_1).n);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
					if (!(i_2 < colontmp_)) goto LA8;
					field_1 = NIM_NIL;
					i_1 = i_2;
					{
						if (!!(((*(*n_1)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA12_;
						internalErrorImpl__msgs_u1598((*g_p1).config, (*a_p0).info, TM__JtgqXuJaW0Uz9aqyNPWIZsw_18, TM__JtgqXuJaW0Uz9aqyNPWIZsw_19);
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					}
LA12_: ;
					eqcopy___ast_u4577(&field_1, (*(*n_1)._kind_6.sons.p->data[i_1])._kind_4.sym);
					if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
					{
						NIM_BOOL T16_;
						T16_ = (NIM_BOOL)0;
						T16_ = eqeq___int128_u987(((NI64) ((*field_1).position)), x_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
						if (!T16_) goto LA17_;
						{
							if (!((*field_1).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA21_;
							eqcopy___system_u2694((&result), (*(*field_1).name).s);
							eqdestroy___ast_u4574(field_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___system_u2691(colontmpD_);
							eqdestroy___ast_u3252(n_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___ast_u3378(t_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
						goto LA19_;
LA21_: ;
						{
							eqcopy___system_u2694((&result), (*(*field_1).ast)._kind_3.strVal);
							eqdestroy___ast_u4574(field_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
							eqdestroy___system_u2691(colontmpD__2);
							eqdestroy___system_u2691(colontmpD_);
							eqdestroy___ast_u3252(n_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							eqdestroy___ast_u3378(t_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
LA19_: ;
					}
LA17_: ;
					i_2 += ((NI)1);
					{
						LA9_:;
					}
					{
						oldNimErrFin9_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u4574(field_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
						*nimErr_ = oldNimErrFin9_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
				} LA8: ;
			}
		}
		colontmpD_ = typeToString__types_u54(t_1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		T26_[0] = colontmpD_;
		colontmpD__2 = nsuFormatOpenArray(TM__JtgqXuJaW0Uz9aqyNPWIZsw_21, T26_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		liMessage__msgs_u1227((*g_p1).config, (*a_p0).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_22, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
		{
			LA5_:;
		}
		{
			oldNimErrFin5_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___ast_u3252(n_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin5_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		result = dollar___int128_u36(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, evalOp__semfold_u73)(tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* c_p4, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p5, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p6) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin107_;
NIM_BOOL oldNimErrFin202_;
NIM_BOOL oldNimErrFin275_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	switch (m_p0) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)31):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T2_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T3_;
		T2_ = getOrdValue__types_u167(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = NIM_NIL;
		T3_ = newIntNodeT__semfold_u44(T2_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T3_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T3_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)43):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T5_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T6_;
		T5_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T6_ = NIM_NIL;
		T6_ = newIntNodeT__semfold_u44(T5_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T6_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)93):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)94):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T8_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
		T8_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T9_ = NIM_NIL;
		T9_ = foldUnarySub__semfold_u141(T8_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T9_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)100):
	{
		NF T11_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T12_;
		T11_ = (NF)0;
		T11_ = getFloat__ast_u7061(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T12_ = NIM_NIL;
		T12_ = newFloatNodeT__semfold_u54(-(T11_), n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T12_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T12_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T14_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T15_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
		T14_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T15_ = minus___int128_u641(One__int128_u9, T14_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T16_ = NIM_NIL;
		T16_ = newIntNodeT__semfold_u44(T15_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T16_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T16_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)42):
	{
		NI64 T18_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T19_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T20_;
		T18_ = (NI64)0;
		T18_ = cardSet__nimsets_u191((*g_p6).config, a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T19_ = toInt128__int128_u937(T18_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T20_ = NIM_NIL;
		T20_ = newIntNodeT__semfold_u44(T19_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T20_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T20_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)98):
	{
		{
			NIM_BOOL T24_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T27_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T28_;
			NI64 T29_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T30_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T31_;
			T24_ = (NIM_BOOL)0;
			T24_ = isUnsigned__types_u141((*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T24_) goto LA25_;
			T27_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T28_ = bitnot__int128_u416(T27_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T29_ = (NI64)0;
			T29_ = getSize__types_u3397((*g_p6).config, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T30_ = maskBytes__int128_u1074(T28_, ((NI) (T29_)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T31_ = NIM_NIL;
			T31_ = newIntNodeT__semfold_u44(T30_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T31_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T31_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA22_;
LA25_: ;
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T33_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T34_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T35_;
			T33_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T34_ = bitnot__int128_u416(T33_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T35_ = NIM_NIL;
			T35_ = newIntNodeT__semfold_u44(T34_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T35_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T35_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA22_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)38):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T37_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T38_;
		T37_ = lengthOrd__types_u1491((*g_p6).config, (*a_p2).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T38_ = NIM_NIL;
		T38_ = newIntNodeT__semfold_u44(T37_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T38_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T38_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)39):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)36):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)37):
	{
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T44_;
			if (!((*a_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA42_;
			T44_ = NIM_NIL;
			T44_ = newIntNodeT__semfold_u44(Zero__int128_u8, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T44_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T44_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA40_;
LA42_: ;
		{
			if (!((*a_p2).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) && (*a_p2).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA46_;
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T52_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T53_;
				if (!((*(*a_p2).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28))) goto LA50_;
				T52_ = toInt128__types_u1207((*a_p2)._kind_3.strVal.len);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T53_ = NIM_NIL;
				T53_ = newIntNodeT__semfold_u44(T52_, n_p1, idgen_p5, g_p6);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T53_); goto BeforeRet_;}
				eqsink___ast_u3261(&result, T53_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA48_;
LA50_: ;
			{
				NI T57_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T58_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T59_;
				if (!((*(*a_p2).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29))) goto LA55_;
				T57_ = (NI)0;
				T57_ = nimCStrLen(nimToCStringConv((*a_p2)._kind_3.strVal));
				T58_ = toInt128__types_u1207(T57_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T59_ = NIM_NIL;
				T59_ = newIntNodeT__semfold_u44(T58_, n_p1, idgen_p5, g_p6);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T59_); goto BeforeRet_;}
				eqsink___ast_u3261(&result, T59_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA48_;
LA55_: ;
LA48_: ;
		}
		goto LA40_;
LA46_: ;
		{
			NI T61_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T62_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T63_;
			T61_ = (NI)0;
			T61_ = len__ast_u3190(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T62_ = toInt128__types_u1207(T61_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T63_ = NIM_NIL;
			T63_ = newIntNodeT__semfold_u44(T62_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T63_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T63_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA40_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)97):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)99):
	{
		eqcopy___ast_u3255(&result, a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)95):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T66_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T67_;
		T66_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T67_ = NIM_NIL;
		T67_ = foldAbs__semfold_u147(T66_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T67_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T67_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)51):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T69_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T70_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T71_;
		T69_ = getOrdValue__types_u167(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T70_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T71_ = NIM_NIL;
		T71_ = foldAdd__semfold_u125(T69_, T70_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T71_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T71_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)52):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T73_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T74_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T75_;
		T73_ = getOrdValue__types_u167(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T74_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T75_ = NIM_NIL;
		T75_ = foldSub__semfold_u133(T73_, T74_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T75_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T75_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)46):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T77_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T78_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T79_;
		T77_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T78_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T79_ = NIM_NIL;
		T79_ = foldAdd__semfold_u125(T77_, T78_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T79_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T79_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)47):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T81_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T82_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T83_;
		T81_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T82_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T83_ = NIM_NIL;
		T83_ = foldSub__semfold_u133(T81_, T82_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T83_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T83_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)48):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T85_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T86_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T87_;
		T85_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T86_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T87_ = NIM_NIL;
		T87_ = foldMul__semfold_u153(T85_, T86_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T87_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T87_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)63):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg colontmpD_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg colontmpD__2;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argA_1;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argB_1;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T89_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T96_;
		nimZeroMem((void*)(&colontmpD_), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
		nimZeroMem((void*)(&colontmpD__2), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
		argA_1 = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		argB_1 = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T92_;
			T92_ = (NIM_BOOL)0;
			T92_ = lt___int128_u404(argA_1, argB_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T92_) goto LA93_;
			colontmpD_ = argA_1;
			T89_ = colontmpD_;
		}
		goto LA90_;
LA93_: ;
		{
			colontmpD__2 = argB_1;
			T89_ = colontmpD__2;
		}
LA90_: ;
		T96_ = NIM_NIL;
		T96_ = newIntNodeT__semfold_u44(T89_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T96_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T96_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)64):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg colontmpD__3;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg colontmpD__4;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argA_2;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argB_2;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T98_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T105_;
		nimZeroMem((void*)(&colontmpD__3), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
		nimZeroMem((void*)(&colontmpD__4), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
		argA_2 = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		argB_2 = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T101_;
			T101_ = (NIM_BOOL)0;
			T101_ = lt___int128_u404(argB_2, argA_2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T101_) goto LA102_;
			colontmpD__3 = argA_2;
			T98_ = colontmpD__3;
		}
		goto LA99_;
LA102_: ;
		{
			colontmpD__4 = argB_2;
			T98_ = colontmpD__4;
		}
LA99_: ;
		T105_ = NIM_NIL;
		T105_ = newIntNodeT__semfold_u44(T98_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T105_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T105_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)58):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__5;
		NI64 valueB_1;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T108_;
		NI64 T109_;
		colontmpD__5 = NIM_NIL;
		T108_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		T109_ = (NI64)0;
		T109_ = toInt64__int128_u53(T108_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		valueB_1 = (NI64)(T109_ & (NI64)((NI64)((*(*n_p1).typField).size * IL64(8)) - IL64(1)));
		colontmpD__5 = skipTypes__ast_u5379((*n_p1).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		switch ((*colontmpD__5).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)32):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T111_;
			NI8 T112_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T113_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T114_;
			T111_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T112_ = (NI8)0;
			T112_ = toInt8__int128_u212(T111_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T113_ = toInt128__semfold_u257((NI8)((NU64)(T112_) << (NU64)(valueB_1 & (8 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T114_ = NIM_NIL;
			T114_ = newIntNodeT__semfold_u44(T113_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T114_); goto LA107_;}
			eqsink___ast_u3261(&result, T114_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T116_;
			NI16 T117_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T118_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T119_;
			T116_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T117_ = (NI16)0;
			T117_ = toInt16__int128_u167(T116_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T118_ = toInt128__semfold_u281((NI16)((NU64)(T117_) << (NU64)(valueB_1 & (16 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T119_ = NIM_NIL;
			T119_ = newIntNodeT__semfold_u44(T118_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T119_); goto LA107_;}
			eqsink___ast_u3261(&result, T119_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T121_;
			NI32 T122_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T123_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T124_;
			T121_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T122_ = (NI32)0;
			T122_ = toInt32__int128_u122(T121_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T123_ = toInt128__semfold_u305((NI32)((NU64)(T122_) << (NU64)(valueB_1 & (32 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T124_ = NIM_NIL;
			T124_ = newIntNodeT__semfold_u44(T123_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T124_); goto LA107_;}
			eqsink___ast_u3261(&result, T124_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T126_;
			NI64 T127_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T128_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T129_;
			T126_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T127_ = (NI64)0;
			T127_ = toInt64__int128_u53(T126_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T128_ = toInt128__int128_u937((NI64)((NU64)(T127_) << (NU64)(valueB_1 & (64 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T129_ = NIM_NIL;
			T129_ = newIntNodeT__semfold_u44(T128_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T129_); goto LA107_;}
			eqsink___ast_u3261(&result, T129_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31):
		{
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T135_;
				NI32 T136_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T137_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T138_;
				if (!((*(*g_p6).config).target.intSize == ((NI)4))) goto LA133_;
				T135_ = getInt__ast_u7046(a_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T136_ = (NI32)0;
				T136_ = toInt32__int128_u122(T135_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T137_ = toInt128__semfold_u305((NI32)((NU64)(T136_) << (NU64)(valueB_1 & (32 - 1))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T138_ = NIM_NIL;
				T138_ = newIntNodeT__semfold_u44(T137_, n_p1, idgen_p5, g_p6);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T138_); goto LA107_;}
				eqsink___ast_u3261(&result, T138_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			}
			goto LA131_;
LA133_: ;
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T140_;
				NI64 T141_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T142_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T143_;
				T140_ = getInt__ast_u7046(a_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T141_ = (NI64)0;
				T141_ = toInt64__int128_u53(T140_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T142_ = toInt128__int128_u937((NI64)((NU64)(T141_) << (NU64)(valueB_1 & (64 - 1))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T143_ = NIM_NIL;
				T143_ = newIntNodeT__semfold_u44(T142_, n_p1, idgen_p5, g_p6);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T143_); goto LA107_;}
				eqsink___ast_u3261(&result, T143_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			}
LA131_: ;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)41):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T145_;
			NU8 T146_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T147_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T148_;
			T145_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T146_ = (NU8)0;
			T146_ = toUInt8__int128_u293(T145_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T147_ = toInt128__semfold_u350((NU8)((NU64)(T146_) << (NU64)(valueB_1 & (8 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T148_ = NIM_NIL;
			T148_ = newIntNodeT__semfold_u44(T147_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T148_); goto LA107_;}
			eqsink___ast_u3261(&result, T148_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)42):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T150_;
			NU16 T151_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T152_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T153_;
			T150_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T151_ = (NU16)0;
			T151_ = toUInt16__int128_u281(T150_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T152_ = toInt128__semfold_u362((NU16)((NU64)(T151_) << (NU64)(valueB_1 & (16 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T153_ = NIM_NIL;
			T153_ = newIntNodeT__semfold_u44(T152_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T153_); goto LA107_;}
			eqsink___ast_u3261(&result, T153_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T155_;
			NU32 T156_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T157_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T158_;
			T155_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T156_ = (NU32)0;
			T156_ = toUInt32__int128_u269(T155_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T157_ = toInt128__semfold_u374((NU32)((NU64)(T156_) << (NU64)(valueB_1 & (32 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T158_ = NIM_NIL;
			T158_ = newIntNodeT__semfold_u44(T157_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T158_); goto LA107_;}
			eqsink___ast_u3261(&result, T158_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T160_;
			NU64 T161_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T162_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T163_;
			T160_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T161_ = (NU64)0;
			T161_ = toUInt64__int128_u260(T160_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T162_ = toInt128__int128_u717((NU64)((NU64)(T161_) << (NU64)(valueB_1 & (64 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			T163_ = NIM_NIL;
			T163_ = newIntNodeT__semfold_u44(T162_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T163_); goto LA107_;}
			eqsink___ast_u3261(&result, T163_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40):
		{
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T169_;
				NU32 T170_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T171_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T172_;
				if (!((*(*g_p6).config).target.intSize == ((NI)4))) goto LA167_;
				T169_ = getInt__ast_u7046(a_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T170_ = (NU32)0;
				T170_ = toUInt32__int128_u269(T169_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T171_ = toInt128__semfold_u374((NU32)((NU64)(T170_) << (NU64)(valueB_1 & (32 - 1))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T172_ = NIM_NIL;
				T172_ = newIntNodeT__semfold_u44(T171_, n_p1, idgen_p5, g_p6);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T172_); goto LA107_;}
				eqsink___ast_u3261(&result, T172_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			}
			goto LA165_;
LA167_: ;
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T174_;
				NU64 T175_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T176_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T177_;
				T174_ = getInt__ast_u7046(a_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T175_ = (NU64)0;
				T175_ = toUInt64__int128_u260(T174_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T176_ = toInt128__int128_u717((NU64)((NU64)(T175_) << (NU64)(valueB_1 & (64 - 1))));
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
				T177_ = NIM_NIL;
				T177_ = newIntNodeT__semfold_u44(T176_, n_p1, idgen_p5, g_p6);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T177_); goto LA107_;}
				eqsink___ast_u3261(&result, T177_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
			}
LA165_: ;
		}
		break;
		default:
		{
			internalErrorImpl__msgs_u1598((*g_p6).config, (*n_p1).info, TM__JtgqXuJaW0Uz9aqyNPWIZsw_5, TM__JtgqXuJaW0Uz9aqyNPWIZsw_6);
			if (NIM_UNLIKELY(*nimErr_)) goto LA107_;
		}
		break;
		}
		{
			LA107_:;
		}
		{
			oldNimErrFin107_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin107_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)57):
	{
		NU64 a_2;
		union { tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg source; NU64 dest; } LOC182;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T183_;
		NU64 b_2;
		union { tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg source; NU64 dest; } LOC184;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T185_;
		NI64 c_2;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T199_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T200_;
		nimZeroMem((void*)(&T183_), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
		T183_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		LOC182.source = T183_;
		a_2 = LOC182.dest;
		nimZeroMem((void*)(&T185_), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
		T185_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		LOC184.source = T185_;
		b_2 = (NU64)(LOC184.dest & ((NU64) ((NI64)((NI64)((*(*n_p1).typField).size * IL64(8)) - IL64(1)))));
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__6;
			if (!((NU64)(0ULL) < (NU64)(b_2))) goto LA188_;
			colontmpD__6 = NIM_NIL;
			colontmpD__6 = skipTypes__ast_u5379((*n_p1).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			switch ((*colontmpD__6).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)32):
			{
				a_2 = (NU64)(a_2 & 255ULL);
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33):
			{
				a_2 = (NU64)(a_2 & 65535ULL);
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
			{
				a_2 = (NU64)(a_2 & 4294967295ULL);
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31):
			{
				{
					if (!((*(*g_p6).config).target.intSize == ((NI)4))) goto LA196_;
					a_2 = (NU64)(a_2 & 4294967295ULL);
				}
LA196_: ;
			}
			break;
			default:
			{
			}
			break;
			}
			eqdestroy___ast_u3378(colontmpD__6);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA188_: ;
		c_2 = ((NI64) ((NU64)((NU64)(a_2) >> (NU64)(b_2 & (64 - 1)))));
		T199_ = toInt128__int128_u937(c_2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T200_ = NIM_NIL;
		T200_ = newIntNodeT__semfold_u44(T199_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T200_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T200_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)59):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__7;
		NI64 valueB_2;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T203_;
		NI64 T204_;
		colontmpD__7 = NIM_NIL;
		T203_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		T204_ = (NI64)0;
		T204_ = toInt64__int128_u53(T203_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		valueB_2 = (NI64)(T204_ & (NI64)((NI64)((*(*n_p1).typField).size * IL64(8)) - IL64(1)));
		colontmpD__7 = skipTypes__ast_u5379((*n_p1).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		switch ((*colontmpD__7).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)32):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T206_;
			NI8 T207_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T208_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T209_;
			T206_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T207_ = (NI8)0;
			T207_ = toInt8__int128_u212(T206_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T208_ = toInt128__semfold_u257((NI8)((NI64)(T207_) >> (NU64)(valueB_2 & (8 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T209_ = NIM_NIL;
			T209_ = newIntNodeT__semfold_u44(T208_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T209_); goto LA202_;}
			eqsink___ast_u3261(&result, T209_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T211_;
			NI16 T212_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T213_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T214_;
			T211_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T212_ = (NI16)0;
			T212_ = toInt16__int128_u167(T211_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T213_ = toInt128__semfold_u281((NI16)((NI64)(T212_) >> (NU64)(valueB_2 & (16 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T214_ = NIM_NIL;
			T214_ = newIntNodeT__semfold_u44(T213_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T214_); goto LA202_;}
			eqsink___ast_u3261(&result, T214_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T216_;
			NI32 T217_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T218_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T219_;
			T216_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T217_ = (NI32)0;
			T217_ = toInt32__int128_u122(T216_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T218_ = toInt128__semfold_u305((NI32)((NI64)(T217_) >> (NU64)(valueB_2 & (32 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T219_ = NIM_NIL;
			T219_ = newIntNodeT__semfold_u44(T218_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T219_); goto LA202_;}
			eqsink___ast_u3261(&result, T219_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T221_;
			NI64 T222_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T223_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T224_;
			T221_ = getInt__ast_u7046(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T222_ = (NI64)0;
			T222_ = toInt64__int128_u53(T221_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T223_ = toInt128__int128_u937((NI64)((NI64)(T222_) >> (NU64)(valueB_2 & (64 - 1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
			T224_ = NIM_NIL;
			T224_ = newIntNodeT__semfold_u44(T223_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T224_); goto LA202_;}
			eqsink___ast_u3261(&result, T224_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		}
		break;
		default:
		{
			internalErrorImpl__msgs_u1598((*g_p6).config, (*n_p1).info, TM__JtgqXuJaW0Uz9aqyNPWIZsw_9, TM__JtgqXuJaW0Uz9aqyNPWIZsw_10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA202_;
		}
		break;
		}
		{
			LA202_:;
		}
		{
			oldNimErrFin202_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__7);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin202_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)49):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argA_3;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argB_3;
		argA_3 = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		argB_3 = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T231_;
			NIM_BOOL T232_;
			NIM_BOOL T234_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T235_;
			NIM_BOOL T236_;
			NIM_BOOL T238_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T241_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T242_;
			T231_ = (NIM_BOOL)0;
			T232_ = (NIM_BOOL)0;
			T232_ = eqeq___int128_u412(argB_3, Zero__int128_u8);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T231_ = !(T232_);
			if (!(T231_)) goto LA233_;
			T234_ = (NIM_BOOL)0;
			T235_ = firstOrd__types_u1182((*g_p6).config, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T236_ = (NIM_BOOL)0;
			T236_ = eqeq___int128_u412(argA_3, T235_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T234_ = !(T236_);
			if (T234_) goto LA237_;
			T238_ = (NIM_BOOL)0;
			T238_ = eqeq___int128_u412(argB_3, NegOne__int128_u29);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T234_ = !(T238_);
LA237_: ;
			T231_ = T234_;
LA233_: ;
			if (!T231_) goto LA239_;
			T241_ = div__int128_u809(argA_3, argB_3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T242_ = NIM_NIL;
			T242_ = newIntNodeT__semfold_u44(T241_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T242_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T242_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA239_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)50):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argA_4;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argB_4;
		argA_4 = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		argB_4 = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T246_;
			NIM_BOOL T247_;
			NIM_BOOL T249_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T250_;
			NIM_BOOL T251_;
			NIM_BOOL T253_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T256_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T257_;
			T246_ = (NIM_BOOL)0;
			T247_ = (NIM_BOOL)0;
			T247_ = eqeq___int128_u412(argB_4, Zero__int128_u8);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T246_ = !(T247_);
			if (!(T246_)) goto LA248_;
			T249_ = (NIM_BOOL)0;
			T250_ = firstOrd__types_u1182((*g_p6).config, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T251_ = (NIM_BOOL)0;
			T251_ = eqeq___int128_u412(argA_4, T250_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T249_ = !(T251_);
			if (T249_) goto LA252_;
			T253_ = (NIM_BOOL)0;
			T253_ = eqeq___int128_u412(argB_4, NegOne__int128_u29);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T249_ = !(T253_);
LA252_: ;
			T246_ = T249_;
LA248_: ;
			if (!T246_) goto LA254_;
			T256_ = mod__int128_u815(argA_4, argB_4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T257_ = NIM_NIL;
			T257_ = newIntNodeT__semfold_u44(T256_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T257_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T257_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA254_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)53):
	{
		NF T259_;
		NF T260_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T261_;
		T259_ = (NF)0;
		T259_ = getFloat__ast_u7061(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T260_ = (NF)0;
		T260_ = getFloat__ast_u7061(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T261_ = NIM_NIL;
		T261_ = newFloatNodeT__semfold_u54(((NF)(T259_) + (NF)(T260_)), n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T261_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T261_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)54):
	{
		NF T263_;
		NF T264_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T265_;
		T263_ = (NF)0;
		T263_ = getFloat__ast_u7061(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T264_ = (NF)0;
		T264_ = getFloat__ast_u7061(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T265_ = NIM_NIL;
		T265_ = newFloatNodeT__semfold_u54(((NF)(T263_) - (NF)(T264_)), n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T265_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T265_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)55):
	{
		NF T267_;
		NF T268_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T269_;
		T267_ = (NF)0;
		T267_ = getFloat__ast_u7061(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T268_ = (NF)0;
		T268_ = getFloat__ast_u7061(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T269_ = NIM_NIL;
		T269_ = newFloatNodeT__semfold_u54(((NF)(T267_) * (NF)(T268_)), n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T269_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T269_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)56):
	{
		NF T271_;
		NF T272_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T273_;
		T271_ = (NF)0;
		T271_ = getFloat__ast_u7061(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T272_ = (NF)0;
		T272_ = getFloat__ast_u7061(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T273_ = NIM_NIL;
		T273_ = newFloatNodeT__semfold_u54(((NF)(T271_) / (NF)(T272_)), n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T273_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T273_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)142):
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
		NIM_BOOL val_1;
		NIM_BOOL T276_;
		NIM_BOOL T278_;
		NIM_BOOL T279_;
		NIM_BOOL T280_;
		NIM_BOOL T281_;
		NIM_BOOL T282_;
		NI T286_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T289_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T290_;
		colontmpD__8 = NIM_NIL;
		T276_ = (NIM_BOOL)0;
		T276_ = ((*a_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
		if (T276_) goto LA277_;
		T278_ = (NIM_BOOL)0;
		T279_ = (NIM_BOOL)0;
		T280_ = (NIM_BOOL)0;
		T281_ = (NIM_BOOL)0;
		T282_ = (NIM_BOOL)0;
		T282_ = !(((*a_p2).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T282_)) goto LA283_;
		colontmpD__8 = skipTypes__ast_u5379((*a_p2).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		T282_ = ((*colontmpD__8).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA283_: ;
		T281_ = T282_;
		if (!(T281_)) goto LA284_;
		T281_ = ((*a_p2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160));
LA284_: ;
		T280_ = T281_;
		if (!(T280_)) goto LA285_;
		T286_ = (NI)0;
		T286_ = len__ast_u3190(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		T280_ = (T286_ == ((NI)2));
LA285_: ;
		T279_ = T280_;
		if (!(T279_)) goto LA287_;
		T279_ = ((*(*a_p2)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA287_: ;
		T278_ = T279_;
		if (!(T278_)) goto LA288_;
		T278_ = ((*(*a_p2)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA288_: ;
		T276_ = T278_;
LA277_: ;
		val_1 = T276_;
		T289_ = toInt128__types_u1207(val_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		T290_ = NIM_NIL;
		T290_ = newIntNodeT__semfold_u44(T289_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T290_); goto LA275_;}
		eqsink___ast_u3261(&result, T290_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA275_;
		{
			LA275_:;
		}
		{
			oldNimErrFin275_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(colontmpD__8);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin275_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)72):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)86):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)80):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)83):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T294_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T295_;
		NIM_BOOL T296_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T297_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T298_;
		T294_ = getOrdValue__types_u167(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T295_ = getOrdValue__types_u167(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T296_ = (NIM_BOOL)0;
		T296_ = lt___int128_u404(T294_, T295_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T297_ = toInt128__types_u1207(T296_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T298_ = NIM_NIL;
		T298_ = newIntNodeT__semfold_u44(T297_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T298_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T298_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)71):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)85):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)79):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)82):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T300_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T301_;
		NIM_BOOL T302_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T303_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T304_;
		T300_ = getOrdValue__types_u167(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T301_ = getOrdValue__types_u167(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T302_ = (NIM_BOOL)0;
		T302_ = lteq___int128_u408(T300_, T301_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T303_ = toInt128__types_u1207(T302_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T304_ = NIM_NIL;
		T304_ = newIntNodeT__semfold_u44(T303_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T304_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T304_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)70):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)84):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)78):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)81):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T306_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T307_;
		NIM_BOOL T308_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T309_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T310_;
		T306_ = getOrdValue__types_u167(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T307_ = getOrdValue__types_u167(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T308_ = (NIM_BOOL)0;
		T308_ = eqeq___int128_u412(T306_, T307_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T309_ = toInt128__types_u1207(T308_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T310_ = NIM_NIL;
		T310_ = newIntNodeT__semfold_u44(T309_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T310_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T310_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)75):
	{
		NF T312_;
		NF T313_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T314_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T315_;
		T312_ = (NF)0;
		T312_ = getFloat__ast_u7061(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T313_ = (NF)0;
		T313_ = getFloat__ast_u7061(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T314_ = toInt128__types_u1207((T312_ < T313_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T315_ = NIM_NIL;
		T315_ = newIntNodeT__semfold_u44(T314_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T315_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T315_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)74):
	{
		NF T317_;
		NF T318_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T319_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T320_;
		T317_ = (NF)0;
		T317_ = getFloat__ast_u7061(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T318_ = (NF)0;
		T318_ = getFloat__ast_u7061(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T319_ = toInt128__types_u1207((T317_ <= T318_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T320_ = NIM_NIL;
		T320_ = newIntNodeT__semfold_u44(T319_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T320_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T320_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)73):
	{
		NF T322_;
		NF T323_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T324_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T325_;
		T322_ = (NF)0;
		T322_ = getFloat__ast_u7061(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T323_ = (NF)0;
		T323_ = getFloat__ast_u7061(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T324_ = toInt128__types_u1207((T322_ == T323_));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T325_ = NIM_NIL;
		T325_ = newIntNodeT__semfold_u44(T324_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T325_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T325_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)115):
	{
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T328_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T329_;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__9 = getStr__ast_u7064(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA327_;
		colontmpD__10 = getStr__ast_u7064(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA327_;
		T328_ = toInt128__types_u1207((cmpStrings(colontmpD__9, colontmpD__10) < 0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA327_;
		T329_ = NIM_NIL;
		T329_ = newIntNodeT__semfold_u44(T328_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T329_); goto LA327_;}
		eqsink___ast_u3261(&result, T329_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA327_;
		{
			LA327_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)114):
	{
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T334_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T335_;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__11 = getStr__ast_u7064(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA333_;
		colontmpD__12 = getStr__ast_u7064(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA333_;
		T334_ = toInt128__types_u1207((cmpStrings(colontmpD__11, colontmpD__12) <= 0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA333_;
		T335_ = NIM_NIL;
		T335_ = newIntNodeT__semfold_u44(T334_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T335_); goto LA333_;}
		eqsink___ast_u3261(&result, T335_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA333_;
		{
			LA333_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)113):
	{
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T340_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T341_;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__13 = getStr__ast_u7064(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA339_;
		colontmpD__14 = getStr__ast_u7064(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA339_;
		T340_ = toInt128__types_u1207(eqStrings(colontmpD__13, colontmpD__14));
		if (NIM_UNLIKELY(*nimErr_)) goto LA339_;
		T341_ = NIM_NIL;
		T341_ = newIntNodeT__semfold_u44(T340_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T341_); goto LA339_;}
		eqsink___ast_u3261(&result, T341_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA339_;
		{
			LA339_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)77):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T345_;
		NI64 T346_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T347_;
		NI64 T348_;
		NIM_BOOL T349_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T350_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T351_;
		T345_ = getOrdValue__types_u167(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T346_ = (NI64)0;
		T346_ = toInt64__int128_u53(T345_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T347_ = getOrdValue__types_u167(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T348_ = (NI64)0;
		T348_ = toInt64__int128_u53(T347_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T349_ = (NIM_BOOL)0;
		T349_ = ltpercent___system_u1108(T346_, T348_);
		T350_ = toInt128__types_u1207(T349_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T351_ = NIM_NIL;
		T351_ = newIntNodeT__semfold_u44(T350_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T351_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T351_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)76):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T353_;
		NI64 T354_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T355_;
		NI64 T356_;
		NIM_BOOL T357_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T358_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T359_;
		T353_ = getOrdValue__types_u167(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T354_ = (NI64)0;
		T354_ = toInt64__int128_u53(T353_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T355_ = getOrdValue__types_u167(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T356_ = (NI64)0;
		T356_ = toInt64__int128_u53(T355_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T357_ = (NIM_BOOL)0;
		T357_ = lteqpercent___system_u1088(T354_, T356_);
		T358_ = toInt128__types_u1207(T357_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T359_ = NIM_NIL;
		T359_ = newIntNodeT__semfold_u44(T358_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T359_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T359_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)60):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)106):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T361_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T362_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T363_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T364_;
		T361_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T362_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T363_ = bitand__int128_u438(T361_, T362_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T364_ = NIM_NIL;
		T364_ = newIntNodeT__semfold_u44(T363_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T364_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T364_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)61):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)107):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T366_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T367_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T368_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T369_;
		T366_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T367_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T368_ = bitor__int128_u442(T366_, T367_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T369_ = NIM_NIL;
		T369_ = newIntNodeT__semfold_u44(T368_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T369_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T369_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)62):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)90):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T371_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T372_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T373_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T374_;
		T371_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T372_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T373_ = bitxor__int128_u446(T371_, T372_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T374_ = NIM_NIL;
		T374_ = newIntNodeT__semfold_u44(T373_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T374_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T374_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)65):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg val_2;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T376_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T377_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T378_;
		NI64 T379_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T380_;
		T376_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T377_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T378_ = plus___int128_u615(T376_, T377_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T379_ = (NI64)0;
		T379_ = getSize__types_u3397((*g_p6).config, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		val_2 = maskBytes__int128_u1074(T378_, ((NI) (T379_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T380_ = NIM_NIL;
		T380_ = newIntNodeT__semfold_u44(val_2, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T380_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T380_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)66):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg val_3;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T382_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T383_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T384_;
		NI64 T385_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T386_;
		T382_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T383_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T384_ = minus___int128_u641(T382_, T383_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T385_ = (NI64)0;
		T385_ = getSize__types_u3397((*g_p6).config, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		val_3 = maskBytes__int128_u1074(T384_, ((NI) (T385_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T386_ = NIM_NIL;
		T386_ = newIntNodeT__semfold_u44(val_3, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T386_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T386_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)67):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg val_4;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T388_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T389_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T390_;
		NI64 T391_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T392_;
		T388_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T389_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T390_ = star___int128_u709(T388_, T389_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T391_ = (NI64)0;
		T391_ = getSize__types_u3397((*g_p6).config, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		val_4 = maskBytes__int128_u1074(T390_, ((NI) (T391_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T392_ = NIM_NIL;
		T392_ = newIntNodeT__semfold_u44(val_4, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T392_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T392_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)69):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argA_5;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T394_;
		NI64 T395_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argB_5;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T396_;
		NI64 T397_;
		T394_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T395_ = (NI64)0;
		T395_ = getSize__types_u3397((*g_p6).config, (*a_p2).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		argA_5 = maskBytes__int128_u1074(T394_, ((NI) (T395_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T396_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T397_ = (NI64)0;
		T397_ = getSize__types_u3397((*g_p6).config, (*a_p2).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		argB_5 = maskBytes__int128_u1074(T396_, ((NI) (T397_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T400_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T403_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T404_;
			T400_ = (NIM_BOOL)0;
			T400_ = eqeq___int128_u412(argB_5, Zero__int128_u8);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T400_)) goto LA401_;
			T403_ = mod__int128_u815(argA_5, argB_5);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T404_ = NIM_NIL;
			T404_ = newIntNodeT__semfold_u44(T403_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T404_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T404_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA401_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)68):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argA_6;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T406_;
		NI64 T407_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg argB_6;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T408_;
		NI64 T409_;
		T406_ = getInt__ast_u7046(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T407_ = (NI64)0;
		T407_ = getSize__types_u3397((*g_p6).config, (*a_p2).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		argA_6 = maskBytes__int128_u1074(T406_, ((NI) (T407_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T408_ = getInt__ast_u7046(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T409_ = (NI64)0;
		T409_ = getSize__types_u3397((*g_p6).config, (*a_p2).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		argB_6 = maskBytes__int128_u1074(T408_, ((NI) (T409_)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T412_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T415_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T416_;
			T412_ = (NIM_BOOL)0;
			T412_ = eqeq___int128_u412(argB_6, Zero__int128_u8);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!!(T412_)) goto LA413_;
			T415_ = div__int128_u809(argA_6, argB_6);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T416_ = NIM_NIL;
			T416_ = newIntNodeT__semfold_u44(T415_, n_p1, idgen_p5, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T416_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T416_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA413_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)117):
	{
		NIM_BOOL T418_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T419_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T420_;
		T418_ = (NIM_BOOL)0;
		T418_ = containsSets__nimsets_u159((*g_p6).config, a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T419_ = toInt128__types_u1207(T418_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T420_ = NIM_NIL;
		T420_ = newIntNodeT__semfold_u44(T419_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T420_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T420_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)116):
	{
		NIM_BOOL T422_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T423_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T424_;
		T422_ = (NIM_BOOL)0;
		T422_ = equalSets__nimsets_u166((*g_p6).config, a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T423_ = toInt128__types_u1207(T422_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T424_ = NIM_NIL;
		T424_ = newIntNodeT__semfold_u44(T423_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T424_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T424_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)118):
	{
		NIM_BOOL T426_;
		NIM_BOOL T428_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T429_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T430_;
		T426_ = (NIM_BOOL)0;
		T426_ = containsSets__nimsets_u159((*g_p6).config, a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T426_)) goto LA427_;
		T428_ = (NIM_BOOL)0;
		T428_ = equalSets__nimsets_u166((*g_p6).config, a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T426_ = !(T428_);
LA427_: ;
		T429_ = toInt128__types_u1207(T426_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T430_ = NIM_NIL;
		T430_ = newIntNodeT__semfold_u44(T429_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T430_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T430_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)119):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T432_;
		T432_ = NIM_NIL;
		T432_ = intersectSets__nimsets_u145((*g_p6).config, a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T432_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T432_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result).info = (*n_p1).info;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)120):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T434_;
		T434_ = NIM_NIL;
		T434_ = unionSets__nimsets_u131((*g_p6).config, a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T434_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T434_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result).info = (*n_p1).info;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)121):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T436_;
		T436_ = NIM_NIL;
		T436_ = diffSets__nimsets_u138((*g_p6).config, a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T436_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T436_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result).info = (*n_p1).info;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)122):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T438_;
		T438_ = NIM_NIL;
		T438_ = symdiffSets__nimsets_u152((*g_p6).config, a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T438_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T438_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result).info = (*n_p1).info;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)123):
	{
		NimStringV2 colontmpD__15;
		NimStringV2 colontmpD__16;
		NimStringV2 colontmpD__17;
		NimStringV2 T441_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T442_;
		colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
		colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
		colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
		T441_.len = 0; T441_.p = NIM_NIL;
		colontmpD__15 = getStrOrChar__ast_u7067(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
		colontmpD__16 = getStrOrChar__ast_u7067(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
		T441_ = rawNewString(colontmpD__15.len + colontmpD__16.len + 0);
appendString((&T441_), colontmpD__15);
appendString((&T441_), colontmpD__16);
		colontmpD__17 = T441_;
		T442_ = NIM_NIL;
		T442_ = newStrNodeT__semfold_u63(colontmpD__17, n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T442_); goto LA440_;}
		eqsink___ast_u3261(&result, T442_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA440_;
		{
			LA440_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__17);
			eqdestroy___system_u2691(colontmpD__16);
			eqdestroy___system_u2691(colontmpD__15);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)132):
	{
		NIM_BOOL T446_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T447_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T448_;
		T446_ = (NIM_BOOL)0;
		T446_ = inSet__nimsets_u8(a_p2, b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T447_ = toInt128__types_u1207(T446_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T448_ = NIM_NIL;
		T448_ = newIntNodeT__semfold_u44(T447_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T448_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T448_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)133):
	{
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)102):
	{
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T453_;
			NIM_BOOL T454_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T457_;
			T453_ = getOrdValue__types_u167(a_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T454_ = (NIM_BOOL)0;
			T454_ = eqeq___int128_u980(T453_, IL64(0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T454_) goto LA455_;
			T457_ = NIM_NIL;
			T457_ = newStrNodeT__semfold_u63(TM__JtgqXuJaW0Uz9aqyNPWIZsw_12, n_p1, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T457_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T457_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA451_;
LA455_: ;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T459_;
			T459_ = NIM_NIL;
			T459_ = newStrNodeT__semfold_u63(TM__JtgqXuJaW0Uz9aqyNPWIZsw_14, n_p1, g_p6);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T459_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T459_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA451_: ;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)103):
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)101):
	{
		NimStringV2 colontmpD__18;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T462_;
		colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
		colontmpD__18 = getStrOrChar__ast_u7067(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA461_;
		T462_ = NIM_NIL;
		T462_ = newStrNodeT__semfold_u63(colontmpD__18, n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T462_); goto LA461_;}
		eqsink___ast_u3261(&result, T462_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA461_;
		{
			LA461_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__18);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)104):
	{
		NimStringV2 colontmpD__19;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T467_;
		colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
		colontmpD__19 = getStrOrChar__ast_u7067(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA466_;
		T467_ = NIM_NIL;
		T467_ = newStrNodeT__semfold_u63(colontmpD__19, n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T467_); goto LA466_;}
		eqsink___ast_u3261(&result, T467_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA466_;
		{
			LA466_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__19);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)105):
	{
		NimStringV2 colontmpD__20;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T472_;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__20 = ordinalValToString__semfold_u161(a_p2, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		T472_ = NIM_NIL;
		T472_ = newStrNodeT__semfold_u63(colontmpD__20, n_p1, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T472_); goto LA471_;}
		eqsink___ast_u3261(&result, T472_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA471_;
		{
			LA471_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__20);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)143):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T476_;
		T476_ = NIM_NIL;
		T476_ = copyTree__ast_u6891(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T476_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T476_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___ast_u3381(&(*result).typField, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)211):
	{
		NimStringV2 colontmpD__21;
		NIM_BOOL T479_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T480_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T481_;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		colontmpD__21 = getStr__ast_u7064(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA478_;
		T479_ = (NIM_BOOL)0;
		T479_ = testCompileOption__commands_u930((*g_p6).config, colontmpD__21, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA478_;
		T480_ = toInt128__types_u1207(T479_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA478_;
		T481_ = NIM_NIL;
		T481_ = newIntNodeT__semfold_u44(T480_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T481_); goto LA478_;}
		eqsink___ast_u3261(&result, T481_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA478_;
		{
			LA478_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__21);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)212):
	{
		NimStringV2 colontmpD__22;
		NimStringV2 colontmpD__23;
		NIM_BOOL T486_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T487_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T488_;
		colontmpD__22.len = 0; colontmpD__22.p = NIM_NIL;
		colontmpD__23.len = 0; colontmpD__23.p = NIM_NIL;
		colontmpD__22 = getStr__ast_u7064(a_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA485_;
		colontmpD__23 = getStr__ast_u7064(b_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA485_;
		T486_ = (NIM_BOOL)0;
		T486_ = testCompileOptionArg__commands_u783((*g_p6).config, colontmpD__22, colontmpD__23, (*n_p1).info);
		if (NIM_UNLIKELY(*nimErr_)) goto LA485_;
		T487_ = toInt128__types_u1207(T486_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA485_;
		T488_ = NIM_NIL;
		T488_ = newIntNodeT__semfold_u44(T487_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T488_); goto LA485_;}
		eqsink___ast_u3261(&result, T488_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA485_;
		{
			LA485_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__23);
			eqdestroy___system_u2691(colontmpD__22);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)92):
	{
		NIM_BOOL T492_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T493_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T494_;
		T492_ = (NIM_BOOL)0;
		T492_ = exprStructuralEquivalent__trees_u63(a_p2, b_p3, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T493_ = toInt128__types_u1207(T492_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T494_ = NIM_NIL;
		T494_ = newIntNodeT__semfold_u44(T493_, n_p1, idgen_p5, g_p6);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T494_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T494_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getAppType__semfold_u647)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!(((*(*g_p1).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)7)))&63U)))!=0)) goto LA3_;
		result = newStrNodeT__semfold_u63(TM__JtgqXuJaW0Uz9aqyNPWIZsw_24, n_p0, g_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		if (!(((*(*g_p1).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)8)))&63U)))!=0)) goto LA6_;
		result = newStrNodeT__semfold_u63(TM__JtgqXuJaW0Uz9aqyNPWIZsw_26, n_p0, g_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
	{
		if (!(((*(*g_p1).config).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)9)))&63U)))!=0)) goto LA9_;
		result = newStrNodeT__semfold_u63(TM__JtgqXuJaW0Uz9aqyNPWIZsw_28, n_p0, g_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA9_: ;
	{
		result = newStrNodeT__semfold_u63(TM__JtgqXuJaW0Uz9aqyNPWIZsw_30, n_p0, g_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (targetDepth_p1 <= (*source_p0).depth);
	if (!(T1_)) goto LA2_;
	T1_ = ((*source_p0).display[targetDepth_p1] == token_p2);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = currException__system_u3629;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	eqcopy___system_u3662(&currException__system_u3629, (*currException__system_u3629).up, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(void, rangeCheck__semfold_u663)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg value_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T4_;
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T6_;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 T10_;
		T3_ = (NIM_BOOL)0;
		T4_ = firstOrd__types_u1182((*g_p2).config, (*n_p0).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = lt___int128_u404(value_p1, T4_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (T3_) goto LA5_;
		T6_ = lastOrd__types_u1298((*g_p2).config, (*n_p0).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = lt___int128_u404(T6_, value_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA5_: ;
		if (!T3_) goto LA7_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T10_.len = 0; T10_.p = NIM_NIL;
		colontmpD_ = dollar___int128_u36(value_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		colontmpD__2 = typeToString__types_u54((*n_p0).typField, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		T10_ = rawNewString(colontmpD_.len + colontmpD__2.len + 19);
appendString((&T10_), TM__JtgqXuJaW0Uz9aqyNPWIZsw_42);
appendString((&T10_), colontmpD_);
appendString((&T10_), TM__JtgqXuJaW0Uz9aqyNPWIZsw_44);
appendString((&T10_), colontmpD__2);
		colontmpD__3 = T10_;
		liMessage__msgs_u1227((*g_p2).config, (*n_p0).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__3, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_45, NIM_FALSE, NIM_FALSE);
		if (NIM_UNLIKELY(*nimErr_)) goto LA9_;
		{
			LA9_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA7_: ;
	}BeforeRet_: ;
}
static N_INLINE(Exception*, getCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	eqcopy___system_u3662(&result, currException__system_u3629, NIM_FALSE);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldDefine__semfold_u832)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NimStringV2 name_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* prag_1;
NIM_BOOL oldNimErrFin87_;
NIM_BOOL oldNimErrFin82_;
NIM_BOOL oldNimErrFin79_;
NIM_BOOL oldNimErrFin125_;
NIM_BOOL oldNimErrFin61_;
NIM_BOOL oldNimErrFin135_;
NIM_BOOL oldNimErrFin143_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	name_1.len = 0; name_1.p = NIM_NIL;
	prag_1 = NIM_NIL;
	result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	eqcopy___system_u2694((&name_1), (*(*s_p1).name).s);
	prag_1 = extractPragma__ast_u4008(s_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!!((prag_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA4_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
			it_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = safeLen__ast_u3197(prag_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				i_2 = ((NI)0);
				{
					while (1) {
						if (!(i_2 < colontmp_)) goto LA9;
						i_1 = i_2;
						eqcopy___ast_u3255(&it_1, (*prag_1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
						{
							NIM_BOOL T12_;
							NIM_BOOL T13_;
							NI T15_;
							tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw word_1;
							T12_ = (NIM_BOOL)0;
							T13_ = (NIM_BOOL)0;
							T13_ = ((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28));
							if (!(T13_)) goto LA14_;
							T15_ = (NI)0;
							T15_ = len__ast_u3190(it_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							T13_ = (T15_ == ((NI)2));
LA14_: ;
							T12_ = T13_;
							if (!(T12_)) goto LA16_;
							T12_ = ((*(*it_1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA16_: ;
							if (!T12_) goto LA17_;
							word_1 = whichKeyword__idents_u360((*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_5.ident);
							if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
							{
								if (!(word_1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)82) || word_1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)81) || word_1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)83) || word_1 == ((tyEnum_TSpecialWord__WgU27rkTe9cqh7pWJYbt9c9bw)131))) goto LA21_;
								{
									if (!((*(*it_1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) || (*(*it_1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)21) || (*(*it_1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22))) goto LA25_;
									eqcopy___system_u2694((&name_1), (*(*it_1)._kind_6.sons.p->data[((NI)1)])._kind_3.strVal);
								}
LA25_: ;
							}
LA21_: ;
						}
LA17_: ;
						i_2 += ((NI)1);
					} LA9: ;
				}
			}
			eqdestroy___ast_u3252(it_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
LA4_: ;
	{
		NIM_BOOL T29_;
		NimStringV2 str_1;
		NimStringV2* T33_;
		T29_ = (NIM_BOOL)0;
		T29_ = isDefined__options_u959((*g_p4).config, name_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T29_) goto LA30_;
		str_1.len = 0; str_1.p = NIM_NIL;
		T33_ = (NimStringV2*)0;
		T33_ = nstTake((*(*g_p4).config).symbols, name_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		eqcopy___system_u2694((&str_1), (*T33_));
		switch ((*s_p1).magic) {
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)264):
		{
			NI T36_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T37_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T38_;
			T36_ = (NI)0;
			T36_ = nsuParseInt(str_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			T37_ = toInt128__types_u1207(T36_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			T38_ = NIM_NIL;
			T38_ = newIntNodeT__semfold_u44(T37_, n_p2, idgen_p3, g_p4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T38_); goto LA35_;}
			eqsink___ast_u3261(&result, T38_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA35_;
			if (NIM_UNLIKELY(*nimErr_)) {
				LA35_:;
				if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
					NimStringV2 colontmpD_;
					NimStringV2 T43_;
					*nimErr_ = NIM_FALSE;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					T43_.len = 0; T43_.p = NIM_NIL;
					T43_ = rawNewString(str_1.len + 53);
appendString((&T43_), TM__JtgqXuJaW0Uz9aqyNPWIZsw_32);
appendString((&T43_), str_1);
appendString((&T43_), TM__JtgqXuJaW0Uz9aqyNPWIZsw_34);
					colontmpD_ = T43_;
					liMessage__msgs_u1227((*g_p4).config, (*s_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_35, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
					{
						LA42_:;
					}
					{
						eqdestroy___system_u2691(colontmpD_);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA40_;
					popCurrentException();
					LA40_:;
				}
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)265):
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T47_;
			T47_ = NIM_NIL;
			T47_ = newStrNodeT__semfold_u63(str_1, n_p2, g_p4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T47_); goto LA32_;}
			eqsink___ast_u3261(&result, T47_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)266):
		{
			NIM_BOOL T50_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T51_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T52_;
			T50_ = (NIM_BOOL)0;
			T50_ = parseBool__pureZstrutils_u1108(str_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T51_ = toInt128__types_u1207(((NI) (T50_)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			T52_ = NIM_NIL;
			T52_ = newIntNodeT__semfold_u44(T51_, n_p2, idgen_p3, g_p4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T52_); goto LA49_;}
			eqsink___ast_u3261(&result, T52_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
			if (NIM_UNLIKELY(*nimErr_)) {
				LA49_:;
				if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
					NimStringV2 colontmpD__2;
					NimStringV2 T57_;
					*nimErr_ = NIM_FALSE;
					colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
					T57_.len = 0; T57_.p = NIM_NIL;
					T57_ = rawNewString(str_1.len + 51);
appendString((&T57_), TM__JtgqXuJaW0Uz9aqyNPWIZsw_37);
appendString((&T57_), str_1);
appendString((&T57_), TM__JtgqXuJaW0Uz9aqyNPWIZsw_38);
					colontmpD__2 = T57_;
					liMessage__msgs_u1227((*g_p4).config, (*s_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_39, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA56_;
					{
						LA56_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__2);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					popCurrentException();
					LA54_:;
				}
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)267):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* rawTyp_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T62_;
			rawTyp_1 = NIM_NIL;
			typ_1 = NIM_NIL;
			eqcopy___ast_u3381(&rawTyp_1, (*s_p1).typ);
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			T62_ = NIM_NIL;
			T62_ = skipTypes__ast_u5379(rawTyp_1, TM__JtgqXuJaW0Uz9aqyNPWIZsw_40);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T62_); goto LA61_;}
			typ_1 = T62_;
			switch ((*typ_1).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T65_;
				T65_ = NIM_NIL;
				T65_ = newStrNodeT__semfold_u63(str_1, n_p2, g_p4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T65_); goto LA63_;}
				eqsink___ast_u3261(&result, T65_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg valX60gensym162__1;
				NI64 T67_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T68_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T69_;
				T67_ = (NI64)0;
				T67_ = nsuParseBiggestInt(str_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				nimZeroMem((void*)(&T68_), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
				T68_ = toInt128__int128_u937(T67_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				valX60gensym162__1 = T68_;
				rangeCheck__semfold_u663(n_p2, valX60gensym162__1, g_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				T69_ = NIM_NIL;
				T69_ = newIntNodeT__semfold_u44(valX60gensym162__1, n_p2, idgen_p3, g_p4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T69_); goto LA63_;}
				eqsink___ast_u3261(&result, T69_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg valX60gensym163__1;
				NU64 T71_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T72_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T73_;
				T71_ = (NU64)0;
				T71_ = nsuParseBiggestUInt(str_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				nimZeroMem((void*)(&T72_), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
				T72_ = toInt128__int128_u717(T71_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				valX60gensym163__1 = T72_;
				rangeCheck__semfold_u663(n_p2, valX60gensym163__1, g_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				T73_ = NIM_NIL;
				T73_ = newIntNodeT__semfold_u44(valX60gensym163__1, n_p2, idgen_p3, g_p4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T73_); goto LA63_;}
				eqsink___ast_u3261(&result, T73_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg valX60gensym164__1;
				NIM_BOOL T75_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T76_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T77_;
				T75_ = (NIM_BOOL)0;
				T75_ = parseBool__pureZstrutils_u1108(str_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				nimZeroMem((void*)(&T76_), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
				T76_ = toInt128__types_u1207(((NI) (T75_)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				valX60gensym164__1 = T76_;
				rangeCheck__semfold_u663(n_p2, valX60gensym164__1, g_p4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
				T77_ = NIM_NIL;
				T77_ = newIntNodeT__semfold_u44(valX60gensym164__1, n_p2, idgen_p3, g_p4);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T77_); goto LA63_;}
				eqsink___ast_u3261(&result, T77_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
			{
				tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_1;
				tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* T80_;
				ident_1 = NIM_NIL;
				T80_ = NIM_NIL;
				T80_ = getIdent__idents_u206((*g_p4).cache, str_1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___idents_u155(T80_); goto LA79_;}
				ident_1 = T80_;
				{
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_1;
					e_1 = NIM_NIL;
					{
						NI i_3;
						NI colontmp__2;
						NI T84_;
						NI i_4;
						i_3 = (NI)0;
						colontmp__2 = (NI)0;
						T84_ = (NI)0;
						T84_ = safeLen__ast_u3197((*typ_1).n);
						if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
						colontmp__2 = T84_;
						i_4 = ((NI)0);
						{
							while (1) {
								tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* es_1;
								NIM_BOOL colontmpD__3;
								NIM_BOOL colontmpD__4;
								NIM_BOOL match_1;
								if (!(i_4 < colontmp__2)) goto LA86;
								es_1 = NIM_NIL;
								colontmpD__3 = (NIM_BOOL)0;
								colontmpD__4 = (NIM_BOOL)0;
								i_3 = i_4;
								eqcopy___ast_u3255(&e_1, (*(*typ_1).n)._kind_6.sons.p->data[i_3]);
								if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
								{
									if (!!(((*e_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA90_;
									internalErrorImpl__msgs_u1598((*g_p4).config, unknownLineInfo__lineinfos_u364, TM__JtgqXuJaW0Uz9aqyNPWIZsw_47, TM__JtgqXuJaW0Uz9aqyNPWIZsw_48);
									if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
								}
LA90_: ;
								eqcopy___ast_u4577(&es_1, (*e_1)._kind_4.sym);
								if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
								{
									if (!((*es_1).ast == 0)) goto LA94_;
									colontmpD__3 = ((*(*es_1).name).id == (*ident_1).id);
									match_1 = colontmpD__3;
								}
								goto LA92_;
LA94_: ;
								{
									colontmpD__4 = eqStrings((*(*es_1).ast)._kind_3.strVal, str_1);
									match_1 = colontmpD__4;
								}
LA92_: ;
								{
									tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg valX60gensym168__1;
									tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T101_;
									tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T102_;
									if (!match_1) goto LA99_;
									nimZeroMem((void*)(&T101_), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
									T101_ = toInt128__types_u1207((*es_1).position);
									if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
									valX60gensym168__1 = T101_;
									rangeCheck__semfold_u663(n_p2, valX60gensym168__1, g_p4);
									if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
									T102_ = NIM_NIL;
									T102_ = newIntNodeT__semfold_u44(valX60gensym168__1, n_p2, idgen_p3, g_p4);
									if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T102_); goto LA87_;}
									eqsink___ast_u3261(&result, T102_);
									if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
									eqdestroy___ast_u4574(es_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
									eqdestroy___ast_u3252(e_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
									goto LA81;
								}
LA99_: ;
								i_4 += ((NI)1);
								{
									LA87_:;
								}
								{
									oldNimErrFin87_ = *nimErr_; *nimErr_ = NIM_FALSE;
									eqdestroy___ast_u4574(es_1);
									if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
									*nimErr_ = oldNimErrFin87_;
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
							} LA86: ;
						}
					}
					{
						LA82_:;
					}
					{
						oldNimErrFin82_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(e_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
						*nimErr_ = oldNimErrFin82_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA79_;
				} LA81: ;
				{
					tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* T111_;
					NimStringV2 T112_;
					if (!(result == 0)) goto LA109_;
					T111_ = NIM_NIL;
					T111_ = (tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) nimNewObj(sizeof(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA), NIM_ALIGNOF(tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA));
					(*T111_).Sup.Sup.Sup.m_type = (&NTIv2__S29bKZF4TUS33IR7ZXb7fFA_);
					(*T111_).Sup.Sup.name = "ValueError";
					T112_.len = 0; T112_.p = NIM_NIL;
					T112_ = rawNewString(str_1.len + 20);
appendString((&T112_), TM__JtgqXuJaW0Uz9aqyNPWIZsw_50);
appendString((&T112_), str_1);
					(*T111_).Sup.Sup.message = T112_;
					(*T111_).Sup.Sup.parent = ((Exception*) NIM_NIL);
					raiseExceptionEx((Exception*)T111_, "ValueError", "foldDefine", "semfold.nim", 592);
goto LA79_;
				}
LA109_: ;
				{
					LA79_:;
				}
				{
					oldNimErrFin79_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___idents_u155(ident_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
					*nimErr_ = oldNimErrFin79_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			}
			break;
			default:
			{
				NimStringV2 colontmpD__5;
				NimStringV2 colontmpD__6;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T117_;
				NimStringV2 T118_;
				NimStringV2 T119_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				T118_.len = 0; T118_.p = NIM_NIL;
				T118_ = typeToString__types_u54(rawTyp_1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T118_); goto LA116_;}
				colontmpD__5 = T118_;
				T117_[0] = colontmpD__5;
				T117_[1] = name_1;
				T119_.len = 0; T119_.p = NIM_NIL;
				T119_ = nsuFormatOpenArray(TM__JtgqXuJaW0Uz9aqyNPWIZsw_52, T117_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T119_); goto LA116_;}
				colontmpD__6 = T119_;
				liMessage__msgs_u1227((*g_p4).config, (*s_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__6, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_53, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA116_;
				{
					LA116_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__6);
					eqdestroy___system_u2691(colontmpD__5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA63_;
			}
			break;
			}
			if (NIM_UNLIKELY(*nimErr_)) {
				LA63_:;
				if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 1871340544)) {
					tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA* e_2;
					NimStringV2 colontmpD__7;
					NimStringV2 colontmpD__8;
					Exception* T126_;
					tyArray__dyW7vpmfeTYw8kX3EXuaJA T127_;
					NimStringV2 T128_;
					NimStringV2 T129_;
					*nimErr_ = NIM_FALSE;
					e_2 = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					T126_ = NIM_NIL;
					T126_ = getCurrentException();
					e_2 = ((tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA*) (T126_));
					T127_[0] = name_1;
					T128_.len = 0; T128_.p = NIM_NIL;
					T128_ = typeToString__types_u54(rawTyp_1, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T128_); goto LA125_;}
					colontmpD__7 = T128_;
					T127_[1] = colontmpD__7;
					T127_[2] = (*e_2).Sup.Sup.message;
					T129_.len = 0; T129_.p = NIM_NIL;
					T129_ = nsuFormatOpenArray(TM__JtgqXuJaW0Uz9aqyNPWIZsw_55, T127_, 3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T129_); goto LA125_;}
					colontmpD__8 = T129_;
					liMessage__msgs_u1227((*g_p4).config, (*s_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__8, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_56, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
					{
						LA125_:;
					}
					{
						oldNimErrFin125_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___system_u2691(colontmpD__8);
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___pureZparseutils_u367(e_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
						*nimErr_ = oldNimErrFin125_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA123_;
					popCurrentException();
					LA123_:;
				}
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA61_;
			{
				LA61_:;
			}
			{
				oldNimErrFin61_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(typ_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
				eqdestroy___ast_u3378(rawTyp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
				*nimErr_ = oldNimErrFin61_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
		break;
		default:
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__9;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T136_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T137_;
			colontmpD__9 = NIM_NIL;
			T136_ = NIM_NIL;
			T136_ = astdef__ast_u4596(s_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T136_); goto LA135_;}
			colontmpD__9 = T136_;
			T137_ = NIM_NIL;
			T137_ = copyTree__ast_u6891(colontmpD__9);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T137_); goto LA135_;}
			eqsink___ast_u3261(&result, T137_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
			{
				LA135_:;
			}
			{
				oldNimErrFin135_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
				*nimErr_ = oldNimErrFin135_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
		}
		break;
		}
		{
			LA32_:;
		}
		{
			eqdestroy___system_u2691(str_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA27_;
LA30_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__10;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T144_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T145_;
		colontmpD__10 = NIM_NIL;
		T144_ = NIM_NIL;
		T144_ = astdef__ast_u4596(s_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T144_); goto LA143_;}
		colontmpD__10 = T144_;
		T145_ = NIM_NIL;
		T145_ = copyTree__ast_u6891(colontmpD__10);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T145_); goto LA143_;}
		eqsink___ast_u3261(&result, T145_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA143_;
		{
			if (!!((result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA148_;
			(*result).info = (*n_p2).info;
		}
LA148_: ;
		{
			LA143_:;
		}
		{
			oldNimErrFin143_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(colontmpD__10);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			*nimErr_ = oldNimErrFin143_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA27_: ;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(prag_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(name_1);
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, base__ast_u5351)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, (*t_p0).sons.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isIntLit__types_u179)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31));
	if (!(T2_)) goto LA3_;
	T2_ = !(((*t_p0).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*t_p0).n).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getConstIfExpr__semfold_u592)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* c_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin10_;
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp_)) goto LA3;
				it_1 = NIM_NIL;
				i_1 = i_2;
				eqcopy___ast_u3255(&it_1, (*n_p1)._kind_6.sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				{
					NI T7_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* e_1;
					T7_ = (NI)0;
					T7_ = len__ast_u3190(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
					if (!(T7_ == ((NI)2))) goto LA8_;
					e_1 = NIM_NIL;
					e_1 = getConstExpr__semfold_u68(c_p0, (*it_1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					{
						if (!(e_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA13_;
						result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
						eqdestroy___ast_u3252(e_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						eqdestroy___ast_u3252(it_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA13_: ;
					{
						tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T17_;
						NIM_BOOL T18_;
						T17_ = getOrdValue__types_u167(e_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						T18_ = (NIM_BOOL)0;
						T18_ = eqeq___int128_u980(T17_, IL64(0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						if (!!(T18_)) goto LA19_;
						{
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T25_;
							if (!(result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA23_;
							T25_ = NIM_NIL;
							T25_ = getConstExpr__semfold_u68(c_p0, (*it_1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T25_); goto LA10_;}
							eqsink___ast_u3261(&result, T25_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
							{
								if (!(result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA28_;
								eqdestroy___ast_u3252(e_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
								eqdestroy___ast_u3252(it_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto BeforeRet_;
							}
LA28_: ;
						}
LA23_: ;
					}
LA19_: ;
					{
						LA10_:;
					}
					{
						oldNimErrFin10_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(e_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
						*nimErr_ = oldNimErrFin10_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
				goto LA5_;
LA8_: ;
				{
					NI T33_;
					T33_ = (NI)0;
					T33_ = len__ast_u3190(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
					if (!(T33_ == ((NI)1))) goto LA34_;
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T40_;
						if (!(result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA38_;
						T40_ = NIM_NIL;
						T40_ = getConstExpr__semfold_u68(c_p0, (*it_1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T40_); goto LA4_;}
						eqsink___ast_u3261(&result, T40_);
						if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
					}
LA38_: ;
				}
				goto LA5_;
LA34_: ;
				{
					internalErrorImpl__msgs_u1598((*g_p3).config, (*it_1).info, TM__JtgqXuJaW0Uz9aqyNPWIZsw_58, TM__JtgqXuJaW0Uz9aqyNPWIZsw_59);
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				}
LA5_: ;
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(it_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, contains__semfold_u1019)(tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww s_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg value_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (s_p0.a <= value_p1);
	if (!(T1_)) goto LA2_;
	T1_ = (value_p1 <= s_p0.b);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww, dotdot___semfold_u987)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg a_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg b_p1) {
	tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getArrayConstr__semfold_u717)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*n_p1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA3_;
		eqcopy___ast_u3255(&result, n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = getConstExpr__semfold_u68(m_p0, n_p1, idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!(result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA8_;
			eqcopy___ast_u3255(&result, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA8_: ;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, magicCall__semfold_u625)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* c_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	s_1 = NIM_NIL;
	a_1 = NIM_NIL;
	b_1 = NIM_NIL;
	c_1 = NIM_NIL;
	{
		NI T4_;
		T4_ = (NI)0;
		T4_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T4_ <= ((NI)1))) goto LA5_;
		eqdestroy___ast_u3252(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA5_: ;
	eqcopy___ast_u4577(&s_1, (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	a_1 = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	b_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	c_1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	{
		if (!(a_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA9_;
		eqdestroy___ast_u3252(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA9_: ;
	{
		NI T13_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
		T13_ = (NI)0;
		T13_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)2) < T13_)) goto LA14_;
		T16_ = NIM_NIL;
		T16_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)2)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T16_); goto LA1_;}
		eqsink___ast_u3261(&b_1, T16_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			if (!(b_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA19_;
			eqdestroy___ast_u3252(c_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(a_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u4574(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA19_: ;
		{
			NI T23_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T26_;
			T23_ = (NI)0;
			T23_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!(((NI)3) < T23_)) goto LA24_;
			T26_ = NIM_NIL;
			T26_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)3)], idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T26_); goto LA1_;}
			eqsink___ast_u3261(&c_1, T26_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				if (!(c_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA29_;
				eqdestroy___ast_u3252(c_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u3252(b_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u3252(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				eqdestroy___ast_u4574(s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				goto BeforeRet_;
			}
LA29_: ;
		}
LA24_: ;
	}
LA14_: ;
	result = evalOp__semfold_u73((*s_1).magic, n_p1, a_1, b_1, c_1, idgen_p2, g_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(c_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(a_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldConStrStr__semfold_u804)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin4_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), (*n_p1).info, (*n_p1).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___system_u2700((&(*result)._kind_3.strVal), TM__JtgqXuJaW0Uz9aqyNPWIZsw_67);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = len__ast_u3190(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		i_2 = ((NI)1);
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
				NimStringV2 colontmpD_;
				if (!(i_2 < colontmp_)) goto LA3;
				a_1 = NIM_NIL;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				i_1 = i_2;
				a_1 = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[i_1], idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				{
					if (!(a_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA7_;
					result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
					eqdestroy___system_u2691(colontmpD_);
					eqdestroy___ast_u3252(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA7_: ;
				colontmpD_ = getStrOrChar__ast_u7067(a_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				prepareAdd((&(*result)._kind_3.strVal), colontmpD_.len + 0);
appendString((&(*result)._kind_3.strVal), colontmpD_);
				i_2 += ((NI)1);
				{
					LA4_:;
				}
				{
					oldNimErrFin4_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___system_u2691(colontmpD_);
					eqdestroy___ast_u3252(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin4_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, leValueConv__semfold_u621)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	switch ((*a_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		switch ((*b_p1).kind) {
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T3_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T4_;
			T3_ = getInt__ast_u7046(a_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T4_ = getInt__ast_u7046(b_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = lteq___int128_u408(T3_, T4_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
		{
			NF T6_;
			T6_ = (NF)0;
			T6_ = round((*b_p1)._kind_2.floatVal);
			result = ((*a_p0)._kind_1.intVal <= ((NI64) ((((NI) (((NI64) (T6_))))))));
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		switch ((*b_p1).kind) {
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
		{
			result = ((*a_p0)._kind_2.floatVal <= (*b_p1)._kind_2.floatVal);
		}
		break;
		case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T11_;
			NF T12_;
			T11_ = getInt__ast_u7046(b_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T12_ = (NF)0;
			T12_ = toFloat64__int128_u1022(T11_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			result = ((*a_p0)._kind_2.floatVal <= T12_);
		}
		break;
		default:
		{
			result = NIM_FALSE;
		}
		break;
		}
	}
	break;
	default:
	{
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldConv__semfold_u674)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3, NIM_BOOL check_p4) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dstTyp_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* srcTyp_1;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	dstTyp_1 = NIM_NIL;
	srcTyp_1 = NIM_NIL;
	dstTyp_1 = skipTypes__ast_u5379((*n_p0).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_77);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	srcTyp_1 = skipTypes__ast_u5379((*a_p1).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_77);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*dstTyp_1).kind) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		switch ((*srcTyp_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
		{
			NF T4_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T5_;
			T4_ = (NF)0;
			T4_ = getFloat__ast_u7061(a_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T5_ = toInt128__semfold_u691(!((T4_ == 0.0)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			result = newIntNodeT__semfold_u44(T5_, n_p0, idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T7_;
			NIM_BOOL T8_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T9_;
			T7_ = getOrdValue__types_u167(a_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T8_ = (NIM_BOOL)0;
			T8_ = eqeq___int128_u980(T7_, IL64(0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T9_ = toInt128__semfold_u691(!(T8_));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			result = newIntNodeT__semfold_u44(T9_, n_p0, idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
		{
			eqcopy___ast_u3255(&result, a_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqcopy___ast_u3381(&(*result).typField, (*n_p0).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
			NimStringV2 colontmpD_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD_ = dollar___ast_u182((*srcTyp_1).kind);
			raiseAssert__stdZassertions_u15(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqdestroy___system_u2691(colontmpD_);
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		switch ((*srcTyp_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
		{
			NF T14_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T15_;
			T14_ = (NF)0;
			T14_ = getFloat__ast_u7061(a_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T15_ = toInt128__int128_u1039(T14_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			result = newIntNodeT__semfold_u44(T15_, n_p0, idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg val_1;
			val_1 = getOrdValue__types_u167(a_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				NI64 T21_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T22_;
				if (!((*dstTyp_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*dstTyp_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44))) goto LA19_;
				T21_ = (NI64)0;
				T21_ = getSize__types_u3397((*g_p3).config, dstTyp_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				T22_ = maskBytes__int128_u1074(val_1, ((NI) (T21_)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				result = newIntNodeT__semfold_u44(T22_, n_p0, idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				transitionIntKind__ast_u6792(result, ((tyEnum_TNodeKind__Vj1MpVCa7BBwvA5h87QXag)11));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA17_;
LA19_: ;
			{
				{
					if (!check_p4) goto LA26_;
					rangeCheck__semfold_u663(n_p0, val_1, g_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				}
LA26_: ;
				result = newIntNodeT__semfold_u44(val_1, n_p0, idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA17_: ;
		}
		break;
		default:
		{
			eqcopy___ast_u3255(&result, a_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqcopy___ast_u3381(&(*result).typField, (*n_p0).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		}
		{
			NIM_BOOL T31_;
			NIM_BOOL T32_;
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T37_;
			T31_ = (NIM_BOOL)0;
			T32_ = (NIM_BOOL)0;
			T32_ = check_p4;
			if (!(T32_)) goto LA33_;
			T32_ = ((*result).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) && (*result).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15));
LA33_: ;
			T31_ = T32_;
			if (!(T31_)) goto LA34_;
			T31_ = !(((*dstTyp_1).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*dstTyp_1).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44)));
LA34_: ;
			if (!T31_) goto LA35_;
			T37_ = getInt__ast_u7046(result);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			rangeCheck__semfold_u663(n_p0, T37_, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA35_: ;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
	{
		switch ((*srcTyp_1).kind) {
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) ... ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
		case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T40_;
			NF T41_;
			T40_ = getOrdValue__types_u167(a_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T41_ = (NF)0;
			T41_ = toFloat64__int128_u1022(T40_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			result = newFloatNodeT__semfold_u54(T41_, n_p0, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		default:
		{
			eqcopy___ast_u3255(&result, a_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			eqcopy___ast_u3381(&(*result).typField, (*n_p0).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		break;
		}
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
	break;
	default:
	{
		eqcopy___ast_u3255(&result, a_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqcopy___ast_u3381(&(*result).typField, (*n_p0).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(srcTyp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(dstTyp_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldArrayAccess__semfold_u731)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_1;
	NI64 idx_1;
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T12_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	x_1 = NIM_NIL;
	colontmpD_ = NIM_NIL;
	y_1 = NIM_NIL;
	x_1 = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = (x_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (T4_) goto LA5_;
		colontmpD_ = skipTypes__ast_u5379((*x_1).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_78);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = ((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8));
LA5_: ;
		if (!T4_) goto LA6_;
		eqdestroy___ast_u3252(y_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA6_: ;
	y_1 = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(y_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA10_;
		eqdestroy___ast_u3252(y_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA10_: ;
	T12_ = getOrdValue__types_u167(y_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	idx_1 = toInt64__int128_u53(T12_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*x_1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
	{
		{
			NIM_BOOL T16_;
			NI T18_;
			T16_ = (NIM_BOOL)0;
			T16_ = (IL64(0) <= idx_1);
			if (!(T16_)) goto LA17_;
			T18_ = (NI)0;
			T18_ = len__ast_u3190(x_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T16_ = (idx_1 < ((NI64) (T18_)));
LA17_: ;
			if (!T16_) goto LA19_;
			eqcopy___ast_u3255(&result, (*x_1)._kind_6.sons.p->data[idx_1]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			{
				if (!((*result).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA23_;
				eqcopy___ast_u3255(&result, (*result)._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
LA23_: ;
		}
		goto LA14_;
LA19_: ;
		{
			result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		}
LA14_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
	{
		tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T27_;
		NI64 T28_;
		T27_ = firstOrd__types_u1182((*g_p3).config, (*x_1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T28_ = (NI64)0;
		T28_ = toInt64__int128_u53(T27_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		idx_1 -= T28_;
		{
			NIM_BOOL T31_;
			NI T33_;
			T31_ = (NIM_BOOL)0;
			T31_ = (IL64(0) <= idx_1);
			if (!(T31_)) goto LA32_;
			T33_ = (NI)0;
			T33_ = len__ast_u3190(x_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T31_ = (idx_1 < ((NI64) (T33_)));
LA32_: ;
			if (!T31_) goto LA34_;
			eqcopy___ast_u3255(&result, (*x_1)._kind_6.sons.p->data[((NI) (idx_1))]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA29_;
LA34_: ;
		{
			result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		}
LA29_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		result = newNodeIT__ast_u4112(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5), (*x_1).info, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			NIM_BOOL T40_;
			T40_ = (NIM_BOOL)0;
			T40_ = (IL64(0) <= idx_1);
			if (!(T40_)) goto LA41_;
			T40_ = (idx_1 < ((NI64) ((*x_1)._kind_3.strVal.len)));
LA41_: ;
			if (!T40_) goto LA42_;
			(*result)._kind_1.intVal = ((NI64) (((NU8)((*x_1)._kind_3.strVal.p->data[((NI) (idx_1))]))));
		}
		goto LA38_;
LA42_: ;
		{
			eqsink___ast_u3261(&result, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA38_: ;
	}
	break;
	default:
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
	break;
	}
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3252(y_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3378(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, foldFieldAccess__semfold_u763)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* x_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* field_1;
	NimStringV2 colontmpD_;
	NimStringV2 T27_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	x_1 = NIM_NIL;
	field_1 = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	{
		if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA4_;
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u4574(field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	x_1 = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (x_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (T8_) goto LA9_;
		T8_ = !(((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38) || (*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37) || (*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160)));
LA9_: ;
		if (!T8_) goto LA10_;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u4574(field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA10_: ;
	eqcopy___ast_u4577(&field_1, (*(*n_p1)._kind_6.sons.p->data[((NI)1)])._kind_4.sym);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI i_1;
		NI colontmp_;
		NI colontmp__2;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp__2 = (NI)0;
		colontmp_ = ((*x_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)38));
		colontmp__2 = len__ast_u3190(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		i_2 = colontmp_;
		{
			while (1) {
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* it_1;
				if (!(i_2 < colontmp__2)) goto LA14;
				it_1 = NIM_NIL;
				i_1 = i_2;
				it_1 = (*x_1)._kind_6.sons.p->data[i_1];
				{
					if (!!(((*it_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34)))) goto LA17_;
					eqcopy___ast_u3255(&result, (*x_1)._kind_6.sons.p->data[(*field_1).position]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					{
						if (!((*result).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA21_;
						eqcopy___ast_u3255(&result, (*result)._kind_6.sons.p->data[((NI)1)]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					}
LA21_: ;
					eqdestroy___system_u2691(colontmpD_);
					eqdestroy___ast_u4574(field_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___ast_u3252(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA17_: ;
				{
					if (!((*(*(*(*it_1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym).name).id == (*(*field_1).name).id)) goto LA25_;
					eqcopy___ast_u3255(&result, (*(*x_1)._kind_6.sons.p->data[i_1])._kind_6.sons.p->data[((NI)1)]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					eqdestroy___system_u2691(colontmpD_);
					eqdestroy___ast_u4574(field_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					eqdestroy___ast_u3252(x_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					goto BeforeRet_;
				}
LA25_: ;
				i_2 += ((NI)1);
			} LA14: ;
		}
	}
	T27_.len = 0; T27_.p = NIM_NIL;
	T27_ = rawNewString((*(*field_1).name).s.len + 17);
appendString((&T27_), TM__JtgqXuJaW0Uz9aqyNPWIZsw_80);
appendString((&T27_), (*(*field_1).name).s);
	colontmpD_ = T27_;
	liMessage__msgs_u1227((*g_p3).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD_, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_81, NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___ast_u4574(field_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u3252(x_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getConstExpr__semfold_u68)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p3) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin30_;
NIM_BOOL oldNimErrFin2_;
NIM_BOOL oldNimErrFin92_;
NIM_BOOL oldNimErrFin125_;
NIM_BOOL oldNimErrFin114_;
NIM_BOOL oldNimErrFin134_;
NIM_BOOL oldNimErrFin108_;
NIM_BOOL oldNimErrFin148_;
NIM_BOOL oldNimErrFin165_;
NIM_BOOL oldNimErrFin176_;
NIM_BOOL oldNimErrFin187_;
NIM_BOOL oldNimErrFin231_;
NIM_BOOL oldNimErrFin226_;
NIM_BOOL oldNimErrFin242_;
NIM_BOOL oldNimErrFin271_;
NIM_BOOL oldNimErrFin266_;
NIM_BOOL oldNimErrFin289_;
NIM_BOOL oldNimErrFin284_;
NIM_BOOL oldNimErrFin300_;
NIM_BOOL oldNimErrFin326_;
NIM_BOOL oldNimErrFin335_;
NIM_BOOL oldNimErrFin345_;
NIM_BOOL oldNimErrFin356_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	switch ((*n_p1).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_1;
		s_1 = NIM_NIL;
		eqcopy___ast_u4577(&s_1, (*n_p1)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		switch ((*s_1).kind) {
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T4_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T5_;
			T4_ = toInt128__types_u1207((*s_1).position);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			T5_ = NIM_NIL;
			T5_ = newIntNodeT__semfold_u44(T4_, n_p1, idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T5_); goto LA2_;}
			eqsink___ast_u3261(&result, T5_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10):
		{
			switch ((*s_1).magic) {
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)201):
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T8_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T9_;
				T8_ = toInt128__types_u1207((((*m_p0).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14)))&63U)))!=0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T9_ = NIM_NIL;
				T9_ = newIntNodeT__semfold_u44(T8_, n_p1, idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T9_); goto LA2_;}
				eqsink___ast_u3261(&result, T9_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)202):
			{
				NimStringV2 colontmpD_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T11_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD_ = getDateStr__options_u643();
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T11_ = NIM_NIL;
				T11_ = newStrNodeT__semfold_u63(colontmpD_, n_p1, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T11_); goto LA2_;}
				eqsink___ast_u3261(&result, T11_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				eqdestroy___system_u2691(colontmpD_);
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)203):
			{
				NimStringV2 colontmpD__2;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T13_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__2 = getClockStr__options_u651();
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T13_ = NIM_NIL;
				T13_ = newStrNodeT__semfold_u63(colontmpD__2, n_p1, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T13_); goto LA2_;}
				eqsink___ast_u3261(&result, T13_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				eqdestroy___system_u2691(colontmpD__2);
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)205):
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T15_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
				T15_ = toInt128__types_u1207(CPU__platform_u740[((*(*g_p3).config).target.targetCPU)- 1].Field2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T16_ = NIM_NIL;
				T16_ = newIntNodeT__semfold_u44(T15_, n_p1, idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T16_); goto LA2_;}
				eqsink___ast_u3261(&result, T16_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)206):
			{
				NimStringV2 colontmpD__3;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T18_;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__3 = nsuToLowerAsciiStr(OS__platform_u534[((*(*g_p3).config).target.targetOS)- 1].Field0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T18_ = NIM_NIL;
				T18_ = newStrNodeT__semfold_u63(colontmpD__3, n_p1, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T18_); goto LA2_;}
				eqsink___ast_u3261(&result, T18_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				eqdestroy___system_u2691(colontmpD__3);
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)207):
			{
				NimStringV2 colontmpD__4;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T20_;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__4 = nsuToLowerAsciiStr(CPU__platform_u740[((*(*g_p3).config).target.targetCPU)- 1].Field0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T20_ = NIM_NIL;
				T20_ = newStrNodeT__semfold_u63(colontmpD__4, n_p1, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T20_); goto LA2_;}
				eqsink___ast_u3261(&result, T20_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				eqdestroy___system_u2691(colontmpD__4);
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)208):
			{
				NimStringV2 colontmpD__5;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T22_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__5 = nsuToLowerAsciiStr(OS__platform_u534[((*(*g_p3).config).target.hostOS)- 1].Field0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T22_ = NIM_NIL;
				T22_ = newStrNodeT__semfold_u63(colontmpD__5, n_p1, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T22_); goto LA2_;}
				eqsink___ast_u3261(&result, T22_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				eqdestroy___system_u2691(colontmpD__5);
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)209):
			{
				NimStringV2 colontmpD__6;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T24_;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				colontmpD__6 = nsuToLowerAsciiStr(CPU__platform_u740[((*(*g_p3).config).target.hostCPU)- 1].Field0);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				T24_ = NIM_NIL;
				T24_ = newStrNodeT__semfold_u63(colontmpD__6, n_p1, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T24_); goto LA2_;}
				eqsink___ast_u3261(&result, T24_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				eqdestroy___system_u2691(colontmpD__6);
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)210):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T26_;
				T26_ = NIM_NIL;
				T26_ = getAppType__semfold_u647(n_p1, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T26_); goto LA2_;}
				eqsink___ast_u3261(&result, T26_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			break;
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)264):
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)265):
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)266):
			case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)267):
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T28_;
				T28_ = NIM_NIL;
				T28_ = foldDefine__semfold_u832(m_p0, s_1, n_p1, idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T28_); goto LA2_;}
				eqsink___ast_u3261(&result, T28_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			break;
			default:
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__7;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T31_;
				colontmpD__7 = NIM_NIL;
				colontmpD__7 = astdef__ast_u4596(s_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				T31_ = NIM_NIL;
				T31_ = copyTree__ast_u6891(colontmpD__7);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T31_); goto LA30_;}
				eqsink___ast_u3261(&result, T31_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				{
					if (!!((result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA34_;
					(*result).info = (*n_p1).info;
				}
LA34_: ;
				{
					LA30_:;
				}
				{
					oldNimErrFin30_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(colontmpD__7);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					*nimErr_ = oldNimErrFin30_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			break;
			}
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12):
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13):
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14):
		{
			eqcopy___ast_u3255(&result, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3):
		{
			{
				NIM_BOOL T42_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T46_;
				T42_ = (NIM_BOOL)0;
				T42_ = !(((*s_1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
				if (!(T42_)) goto LA43_;
				T42_ = ((*(*s_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8));
LA43_: ;
				if (!T42_) goto LA44_;
				T46_ = NIM_NIL;
				T46_ = newSymNodeTypeDesc__semfold_u820(s_1, idgen_p2, (*n_p1).info);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T46_); goto LA2_;}
				eqsink___ast_u3261(&result, T46_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA44_: ;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7):
		{
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T52_;
				if (!!(((*s_1).typ == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA50_;
				T52_ = NIM_NIL;
				T52_ = newSymNodeTypeDesc__semfold_u820(s_1, idgen_p2, (*n_p1).info);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T52_); goto LA2_;}
				eqsink___ast_u3261(&result, T52_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA50_: ;
		}
		break;
		case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)4):
		{
			{
				if (!((*(*s_1).typ).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60))) goto LA56_;
				{
					NIM_BOOL T60_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T64_;
					T60_ = (NIM_BOOL)0;
					T60_ = !(((*(*s_1).typ).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
					if (!(T60_)) goto LA61_;
					T60_ = !((((*(*s_1).typ).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)9)))&63U)))!=0));
LA61_: ;
					if (!T60_) goto LA62_;
					eqcopy___ast_u3255(&result, (*(*s_1).typ).n);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
					T64_ = NIM_NIL;
					T64_ = base__ast_u5351((*s_1).typ);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T64_); goto LA2_;}
					eqsink___ast_u3387(&(*result).typField, T64_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				}
LA62_: ;
			}
			goto LA54_;
LA56_: ;
			{
				NIM_BOOL T66_;
				T66_ = (NIM_BOOL)0;
				T66_ = isIntLit__types_u179((*s_1).typ);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
				if (!T66_) goto LA67_;
				eqcopy___ast_u3255(&result, (*(*s_1).typ).n);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
			goto LA54_;
LA67_: ;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T70_;
				T70_ = NIM_NIL;
				T70_ = newSymNodeTypeDesc__semfold_u820(s_1, idgen_p2, (*n_p1).info);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T70_); goto LA2_;}
				eqsink___ast_u3261(&result, T70_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA2_;
			}
LA54_: ;
		}
		break;
		default:
		{
		}
		break;
		}
		{
			LA2_:;
		}
		{
			oldNimErrFin2_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u4574(s_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin2_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T75_;
		T75_ = NIM_NIL;
		T75_ = copyNode__ast_u6736(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T75_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T75_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)48):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T77_;
		T77_ = NIM_NIL;
		T77_ = getConstIfExpr__semfold_u592(m_p0, n_p1, idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T77_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T77_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32):
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_2;
		s_2 = NIM_NIL;
		{
			if (!!(((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3)))) goto LA81_;
			goto BeforeRet_;
		}
LA81_: ;
		s_2 = (*(*n_p1)._kind_6.sons.p->data[((NI)0)])._kind_4.sym;
		{
			NIM_BOOL T85_;
			T85_ = (NIM_BOOL)0;
			T85_ = !(((*s_2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12)));
			if (!(T85_)) goto LA86_;
			T85_ = !(((*s_2).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13)));
LA86_: ;
			if (!T85_) goto LA87_;
			goto BeforeRet_;
		}
LA87_: ;
		switch ((*s_2).magic) {
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0):
		{
			goto BeforeRet_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)8):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__8;
			colontmpD__8 = NIM_NIL;
			{
				tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T95_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T96_;
				NIM_BOOL T97_;
				NF T100_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T101_;
				T95_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38));
				T96_ = NIM_NIL;
				T96_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_60);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T96_); goto LA92_;}
				colontmpD__8 = T96_;
				T97_ = (NIM_BOOL)0;
				T97_ = contains__semfold_u1019(T95_, (*colontmpD__8).kind);
				if (!T97_) goto LA98_;
				T100_ = (NF)0;
				T100_ = firstFloat__types_u1268((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
				T101_ = NIM_NIL;
				T101_ = newFloatNodeT__semfold_u54(T100_, n_p1, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T101_); goto LA92_;}
				eqsink___ast_u3261(&result, T101_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
			}
			goto LA93_;
LA98_: ;
			{
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T103_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T104_;
				T103_ = firstOrd__types_u1182((*g_p3).config, (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
				T104_ = NIM_NIL;
				T104_ = newIntNodeT__semfold_u44(T103_, n_p1, idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T104_); goto LA92_;}
				eqsink___ast_u3261(&result, T104_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA92_;
			}
LA93_: ;
			{
				LA92_:;
			}
			{
				oldNimErrFin92_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__8);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				*nimErr_ = oldNimErrFin92_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9):
		{
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__9;
			colontmpD__9 = NIM_NIL;
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T111_;
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__10;
				T111_ = NIM_NIL;
				T111_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_61);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T111_); goto LA108_;}
				colontmpD__9 = T111_;
				if (!!(((*colontmpD__9).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24) || (*colontmpD__9).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28) || (*colontmpD__9).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29) || (*colontmpD__9).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27) || (*colontmpD__9).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48)))) goto LA112_;
				colontmpD__10 = NIM_NIL;
				{
					tyObject_HSlice__Td0KDtM8kU0p7CVwrbJeww T117_;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T118_;
					NIM_BOOL T119_;
					NF T122_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T123_;
					T117_ = dotdot___semfold_u987(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36), ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38));
					T118_ = NIM_NIL;
					T118_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_60);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T118_); goto LA114_;}
					colontmpD__10 = T118_;
					T119_ = (NIM_BOOL)0;
					T119_ = contains__semfold_u1019(T117_, (*colontmpD__10).kind);
					if (!T119_) goto LA120_;
					T122_ = (NF)0;
					T122_ = lastFloat__types_u1400((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField);
					if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
					T123_ = NIM_NIL;
					T123_ = newFloatNodeT__semfold_u54(T122_, n_p1, g_p3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T123_); goto LA114_;}
					eqsink___ast_u3261(&result, T123_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
				}
				goto LA115_;
LA120_: ;
				{
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__11;
					tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T126_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T127_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T128_;
					colontmpD__11 = NIM_NIL;
					T126_ = NIM_NIL;
					T126_ = skipTypes__ast_u5379((*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField, TM__JtgqXuJaW0Uz9aqyNPWIZsw_62);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T126_); goto LA125_;}
					colontmpD__11 = T126_;
					T127_ = lastOrd__types_u1298((*g_p3).config, colontmpD__11);
					if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
					T128_ = NIM_NIL;
					T128_ = newIntNodeT__semfold_u44(T127_, n_p1, idgen_p2, g_p3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T128_); goto LA125_;}
					eqsink___ast_u3261(&result, T128_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
					{
						LA125_:;
					}
					{
						oldNimErrFin125_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3378(colontmpD__11);
						if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
						*nimErr_ = oldNimErrFin125_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA114_;
				}
LA115_: ;
				{
					LA114_:;
				}
				{
					oldNimErrFin114_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3378(colontmpD__10);
					if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
					*nimErr_ = oldNimErrFin114_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
			}
			goto LA109_;
LA112_: ;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T135_;
				a_1 = NIM_NIL;
				T135_ = NIM_NIL;
				T135_ = getArrayConstr__semfold_u717(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T135_); goto LA134_;}
				a_1 = T135_;
				{
					NI T140_;
					tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T141_;
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T142_;
					if (!((*a_1).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA138_;
					T140_ = (NI)0;
					T140_ = len__ast_u3190(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
					T141_ = toInt128__types_u1207((NI)(T140_ - ((NI)1)));
					if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
					T142_ = NIM_NIL;
					T142_ = newIntNodeT__semfold_u44(T141_, n_p1, idgen_p2, g_p3);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T142_); goto LA134_;}
					eqsink___ast_u3261(&result, T142_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA134_;
				}
LA138_: ;
				{
					LA134_:;
				}
				{
					oldNimErrFin134_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(a_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
					*nimErr_ = oldNimErrFin134_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
			}
LA109_: ;
			{
				LA108_:;
			}
			{
				oldNimErrFin108_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(colontmpD__9);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				*nimErr_ = oldNimErrFin108_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)36):
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_2;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T149_;
			a_2 = NIM_NIL;
			T149_ = NIM_NIL;
			T149_ = getArrayConstr__semfold_u717(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T149_); goto LA148_;}
			a_2 = T149_;
			{
				NI T154_;
				tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T155_;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T156_;
				if (!((*a_2).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41))) goto LA152_;
				T154_ = (NI)0;
				T154_ = len__ast_u3190(a_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
				T155_ = toInt128__types_u1207(T154_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
				T156_ = NIM_NIL;
				T156_ = newIntNodeT__semfold_u44(T155_, n_p1, idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T156_); goto LA148_;}
				eqsink___ast_u3261(&result, T156_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
			}
			goto LA150_;
LA152_: ;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T158_;
				T158_ = NIM_NIL;
				T158_ = magicCall__semfold_u625(m_p0, n_p1, idgen_p2, g_p3);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T158_); goto LA148_;}
				eqsink___ast_u3261(&result, T158_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA148_;
			}
LA150_: ;
			{
				LA148_:;
			}
			{
				oldNimErrFin148_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(a_2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				*nimErr_ = oldNimErrFin148_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)38):
		{
			tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg T162_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T163_;
			T162_ = lengthOrd__types_u1491((*g_p3).config, (*(*n_p1)._kind_6.sons.p->data[((NI)1)]).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
			T163_ = NIM_NIL;
			T163_ = newIntNodeT__semfold_u44(T162_, n_p1, idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T163_); goto LA89_;}
			eqsink___ast_u3261(&result, T163_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)10):
		{
			tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* configX60gensym208__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nodeX60gensym208__1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typX60gensym208__1;
			NI64 sizeX60gensym208__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T166_;
			configX60gensym208__1 = NIM_NIL;
			nodeX60gensym208__1 = NIM_NIL;
			typX60gensym208__1 = NIM_NIL;
			eqcopy___options_u2138(&configX60gensym208__1, (*g_p3).config);
			eqcopy___ast_u3255(&nodeX60gensym208__1, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
			eqcopy___ast_u3381(&typX60gensym208__1, (*(*nodeX60gensym208__1)._kind_6.sons.p->data[((NI)1)]).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
			computeSizeAlign__types_u3070(configX60gensym208__1, typX60gensym208__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
			sizeX60gensym208__1 = (*typX60gensym208__1).size;
			T166_ = NIM_NIL;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* resX60gensym208__1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T171_;
				if (!(IL64(0) <= sizeX60gensym208__1)) goto LA169_;
				resX60gensym208__1 = NIM_NIL;
				T171_ = NIM_NIL;
				T171_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), sizeX60gensym208__1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T171_); goto LA165_;}
				resX60gensym208__1 = T171_;
				(*resX60gensym208__1).info = (*nodeX60gensym208__1).info;
				eqcopy___ast_u3381(&(*resX60gensym208__1).typField, (*nodeX60gensym208__1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
				eqsink___ast_u3261(&result, resX60gensym208__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
			}
			goto LA167_;
LA169_: ;
			{
				eqsink___ast_u3261(&result, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
				if (NIM_UNLIKELY(*nimErr_)) goto LA165_;
			}
LA167_: ;
			{
				LA165_:;
			}
			{
				oldNimErrFin165_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(typX60gensym208__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				eqdestroy___ast_u3252(nodeX60gensym208__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				eqdestroy___options_u2135(configX60gensym208__1);
				*nimErr_ = oldNimErrFin165_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)11):
		{
			tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* configX60gensym214__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nodeX60gensym214__1;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typX60gensym214__1;
			NI16 alignX60gensym214__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T177_;
			configX60gensym214__1 = NIM_NIL;
			nodeX60gensym214__1 = NIM_NIL;
			typX60gensym214__1 = NIM_NIL;
			eqcopy___options_u2138(&configX60gensym214__1, (*g_p3).config);
			eqcopy___ast_u3255(&nodeX60gensym214__1, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA176_;
			eqcopy___ast_u3381(&typX60gensym214__1, (*(*nodeX60gensym214__1)._kind_6.sons.p->data[((NI)1)]).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA176_;
			computeSizeAlign__types_u3070(configX60gensym214__1, typX60gensym214__1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA176_;
			alignX60gensym214__1 = (*typX60gensym214__1).align;
			T177_ = NIM_NIL;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* resX60gensym214__1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T182_;
				if (!(((NI16)0) <= alignX60gensym214__1)) goto LA180_;
				resX60gensym214__1 = NIM_NIL;
				T182_ = NIM_NIL;
				T182_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), ((NI64) (alignX60gensym214__1)));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T182_); goto LA176_;}
				resX60gensym214__1 = T182_;
				(*resX60gensym214__1).info = (*nodeX60gensym214__1).info;
				eqcopy___ast_u3381(&(*resX60gensym214__1).typField, (*nodeX60gensym214__1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA176_;
				eqsink___ast_u3261(&result, resX60gensym214__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA176_;
			}
			goto LA178_;
LA180_: ;
			{
				eqsink___ast_u3261(&result, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
				if (NIM_UNLIKELY(*nimErr_)) goto LA176_;
			}
LA178_: ;
			{
				LA176_:;
			}
			{
				oldNimErrFin176_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3378(typX60gensym214__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				eqdestroy___ast_u3252(nodeX60gensym214__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				eqdestroy___options_u2135(configX60gensym214__1);
				*nimErr_ = oldNimErrFin176_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)12):
		{
			tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* configX60gensym220__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* nodeX60gensym220__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dotExprX60gensym220__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* valueX60gensym220__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* memberX60gensym220__1;
			NI32 offsetX60gensym220__1;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T197_;
			configX60gensym220__1 = NIM_NIL;
			nodeX60gensym220__1 = NIM_NIL;
			dotExprX60gensym220__1 = NIM_NIL;
			valueX60gensym220__1 = NIM_NIL;
			memberX60gensym220__1 = NIM_NIL;
			eqcopy___options_u2138(&configX60gensym220__1, (*g_p3).config);
			eqcopy___ast_u3255(&nodeX60gensym220__1, n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			{
				{
					if (!((*(*nodeX60gensym220__1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45))) goto LA191_;
					dotExprX60gensym220__1 = (*nodeX60gensym220__1)._kind_6.sons.p->data[((NI)1)];
				}
				goto LA189_;
LA191_: ;
				{
					if (!((*(*nodeX60gensym220__1)._kind_6.sons.p->data[((NI)1)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46))) goto LA194_;
					dotExprX60gensym220__1 = (*(*nodeX60gensym220__1)._kind_6.sons.p->data[((NI)1)])._kind_6.sons.p->data[((NI)0)];
				}
				goto LA189_;
LA194_: ;
				{
					dotExprX60gensym220__1 = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
					liMessage__msgs_u1227(configX60gensym220__1, (*nodeX60gensym220__1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__JtgqXuJaW0Uz9aqyNPWIZsw_64, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_65, NIM_FALSE, NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
				}
LA189_: ;
			}
			eqcopy___ast_u3255(&valueX60gensym220__1, (*dotExprX60gensym220__1)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			eqcopy___ast_u3255(&memberX60gensym220__1, (*dotExprX60gensym220__1)._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			computeSizeAlign__types_u3070(configX60gensym220__1, (*valueX60gensym220__1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			offsetX60gensym220__1 = (*(*memberX60gensym220__1)._kind_4.sym).offset;
			T197_ = NIM_NIL;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* tmpX60gensym220__1;
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T202_;
				if (!(((NI32)0) <= offsetX60gensym220__1)) goto LA200_;
				tmpX60gensym220__1 = NIM_NIL;
				T202_ = NIM_NIL;
				T202_ = newIntNode__ast_u5200(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6), ((NI64) (offsetX60gensym220__1)));
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T202_); goto LA187_;}
				tmpX60gensym220__1 = T202_;
				(*tmpX60gensym220__1).info = (*nodeX60gensym220__1).info;
				eqcopy___ast_u3381(&(*tmpX60gensym220__1).typField, (*nodeX60gensym220__1).typField);
				if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
				eqsink___ast_u3261(&result, tmpX60gensym220__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			}
			goto LA198_;
LA200_: ;
			{
				eqsink___ast_u3261(&result, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
				if (NIM_UNLIKELY(*nimErr_)) goto LA187_;
			}
LA198_: ;
			{
				LA187_:;
			}
			{
				oldNimErrFin187_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(memberX60gensym220__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				eqdestroy___ast_u3252(valueX60gensym220__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				eqdestroy___ast_u3252(nodeX60gensym220__1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
				eqdestroy___options_u2135(configX60gensym220__1);
				*nimErr_ = oldNimErrFin187_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)139):
		{
			NimStringV2 colontmpD__12;
			NimStringV2 T208_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T209_;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			T208_.len = 0; T208_.p = NIM_NIL;
			T208_ = renderTree__renderer_u59((*n_p1)._kind_6.sons.p->data[((NI)1)], 4);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T208_); goto LA207_;}
			colontmpD__12 = T208_;
			T209_ = NIM_NIL;
			T209_ = newStrNodeT__semfold_u63(colontmpD__12, n_p1, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T209_); goto LA207_;}
			eqsink___ast_u3261(&result, T209_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA207_;
			{
				LA207_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__12);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)123):
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T213_;
			T213_ = NIM_NIL;
			T213_ = foldConStrStr__semfold_u804(m_p0, n_p1, idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T213_); goto LA89_;}
			eqsink___ast_u3261(&result, T213_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)14):
		{
		}
		break;
		default:
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T216_;
			T216_ = NIM_NIL;
			T216_ = magicCall__semfold_u625(m_p0, n_p1, idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T216_); goto LA89_;}
			eqsink___ast_u3261(&result, T216_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA89_;
		}
		break;
		}
		if (NIM_UNLIKELY(*nimErr_)) {
			LA89_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 4, 4058593536)) {
				*nimErr_ = NIM_FALSE;
				liMessage__msgs_u1227((*g_p3).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__JtgqXuJaW0Uz9aqyNPWIZsw_69, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_70, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA218_;
				popCurrentException();
				LA218_:;
			}
			else 			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 4, 901915392)) {
				*nimErr_ = NIM_FALSE;
				liMessage__msgs_u1227((*g_p3).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), TM__JtgqXuJaW0Uz9aqyNPWIZsw_72, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_73, NIM_FALSE, NIM_FALSE);
				if (NIM_UNLIKELY(*nimErr_)) goto LA220_;
				popCurrentException();
				LA220_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)63):
	{
		eqsink___ast_u3261(&result, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)41):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)39):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T224_;
		T224_ = NIM_NIL;
		T224_ = copyNode__ast_u6736(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T224_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T224_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_1;
			son_1 = NIM_NIL;
			{
				NI i_1;
				NI colontmp_;
				NI T228_;
				NI i_2;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				T228_ = (NI)0;
				T228_ = safeLen__ast_u3197(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA226_;
				colontmp_ = T228_;
				i_2 = ((NI)0);
				{
					while (1) {
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_3;
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T232_;
						if (!(i_2 < colontmp_)) goto LA230;
						a_3 = NIM_NIL;
						i_1 = i_2;
						eqcopy___ast_u3255(&son_1, (*n_p1)._kind_6.sons.p->data[i_1]);
						if (NIM_UNLIKELY(*nimErr_)) goto LA231_;
						T232_ = NIM_NIL;
						T232_ = getConstExpr__semfold_u68(m_p0, son_1, idgen_p2, g_p3);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T232_); goto LA231_;}
						a_3 = T232_;
						{
							if (!(a_3 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA235_;
							result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
							eqdestroy___ast_u3252(a_3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA226_;
							eqdestroy___ast_u3252(son_1);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							goto BeforeRet_;
						}
LA235_: ;
						add__ast_u3215(result, a_3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA231_;
						i_2 += ((NI)1);
						{
							LA231_:;
						}
						{
							oldNimErrFin231_ = *nimErr_; *nimErr_ = NIM_FALSE;
							eqdestroy___ast_u3252(a_3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA226_;
							*nimErr_ = oldNimErrFin231_;
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA226_;
					} LA230: ;
				}
			}
			{
				LA226_:;
			}
			{
				oldNimErrFin226_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3252(son_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				*nimErr_ = oldNimErrFin226_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		(*result).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)4))) & 31);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)44):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_4;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* b_1;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T243_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T248_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T253_;
		a_4 = NIM_NIL;
		b_1 = NIM_NIL;
		T243_ = NIM_NIL;
		T243_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T243_); goto LA242_;}
		a_4 = T243_;
		{
			if (!(a_4 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA246_;
			eqdestroy___ast_u3252(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(a_4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA246_: ;
		T248_ = NIM_NIL;
		T248_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T248_); goto LA242_;}
		b_1 = T248_;
		{
			if (!(b_1 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA251_;
			eqdestroy___ast_u3252(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(a_4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA251_: ;
		T253_ = NIM_NIL;
		T253_ = copyNode__ast_u6736(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T253_); goto LA242_;}
		eqsink___ast_u3261(&result, T253_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA242_;
		add__ast_u3215(result, a_4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA242_;
		add__ast_u3215(result, b_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA242_;
		{
			LA242_:;
		}
		{
			oldNimErrFin242_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(b_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___ast_u3252(a_4);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin242_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)37):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)160):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T257_;
		T257_ = NIM_NIL;
		T257_ = copyNode__ast_u6736(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T257_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T257_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T260_;
			NI T261_;
			T260_ = (NIM_BOOL)0;
			T261_ = (NI)0;
			T261_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T260_ = (((NI)0) < T261_);
			if (!(T260_)) goto LA262_;
			T260_ = ((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34));
LA262_: ;
			if (!T260_) goto LA263_;
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* expr_1;
				expr_1 = NIM_NIL;
				{
					NI i_3;
					NI colontmp__2;
					NI T268_;
					NI i_4;
					i_3 = (NI)0;
					colontmp__2 = (NI)0;
					T268_ = (NI)0;
					T268_ = safeLen__ast_u3197(n_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA266_;
					colontmp__2 = T268_;
					i_4 = ((NI)0);
					{
						while (1) {
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* exprNew_1;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_5;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T272_;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T273_;
							if (!(i_4 < colontmp__2)) goto LA270;
							exprNew_1 = NIM_NIL;
							a_5 = NIM_NIL;
							i_3 = i_4;
							eqcopy___ast_u3255(&expr_1, (*n_p1)._kind_6.sons.p->data[i_3]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA271_;
							T272_ = NIM_NIL;
							T272_ = copyNode__ast_u6736(expr_1);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T272_); goto LA271_;}
							exprNew_1 = T272_;
							add__ast_u3215(exprNew_1, (*expr_1)._kind_6.sons.p->data[((NI)0)]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA271_;
							T273_ = NIM_NIL;
							T273_ = getConstExpr__semfold_u68(m_p0, (*expr_1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T273_); goto LA271_;}
							a_5 = T273_;
							{
								if (!(a_5 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA276_;
								result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
								eqdestroy___ast_u3252(a_5);
								if (NIM_UNLIKELY(*nimErr_)) goto LA266_;
								eqdestroy___ast_u3252(exprNew_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA266_;
								eqdestroy___ast_u3252(expr_1);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto BeforeRet_;
							}
LA276_: ;
							add__ast_u3215(exprNew_1, a_5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA271_;
							add__ast_u3215(result, exprNew_1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA271_;
							i_4 += ((NI)1);
							{
								LA271_:;
							}
							{
								oldNimErrFin271_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(a_5);
								if (NIM_UNLIKELY(*nimErr_)) goto LA266_;
								eqdestroy___ast_u3252(exprNew_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA266_;
								*nimErr_ = oldNimErrFin271_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA266_;
						} LA270: ;
					}
				}
				{
					LA266_:;
				}
				{
					oldNimErrFin266_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(expr_1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin266_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
		}
		goto LA258_;
LA263_: ;
		{
			{
				tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* expr_2;
				expr_2 = NIM_NIL;
				{
					NI i_5;
					NI colontmp__3;
					NI T286_;
					NI i_6;
					i_5 = (NI)0;
					colontmp__3 = (NI)0;
					T286_ = (NI)0;
					T286_ = safeLen__ast_u3197(n_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA284_;
					colontmp__3 = T286_;
					i_6 = ((NI)0);
					{
						while (1) {
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_6;
							tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T290_;
							if (!(i_6 < colontmp__3)) goto LA288;
							a_6 = NIM_NIL;
							i_5 = i_6;
							eqcopy___ast_u3255(&expr_2, (*n_p1)._kind_6.sons.p->data[i_5]);
							if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
							T290_ = NIM_NIL;
							T290_ = getConstExpr__semfold_u68(m_p0, expr_2, idgen_p2, g_p3);
							if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T290_); goto LA289_;}
							a_6 = T290_;
							{
								if (!(a_6 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA293_;
								result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
								eqdestroy___ast_u3252(a_6);
								if (NIM_UNLIKELY(*nimErr_)) goto LA284_;
								eqdestroy___ast_u3252(expr_2);
								if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
								goto BeforeRet_;
							}
LA293_: ;
							add__ast_u3215(result, a_6);
							if (NIM_UNLIKELY(*nimErr_)) goto LA289_;
							i_6 += ((NI)1);
							{
								LA289_:;
							}
							{
								oldNimErrFin289_ = *nimErr_; *nimErr_ = NIM_FALSE;
								eqdestroy___ast_u3252(a_6);
								if (NIM_UNLIKELY(*nimErr_)) goto LA284_;
								*nimErr_ = oldNimErrFin289_;
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA284_;
						} LA288: ;
					}
				}
				{
					LA284_:;
				}
				{
					oldNimErrFin284_ = *nimErr_; *nimErr_ = NIM_FALSE;
					eqdestroy___ast_u3252(expr_2);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					*nimErr_ = oldNimErrFin284_;
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
		}
LA258_: ;
		(*result).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)4))) & 31);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)68):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)69):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)70):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_7;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T301_;
		a_7 = NIM_NIL;
		T301_ = NIM_NIL;
		T301_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T301_); goto LA300_;}
		a_7 = T301_;
		{
			if (!(a_7 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA304_;
			eqdestroy___ast_u3252(a_7);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA304_: ;
		{
			NIM_BOOL T308_;
			T308_ = (NIM_BOOL)0;
			T308_ = leValueConv__semfold_u621((*n_p1)._kind_6.sons.p->data[((NI)1)], a_7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA300_;
			if (!(T308_)) goto LA309_;
			T308_ = leValueConv__semfold_u621(a_7, (*n_p1)._kind_6.sons.p->data[((NI)2)]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA300_;
LA309_: ;
			if (!T308_) goto LA310_;
			eqsink___ast_u3261(&result, a_7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA300_;
			eqwasMoved___ast_u3249(&a_7);
			if (NIM_UNLIKELY(*nimErr_)) goto LA300_;
			eqcopy___ast_u3381(&(*result).typField, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA300_;
		}
		goto LA306_;
LA310_: ;
		{
			if (!((*(*n_p1).typField).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40) && (*(*n_p1).typField).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44))) goto LA313_;
		}
		goto LA306_;
LA313_: ;
		{
			NimStringV2 colontmpD__13;
			NimStringV2 colontmpD__14;
			NimStringV2 colontmpD__15;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T317_;
			NimStringV2 T318_;
			NimStringV2 T319_;
			NimStringV2 T320_;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
			colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
			T318_.len = 0; T318_.p = NIM_NIL;
			T318_ = typeToString__types_u54((*(*n_p1)._kind_6.sons.p->data[((NI)0)]).typField, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T318_); goto LA316_;}
			colontmpD__13 = T318_;
			T317_[0] = colontmpD__13;
			T319_.len = 0; T319_.p = NIM_NIL;
			T319_ = typeToString__types_u54((*n_p1).typField, ((tyEnum_TPreferedDesc__ddj0M89bv09cBYthgD4XTq3Q)0));
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T319_); goto LA316_;}
			colontmpD__14 = T319_;
			T317_[1] = colontmpD__14;
			T320_.len = 0; T320_.p = NIM_NIL;
			T320_ = nsuFormatOpenArray(TM__JtgqXuJaW0Uz9aqyNPWIZsw_75, T317_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T320_); goto LA316_;}
			colontmpD__15 = T320_;
			liMessage__msgs_u1227((*g_p3).config, (*n_p1).info, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17), colontmpD__15, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)0), TM__JtgqXuJaW0Uz9aqyNPWIZsw_76, NIM_FALSE, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto LA316_;
			{
				LA316_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__15);
				eqdestroy___system_u2691(colontmpD__14);
				eqdestroy___system_u2691(colontmpD__13);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA300_;
		}
LA306_: ;
		{
			LA300_:;
		}
		{
			oldNimErrFin300_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(a_7);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin300_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)71):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)72):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_8;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T327_;
		a_8 = NIM_NIL;
		T327_ = NIM_NIL;
		T327_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T327_); goto LA326_;}
		a_8 = T327_;
		{
			if (!(a_8 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA330_;
			eqdestroy___ast_u3252(a_8);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA330_: ;
		eqsink___ast_u3261(&result, a_8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA326_;
		eqwasMoved___ast_u3249(&a_8);
		if (NIM_UNLIKELY(*nimErr_)) goto LA326_;
		eqcopy___ast_u3381(&(*result).typField, (*n_p1).typField);
		if (NIM_UNLIKELY(*nimErr_)) goto LA326_;
		{
			LA326_:;
		}
		{
			oldNimErrFin326_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(a_8);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin326_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)58):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)59):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)60):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_9;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T336_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T341_;
		a_9 = NIM_NIL;
		T336_ = NIM_NIL;
		T336_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T336_); goto LA335_;}
		a_9 = T336_;
		{
			if (!(a_9 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA339_;
			eqdestroy___ast_u3252(a_9);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA339_: ;
		T341_ = NIM_NIL;
		T341_ = foldConv__semfold_u674(n_p1, a_9, idgen_p2, g_p3, NIM_TRUE);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T341_); goto LA335_;}
		eqsink___ast_u3261(&result, T341_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA335_;
		{
			LA335_:;
		}
		{
			oldNimErrFin335_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(a_9);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin335_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)47):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)65):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_10;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T346_;
		a_10 = NIM_NIL;
		T346_ = NIM_NIL;
		T346_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T346_); goto LA345_;}
		a_10 = T346_;
		{
			NIM_BOOL T349_;
			T349_ = (NIM_BOOL)0;
			T349_ = !((a_10 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
			if (!(T349_)) goto LA350_;
			T349_ = ((*a_10).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23));
LA350_: ;
			if (!T349_) goto LA351_;
			eqsink___ast_u3261(&result, ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
			if (NIM_UNLIKELY(*nimErr_)) goto LA345_;
		}
LA351_: ;
		{
			LA345_:;
		}
		{
			oldNimErrFin345_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(a_10);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin345_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)61):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_11;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T357_;
		a_11 = NIM_NIL;
		T357_ = NIM_NIL;
		T357_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)1)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T357_); goto LA356_;}
		a_11 = T357_;
		{
			if (!(a_11 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA360_;
			eqdestroy___ast_u3252(a_11);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA360_: ;
		{
			NIM_BOOL T364_;
			NIM_BOOL T365_;
			NIM_BOOL T368_;
			T364_ = (NIM_BOOL)0;
			T365_ = (NIM_BOOL)0;
			T365_ = !(((*n_p1).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
			if (!(T365_)) goto LA366_;
			T365_ = ((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25) || (*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)50));
LA366_: ;
			T364_ = T365_;
			if (!(T364_)) goto LA367_;
			T368_ = (NIM_BOOL)0;
			T368_ = ((*(*n_p1).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
			if (!(T368_)) goto LA369_;
			T368_ = ((*(*a_11).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA369_: ;
			T364_ = !(T368_);
LA367_: ;
			if (!T364_) goto LA370_;
			eqsink___ast_u3261(&result, a_11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA356_;
			eqwasMoved___ast_u3249(&a_11);
			if (NIM_UNLIKELY(*nimErr_)) goto LA356_;
			eqcopy___ast_u3381(&(*result).typField, (*n_p1).typField);
			if (NIM_UNLIKELY(*nimErr_)) goto LA356_;
		}
LA370_: ;
		{
			LA356_:;
		}
		{
			oldNimErrFin356_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(a_11);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin356_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)42):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T375_;
		T375_ = NIM_NIL;
		T375_ = foldArrayAccess__semfold_u731(m_p0, n_p1, idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T375_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T375_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)45):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T377_;
		T377_ = NIM_NIL;
		T377_ = foldFieldAccess__semfold_u763(m_p0, n_p1, idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T377_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T377_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)46):
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T379_;
		T379_ = NIM_NIL;
		T379_ = foldFieldAccess__semfold_u763(m_p0, (*n_p1)._kind_6.sons.p->data[((NI)0)], idgen_p2, g_p3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T379_); goto BeforeRet_;}
		eqsink___ast_u3261(&result, T379_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126):
	{
		NI i_7;
		i_7 = ((NI)0);
		{
			while (1) {
				NI T383_;
				T383_ = (NI)0;
				T383_ = len__ast_u3190(n_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				if (!(i_7 <= (NI)(T383_ - ((NI)2)))) goto LA382;
				{
					if (!((*(*n_p1)._kind_6.sons.p->data[i_7]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)24) || (*(*n_p1)._kind_6.sons.p->data[i_7]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125) || (*(*n_p1)._kind_6.sons.p->data[i_7]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1))) goto LA386_;
					i_7 += ((NI)1);
				}
				goto LA384_;
LA386_: ;
				{
					goto LA381;
				}
LA384_: ;
			} LA382: ;
		} LA381: ;
		{
			NI T391_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T394_;
			T391_ = (NI)0;
			T391_ = len__ast_u3190(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(i_7 == (NI)(T391_ - ((NI)1)))) goto LA392_;
			T394_ = NIM_NIL;
			T394_ = getConstExpr__semfold_u68(m_p0, (*n_p1)._kind_6.sons.p->data[i_7], idgen_p2, g_p3);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T394_); goto BeforeRet_;}
			eqsink___ast_u3261(&result, T394_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA392_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
