/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_Gconfig__YzAefAIiOD2E89cs4Ro1q0A tyObject_Gconfig__YzAefAIiOD2E89cs4Ro1q0A;
typedef struct tyObject_Table__r6SySATn9aFiGJCuriaCXGg tyObject_Table__r6SySATn9aFiGJCuriaCXGg;
typedef struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ tySequence__7s5HyddQ0f9bxMNILHrXwJQ;
typedef struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw tySequence__hRbbzIynOoxrYjHTIKZ3Gw;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content;
typedef struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ;
typedef struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw tySequence__ZUeR9b415wicThQ9cBWO9aYMw;
typedef struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content;
typedef struct tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A;
typedef struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ tySequence__7OXYQ6bHRkhJpRaiS7kiwQ;
typedef struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content;
typedef struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg;
typedef struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA;
typedef struct tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA;
typedef struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg;
typedef struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w tySequence__GH1mmNKNA2QP4n1tnxJf1w;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content;
typedef struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ;
typedef struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g;
typedef struct tySequence__tt8kXsbz31MUMFUF6Q9aQuQ tySequence__tt8kXsbz31MUMFUF6Q9aQuQ;
typedef struct tySequence__tt8kXsbz31MUMFUF6Q9aQuQ_Content tySequence__tt8kXsbz31MUMFUF6Q9aQuQ_Content;
typedef struct tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg;
typedef struct tyObject_TIdTable__8wpQEq0X9akVm73iKe4zg6Q tyObject_TIdTable__8wpQEq0X9akVm73iKe4zg6Q;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyTuple__IYAk6y4YHp5OEJgCALGjQw tyTuple__IYAk6y4YHp5OEJgCALGjQw;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
typedef struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g tyTuple__kuMQ1fbjJlHtwKTmBGAe6g;
typedef struct tyTuple__Oubp8LPEu86EPyDuc56AXg tyTuple__Oubp8LPEu86EPyDuc56AXg;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ {
  NI len; tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content* p;
};
struct tyObject_Table__r6SySATn9aFiGJCuriaCXGg {
	tySequence__7s5HyddQ0f9bxMNILHrXwJQ data;
	NI counter;
};
struct tyObject_Gconfig__YzAefAIiOD2E89cs4Ro1q0A {
	tyObject_Table__r6SySATn9aFiGJCuriaCXGg comments;
	NIM_BOOL useIc;
};
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU8 tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
typedef NU8 tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg sons;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typeInst;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA uniqueId;
};
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NimStringV2 name;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* path;
};
struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA {
	NI id;
	NimStringV2 s;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* next;
	NI h;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw {
  NI len; tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content* p;
};
struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ {
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug {
	NI32 module;
	NI32 symId;
	NI32 typeId_0;
	NIM_BOOL sealed;
	tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ disambTable;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg concreteTypes;
	NI compilesId;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
typedef NU8 tyEnum_TNodeKind__fgQOep3rrztw9aeZI9aS2Ltg;
struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ {
	NI len;
	void* p;
};
struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw {
  NI len; tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content* p;
};
struct tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* val;
};
struct tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww {
	NI depthLevel;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg symbols;
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* parent;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA allowPrivateAccess;
	NI optionStackLen;
};
typedef NU8 tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg[9];
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ {
  NI len; tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content* p;
};
struct tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* val;
};
struct tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA {
	NI counter;
	tySequence__7OXYQ6bHRkhJpRaiS7kiwQ data;
};
struct tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA {
	NI counter;
	tySequence__ZUeR9b415wicThQ9cBWO9aYMw data;
};
typedef NU32 tyArray__PPSU5X9aizf5OJq0lL4Og7A[4];
struct tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg {
	tyArray__PPSU5X9aizf5OJq0lL4Og7A udata;
};
struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig {
	NI a;
	NI b;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w {
  NI len; tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content* p;
};
struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ {
	NI h;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key;
	NI val;
};
struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g {
	NI counter;
	tySequence__GH1mmNKNA2QP4n1tnxJf1w data;
	NIM_BOOL ignoreTypes;
};
typedef NimStringV2 tyArray__dwfJdPZJYBY1vfSlirNUOQ[7];
struct tySequence__tt8kXsbz31MUMFUF6Q9aQuQ {
  NI len; tySequence__tt8kXsbz31MUMFUF6Q9aQuQ_Content* p;
};
struct tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA key;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* val;
};
struct tyObject_TIdTable__8wpQEq0X9akVm73iKe4zg6Q {
	NI counter;
	tySequence__tt8kXsbz31MUMFUF6Q9aQuQ data;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef NU8 tyEnum_TNodeKind__Vj1MpVCa7BBwvA5h87QXag;
typedef NU8 tyEnum_TSymKind__fzoDhZbHLwFaqo7QLPWQkQ;
typedef NU32 tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU8 tySet_tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw[21];
struct tyTuple__IYAk6y4YHp5OEJgCALGjQw {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
typedef NU8 tyEnum_TNodeKind__ejrmw4CHo9bZqcGZhO9alDfA;
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tyTuple__kuMQ1fbjJlHtwKTmBGAe6g {
	NI Field0;
	NI Field1;
	NimStringV2 Field2;
};
struct tySequence__7s5HyddQ0f9bxMNILHrXwJQ_Content { NI cap; tyTuple__kuMQ1fbjJlHtwKTmBGAe6g data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tyTuple__Oubp8LPEu86EPyDuc56AXg {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field0;
	NI Field1;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content { NI cap; tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tySequence__ZUeR9b415wicThQ9cBWO9aYMw_Content { NI cap; tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A data[SEQ_DECL_SIZE]; };
struct tySequence__7OXYQ6bHRkhJpRaiS7kiwQ_Content { NI cap; tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg data[SEQ_DECL_SIZE]; };
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content { NI cap; tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ data[SEQ_DECL_SIZE]; };
struct tySequence__tt8kXsbz31MUMFUF6Q9aQuQ_Content { NI cap; tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2*, X5BX5D___ast_u893)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0, NI key_p1);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(void, nimIncRef)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3125)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3288)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3521)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u173)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3696)(tySequence__9ahcSjIErJohSBBFLwuF56Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3311)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3027)(tySequence__hRbbzIynOoxrYjHTIKZ3Gw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3074)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u6323)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, eqdup___lineinfos_u2037)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA src_p0);
static N_INLINE(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA, nextSymId__ast_u3137)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* x_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA*, eqdup___idents_u161)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__ast_u4282)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, NI def_p2);
N_LIB_PRIVATE N_NIMCALL(void, inc__ast_u4349)(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ* t_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* key_p1, NI val_p2);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___ast_u1378)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0, NI key_p1, NimStringV2 val_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, del__ast_u2399)(tyObject_Table__r6SySATn9aFiGJCuriaCXGg* t_p0, NI key_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3225)(tySequence__9ahcSjIErJohSBBFLwuF56Q* x_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, eqdup___ast_u3258)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNode__ast_u4117)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___idents_u158)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3273)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3699)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1);
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3718)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3279)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, eqdup___ast_u3384)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3705)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3693)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__9ahcSjIErJohSBBFLwuF56Q, at___ast_u4149)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** a_p0, NI a_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNode__ast_u4069)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ, initCountTable__ast_u2869)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2873)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* dest_p0);
static N_INLINE(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA, nextTypeId__ast_u3168)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* x_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA, eqdup___ast_u3157)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA src_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3891)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* x_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3375)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, last__ast_u5278)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u4725)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__layeredtable_u20)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___layeredtable_u168)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u6219)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, mergeLoc__ast_u6020)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSons__ast_u6115)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, NI length_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__ast_u3333)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, commenteq___ast_u1334)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, comment__ast_u836)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u4100)(tySequence__9ahcSjIErJohSBBFLwuF56Q* s_p0, NI len_p1);
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyTree__ast_u6891)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newType__ast_u5900)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p3);
N_LIB_PRIVATE N_NIMCALL(void, assignType__ast_u6138)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1);
N_LIB_PRIVATE N_NIMCALL(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ, eqdup___layeredtable_u174)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ src_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__layeredtable_u28)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__semdata_u1100)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u748)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw dest_p0);
static N_INLINE(NI, hash__ast_u624)(NI32 x_p0);
static N_INLINE(NI, hashWangYi1__pureZhashes_u140)(NU64 x_p0);
static N_INLINE(NU64, hiXorLo__pureZhashes_u81)(NU64 a_p0, NU64 b_p1);
static N_INLINE(NU64, hiXorLoFallback64__pureZhashes_u37)(NU64 a_p0, NU64 b_p1);
static N_INLINE(NI, emarkamp___pureZhashes_u5)(NI h_p0, NI val_p1);
static N_INLINE(NI, emarkdollar___pureZhashes_u20)(NI h_p0);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u24)(NI32 xX60gensym3__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__int128_u717)(NU64 arg_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, toInt128__int128_u937)(NI64 arg_p0);
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__lineinfos_u299)(NimStringV2 msg_p0);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMetaType__ast_u4607)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1);
static N_INLINE(NIM_BOOL, isGCedMem__ast_u6621)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__ast_u6637)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* owner_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* elem_p1, NIM_BOOL propagateHasAsgn_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5);
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u6287)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
static N_INLINE(NIM_BOOL, genericParamHasConstraints__ast_u5654)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0);
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, findUnresolvedStatic__ast_u7354)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHumanStrImpl__ast_u7577)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u309)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q e_p0);
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1314)(NimStringV2 s_p0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
static N_INLINE(tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig, dotdot___stdZenumutils_u106)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_CHAR, nsuToLowerAsciiChar)(NIM_CHAR c_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3472)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3478)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___idents_u152)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6281)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6213)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u182)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHumanStrImpl__ast_u7607)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1177)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__semdata_u770)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__ast_u6400)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5168)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0);
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_u6706)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1, NIM_BOOL propagateHasAsgn_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeIT__ast_u4112)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__transf_u102)(tySequence__tt8kXsbz31MUMFUF6Q9aQuQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntTypeNode__ast_u5387)(NI64 intVal_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1);
N_LIB_PRIVATE N_NIMCALL(NI64, castToInt64__int128_u308)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg arg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimCharToStr)(NIM_CHAR x_p0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0);
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6548)(tySequence__GH1mmNKNA2QP4n1tnxJf1w dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, setInfoRecursive__ast_u4054)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayloadUninit)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyTreeWithoutNode__ast_u6911)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* skippedNode_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsNode__ast_u7008)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kinds_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__ast_u7029)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p1);
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0);
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_2 = { 9 | NIM_STRLIT_FLAG, "skUnknown" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_3 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_2};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_4 = { 13 | NIM_STRLIT_FLAG, "skConditional" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_5 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_4};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_6 = { 8 | NIM_STRLIT_FLAG, "skDynLib" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_7 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_6};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_8 = { 7 | NIM_STRLIT_FLAG, "skParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_9 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_8};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_10 = { 14 | NIM_STRLIT_FLAG, "skGenericParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_11 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_10};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_12 = { 6 | NIM_STRLIT_FLAG, "skTemp" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_13 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_12};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_14 = { 8 | NIM_STRLIT_FLAG, "skModule" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_15 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_14};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_16 = { 6 | NIM_STRLIT_FLAG, "skType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_17 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_16};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_18 = { 5 | NIM_STRLIT_FLAG, "skVar" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_19 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_18};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_20 = { 5 | NIM_STRLIT_FLAG, "skLet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_21 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_20};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_22 = { 7 | NIM_STRLIT_FLAG, "skConst" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_23 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_22};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_24 = { 8 | NIM_STRLIT_FLAG, "skResult" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_25 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_24};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_26 = { 6 | NIM_STRLIT_FLAG, "skProc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_27 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_26};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_28 = { 6 | NIM_STRLIT_FLAG, "skFunc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_29 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_28};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_30 = { 8 | NIM_STRLIT_FLAG, "skMethod" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_31 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_30};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_32 = { 10 | NIM_STRLIT_FLAG, "skIterator" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_33 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_32};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_34 = { 11 | NIM_STRLIT_FLAG, "skConverter" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_35 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_34};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_36 = { 7 | NIM_STRLIT_FLAG, "skMacro" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_37 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_36};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_38 = { 10 | NIM_STRLIT_FLAG, "skTemplate" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_39 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_38};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_40 = { 7 | NIM_STRLIT_FLAG, "skField" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_41 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_40};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_42 = { 11 | NIM_STRLIT_FLAG, "skEnumField" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_43 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_42};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_44 = { 8 | NIM_STRLIT_FLAG, "skForVar" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_45 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_44};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_46 = { 7 | NIM_STRLIT_FLAG, "skLabel" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_47 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_46};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_48 = { 6 | NIM_STRLIT_FLAG, "skStub" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_49 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_48};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_50 = { 9 | NIM_STRLIT_FLAG, "skPackage" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_51 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_50};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_52 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_53 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_52};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_54 = { 6 | NIM_STRLIT_FLAG, "sfUsed" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_55 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_54};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_56 = { 10 | NIM_STRLIT_FLAG, "sfExported" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_57 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_56};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_58 = { 13 | NIM_STRLIT_FLAG, "sfFromGeneric" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_59 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_58};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_60 = { 8 | NIM_STRLIT_FLAG, "sfGlobal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_61 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_60};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_62 = { 9 | NIM_STRLIT_FLAG, "sfForward" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_63 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_62};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_64 = { 14 | NIM_STRLIT_FLAG, "sfWasForwarded" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_65 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_64};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_66 = { 9 | NIM_STRLIT_FLAG, "sfImportc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_67 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_66};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_68 = { 9 | NIM_STRLIT_FLAG, "sfExportc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_69 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_68};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_70 = { 11 | NIM_STRLIT_FLAG, "sfMangleCpp" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_71 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_70};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_72 = { 10 | NIM_STRLIT_FLAG, "sfVolatile" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_73 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_72};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_74 = { 10 | NIM_STRLIT_FLAG, "sfRegister" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_75 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_74};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_76 = { 6 | NIM_STRLIT_FLAG, "sfPure" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_77 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_76};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_78 = { 14 | NIM_STRLIT_FLAG, "sfNoSideEffect" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_79 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_78};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_80 = { 12 | NIM_STRLIT_FLAG, "sfSideEffect" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_81 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_80};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_82 = { 12 | NIM_STRLIT_FLAG, "sfMainModule" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_83 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_82};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_84 = { 14 | NIM_STRLIT_FLAG, "sfSystemModule" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_85 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_84};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_86 = { 10 | NIM_STRLIT_FLAG, "sfNoReturn" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_87 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_86};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_88 = { 11 | NIM_STRLIT_FLAG, "sfAddrTaken" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_89 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_88};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_90 = { 14 | NIM_STRLIT_FLAG, "sfCompilerProc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_91 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_90};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_92 = { 9 | NIM_STRLIT_FLAG, "sfEscapes" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_93 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_92};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_94 = { 14 | NIM_STRLIT_FLAG, "sfDiscriminant" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_95 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_94};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_96 = { 14 | NIM_STRLIT_FLAG, "sfRequiresInit" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_97 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_96};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_98 = { 12 | NIM_STRLIT_FLAG, "sfDeprecated" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_99 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_98};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_100 = { 9 | NIM_STRLIT_FLAG, "sfExplain" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_101 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_100};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_102 = { 7 | NIM_STRLIT_FLAG, "sfError" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_103 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_102};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_104 = { 10 | NIM_STRLIT_FLAG, "sfShadowed" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_105 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_104};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_106 = { 8 | NIM_STRLIT_FLAG, "sfThread" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_107 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_106};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_108 = { 11 | NIM_STRLIT_FLAG, "sfCppNonPod" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_109 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_108};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_110 = { 13 | NIM_STRLIT_FLAG, "sfCompileTime" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_111 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_110};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_112 = { 13 | NIM_STRLIT_FLAG, "sfConstructor" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_113 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_112};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_114 = { 12 | NIM_STRLIT_FLAG, "sfDispatcher" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_115 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_114};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_116 = { 8 | NIM_STRLIT_FLAG, "sfBorrow" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_117 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_116};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_118 = { 11 | NIM_STRLIT_FLAG, "sfInfixCall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_119 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_118};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_120 = { 16 | NIM_STRLIT_FLAG, "sfNamedParamCall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_121 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_120};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_122 = { 13 | NIM_STRLIT_FLAG, "sfDiscardable" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_123 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_122};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_124 = { 12 | NIM_STRLIT_FLAG, "sfOverridden" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_125 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_124};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_126 = { 10 | NIM_STRLIT_FLAG, "sfCallsite" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_127 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_126};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_128 = { 8 | NIM_STRLIT_FLAG, "sfGenSym" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_129 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_128};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_130 = { 15 | NIM_STRLIT_FLAG, "sfNonReloadable" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_131 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_130};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_132 = { 13 | NIM_STRLIT_FLAG, "sfGeneratedOp" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_133 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_132};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_134 = { 15 | NIM_STRLIT_FLAG, "sfTemplateParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_135 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_134};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_136 = { 8 | NIM_STRLIT_FLAG, "sfCursor" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_137 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_136};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_138 = { 19 | NIM_STRLIT_FLAG, "sfInjectDestructors" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_139 = {19, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_138};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_140 = { 13 | NIM_STRLIT_FLAG, "sfNeverRaises" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_141 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_140};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_142 = { 20 | NIM_STRLIT_FLAG, "sfSystemRaisesDefect" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_143 = {20, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_142};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_144 = { 23 | NIM_STRLIT_FLAG, "sfUsedInFinallyOrExcept" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_145 = {23, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_144};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_146 = { 16 | NIM_STRLIT_FLAG, "sfSingleUsedTemp" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_147 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_146};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_148 = { 9 | NIM_STRLIT_FLAG, "sfNoalias" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_149 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_148};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_150 = { 16 | NIM_STRLIT_FLAG, "sfEffectsDelayed" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_151 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_150};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_152 = { 15 | NIM_STRLIT_FLAG, "sfGeneratedType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_153 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_152};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_154 = { 9 | NIM_STRLIT_FLAG, "sfVirtual" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_155 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_154};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_156 = { 8 | NIM_STRLIT_FLAG, "sfByCopy" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_157 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_156};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_158 = { 8 | NIM_STRLIT_FLAG, "sfMember" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_159 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_158};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_160 = { 13 | NIM_STRLIT_FLAG, "sfCodegenDecl" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_161 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_160};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_162 = { 11 | NIM_STRLIT_FLAG, "sfWasGenSym" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_163 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_162};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_164 = { 11 | NIM_STRLIT_FLAG, "sfForceLift" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_165 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_164};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_166 = { 7 | NIM_STRLIT_FLAG, "sfDirty" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_167 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_166};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_168 = { 14 | NIM_STRLIT_FLAG, "sfCustomPragma" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_169 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_168};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_170 = { 6 | NIM_STRLIT_FLAG, "sfBase" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_171 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_170};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_172 = { 6 | NIM_STRLIT_FLAG, "sfGoto" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_173 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_172};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_174 = { 6 | NIM_STRLIT_FLAG, "sfAnon" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_175 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_174};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_176 = { 12 | NIM_STRLIT_FLAG, "sfAllUntyped" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_177 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_176};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_178 = { 22 | NIM_STRLIT_FLAG, "sfTemplateRedefinition" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_179 = {22, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_178};
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_180 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_52};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_181 = { 6 | NIM_STRLIT_FLAG, "tyNone" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_182 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_181};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_183 = { 6 | NIM_STRLIT_FLAG, "tyBool" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_184 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_183};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_185 = { 6 | NIM_STRLIT_FLAG, "tyChar" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_186 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_185};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_187 = { 7 | NIM_STRLIT_FLAG, "tyEmpty" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_188 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_187};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_189 = { 7 | NIM_STRLIT_FLAG, "tyAlias" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_190 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_189};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_191 = { 5 | NIM_STRLIT_FLAG, "tyNil" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_192 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_191};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_193 = { 9 | NIM_STRLIT_FLAG, "tyUntyped" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_194 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_193};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_195 = { 7 | NIM_STRLIT_FLAG, "tyTyped" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_196 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_195};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_197 = { 10 | NIM_STRLIT_FLAG, "tyTypeDesc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_198 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_197};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_199 = { 19 | NIM_STRLIT_FLAG, "tyGenericInvocation" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_200 = {19, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_199};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_201 = { 13 | NIM_STRLIT_FLAG, "tyGenericBody" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_202 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_201};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_203 = { 13 | NIM_STRLIT_FLAG, "tyGenericInst" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_204 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_203};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_205 = { 14 | NIM_STRLIT_FLAG, "tyGenericParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_206 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_205};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_207 = { 10 | NIM_STRLIT_FLAG, "tyDistinct" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_208 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_207};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_209 = { 6 | NIM_STRLIT_FLAG, "tyEnum" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_210 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_209};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_211 = { 9 | NIM_STRLIT_FLAG, "tyOrdinal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_212 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_211};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_213 = { 7 | NIM_STRLIT_FLAG, "tyArray" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_214 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_213};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_215 = { 8 | NIM_STRLIT_FLAG, "tyObject" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_216 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_215};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_217 = { 7 | NIM_STRLIT_FLAG, "tyTuple" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_218 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_217};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_219 = { 5 | NIM_STRLIT_FLAG, "tySet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_220 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_219};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_221 = { 7 | NIM_STRLIT_FLAG, "tyRange" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_222 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_221};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_223 = { 5 | NIM_STRLIT_FLAG, "tyPtr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_224 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_223};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_225 = { 5 | NIM_STRLIT_FLAG, "tyRef" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_226 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_225};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_227 = { 5 | NIM_STRLIT_FLAG, "tyVar" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_228 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_227};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_229 = { 10 | NIM_STRLIT_FLAG, "tySequence" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_230 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_229};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_231 = { 6 | NIM_STRLIT_FLAG, "tyProc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_232 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_231};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_233 = { 9 | NIM_STRLIT_FLAG, "tyPointer" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_234 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_233};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_235 = { 11 | NIM_STRLIT_FLAG, "tyOpenArray" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_236 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_235};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_237 = { 8 | NIM_STRLIT_FLAG, "tyString" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_238 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_237};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_239 = { 9 | NIM_STRLIT_FLAG, "tyCstring" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_240 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_239};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_241 = { 9 | NIM_STRLIT_FLAG, "tyForward" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_242 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_241};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_243 = { 5 | NIM_STRLIT_FLAG, "tyInt" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_244 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_243};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_245 = { 6 | NIM_STRLIT_FLAG, "tyInt8" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_246 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_245};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_247 = { 7 | NIM_STRLIT_FLAG, "tyInt16" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_248 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_247};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_249 = { 7 | NIM_STRLIT_FLAG, "tyInt32" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_250 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_249};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_251 = { 7 | NIM_STRLIT_FLAG, "tyInt64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_252 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_251};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_253 = { 7 | NIM_STRLIT_FLAG, "tyFloat" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_254 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_253};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_255 = { 9 | NIM_STRLIT_FLAG, "tyFloat32" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_256 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_255};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_257 = { 9 | NIM_STRLIT_FLAG, "tyFloat64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_258 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_257};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_259 = { 10 | NIM_STRLIT_FLAG, "tyFloat128" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_260 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_259};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_261 = { 6 | NIM_STRLIT_FLAG, "tyUInt" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_262 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_261};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_263 = { 7 | NIM_STRLIT_FLAG, "tyUInt8" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_264 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_263};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_265 = { 8 | NIM_STRLIT_FLAG, "tyUInt16" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_266 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_265};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_267 = { 8 | NIM_STRLIT_FLAG, "tyUInt32" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_268 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_267};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_269 = { 8 | NIM_STRLIT_FLAG, "tyUInt64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_270 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_269};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_271 = { 7 | NIM_STRLIT_FLAG, "tyOwned" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_272 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_271};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_273 = { 6 | NIM_STRLIT_FLAG, "tySink" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_274 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_273};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_275 = { 6 | NIM_STRLIT_FLAG, "tyLent" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_276 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_275};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_277 = { 9 | NIM_STRLIT_FLAG, "tyVarargs" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_278 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_277};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_279 = { 16 | NIM_STRLIT_FLAG, "tyUncheckedArray" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_280 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_279};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_281 = { 7 | NIM_STRLIT_FLAG, "tyError" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_282 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_281};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_283 = { 18 | NIM_STRLIT_FLAG, "tyBuiltInTypeClass" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_284 = {18, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_283};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_285 = { 15 | NIM_STRLIT_FLAG, "tyUserTypeClass" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_286 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_285};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_287 = { 19 | NIM_STRLIT_FLAG, "tyUserTypeClassInst" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_288 = {19, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_287};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_289 = { 20 | NIM_STRLIT_FLAG, "tyCompositeTypeClass" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_290 = {20, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_289};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_291 = { 10 | NIM_STRLIT_FLAG, "tyInferred" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_292 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_291};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_293 = { 5 | NIM_STRLIT_FLAG, "tyAnd" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_294 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_293};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_295 = { 4 | NIM_STRLIT_FLAG, "tyOr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_296 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_295};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_297 = { 5 | NIM_STRLIT_FLAG, "tyNot" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_298 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_297};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_299 = { 10 | NIM_STRLIT_FLAG, "tyAnything" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_300 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_299};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_301 = { 8 | NIM_STRLIT_FLAG, "tyStatic" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_302 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_301};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_303 = { 10 | NIM_STRLIT_FLAG, "tyFromExpr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_304 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_303};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_305 = { 9 | NIM_STRLIT_FLAG, "tyConcept" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_306 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_305};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_307 = { 6 | NIM_STRLIT_FLAG, "tyVoid" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_308 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_307};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_309 = { 10 | NIM_STRLIT_FLAG, "tyIterable" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_310 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_309};
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_311 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_52};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_312 = { 9 | NIM_STRLIT_FLAG, "tfVarargs" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_313 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_312};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_314 = { 14 | NIM_STRLIT_FLAG, "tfNoSideEffect" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_315 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_314};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_316 = { 7 | NIM_STRLIT_FLAG, "tfFinal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_317 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_316};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_318 = { 13 | NIM_STRLIT_FLAG, "tfInheritable" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_319 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_318};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_320 = { 10 | NIM_STRLIT_FLAG, "tfHasOwned" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_321 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_320};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_322 = { 14 | NIM_STRLIT_FLAG, "tfEnumHasHoles" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_323 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_322};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_324 = { 9 | NIM_STRLIT_FLAG, "tfShallow" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_325 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_324};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_326 = { 8 | NIM_STRLIT_FLAG, "tfThread" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_327 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_326};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_328 = { 13 | NIM_STRLIT_FLAG, "tfFromGeneric" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_329 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_328};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_330 = { 12 | NIM_STRLIT_FLAG, "tfUnresolved" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_331 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_330};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_332 = { 10 | NIM_STRLIT_FLAG, "tfResolved" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_333 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_332};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_334 = { 9 | NIM_STRLIT_FLAG, "tfRetType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_335 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_334};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_336 = { 13 | NIM_STRLIT_FLAG, "tfCapturesEnv" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_337 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_336};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_338 = { 8 | NIM_STRLIT_FLAG, "tfByCopy" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_339 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_338};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_340 = { 7 | NIM_STRLIT_FLAG, "tfByRef" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_341 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_340};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_342 = { 10 | NIM_STRLIT_FLAG, "tfIterator" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_343 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_342};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_344 = { 9 | NIM_STRLIT_FLAG, "tfPartial" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_345 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_344};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_346 = { 8 | NIM_STRLIT_FLAG, "tfNotNil" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_347 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_346};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_348 = { 14 | NIM_STRLIT_FLAG, "tfRequiresInit" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_349 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_348};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_350 = { 15 | NIM_STRLIT_FLAG, "tfNeedsFullInit" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_351 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_350};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_352 = { 10 | NIM_STRLIT_FLAG, "tfVarIsPtr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_353 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_352};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_354 = { 9 | NIM_STRLIT_FLAG, "tfHasMeta" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_355 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_354};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_356 = { 12 | NIM_STRLIT_FLAG, "tfHasGCedMem" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_357 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_356};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_358 = { 8 | NIM_STRLIT_FLAG, "tfPacked" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_359 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_358};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_360 = { 11 | NIM_STRLIT_FLAG, "tfHasStatic" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_361 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_360};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_362 = { 18 | NIM_STRLIT_FLAG, "tfGenericTypeParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_363 = {18, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_362};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_364 = { 19 | NIM_STRLIT_FLAG, "tfImplicitTypeParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_365 = {19, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_364};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_366 = { 18 | NIM_STRLIT_FLAG, "tfInferrableStatic" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_367 = {18, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_366};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_368 = { 23 | NIM_STRLIT_FLAG, "tfConceptMatchedTypeSym" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_369 = {23, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_368};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_370 = { 10 | NIM_STRLIT_FLAG, "tfExplicit" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_371 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_370};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_372 = { 10 | NIM_STRLIT_FLAG, "tfWildcard" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_373 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_372};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_374 = { 9 | NIM_STRLIT_FLAG, "tfHasAsgn" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_375 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_374};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_376 = { 11 | NIM_STRLIT_FLAG, "tfBorrowDot" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_377 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_376};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_378 = { 21 | NIM_STRLIT_FLAG, "tfTriggersCompileTime" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_379 = {21, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_378};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_380 = { 13 | NIM_STRLIT_FLAG, "tfRefsAnonObj" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_381 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_380};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_382 = { 11 | NIM_STRLIT_FLAG, "tfCovariant" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_383 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_382};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_384 = { 15 | NIM_STRLIT_FLAG, "tfWeakCovariant" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_385 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_384};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_386 = { 15 | NIM_STRLIT_FLAG, "tfContravariant" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_387 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_386};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_388 = { 22 | NIM_STRLIT_FLAG, "tfCheckedForDestructor" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_389 = {22, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_388};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_390 = { 9 | NIM_STRLIT_FLAG, "tfAcyclic" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_391 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_390};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_392 = { 18 | NIM_STRLIT_FLAG, "tfIncompleteStruct" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_393 = {18, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_392};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_394 = { 16 | NIM_STRLIT_FLAG, "tfCompleteStruct" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_395 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_394};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_396 = { 18 | NIM_STRLIT_FLAG, "tfExplicitCallConv" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_397 = {18, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_396};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_398 = { 15 | NIM_STRLIT_FLAG, "tfIsConstructor" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_399 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_398};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_400 = { 24 | NIM_STRLIT_FLAG, "tfEffectSystemWorkaround" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_401 = {24, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_400};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_402 = { 12 | NIM_STRLIT_FLAG, "tfIsOutParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_403 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_402};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_404 = { 10 | NIM_STRLIT_FLAG, "tfSendable" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_405 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_404};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_406 = { 16 | NIM_STRLIT_FLAG, "tfImplicitStatic" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_407 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_406};
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_408 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_52};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_409 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_410 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_409};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_411 = { 6 | NIM_STRLIT_FLAG, "nfNone" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_412 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_411};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_413 = { 7 | NIM_STRLIT_FLAG, "nfBase2" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_414 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_413};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_415 = { 7 | NIM_STRLIT_FLAG, "nfBase8" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_416 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_415};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_417 = { 8 | NIM_STRLIT_FLAG, "nfBase16" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_418 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_417};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_419 = { 10 | NIM_STRLIT_FLAG, "nfAllConst" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_420 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_419};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_421 = { 8 | NIM_STRLIT_FLAG, "nfTransf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_422 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_421};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_423 = { 11 | NIM_STRLIT_FLAG, "nfNoRewrite" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_424 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_423};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_425 = { 5 | NIM_STRLIT_FLAG, "nfSem" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_426 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_425};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_427 = { 4 | NIM_STRLIT_FLAG, "nfLL" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_428 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_427};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_429 = { 10 | NIM_STRLIT_FLAG, "nfDotField" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_430 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_429};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_431 = { 11 | NIM_STRLIT_FLAG, "nfDotSetter" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_432 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_431};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_433 = { 14 | NIM_STRLIT_FLAG, "nfExplicitCall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_434 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_433};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_435 = { 10 | NIM_STRLIT_FLAG, "nfExprCall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_436 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_435};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_437 = { 7 | NIM_STRLIT_FLAG, "nfIsRef" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_438 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_437};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_439 = { 7 | NIM_STRLIT_FLAG, "nfIsPtr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_440 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_439};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_441 = { 11 | NIM_STRLIT_FLAG, "nfPreventCg" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_442 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_441};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_443 = { 10 | NIM_STRLIT_FLAG, "nfBlockArg" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_444 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_443};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_445 = { 14 | NIM_STRLIT_FLAG, "nfFromTemplate" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_446 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_445};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_447 = { 14 | NIM_STRLIT_FLAG, "nfDefaultParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_448 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_447};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_449 = { 18 | NIM_STRLIT_FLAG, "nfDefaultRefsParam" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_450 = {18, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_449};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_451 = { 17 | NIM_STRLIT_FLAG, "nfExecuteOnReload" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_452 = {17, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_451};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_453 = { 10 | NIM_STRLIT_FLAG, "nfLastRead" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_454 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_453};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_455 = { 12 | NIM_STRLIT_FLAG, "nfFirstWrite" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_456 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_455};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_457 = { 12 | NIM_STRLIT_FLAG, "nfHasComment" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_458 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_457};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_459 = { 19 | NIM_STRLIT_FLAG, "nfSkipFieldChecking" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_460 = {19, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_459};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_461 = { 17 | NIM_STRLIT_FLAG, "nfDisabledOpenSym" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_462 = {17, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_461};
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_463 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_52};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_464 = { 7 | NIM_STRLIT_FLAG, "nimcall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_465 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_464};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_466 = { 7 | NIM_STRLIT_FLAG, "stdcall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_467 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_466};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_468 = { 5 | NIM_STRLIT_FLAG, "cdecl" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_469 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_468};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_470 = { 8 | NIM_STRLIT_FLAG, "safecall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_471 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_470};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_472 = { 7 | NIM_STRLIT_FLAG, "syscall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_473 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_472};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_474 = { 6 | NIM_STRLIT_FLAG, "inline" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_475 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_474};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_476 = { 8 | NIM_STRLIT_FLAG, "noinline" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_477 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_476};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_478 = { 8 | NIM_STRLIT_FLAG, "fastcall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_479 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_478};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_480 = { 8 | NIM_STRLIT_FLAG, "thiscall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_481 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_480};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_482 = { 7 | NIM_STRLIT_FLAG, "closure" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_483 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_482};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_484 = { 6 | NIM_STRLIT_FLAG, "noconv" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_485 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_484};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_486 = { 6 | NIM_STRLIT_FLAG, "member" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_487 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_486};
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_488 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_52};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_489 = { 9 | NIM_STRLIT_FLAG, "(module: " };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_490 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_489};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_491 = { 8 | NIM_STRLIT_FLAG, ", item: " };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_492 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_491};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_493 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_494 = {1, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_493};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_495 = { 43 | NIM_STRLIT_FLAG, "cannot extract number from invalid AST node" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_496 = {43, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_495};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__EnH1I9cGkGYbf9a1NwhuXDPg_497 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__EnH1I9cGkGYbf9a1NwhuXDPg_498 = {
0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__EnH1I9cGkGYbf9a1NwhuXDPg_499 = {
0x10, 0xa9, 0x90, 0x00, 0x00, 0x60, 0x80, 0x00,
0x00}
;
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_500 = { 5 | NIM_STRLIT_FLAG, "mNone" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_501 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_500};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_502 = { 8 | NIM_STRLIT_FLAG, "mDefined" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_503 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_502};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_504 = { 9 | NIM_STRLIT_FLAG, "mDeclared" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_505 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_504};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_506 = { 16 | NIM_STRLIT_FLAG, "mDeclaredInScope" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_507 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_506};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_508 = { 9 | NIM_STRLIT_FLAG, "mCompiles" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_509 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_508};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_510 = { 7 | NIM_STRLIT_FLAG, "mArrGet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_511 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_510};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_512 = { 7 | NIM_STRLIT_FLAG, "mArrPut" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_513 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_512};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_514 = { 5 | NIM_STRLIT_FLAG, "mAsgn" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_515 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_514};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_516 = { 4 | NIM_STRLIT_FLAG, "mLow" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_517 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_516};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_518 = { 5 | NIM_STRLIT_FLAG, "mHigh" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_519 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_518};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_520 = { 7 | NIM_STRLIT_FLAG, "mSizeOf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_521 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_520};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_522 = { 8 | NIM_STRLIT_FLAG, "mAlignOf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_523 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_522};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_524 = { 9 | NIM_STRLIT_FLAG, "mOffsetOf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_525 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_524};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_526 = { 10 | NIM_STRLIT_FLAG, "mTypeTrait" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_527 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_526};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_528 = { 3 | NIM_STRLIT_FLAG, "mIs" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_529 = {3, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_528};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_530 = { 3 | NIM_STRLIT_FLAG, "mOf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_531 = {3, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_530};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_532 = { 5 | NIM_STRLIT_FLAG, "mAddr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_533 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_532};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_534 = { 5 | NIM_STRLIT_FLAG, "mType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_535 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_534};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_536 = { 7 | NIM_STRLIT_FLAG, "mTypeOf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_537 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_536};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_538 = { 7 | NIM_STRLIT_FLAG, "mPlugin" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_539 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_538};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_540 = { 5 | NIM_STRLIT_FLAG, "mEcho" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_541 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_540};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_542 = { 12 | NIM_STRLIT_FLAG, "mShallowCopy" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_543 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_542};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_544 = { 6 | NIM_STRLIT_FLAG, "mSlurp" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_545 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_544};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_546 = { 11 | NIM_STRLIT_FLAG, "mStaticExec" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_547 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_546};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_548 = { 7 | NIM_STRLIT_FLAG, "mStatic" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_549 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_548};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_550 = { 15 | NIM_STRLIT_FLAG, "mParseExprToAst" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_551 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_550};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_552 = { 15 | NIM_STRLIT_FLAG, "mParseStmtToAst" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_553 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_552};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_554 = { 12 | NIM_STRLIT_FLAG, "mExpandToAst" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_555 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_554};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_556 = { 9 | NIM_STRLIT_FLAG, "mQuoteAst" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_557 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_556};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_558 = { 4 | NIM_STRLIT_FLAG, "mInc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_559 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_558};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_560 = { 4 | NIM_STRLIT_FLAG, "mDec" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_561 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_560};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_562 = { 4 | NIM_STRLIT_FLAG, "mOrd" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_563 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_562};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_564 = { 4 | NIM_STRLIT_FLAG, "mNew" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_565 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_564};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_566 = { 12 | NIM_STRLIT_FLAG, "mNewFinalize" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_567 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_566};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_568 = { 7 | NIM_STRLIT_FLAG, "mNewSeq" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_569 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_568};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_570 = { 12 | NIM_STRLIT_FLAG, "mNewSeqOfCap" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_571 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_570};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_572 = { 16 | NIM_STRLIT_FLAG, "mLengthOpenArray" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_573 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_572};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_574 = { 10 | NIM_STRLIT_FLAG, "mLengthStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_575 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_574};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_576 = { 12 | NIM_STRLIT_FLAG, "mLengthArray" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_577 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_576};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_578 = { 10 | NIM_STRLIT_FLAG, "mLengthSeq" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_579 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_578};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_580 = { 5 | NIM_STRLIT_FLAG, "mIncl" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_581 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_580};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_582 = { 5 | NIM_STRLIT_FLAG, "mExcl" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_583 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_582};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_584 = { 5 | NIM_STRLIT_FLAG, "mCard" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_585 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_584};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_586 = { 4 | NIM_STRLIT_FLAG, "mChr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_587 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_586};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_588 = { 6 | NIM_STRLIT_FLAG, "mGCref" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_589 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_588};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_590 = { 8 | NIM_STRLIT_FLAG, "mGCunref" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_591 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_590};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_592 = { 5 | NIM_STRLIT_FLAG, "mAddI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_593 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_592};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_594 = { 5 | NIM_STRLIT_FLAG, "mSubI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_595 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_594};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_596 = { 5 | NIM_STRLIT_FLAG, "mMulI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_597 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_596};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_598 = { 5 | NIM_STRLIT_FLAG, "mDivI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_599 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_598};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_600 = { 5 | NIM_STRLIT_FLAG, "mModI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_601 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_600};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_602 = { 5 | NIM_STRLIT_FLAG, "mSucc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_603 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_602};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_604 = { 5 | NIM_STRLIT_FLAG, "mPred" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_605 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_604};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_606 = { 7 | NIM_STRLIT_FLAG, "mAddF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_607 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_606};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_608 = { 7 | NIM_STRLIT_FLAG, "mSubF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_609 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_608};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_610 = { 7 | NIM_STRLIT_FLAG, "mMulF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_611 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_610};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_612 = { 7 | NIM_STRLIT_FLAG, "mDivF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_613 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_612};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_614 = { 5 | NIM_STRLIT_FLAG, "mShrI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_615 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_614};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_616 = { 5 | NIM_STRLIT_FLAG, "mShlI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_617 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_616};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_618 = { 6 | NIM_STRLIT_FLAG, "mAshrI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_619 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_618};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_620 = { 8 | NIM_STRLIT_FLAG, "mBitandI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_621 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_620};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_622 = { 7 | NIM_STRLIT_FLAG, "mBitorI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_623 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_622};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_624 = { 8 | NIM_STRLIT_FLAG, "mBitxorI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_625 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_624};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_626 = { 5 | NIM_STRLIT_FLAG, "mMinI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_627 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_626};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_628 = { 5 | NIM_STRLIT_FLAG, "mMaxI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_629 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_628};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_630 = { 5 | NIM_STRLIT_FLAG, "mAddU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_631 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_630};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_632 = { 5 | NIM_STRLIT_FLAG, "mSubU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_633 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_632};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_634 = { 5 | NIM_STRLIT_FLAG, "mMulU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_635 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_634};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_636 = { 5 | NIM_STRLIT_FLAG, "mDivU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_637 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_636};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_638 = { 5 | NIM_STRLIT_FLAG, "mModU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_639 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_638};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_640 = { 4 | NIM_STRLIT_FLAG, "mEqI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_641 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_640};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_642 = { 4 | NIM_STRLIT_FLAG, "mLeI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_643 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_642};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_644 = { 4 | NIM_STRLIT_FLAG, "mLtI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_645 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_644};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_646 = { 6 | NIM_STRLIT_FLAG, "mEqF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_647 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_646};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_648 = { 6 | NIM_STRLIT_FLAG, "mLeF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_649 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_648};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_650 = { 6 | NIM_STRLIT_FLAG, "mLtF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_651 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_650};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_652 = { 4 | NIM_STRLIT_FLAG, "mLeU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_653 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_652};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_654 = { 4 | NIM_STRLIT_FLAG, "mLtU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_655 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_654};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_656 = { 7 | NIM_STRLIT_FLAG, "mEqEnum" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_657 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_656};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_658 = { 7 | NIM_STRLIT_FLAG, "mLeEnum" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_659 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_658};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_660 = { 7 | NIM_STRLIT_FLAG, "mLtEnum" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_661 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_660};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_662 = { 5 | NIM_STRLIT_FLAG, "mEqCh" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_663 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_662};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_664 = { 5 | NIM_STRLIT_FLAG, "mLeCh" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_665 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_664};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_666 = { 5 | NIM_STRLIT_FLAG, "mLtCh" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_667 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_666};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_668 = { 4 | NIM_STRLIT_FLAG, "mEqB" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_669 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_668};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_670 = { 4 | NIM_STRLIT_FLAG, "mLeB" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_671 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_670};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_672 = { 4 | NIM_STRLIT_FLAG, "mLtB" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_673 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_672};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_674 = { 6 | NIM_STRLIT_FLAG, "mEqRef" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_675 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_674};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_676 = { 6 | NIM_STRLIT_FLAG, "mLePtr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_677 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_676};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_678 = { 6 | NIM_STRLIT_FLAG, "mLtPtr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_679 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_678};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_680 = { 4 | NIM_STRLIT_FLAG, "mXor" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_681 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_680};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_682 = { 10 | NIM_STRLIT_FLAG, "mEqCString" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_683 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_682};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_684 = { 7 | NIM_STRLIT_FLAG, "mEqProc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_685 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_684};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_686 = { 12 | NIM_STRLIT_FLAG, "mUnaryMinusI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_687 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_686};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_688 = { 14 | NIM_STRLIT_FLAG, "mUnaryMinusI64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_689 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_688};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_690 = { 5 | NIM_STRLIT_FLAG, "mAbsI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_691 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_690};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_692 = { 4 | NIM_STRLIT_FLAG, "mNot" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_693 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_692};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_694 = { 11 | NIM_STRLIT_FLAG, "mUnaryPlusI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_695 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_694};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_696 = { 8 | NIM_STRLIT_FLAG, "mBitnotI" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_697 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_696};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_698 = { 13 | NIM_STRLIT_FLAG, "mUnaryPlusF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_699 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_698};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_700 = { 14 | NIM_STRLIT_FLAG, "mUnaryMinusF64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_701 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_700};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_702 = { 10 | NIM_STRLIT_FLAG, "mCharToStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_703 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_702};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_704 = { 10 | NIM_STRLIT_FLAG, "mBoolToStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_705 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_704};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_706 = { 10 | NIM_STRLIT_FLAG, "mCStrToStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_707 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_706};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_708 = { 9 | NIM_STRLIT_FLAG, "mStrToStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_709 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_708};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_710 = { 10 | NIM_STRLIT_FLAG, "mEnumToStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_711 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_710};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_712 = { 4 | NIM_STRLIT_FLAG, "mAnd" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_713 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_712};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_714 = { 3 | NIM_STRLIT_FLAG, "mOr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_715 = {3, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_714};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_716 = { 8 | NIM_STRLIT_FLAG, "mImplies" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_717 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_716};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_718 = { 4 | NIM_STRLIT_FLAG, "mIff" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_719 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_718};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_720 = { 7 | NIM_STRLIT_FLAG, "mExists" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_721 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_720};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_722 = { 7 | NIM_STRLIT_FLAG, "mForall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_723 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_722};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_724 = { 4 | NIM_STRLIT_FLAG, "mOld" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_725 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_724};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_726 = { 6 | NIM_STRLIT_FLAG, "mEqStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_727 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_726};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_728 = { 6 | NIM_STRLIT_FLAG, "mLeStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_729 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_728};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_730 = { 6 | NIM_STRLIT_FLAG, "mLtStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_731 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_730};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_732 = { 6 | NIM_STRLIT_FLAG, "mEqSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_733 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_732};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_734 = { 6 | NIM_STRLIT_FLAG, "mLeSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_735 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_734};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_736 = { 6 | NIM_STRLIT_FLAG, "mLtSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_737 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_736};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_738 = { 7 | NIM_STRLIT_FLAG, "mMulSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_739 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_738};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_740 = { 8 | NIM_STRLIT_FLAG, "mPlusSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_741 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_740};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_742 = { 9 | NIM_STRLIT_FLAG, "mMinusSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_743 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_742};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_744 = { 7 | NIM_STRLIT_FLAG, "mXorSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_745 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_744};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_746 = { 10 | NIM_STRLIT_FLAG, "mConStrStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_747 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_746};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_748 = { 6 | NIM_STRLIT_FLAG, "mSlice" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_749 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_748};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_750 = { 7 | NIM_STRLIT_FLAG, "mDotDot" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_751 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_750};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_752 = { 7 | NIM_STRLIT_FLAG, "mFields" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_753 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_752};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_754 = { 11 | NIM_STRLIT_FLAG, "mFieldPairs" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_755 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_754};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_756 = { 10 | NIM_STRLIT_FLAG, "mOmpParFor" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_757 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_756};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_758 = { 12 | NIM_STRLIT_FLAG, "mAppendStrCh" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_759 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_758};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_760 = { 13 | NIM_STRLIT_FLAG, "mAppendStrStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_761 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_760};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_762 = { 14 | NIM_STRLIT_FLAG, "mAppendSeqElem" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_763 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_762};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_764 = { 6 | NIM_STRLIT_FLAG, "mInSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_765 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_764};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_766 = { 5 | NIM_STRLIT_FLAG, "mRepr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_767 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_766};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_768 = { 5 | NIM_STRLIT_FLAG, "mExit" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_769 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_768};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_770 = { 13 | NIM_STRLIT_FLAG, "mSetLengthStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_771 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_770};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_772 = { 13 | NIM_STRLIT_FLAG, "mSetLengthSeq" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_773 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_772};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_774 = { 19 | NIM_STRLIT_FLAG, "mSetLengthSeqUninit" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_775 = {19, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_774};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_776 = { 9 | NIM_STRLIT_FLAG, "mIsPartOf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_777 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_776};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_778 = { 9 | NIM_STRLIT_FLAG, "mAstToStr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_779 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_778};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_780 = { 9 | NIM_STRLIT_FLAG, "mParallel" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_781 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_780};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_782 = { 5 | NIM_STRLIT_FLAG, "mSwap" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_783 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_782};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_784 = { 6 | NIM_STRLIT_FLAG, "mIsNil" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_785 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_784};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_786 = { 9 | NIM_STRLIT_FLAG, "mArrToSeq" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_787 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_786};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_788 = { 15 | NIM_STRLIT_FLAG, "mOpenArrayToSeq" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_789 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_788};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_790 = { 10 | NIM_STRLIT_FLAG, "mNewString" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_791 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_790};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_792 = { 15 | NIM_STRLIT_FLAG, "mNewStringOfCap" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_793 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_792};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_794 = { 18 | NIM_STRLIT_FLAG, "mParseBiggestFloat" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_795 = {18, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_794};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_796 = { 5 | NIM_STRLIT_FLAG, "mMove" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_797 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_796};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_798 = { 11 | NIM_STRLIT_FLAG, "mEnsureMove" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_799 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_798};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_800 = { 9 | NIM_STRLIT_FLAG, "mWasMoved" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_801 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_800};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_802 = { 4 | NIM_STRLIT_FLAG, "mDup" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_803 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_802};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_804 = { 8 | NIM_STRLIT_FLAG, "mDestroy" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_805 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_804};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_806 = { 6 | NIM_STRLIT_FLAG, "mTrace" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_807 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_806};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_808 = { 8 | NIM_STRLIT_FLAG, "mDefault" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_809 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_808};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_810 = { 6 | NIM_STRLIT_FLAG, "mUnown" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_811 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_810};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_812 = { 9 | NIM_STRLIT_FLAG, "mFinished" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_813 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_812};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_814 = { 8 | NIM_STRLIT_FLAG, "mIsolate" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_815 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_814};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_816 = { 10 | NIM_STRLIT_FLAG, "mAccessEnv" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_817 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_816};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_818 = { 16 | NIM_STRLIT_FLAG, "mAccessTypeField" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_819 = {16, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_818};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_820 = { 6 | NIM_STRLIT_FLAG, "mArray" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_821 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_820};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_822 = { 10 | NIM_STRLIT_FLAG, "mOpenArray" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_823 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_822};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_824 = { 6 | NIM_STRLIT_FLAG, "mRange" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_825 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_824};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_826 = { 4 | NIM_STRLIT_FLAG, "mSet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_827 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_826};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_828 = { 4 | NIM_STRLIT_FLAG, "mSeq" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_829 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_828};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_830 = { 8 | NIM_STRLIT_FLAG, "mVarargs" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_831 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_830};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_832 = { 4 | NIM_STRLIT_FLAG, "mRef" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_833 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_832};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_834 = { 4 | NIM_STRLIT_FLAG, "mPtr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_835 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_834};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_836 = { 4 | NIM_STRLIT_FLAG, "mVar" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_837 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_836};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_838 = { 9 | NIM_STRLIT_FLAG, "mDistinct" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_839 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_838};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_840 = { 5 | NIM_STRLIT_FLAG, "mVoid" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_841 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_840};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_842 = { 6 | NIM_STRLIT_FLAG, "mTuple" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_843 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_842};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_844 = { 8 | NIM_STRLIT_FLAG, "mOrdinal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_845 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_844};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_846 = { 13 | NIM_STRLIT_FLAG, "mIterableType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_847 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_846};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_848 = { 4 | NIM_STRLIT_FLAG, "mInt" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_849 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_848};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_850 = { 5 | NIM_STRLIT_FLAG, "mInt8" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_851 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_850};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_852 = { 6 | NIM_STRLIT_FLAG, "mInt16" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_853 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_852};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_854 = { 6 | NIM_STRLIT_FLAG, "mInt32" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_855 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_854};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_856 = { 6 | NIM_STRLIT_FLAG, "mInt64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_857 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_856};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_858 = { 5 | NIM_STRLIT_FLAG, "mUInt" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_859 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_858};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_860 = { 6 | NIM_STRLIT_FLAG, "mUInt8" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_861 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_860};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_862 = { 7 | NIM_STRLIT_FLAG, "mUInt16" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_863 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_862};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_864 = { 7 | NIM_STRLIT_FLAG, "mUInt32" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_865 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_864};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_866 = { 7 | NIM_STRLIT_FLAG, "mUInt64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_867 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_866};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_868 = { 6 | NIM_STRLIT_FLAG, "mFloat" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_869 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_868};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_870 = { 8 | NIM_STRLIT_FLAG, "mFloat32" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_871 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_870};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_872 = { 8 | NIM_STRLIT_FLAG, "mFloat64" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_873 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_872};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_874 = { 9 | NIM_STRLIT_FLAG, "mFloat128" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_875 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_874};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_876 = { 5 | NIM_STRLIT_FLAG, "mBool" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_877 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_876};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_878 = { 5 | NIM_STRLIT_FLAG, "mChar" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_879 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_878};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_880 = { 7 | NIM_STRLIT_FLAG, "mString" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_881 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_880};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_882 = { 8 | NIM_STRLIT_FLAG, "mCstring" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_883 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_882};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_884 = { 8 | NIM_STRLIT_FLAG, "mPointer" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_885 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_884};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_886 = { 4 | NIM_STRLIT_FLAG, "mNil" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_887 = {4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_886};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_888 = { 5 | NIM_STRLIT_FLAG, "mExpr" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_889 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_888};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_890 = { 5 | NIM_STRLIT_FLAG, "mStmt" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_891 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_890};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_892 = { 9 | NIM_STRLIT_FLAG, "mTypeDesc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_893 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_892};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_894 = { 9 | NIM_STRLIT_FLAG, "mVoidType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_895 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_894};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_896 = { 12 | NIM_STRLIT_FLAG, "mPNimrodNode" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_897 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_896};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_898 = { 6 | NIM_STRLIT_FLAG, "mSpawn" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_899 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_898};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_900 = { 9 | NIM_STRLIT_FLAG, "mDeepCopy" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_901 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_900};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_902 = { 13 | NIM_STRLIT_FLAG, "mIsMainModule" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_903 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_902};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_904 = { 12 | NIM_STRLIT_FLAG, "mCompileDate" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_905 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_904};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_906 = { 12 | NIM_STRLIT_FLAG, "mCompileTime" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_907 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_906};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_908 = { 9 | NIM_STRLIT_FLAG, "mProcCall" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_909 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_908};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_910 = { 10 | NIM_STRLIT_FLAG, "mCpuEndian" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_911 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_910};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_912 = { 7 | NIM_STRLIT_FLAG, "mHostOS" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_913 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_912};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_914 = { 8 | NIM_STRLIT_FLAG, "mHostCPU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_915 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_914};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_916 = { 8 | NIM_STRLIT_FLAG, "mBuildOS" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_917 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_916};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_918 = { 9 | NIM_STRLIT_FLAG, "mBuildCPU" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_919 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_918};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_920 = { 8 | NIM_STRLIT_FLAG, "mAppType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_921 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_920};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_922 = { 14 | NIM_STRLIT_FLAG, "mCompileOption" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_923 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_922};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_924 = { 17 | NIM_STRLIT_FLAG, "mCompileOptionArg" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_925 = {17, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_924};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_926 = { 5 | NIM_STRLIT_FLAG, "mNLen" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_927 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_926};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_928 = { 7 | NIM_STRLIT_FLAG, "mNChild" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_929 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_928};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_930 = { 10 | NIM_STRLIT_FLAG, "mNSetChild" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_931 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_930};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_932 = { 5 | NIM_STRLIT_FLAG, "mNAdd" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_933 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_932};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_934 = { 13 | NIM_STRLIT_FLAG, "mNAddMultiple" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_935 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_934};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_936 = { 5 | NIM_STRLIT_FLAG, "mNDel" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_937 = {5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_936};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_938 = { 6 | NIM_STRLIT_FLAG, "mNKind" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_939 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_938};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_940 = { 9 | NIM_STRLIT_FLAG, "mNSymKind" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_941 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_940};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_942 = { 9 | NIM_STRLIT_FLAG, "mNccValue" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_943 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_942};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_944 = { 7 | NIM_STRLIT_FLAG, "mNccInc" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_945 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_944};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_946 = { 7 | NIM_STRLIT_FLAG, "mNcsAdd" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_947 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_946};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_948 = { 8 | NIM_STRLIT_FLAG, "mNcsIncl" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_949 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_948};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_950 = { 7 | NIM_STRLIT_FLAG, "mNcsLen" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_951 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_950};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_952 = { 6 | NIM_STRLIT_FLAG, "mNcsAt" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_953 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_952};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_954 = { 7 | NIM_STRLIT_FLAG, "mNctPut" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_955 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_954};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_956 = { 7 | NIM_STRLIT_FLAG, "mNctLen" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_957 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_956};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_958 = { 7 | NIM_STRLIT_FLAG, "mNctGet" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_959 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_958};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_960 = { 11 | NIM_STRLIT_FLAG, "mNctHasNext" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_961 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_960};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_962 = { 8 | NIM_STRLIT_FLAG, "mNctNext" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_963 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_962};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_964 = { 8 | NIM_STRLIT_FLAG, "mNIntVal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_965 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_964};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_966 = { 10 | NIM_STRLIT_FLAG, "mNFloatVal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_967 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_966};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_968 = { 8 | NIM_STRLIT_FLAG, "mNSymbol" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_969 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_968};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_970 = { 7 | NIM_STRLIT_FLAG, "mNIdent" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_971 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_970};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_972 = { 9 | NIM_STRLIT_FLAG, "mNGetType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_973 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_972};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_974 = { 8 | NIM_STRLIT_FLAG, "mNStrVal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_975 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_974};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_976 = { 11 | NIM_STRLIT_FLAG, "mNSetIntVal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_977 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_976};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_978 = { 13 | NIM_STRLIT_FLAG, "mNSetFloatVal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_979 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_978};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_980 = { 11 | NIM_STRLIT_FLAG, "mNSetSymbol" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_981 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_980};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_982 = { 10 | NIM_STRLIT_FLAG, "mNSetIdent" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_983 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_982};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_984 = { 11 | NIM_STRLIT_FLAG, "mNSetStrVal" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_985 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_984};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_986 = { 10 | NIM_STRLIT_FLAG, "mNLineInfo" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_987 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_986};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_988 = { 12 | NIM_STRLIT_FLAG, "mNNewNimNode" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_989 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_988};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_990 = { 13 | NIM_STRLIT_FLAG, "mNCopyNimNode" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_991 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_990};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_992 = { 13 | NIM_STRLIT_FLAG, "mNCopyNimTree" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_993 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_992};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_994 = { 11 | NIM_STRLIT_FLAG, "mStrToIdent" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_995 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_994};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_996 = { 9 | NIM_STRLIT_FLAG, "mNSigHash" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_997 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_996};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_998 = { 8 | NIM_STRLIT_FLAG, "mNSizeOf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_999 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_998};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1000 = { 9 | NIM_STRLIT_FLAG, "mNBindSym" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1001 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1000};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1002 = { 10 | NIM_STRLIT_FLAG, "mNCallSite" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1003 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1002};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1004 = { 8 | NIM_STRLIT_FLAG, "mEqIdent" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1005 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1004};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1006 = { 13 | NIM_STRLIT_FLAG, "mEqNimrodNode" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1007 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1006};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1008 = { 13 | NIM_STRLIT_FLAG, "mSameNodeType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1009 = {13, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1008};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1010 = { 8 | NIM_STRLIT_FLAG, "mGetImpl" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1011 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1010};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1012 = { 8 | NIM_STRLIT_FLAG, "mNGenSym" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1013 = {8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1012};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1014 = { 6 | NIM_STRLIT_FLAG, "mNHint" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1015 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1014};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1016 = { 9 | NIM_STRLIT_FLAG, "mNWarning" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1017 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1016};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1018 = { 7 | NIM_STRLIT_FLAG, "mNError" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1019 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1018};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1020 = { 18 | NIM_STRLIT_FLAG, "mInstantiationInfo" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1021 = {18, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1020};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1022 = { 12 | NIM_STRLIT_FLAG, "mGetTypeInfo" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1023 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1022};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1024 = { 14 | NIM_STRLIT_FLAG, "mGetTypeInfoV2" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1025 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1024};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1026 = { 6 | NIM_STRLIT_FLAG, "mNimvm" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1027 = {6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1026};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1028 = { 10 | NIM_STRLIT_FLAG, "mIntDefine" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1029 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1028};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1030 = { 10 | NIM_STRLIT_FLAG, "mStrDefine" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1031 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1030};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1032 = { 11 | NIM_STRLIT_FLAG, "mBoolDefine" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1033 = {11, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1032};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1034 = { 14 | NIM_STRLIT_FLAG, "mGenericDefine" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1035 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1034};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1036 = { 17 | NIM_STRLIT_FLAG, "mRunnableExamples" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1037 = {17, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1036};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1038 = { 10 | NIM_STRLIT_FLAG, "mException" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1039 = {10, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1038};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1040 = { 12 | NIM_STRLIT_FLAG, "mBuiltinType" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1041 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1040};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1042 = { 9 | NIM_STRLIT_FLAG, "mSymOwner" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1043 = {9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1042};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1044 = { 15 | NIM_STRLIT_FLAG, "mUncheckedArray" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1045 = {15, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1044};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1046 = { 14 | NIM_STRLIT_FLAG, "mGetImplTransf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1047 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1046};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1048 = { 21 | NIM_STRLIT_FLAG, "mSymIsInstantiationOf" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1049 = {21, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1048};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1050 = { 7 | NIM_STRLIT_FLAG, "mNodeId" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1051 = {7, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1050};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1052 = { 14 | NIM_STRLIT_FLAG, "mPrivateAccess" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1053 = {14, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1052};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1054 = { 12 | NIM_STRLIT_FLAG, "mZeroDefault" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1055 = {12, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1054};
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1056 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_52};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1057 = { 9 | NIM_STRLIT_FLAG, "=wasMoved" };
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1058 = { 8 | NIM_STRLIT_FLAG, "=destroy" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1059 = { 5 | NIM_STRLIT_FLAG, "=copy" };
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1060 = { 4 | NIM_STRLIT_FLAG, "=dup" };
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1061 = { 5 | NIM_STRLIT_FLAG, "=sink" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1062 = { 6 | NIM_STRLIT_FLAG, "=trace" };
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1063 = { 9 | NIM_STRLIT_FLAG, "=deepcopy" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1064 = {43, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_495};
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1065 = {0, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_409};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__EnH1I9cGkGYbf9a1NwhuXDPg_1066 = { 43 | NIM_STRLIT_FLAG, "cannot extract string from invalid AST node" };
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1067 = {43, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1066};
static const NimStringV2 TM__EnH1I9cGkGYbf9a1NwhuXDPg_1068 = {43, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1066};
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__EnH1I9cGkGYbf9a1NwhuXDPg_1069 = {
0x10, 0x28, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
static NIM_CONST tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg TM__EnH1I9cGkGYbf9a1NwhuXDPg_1070 = {
0x10, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00}
;
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
N_LIB_PRIVATE NIM_CONST tyArray__dwfJdPZJYBY1vfSlirNUOQ AttachedOpToStr__ast_u5487 = {{9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1057},
{8, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1058},
{5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1059},
{4, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1060},
{5, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1061},
{6, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1062},
{9, (NimStrPayload*)&TM__EnH1I9cGkGYbf9a1NwhuXDPg_1063}}
;
N_LIB_PRIVATE NIM_CONST tySet_tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q routineKinds__ast_u312 = 520192;
N_LIB_PRIVATE tyObject_Gconfig__YzAefAIiOD2E89cs4Ro1q0A gconfig__ast_u833;
N_LIB_PRIVATE tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A eqTypeFlags__ast_u326 = IL64(35184373301378);
N_LIB_PRIVATE NIM_BOOL ggDebug__ast_u3179;
extern NIM_BOOL nimInErrorMode__system_u4141;
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u309)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)0):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_3;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)1):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_5;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)2):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_7;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)3):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_9;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)4):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_11;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)5):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_13;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_15;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_17;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_19;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_21;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_23;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)11):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_25;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_27;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_29;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_31;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_33;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_35;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_37;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_39;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_41;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_43;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_45;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)22):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_47;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)23):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_49;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)24):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_51;
	}
	break;
	default:
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_53;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u94)(tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)0):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_55;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)1):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_57;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)2):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_59;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)3):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_61;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)4):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_63;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)5):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_65;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)6):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_67;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)7):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_69;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)8):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_71;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)9):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_73;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)10):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_75;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)11):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_77;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)12):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_79;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)13):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_81;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)14):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_83;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)15):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_85;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)16):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_87;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)17):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_89;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)18):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_91;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)19):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_93;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)20):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_95;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)21):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_97;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)22):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_99;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)23):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_101;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)24):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_103;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)25):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_105;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)26):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_107;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)27):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_109;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)28):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_111;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)29):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_113;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)30):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_115;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)31):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_117;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)32):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_119;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)33):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_121;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)34):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_123;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)35):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_125;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)36):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_127;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)37):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_129;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)38):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_131;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)39):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_133;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)40):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_135;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)41):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_137;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)42):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_139;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)43):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_141;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)44):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_143;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)45):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_145;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)46):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_147;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)47):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_149;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)48):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_151;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)49):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_153;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)50):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_155;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)51):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_157;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)52):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_159;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)53):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_161;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)54):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_163;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)55):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_165;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)56):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_167;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)57):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_169;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)58):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_171;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)59):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_173;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)60):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_175;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)61):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_177;
	}
	break;
	case ((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)62):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_179;
	}
	break;
	default:
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_180;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u182)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)0):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_182;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_184;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_186;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)3):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_188;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_190;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)5):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_192;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)6):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_194;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)7):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_196;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_198;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)9):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_200;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_202;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_204;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_206;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_208;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_210;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)15):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_212;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_214;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_216;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_218;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_220;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)20):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_222;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_224;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_226;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)23):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_228;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_230;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_232;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)26):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_234;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)27):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_236;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_238;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)29):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_240;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)30):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_242;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_244;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)32):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_246;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_248;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_250;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_252;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)36):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_254;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)37):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_256;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)38):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_258;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)39):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_260;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_262;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)41):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_264;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)42):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_266;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_268;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_270;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)45):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_272;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)46):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_274;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)47):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_276;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)48):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_278;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)49):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_280;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)50):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_282;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)51):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_284;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)52):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_286;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)53):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_288;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)54):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_290;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)55):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_292;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)56):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_294;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)57):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_296;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)58):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_298;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)59):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_300;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_302;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)61):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_304;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)62):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_306;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)63):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_308;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)64):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_310;
	}
	break;
	default:
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_311;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u281)(tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)0):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_313;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)1):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_315;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)2):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_317;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)3):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_319;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)4):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_321;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)5):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_323;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)6):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_325;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)7):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_327;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)8):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_329;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)9):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_331;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)10):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_333;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)11):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_335;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)12):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_337;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)13):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_339;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)14):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_341;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)15):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_343;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)16):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_345;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)17):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_347;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)18):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_349;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)19):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_351;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)20):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_353;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)21):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_355;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)22):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_357;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)23):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_359;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)24):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_361;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)25):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_363;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)26):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_365;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)27):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_367;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)28):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_369;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)29):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_371;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)30):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_373;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)31):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_375;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)32):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_377;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)33):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_379;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)34):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_381;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)35):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_383;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)36):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_385;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)37):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_387;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)38):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_389;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)39):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_391;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)40):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_393;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)41):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_395;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)42):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_397;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)43):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_399;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)44):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_401;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)45):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_403;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)46):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_405;
	}
	break;
	case ((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)47):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_407;
	}
	break;
	default:
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_408;
	}
	break;
	}
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4141);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, comment__ast_u836)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		NimStringV2* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((*n_p0).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)23)))&31U)))!=0);
		if (!(T3_)) goto LA4_;
		T3_ = !(gconfig__ast_u833.useIc);
LA4_: ;
		if (!T3_) goto LA5_;
		T7_ = (NimStringV2*)0;
		T7_ = X5BX5D___ast_u893((&gconfig__ast_u833.comments), ((NI) (n_p0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqcopy___system_u2694((&result), (*T7_));
	}
	goto LA1_;
LA5_: ;
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_410;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u230)(tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)0):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_412;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)1):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_414;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)2):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_416;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)3):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_418;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)4):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_420;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)5):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_422;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)6):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_424;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)7):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_426;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)8):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_428;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)9):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_430;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)10):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_432;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)11):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_434;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)12):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_436;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)13):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_438;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)14):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_440;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)15):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_442;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)16):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_444;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)17):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_446;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)18):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_448;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)19):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_450;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)20):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_452;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)21):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_454;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)22):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_456;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)23):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_458;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)24):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_460;
	}
	break;
	case ((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)25):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_462;
	}
	break;
	default:
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_463;
	}
	break;
	}
	return result;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) - (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU32)(((NU) (x_p0))) + (NU32)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3125(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)8));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI32)((*cell_1).rc) >> (NU32)(((NI)4) & (32 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3521)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.path);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.path)));
		nimRawDispose(dest_p0.path, ((NI)8));
	}
LA4_: ;
	eqdestroy___system_u2691(dest_p0.name);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).instantiatedFrom);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).instantiatedFrom)));
		nimRawDispose((*dest_p0).instantiatedFrom, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).constraint);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3270((&(*(*dest_p0).constraint)));
		nimRawDispose((*dest_p0).constraint, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLast((*dest_p0).annex);
		if (!T13_) goto LA14_;
		eqdestroy___ast_u3521((*(*dest_p0).annex));
		nimRawDispose((*dest_p0).annex, ((NI)4));
	}
LA14_: ;
	eqdestroy___system_u2691((*dest_p0).loc.snippet);
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastDyn((*dest_p0).loc.lode);
		if (!T18_) goto LA19_;
		eqdestroy___ast_u3270((&(*(*dest_p0).loc.lode)));
		nimRawDispose((*dest_p0).loc.lode, ((NI)8));
	}
LA19_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).ast);
		if (!T23_) goto LA24_;
		eqdestroy___ast_u3270((&(*(*dest_p0).ast)));
		nimRawDispose((*dest_p0).ast, ((NI)8));
	}
LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLastDyn((*dest_p0).ownerField);
		if (!T28_) goto LA29_;
		eqdestroy___ast_u3469((&(*(*dest_p0).ownerField)));
		nimRawDispose((*dest_p0).ownerField, ((NI)8));
	}
LA29_: ;
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = nimDecRefIsLastDyn((*dest_p0).name);
		if (!T33_) goto LA34_;
		eqdestroy___idents_u173((*(*dest_p0).name));
		nimRawDispose((*dest_p0).name, ((NI)4));
	}
LA34_: ;
	{
		NIM_BOOL T38_;
		T38_ = (NIM_BOOL)0;
		T38_ = nimDecRefIsLastDyn((*dest_p0).typ);
		if (!T38_) goto LA39_;
		eqdestroy___ast_u3288((&(*(*dest_p0).typ)));
		nimRawDispose((*dest_p0).typ, ((NI)8));
	}
LA39_: ;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) ... ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	{
		{
			NIM_BOOL T44_;
			T44_ = (NIM_BOOL)0;
			T44_ = nimDecRefIsLastDyn((*dest_p0)._kind_1.transformedBody);
			if (!T44_) goto LA45_;
			eqdestroy___ast_u3270((&(*(*dest_p0)._kind_1.transformedBody)));
			nimRawDispose((*dest_p0)._kind_1.transformedBody, ((NI)8));
		}
LA45_: ;
		{
			NIM_BOOL T49_;
			T49_ = (NIM_BOOL)0;
			T49_ = nimDecRefIsLastDyn((*dest_p0)._kind_1.gcUnsafetyReason);
			if (!T49_) goto LA50_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_1.gcUnsafetyReason)));
			nimRawDispose((*dest_p0)._kind_1.gcUnsafetyReason, ((NI)8));
		}
LA50_: ;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
	{
		{
			NIM_BOOL T55_;
			T55_ = (NIM_BOOL)0;
			T55_ = nimDecRefIsLastDyn((*dest_p0)._kind_2.guard);
			if (!T55_) goto LA56_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_2.guard)));
			nimRawDispose((*dest_p0)._kind_2.guard, ((NI)8));
		}
LA56_: ;
	}
	break;
	default:
	{
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3696)(tySequence__9ahcSjIErJohSBBFLwuF56Q dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_]);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_])));
				nimRawDispose(dest_p0.p->data[colontmp_], ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0) {
	switch ((*dest_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqdestroy___system_u2691((*dest_p0)._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = nimDecRefIsLastDyn((*dest_p0)._kind_4.sym);
			if (!T7_) goto LA8_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_4.sym)));
			nimRawDispose((*dest_p0)._kind_4.sym, ((NI)8));
		}
LA8_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		{
			NIM_BOOL T13_;
			T13_ = (NIM_BOOL)0;
			T13_ = nimDecRefIsLastDyn((*dest_p0)._kind_5.ident);
			if (!T13_) goto LA14_;
			eqdestroy___idents_u173((*(*dest_p0)._kind_5.ident));
			nimRawDispose((*dest_p0)._kind_5.ident, ((NI)4));
		}
LA14_: ;
	}
	break;
	default:
	{
		eqdestroy___ast_u3696((*dest_p0)._kind_6.sons);
	}
	break;
	}
	{
		NIM_BOOL T19_;
		T19_ = (NIM_BOOL)0;
		T19_ = nimDecRefIsLastDyn((*dest_p0).typField);
		if (!T19_) goto LA20_;
		eqdestroy___ast_u3288((&(*(*dest_p0).typField)));
		nimRawDispose((*dest_p0).typField, ((NI)8));
	}
LA20_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3311)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_]);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_])));
				nimRawDispose(dest_p0.p->data[colontmp_], ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3288)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).typeInst);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*(*dest_p0).typeInst)));
		nimRawDispose((*dest_p0).typeInst, ((NI)8));
	}
LA4_: ;
	eqdestroy___system_u2691((*dest_p0).loc.snippet);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).loc.lode);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3270((&(*(*dest_p0).loc.lode)));
		nimRawDispose((*dest_p0).loc.lode, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).sym);
		if (!T13_) goto LA14_;
		eqdestroy___ast_u3469((&(*(*dest_p0).sym)));
		nimRawDispose((*dest_p0).sym, ((NI)8));
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastDyn((*dest_p0).ownerField);
		if (!T18_) goto LA19_;
		eqdestroy___ast_u3469((&(*(*dest_p0).ownerField)));
		nimRawDispose((*dest_p0).ownerField, ((NI)8));
	}
LA19_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).n);
		if (!T23_) goto LA24_;
		eqdestroy___ast_u3270((&(*(*dest_p0).n)));
		nimRawDispose((*dest_p0).n, ((NI)8));
	}
LA24_: ;
	eqdestroy___ast_u3311((*dest_p0).sons);
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3381)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3288((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3378)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setUseIc__ast_u834)(NIM_BOOL useIc_p0) {
	gconfig__ast_u833.useIc = useIc_p0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3074)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* dest_p0) {
	eqdestroy___ast_u3027((*dest_p0).disambTable.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4848)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_]);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_])));
				nimRawDispose(dest_p0.p->data[colontmp_], ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u1177)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ dest_p0) {
	eqdestroy___ast_u3311(dest_p0.concreteTypes);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.sym);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.sym)));
		nimRawDispose(dest_p0.sym, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3109)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug** dest_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3074((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6347)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg* dest_p0, tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).counter = src_p1.counter;
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___ast_u4848((*dest_p0).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	}BeforeRet_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u4574)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4571)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg, initStrTable__ast_u6321)(void) {
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg));
	result.counter = ((NI)0);
	newSeq__ast_u6323((&result.data), ((NI)8));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6338)(tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg dest_p0) {
	eqdestroy___ast_u4848(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4857)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0, tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___ast_u4848((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3261)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNode__ast_u4069)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) nimNewObj(sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	(*T1_).kind = kind_p0;
	colontmpD_ = eqdup___lineinfos_u2037(unknownLineInfo__lineinfos_u364);
	(*T1_).info = colontmpD_;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
static N_INLINE(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA, nextSymId__ast_u3137)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* x_p0) {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA result;
	(*x_p0).symId += ((NI)1);
	result.module = (*x_p0).module;
	result.item = (*x_p0).symId;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, newSym__ast_u4205)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q symKind_p0, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p3, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p4, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p5) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* colontmpD_;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__3;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA id_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T1_;
	NI T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	id_1 = nextSymId__ast_u3137(idgen_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) nimNewObj(sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg), NIM_ALIGNOF(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	colontmpD_ = eqdup___idents_u161(name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).name = colontmpD_;
	(*T1_).kind = symKind_p0;
	(*T1_).flags = 0;
	colontmpD__2 = eqdup___lineinfos_u2037(info_p4);
	(*T1_).info = colontmpD__2;
	(*T1_).itemId = id_1;
	(*T1_).options = options_p5;
	colontmpD__3 = eqdup___ast_u4580(owner_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).ownerField = colontmpD__3;
	(*T1_).offset = ((NI32)-1);
	T2_ = (NI)0;
	T2_ = getOrDefault__ast_u4282((*idgen_p2).disambTable, name_p1, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).disamb = ((NI32) (T2_));
	result = T1_;
	inc__ast_u4349((&(*idgen_p2).disambTable), name_p1, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNode__ast_u4117)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) nimNewObj(sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	(*T1_).kind = kind_p0;
	colontmpD_ = eqdup___lineinfos_u2037(info_p1);
	(*T1_).info = colontmpD_;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3255)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3270((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, commenteq___ast_u1334)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, NimStringV2 a_p1) {
	NI id_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	id_1 = ((NI) (n_p0));
	{
		NimStringV2 colontmpD_;
		if (!(((NI)0) < a_p1.len)) goto LA3_;
		(*n_p0).flags |= ((NU32)1)<<(((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)23))) & 31);
		colontmpD_ = eqdup___system_u2697(a_p1);
		X5BX5Deq___ast_u1378((&gconfig__ast_u833.comments), id_1, colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		if (!(((*n_p0).flags &((NU32)1<<((NU)((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)23)))&31U)))!=0)) goto LA6_;
		(*n_p0).flags &= ~(((NU32)1) << (((((tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw)23))) & 31));
		del__ast_u2399((&gconfig__ast_u833.comments), id_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA6_: ;
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, eqdup___ast_u3258)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3215)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___ast_u3258(son_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3225((&(*father_p0)._kind_6.sons), colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newAtom__ast_u4121)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4117(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2), info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___idents_u158(&(*result)._kind_5.ident, ident_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1) {
	NIM_BOOL result;
	result = ((*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (x_p0))).p == (*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (y_p1))).p);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3249)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3699)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__ast_u3718((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			{
				if (!src_p1.p->data[colontmp_]) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_]);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_]);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3270((&(*(*dest_p0).p->data[colontmp_])));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_], ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_] = src_p1.p->data[colontmp_];
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3273)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(dest_p0 == src_p1)) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	nimZeroMem((void*)(&colontmp_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	colontmp_ = (*dest_p0);
	nimZeroMem((void*)(&(*dest_p0)), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	{
		if (!(*src_p1).typField) goto LA7_;
		nimIncRef((*src_p1).typField);
	}
LA7_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = nimDecRefIsLastDyn((*dest_p0).typField);
		if (!T11_) goto LA12_;
		eqdestroy___ast_u3288((&(*(*dest_p0).typField)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).typField, ((NI)8));
	}
LA12_: ;
	(*dest_p0).typField = (*src_p1).typField;
	(*dest_p0).info.line = (*src_p1).info.line;
	(*dest_p0).info.col = (*src_p1).info.col;
	(*dest_p0).info.fileIndex = (*src_p1).info.fileIndex;
	(*dest_p0).flags = (*src_p1).flags;
	(*dest_p0).kind = (*src_p1).kind;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*dest_p0)._kind_1.intVal = 0;
		(*dest_p0)._kind_1.intVal = (*src_p1)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*dest_p0)._kind_2.floatVal = 0;
		(*dest_p0)._kind_2.floatVal = (*src_p1)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		(*dest_p0)._kind_3.strVal.len = 0; (*dest_p0)._kind_3.strVal.p = NIM_NIL;
		eqcopy___system_u2694((&(*dest_p0)._kind_3.strVal), (*src_p1)._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		(*dest_p0)._kind_4.sym = 0;
		{
			if (!(*src_p1)._kind_4.sym) goto LA20_;
			nimIncRef((*src_p1)._kind_4.sym);
		}
LA20_: ;
		{
			NIM_BOOL T24_;
			T24_ = (NIM_BOOL)0;
			T24_ = nimDecRefIsLastDyn((*dest_p0)._kind_4.sym);
			if (!T24_) goto LA25_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_4.sym)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose((*dest_p0)._kind_4.sym, ((NI)8));
		}
LA25_: ;
		(*dest_p0)._kind_4.sym = (*src_p1)._kind_4.sym;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		(*dest_p0)._kind_5.ident = 0;
		{
			if (!(*src_p1)._kind_5.ident) goto LA30_;
			nimIncRef((*src_p1)._kind_5.ident);
		}
LA30_: ;
		{
			NIM_BOOL T34_;
			T34_ = (NIM_BOOL)0;
			T34_ = nimDecRefIsLastDyn((*dest_p0)._kind_5.ident);
			if (!T34_) goto LA35_;
			eqdestroy___idents_u173((*(*dest_p0)._kind_5.ident));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose((*dest_p0)._kind_5.ident, ((NI)4));
		}
LA35_: ;
		(*dest_p0)._kind_5.ident = (*src_p1)._kind_5.ident;
	}
	break;
	default:
	{
		(*dest_p0)._kind_6.sons.len = 0; (*dest_p0)._kind_6.sons.p = NIM_NIL;
		eqcopy___ast_u3699((&(*dest_p0)._kind_6.sons), (*src_p1)._kind_6.sons);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	switch (colontmp_.kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqdestroy___system_u2691(colontmp_._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		{
			NIM_BOOL T44_;
			T44_ = (NIM_BOOL)0;
			T44_ = nimDecRefIsLastDyn(colontmp_._kind_4.sym);
			if (!T44_) goto LA45_;
			eqdestroy___ast_u3469((&(*colontmp_._kind_4.sym)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose(colontmp_._kind_4.sym, ((NI)8));
		}
LA45_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		{
			NIM_BOOL T50_;
			T50_ = (NIM_BOOL)0;
			T50_ = nimDecRefIsLastDyn(colontmp_._kind_5.ident);
			if (!T50_) goto LA51_;
			eqdestroy___idents_u173((*colontmp_._kind_5.ident));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose(colontmp_._kind_5.ident, ((NI)4));
		}
LA51_: ;
	}
	break;
	default:
	{
		eqdestroy___ast_u3696(colontmp_._kind_6.sons);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	{
		NIM_BOOL T56_;
		T56_ = (NIM_BOOL)0;
		T56_ = nimDecRefIsLastDyn(colontmp_.typField);
		if (!T56_) goto LA57_;
		eqdestroy___ast_u3288((&(*colontmp_.typField)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.typField, ((NI)8));
	}
LA57_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3279)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).typField);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*(*dest_p0).typField)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).typField, ((NI)8));
	}
LA4_: ;
	(*dest_p0).typField = (*src_p1).typField;
	(*dest_p0).info.line = (*src_p1).info.line;
	(*dest_p0).info.col = (*src_p1).info.col;
	(*dest_p0).info.fileIndex = (*src_p1).info.fileIndex;
	(*dest_p0).flags = (*src_p1).flags;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*dest_p0)._kind_1.intVal = 0;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*dest_p0)._kind_2.floatVal = 0;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqdestroy___system_u2691((*dest_p0)._kind_3.strVal);
		(*dest_p0)._kind_3.strVal.len = 0; (*dest_p0)._kind_3.strVal.p = NIM_NIL;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = nimDecRefIsLastDyn((*dest_p0)._kind_4.sym);
			if (!T12_) goto LA13_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_4.sym)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimZeroMem((void*)(&(*(*dest_p0)._kind_4.sym)), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
			nimRawDispose((*dest_p0)._kind_4.sym, ((NI)8));
		}
LA13_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = nimDecRefIsLastDyn((*dest_p0)._kind_5.ident);
			if (!T18_) goto LA19_;
			eqdestroy___idents_u173((*(*dest_p0)._kind_5.ident));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimZeroMem((void*)(&(*(*dest_p0)._kind_5.ident)), sizeof(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA));
			nimRawDispose((*dest_p0)._kind_5.ident, ((NI)4));
		}
LA19_: ;
	}
	break;
	default:
	{
		eqdestroy___ast_u3696((*dest_p0)._kind_6.sons);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*dest_p0)._kind_6.sons.len = 0; (*dest_p0)._kind_6.sons.p = NIM_NIL;
	}
	break;
	}
	(*dest_p0).kind = 0;
	(*dest_p0).kind = (*src_p1).kind;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*dest_p0)._kind_1.intVal = (*src_p1)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*dest_p0)._kind_2.floatVal = (*src_p1)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		(*dest_p0)._kind_3.strVal = (*src_p1)._kind_3.strVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		(*dest_p0)._kind_4.sym = (*src_p1)._kind_4.sym;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		(*dest_p0)._kind_5.ident = (*src_p1)._kind_5.ident;
	}
	break;
	default:
	{
		(*dest_p0)._kind_6.sons = (*src_p1)._kind_6.sons;
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, eqdup___ast_u3384)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3705)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0, tySequence__9ahcSjIErJohSBBFLwuF56Q src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___ast_u3696((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3693)(tySequence__9ahcSjIErJohSBBFLwuF56Q* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionSonsKind__ast_u6769)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__fgQOep3rrztw9aeZI9aS2Ltg kind_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ obj_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	eqcopy___ast_u3273((&obj_1), (&(*n_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	T1_.kind = kind_p1;
	colontmpD_ = eqdup___ast_u3384((*n_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.typField = colontmpD_;
	T1_.info = obj_1.info;
	T1_.flags = obj_1.flags;
	eqsink___ast_u3279((&(*n_p0)), (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___ast_u3705((&(*n_p0)._kind_6.sons), obj_1._kind_6.sons);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u3693((&obj_1._kind_6.sons));
	eqdestroy___ast_u3270((&obj_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newAtom__ast_u4135)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NimStringV2 strVal_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4117(kind_p0, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___system_u2700((&(*result)._kind_3.strVal), strVal_p1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newAtom__ast_u4125)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NI64 intVal_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4117(kind_p0, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result)._kind_1.intVal = intVal_p1;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newAtom__ast_u4130)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NF floatVal_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4117(kind_p0, info_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result)._kind_2.floatVal = floatVal_p1;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4091)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) nimNewObj(sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	(*T1_).kind = kind_p0;
	colontmpD_ = eqdup___lineinfos_u2037(info_p1);
	(*T1_).info = colontmpD_;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newProcNode__ast_u5430)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* params_p3, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* name_p4, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pattern_p5, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* genericParams_p6, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* pragmas_p7, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* exceptions_p8) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__4;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__5;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__6;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__7;
	tySequence__9ahcSjIErJohSBBFLwuF56Q T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeI__ast_u4091(kind_p0, info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_.len = 7; T1_.p = (tySequence__9ahcSjIErJohSBBFLwuF56Q_Content*) newSeqPayload(7, sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
	colontmpD_ = eqdup___ast_u3258(name_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.p->data[0] = colontmpD_;
	colontmpD__2 = eqdup___ast_u3258(pattern_p5);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.p->data[1] = colontmpD__2;
	colontmpD__3 = eqdup___ast_u3258(genericParams_p6);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.p->data[2] = colontmpD__3;
	colontmpD__4 = eqdup___ast_u3258(params_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.p->data[3] = colontmpD__4;
	colontmpD__5 = eqdup___ast_u3258(pragmas_p7);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.p->data[4] = colontmpD__5;
	colontmpD__6 = eqdup___ast_u3258(exceptions_p8);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.p->data[5] = colontmpD__6;
	colontmpD__7 = eqdup___ast_u3258(body_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.p->data[6] = colontmpD__7;
	eqsink___ast_u3705((&(*result)._kind_6.sons), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTree__ast_u4140)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p2, NI children_p2Len_0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__9ahcSjIErJohSBBFLwuF56Q T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeI__ast_u4091(kind_p0, info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) < children_p2Len_0)) goto LA3_;
		(*result).info = (*children_p2[((NI)0)]).info;
	}
LA3_: ;
	T5_.len = 0; T5_.p = NIM_NIL;
	T5_ = at___ast_u4149(children_p2, children_p2Len_0);
	eqsink___ast_u3705((&(*result)._kind_6.sons), T5_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3387)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3469((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5168)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u4577(&(*result)._kind_4.sym, sym_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&(*result).typField, (*sym_p0).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).info = (*sym_p0).info;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u4583)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug*, idGeneratorForPackage__ast_u3122)(NI32 nextIdWillBe_p0) {
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* result;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug*) nimNewObj(sizeof(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug), NIM_ALIGNOF(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug));
	(*T1_).module = ((NI32)-3);
	(*T1_).symId = (NI32)(nextIdWillBe_p0 - ((NI32)1));
	(*T1_).typeId_0 = ((NI32)0);
	(*T1_).disambTable = initCountTable__ast_u2869(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3100)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3074((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeIT__ast_u4112)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(kind_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).info = info_p1;
	eqcopy___ast_u3381(&(*result).typField, typ_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3375)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6225)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3521((*(*dest_p0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6216)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3521((*dest_p0));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3320)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* dest_p0, tySequence__d8ZV4IMgHt9biik9cS9a0hrmg src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___ast_u3311((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3308)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionNoneToSym__ast_u6838)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ obj_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__2;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	obj_1 = (*n_p0);
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	T1_.kind = ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3);
	colontmpD_ = eqdup___ast_u3384((*n_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.typField = colontmpD_;
	colontmpD__2 = eqdup___lineinfos_u2037(obj_1.info);
	T1_.info = colontmpD__2;
	T1_.flags = obj_1.flags;
	T1_._kind_4.sym = 0;
	eqsink___ast_u3279((&(*n_p0)), (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u748)(tySequence__ZUeR9b415wicThQ9cBWO9aYMw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].val);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].val)));
				nimRawDispose(dest_p0.p->data[colontmp_].val, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u2873)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* dest_p0) {
	eqdestroy___ast_u4848((*dest_p0).allowPrivateAccess);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).parent);
		if (!T3_) goto LA4_;
		eqdestroy___semdata_u2873((&(*(*dest_p0).parent)));
		nimRawDispose((*dest_p0).parent, ((NI)4));
	}
LA4_: ;
	eqdestroy___ast_u4848((*dest_p0).symbols.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3103)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug** dest_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLast((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3074((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA, nextTypeId__ast_u3168)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* x_p0) {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA result;
	(*x_p0).typeId_0 += ((NI)1);
	result.module = (*x_p0).module;
	result.item = (*x_p0).typeId_0;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA, eqdup___ast_u3157)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA src_p0) {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA));
	result.module = src_p0.module;
	result.item = src_p0.item;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newType__ast_u5900)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p3) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA colontmpD__2;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA id_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	id_1 = nextTypeId__ast_u3168(idgen_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) nimNewObj(sizeof(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg), NIM_ALIGNOF(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg));
	(*T1_).kind = kind_p0;
	colontmpD_ = eqdup___ast_u4580(owner_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).ownerField = colontmpD_;
	(*T1_).size = IL64(-1);
	(*T1_).align = ((NI16)-1);
	colontmpD__2 = eqdup___ast_u3157(id_1);
	(*T1_).itemId = colontmpD__2;
	(*T1_).uniqueId = id_1;
	(*T1_).sons.len = 0; (*T1_).sons.p = (tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content*) newSeqPayload(0, sizeof(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*), NIM_ALIGNOF(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*));
	result = T1_;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* blitTmp_1;
		if (!!((son_p3 == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)))) goto LA4_;
		blitTmp_1 = son_p3;
		eqwasMoved___ast_u3375(&son_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__ast_u3891((&(*result).sons), blitTmp_1);
	}
LA4_: ;
	eqdestroy___ast_u3378(son_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u26)(tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)0):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_465;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)1):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_467;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)2):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_469;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)3):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_471;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)4):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_473;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)5):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_475;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)6):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_477;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)7):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_479;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)8):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_481;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_483;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)10):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_485;
	}
	break;
	case ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)11):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_487;
	}
	break;
	default:
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_488;
	}
	break;
	}
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**, X5BX5D___ast_u5281)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, last__ast_u5278)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u5379)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T3_;
			if (!((kinds_p1[(NU)(((*result).kind))>>3] &(1U<<((NU)(((*result).kind))&7U)))!=0)) goto LA2;
			T3_ = NIM_NIL;
			T3_ = last__ast_u5278(result);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T3_); goto BeforeRet_;}
			eqsink___ast_u3387(&result, T3_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4851)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0, tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__ast_u4725((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			{
				if (!src_p1.p->data[colontmp_]) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_]);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_]);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3469((&(*(*dest_p0).p->data[colontmp_])));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_], ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_] = src_p1.p->data[colontmp_];
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___lookups_u77)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww** dest_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___semdata_u2873((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lookups_u74)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___semdata_u2873((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, toObjectFromRefPtrGeneric__ast_u7299)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, typ_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			switch ((*result).kind) {
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10):
			{
				tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T4_;
				T4_ = NIM_NIL;
				T4_ = last__ast_u5278(result);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T4_); goto BeforeRet_;}
				eqsink___ast_u3387(&result, T4_);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)9):
			case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)4):
			{
				eqcopy___ast_u3381(&result, (*result).sons.p->data[((NI)0)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			default:
			{
				goto LA1;
			}
			break;
			}
		}
	} LA1: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___layeredtable_u168)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].val);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3288((&(*dest_p0.p->data[colontmp_].val)));
				nimRawDispose(dest_p0.p->data[colontmp_].val, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___layeredtable_u98)(tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.val);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*dest_p0.val)));
		nimRawDispose(dest_p0.val, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___layeredtable_u95)(tyObject_TIdPair__jFcUgE4X1tLOqan9b4YIIeg* dest_p0) {
	(*dest_p0).key.module = 0;
	(*dest_p0).key.item = 0;
	(*dest_p0).val = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA, initIdTable__layeredtable_u16)(void) {
	tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA));
	nimZeroMem((void*)(&result), sizeof(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA));
	result.counter = ((NI)0);
	newSeq__layeredtable_u20((&result.data), ((NI)8));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___layeredtable_u149)(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA dest_p0) {
	eqdestroy___layeredtable_u168(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u6219)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0, tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLast((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3521((*(*dest_p0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, mergeLoc__ast_u6020)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* a_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw b_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!((*a_p0).k == ((tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ)0))) goto LA3_;
		(*a_p0).k = b_p1.k;
	}
LA3_: ;
	{
		if (!((*a_p0).storage == ((tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg)0))) goto LA7_;
		(*a_p0).storage = b_p1.storage;
	}
LA7_: ;
	(*a_p0).flags = ((*a_p0).flags | b_p1.flags);
	{
		if (!((*a_p0).lode == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA11_;
		eqcopy___ast_u3255(&(*a_p0).lode, b_p1.lode);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA11_: ;
	{
		if (!((*a_p0).snippet.len == 0)) goto LA15_;
		eqcopy___system_u2694((&(*a_p0).snippet), b_p1.snippet);
	}
LA15_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, newSons__ast_u6115)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, NI length_p1) {
	setLen__ast_u3333((&(*father_p0).sons), (length_p1));
}
N_LIB_PRIVATE N_NIMCALL(void, assignType__ast_u6138)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* dest_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* src_p1) {
	NI T14_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).kind = (*src_p1).kind;
	(*dest_p0).flags = (*src_p1).flags;
	(*dest_p0).callConv = (*src_p1).callConv;
	eqcopy___ast_u3255(&(*dest_p0).n, (*src_p1).n);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*dest_p0).size = (*src_p1).size;
	(*dest_p0).align = (*src_p1).align;
	{
		if (!!(((*src_p1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA3_;
		{
			if (!!(((*dest_p0).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)))) goto LA7_;
			(*(*dest_p0).sym).flags = ((*(*dest_p0).sym).flags | ((*(*src_p1).sym).flags & ~ 3));
			{
				if (!((*(*dest_p0).sym).annex == ((tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*) NIM_NIL))) goto LA11_;
				eqcopy___ast_u6219(&(*(*dest_p0).sym).annex, (*(*src_p1).sym).annex);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA11_: ;
			mergeLoc__ast_u6020((&(*(*dest_p0).sym).loc), (*(*src_p1).sym).loc);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA5_;
LA7_: ;
		{
			eqcopy___ast_u4577(&(*dest_p0).sym, (*src_p1).sym);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA5_: ;
	}
LA3_: ;
	T14_ = (*src_p1).sons.len;
	newSons__ast_u6115(dest_p0, T14_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI colontmp_;
		NI T16_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T16_ = (*src_p1).sons.len;
		colontmp_ = T16_;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA18;
				i_1 = i_2;
				eqcopy___ast_u3381(&(*dest_p0).sons.p->data[i_1], (*src_p1).sons.p->data[i_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA18: ;
		}
	}
	}BeforeRet_: ;
}
static N_INLINE(NI, len__ast_u3190)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
	NI T1_;
	T1_ = (*n_p0)._kind_6.sons.len;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyTree__ast_u6891)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		if (!(src_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
	}
LA4_: ;
	result = newNode__ast_u4069((*src_p0).kind);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).info = (*src_p0).info;
	eqcopy___ast_u3381(&(*result).typField, (*src_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).flags = ((*src_p0).flags & 58386190);
	colontmpD_ = comment__ast_u836(src_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	commenteq___ast_u1334(result, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*src_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*result)._kind_1.intVal = (*src_p0)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*result)._kind_2.floatVal = (*src_p0)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___ast_u4577(&(*result)._kind_4.sym, (*src_p0)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		eqcopy___idents_u158(&(*result)._kind_5.ident, (*src_p0)._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqcopy___system_u2694((&(*result)._kind_3.strVal), (*src_p0)._kind_3.strVal);
	}
	break;
	default:
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__ast_u3190(src_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		newSeq__ast_u4100((&(*result)._kind_6.sons), (T12_));
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(src_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T16_;
					if (!(i_2 < colontmp_)) goto LA15;
					i_1 = i_2;
					T16_ = NIM_NIL;
					T16_ = copyTree__ast_u6891((*src_p0)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T16_); goto LA1_;}
					eqsink___ast_u3261(&(*result)._kind_6.sons.p->data[i_1], T16_);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					i_2 += ((NI)1);
				} LA15: ;
			}
		}
	}
	break;
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, copyType__ast_u6238)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newType__ast_u5900((*t_p0).kind, idgen_p1, owner_p2, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	assignType__ast_u6138(result, t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u4577(&(*result).sym, (*t_p0).sym);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ, eqdup___layeredtable_u174)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ src_p0) {
	tySequence__7OXYQ6bHRkhJpRaiS7kiwQ result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__layeredtable_u28((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_].key.module = src_p0.p->data[colontmp_].key.module;
			result.p->data[colontmp_].key.item = src_p0.p->data[colontmp_].key.item;
			result.p->data[colontmp_].val = src_p0.p->data[colontmp_].val;
			{
				if (!src_p0.p->data[colontmp_].val) goto LA7_;
				nimIncRef(src_p0.p->data[colontmp_].val);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA, eqdup___layeredtable_u155)(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA src_p0) {
	tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA result;
	tySequence__7OXYQ6bHRkhJpRaiS7kiwQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA));
	result.counter = src_p0.counter;
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = eqdup___layeredtable_u174(src_p0.data);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___layeredtable_u168(T1_); goto BeforeRet_;}
	result.data = T1_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u815)(tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.val);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.val)));
		nimRawDispose(dest_p0.val, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___semdata_u812)(tyObject_TIdPair__03S6SAVUgd0pzOKFuxkR1A* dest_p0) {
	(*dest_p0).key.module = 0;
	(*dest_p0).key.item = 0;
	(*dest_p0).val = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA, initIdTable__semdata_u1096)(void) {
	tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA));
	nimZeroMem((void*)(&result), sizeof(tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA));
	result.counter = ((NI)0);
	newSeq__semdata_u1100((&result.data), ((NI)8));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___semdata_u1115)(tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA dest_p0) {
	eqdestroy___semdata_u748(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyNode__ast_u6736)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		if (!(src_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
	}
LA4_: ;
	result = newNode__ast_u4069((*src_p0).kind);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).info = (*src_p0).info;
	eqcopy___ast_u3381(&(*result).typField, (*src_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).flags = ((*src_p0).flags & 58386190);
	colontmpD_ = comment__ast_u836(src_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	commenteq___ast_u1334(result, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*src_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*result)._kind_1.intVal = (*src_p0)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*result)._kind_2.floatVal = (*src_p0)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___ast_u4577(&(*result)._kind_4.sym, (*src_p0)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		eqcopy___idents_u158(&(*result)._kind_5.ident, (*src_p0)._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqcopy___system_u2694((&(*result)._kind_3.strVal), (*src_p0)._kind_3.strVal);
	}
	break;
	default:
	{
	}
	break;
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NU64, hiXorLoFallback64__pureZhashes_u37)(NU64 a_p0, NU64 b_p1) {
	NU64 result;
	NU64 colontmpD_;
	NU64 colontmpD__2;
	NU64 colontmpD__3;
	NU64 colontmpD__4;
	NU64 aH_1;
	NU64 aL_1;
	NU64 bH_1;
	NU64 bL_1;
	NU64 rHH_1;
	NU64 rHL_1;
	NU64 rLH_1;
	NU64 rLL_1;
	NU64 t_1;
	NU64 c_1;
	NU64 lo_1;
	NU64 T6_;
	NU64 hi_1;
{	colontmpD_ = (NU64)0;
	colontmpD__2 = (NU64)0;
	colontmpD__3 = (NU64)0;
	colontmpD__4 = (NU64)0;
	aH_1 = (NU64)((NU64)(a_p0) >> (NU64)(((NI)32) & (64 - 1)));
	aL_1 = (NU64)(a_p0 & 4294967295ULL);
	bH_1 = (NU64)((NU64)(b_p1) >> (NU64)(((NI)32) & (64 - 1)));
	bL_1 = (NU64)(b_p1 & 4294967295ULL);
	rHH_1 = (NU64)((NU64)(aH_1) * (NU64)(bH_1));
	rHL_1 = (NU64)((NU64)(aH_1) * (NU64)(bL_1));
	rLH_1 = (NU64)((NU64)(aL_1) * (NU64)(bH_1));
	rLL_1 = (NU64)((NU64)(aL_1) * (NU64)(bL_1));
	t_1 = (NU64)((NU64)(rLL_1) + (NU64)((NU64)((NU64)(rHL_1) << (NU64)(((NI)32) & (64 - 1)))));
	{
		if (!((NU64)(t_1) < (NU64)(rLL_1))) goto LA3_;
		colontmpD_ = 1ULL;
		c_1 = colontmpD_;
	}
	goto LA1_;
LA3_: ;
	{
		colontmpD__2 = 0ULL;
		c_1 = colontmpD__2;
	}
LA1_: ;
	lo_1 = (NU64)((NU64)(t_1) + (NU64)((NU64)((NU64)(rLH_1) << (NU64)(((NI)32) & (64 - 1)))));
	T6_ = (NU64)0;
	{
		if (!((NU64)(lo_1) < (NU64)(t_1))) goto LA9_;
		colontmpD__3 = 1ULL;
		T6_ = colontmpD__3;
	}
	goto LA7_;
LA9_: ;
	{
		colontmpD__4 = 0ULL;
		T6_ = colontmpD__4;
	}
LA7_: ;
	c_1 += T6_;
	hi_1 = (NU64)((NU64)((NU64)((NU64)((NU64)((NU64)(rHH_1) + (NU64)((NU64)((NU64)(rHL_1) >> (NU64)(((NI)32) & (64 - 1)))))) + (NU64)((NU64)((NU64)(rLH_1) >> (NU64)(((NI)32) & (64 - 1)))))) + (NU64)(c_1));
	result = (NU64)(hi_1 ^ lo_1);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NU64, hiXorLo__pureZhashes_u81)(NU64 a_p0, NU64 b_p1) {
	NU64 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NU64)0;
	result = hiXorLoFallback64__pureZhashes_u37(a_p0, b_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, hashWangYi1__pureZhashes_u140)(NU64 x_p0) {
	NI result;
	NU64 T1_;
	NU64 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_ = (NU64)0;
	T1_ = hiXorLo__pureZhashes_u81(11562461410679940143ULL, (NU64)(x_p0 ^ 16646288086500911323ULL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T2_ = (NU64)0;
	T2_ = hiXorLo__pureZhashes_u81(T1_, 16952864883938283885ULL);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = ((NI) (T2_));
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, hash__ast_u624)(NI32 x_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	result = hashWangYi1__pureZhashes_u140(((NU64) (x_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, emarkamp___pureZhashes_u5)(NI h_p0, NI val_p1) {
	NI result;
	NU h_2;
	NU val_2;
	NU res_1;
	h_2 = ((NU) (h_p0));
	val_2 = ((NU) (val_p1));
	res_1 = (NU)((NU32)(h_2) + (NU32)(val_2));
	res_1 = (NU)((NU32)(res_1) + (NU32)((NU)((NU32)(res_1) << (NU32)(((NI)10) & (32 - 1)))));
	res_1 = (NU)(res_1 ^ (NU)((NU32)(res_1) >> (NU32)(((NI)6) & (32 - 1))));
	result = ((NI) (res_1));
	return result;
}
static N_INLINE(NI, emarkdollar___pureZhashes_u20)(NI h_p0) {
	NI result;
	NU h_2;
	NU res_1;
	h_2 = ((NU) (h_p0));
	res_1 = (NU)((NU32)(h_2) + (NU32)((NU)((NU32)(h_2) << (NU32)(((NI)3) & (32 - 1)))));
	res_1 = (NU)(res_1 ^ (NU)((NU32)(res_1) >> (NU32)(((NI)11) & (32 - 1))));
	res_1 = (NU)((NU32)(res_1) + (NU32)((NU)((NU32)(res_1) << (NU32)(((NI)15) & (32 - 1)))));
	result = ((NI) (res_1));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, hash__ast_u621)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA x_p0) {
	NI result;
	NI h_1;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	h_1 = hash__ast_u624(x_p0.module);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI)0;
	T1_ = hash__ast_u624(x_p0.item);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	h_1 = emarkamp___pureZhashes_u5(h_1, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = emarkdollar___pureZhashes_u20(h_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u614)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA x_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	colontmpD_ = dollar___systemZdollars_u24(x_p0.module);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD__2 = dollar___systemZdollars_u24(x_p0.item);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = rawNewString(colontmpD_.len + colontmpD__2.len + 18);
appendString((&T1_), TM__EnH1I9cGkGYbf9a1NwhuXDPg_490);
appendString((&T1_), colontmpD_);
appendString((&T1_), TM__EnH1I9cGkGYbf9a1NwhuXDPg_492);
appendString((&T1_), colontmpD__2);
appendString((&T1_), TM__EnH1I9cGkGYbf9a1NwhuXDPg_494);
	result = T1_;
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg, getInt__ast_u7046)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0) {
	tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&result), sizeof(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg));
	switch ((*a_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)11) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		result = toInt128__int128_u717(((NU64) ((*a_p0)._kind_1.intVal)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)7) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)10):
	{
		result = toInt128__int128_u937((*a_p0)._kind_1.intVal);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6):
	{
		result = toInt128__int128_u937((*a_p0)._kind_1.intVal);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		raiseRecoverableError__lineinfos_u299(TM__EnH1I9cGkGYbf9a1NwhuXDPg_496);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6246)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, exactReplica__ast_u6243)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA colontmpD_;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA colontmpD__2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) nimNewObj(sizeof(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg), NIM_ALIGNOF(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg));
	(*T1_).kind = (*t_p0).kind;
	(*T1_).ownerField = owner__ast_u6246(t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).size = IL64(-1);
	(*T1_).align = ((NI16)-1);
	colontmpD_ = eqdup___ast_u3157((*t_p0).itemId);
	(*T1_).itemId = colontmpD_;
	colontmpD__2 = eqdup___ast_u3157((*t_p0).uniqueId);
	(*T1_).uniqueId = colontmpD__2;
	result = T1_;
	assignType__ast_u6138(result, t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u4577(&(*result).sym, (*t_p0).sym);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3148)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA* dest_p0) {
	(*dest_p0).module = 0;
	(*dest_p0).item = 0;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isMetaType__ast_u4607)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T4_;
{	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)6) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12) || (*t_p0).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)51) && (*t_p0).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)54) || (*t_p0).kind >= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)56) && (*t_p0).kind <= ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)59) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)62));
	if (T2_) goto LA3_;
	T4_ = (NIM_BOOL)0;
	T4_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60));
	if (!(T4_)) goto LA5_;
	T4_ = ((*t_p0).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA5_: ;
	T2_ = T4_;
LA3_: ;
	T1_ = T2_;
	if (T1_) goto LA6_;
	T1_ = (((*t_p0).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)21)))&63U)))!=0);
LA6_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isGCedMem__ast_u6621)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T3_;
	T1_ = (NIM_BOOL)0;
	T1_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22) || (*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24));
	if (T1_) goto LA2_;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
	if (!(T3_)) goto LA4_;
	T3_ = ((*t_p0).callConv == ((tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ)9));
LA4_: ;
	T1_ = T3_;
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, propagateToOwner__ast_u6637)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* owner_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* elem_p1, NIM_BOOL propagateHasAsgn_p2) {
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A mask_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*owner_p0).flags = ((*owner_p0).flags | ((*elem_p1).flags & IL64(8592031744)));
	{
		if (!(((*elem_p1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)17)))&63U)))!=0)) goto LA3_;
		{
			if (!((*owner_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11) || (*owner_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10) || (*owner_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)9))) goto LA7_;
			(*owner_p0).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)17))) & 63);
		}
LA7_: ;
	}
LA3_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = isMetaType__ast_u4607(elem_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T11_) goto LA12_;
		(*owner_p0).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)21))) & 63);
	}
LA12_: ;
	mask_1 = ((*elem_p1).flags & IL64(2147483664));
	{
		NIM_BOOL T16_;
		tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A T17_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* o2_1;
		T16_ = (NIM_BOOL)0;
		T17_ = 0;
		T16_ = !((mask_1 == T17_));
		if (!(T16_)) goto LA18_;
		T16_ = propagateHasAsgn_p2;
LA18_: ;
		if (!T16_) goto LA19_;
		o2_1 = NIM_NIL;
		o2_1 = skipTypes__ast_u5379(owner_p0, TM__EnH1I9cGkGYbf9a1NwhuXDPg_497);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			if (!((*o2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)18) || (*o2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17) || (*o2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)16) || (*o2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)24) || (*o2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)28) || (*o2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)19) || (*o2_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)13))) goto LA23_;
			(*o2_1).flags = ((*o2_1).flags | mask_1);
			(*owner_p0).flags = ((*owner_p0).flags | mask_1);
		}
LA23_: ;
		eqdestroy___ast_u3378(o2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA19_: ;
	{
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* elemB_1;
		if (!!(((*owner_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25) || (*owner_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)11) || (*owner_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)10) || (*owner_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)9) || (*owner_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)21)))) goto LA27_;
		elemB_1 = NIM_NIL;
		elemB_1 = skipTypes__ast_u5379(elem_p1, TM__EnH1I9cGkGYbf9a1NwhuXDPg_497);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = isGCedMem__ast_u6621(elemB_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (T31_) goto LA32_;
			T31_ = (((*elemB_1).flags &((NU64)1<<((NU)((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)22)))&63U)))!=0);
LA32_: ;
			if (!T31_) goto LA33_;
			(*owner_p0).flags |= ((NU64)1)<<(((((tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A)22))) & 63);
		}
LA33_: ;
		eqdestroy___ast_u3378(elemB_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA27_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___layeredtable_u171)(tySequence__7OXYQ6bHRkhJpRaiS7kiwQ* dest_p0, tySequence__7OXYQ6bHRkhJpRaiS7kiwQ src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__layeredtable_u28((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			(*dest_p0).p->data[colontmp_].key.module = src_p1.p->data[colontmp_].key.module;
			(*dest_p0).p->data[colontmp_].key.item = src_p1.p->data[colontmp_].key.item;
			{
				if (!src_p1.p->data[colontmp_].val) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_].val);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_].val);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3288((&(*(*dest_p0).p->data[colontmp_].val)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_].val, ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_].val = src_p1.p->data[colontmp_].val;
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rawAddSon__ast_u6706)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1, NIM_BOOL propagateHasAsgn_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___ast_u3384(son_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3891((&(*father_p0).sons), colontmpD_);
	{
		if (!!((son_p1 == 0))) goto LA3_;
		propagateToOwner__ast_u6637(father_p0, son_p1, propagateHasAsgn_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, owner__ast_u6254)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, (*s_p0).ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u6287)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).k = src_p1.k;
	(*dest_p0).storage = src_p1.storage;
	(*dest_p0).flags = src_p1.flags;
	{
		if (!src_p1.lode) goto LA3_;
		nimIncRef(src_p1.lode);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0).lode);
		if (!T7_) goto LA8_;
		eqdestroy___ast_u3270((&(*(*dest_p0).lode)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).lode, ((NI)8));
	}
LA8_: ;
	(*dest_p0).lode = src_p1.lode;
	eqcopy___system_u2694((&(*dest_p0).snippet), src_p1.snippet);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, copySym__ast_u6250)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = owner__ast_u6254(s_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newSym__ast_u4205((*s_p0).kind, (*s_p0).name, idgen_p1, colontmpD_, (*s_p0).info, (*s_p0).options);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&(*result).typ, (*s_p0).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).flags = (*s_p0).flags;
	(*result).magic = (*s_p0).magic;
	(*result).options = (*s_p0).options;
	(*result).position = (*s_p0).position;
	eqcopy___ast_u6287((&(*result).loc), (*s_p0).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u6219(&(*result).annex, (*s_p0).annex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&(*result).constraint, (*s_p0).constraint);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!((*result).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*result).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9) || (*result).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19))) goto LA3_;
		eqcopy___ast_u4577(&(*result)._kind_2.guard, (*s_p0)._kind_2.guard);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		(*result)._kind_2.bitsize = (*s_p0)._kind_2.bitsize;
		(*result)._kind_2.alignment = (*s_p0)._kind_2.alignment;
	}
LA3_: ;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, newSons__ast_u6108)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, NI length_p1) {
	setLen__ast_u3718((&(*father_p0)._kind_6.sons), (length_p1));
}
N_LIB_PRIVATE N_NIMCALL(void, add__ast_u3881)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* father_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* son_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = eqdup___ast_u3384(son_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3891((&(*father_p0).sons), colontmpD_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntNode__ast_u5200)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NI64 intVal_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(kind_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result)._kind_1.intVal = intVal_p1;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, genericParamHasConstraints__ast_u5654)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NI T1_;
	T1_ = (*t_p0).sons.len;
	result = (((NI)0) < T1_);
	return result;
}
static N_INLINE(NI, safeLen__ast_u3197)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NI result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	{
		if (!((*n_p0).kind >= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)0) && (*n_p0).kind <= ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23))) goto LA3_;
		result = ((NI)0);
	}
	goto LA1_;
LA3_: ;
	{
		result = len__ast_u3190(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, findUnresolvedStatic__ast_u7354)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL oldNimErrFin17_;
NIM_BOOL oldNimErrFin32_;
NIM_BOOL oldNimErrFin28_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T4_;
		NIM_BOOL T5_;
		T3_ = (NIM_BOOL)0;
		T4_ = (NIM_BOOL)0;
		T5_ = (NIM_BOOL)0;
		T5_ = ((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T5_)) goto LA6_;
		T5_ = !(((*n_p0).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
LA6_: ;
		T4_ = T5_;
		if (!(T4_)) goto LA7_;
		T4_ = ((*(*n_p0).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60));
LA7_: ;
		T3_ = T4_;
		if (!(T3_)) goto LA8_;
		T3_ = ((*(*n_p0).typField).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA8_: ;
		if (!T3_) goto LA9_;
		eqcopy___ast_u3255(&result, n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
		T13_ = (NIM_BOOL)0;
		T13_ = !(((*n_p0).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T13_)) goto LA14_;
		T13_ = ((*(*n_p0).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)8));
LA14_: ;
		if (!T13_) goto LA15_;
		t_1 = NIM_NIL;
		t_1 = skipTypes__ast_u5379((*n_p0).typField, TM__EnH1I9cGkGYbf9a1NwhuXDPg_498);
		if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
		{
			NIM_BOOL T20_;
			NIM_BOOL T22_;
			T20_ = (NIM_BOOL)0;
			T20_ = ((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)12));
			if (!(T20_)) goto LA21_;
			T22_ = (NIM_BOOL)0;
			T22_ = genericParamHasConstraints__ast_u5654(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			T20_ = !(T22_);
LA21_: ;
			if (!T20_) goto LA23_;
			eqcopy___ast_u3255(&result, n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			goto BeforeRet_;
		}
LA23_: ;
		{
			LA17_:;
		}
		{
			oldNimErrFin17_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3378(t_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin17_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA15_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* son_1;
		son_1 = NIM_NIL;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
			i_2 = ((NI)0);
			{
				while (1) {
					tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_2;
					if (!(i_2 < colontmp_)) goto LA31;
					n_2 = NIM_NIL;
					i_1 = i_2;
					eqcopy___ast_u3255(&son_1, (*n_p0)._kind_6.sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					n_2 = findUnresolvedStatic__ast_u7354(son_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
					{
						if (!!((n_2 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA35_;
						result = n_2;
						eqwasMoved___ast_u3249(&n_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA32_;
						eqdestroy___ast_u3252(n_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
						eqdestroy___ast_u3252(son_1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA35_: ;
					i_2 += ((NI)1);
					{
						LA32_:;
					}
					{
						oldNimErrFin32_ = *nimErr_; *nimErr_ = NIM_FALSE;
						eqdestroy___ast_u3252(n_2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
						*nimErr_ = oldNimErrFin32_;
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA28_;
				} LA31: ;
			}
		}
		{
			LA28_:;
		}
		{
			oldNimErrFin28_ = *nimErr_; *nimErr_ = NIM_FALSE;
			eqdestroy___ast_u3252(son_1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			*nimErr_ = oldNimErrFin28_;
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww*, eqdup___lookups_u80)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* src_p0) {
	tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)1073741824)) == ((NI)1073741824));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1314)(NimStringV2 s_p0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1) {
	NimStringV2 result;
	NI a_1;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)((NI)(s_p0.len - x_p1.b) - a_1) + ((NI)1));
	result = mnewString((L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				nimPrepareStrMutationV2((&result));
				result.p->data[i_1] = s_p0.p->data[(NI)(i_1 + a_1)];
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig, dotdot___stdZenumutils_u106)(NI a_p0, NI b_p1) {
	tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHumanStrImpl__ast_u7577)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p0) {
	NimStringV2 result;
	tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig T1_;
	NimStringV2 T2_;
	NIM_CHAR T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = dollar___ast_u309(kind_p0);
	T1_ = dotdot___stdZenumutils_u106(((NI)2), ((NI)1));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = X5BX5D___pureZstrutils_u1314(result, T1_);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T2_); goto BeforeRet_;}
	eqsink___system_u2700((&result), T2_);
	nimPrepareStrMutationV2((&result));
	T3_ = (NIM_CHAR)0;
	T3_ = nsuToLowerAsciiChar(result.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.p->data[((NI)0)] = T3_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHumanStr__ast_u7574)(tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = toHumanStrImpl__ast_u7577(kind_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3472)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(dest_p0 == src_p1)) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	nimZeroMem((void*)(&colontmp_), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	colontmp_ = (*dest_p0);
	nimZeroMem((void*)(&(*dest_p0)), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	(*dest_p0).itemId.module = (*src_p1).itemId.module;
	(*dest_p0).itemId.item = (*src_p1).itemId.item;
	(*dest_p0).kind = (*src_p1).kind;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) ... ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	{
		(*dest_p0)._kind_1.gcUnsafetyReason = 0;
		{
			if (!(*src_p1)._kind_1.gcUnsafetyReason) goto LA8_;
			nimIncRef((*src_p1)._kind_1.gcUnsafetyReason);
		}
LA8_: ;
		{
			NIM_BOOL T12_;
			T12_ = (NIM_BOOL)0;
			T12_ = nimDecRefIsLastDyn((*dest_p0)._kind_1.gcUnsafetyReason);
			if (!T12_) goto LA13_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_1.gcUnsafetyReason)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose((*dest_p0)._kind_1.gcUnsafetyReason, ((NI)8));
		}
LA13_: ;
		(*dest_p0)._kind_1.gcUnsafetyReason = (*src_p1)._kind_1.gcUnsafetyReason;
		(*dest_p0)._kind_1.transformedBody = 0;
		{
			if (!(*src_p1)._kind_1.transformedBody) goto LA17_;
			nimIncRef((*src_p1)._kind_1.transformedBody);
		}
LA17_: ;
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = nimDecRefIsLastDyn((*dest_p0)._kind_1.transformedBody);
			if (!T21_) goto LA22_;
			eqdestroy___ast_u3270((&(*(*dest_p0)._kind_1.transformedBody)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose((*dest_p0)._kind_1.transformedBody, ((NI)8));
		}
LA22_: ;
		(*dest_p0)._kind_1.transformedBody = (*src_p1)._kind_1.transformedBody;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
	{
		(*dest_p0)._kind_2.guard = 0;
		{
			if (!(*src_p1)._kind_2.guard) goto LA27_;
			nimIncRef((*src_p1)._kind_2.guard);
		}
LA27_: ;
		{
			NIM_BOOL T31_;
			T31_ = (NIM_BOOL)0;
			T31_ = nimDecRefIsLastDyn((*dest_p0)._kind_2.guard);
			if (!T31_) goto LA32_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_2.guard)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose((*dest_p0)._kind_2.guard, ((NI)8));
		}
LA32_: ;
		(*dest_p0)._kind_2.guard = (*src_p1)._kind_2.guard;
		(*dest_p0)._kind_2.bitsize = 0;
		(*dest_p0)._kind_2.bitsize = (*src_p1)._kind_2.bitsize;
		(*dest_p0)._kind_2.alignment = 0;
		(*dest_p0)._kind_2.alignment = (*src_p1)._kind_2.alignment;
	}
	break;
	default:
	{
	}
	break;
	}
	(*dest_p0).magic = (*src_p1).magic;
	{
		if (!(*src_p1).typ) goto LA37_;
		nimIncRef((*src_p1).typ);
	}
LA37_: ;
	{
		NIM_BOOL T41_;
		T41_ = (NIM_BOOL)0;
		T41_ = nimDecRefIsLastDyn((*dest_p0).typ);
		if (!T41_) goto LA42_;
		eqdestroy___ast_u3288((&(*(*dest_p0).typ)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).typ, ((NI)8));
	}
LA42_: ;
	(*dest_p0).typ = (*src_p1).typ;
	{
		if (!(*src_p1).name) goto LA46_;
		nimIncRef((*src_p1).name);
	}
LA46_: ;
	{
		NIM_BOOL T50_;
		T50_ = (NIM_BOOL)0;
		T50_ = nimDecRefIsLastDyn((*dest_p0).name);
		if (!T50_) goto LA51_;
		eqdestroy___idents_u173((*(*dest_p0).name));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).name, ((NI)4));
	}
LA51_: ;
	(*dest_p0).name = (*src_p1).name;
	(*dest_p0).info.line = (*src_p1).info.line;
	(*dest_p0).info.col = (*src_p1).info.col;
	(*dest_p0).info.fileIndex = (*src_p1).info.fileIndex;
	{
		if (!(*src_p1).ownerField) goto LA55_;
		nimIncRef((*src_p1).ownerField);
	}
LA55_: ;
	{
		NIM_BOOL T59_;
		T59_ = (NIM_BOOL)0;
		T59_ = nimDecRefIsLastDyn((*dest_p0).ownerField);
		if (!T59_) goto LA60_;
		eqdestroy___ast_u3469((&(*(*dest_p0).ownerField)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).ownerField, ((NI)8));
	}
LA60_: ;
	(*dest_p0).ownerField = (*src_p1).ownerField;
	(*dest_p0).flags = (*src_p1).flags;
	{
		if (!(*src_p1).ast) goto LA64_;
		nimIncRef((*src_p1).ast);
	}
LA64_: ;
	{
		NIM_BOOL T68_;
		T68_ = (NIM_BOOL)0;
		T68_ = nimDecRefIsLastDyn((*dest_p0).ast);
		if (!T68_) goto LA69_;
		eqdestroy___ast_u3270((&(*(*dest_p0).ast)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).ast, ((NI)8));
	}
LA69_: ;
	(*dest_p0).ast = (*src_p1).ast;
	(*dest_p0).options = (*src_p1).options;
	(*dest_p0).position = (*src_p1).position;
	(*dest_p0).offset = (*src_p1).offset;
	(*dest_p0).disamb = (*src_p1).disamb;
	(*dest_p0).loc.k = (*src_p1).loc.k;
	(*dest_p0).loc.storage = (*src_p1).loc.storage;
	(*dest_p0).loc.flags = (*src_p1).loc.flags;
	{
		if (!(*src_p1).loc.lode) goto LA73_;
		nimIncRef((*src_p1).loc.lode);
	}
LA73_: ;
	{
		NIM_BOOL T77_;
		T77_ = (NIM_BOOL)0;
		T77_ = nimDecRefIsLastDyn((*dest_p0).loc.lode);
		if (!T77_) goto LA78_;
		eqdestroy___ast_u3270((&(*(*dest_p0).loc.lode)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).loc.lode, ((NI)8));
	}
LA78_: ;
	(*dest_p0).loc.lode = (*src_p1).loc.lode;
	eqcopy___system_u2694((&(*dest_p0).loc.snippet), (*src_p1).loc.snippet);
	{
		if (!(*src_p1).annex) goto LA82_;
		nimIncRef((*src_p1).annex);
	}
LA82_: ;
	{
		NIM_BOOL T86_;
		T86_ = (NIM_BOOL)0;
		T86_ = nimDecRefIsLast((*dest_p0).annex);
		if (!T86_) goto LA87_;
		eqdestroy___ast_u3521((*(*dest_p0).annex));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).annex, ((NI)4));
	}
LA87_: ;
	(*dest_p0).annex = (*src_p1).annex;
	{
		if (!(*src_p1).constraint) goto LA91_;
		nimIncRef((*src_p1).constraint);
	}
LA91_: ;
	{
		NIM_BOOL T95_;
		T95_ = (NIM_BOOL)0;
		T95_ = nimDecRefIsLastDyn((*dest_p0).constraint);
		if (!T95_) goto LA96_;
		eqdestroy___ast_u3270((&(*(*dest_p0).constraint)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).constraint, ((NI)8));
	}
LA96_: ;
	(*dest_p0).constraint = (*src_p1).constraint;
	{
		if (!(*src_p1).instantiatedFrom) goto LA100_;
		nimIncRef((*src_p1).instantiatedFrom);
	}
LA100_: ;
	{
		NIM_BOOL T104_;
		T104_ = (NIM_BOOL)0;
		T104_ = nimDecRefIsLastDyn((*dest_p0).instantiatedFrom);
		if (!T104_) goto LA105_;
		eqdestroy___ast_u3469((&(*(*dest_p0).instantiatedFrom)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).instantiatedFrom, ((NI)8));
	}
LA105_: ;
	(*dest_p0).instantiatedFrom = (*src_p1).instantiatedFrom;
	{
		NIM_BOOL T109_;
		T109_ = (NIM_BOOL)0;
		T109_ = nimDecRefIsLastDyn(colontmp_.instantiatedFrom);
		if (!T109_) goto LA110_;
		eqdestroy___ast_u3469((&(*colontmp_.instantiatedFrom)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.instantiatedFrom, ((NI)8));
	}
LA110_: ;
	{
		NIM_BOOL T114_;
		T114_ = (NIM_BOOL)0;
		T114_ = nimDecRefIsLastDyn(colontmp_.constraint);
		if (!T114_) goto LA115_;
		eqdestroy___ast_u3270((&(*colontmp_.constraint)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.constraint, ((NI)8));
	}
LA115_: ;
	{
		NIM_BOOL T119_;
		T119_ = (NIM_BOOL)0;
		T119_ = nimDecRefIsLast(colontmp_.annex);
		if (!T119_) goto LA120_;
		eqdestroy___ast_u3521((*colontmp_.annex));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.annex, ((NI)4));
	}
LA120_: ;
	eqdestroy___system_u2691(colontmp_.loc.snippet);
	{
		NIM_BOOL T124_;
		T124_ = (NIM_BOOL)0;
		T124_ = nimDecRefIsLastDyn(colontmp_.loc.lode);
		if (!T124_) goto LA125_;
		eqdestroy___ast_u3270((&(*colontmp_.loc.lode)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.loc.lode, ((NI)8));
	}
LA125_: ;
	{
		NIM_BOOL T129_;
		T129_ = (NIM_BOOL)0;
		T129_ = nimDecRefIsLastDyn(colontmp_.ast);
		if (!T129_) goto LA130_;
		eqdestroy___ast_u3270((&(*colontmp_.ast)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.ast, ((NI)8));
	}
LA130_: ;
	{
		NIM_BOOL T134_;
		T134_ = (NIM_BOOL)0;
		T134_ = nimDecRefIsLastDyn(colontmp_.ownerField);
		if (!T134_) goto LA135_;
		eqdestroy___ast_u3469((&(*colontmp_.ownerField)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.ownerField, ((NI)8));
	}
LA135_: ;
	{
		NIM_BOOL T139_;
		T139_ = (NIM_BOOL)0;
		T139_ = nimDecRefIsLastDyn(colontmp_.name);
		if (!T139_) goto LA140_;
		eqdestroy___idents_u173((*colontmp_.name));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.name, ((NI)4));
	}
LA140_: ;
	{
		NIM_BOOL T144_;
		T144_ = (NIM_BOOL)0;
		T144_ = nimDecRefIsLastDyn(colontmp_.typ);
		if (!T144_) goto LA145_;
		eqdestroy___ast_u3288((&(*colontmp_.typ)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose(colontmp_.typ, ((NI)8));
	}
LA145_: ;
	switch (colontmp_.kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) ... ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	{
		{
			NIM_BOOL T150_;
			T150_ = (NIM_BOOL)0;
			T150_ = nimDecRefIsLastDyn(colontmp_._kind_1.transformedBody);
			if (!T150_) goto LA151_;
			eqdestroy___ast_u3270((&(*colontmp_._kind_1.transformedBody)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose(colontmp_._kind_1.transformedBody, ((NI)8));
		}
LA151_: ;
		{
			NIM_BOOL T155_;
			T155_ = (NIM_BOOL)0;
			T155_ = nimDecRefIsLastDyn(colontmp_._kind_1.gcUnsafetyReason);
			if (!T155_) goto LA156_;
			eqdestroy___ast_u3469((&(*colontmp_._kind_1.gcUnsafetyReason)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose(colontmp_._kind_1.gcUnsafetyReason, ((NI)8));
		}
LA156_: ;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
	{
		{
			NIM_BOOL T161_;
			T161_ = (NIM_BOOL)0;
			T161_ = nimDecRefIsLastDyn(colontmp_._kind_2.guard);
			if (!T161_) goto LA162_;
			eqdestroy___ast_u3469((&(*colontmp_._kind_2.guard)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose(colontmp_._kind_2.guard, ((NI)8));
		}
LA162_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u3478)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).itemId.module = (*src_p1).itemId.module;
	(*dest_p0).itemId.item = (*src_p1).itemId.item;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) ... ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	{
		{
			NIM_BOOL T4_;
			T4_ = (NIM_BOOL)0;
			T4_ = nimDecRefIsLastDyn((*dest_p0)._kind_1.transformedBody);
			if (!T4_) goto LA5_;
			eqdestroy___ast_u3270((&(*(*dest_p0)._kind_1.transformedBody)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimZeroMem((void*)(&(*(*dest_p0)._kind_1.transformedBody)), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
			nimRawDispose((*dest_p0)._kind_1.transformedBody, ((NI)8));
		}
LA5_: ;
		{
			NIM_BOOL T9_;
			T9_ = (NIM_BOOL)0;
			T9_ = nimDecRefIsLastDyn((*dest_p0)._kind_1.gcUnsafetyReason);
			if (!T9_) goto LA10_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_1.gcUnsafetyReason)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimZeroMem((void*)(&(*(*dest_p0)._kind_1.gcUnsafetyReason)), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
			nimRawDispose((*dest_p0)._kind_1.gcUnsafetyReason, ((NI)8));
		}
LA10_: ;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
	{
		(*dest_p0)._kind_2.alignment = 0;
		(*dest_p0)._kind_2.bitsize = 0;
		{
			NIM_BOOL T15_;
			T15_ = (NIM_BOOL)0;
			T15_ = nimDecRefIsLastDyn((*dest_p0)._kind_2.guard);
			if (!T15_) goto LA16_;
			eqdestroy___ast_u3469((&(*(*dest_p0)._kind_2.guard)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimZeroMem((void*)(&(*(*dest_p0)._kind_2.guard)), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
			nimRawDispose((*dest_p0)._kind_2.guard, ((NI)8));
		}
LA16_: ;
	}
	break;
	default:
	{
	}
	break;
	}
	(*dest_p0).kind = 0;
	(*dest_p0).kind = (*src_p1).kind;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) ... ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18):
	{
		(*dest_p0)._kind_1.gcUnsafetyReason = (*src_p1)._kind_1.gcUnsafetyReason;
		(*dest_p0)._kind_1.transformedBody = (*src_p1)._kind_1.transformedBody;
	}
	break;
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)19):
	case ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)21):
	{
		(*dest_p0)._kind_2.guard = (*src_p1)._kind_2.guard;
		(*dest_p0)._kind_2.bitsize = (*src_p1)._kind_2.bitsize;
		(*dest_p0)._kind_2.alignment = (*src_p1)._kind_2.alignment;
	}
	break;
	default:
	{
	}
	break;
	}
	(*dest_p0).magic = (*src_p1).magic;
	{
		NIM_BOOL T24_;
		T24_ = (NIM_BOOL)0;
		T24_ = nimDecRefIsLastDyn((*dest_p0).typ);
		if (!T24_) goto LA25_;
		eqdestroy___ast_u3288((&(*(*dest_p0).typ)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).typ, ((NI)8));
	}
LA25_: ;
	(*dest_p0).typ = (*src_p1).typ;
	{
		NIM_BOOL T29_;
		T29_ = (NIM_BOOL)0;
		T29_ = nimDecRefIsLastDyn((*dest_p0).name);
		if (!T29_) goto LA30_;
		eqdestroy___idents_u173((*(*dest_p0).name));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).name, ((NI)4));
	}
LA30_: ;
	(*dest_p0).name = (*src_p1).name;
	(*dest_p0).info.line = (*src_p1).info.line;
	(*dest_p0).info.col = (*src_p1).info.col;
	(*dest_p0).info.fileIndex = (*src_p1).info.fileIndex;
	{
		NIM_BOOL T34_;
		T34_ = (NIM_BOOL)0;
		T34_ = nimDecRefIsLastDyn((*dest_p0).ownerField);
		if (!T34_) goto LA35_;
		eqdestroy___ast_u3469((&(*(*dest_p0).ownerField)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).ownerField, ((NI)8));
	}
LA35_: ;
	(*dest_p0).ownerField = (*src_p1).ownerField;
	(*dest_p0).flags = (*src_p1).flags;
	{
		NIM_BOOL T39_;
		T39_ = (NIM_BOOL)0;
		T39_ = nimDecRefIsLastDyn((*dest_p0).ast);
		if (!T39_) goto LA40_;
		eqdestroy___ast_u3270((&(*(*dest_p0).ast)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).ast, ((NI)8));
	}
LA40_: ;
	(*dest_p0).ast = (*src_p1).ast;
	(*dest_p0).options = (*src_p1).options;
	(*dest_p0).position = (*src_p1).position;
	(*dest_p0).offset = (*src_p1).offset;
	(*dest_p0).disamb = (*src_p1).disamb;
	(*dest_p0).loc.k = (*src_p1).loc.k;
	(*dest_p0).loc.storage = (*src_p1).loc.storage;
	(*dest_p0).loc.flags = (*src_p1).loc.flags;
	{
		NIM_BOOL T44_;
		T44_ = (NIM_BOOL)0;
		T44_ = nimDecRefIsLastDyn((*dest_p0).loc.lode);
		if (!T44_) goto LA45_;
		eqdestroy___ast_u3270((&(*(*dest_p0).loc.lode)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).loc.lode, ((NI)8));
	}
LA45_: ;
	(*dest_p0).loc.lode = (*src_p1).loc.lode;
	if ((*dest_p0).loc.snippet.p != (*src_p1).loc.snippet.p) {	eqdestroy___system_u2691((*dest_p0).loc.snippet);
	}
(*dest_p0).loc.snippet.len = (*src_p1).loc.snippet.len; (*dest_p0).loc.snippet.p = (*src_p1).loc.snippet.p;
	{
		NIM_BOOL T49_;
		T49_ = (NIM_BOOL)0;
		T49_ = nimDecRefIsLast((*dest_p0).annex);
		if (!T49_) goto LA50_;
		eqdestroy___ast_u3521((*(*dest_p0).annex));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).annex, ((NI)4));
	}
LA50_: ;
	(*dest_p0).annex = (*src_p1).annex;
	{
		NIM_BOOL T54_;
		T54_ = (NIM_BOOL)0;
		T54_ = nimDecRefIsLastDyn((*dest_p0).constraint);
		if (!T54_) goto LA55_;
		eqdestroy___ast_u3270((&(*(*dest_p0).constraint)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).constraint, ((NI)8));
	}
LA55_: ;
	(*dest_p0).constraint = (*src_p1).constraint;
	{
		NIM_BOOL T59_;
		T59_ = (NIM_BOOL)0;
		T59_ = nimDecRefIsLastDyn((*dest_p0).instantiatedFrom);
		if (!T59_) goto LA60_;
		eqdestroy___ast_u3469((&(*(*dest_p0).instantiatedFrom)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).instantiatedFrom, ((NI)8));
	}
LA60_: ;
	(*dest_p0).instantiatedFrom = (*src_p1).instantiatedFrom;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6281)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_p0) {
	(*dest_p0).k = 0;
	(*dest_p0).storage = 0;
	nimZeroMem((void*)(&(*dest_p0).flags), sizeof(tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg));
	(*dest_p0).lode = 0;
	(*dest_p0).snippet.len = 0; (*dest_p0).snippet.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6213)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionGenericParamToType__ast_u6843)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg obj_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg T1_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* blitTmp_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* blitTmp_2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_4;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw blitTmp_5;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* blitTmp_6;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_7;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	eqcopy___ast_u3472((&obj_1), (&(*s_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	T1_.kind = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7);
	T1_.itemId = obj_1.itemId;
	T1_.magic = obj_1.magic;
	blitTmp_1 = obj_1.typ;
	eqwasMoved___ast_u3375(&obj_1.typ);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.typ = blitTmp_1;
	blitTmp_2 = obj_1.name;
	eqwasMoved___idents_u152(&obj_1.name);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.name = blitTmp_2;
	T1_.info = obj_1.info;
	blitTmp_3 = obj_1.ownerField;
	eqwasMoved___ast_u4571(&obj_1.ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.ownerField = blitTmp_3;
	T1_.flags = obj_1.flags;
	blitTmp_4 = obj_1.ast;
	eqwasMoved___ast_u3249(&obj_1.ast);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.ast = blitTmp_4;
	T1_.options = obj_1.options;
	T1_.position = obj_1.position;
	T1_.offset = obj_1.offset;
	nimZeroMem((void*)(&blitTmp_5), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	blitTmp_5 = obj_1.loc;
	eqwasMoved___ast_u6281((&obj_1.loc));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.loc = blitTmp_5;
	blitTmp_6 = obj_1.annex;
	eqwasMoved___ast_u6213(&obj_1.annex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.annex = blitTmp_6;
	blitTmp_7 = obj_1.constraint;
	eqwasMoved___ast_u3249(&obj_1.constraint);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.constraint = blitTmp_7;
	eqsink___ast_u3478((&(*s_p0)), (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3469((&obj_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newSymNode__ast_u5171)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u4577(&(*result)._kind_4.sym, sym_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&(*result).typField, (*sym_p0).typ);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).info = info_p1;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, toVar__ast_u7268)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, typ_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T5_;
		if (!!(((*typ_p0).kind == kind_p1))) goto LA3_;
		colontmpD_ = NIM_NIL;
		colontmpD_ = owner__ast_u6246(typ_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__2 = eqdup___ast_u3384(typ_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T5_ = NIM_NIL;
		T5_ = newType__ast_u5900(kind_p1, idgen_p2, colontmpD_, colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T5_); goto BeforeRet_;}
		eqsink___ast_u3387(&result, T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTree__ast_u4170)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p1, NI children_p1Len_0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__9ahcSjIErJohSBBFLwuF56Q T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(kind_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) < children_p1Len_0)) goto LA3_;
		(*result).info = (*children_p1[((NI)0)]).info;
	}
LA3_: ;
	T5_.len = 0; T5_.p = NIM_NIL;
	T5_ = at___ast_u4149(children_p1, children_p1Len_0);
	eqsink___ast_u3705((&(*result)._kind_6.sons), T5_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, astdef__ast_u4596)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	{
		NIM_BOOL T4_;
		T4_ = (NIM_BOOL)0;
		T4_ = !(((*s_p0).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
		if (!(T4_)) goto LA5_;
		T4_ = ((*(*s_p0).ast).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)35) || (*(*s_p0).ast).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)102));
LA5_: ;
		if (!T4_) goto LA6_;
		eqcopy___ast_u3255(&result, (*(*s_p0).ast)._kind_6.sons.p->data[((NI)2)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA6_: ;
	{
		eqcopy___ast_u3255(&result, (*s_p0).ast);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, originatingModule__ast_u7142)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&result, s_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T3_;
			if (!!(((*result).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6)))) goto LA2;
			T3_ = NIM_NIL;
			T3_ = owner__ast_u6254(result);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u4574(T3_); goto BeforeRet_;}
			eqsink___ast_u4583(&result, T3_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, skipGenericOwner__ast_u7111)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	T1_ = NIM_NIL;
	{
		if (!((*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6))) goto LA4_;
		eqcopy___ast_u4577(&result, s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA4_: ;
	{
		NIM_BOOL T7_;
		NIM_BOOL T8_;
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
		T7_ = (NIM_BOOL)0;
		T8_ = (NIM_BOOL)0;
		T8_ = ((*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16));
		if (!(T8_)) goto LA9_;
		T8_ = (((*s_p0).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)2)))&63U)))!=0);
LA9_: ;
		T7_ = T8_;
		if (!(T7_)) goto LA10_;
		colontmpD_ = owner__ast_u6254(s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T7_ = !(((*colontmpD_).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)6)));
LA10_: ;
		if (!T7_) goto LA11_;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = owner__ast_u6254(s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = owner__ast_u6254(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA11_: ;
	{
		result = owner__ast_u6254(s_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3314)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg* dest_p0, tySequence__d8ZV4IMgHt9biik9cS9a0hrmg src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__ast_u3333((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			{
				if (!src_p1.p->data[colontmp_]) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_]);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_]);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3288((&(*(*dest_p0).p->data[colontmp_])));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_], ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_] = src_p1.p->data[colontmp_];
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, extractPragma__ast_u4008)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)12) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)13) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)14) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)15) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)16) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)17) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)18))) goto LA3_;
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = !(((*(*s_p0).ast)._kind_6.sons.p->data[((NI)4)] == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
			if (!(T7_)) goto LA8_;
			T7_ = !(((*(*(*s_p0).ast)._kind_6.sons.p->data[((NI)4)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)));
LA8_: ;
			if (!T7_) goto LA9_;
			eqcopy___ast_u3255(&result, (*(*s_p0).ast)._kind_6.sons.p->data[((NI)4)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA5_;
LA9_: ;
		{
			result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		}
LA5_: ;
	}
	goto LA1_;
LA3_: ;
	{
		if (!((*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)7) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)8) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9) || (*s_p0).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)10))) goto LA13_;
		{
			NIM_BOOL T17_;
			NI T19_;
			T17_ = (NIM_BOOL)0;
			T17_ = !(((*s_p0).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
			if (!(T17_)) goto LA18_;
			T19_ = (NI)0;
			T19_ = len__ast_u3190((*s_p0).ast);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T17_ = (((NI)0) < T19_);
LA18_: ;
			if (!T17_) goto LA20_;
			{
				NIM_BOOL T24_;
				NI T26_;
				T24_ = (NIM_BOOL)0;
				T24_ = ((*(*(*s_p0).ast)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)43));
				if (!(T24_)) goto LA25_;
				T26_ = (NI)0;
				T26_ = len__ast_u3190((*(*s_p0).ast)._kind_6.sons.p->data[((NI)0)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				T24_ = (((NI)1) < T26_);
LA25_: ;
				if (!T24_) goto LA27_;
				eqcopy___ast_u3255(&result, (*(*(*s_p0).ast)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA22_;
LA27_: ;
			{
				result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
			}
LA22_: ;
		}
		goto LA15_;
LA20_: ;
		{
			result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		}
LA15_: ;
	}
	goto LA1_;
LA13_: ;
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___lookups_u83)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww** dest_p0, tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___semdata_u2873((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntTypeNode__ast_u5387)(NI64 intVal_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = skipTypes__ast_u5379(typ_p1, TM__EnH1I9cGkGYbf9a1NwhuXDPg_499);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	kind_1 = (*colontmpD_).kind;
	switch (kind_1) {
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)31):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)32):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)7));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)33):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)8));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)34):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)9));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)35):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)10));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)2):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)40):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)11));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)41):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)12));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)42):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)13));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)43):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)14));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)44):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)1):
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)14):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60):
	{
		result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default:
	{
		NimStringV2 colontmpD__2;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = dollar___ast_u182(kind_1);
		raiseAssert__stdZassertions_u15(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD__2);
	}
	break;
	}
	(*result)._kind_1.intVal = intVal_p0;
	eqcopy___ast_u3381(&(*result).typField, typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIdentNode__ast_u5164)(tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___idents_u158(&(*result)._kind_5.ident, ident_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).info = info_p1;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHumanStrImpl__ast_u7607)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0) {
	NimStringV2 result;
	tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig T1_;
	NimStringV2 T2_;
	NIM_CHAR T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = dollar___ast_u182(kind_p0);
	T1_ = dotdot___stdZenumutils_u106(((NI)2), ((NI)1));
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = X5BX5D___pureZstrutils_u1314(result, T1_);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T2_); goto BeforeRet_;}
	eqsink___system_u2700((&result), T2_);
	nimPrepareStrMutationV2((&result));
	T3_ = (NIM_CHAR)0;
	T3_ = nsuToLowerAsciiChar(result.p->data[((NI)0)]);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result.p->data[((NI)0)] = T3_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHumanStr__ast_u7604)(tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = toHumanStrImpl__ast_u7607(kind_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u3561)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u1177((*dest_p0));
		nimRawDispose(dest_p0, ((NI)4));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___modulegraphs_u3558)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isUnresolvedStatic__ast_u4629)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
{	T1_ = (NIM_BOOL)0;
	T1_ = ((*t_p0).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)60));
	if (!(T1_)) goto LA2_;
	T1_ = ((*t_p0).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL));
LA2_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, shallowCopy__ast_u6876)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		if (!(src_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
	}
LA4_: ;
	result = newNode__ast_u4069((*src_p0).kind);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).info = (*src_p0).info;
	eqcopy___ast_u3381(&(*result).typField, (*src_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).flags = ((*src_p0).flags & 58386190);
	colontmpD_ = comment__ast_u836(src_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	commenteq___ast_u1334(result, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*src_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*result)._kind_1.intVal = (*src_p0)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*result)._kind_2.floatVal = (*src_p0)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___ast_u4577(&(*result)._kind_4.sym, (*src_p0)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		eqcopy___idents_u158(&(*result)._kind_5.ident, (*src_p0)._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqcopy___system_u2694((&(*result)._kind_3.strVal), (*src_p0)._kind_3.strVal);
	}
	break;
	default:
	{
		NI T12_;
		T12_ = (NI)0;
		T12_ = len__ast_u3190(src_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		newSeq__ast_u4100((&(*result)._kind_6.sons), (T12_));
	}
	break;
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, resetIdTable__sem_u1372)(tyObject_TIdTable__xRBvhNSbEADzUTJAdtlGtA* x_p0) {
	(*x_p0).counter = ((NI)0);
	setLen__semdata_u770((&(*x_p0).data), ((NI)0));
	setLen__semdata_u770((&(*x_p0).data), ((NI)8));
}
N_LIB_PRIVATE N_NIMCALL(void, resetIdTable__sem_u1387)(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA* x_p0) {
	(*x_p0).counter = ((NI)0);
	setLen__layeredtable_u28((&(*x_p0).data), ((NI)0));
	setLen__layeredtable_u28((&(*x_p0).data), ((NI)8));
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___modulegraphs_u3570)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ** dest_p0, tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___modulegraphs_u1177((*(*dest_p0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___modulegraphs_u3564)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ** dest_p0, tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLast((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___modulegraphs_u1177((*(*dest_p0)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)4));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ*, eqdup___modulegraphs_u3567)(tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* src_p0) {
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5426)(NimStringV2 strVal_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20), info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___system_u2694((&(*result)._kind_3.strVal), strVal_p0);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___ast_u606)(tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_501;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)1):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_503;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)2):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_505;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)3):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_507;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)4):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_509;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)5):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_511;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)6):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_513;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)7):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_515;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)8):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_517;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)9):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_519;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)10):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_521;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)11):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_523;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)12):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_525;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)13):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_527;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)14):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_529;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)15):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_531;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)16):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_533;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)17):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_535;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)18):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_537;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)19):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_539;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)20):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_541;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)21):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_543;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)22):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_545;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)23):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_547;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)24):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_549;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)25):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_551;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)26):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_553;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)27):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_555;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)28):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_557;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)29):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_559;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)30):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_561;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)31):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_563;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)32):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_565;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)33):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_567;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)34):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_569;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)35):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_571;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)36):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_573;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)37):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_575;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)38):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_577;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)39):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_579;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)40):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_581;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)41):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_583;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)42):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_585;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)43):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_587;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)44):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_589;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)45):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_591;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)46):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_593;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)47):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_595;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)48):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_597;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)49):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_599;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)50):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_601;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)51):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_603;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)52):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_605;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)53):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_607;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)54):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_609;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)55):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_611;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)56):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_613;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)57):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_615;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)58):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_617;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)59):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_619;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)60):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_621;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)61):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_623;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)62):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_625;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)63):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_627;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)64):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_629;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)65):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_631;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)66):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_633;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)67):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_635;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)68):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_637;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)69):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_639;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)70):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_641;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)71):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_643;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)72):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_645;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)73):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_647;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)74):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_649;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)75):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_651;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)76):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_653;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)77):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_655;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)78):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_657;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)79):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_659;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)80):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_661;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)81):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_663;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)82):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_665;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)83):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_667;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)84):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_669;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)85):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_671;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)86):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_673;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)87):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_675;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)88):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_677;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)89):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_679;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)90):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_681;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)91):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_683;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)92):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_685;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)93):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_687;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)94):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_689;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)95):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_691;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)96):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_693;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)97):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_695;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)98):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_697;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)99):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_699;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)100):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_701;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)101):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_703;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)102):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_705;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)103):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_707;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)104):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_709;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)105):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_711;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)106):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_713;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)107):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_715;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)108):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_717;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)109):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_719;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)110):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_721;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)111):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_723;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)112):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_725;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)113):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_727;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)114):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_729;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)115):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_731;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)116):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_733;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)117):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_735;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)118):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_737;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)119):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_739;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)120):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_741;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)121):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_743;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)122):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_745;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)123):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_747;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)124):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_749;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)125):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_751;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)126):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_753;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)127):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_755;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)128):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_757;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)129):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_759;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)130):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_761;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)131):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_763;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)132):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_765;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)133):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_767;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)134):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_769;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)135):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_771;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)136):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_773;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)137):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_775;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)138):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_777;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)139):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_779;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)140):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_781;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)141):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_783;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)142):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_785;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)143):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_787;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)144):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_789;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)145):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_791;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)146):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_793;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)147):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_795;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)148):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_797;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)149):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_799;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)150):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_801;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)151):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_803;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)152):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_805;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)153):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_807;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)154):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_809;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)155):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_811;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)156):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_813;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)157):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_815;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)158):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_817;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)159):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_819;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)160):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_821;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)161):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_823;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)162):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_825;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)163):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_827;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)164):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_829;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)165):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_831;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)166):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_833;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)167):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_835;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)168):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_837;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)169):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_839;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)170):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_841;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)171):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_843;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)172):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_845;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)173):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_847;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)174):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_849;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)175):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_851;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)176):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_853;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)177):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_855;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)178):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_857;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)179):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_859;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)180):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_861;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)181):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_863;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)182):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_865;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)183):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_867;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)184):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_869;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)185):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_871;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)186):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_873;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)187):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_875;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)188):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_877;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)189):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_879;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)190):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_881;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)191):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_883;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)192):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_885;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)193):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_887;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)194):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_889;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)195):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_891;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)196):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_893;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)197):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_895;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)198):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_897;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)199):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_899;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)200):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_901;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)201):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_903;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)202):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_905;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)203):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_907;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)204):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_909;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)205):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_911;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)206):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_913;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)207):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_915;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)208):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_917;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)209):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_919;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)210):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_921;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)211):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_923;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)212):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_925;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)213):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_927;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)214):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_929;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)215):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_931;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)216):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_933;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)217):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_935;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)218):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_937;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)219):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_939;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)220):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_941;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)221):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_943;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)222):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_945;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)223):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_947;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)224):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_949;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)225):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_951;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)226):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_953;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)227):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_955;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)228):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_957;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)229):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_959;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)230):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_961;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)231):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_963;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)232):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_965;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)233):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_967;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)234):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_969;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)235):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_971;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)236):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_973;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)237):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_975;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)238):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_977;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)239):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_979;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)240):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_981;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)241):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_983;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)242):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_985;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)243):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_987;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)244):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_989;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)245):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_991;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)246):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_993;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)247):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_995;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)248):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_997;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)249):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_999;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)250):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1001;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)251):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1003;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)252):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1005;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)253):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1007;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)254):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1009;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)255):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1011;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)256):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1013;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)257):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1015;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)258):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1017;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)259):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1019;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)260):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1021;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)261):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1023;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)262):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1025;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)263):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1027;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)264):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1029;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)265):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1031;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)266):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1033;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)267):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1035;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)268):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1037;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)269):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1039;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)270):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1041;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)271):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1043;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)272):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1045;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)273):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1047;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)274):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1049;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)275):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1051;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)276):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1053;
	}
	break;
	case ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)277):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1055;
	}
	break;
	default:
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1056;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig*, eqdup___ast_u6222)(tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* src_p0) {
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, appendToModule__ast_u4652)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T5_;
		tySequence__9ahcSjIErJohSBBFLwuF56Q T6_;
		if (!((*m_p0).ast == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115));
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T5_); goto BeforeRet_;}
		eqsink___ast_u3261(&(*m_p0).ast, T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T6_.len = 0; T6_.p = NIM_NIL;
		T6_.len = 1; T6_.p = (tySequence__9ahcSjIErJohSBBFLwuF56Q_Content*) newSeqPayload(1, sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
		colontmpD_ = eqdup___ast_u3258(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T6_.p->data[0] = colontmpD_;
		eqsink___ast_u3705((&(*(*m_p0).ast)._kind_6.sons), T6_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD__2;
		colontmpD__2 = eqdup___ast_u3258(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__ast_u3225((&(*(*m_p0).ast)._kind_6.sons), colontmpD__2);
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTreeI__ast_u4180)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p2, NI children_p2Len_0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__9ahcSjIErJohSBBFLwuF56Q T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeI__ast_u4091(kind_p0, info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) < children_p2Len_0)) goto LA3_;
		(*result).info = (*children_p2[((NI)0)]).info;
	}
LA3_: ;
	T5_.len = 0; T5_.p = NIM_NIL;
	T5_ = at___ast_u4149(children_p2, children_p2Len_0);
	eqsink___ast_u3705((&(*result)._kind_6.sons), T5_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNodeI__ast_u4095)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NI children_p2) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) nimNewObj(sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	(*T1_).kind = kind_p0;
	colontmpD_ = eqdup___lineinfos_u2037(info_p1);
	(*T1_).info = colontmpD_;
	result = T1_;
	{
		if (!(((NI)0) < children_p2)) goto LA4_;
		newSeq__ast_u4100((&(*result)._kind_6.sons), (children_p2));
	}
LA4_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newStrNode__ast_u5422)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NimStringV2 strVal_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(kind_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___system_u2694((&(*result)._kind_3.strVal), strVal_p1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lookups_u71)(tyObject_TScope__x7gU4GnNOGxq5tpoU40Lww** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6548)(tySequence__GH1mmNKNA2QP4n1tnxJf1w dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].key);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].key)));
				nimRawDispose(dest_p0.p->data[colontmp_].key, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ));
}
}
N_LIB_PRIVATE N_NIMCALL(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug*, eqdup___ast_u3106)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* src_p0) {
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6478)(tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.key);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.key)));
		nimRawDispose(dest_p0.key, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6475)(tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ* dest_p0) {
	(*dest_p0).h = 0;
	(*dest_p0).key = 0;
	(*dest_p0).val = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g, initNodeTable__ast_u6397)(NIM_BOOL ignoreTypes_p0) {
	tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g));
	result.counter = ((NI)0);
	result.ignoreTypes = ignoreTypes_p0;
	newSeq__ast_u6400((&result.data), ((NI)8));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipColon__ast_u7347)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3255(&result, n_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)34))) goto LA3_;
		eqcopy___ast_u3255(&result, (*n_p0)._kind_6.sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newFloatNode__ast_u5418)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, NF floatVal_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(kind_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result)._kind_2.floatVal = floatVal_p1;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isCallExpr__ast_u3180)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	result = ((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)27) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)30) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)31) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)26) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)28) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)32));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addParam__ast_u7497)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* procType_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* param_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = NIM_NIL;
	T1_ = (*procType_p0).sons.len;
	(*param_p1).position = (NI)(T1_ - ((NI)1));
	colontmpD_ = newSymNode__ast_u5168(param_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3215((*procType_p0).n, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	rawAddSon__ast_u6706(procType_p0, (*param_p1).typ, NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, newProcType__ast_u7492)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	result = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25), idgen_p1, owner_p2, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	T1_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76), info_p0);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T1_); goto BeforeRet_;}
	eqsink___ast_u3261(&(*result).n, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	rawAddSon__ast_u6706(result, ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL), NIM_TRUE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	colontmpD_ = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)152), info_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	add__ast_u3215((*result).n, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3252(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newTreeIT__ast_u4191)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p2, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** children_p3, NI children_p3Len_0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tySequence__9ahcSjIErJohSBBFLwuF56Q T5_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNodeIT__ast_u4112(kind_p0, info_p1, typ_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(((NI)0) < children_p3Len_0)) goto LA3_;
		(*result).info = (*children_p3[((NI)0)]).info;
	}
LA3_: ;
	T5_.len = 0; T5_.p = NIM_NIL;
	T5_ = at___ast_u4149(children_p3, children_p3Len_0);
	eqsink___ast_u3705((&(*result)._kind_6.sons), T5_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___transf_u250)(tySequence__tt8kXsbz31MUMFUF6Q9aQuQ dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].val);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].val)));
				nimRawDispose(dest_p0.p->data[colontmp_].val, ((NI)8));
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___transf_u180)(tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.val);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.val)));
		nimRawDispose(dest_p0.val, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___transf_u177)(tyObject_TIdPair__dYeu3zo1ycz2MpUdjM5Vvg* dest_p0) {
	(*dest_p0).key.module = 0;
	(*dest_p0).key.item = 0;
	(*dest_p0).val = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TIdTable__8wpQEq0X9akVm73iKe4zg6Q, initIdTable__transf_u98)(void) {
	tyObject_TIdTable__8wpQEq0X9akVm73iKe4zg6Q result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TIdTable__8wpQEq0X9akVm73iKe4zg6Q));
	nimZeroMem((void*)(&result), sizeof(tyObject_TIdTable__8wpQEq0X9akVm73iKe4zg6Q));
	result.counter = ((NI)0);
	newSeq__transf_u102((&result.data), ((NI)8));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionToLet__ast_u6869)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg obj_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg T1_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* blitTmp_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* blitTmp_2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_4;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw blitTmp_5;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* blitTmp_6;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_7;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	eqcopy___ast_u3472((&obj_1), (&(*s_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	T1_.kind = ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)9);
	T1_.itemId = obj_1.itemId;
	T1_.magic = obj_1.magic;
	blitTmp_1 = obj_1.typ;
	eqwasMoved___ast_u3375(&obj_1.typ);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.typ = blitTmp_1;
	blitTmp_2 = obj_1.name;
	eqwasMoved___idents_u152(&obj_1.name);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.name = blitTmp_2;
	T1_.info = obj_1.info;
	blitTmp_3 = obj_1.ownerField;
	eqwasMoved___ast_u4571(&obj_1.ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.ownerField = blitTmp_3;
	T1_.flags = obj_1.flags;
	blitTmp_4 = obj_1.ast;
	eqwasMoved___ast_u3249(&obj_1.ast);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.ast = blitTmp_4;
	T1_.options = obj_1.options;
	T1_.position = obj_1.position;
	T1_.offset = obj_1.offset;
	nimZeroMem((void*)(&blitTmp_5), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	blitTmp_5 = obj_1.loc;
	eqwasMoved___ast_u6281((&obj_1.loc));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.loc = blitTmp_5;
	blitTmp_6 = obj_1.annex;
	eqwasMoved___ast_u6213(&obj_1.annex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.annex = blitTmp_6;
	blitTmp_7 = obj_1.constraint;
	eqwasMoved___ast_u3249(&obj_1.constraint);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.constraint = blitTmp_7;
	T1_._kind_2.guard = 0;
	T1_._kind_2.bitsize = 0;
	T1_._kind_2.alignment = 0;
	eqsink___ast_u3478((&(*s_p0)), (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___ast_u4583(&(*s_p0)._kind_2.guard, obj_1._kind_2.guard);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u4571(&obj_1._kind_2.guard);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*s_p0)._kind_2.bitsize = obj_1._kind_2.bitsize;
	(*s_p0)._kind_2.alignment = obj_1._kind_2.alignment;
	eqdestroy___ast_u3469((&obj_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntTypeNode__ast_u5414)(tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg intVal_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NI64 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (NI64)0;
	T1_ = castToInt64__int128_u308(intVal_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newIntTypeNode__ast_u5387(T1_, typ_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NF, getFloat__ast_u7061)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0) {
	NF result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NF)0;
	switch ((*a_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		result = (*a_p0)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)11) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)10):
	{
		result = ((NF) ((*a_p0)._kind_1.intVal));
	}
	break;
	default:
	{
		raiseRecoverableError__lineinfos_u299(TM__EnH1I9cGkGYbf9a1NwhuXDPg_1064);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getStr__ast_u7064)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	switch ((*a_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqcopy___system_u2694((&result), (*a_p0)._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
		result = TM__EnH1I9cGkGYbf9a1NwhuXDPg_1065;
	}
	break;
	default:
	{
		raiseRecoverableError__lineinfos_u299(TM__EnH1I9cGkGYbf9a1NwhuXDPg_1067);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getStrOrChar__ast_u7067)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* a_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	switch ((*a_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqcopy___system_u2694((&result), (*a_p0)._kind_3.strVal);
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		result = nimCharToStr(((NIM_CHAR) ((((NI) ((*a_p0)._kind_1.intVal))))));
	}
	break;
	default:
	{
		raiseRecoverableError__lineinfos_u299(TM__EnH1I9cGkGYbf9a1NwhuXDPg_1068);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipPragmaExpr__ast_u4047)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)43))) goto LA3_;
		eqcopy___ast_u3255(&result, (*n_p0)._kind_6.sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		eqcopy___ast_u3255(&result, n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isInfixAs__ast_u7333)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
{	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = ((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)29));
	if (!(T2_)) goto LA3_;
	T2_ = ((*(*n_p0)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2));
LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = ((*(*(*n_p0)._kind_6.sons.p->data[((NI)0)])._kind_5.ident).id == ((NI)3));
LA4_: ;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isImportedException__ast_u7302)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p1) {
	NIM_BOOL result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* base_1;
	NIM_BOOL T6_;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg T8_;
NIM_BOOL oldNimErrFin1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	base_1 = NIM_NIL;
	{
		if (!!(((*conf_p1).exc == ((tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw)2)))) goto LA4_;
		result = NIM_FALSE;
		eqdestroy___ast_u3378(base_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		goto BeforeRet_;
	}
LA4_: ;
	base_1 = skipTypes__ast_u5379(t_p0, TM__EnH1I9cGkGYbf9a1NwhuXDPg_1069);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = (NIM_BOOL)0;
	T6_ = !(((*base_1).sym == ((tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*) NIM_NIL)));
	if (!(T6_)) goto LA7_;
	T8_ = 0;
	T6_ = !(((IL64(4294967360) & (*(*base_1).sym).flags) == T8_));
LA7_: ;
	result = T6_;
	{
		LA1_:;
	}
	{
		oldNimErrFin1_ = *nimErr_; *nimErr_ = NIM_FALSE;
		eqdestroy___ast_u3378(base_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		*nimErr_ = oldNimErrFin1_;
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, toRef__ast_u7280)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	eqcopy___ast_u3381(&result, typ_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD__2;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD__3;
		tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T5_;
		colontmpD_ = skipTypes__ast_u5379(typ_p0, TM__EnH1I9cGkGYbf9a1NwhuXDPg_1070);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!((*colontmpD_).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)17))) goto LA3_;
		colontmpD__2 = NIM_NIL;
		colontmpD__2 = owner__ast_u6246(typ_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__3 = eqdup___ast_u3384(typ_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T5_ = NIM_NIL;
		T5_ = newType__ast_u5900(((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22), idgen_p1, colontmpD__2, colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T5_); goto BeforeRet_;}
		eqsink___ast_u3387(&result, T5_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___ast_u4574(colontmpD__2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	eqdestroy___ast_u3378(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionIntKind__ast_u6792)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__Vj1MpVCa7BBwvA5h87QXag kind_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ obj_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	eqcopy___ast_u3273((&obj_1), (&(*n_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	T1_.kind = kind_p1;
	colontmpD_ = eqdup___ast_u3384((*n_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.typField = colontmpD_;
	T1_.info = obj_1.info;
	T1_.flags = obj_1.flags;
	eqsink___ast_u3279((&(*n_p0)), (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*n_p0)._kind_1.intVal = obj_1._kind_1.intVal;
	eqdestroy___ast_u3270((&obj_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**, X5BX5D___ast_u5211)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** s_p0, NI s_p0Len_0, NI i_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** result;
	result = &s_p0[(NI)(s_p0Len_0 - i_p1)];
	return result;
}
static N_INLINE(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, lastSon__ast_u5208)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
	T1_ = X5BX5D___ast_u5211((((*n_p0)._kind_6.sons).p) ? ((*n_p0)._kind_6.sons.p->data) : NIM_NIL, (*n_p0)._kind_6.sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, skipStmtList__ast_u7252)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115) || (*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126))) goto LA3_;
		{
			NI i_1;
			NI colontmp_;
			NI T6_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T6_ = (NI)0;
			T6_ = len__ast_u3190(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmp_ = (NI)(T6_ - ((NI)1));
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA8;
					i_1 = i_2;
					{
						if (!!(((*(*n_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) || (*(*n_p0)._kind_6.sons.p->data[i_1]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)125)))) goto LA11_;
						eqcopy___ast_u3255(&result, n_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						goto BeforeRet_;
					}
LA11_: ;
					i_2 += ((NI)1);
				} LA8: ;
			}
		}
		result = lastSon__ast_u5208(n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		eqcopy___ast_u3255(&result, n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypesOrNil__ast_u6606)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			NIM_BOOL T3_;
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T10_;
			T3_ = (NIM_BOOL)0;
			T3_ = !((result == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
			if (!(T3_)) goto LA4_;
			T3_ = ((kinds_p1[(NU)(((*result).kind))>>3] &(1U<<((NU)(((*result).kind))&7U)))!=0);
LA4_: ;
			if (!T3_) goto LA2;
			{
				NI T7_;
				T7_ = (*result).sons.len;
				if (!(T7_ == ((NI)0))) goto LA8_;
				result = ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL);
				goto BeforeRet_;
			}
LA8_: ;
			T10_ = NIM_NIL;
			T10_ = last__ast_u5278(result);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T10_); goto BeforeRet_;}
			eqsink___ast_u3387(&result, T10_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6557)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* dest_p0, tySequence__GH1mmNKNA2QP4n1tnxJf1w src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	if ((*dest_p0).p != src_p1.p) {	eqdestroy___ast_u6548((*dest_p0));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).len = src_p1.len; (*dest_p0).p = src_p1.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u6545)(tySequence__GH1mmNKNA2QP4n1tnxJf1w* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isTrue__ast_u7675)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	NIM_BOOL T3_;
	NIM_BOOL T7_;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T3_ = (NIM_BOOL)0;
	T3_ = ((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
	if (!(T3_)) goto LA4_;
	T3_ = ((*(*n_p0)._kind_4.sym).kind == ((tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q)20));
LA4_: ;
	T2_ = T3_;
	if (!(T2_)) goto LA5_;
	T2_ = !(((*(*n_p0)._kind_4.sym).position == ((NI)0)));
LA5_: ;
	T1_ = T2_;
	if (T1_) goto LA6_;
	T7_ = (NIM_BOOL)0;
	T7_ = ((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)6));
	if (!(T7_)) goto LA8_;
	T7_ = !(((*n_p0)._kind_1.intVal == IL64(0)));
LA8_: ;
	T1_ = T7_;
LA6_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, discardSons__ast_u3188)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0) {
	tySequence__9ahcSjIErJohSBBFLwuF56Q T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_.len = 0; T1_.p = (tySequence__9ahcSjIErJohSBBFLwuF56Q_Content*) newSeqPayload(0, sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
	eqsink___ast_u3705((&(*father_p0)._kind_6.sons), T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setInfoRecursive__ast_u4054)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!((n_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA3_;
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = safeLen__ast_u3197(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA7;
					i_1 = i_2;
					setInfoRecursive__ast_u4054((*n_p0)._kind_6.sons.p->data[i_1], info_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					i_2 += ((NI)1);
				} LA7: ;
			}
		}
		(*n_p0).info = info_p1;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, delSon__ast_u6724)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* father_p0, NI idx_p1) {
	NI T10_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI T3_;
		T3_ = (NI)0;
		T3_ = len__ast_u3190(father_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T3_ == ((NI)0))) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	{
		NI i_1;
		NI colontmp_;
		NI T7_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T7_ = (NI)0;
		T7_ = len__ast_u3190(father_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmp_ = (NI)(T7_ - ((NI)1));
		i_2 = idx_p1;
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA9;
				i_1 = i_2;
				eqcopy___ast_u3255(&(*father_p0)._kind_6.sons.p->data[i_1], (*father_p0)._kind_6.sons.p->data[(NI)(i_1 + ((NI)1))]);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA9: ;
		}
	}
	T10_ = (NI)0;
	T10_ = len__ast_u3190(father_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	setLen__ast_u3718((&(*father_p0)._kind_6.sons), ((NI)(T10_ - ((NI)1))));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newIntNode__ast_u5204)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0, tyObject_Int128__Moyhy3H7f18q9axhPc7Yt9bg intVal_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NI64 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	result = newNode__ast_u4069(kind_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = (NI64)0;
	T1_ = castToInt64__int128_u308(intVal_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result)._kind_1.intVal = T1_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u3267)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0) {
	(*dest_p0).typField = 0;
	(*dest_p0).info.line = 0;
	(*dest_p0).info.col = 0;
	(*dest_p0).info.fileIndex = 0;
	nimZeroMem((void*)(&(*dest_p0).flags), sizeof(tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw));
	(*dest_p0).kind = 0;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*dest_p0)._kind_1.intVal = 0;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*dest_p0)._kind_2.floatVal = 0;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		(*dest_p0)._kind_3.strVal.len = 0; (*dest_p0)._kind_3.strVal.p = NIM_NIL;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		(*dest_p0)._kind_4.sym = 0;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		(*dest_p0)._kind_5.ident = 0;
	}
	break;
	default:
	{
		(*dest_p0)._kind_6.sons.len = 0; (*dest_p0)._kind_6.sons.p = NIM_NIL;
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___layeredtable_u158)(tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA* dest_p0, tyObject_TIdTable__XZ9cFaLoittQMULJSfBpHrA src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).counter = src_p1.counter;
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___layeredtable_u168((*dest_p0).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, skipTypes__ast_u6591)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p0, tySet_tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kinds_p1, NI maxIters_p2) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	NI i_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u3381(&result, t_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	i_1 = maxIters_p2;
	{
		while (1) {
			tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T3_;
			if (!((kinds_p1[(NU)(((*result).kind))>>3] &(1U<<((NU)(((*result).kind))&7U)))!=0)) goto LA2;
			T3_ = NIM_NIL;
			T3_ = last__ast_u5278(result);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3378(T3_); goto BeforeRet_;}
			eqsink___ast_u3387(&result, T3_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_1 -= ((NI)1);
			{
				if (!(i_1 == ((NI)0))) goto LA6_;
				result = ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL);
				goto BeforeRet_;
			}
LA6_: ;
		} LA2: ;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, copyTreeWithoutNode__ast_u6911)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* src_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* skippedNode_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
	NimStringV2 colontmpD_;
NIM_BOOL oldNimErrFin15_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	{
		if (!(src_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA4_;
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
	}
LA4_: ;
	result = newNode__ast_u4069((*src_p0).kind);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).info = (*src_p0).info;
	eqcopy___ast_u3381(&(*result).typField, (*src_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*result).flags = ((*src_p0).flags & 58386190);
	colontmpD_ = comment__ast_u836(src_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	commenteq___ast_u1334(result, colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	switch ((*src_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)5) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)15):
	{
		(*result)._kind_1.intVal = (*src_p0)._kind_1.intVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)16) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)19):
	{
		(*result)._kind_2.floatVal = (*src_p0)._kind_2.floatVal;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3):
	{
		eqcopy___ast_u4577(&(*result)._kind_4.sym, (*src_p0)._kind_4.sym);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)2):
	{
		eqcopy___idents_u158(&(*result)._kind_5.ident, (*src_p0)._kind_5.ident);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)20) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)22):
	{
		eqcopy___system_u2694((&(*result)._kind_3.strVal), (*src_p0)._kind_3.strVal);
	}
	break;
	default:
	{
		NI T12_;
		tySequence__9ahcSjIErJohSBBFLwuF56Q T13_;
		T12_ = (NI)0;
		T12_ = len__ast_u3190(src_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T13_.len = 0; T13_.p = NIM_NIL;
		T13_.len = 0; T13_.p = (tySequence__9ahcSjIErJohSBBFLwuF56Q_Content*) newSeqPayloadUninit((T12_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*), NIM_ALIGNOF(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*));
		eqsink___ast_u3705((&(*result)._kind_6.sons), T13_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		{
			tySequence__9ahcSjIErJohSBBFLwuF56Q colontmp_;
			tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** n_1;
			NI i_1;
			NI L_1;
			NI T16_;
			colontmp_.len = 0; colontmp_.p = NIM_NIL;
			n_1 = (tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ**)0;
			eqcopy___ast_u3699((&colontmp_), (*src_p0)._kind_6.sons);
			if (NIM_UNLIKELY(*nimErr_)) goto LA15_;
			i_1 = ((NI)0);
			T16_ = colontmp_.len;
			L_1 = T16_;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA18;
					n_1 = &colontmp_.p->data[i_1];
					{
						tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* T23_;
						if (!!(((*n_1) == skippedNode_p1))) goto LA21_;
						T23_ = NIM_NIL;
						T23_ = copyTreeWithoutNode__ast_u6911((*n_1), skippedNode_p1);
						if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___ast_u3252(T23_); goto LA15_;}
						add__ast_u3225((&(*result)._kind_6.sons), T23_);
					}
LA21_: ;
					i_1 += ((NI)1);
				} LA18: ;
			}
			{
				LA15_:;
			}
			{
				oldNimErrFin15_ = *nimErr_; *nimErr_ = NIM_FALSE;
				eqdestroy___ast_u3696(colontmp_);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				*nimErr_ = oldNimErrFin15_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
	}
	break;
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, linkTo__ast_u4644)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	eqcopy___ast_u4577(&(*t_p1).sym, s_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&(*s_p0).typ, t_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u4577(&result, s_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u4845)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA* dest_p0) {
	(*dest_p0).len = 0; (*dest_p0).p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(tySequence__ZCZaCk14bTmSb6LMW9aWPVA, eqdup___ast_u4854)(tySequence__ZCZaCk14bTmSb6LMW9aWPVA src_p0) {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA result;
	NI T1_;
	NI colontmp_;
	result.len = 0; result.p = NIM_NIL;
	T1_ = src_p0.len;
	setLen__ast_u4725((&result), T1_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T4_;
			T4_ = result.len;
			if (!(colontmp_ < T4_)) goto LA3;
			result.p->data[colontmp_] = src_p0.p->data[colontmp_];
			{
				if (!src_p0.p->data[colontmp_]) goto LA7_;
				nimIncRef(src_p0.p->data[colontmp_]);
			}
LA7_: ;
			colontmp_ += ((NI)1);
		} LA3: ;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3151)(tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA dest_p0) {
}
N_LIB_PRIVATE N_NIMCALL(void, transitionRoutineSymKind__ast_u6846)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyEnum_TSymKind__fzoDhZbHLwFaqo7QLPWQkQ kind_p1) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg obj_1;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg T1_;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* blitTmp_1;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* blitTmp_2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* blitTmp_3;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_4;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw blitTmp_5;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* blitTmp_6;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* blitTmp_7;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	eqcopy___ast_u3472((&obj_1), (&(*s_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg));
	T1_.kind = kind_p1;
	T1_.itemId = obj_1.itemId;
	T1_.magic = obj_1.magic;
	blitTmp_1 = obj_1.typ;
	eqwasMoved___ast_u3375(&obj_1.typ);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.typ = blitTmp_1;
	blitTmp_2 = obj_1.name;
	eqwasMoved___idents_u152(&obj_1.name);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.name = blitTmp_2;
	T1_.info = obj_1.info;
	blitTmp_3 = obj_1.ownerField;
	eqwasMoved___ast_u4571(&obj_1.ownerField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.ownerField = blitTmp_3;
	T1_.flags = obj_1.flags;
	blitTmp_4 = obj_1.ast;
	eqwasMoved___ast_u3249(&obj_1.ast);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.ast = blitTmp_4;
	T1_.options = obj_1.options;
	T1_.position = obj_1.position;
	T1_.offset = obj_1.offset;
	nimZeroMem((void*)(&blitTmp_5), sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	blitTmp_5 = obj_1.loc;
	eqwasMoved___ast_u6281((&obj_1.loc));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.loc = blitTmp_5;
	blitTmp_6 = obj_1.annex;
	eqwasMoved___ast_u6213(&obj_1.annex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.annex = blitTmp_6;
	blitTmp_7 = obj_1.constraint;
	eqwasMoved___ast_u3249(&obj_1.constraint);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.constraint = blitTmp_7;
	eqsink___ast_u3478((&(*s_p0)), (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___ast_u4583(&(*s_p0)._kind_1.gcUnsafetyReason, obj_1._kind_1.gcUnsafetyReason);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u4571(&obj_1._kind_1.gcUnsafetyReason);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqsink___ast_u3261(&(*s_p0)._kind_1.transformedBody, obj_1._kind_1.transformedBody);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqwasMoved___ast_u3249(&obj_1._kind_1.transformedBody);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u3469((&obj_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, containsNode__ast_u7008)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tySet_tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kinds_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_FALSE;
	{
		if (!(n_p0 == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	switch ((*n_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	{
		result = ((kinds_p1[(NU)(((*n_p0).kind))>>3] &(1U<<((NU)(((*n_p0).kind))&7U)))!=0);
	}
	break;
	default:
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA9;
					i_1 = i_2;
					{
						NIM_BOOL T12_;
						T12_ = (NIM_BOOL)0;
						T12_ = ((kinds_p1[(NU)(((*n_p0).kind))>>3] &(1U<<((NU)(((*n_p0).kind))&7U)))!=0);
						if (T12_) goto LA13_;
						T12_ = containsNode__ast_u7008((*n_p0)._kind_6.sons.p->data[i_1], kinds_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA13_: ;
						if (!T12_) goto LA14_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
LA14_: ;
					i_2 += ((NI)1);
				} LA9: ;
			}
		}
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasSubnodeWith__ast_u7029)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p1) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	switch ((*n_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)23):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)76):
	{
		result = ((*n_p0).kind == kind_p1);
	}
	break;
	default:
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__ast_u3190(n_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA5;
					i_1 = i_2;
					{
						NIM_BOOL T8_;
						T8_ = (NIM_BOOL)0;
						T8_ = ((*(*n_p0)._kind_6.sons.p->data[i_1]).kind == kind_p1);
						if (T8_) goto LA9_;
						T8_ = hasSubnodeWith__ast_u7029((*n_p0)._kind_6.sons.p->data[i_1], kind_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA9_: ;
						if (!T8_) goto LA10_;
						result = NIM_TRUE;
						goto BeforeRet_;
					}
LA10_: ;
					i_2 += ((NI)1);
				} LA5: ;
			}
		}
		result = NIM_FALSE;
	}
	break;
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaise__ast_u7516)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fn_p0) {
	NIM_BOOL result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NIM_BOOL)0;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NIM_BOOL T6_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*fn_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T6_ = (NIM_BOOL)0;
		T6_ = !(((*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)22) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)23) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)25) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)26) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)20)));
		if (T6_) goto LA7_;
		T6_ = ((IL64(4294967360) & (*(*fn_p0)._kind_4.sym).flags) == 64);
LA7_: ;
		T5_ = T6_;
		if (T5_) goto LA8_;
		T5_ = (((*(*fn_p0)._kind_4.sym).flags &((NU64)1<<((NU)((((tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg)39)))&63U)))!=0);
LA8_: ;
		T3_ = T5_;
LA4_: ;
		if (!T3_) goto LA9_;
		result = NIM_FALSE;
	}
	goto LA1_;
LA9_: ;
	{
		NIM_BOOL T12_;
		T12_ = (NIM_BOOL)0;
		T12_ = ((*fn_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T12_)) goto LA13_;
		T12_ = ((*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)20));
LA13_: ;
		if (!T12_) goto LA14_;
		result = NIM_TRUE;
	}
	goto LA1_;
LA14_: ;
	{
		NIM_BOOL T17_;
		NIM_BOOL T18_;
		T17_ = (NIM_BOOL)0;
		T18_ = (NIM_BOOL)0;
		T18_ = !(((*fn_p0).typField == ((tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*) NIM_NIL)));
		if (!(T18_)) goto LA19_;
		T18_ = ((*(*fn_p0).typField).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)25));
LA19_: ;
		T17_ = T18_;
		if (!(T17_)) goto LA20_;
		T17_ = !(((*(*fn_p0).typField).n == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
LA20_: ;
		if (!T17_) goto LA21_;
		{
			if (!((*(*(*(*fn_p0).typField).n)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3))) goto LA25_;
			result = NIM_FALSE;
		}
		goto LA23_;
LA25_: ;
		{
			NIM_BOOL T28_;
			NI T29_;
			NIM_BOOL T31_;
			NI T33_;
			T28_ = (NIM_BOOL)0;
			T29_ = (NI)0;
			T29_ = len__ast_u3190((*(*(*fn_p0).typField).n)._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T28_ = (T29_ < ((NI)6));
			if (T28_) goto LA30_;
			T31_ = (NIM_BOOL)0;
			T31_ = !(((*(*(*(*fn_p0).typField).n)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)] == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)));
			if (!(T31_)) goto LA32_;
			T33_ = (NI)0;
			T33_ = safeLen__ast_u3197((*(*(*(*fn_p0).typField).n)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)0)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T31_ = (((NI)0) < T33_);
LA32_: ;
			T28_ = T31_;
LA30_: ;
			result = T28_;
		}
LA23_: ;
	}
	goto LA1_;
LA21_: ;
	{
		result = NIM_FALSE;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u5581)(tyTuple__IYAk6y4YHp5OEJgCALGjQw dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn(dest_p0.Field1);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3288((&(*dest_p0.Field1)));
		nimRawDispose(dest_p0.Field1, ((NI)8));
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u5578)(tyTuple__IYAk6y4YHp5OEJgCALGjQw* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, transitionIntToFloatKind__ast_u6815)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0, tyEnum_TNodeKind__ejrmw4CHo9bZqcGZhO9alDfA kind_p1) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ obj_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* colontmpD_;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&obj_1), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	eqcopy___ast_u3273((&obj_1), (&(*n_p0)));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	nimZeroMem((void*)(&T1_), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
	T1_.kind = kind_p1;
	colontmpD_ = eqdup___ast_u3384((*n_p0).typField);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_.typField = colontmpD_;
	T1_.info = obj_1.info;
	T1_.flags = obj_1.flags;
	eqsink___ast_u3279((&(*n_p0)), (&T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*n_p0)._kind_2.floatVal = ((NF) (obj_1._kind_1.intVal));
	eqdestroy___ast_u3270((&obj_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, makeStmtList__ast_u7245)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	{
		if (!((*n_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115))) goto LA3_;
		eqcopy___ast_u3255(&result, n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = newNodeI__ast_u4091(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115), (*n_p0).info);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		add__ast_u3215(result, n_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, elementType__ast_u5331)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* n_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg** T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = (tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg**)0;
	T1_ = X5BX5D___ast_u5281((((*n_p0).sons).p) ? ((*n_p0).sons.p->data) : NIM_NIL, (*n_p0).sons.len, ((NI)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3381(&result, (*T1_));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*, toObject__ast_u7291)(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ_p0) {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* result;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* t_1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	t_1 = NIM_NIL;
	t_1 = skipTypes__ast_u5379(typ_p0, TM__EnH1I9cGkGYbf9a1NwhuXDPg_1070);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	{
		if (!((*t_1).kind == ((tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg)22))) goto LA4_;
		result = elementType__ast_u5331(t_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA2_;
LA4_: ;
	{
		eqcopy___ast_u3381(&result, typ_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	eqdestroy___ast_u3378(t_1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, createModuleAlias__ast_u6311)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p1, tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* newIdent_p2, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p3, tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options_p4) {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	colontmpD_ = NIM_NIL;
	colontmpD_ = owner__ast_u6254(s_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = newSym__ast_u4205((*s_p0).kind, newIdent_p2, idgen_p1, colontmpD_, info_p3, options_p4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u3255(&(*result).ast, (*s_p0).ast);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*result).flags = (*s_p0).flags;
	(*result).options = (*s_p0).options;
	(*result).position = (*s_p0).position;
	eqcopy___ast_u6287((&(*result).loc), (*s_p0).loc);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqcopy___ast_u6219(&(*result).annex, (*s_p0).annex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___ast_u4574(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6538)(tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g* dest_p0, tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).counter = src_p1.counter;
	if ((*dest_p0).data.p != src_p1.data.p) {	eqdestroy___ast_u6548((*dest_p0).data);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
(*dest_p0).data.len = src_p1.data.len; (*dest_p0).data.p = src_p1.data.p;
	(*dest_p0).ignoreTypes = src_p1.ignoreTypes;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6529)(tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g dest_p0) {
	eqdestroy___ast_u6548(dest_p0.data);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u5812)(tyTuple__V6P73hvHy70PBBwharKjig dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field1);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*dest_p0.Field1)));
		nimRawDispose(dest_p0.Field1, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___ast_u5809)(tyTuple__V6P73hvHy70PBBwharKjig* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u5821)(tyTuple__V6P73hvHy70PBBwharKjig* dest_p0, tyTuple__V6P73hvHy70PBBwharKjig src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).Field0 = src_p1.Field0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).Field1);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3288((&(*(*dest_p0).Field1)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).Field1, ((NI)8));
	}
LA4_: ;
	(*dest_p0).Field1 = src_p1.Field1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, canRaiseConservative__ast_u7504)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* fn_p0) {
	NIM_BOOL result;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*fn_p0).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)3));
		if (!(T3_)) goto LA4_;
		T3_ = !(((*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)0) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)22) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)23) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)25) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)26) || (*(*fn_p0)._kind_4.sym).magic == ((tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg)20)));
LA4_: ;
		if (!T3_) goto LA5_;
		result = NIM_FALSE;
	}
	goto LA1_;
LA5_: ;
	{
		result = NIM_TRUE;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6284)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw dest_p0) {
	eqdestroy___system_u2691(dest_p0.snippet);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.lode);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*dest_p0.lode)));
		nimRawDispose(dest_p0.lode, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___ast_u6293)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* dest_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	(*dest_p0).k = src_p1.k;
	(*dest_p0).storage = src_p1.storage;
	(*dest_p0).flags = src_p1.flags;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).lode);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0).lode)));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0).lode, ((NI)8));
	}
LA4_: ;
	(*dest_p0).lode = src_p1.lode;
	if ((*dest_p0).snippet.p != src_p1.snippet.p) {	eqdestroy___system_u2691((*dest_p0).snippet);
	}
(*dest_p0).snippet.len = src_p1.snippet.len; (*dest_p0).snippet.p = src_p1.snippet.p;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdup___ast_u6290)(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw src_p0, tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw* Result) {
	nimZeroMem((void*)Result, sizeof(tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw));
	(*Result).k = src_p0.k;
	(*Result).storage = src_p0.storage;
	(*Result).flags = src_p0.flags;
	(*Result).lode = src_p0.lode;
	{
		if (!src_p0.lode) goto LA3_;
		nimIncRef(src_p0.lode);
	}
LA3_: ;
	(*Result).snippet = eqdup___system_u2697(src_p0.snippet);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, getDeclPragma__ast_u3932)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p0) {
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	switch ((*n_p0).kind) {
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)79) ... ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)84):
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)159):
	{
		{
			if (!!(((*(*n_p0)._kind_6.sons.p->data[((NI)4)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)1)))) goto LA4_;
			eqcopy___ast_u3255(&result, (*n_p0)._kind_6.sons.p->data[((NI)4)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA2_;
LA4_: ;
		{
			result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		}
LA2_: ;
	}
	break;
	case ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)103):
	{
		{
			if (!((*(*n_p0)._kind_6.sons.p->data[((NI)0)]).kind == ((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)43))) goto LA10_;
			eqcopy___ast_u3255(&result, (*(*n_p0)._kind_6.sons.p->data[((NI)0)])._kind_6.sons.p->data[((NI)1)]);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA8_;
LA10_: ;
		{
			result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
		}
LA8_: ;
	}
	break;
	default:
	{
		result = ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL);
	}
	break;
	}
	{
		if (!!((result == ((tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*) NIM_NIL)))) goto LA16_;
	}
LA16_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug*, idGeneratorFromModule__ast_u2849)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p0) {
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* result;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug*) nimNewObj(sizeof(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug), NIM_ALIGNOF(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug));
	(*T1_).module = (*m_p0).itemId.module;
	(*T1_).symId = (*m_p0).itemId.item;
	(*T1_).typeId_0 = ((NI32)0);
	(*T1_).disambTable = initCountTable__ast_u2869(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
