/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew;
typedef struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg;
typedef struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA;
typedef struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw;
typedef struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q tySequence__YdLNCDKYeipzJx3I8Xw82Q;
typedef struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA tySequence__TLbZ2GqL3Zio1f8bNpj2NA;
typedef struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content;
typedef struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ;
typedef struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w tySequence__GH1mmNKNA2QP4n1tnxJf1w;
typedef struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg tySequence__d8ZV4IMgHt9biik9cS9a0hrmg;
typedef struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content;
typedef struct tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA tySequence__TEgqV1E9aHqnwBUoeXjBI9aA;
typedef struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content;
typedef struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ tyObject_Table__tro5f9chxPVpES1mQpDwZtQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_Profiler__YI4zs2CaXXndlYireD0I8A tyObject_Profiler__YI4zs2CaXXndlYireD0I8A;
typedef struct tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw tySequence__fnH5Zt4fsGx0AgDTOw8pKw;
typedef struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content;
typedef struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ tyObject_Table__lPs28yjGTxD0LzUoPspSBQ;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q tySequence__Fc8Q26tsngy2yxcpyrnT4Q;
typedef struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content;
typedef struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA;
typedef struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA tySequence__ZeWVlH6DqG79b1pTDhrrUYA;
typedef struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ;
typedef struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA;
typedef struct tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg;
typedef struct tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA;
typedef struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw;
typedef struct tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q tySequence__9ahcSjIErJohSBBFLwuF56Q;
typedef struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content tySequence__9ahcSjIErJohSBBFLwuF56Q_Content;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g tySequence__qwqHTkRvwhrRyENtudHQ7g;
typedef struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content tySequence__qwqHTkRvwhrRyENtudHQ7g_Content;
typedef struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA tySequence__9c9aWmheGsuf9aHtY7gTnUcPA;
typedef struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content;
typedef struct tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg tySequence__TfHJycarvNts8E4mVG4Mfg;
typedef struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content tySequence__TfHJycarvNts8E4mVG4Mfg_Content;
typedef struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg tySequence__5reviU45axUMPQgL9aoENrg;
typedef struct tySequence__5reviU45axUMPQgL9aoENrg_Content tySequence__5reviU45axUMPQgL9aoENrg_Content;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw tySequence__dtr79aXjHrgHuH79ac55I2aw;
typedef struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content tySequence__dtr79aXjHrgHuH79ac55I2aw_Content;
typedef struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw tySequence__8y0Gi4GwtXi2wk2mK1IOzw;
typedef struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content;
typedef struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw tySequence__C2ivDnhTZ6IxAdui1rfuqw;
typedef struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content;
typedef struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g tySequence__3vEEVfBECLN6NIRA3FIp5g;
typedef struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content tySequence__3vEEVfBECLN6NIRA3FIp5g_Content;
typedef struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g tyObject_Table__tEqt8LkShErhjQ9acvGyE7g;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw tySequence__9aSa87aKMiolq9a7z3kC0jTw;
typedef struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content;
typedef struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ tySequence__N589c2UsUgqqOITU2JfIuAQ;
typedef struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content tySequence__N589c2UsUgqqOITU2JfIuAQ_Content;
typedef struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ tySequence__GYDW6wGgERshoSd16jJ3eQ;
typedef struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content tySequence__GYDW6wGgERshoSd16jJ3eQ_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ;
typedef struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA tySequence__ZCZaCk14bTmSb6LMW9aWPVA;
typedef struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content;
typedef struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg tySequence__fdmz6VkIf1ewwrssKYqRFg;
typedef struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content tySequence__fdmz6VkIf1ewwrssKYqRFg_Content;
typedef struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA tyObject_Table__AC9bec2JdoOuC3xQePGWgmA;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg tySequence__kxu4GK0onha2t9bo86mdVAg;
typedef struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content tySequence__kxu4GK0onha2t9bo86mdVAg_Content;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA tySequence__48JTohSgTy339bRxHzUD8KA;
typedef struct tySequence__48JTohSgTy339bRxHzUD8KA_Content tySequence__48JTohSgTy339bRxHzUD8KA_Content;
typedef struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg tySequence__fz0REU1l0nYmKHXgMLRrIg;
typedef struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content tySequence__fz0REU1l0nYmKHXgMLRrIg_Content;
typedef struct tyObject_Table__w2vCG1OPnHmNolvQVT168g tyObject_Table__w2vCG1OPnHmNolvQVT168g;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ tySequence__Ip9aV1IKO2gVdheNOM31DCQ;
typedef struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg tySequence__kHjIdgrpmuSn9cUIIKpSiDg;
typedef struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content;
typedef struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA tySequence__Wd0Vle6gxRCPPoSlNEvfTA;
typedef struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content;
typedef struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag tyObject_Table__fZyCWkMwhdvr3pauCNDaag;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw tySequence__T7nNEWoEbKBa0G5Htr45Xw;
typedef struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content;
typedef struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ tyObject_Table__5vmBY49areSIlgIs4A1LLKQ;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA tySequence__q9cHvMDDxYU1hSCdG4YwIhA;
typedef struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA tySequence__olFOFaYzOJN9aV5BWqK4b9bA;
typedef struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content;
typedef struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA tySequence__vJcM7B74R2U5db9cxyXT9coA;
typedef struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content tySequence__vJcM7B74R2U5db9cxyXT9coA_Content;
typedef struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg;
typedef struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content;
typedef struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg tySequence__R9c39btP6BwOBBPnbaNUtMQg;
typedef struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content;
typedef struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA tySequence__squ9b9bUH4OLHf6cEMrt6hVA;
typedef struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content;
typedef struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw tySequence__3nALyQgqjnfK2Qjc6ny2Uw;
typedef struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg tySequence__WbW5Q8QVks0bQpUJSGmuVg;
typedef struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content;
typedef struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tySequence__grdS5PdBBxkq9bxi4lFAdAw tySequence__grdS5PdBBxkq9bxi4lFAdAw;
typedef struct tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content;
typedef struct tyTuple__9ap1MJ9bVBlP34AqrUq01n8w tyTuple__9ap1MJ9bVBlP34AqrUq01n8w;
typedef struct tySequence__b9bG03Q6unwlMU0dM7uOPIA tySequence__b9bG03Q6unwlMU0dM7uOPIA;
typedef struct tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content;
typedef struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw tySequence__hRbbzIynOoxrYjHTIKZ3Gw;
typedef struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content;
typedef struct tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA;
typedef struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg;
typedef struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg;
typedef struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ;
typedef struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g tyTuple__y6bKAf9a9aaVwun6lVDxSX7g;
typedef struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow;
typedef struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA;
typedef struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA tySequence__PXIzfWocnrafGz5p3CP5LA;
typedef struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content tySequence__PXIzfWocnrafGz5p3CP5LA_Content;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA tySequence__9bAGqSvkAaFL9bWjsEPslrFA;
typedef struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content;
typedef struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA tySequence__OxRbUT0qZaZN5UjnqQjGPA;
typedef struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA tySequence__ezS5mGPcRfBURJyMgqYVzA;
typedef struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content tySequence__ezS5mGPcRfBURJyMgqYVzA_Content;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA tySequence__wW7xkohjuUKO9aMaB0nt9cqA;
typedef struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg tySequence__b89aLriiJnVTD186H6zNIgg;
typedef struct tySequence__b89aLriiJnVTD186H6zNIgg_Content tySequence__b89aLriiJnVTD186H6zNIgg_Content;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg tySequence__hIPTk9aFdaMMVAOzEbnPyqg;
typedef struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg tySequence__YYy1721YAuPF0ajBYHd8Wg;
typedef struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content tySequence__YYy1721YAuPF0ajBYHd8Wg_Content;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ tySequence__UODJbvzmu39c3Ho9cqhSk9agQ;
typedef struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw tySequence__F1qNdU7m0Czu7Y2q0eksXw;
typedef struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q tySequence__r3Kz9breImOXyFFoJ29aBM8Q;
typedef struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw tySequence__qBes3XzcQQ9cyia9bRwnmbJw;
typedef struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content;
typedef struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA tySequence__Vl1abU3gfp0RqCb1KKfmDA;
typedef struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content;
typedef struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ tySequence__qyyNkmlc4fzOzelC8spUkQ;
typedef struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content tySequence__qyyNkmlc4fzOzelC8spUkQ_Content;
typedef struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA;
typedef struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ tySequence__IHUFRsFxZNv7YydiUO2esQ;
typedef struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content tySequence__IHUFRsFxZNv7YydiUO2esQ_Content;
typedef struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw tySequence__orxtl6CusdjXleqrxi67gw;
typedef struct tySequence__orxtl6CusdjXleqrxi67gw_Content tySequence__orxtl6CusdjXleqrxi67gw_Content;
typedef struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw tySequence__K0j67V58u5FW0dCC534FQw;
typedef struct tySequence__K0j67V58u5FW0dCC534FQw_Content tySequence__K0j67V58u5FW0dCC534FQw_Content;
typedef struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw tySequence__UE4b6iUkm1b3zTPamTTkDw;
typedef struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content tySequence__UE4b6iUkm1b3zTPamTTkDw_Content;
typedef struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA tySequence__FmsTQiIcS9arxHxs3QY48vA;
typedef struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content tySequence__FmsTQiIcS9arxHxs3QY48vA_Content;
typedef struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ;
typedef struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg tyObject_Table__uaQEKxLZNO5fpFluyxnhTg;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ tySequence__9cnx3zXnWzeclW8Ko4oUgAQ;
typedef struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content;
typedef struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ tySequence__vb3AGHvMJTxdOSSwMmBmTQ;
typedef struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content;
typedef struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q tyTuple__F1mMODXmKFMNQ5rLCtcv0Q;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA tySequence__apM9bRAO19cVjhWlxqd1PGeA;
typedef struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content;
typedef struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw;
typedef struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA;
typedef struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ;
typedef struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig;
typedef struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw tySequence__9bW2eTK9b7vXE70Sx5VPH1mw;
typedef struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content;
typedef struct tyTuple__bnJwOH0eJlAwCAMbr1inhw tyTuple__bnJwOH0eJlAwCAMbr1inhw;
typedef struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw tyTuple__YG7h1OUHzgfgTeH9cl0U0dw;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q;
typedef struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ tyTuple__xDU9bZmv1ZbZkJDaATBekIQ;
typedef struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ tyTuple__tG5yYi8DnD7bl00aT9cgctQ;
typedef struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg;
typedef struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content;
typedef struct tySequence__yUWoZehF86MIc40opFgacw tySequence__yUWoZehF86MIc40opFgacw;
typedef struct tySequence__yUWoZehF86MIc40opFgacw_Content tySequence__yUWoZehF86MIc40opFgacw_Content;
typedef struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw;
typedef struct tyTuple__gnRkA1L4XiR4uByriyHW8Q tyTuple__gnRkA1L4XiR4uByriyHW8Q;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA tySequence__nSO1ltijM4vhc0UrrXKEqA;
typedef struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content tySequence__nSO1ltijM4vhc0UrrXKEqA_Content;
typedef struct tyTuple__CvjVmQeIfivirDme2r5MRw tyTuple__CvjVmQeIfivirDme2r5MRw;
typedef struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g tyTuple__2QDyOgS51ZMPO0W1pWCY6g;
typedef struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ tyTuple__UbCNQED4XJUgxOgPHJUcAQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ tySequence__juxPMVNF1FoR2ltzeQu8NQ;
typedef struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content;
typedef struct tyTuple__zExIg9bDTcVf2FHROUpzoow tyTuple__zExIg9bDTcVf2FHROUpzoow;
typedef struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA tyTuple__XrHNJHOzS3O7uwF9bvCySiA;
typedef struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ tyTuple__EdLY4EJQ37VFgbAn5g5rXQ;
typedef struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA tyTuple__OtlgAx3kBps9cOSMNDZSzBA;
typedef struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg tyTuple__F3gkSrMB1qp2Tvf9bixVXwg;
typedef struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ;
typedef struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw;
typedef struct tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q;
typedef struct tyTuple__O3g9a8zTXSX36ljWponcAoA tyTuple__O3g9a8zTXSX36ljWponcAoA;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyTuple__Oubp8LPEu86EPyDuc56AXg tyTuple__Oubp8LPEu86EPyDuc56AXg;
typedef struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q tyTuple__0q9cmhneJEKnQERTpXXdz6Q;
typedef struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w;
typedef struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ tyTuple__48iPM3yLBKU5nyEuYwJvuQ;
typedef struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg tyTuple__R3ddFrA0G9buJY57Qhf9cTpg;
typedef struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ;
typedef struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA tyTuple__7rmdAMLZ8fDd79brQn2ixZA;
typedef struct tyTuple__qPXRCRNQuZLLKto7CIIEzw tyTuple__qPXRCRNQuZLLKto7CIIEzw;
typedef struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg;
typedef struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw tyTuple__6kG8KAxm9aXPdLdlxcxqJJw;
typedef struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw tyTuple__TRK7rrwoha9bbDAdPWsqJMw;
typedef struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q tyTuple__V1VWX9bHapuzCjpMfFfys5Q;
typedef struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw;
typedef struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg;
typedef struct tyTuple__anemVmHCFglLFt6LiEhFvg tyTuple__anemVmHCFglLFt6LiEhFvg;
typedef struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ;
typedef struct tyTuple__MaWaKZwaGUqCXKsSK12rVg tyTuple__MaWaKZwaGUqCXKsSK12rVg;
typedef struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA;
typedef struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA tyTuple__1xWeGeoNoZxaLhTUDDWYyA;
typedef struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ tyTuple__MZVSn3SE3XUBJOaMu7ofRQ;
typedef struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA tyTuple__UvldbCB6B9ayi9bGYW7vJNLA;
typedef struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA;
typedef struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ tySequence__YxH9cgSorHRI8ZPzHf47NNQ;
typedef struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content;
typedef struct tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ;
typedef struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw tyTuple__lGHLhAAUpxgfrnQkIzNrMw;
typedef struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA;
typedef struct tyTuple__V6P73hvHy70PBBwharKjig tyTuple__V6P73hvHy70PBBwharKjig;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ {
	RootObj Sup;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q {
  NI len; tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content* p;
};
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA {
  NI len; tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content* p;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w {
  NI len; tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content* p;
};
struct tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g {
	NI counter;
	tySequence__GH1mmNKNA2QP4n1tnxJf1w data;
	NIM_BOOL ignoreTypes;
};
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg {
  NI len; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content* p;
};
typedef NU8 tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg;
typedef NU8 tySet_tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g;
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA {
  NI len; tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content* p;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  NI len; tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content* p;
};
struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og data;
	NI counter;
};
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyObject_Profiler__YI4zs2CaXXndlYireD0I8A {
	NF tEnter;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* tos;
};
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw {
  NI len; tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content* p;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q {
  NI len; tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content* p;
};
struct tyObject_Table__lPs28yjGTxD0LzUoPspSBQ {
	tySequence__Fc8Q26tsngy2yxcpyrnT4Q data;
	NI counter;
};
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA {
  NI len; tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content* p;
};
typedef NI tyArray__k7D0lwfLmYccbQxUd49bbcQ[34];
struct tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA {
	NI elems;
	NI counter;
	NI max;
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* head;
	tySequence__ZeWVlH6DqG79b1pTDhrrUYA data;
	tyArray__k7D0lwfLmYccbQxUd49bbcQ a;
};
struct tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew {
	tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ Sup;
	tySequence__YdLNCDKYeipzJx3I8Xw82Q code;
	tySequence__TLbZ2GqL3Zio1f8bNpj2NA debug;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* globals;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constants;
	tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g contstantTab;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg types;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentExceptionA;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentExceptionB;
	NI exceptionInstr;
	tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* prc;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* callsite;
	tyEnum_TEvalMode__sQljSFf0fjnsNV1fpgXakg mode;
	tySet_tyEnum_TSandboxFlag__II2KpGKWwJH9bdjbBum5d1g features;
	NIM_BOOL traceActive;
	NI loopIterations;
	NI callDepth;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA comesFromHeuristic;
	tySequence__TEgqV1E9aHqnwBUoeXjBI9aA callbacks;
	tyObject_Table__tro5f9chxPVpES1mQpDwZtQ callbackIndex;
	NimStringV2 errorFlag;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph;
	NI oldErrorCount;
	tyObject_Profiler__YI4zs2CaXXndlYireD0I8A profiler;
	NI* templInstCounter;
	tySequence__fnH5Zt4fsGx0AgDTOw8pKw vmstateDiff;
	tyObject_Table__lPs28yjGTxD0LzUoPspSBQ procToCodePos;
	NIM_BOOL cannotEval;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA locals;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef NU tyArray__KznKlIbW0OmA9ckg0NfmHVQ[8];
struct tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA {
	tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* next;
	NI key;
	tyArray__KznKlIbW0OmA9ckg0NfmHVQ bits;
};
struct tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field0;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field1;
};
struct tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA {
	NI32 module;
	NI32 item;
};
typedef NU8 tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q;
typedef NU16 tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg;
typedef NU64 tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg;
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU8 tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ;
typedef NU8 tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg;
typedef NU16 tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg;
struct tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw {
	tyEnum_TLocKind__4f5UmCRM8alrCgj32FqIRQ k;
	tyEnum_TStorageLoc__f19b6ZkRyh7BNPxlyjRbEGg storage;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* lode;
	NimStringV2 snippet;
};
struct tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA itemId;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
union{
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* gcUnsafetyReason;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* transformedBody;
} _kind_1;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* guard;
	NI bitsize;
	NI alignment;
} _kind_2;
};
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* name;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* ownerField;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* ast;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	tyObject_TLoc__KvQVlvKb6mbV567NQ0hMOw loc;
	tyObject_TLib__sVuuRvQkiYNOUiPRZhmZig* annex;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* constraint;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* instantiatedFrom;
};
typedef NU32 tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw;
typedef NU8 tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw;
struct tySequence__9ahcSjIErJohSBBFLwuF56Q {
  NI len; tySequence__9ahcSjIErJohSBBFLwuF56Q_Content* p;
};
struct tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ {
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typField;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw flags;
	tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind;
union{
	struct {
	NI64 intVal;
} _kind_1;
	struct {
	NF floatVal;
} _kind_2;
	struct {
	NimStringV2 strVal;
} _kind_3;
	struct {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
} _kind_4;
	struct {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* ident;
} _kind_5;
	struct {
	tySequence__9ahcSjIErJohSBBFLwuF56Q sons;
} _kind_6;
};
};
struct tySequence__qwqHTkRvwhrRyENtudHQ7g {
  NI len; tySequence__qwqHTkRvwhrRyENtudHQ7g_Content* p;
};
struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA {
  NI len; tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content* p;
};
struct tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* prc;
	tySequence__9c9aWmheGsuf9aHtY7gTnUcPA slots;
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* next;
	NI comesFrom;
	tySequence__qwqHTkRvwhrRyENtudHQ7g safePoints;
};
typedef NU8 tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA;
struct tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A {
	tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA kind;
union{
	NI64 intVal;
	NF floatVal;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* node;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* regAddr;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ** nodeAddr;
};
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg {
  NI len; tySequence__TfHJycarvNts8E4mVG4Mfg_Content* p;
};
struct tySequence__5reviU45axUMPQgL9aoENrg {
  NI len; tySequence__5reviU45axUMPQgL9aoENrg_Content* p;
};
struct tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg {
	tySequence__5reviU45axUMPQgL9aoENrg pm;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw {
  NI len; tySequence__dtr79aXjHrgHuH79ac55I2aw_Content* p;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw {
  NI len; tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content* p;
};
struct tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg {
	tySequence__8y0Gi4GwtXi2wk2mK1IOzw data;
	NI counter;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw {
  NI len; tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content* p;
};
struct tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w {
	tySequence__C2ivDnhTZ6IxAdui1rfuqw data;
	NI counter;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g {
  NI len; tySequence__3vEEVfBECLN6NIRA3FIp5g_Content* p;
};
struct tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA {
	tySequence__3vEEVfBECLN6NIRA3FIp5g data;
	NI counter;
};
typedef tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA tyArray__HTPiakF26bUQGH9bgtmrtkA[7];
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw {
  NI len; tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content* p;
};
struct tyObject_Table__tEqt8LkShErhjQ9acvGyE7g {
	tySequence__9aSa87aKMiolq9a7z3kC0jTw data;
	NI counter;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ {
  NI len; tySequence__N589c2UsUgqqOITU2JfIuAQ_Content* p;
};
struct tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw {
	tySequence__N589c2UsUgqqOITU2JfIuAQ data;
	NI counter;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ {
  NI len; tySequence__GYDW6wGgERshoSd16jJ3eQ_Content* p;
};
struct tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw {
	tySequence__GYDW6wGgERshoSd16jJ3eQ data;
	NI counter;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
};
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA {
  NI len; tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content* p;
};
struct tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg {
	NI counter;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA data;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg {
  NI len; tySequence__fdmz6VkIf1ewwrssKYqRFg_Content* p;
};
struct tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw {
	tySequence__fdmz6VkIf1ewwrssKYqRFg data;
	NI counter;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg {
  NI len; tySequence__kxu4GK0onha2t9bo86mdVAg_Content* p;
};
struct tyObject_Table__AC9bec2JdoOuC3xQePGWgmA {
	tySequence__kxu4GK0onha2t9bo86mdVAg data;
	NI counter;
};
struct tySequence__48JTohSgTy339bRxHzUD8KA {
  NI len; tySequence__48JTohSgTy339bRxHzUD8KA_Content* p;
};
typedef struct {
N_NIMCALL_PTR(NIM_BOOL, ClP_0) (void* ClE_0);
void* ClE_0;
} tyProc__In3g79a0qTcRmbTbJp9ba9ctg;
struct tySequence__fz0REU1l0nYmKHXgMLRrIg {
  NI len; tySequence__fz0REU1l0nYmKHXgMLRrIg_Content* p;
};
struct tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ {
	tySequence__fz0REU1l0nYmKHXgMLRrIg data;
	NI counter;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ {
  NI len; tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content* p;
};
struct tyObject_Table__w2vCG1OPnHmNolvQVT168g {
	tySequence__Ip9aV1IKO2gVdheNOM31DCQ data;
	NI counter;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg {
  NI len; tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content* p;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA {
  NI len; tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content* p;
};
struct tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA {
	tySequence__Wd0Vle6gxRCPPoSlNEvfTA data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw {
  NI len; tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content* p;
};
struct tyObject_Table__fZyCWkMwhdvr3pauCNDaag {
	tySequence__T7nNEWoEbKBa0G5Htr45Xw data;
	NI counter;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA {
  NI len; tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content* p;
};
struct tyObject_Table__5vmBY49areSIlgIs4A1LLKQ {
	tySequence__q9cHvMDDxYU1hSCdG4YwIhA data;
	NI counter;
};
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA {
  NI len; tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content* p;
};
typedef tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* tyArray__EOkbZZXacNOZHC8p7xc7hw[65];
struct tySequence__vJcM7B74R2U5db9cxyXT9coA {
  NI len; tySequence__vJcM7B74R2U5db9cxyXT9coA_Content* p;
};
struct tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw {
	tySequence__vJcM7B74R2U5db9cxyXT9coA data;
	NI counter;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg {
  NI len; tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content* p;
};
struct tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg {
	tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg data;
	NI counter;
};
typedef N_NIMCALL_PTR(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, tyProc__QieBhPPkGvcmpFg89a4ftcA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__F2ahyGAjs3aNLJYEXzu07g) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* m_p1, NI32 fileIdx_p2);
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg {
  NI len; tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content* p;
};
struct tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ {
	tySequence__R9c39btP6BwOBBPnbaNUtMQg data;
	NI counter;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA {
  NI len; tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content* p;
};
struct tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw {
	tySequence__squ9b9bUH4OLHf6cEMrt6hVA data;
	NI counter;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw {
  NI len; tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content* p;
};
struct tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ {
	tySequence__3nALyQgqjnfK2Qjc6ny2Uw data;
	NI counter;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg {
  NI len; tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content* p;
};
typedef NU8 tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg;
typedef N_NIMCALL_PTR(void, tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* s_p1, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p2);
typedef N_NIMCALL_PTR(void, tyProc__kj3TYePLaHBuXxhRznQQNQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* owner_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* body_p2);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__D3Q9bYoPIpHZVLfEIxpBssA) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* formal_p1, tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* actual_p2);
struct tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opNot;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opContains;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLe;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLt;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAnd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opOr;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opIsNil;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opEq;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opAdd;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opSub;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opMul;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opDiv;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* opLen;
};
struct tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw {
	tySequence__TfHJycarvNts8E4mVG4Mfg ifaces;
	tyObject_PackedModuleGraph__vzv9a6xTiz616FotDgUeo9bg packed_0;
	tySequence__dtr79aXjHrgHuH79ac55I2aw encoders;
	tyObject_Table__EBJpp1hXwvFl9cyekUv4qHg typeInstCache;
	tyObject_Table__nn0jq9adRZXGGj9assM9c9bR0w procInstCache;
	tyArray__HTPiakF26bUQGH9bgtmrtkA attachedOps;
	tyObject_Table__tEqt8LkShErhjQ9acvGyE7g methodsPerGenericType;
	tyObject_Table__QS2Z9cQjmvkp1aaFGq4ippw memberProcsPerType;
	tyObject_Table__bnfVX2VJ9aUicVujDM0GIhw initializersPerType;
	tyObject_Table__ChMwcRY3QzpOEBWbGAfvcA enumToStringProcs;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A emittedTypeInfo;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ startupPackedConfig;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA deps;
	tyObject_Table__79b4rr6WWQqgRr9b4NH4UF9cw importDeps;
	NIM_BOOL suggestMode;
	NIM_BOOL invalidTransitiveClosure;
	NIM_BOOL interactive;
	NIM_BOOL withinSystem;
	tyObject_Table__AC9bec2JdoOuC3xQePGWgmA inclToMod;
	tySequence__48JTohSgTy339bRxHzUD8KA importStack;
	RootObj* backend;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache;
	RootObj* vm;
	RootObj* repl;
	tyProc__In3g79a0qTcRmbTbJp9ba9ctg doStopCompile;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* usageSym;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA owners;
	tyObject_Table__bHTcQUCehDW9clHfFZXI7lQ suggestSymbols;
	tyObject_Table__w2vCG1OPnHmNolvQVT168g suggestErrors;
	tySequence__kHjIdgrpmuSn9cUIIKpSiDg methods;
	tyObject_CountTable__qvMelb9coODdwoghoAPc9c9aA bucketTable;
	tyObject_Table__fZyCWkMwhdvr3pauCNDaag objectTree;
	tyObject_Table__5vmBY49areSIlgIs4A1LLKQ methodsPerType;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA dispatchers;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* systemModule;
	tyArray__EOkbZZXacNOZHC8p7xc7hw sysTypes;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg compilerprocs;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg exposed;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg packageTypes;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* emptyNode;
	tyObject_Table__9bmd0cvHWe1s4FTDn5BPmfw canonTypes;
	tyObject_Table__GhjCMuklnRqwdX9bZo9bCoNg symBodyHashes;
	tyProc__QieBhPPkGvcmpFg89a4ftcA importModuleCallback;
	tyProc__F2ahyGAjs3aNLJYEXzu07g includeFileCallback;
	tyObject_Table__pI3mJh4Ap2XujSCfcSeUvQ cacheSeqs;
	tyObject_Table__MsPmCuYz1KcEw6lr7P9cGkw cacheCounters;
	tyObject_Table__1HJsK7ponJ4Vb1lJgVFVTQ cacheTables;
	tySequence__WbW5Q8QVks0bQpUJSGmuVg passes;
	tyEnum_PipelinePass__kO50VlNfBJZtrNuD4VL9aTg pipelinePass;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinition;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onDefinitionResolveForward;
	tyProc__c9a5q9aZQWYYOu1vHoRoq9bVQ onUsage;
	tySequence__9ahcSjIErJohSBBFLwuF56Q globalDestructors;
	tyProc__kj3TYePLaHBuXxhRznQQNQ strongSemCheck;
	tyProc__D3Q9bYoPIpHZVLfEIxpBssA compatibleProps;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen;
	tyObject_Operators__yrAfvKhiysDamJlcGNgVfQ operators;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cachedFiles;
	tySequence__9ahcSjIErJohSBBFLwuF56Q procGlobals;
};
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
typedef tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* tyArray__s9a2jZbmN9cnqFaNnzUrYEjg[8192];
struct tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA {
	tyArray__s9a2jZbmN9cnqFaNnzUrYEjg buckets;
	NI wordCounter;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idAnon;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* idDelegator;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* emptyIdent;
};
struct tySequence__grdS5PdBBxkq9bxi4lFAdAw {
  NI len; tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content* p;
};
typedef NU8 tyEnum_TSlotKind__oo9bgjIHoNBV9c9cKJRycJW4A;
struct tyTuple__9ap1MJ9bVBlP34AqrUq01n8w {
	NIM_BOOL Field0;
	tyEnum_TSlotKind__oo9bgjIHoNBV9c9cKJRycJW4A Field1;
};
struct tySequence__b9bG03Q6unwlMU0dM7uOPIA {
  NI len; tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content* p;
};
struct tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg {
	tySequence__b9bG03Q6unwlMU0dM7uOPIA blocks;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
	tySequence__grdS5PdBBxkq9bxi4lFAdAw regInfo;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw {
  NI len; tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content* p;
};
struct tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ {
	tySequence__hRbbzIynOoxrYjHTIKZ3Gw data;
	NI counter;
	NIM_BOOL isSorted;
};
struct tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug {
	NI32 module;
	NI32 symId;
	NI32 typeId_0;
	NIM_BOOL sealed;
	tyObject_CountTable__5N9carAoH8U5E301UN9ccEmQ disambTable;
};
struct tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* label;
	tySequence__qwqHTkRvwhrRyENtudHQ7g fixups;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* args_p0, void* ClE_0);
void* ClE_0;
} tyProc__c9bXGQkBnyyGGVw063jrwZw;
struct tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg {
	NI32 pc;
	NI32 usedRegisters;
};
typedef NU8 tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA;
struct tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg {
	NI ra;
	NI rb;
	NI rc;
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* slots;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* currentException;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA currentLineInfo;
};
struct tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ {
	NI len;
	void* p;
};
struct tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content { NI cap; NU64 data[SEQ_DECL_SIZE]; };
struct tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content { NI cap; tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA data[SEQ_DECL_SIZE]; };
struct tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ {
	NI h;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* key;
	NI val;
};
struct tySequence__GH1mmNKNA2QP4n1tnxJf1w_Content { NI cap; tyObject_TNodePair__KE5IEbxbTGxhrXo6rzddjQ data[SEQ_DECL_SIZE]; };
struct tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content { NI cap; tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* data[SEQ_DECL_SIZE]; };
struct tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content { NI cap; tyProc__c9bXGQkBnyyGGVw063jrwZw data[SEQ_DECL_SIZE]; };
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
	NI Field0;
	NimStringV2 Field1;
	NI Field2;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content { NI cap; tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE]; };
struct tySequence__fnH5Zt4fsGx0AgDTOw8pKw_Content { NI cap; tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ data[SEQ_DECL_SIZE]; };
struct tyTuple__y6bKAf9a9aaVwun6lVDxSX7g {
	NI Field0;
	NI Field1;
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg Field2;
};
struct tySequence__Fc8Q26tsngy2yxcpyrnT4Q_Content { NI cap; tyTuple__y6bKAf9a9aaVwun6lVDxSX7g data[SEQ_DECL_SIZE]; };
struct tySequence__ZeWVlH6DqG79b1pTDhrrUYA_Content { NI cap; tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* data[SEQ_DECL_SIZE]; };
struct tySequence__9ahcSjIErJohSBBFLwuF56Q_Content { NI cap; tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* data[SEQ_DECL_SIZE]; };
struct tySequence__qwqHTkRvwhrRyENtudHQ7g_Content { NI cap; NI data[SEQ_DECL_SIZE]; };
struct tySequence__9c9aWmheGsuf9aHtY7gTnUcPA_Content { NI cap; tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A data[SEQ_DECL_SIZE]; };
struct tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow {
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA converters;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA patterns;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA pureEnums;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interf;
	tyObject_TStrTable__Ry5QUbfaMzlI1Jpe9bUTBDg interfHidden;
	NimStringV2 uniqueName;
};
struct tySequence__TfHJycarvNts8E4mVG4Mfg_Content { NI cap; tyObject_Iface__j1FkQxwEAKMJy1o9bap1xow data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ;
struct tySequence__PXIzfWocnrafGz5p3CP5LA {
  NI len; tySequence__PXIzfWocnrafGz5p3CP5LA_Content* p;
};
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA {
  NI len; tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content* p;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA {
  NI len; tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content* p;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA {
  NI len; tySequence__ezS5mGPcRfBURJyMgqYVzA_Content* p;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA {
  NI len; tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content* p;
};
struct tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w {
	tySequence__OxRbUT0qZaZN5UjnqQjGPA nodes;
	tySequence__ezS5mGPcRfBURJyMgqYVzA withFlags;
	tySequence__wW7xkohjuUKO9aMaB0nt9cqA withTypes;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg {
  NI len; tySequence__b89aLriiJnVTD186H6zNIgg_Content* p;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg {
  NI len; tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content* p;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg {
  NI len; tySequence__YYy1721YAuPF0ajBYHd8Wg_Content* p;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ {
  NI len; tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content* p;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw {
  NI len; tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content* p;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q {
  NI len; tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content* p;
};
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw {
  NI len; tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content* p;
};
typedef NU8 tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ;
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA {
  NI len; tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content* p;
};
struct tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw {
	tySequence__Vl1abU3gfp0RqCb1KKfmDA data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ {
  NI len; tySequence__qyyNkmlc4fzOzelC8spUkQ_Content* p;
};
struct tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw {
	tySequence__qyyNkmlc4fzOzelC8spUkQ data;
	NI counter;
	NI first;
	NI last;
};
struct tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__IHUFRsFxZNv7YydiUO2esQ {
  NI len; tySequence__IHUFRsFxZNv7YydiUO2esQ_Content* p;
};
struct tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg {
	tySequence__IHUFRsFxZNv7YydiUO2esQ vals;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA keys;
};
struct tySequence__orxtl6CusdjXleqrxi67gw {
  NI len; tySequence__orxtl6CusdjXleqrxi67gw_Content* p;
};
struct tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ {
	tySequence__orxtl6CusdjXleqrxi67gw aside;
};
struct tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ {
	NimStringV2 definedSymbols;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg moduleFlags;
	tySequence__PXIzfWocnrafGz5p3CP5LA includes;
	tySequence__9bAGqSvkAaFL9bWjsEPslrFA imports;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w toReplay;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w topLevel;
	tyObject_PackedTree__YtSUB9b7CaIoOyHxDty9bm6w bodies;
	tySequence__b89aLriiJnVTD186H6zNIgg exports;
	tySequence__b89aLriiJnVTD186H6zNIgg hidden;
	tySequence__hIPTk9aFdaMMVAOzEbnPyqg reexports;
	tySequence__b89aLriiJnVTD186H6zNIgg compilerProcs;
	tySequence__48JTohSgTy339bRxHzUD8KA converters;
	tySequence__48JTohSgTy339bRxHzUD8KA methods;
	tySequence__48JTohSgTy339bRxHzUD8KA trmacros;
	tySequence__48JTohSgTy339bRxHzUD8KA pureEnums;
	tySequence__YYy1721YAuPF0ajBYHd8Wg typeInstCache;
	tySequence__UODJbvzmu39c3Ho9cqhSk9agQ procInstCache;
	tySequence__F1qNdU7m0Czu7Y2q0eksXw attachedOps;
	tySequence__r3Kz9breImOXyFFoJ29aBM8Q methodsPerGenericType;
	tySequence__YYy1721YAuPF0ajBYHd8Wg enumToStringProcs;
	tySequence__YYy1721YAuPF0ajBYHd8Wg methodsPerType;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw dispatchers;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ emittedTypeInfo;
	tySet_tyEnum_ModuleBackendFlag__5FvIlwIIbpcHU0ZRU9a5hrQ backendFlags;
	tyObject_OrderedTable__vodBW9bS41CI2hVVsJJ8qiw syms;
	tyObject_OrderedTable__y5tq9cRly5CxS2mQPchEHcw types;
	tyObject_BiTable__KR9c7QZguPO3OKZOIcphgcA strings;
	tyObject_BiTable__9aUXwPoJbNPqj9a249c0iSmlg numbers;
	tyObject_LineInfoManager__TTy646Kfh1cVyXU9aSMasUQ man;
	tyObject_PackedConfig__Hpn673wkKPDorr1HY9bOaDQ cfg;
};
struct tySequence__K0j67V58u5FW0dCC534FQw {
  NI len; tySequence__K0j67V58u5FW0dCC534FQw_Content* p;
};
struct tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ {
	tySequence__K0j67V58u5FW0dCC534FQw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw {
  NI len; tySequence__UE4b6iUkm1b3zTPamTTkDw_Content* p;
};
struct tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ {
	tySequence__UE4b6iUkm1b3zTPamTTkDw data;
	NI counter;
	NI first;
	NI last;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA {
  NI len; tySequence__FmsTQiIcS9arxHxs3QY48vA_Content* p;
};
struct tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg {
	tySequence__FmsTQiIcS9arxHxs3QY48vA data;
	NI counter;
};
struct tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA {
	tyEnum_ModuleStatus__uT4B39a2dNaG9a9aunVdyhQtQ status;
	NIM_BOOL symsInit;
	NIM_BOOL typesInit;
	NIM_BOOL loadedButAliveSetChanged;
	tyObject_PackedModule__sRHd9aQ2ZMII76xRsfAbE9aQ fromDisk;
	tyObject_OrderedTable__h8mIUVGY8LJXF9cakgvB9bqQ syms;
	tyObject_OrderedTable__DED9c7j9bI3Lh5w4GQakK8yQ types;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg iface;
	tyObject_Table__BH9cy1hZ1rZZoGkNCEN1uvg ifaceHidden;
};
struct tySequence__5reviU45axUMPQgL9aoENrg_Content { NI cap; tyObject_LoadedModule__7NEKRkz5hkiOxQy5guqIHA data[SEQ_DECL_SIZE]; };
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ {
  NI len; tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content* p;
};
struct tyObject_Table__uaQEKxLZNO5fpFluyxnhTg {
	tySequence__9cnx3zXnWzeclW8Ko4oUgAQ data;
	NI counter;
};
struct tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ {
	NI32 thisModule;
	NI32 lastFile;
	NU32 lastLit;
	tyObject_Table__uaQEKxLZNO5fpFluyxnhTg filenames;
	tySequence__d8ZV4IMgHt9biik9cS9a0hrmg pendingTypes;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA pendingSyms;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA typeMarker;
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA symMarker;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config;
};
struct tySequence__dtr79aXjHrgHuH79ac55I2aw_Content { NI cap; tyObject_PackedEncoder__FGa18gE2dyYyuq9ckHprjTQ data[SEQ_DECL_SIZE]; };
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ {
  NI len; tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content* p;
};
struct tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__vb3AGHvMJTxdOSSwMmBmTQ Field2;
};
struct tySequence__8y0Gi4GwtXi2wk2mK1IOzw_Content { NI cap; tyTuple__7TXOq9czx9cn1FWKG5gXNK8Q data[SEQ_DECL_SIZE]; };
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA {
  NI len; tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content* p;
};
struct tyTuple__F1mMODXmKFMNQ5rLCtcv0Q {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__apM9bRAO19cVjhWlxqd1PGeA Field2;
};
struct tySequence__C2ivDnhTZ6IxAdui1rfuqw_Content { NI cap; tyTuple__F1mMODXmKFMNQ5rLCtcv0Q data[SEQ_DECL_SIZE]; };
struct tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig {
	NU32 module;
	NI32 item;
};
struct tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ {
	NI module;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig packed_0;
};
struct tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* sym;
};
struct tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field2;
};
struct tySequence__3vEEVfBECLN6NIRA3FIp5g_Content { NI cap; tyTuple__vHfXSpEC1R9b9cKgfFB9a58gw data[SEQ_DECL_SIZE]; };
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw {
  NI len; tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content* p;
};
struct tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__9bW2eTK9b7vXE70Sx5VPH1mw Field2;
};
struct tySequence__9aSa87aKMiolq9a7z3kC0jTw_Content { NI cap; tyTuple__4iq9bD09amB7Ah0r9cBB0nSPQ data[SEQ_DECL_SIZE]; };
struct tyTuple__bnJwOH0eJlAwCAMbr1inhw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field2;
};
struct tySequence__N589c2UsUgqqOITU2JfIuAQ_Content { NI cap; tyTuple__bnJwOH0eJlAwCAMbr1inhw data[SEQ_DECL_SIZE]; };
struct tyTuple__YG7h1OUHzgfgTeH9cl0U0dw {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__GYDW6wGgERshoSd16jJ3eQ_Content { NI cap; tyTuple__YG7h1OUHzgfgTeH9cl0U0dw data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__ZCZaCk14bTmSb6LMW9aWPVA_Content { NI cap; tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* data[SEQ_DECL_SIZE]; };
struct tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q {
	NI Field0;
	NI32 Field1;
	tySequence__48JTohSgTy339bRxHzUD8KA Field2;
};
struct tySequence__fdmz6VkIf1ewwrssKYqRFg_Content { NI cap; tyTuple__1mtQ8sCEE7DbfIuQciv9b5Q data[SEQ_DECL_SIZE]; };
struct tyTuple__xDU9bZmv1ZbZkJDaATBekIQ {
	NI Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__kxu4GK0onha2t9bo86mdVAg_Content { NI cap; tyTuple__xDU9bZmv1ZbZkJDaATBekIQ data[SEQ_DECL_SIZE]; };
struct tySequence__48JTohSgTy339bRxHzUD8KA_Content { NI cap; NI32 data[SEQ_DECL_SIZE]; };
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg {
  NI len; tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content* p;
};
struct tySequence__yUWoZehF86MIc40opFgacw {
  NI len; tySequence__yUWoZehF86MIc40opFgacw_Content* p;
};
struct tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw {
	tyObject_PackedSet__uMCH0vzAEgrsmOKwCWxFrA s;
	NI len;
};
struct tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ {
	tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg lineInfo;
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA sym;
	tySequence__yUWoZehF86MIc40opFgacw caughtExceptions;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw caughtExceptionsSet;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isDecl;
	tyObject_PackedBoolArray__1pk9boftqWMNDE1oh5HcIhw isGenericInstance;
	NI32 fileIndex;
	NIM_BOOL trackCaughtExceptions;
	NIM_BOOL isSorted;
};
struct tyTuple__tG5yYi8DnD7bl00aT9cgctQ {
	NI Field0;
	NI32 Field1;
	tyObject_SuggestFileSymbolDatabase__o0ahEzaLn5a7TdNqH4OVqQ Field2;
};
struct tySequence__fz0REU1l0nYmKHXgMLRrIg_Content { NI cap; tyTuple__tG5yYi8DnD7bl00aT9cgctQ data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA {
  NI len; tySequence__nSO1ltijM4vhc0UrrXKEqA_Content* p;
};
struct tyTuple__gnRkA1L4XiR4uByriyHW8Q {
	NI Field0;
	NI32 Field1;
	tySequence__nSO1ltijM4vhc0UrrXKEqA Field2;
};
struct tySequence__Ip9aV1IKO2gVdheNOM31DCQ_Content { NI cap; tyTuple__gnRkA1L4XiR4uByriyHW8Q data[SEQ_DECL_SIZE]; };
struct tyTuple__CvjVmQeIfivirDme2r5MRw {
	tySequence__ZCZaCk14bTmSb6LMW9aWPVA Field0;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field1;
};
struct tySequence__kHjIdgrpmuSn9cUIIKpSiDg_Content { NI cap; tyTuple__CvjVmQeIfivirDme2r5MRw data[SEQ_DECL_SIZE]; };
struct tyTuple__2QDyOgS51ZMPO0W1pWCY6g {
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field0;
	NI Field1;
};
struct tySequence__Wd0Vle6gxRCPPoSlNEvfTA_Content { NI cap; tyTuple__2QDyOgS51ZMPO0W1pWCY6g data[SEQ_DECL_SIZE]; };
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ {
  NI len; tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content* p;
};
struct tyTuple__UbCNQED4XJUgxOgPHJUcAQ {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__juxPMVNF1FoR2ltzeQu8NQ Field2;
};
struct tySequence__T7nNEWoEbKBa0G5Htr45Xw_Content { NI cap; tyTuple__UbCNQED4XJUgxOgPHJUcAQ data[SEQ_DECL_SIZE]; };
struct tyTuple__zExIg9bDTcVf2FHROUpzoow {
	NI Field0;
	tyObject_ItemId__N3z7uIvKCrk0S9cej5ew0nA Field1;
	tySequence__olFOFaYzOJN9aV5BWqK4b9bA Field2;
};
struct tySequence__q9cHvMDDxYU1hSCdG4YwIhA_Content { NI cap; tyTuple__zExIg9bDTcVf2FHROUpzoow data[SEQ_DECL_SIZE]; };
struct tySequence__olFOFaYzOJN9aV5BWqK4b9bA_Content { NI cap; tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA data[SEQ_DECL_SIZE]; };
typedef NU8 tyArray__dnD8kjh6rJ1Yy5jHvid0Ow[16];
struct tyTuple__XrHNJHOzS3O7uwF9bvCySiA {
	NI Field0;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field1;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field2;
};
struct tySequence__vJcM7B74R2U5db9cxyXT9coA_Content { NI cap; tyTuple__XrHNJHOzS3O7uwF9bvCySiA data[SEQ_DECL_SIZE]; };
struct tyTuple__EdLY4EJQ37VFgbAn5g5rXQ {
	NI Field0;
	NI Field1;
	tyArray__dnD8kjh6rJ1Yy5jHvid0Ow Field2;
};
struct tySequence__Mt5NbgJ9cKUrhjgdsnfKvXg_Content { NI cap; tyTuple__EdLY4EJQ37VFgbAn5g5rXQ data[SEQ_DECL_SIZE]; };
struct tyTuple__OtlgAx3kBps9cOSMNDZSzBA {
	NI Field0;
	NimStringV2 Field1;
	tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* Field2;
};
struct tySequence__R9c39btP6BwOBBPnbaNUtMQg_Content { NI cap; tyTuple__OtlgAx3kBps9cOSMNDZSzBA data[SEQ_DECL_SIZE]; };
struct tyTuple__F3gkSrMB1qp2Tvf9bixVXwg {
	NI Field0;
	NimStringV2 Field1;
	NI64 Field2;
};
struct tySequence__squ9b9bUH4OLHf6cEMrt6hVA_Content { NI cap; tyTuple__F3gkSrMB1qp2Tvf9bixVXwg data[SEQ_DECL_SIZE]; };
struct tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw {
	tyObject_NodecolonObjectType___U4ON6JZL9cIHezBQjmQzJ8Q* root;
	NI entries;
};
struct tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ {
	NI Field0;
	NimStringV2 Field1;
	tyObject_BTree__gZru4m5AxLV1lYyWPNBQBw Field2;
};
struct tySequence__3nALyQgqjnfK2Qjc6ny2Uw_Content { NI cap; tyTuple__RFOJ4fF7D9bpvmh9birH1JhQ data[SEQ_DECL_SIZE]; };
typedef N_NIMCALL_PTR(tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ*, tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__74nHWc2UIRu3iSR9akqDDBg) (tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p0, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* topLevelStmt_p1);
typedef N_NIMCALL_PTR(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, tyProc__S9bLWKf8jgjzoiotAmEyFSw) (tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* graph_p0, tyObject_TPassContext__QQOybmyOwFn29csyFzTSLNQ* p_p1, tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* n_p2);
struct tyTuple__O3g9a8zTXSX36ljWponcAoA {
	tyProc__TVHQTM3bKm4Mi6Ul6zgzuQ Field0;
	tyProc__74nHWc2UIRu3iSR9akqDDBg Field1;
	tyProc__S9bLWKf8jgjzoiotAmEyFSw Field2;
	NIM_BOOL Field3;
};
struct tySequence__WbW5Q8QVks0bQpUJSGmuVg_Content { NI cap; tyTuple__O3g9a8zTXSX36ljWponcAoA data[SEQ_DECL_SIZE]; };
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tySequence__grdS5PdBBxkq9bxi4lFAdAw_Content { NI cap; tyTuple__9ap1MJ9bVBlP34AqrUq01n8w data[SEQ_DECL_SIZE]; };
struct tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content { NI cap; tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA data[SEQ_DECL_SIZE]; };
struct tyTuple__Oubp8LPEu86EPyDuc56AXg {
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field0;
	NI Field1;
};
struct tySequence__hRbbzIynOoxrYjHTIKZ3Gw_Content { NI cap; tyTuple__Oubp8LPEu86EPyDuc56AXg data[SEQ_DECL_SIZE]; };
struct tyTuple__0q9cmhneJEKnQERTpXXdz6Q {
	NU32 Field0;
	NimStringV2 Field1;
};
struct tySequence__PXIzfWocnrafGz5p3CP5LA_Content { NI cap; tyTuple__0q9cmhneJEKnQERTpXXdz6Q data[SEQ_DECL_SIZE]; };
struct tySequence__9bAGqSvkAaFL9bWjsEPslrFA_Content { NI cap; NU32 data[SEQ_DECL_SIZE]; };
struct tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w {
	NU32 x;
	NU32 info;
};
struct tySequence__OxRbUT0qZaZN5UjnqQjGPA_Content { NI cap; tyObject_PackedNode__YxKk4C732K04CNgtMhmc0w data[SEQ_DECL_SIZE]; };
struct tyTuple__48iPM3yLBKU5nyEuYwJvuQ {
	NI32 Field0;
	tySet_tyEnum_TNodeFlag__3UjGgL9bLM4RXBnoZJs9cviw Field1;
};
struct tySequence__ezS5mGPcRfBURJyMgqYVzA_Content { NI cap; tyTuple__48iPM3yLBKU5nyEuYwJvuQ data[SEQ_DECL_SIZE]; };
struct tyTuple__R3ddFrA0G9buJY57Qhf9cTpg {
	NI32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__wW7xkohjuUKO9aMaB0nt9cqA_Content { NI cap; tyTuple__R3ddFrA0G9buJY57Qhf9cTpg data[SEQ_DECL_SIZE]; };
struct tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ {
	NU32 Field0;
	NI32 Field1;
};
struct tySequence__b89aLriiJnVTD186H6zNIgg_Content { NI cap; tyTuple__Izx9aRSX9a0diDXD84jOS9aMQ data[SEQ_DECL_SIZE]; };
struct tyTuple__7rmdAMLZ8fDd79brQn2ixZA {
	NU32 Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__hIPTk9aFdaMMVAOzEbnPyqg_Content { NI cap; tyTuple__7rmdAMLZ8fDd79brQn2ixZA data[SEQ_DECL_SIZE]; };
struct tyTuple__qPXRCRNQuZLLKto7CIIEzw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field1;
};
struct tySequence__YYy1721YAuPF0ajBYHd8Wg_Content { NI cap; tyTuple__qPXRCRNQuZLLKto7CIIEzw data[SEQ_DECL_SIZE]; };
struct tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig key;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw concreteTypes;
};
struct tySequence__UODJbvzmu39c3Ho9cqhSk9agQ_Content { NI cap; tyObject_PackedInstantiation__C3FSePJFY8gUIMObsjT2dg data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q;
struct tyTuple__6kG8KAxm9aXPdLdlxcxqJJw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	tyEnum_TTypeAttachedOp__RefHoBI5deIfxIZqo3dS5Q Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__F1qNdU7m0Czu7Y2q0eksXw_Content { NI cap; tyTuple__6kG8KAxm9aXPdLdlxcxqJJw data[SEQ_DECL_SIZE]; };
struct tyTuple__TRK7rrwoha9bbDAdPWsqJMw {
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field0;
	NI Field1;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig Field2;
};
struct tySequence__r3Kz9breImOXyFFoJ29aBM8Q_Content { NI cap; tyTuple__TRK7rrwoha9bbDAdPWsqJMw data[SEQ_DECL_SIZE]; };
struct tySequence__qBes3XzcQQ9cyia9bRwnmbJw_Content { NI cap; tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A;
struct tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg {
	tyEnum_TLibKind__BkKL8ReLoyYDI7of9aQPV0A kind;
	NIM_BOOL generated;
	NIM_BOOL isOverridden;
	NU32 name;
	NI32 path;
};
struct tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw {
	NI32 id;
	tyEnum_TSymKind__9a75lHd9cV25XwN4jXXBmM0Q kind;
	NU32 name;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typ;
	tySet_tyEnum_TSymFlag__Ii9cPbwXR8ePKVRFOdTKpDg flags;
	tyEnum_TMagic__I3BbtzbLAKAfOym58MkGAg magic;
	NU32 info;
	NI32 ast;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig guard;
	NI bitsize;
	NI alignment;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	NI position;
	NI32 offset;
	NI32 disamb;
	NU32 externalName;
	tySet_tyEnum_TLocFlag__Df76pxukl21zlyRFq9aa0Bg locFlags;
	tyObject_PackedLib__EpwVLk0Fuc5Q9agKLMWedbg annex;
	NI32 constraint;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig instantiatedFrom;
};
struct tyTuple__V1VWX9bHapuzCjpMfFfys5Q {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedSym__KKnx6w8Cc9aaVsaPOpaqxbw Field3;
};
struct tySequence__Vl1abU3gfp0RqCb1KKfmDA_Content { NI cap; tyTuple__V1VWX9bHapuzCjpMfFfys5Q data[SEQ_DECL_SIZE]; };
typedef NU8 tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg;
typedef NU8 tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ;
typedef NU64 tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A;
struct tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ {
	NI32 id;
	tyEnum_TTypeKind__DYVdhzQ9cMfgoirdzGDwSCg kind;
	tyEnum_TCallingConvention__MvGn9cvx9bNYQKo7Hhd5GM9cQ callConv;
	tySet_tyEnum_TTypeFlag__HJaExo9c84N85e9br9anJmV1A flags;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw types;
	NI32 n;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig sym;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig owner;
	NI64 size;
	NI16 align;
	NI16 paddingAtEnd;
	tyObject_PackedItemId__WqAMZCDwoZiUuOt3ohcDig typeInst;
	NI32 nonUniqueId;
};
struct tyTuple__anemVmHCFglLFt6LiEhFvg {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_PackedType__8M8VlYfwJ6AtpxG1HNn4bQ Field3;
};
struct tySequence__qyyNkmlc4fzOzelC8spUkQ_Content { NI cap; tyTuple__anemVmHCFglLFt6LiEhFvg data[SEQ_DECL_SIZE]; };
struct tySequence__IHUFRsFxZNv7YydiUO2esQ_Content { NI cap; NI64 data[SEQ_DECL_SIZE]; };
struct tyTuple__MaWaKZwaGUqCXKsSK12rVg {
	NU32 Field0;
	NI32 Field1;
	NI32 Field2;
};
struct tySequence__orxtl6CusdjXleqrxi67gw_Content { NI cap; tyTuple__MaWaKZwaGUqCXKsSK12rVg data[SEQ_DECL_SIZE]; };
struct tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* Field3;
};
struct tySequence__K0j67V58u5FW0dCC534FQw_Content { NI cap; tyTuple__nL9cBxaIV4ZA9b9ceY79coA5eA data[SEQ_DECL_SIZE]; };
struct tyTuple__1xWeGeoNoZxaLhTUDDWYyA {
	NI Field0;
	NI Field1;
	NI32 Field2;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field3;
};
struct tySequence__UE4b6iUkm1b3zTPamTTkDw_Content { NI cap; tyTuple__1xWeGeoNoZxaLhTUDDWYyA data[SEQ_DECL_SIZE]; };
struct tyTuple__MZVSn3SE3XUBJOaMu7ofRQ {
	NI Field0;
	tyObject_TIdent__LG4CHFyohryWo9bzZeyjDjA* Field1;
	tySequence__qBes3XzcQQ9cyia9bRwnmbJw Field2;
};
struct tySequence__FmsTQiIcS9arxHxs3QY48vA_Content { NI cap; tyTuple__MZVSn3SE3XUBJOaMu7ofRQ data[SEQ_DECL_SIZE]; };
struct tyTuple__UvldbCB6B9ayi9bGYW7vJNLA {
	NI Field0;
	NI32 Field1;
	NU32 Field2;
};
struct tySequence__9cnx3zXnWzeclW8Ko4oUgAQ_Content { NI cap; tyTuple__UvldbCB6B9ayi9bGYW7vJNLA data[SEQ_DECL_SIZE]; };
struct tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA {
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ id;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* typ;
};
struct tySequence__vb3AGHvMJTxdOSSwMmBmTQ_Content { NI cap; tyObject_LazyType__dsEGDq9cOhnzsRvTUTwwwuA data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ {
  NI len; tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content* p;
};
struct tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA {
	NI module;
	tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ sym;
	tySequence__YxH9cgSorHRI8ZPzHf47NNQ concreteTypes;
	tyObject_TInstantiation__jr8MibvPn2sQBnO7XCoZRQ* inst;
};
struct tySequence__apM9bRAO19cVjhWlxqd1PGeA_Content { NI cap; tyObject_LazyInstantiation__n72c7MnOoHWBy9c9akgwGqEA data[SEQ_DECL_SIZE]; };
struct tyTuple__lGHLhAAUpxgfrnQkIzNrMw {
	NI Field0;
	tyObject_LazySym__yw1M8ZE9be6l5XOjcw0euIA Field1;
};
struct tySequence__9bW2eTK9b7vXE70Sx5VPH1mw_Content { NI cap; tyTuple__lGHLhAAUpxgfrnQkIzNrMw data[SEQ_DECL_SIZE]; };
struct tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA {
	NU16 line;
	NI16 col;
};
struct tySequence__9aCujOg9b8Xgx9aYJJEMRHVwg_Content { NI cap; tyObject_TinyLineInfo__qW2GTIPjeOQ42q9c2MPWLLA data[SEQ_DECL_SIZE]; };
struct tySequence__yUWoZehF86MIc40opFgacw_Content { NI cap; tySequence__d8ZV4IMgHt9biik9cS9a0hrmg data[SEQ_DECL_SIZE]; };
struct tySequence__nSO1ltijM4vhc0UrrXKEqA_Content { NI cap; tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* data[SEQ_DECL_SIZE]; };
struct tyTuple__V6P73hvHy70PBBwharKjig {
	NI Field0;
	tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg* Field1;
};
struct tySequence__juxPMVNF1FoR2ltzeQu8NQ_Content { NI cap; tyTuple__V6P73hvHy70PBBwharKjig data[SEQ_DECL_SIZE]; };
struct tySequence__YxH9cgSorHRI8ZPzHf47NNQ_Content { NI cap; tyObject_FullId__tYrGdGRoone9bMsQwSCYR9bQ data[SEQ_DECL_SIZE]; };
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__vmdef_u3600)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1539)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u100)(tySequence__ZeWVlH6DqG79b1pTDhrrUYA dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, unregisterCycle__system_u3127)(tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZcollectionsZintsets_u66)(tyObject_TrunkcolonObjectType___lmbdIZwAo9agPlTE1wBREkA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimRawDispose)(void* p_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u2010)(tySequence__Fc8Q26tsngy2yxcpyrnT4Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1844)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3469)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3270)(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, alignedDealloc)(void* p_p0, NI align_p1);
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u8092)(NI dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1600)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZosproc_u474)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1620)(tySequence__9c9aWmheGsuf9aHtY7gTnUcPA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___modulegraphs_u13532)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___options_u1751)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___idents_u274)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u577)(tySequence__pUxI6Ljo6IKKHXKOZkQ7Og dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1321)(tySequence__TEgqV1E9aHqnwBUoeXjBI9aA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1165)(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1186)(tySequence__grdS5PdBBxkq9bxi4lFAdAw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u862)(tySequence__b9bG03Q6unwlMU0dM7uOPIA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3311)(tySequence__d8ZV4IMgHt9biik9cS9a0hrmg dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u6548)(tySequence__GH1mmNKNA2QP4n1tnxJf1w dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u741)(tySequence__TLbZ2GqL3Zio1f8bNpj2NA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u620)(tySequence__YdLNCDKYeipzJx3I8Xw82Q dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___ast_u3074)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___vmdef_u1551)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* dest_p0, void* env_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___vmdef_u1333)(tySequence__TEgqV1E9aHqnwBUoeXjBI9aA* dest_p0, void* env_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ*, newNode__ast_u4069)(tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw kind_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg*, eqdup___ast_u4580)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, eqdup___lineinfos_u2037)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ, initTable__vmdef_u421)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA*, eqdup___idents_u344)(tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*, eqdup___options_u2141)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw*, eqdup___modulegraphs_u14759)(tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug*, eqdup___ast_u3106)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* src_p0);
N_LIB_PRIVATE N_NIMCALL(void, initNodeTable__ast_u6397)(NIM_BOOL ignoreTypes_p0, tyObject_TNodeTable__RKuYIY5Phq1xnepo5DZI2g* Result);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__vmdef_u2266)(tySequence__TEgqV1E9aHqnwBUoeXjBI9aA* x_p0, tyProc__c9bXGQkBnyyGGVw063jrwZw y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdup___vmdef_u1392)(tyProc__c9bXGQkBnyyGGVw063jrwZw src_p0, NIM_BOOL cyclic_p1, tyProc__c9bXGQkBnyyGGVw063jrwZw* Result);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmdef_u2322)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* t_p0, NimStringV2 key_p1, NI val_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, reverseName__vmdef_u2235)(NimStringV2 s_p0);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
N_LIB_PRIVATE N_NIMCALL(tySequence__sM4lkSb7zS6F7OVMvW9cffQ, nsuSplitChar)(NimStringV2 s_p0, NIM_CHAR sep_p1, NI maxsplit_p2);
static N_INLINE(NimStringV2, X5BX5D___vmdef_u2247)(NimStringV2* s_p0, NI s_p0Len_0, NI i_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5506)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
static N_INLINE(void, nimIncRef)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u4577)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg** dest_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vmdef_u1305)(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg** dest_p0, tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___ast_u3103)(tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug** dest_p0, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u883)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0);
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__vmdef_u1867)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw* s_p0, NI newlen_p1);
N_LIB_PRIVATE TNimTypeV2 NTIv2__FHLmhXedV9bg0OyLunsHRew_;
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_3 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_4 = {0, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_3};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_5 = { 6 | NIM_STRLIT_FLAG, "rkNone" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_6 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_5};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_7 = { 6 | NIM_STRLIT_FLAG, "rkNode" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_8 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_7};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_9 = { 5 | NIM_STRLIT_FLAG, "rkInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_10 = {5, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_9};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_11 = { 7 | NIM_STRLIT_FLAG, "rkFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_12 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_11};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_13 = { 14 | NIM_STRLIT_FLAG, "rkRegisterAddr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_14 = {14, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_13};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_15 = { 10 | NIM_STRLIT_FLAG, "rkNodeAddr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_16 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_15};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_17 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_18 = {0, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_17};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_19 = { 6 | NIM_STRLIT_FLAG, "opcEof" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_20 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_19};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_21 = { 6 | NIM_STRLIT_FLAG, "opcRet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_22 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_21};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_23 = { 10 | NIM_STRLIT_FLAG, "opcYldYoid" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_24 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_23};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_25 = { 9 | NIM_STRLIT_FLAG, "opcYldVal" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_26 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_25};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_27 = { 10 | NIM_STRLIT_FLAG, "opcAsgnInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_28 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_27};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_29 = { 12 | NIM_STRLIT_FLAG, "opcAsgnFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_30 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_29};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_31 = { 10 | NIM_STRLIT_FLAG, "opcAsgnRef" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_32 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_31};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_33 = { 14 | NIM_STRLIT_FLAG, "opcAsgnComplex" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_34 = {14, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_33};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_35 = { 19 | NIM_STRLIT_FLAG, "opcCastIntToFloat32" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_36 = {19, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_35};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_37 = { 19 | NIM_STRLIT_FLAG, "opcCastIntToFloat64" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_38 = {19, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_37};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_39 = { 19 | NIM_STRLIT_FLAG, "opcCastFloatToInt32" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_40 = {19, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_39};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_41 = { 19 | NIM_STRLIT_FLAG, "opcCastFloatToInt64" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_42 = {19, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_41};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_43 = { 15 | NIM_STRLIT_FLAG, "opcCastPtrToInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_44 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_43};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_45 = { 15 | NIM_STRLIT_FLAG, "opcCastIntToPtr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_46 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_45};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_47 = { 18 | NIM_STRLIT_FLAG, "opcFastAsgnComplex" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_48 = {18, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_47};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_49 = { 12 | NIM_STRLIT_FLAG, "opcNodeToReg" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_50 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_49};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_51 = { 8 | NIM_STRLIT_FLAG, "opcLdArr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_52 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_51};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_53 = { 12 | NIM_STRLIT_FLAG, "opcLdArrAddr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_54 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_53};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_55 = { 8 | NIM_STRLIT_FLAG, "opcWrArr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_56 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_55};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_57 = { 8 | NIM_STRLIT_FLAG, "opcLdObj" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_58 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_57};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_59 = { 12 | NIM_STRLIT_FLAG, "opcLdObjAddr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_60 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_59};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_61 = { 8 | NIM_STRLIT_FLAG, "opcWrObj" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_62 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_61};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_63 = { 10 | NIM_STRLIT_FLAG, "opcAddrReg" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_64 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_63};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_65 = { 11 | NIM_STRLIT_FLAG, "opcAddrNode" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_66 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_65};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_67 = { 10 | NIM_STRLIT_FLAG, "opcLdDeref" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_68 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_67};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_69 = { 10 | NIM_STRLIT_FLAG, "opcWrDeref" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_70 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_69};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_71 = { 11 | NIM_STRLIT_FLAG, "opcWrStrIdx" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_72 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_71};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_73 = { 11 | NIM_STRLIT_FLAG, "opcLdStrIdx" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_74 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_73};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_75 = { 15 | NIM_STRLIT_FLAG, "opcLdStrIdxAddr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_76 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_75};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_77 = { 8 | NIM_STRLIT_FLAG, "opcSlice" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_78 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_77};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_79 = { 9 | NIM_STRLIT_FLAG, "opcAddInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_80 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_79};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_81 = { 12 | NIM_STRLIT_FLAG, "opcAddImmInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_82 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_81};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_83 = { 9 | NIM_STRLIT_FLAG, "opcSubInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_84 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_83};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_85 = { 12 | NIM_STRLIT_FLAG, "opcSubImmInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_86 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_85};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_87 = { 9 | NIM_STRLIT_FLAG, "opcLenSeq" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_88 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_87};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_89 = { 9 | NIM_STRLIT_FLAG, "opcLenStr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_90 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_89};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_91 = { 13 | NIM_STRLIT_FLAG, "opcLenCstring" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_92 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_91};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_93 = { 7 | NIM_STRLIT_FLAG, "opcIncl" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_94 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_93};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_95 = { 12 | NIM_STRLIT_FLAG, "opcInclRange" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_96 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_95};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_97 = { 7 | NIM_STRLIT_FLAG, "opcExcl" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_98 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_97};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_99 = { 7 | NIM_STRLIT_FLAG, "opcCard" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_100 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_99};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_101 = { 9 | NIM_STRLIT_FLAG, "opcMulInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_102 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_101};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_103 = { 9 | NIM_STRLIT_FLAG, "opcDivInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_104 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_103};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_105 = { 9 | NIM_STRLIT_FLAG, "opcModInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_106 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_105};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_107 = { 11 | NIM_STRLIT_FLAG, "opcAddFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_108 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_107};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_109 = { 11 | NIM_STRLIT_FLAG, "opcSubFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_110 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_109};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_111 = { 11 | NIM_STRLIT_FLAG, "opcMulFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_112 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_111};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_113 = { 11 | NIM_STRLIT_FLAG, "opcDivFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_114 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_113};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_115 = { 9 | NIM_STRLIT_FLAG, "opcShrInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_116 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_115};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_117 = { 9 | NIM_STRLIT_FLAG, "opcShlInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_118 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_117};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_119 = { 10 | NIM_STRLIT_FLAG, "opcAshrInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_120 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_119};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_121 = { 12 | NIM_STRLIT_FLAG, "opcBitandInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_122 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_121};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_123 = { 11 | NIM_STRLIT_FLAG, "opcBitorInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_124 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_123};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_125 = { 12 | NIM_STRLIT_FLAG, "opcBitxorInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_126 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_125};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_127 = { 7 | NIM_STRLIT_FLAG, "opcAddu" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_128 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_127};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_129 = { 7 | NIM_STRLIT_FLAG, "opcSubu" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_130 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_129};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_131 = { 7 | NIM_STRLIT_FLAG, "opcMulu" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_132 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_131};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_133 = { 7 | NIM_STRLIT_FLAG, "opcDivu" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_134 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_133};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_135 = { 7 | NIM_STRLIT_FLAG, "opcModu" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_136 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_135};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_137 = { 8 | NIM_STRLIT_FLAG, "opcEqInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_138 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_137};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_139 = { 8 | NIM_STRLIT_FLAG, "opcLeInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_140 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_139};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_141 = { 8 | NIM_STRLIT_FLAG, "opcLtInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_142 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_141};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_143 = { 10 | NIM_STRLIT_FLAG, "opcEqFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_144 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_143};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_145 = { 10 | NIM_STRLIT_FLAG, "opcLeFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_146 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_145};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_147 = { 10 | NIM_STRLIT_FLAG, "opcLtFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_148 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_147};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_149 = { 6 | NIM_STRLIT_FLAG, "opcLeu" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_150 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_149};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_151 = { 6 | NIM_STRLIT_FLAG, "opcLtu" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_152 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_151};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_153 = { 8 | NIM_STRLIT_FLAG, "opcEqRef" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_154 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_153};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_155 = { 12 | NIM_STRLIT_FLAG, "opcEqNimNode" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_156 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_155};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_157 = { 15 | NIM_STRLIT_FLAG, "opcSameNodeType" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_158 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_157};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_159 = { 6 | NIM_STRLIT_FLAG, "opcXor" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_160 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_159};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_161 = { 6 | NIM_STRLIT_FLAG, "opcNot" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_162 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_161};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_163 = { 16 | NIM_STRLIT_FLAG, "opcUnaryMinusInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_164 = {16, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_163};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_165 = { 18 | NIM_STRLIT_FLAG, "opcUnaryMinusFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_166 = {18, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_165};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_167 = { 12 | NIM_STRLIT_FLAG, "opcBitnotInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_168 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_167};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_169 = { 8 | NIM_STRLIT_FLAG, "opcEqStr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_170 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_169};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_171 = { 12 | NIM_STRLIT_FLAG, "opcEqCString" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_172 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_171};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_173 = { 8 | NIM_STRLIT_FLAG, "opcLeStr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_174 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_173};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_175 = { 8 | NIM_STRLIT_FLAG, "opcLtStr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_176 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_175};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_177 = { 8 | NIM_STRLIT_FLAG, "opcEqSet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_178 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_177};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_179 = { 8 | NIM_STRLIT_FLAG, "opcLeSet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_180 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_179};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_181 = { 8 | NIM_STRLIT_FLAG, "opcLtSet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_182 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_181};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_183 = { 9 | NIM_STRLIT_FLAG, "opcMulSet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_184 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_183};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_185 = { 10 | NIM_STRLIT_FLAG, "opcPlusSet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_186 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_185};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_187 = { 11 | NIM_STRLIT_FLAG, "opcMinusSet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_188 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_187};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_189 = { 9 | NIM_STRLIT_FLAG, "opcXorSet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_190 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_189};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_191 = { 12 | NIM_STRLIT_FLAG, "opcConcatStr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_192 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_191};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_193 = { 14 | NIM_STRLIT_FLAG, "opcContainsSet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_194 = {14, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_193};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_195 = { 7 | NIM_STRLIT_FLAG, "opcRepr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_196 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_195};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_197 = { 12 | NIM_STRLIT_FLAG, "opcSetLenStr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_198 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_197};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_199 = { 12 | NIM_STRLIT_FLAG, "opcSetLenSeq" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_200 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_199};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_201 = { 8 | NIM_STRLIT_FLAG, "opcIsNil" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_202 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_201};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_203 = { 5 | NIM_STRLIT_FLAG, "opcOf" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_204 = {5, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_203};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_205 = { 5 | NIM_STRLIT_FLAG, "opcIs" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_206 = {5, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_205};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_207 = { 13 | NIM_STRLIT_FLAG, "opcParseFloat" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_208 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_207};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_209 = { 7 | NIM_STRLIT_FLAG, "opcConv" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_210 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_209};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_211 = { 7 | NIM_STRLIT_FLAG, "opcCast" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_212 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_211};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_213 = { 7 | NIM_STRLIT_FLAG, "opcQuit" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_214 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_213};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_215 = { 15 | NIM_STRLIT_FLAG, "opcInvalidField" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_216 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_215};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_217 = { 10 | NIM_STRLIT_FLAG, "opcNarrowS" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_218 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_217};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_219 = { 10 | NIM_STRLIT_FLAG, "opcNarrowU" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_220 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_219};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_221 = { 10 | NIM_STRLIT_FLAG, "opcNarrowR" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_222 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_221};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_223 = { 13 | NIM_STRLIT_FLAG, "opcSignExtend" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_224 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_223};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_225 = { 11 | NIM_STRLIT_FLAG, "opcAddStrCh" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_226 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_225};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_227 = { 12 | NIM_STRLIT_FLAG, "opcAddStrStr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_228 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_227};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_229 = { 13 | NIM_STRLIT_FLAG, "opcAddSeqElem" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_230 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_229};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_231 = { 12 | NIM_STRLIT_FLAG, "opcRangeChck" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_232 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_231};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_233 = { 7 | NIM_STRLIT_FLAG, "opcNAdd" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_234 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_233};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_235 = { 15 | NIM_STRLIT_FLAG, "opcNAddMultiple" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_236 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_235};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_237 = { 8 | NIM_STRLIT_FLAG, "opcNKind" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_238 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_237};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_239 = { 11 | NIM_STRLIT_FLAG, "opcNSymKind" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_240 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_239};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_241 = { 10 | NIM_STRLIT_FLAG, "opcNIntVal" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_242 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_241};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_243 = { 12 | NIM_STRLIT_FLAG, "opcNFloatVal" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_244 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_243};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_245 = { 10 | NIM_STRLIT_FLAG, "opcNSymbol" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_246 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_245};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_247 = { 9 | NIM_STRLIT_FLAG, "opcNIdent" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_248 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_247};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_249 = { 11 | NIM_STRLIT_FLAG, "opcNGetType" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_250 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_249};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_251 = { 10 | NIM_STRLIT_FLAG, "opcNStrVal" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_252 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_251};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_253 = { 11 | NIM_STRLIT_FLAG, "opcNSigHash" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_254 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_253};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_255 = { 11 | NIM_STRLIT_FLAG, "opcNGetSize" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_256 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_255};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_257 = { 13 | NIM_STRLIT_FLAG, "opcNSetIntVal" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_258 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_257};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_259 = { 15 | NIM_STRLIT_FLAG, "opcNSetFloatVal" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_260 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_259};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_261 = { 13 | NIM_STRLIT_FLAG, "opcNSetSymbol" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_262 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_261};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_263 = { 12 | NIM_STRLIT_FLAG, "opcNSetIdent" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_264 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_263};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_265 = { 13 | NIM_STRLIT_FLAG, "opcNSetStrVal" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_266 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_265};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_267 = { 14 | NIM_STRLIT_FLAG, "opcNNewNimNode" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_268 = {14, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_267};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_269 = { 15 | NIM_STRLIT_FLAG, "opcNCopyNimNode" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_270 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_269};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_271 = { 15 | NIM_STRLIT_FLAG, "opcNCopyNimTree" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_272 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_271};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_273 = { 7 | NIM_STRLIT_FLAG, "opcNDel" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_274 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_273};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_275 = { 9 | NIM_STRLIT_FLAG, "opcGenSym" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_276 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_275};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_277 = { 11 | NIM_STRLIT_FLAG, "opcNccValue" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_278 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_277};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_279 = { 9 | NIM_STRLIT_FLAG, "opcNccInc" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_280 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_279};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_281 = { 9 | NIM_STRLIT_FLAG, "opcNcsAdd" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_282 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_281};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_283 = { 10 | NIM_STRLIT_FLAG, "opcNcsIncl" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_284 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_283};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_285 = { 9 | NIM_STRLIT_FLAG, "opcNcsLen" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_286 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_285};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_287 = { 8 | NIM_STRLIT_FLAG, "opcNcsAt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_288 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_287};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_289 = { 9 | NIM_STRLIT_FLAG, "opcNctPut" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_290 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_289};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_291 = { 9 | NIM_STRLIT_FLAG, "opcNctLen" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_292 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_291};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_293 = { 9 | NIM_STRLIT_FLAG, "opcNctGet" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_294 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_293};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_295 = { 13 | NIM_STRLIT_FLAG, "opcNctHasNext" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_296 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_295};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_297 = { 10 | NIM_STRLIT_FLAG, "opcNctNext" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_298 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_297};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_299 = { 9 | NIM_STRLIT_FLAG, "opcNodeId" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_300 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_299};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_301 = { 8 | NIM_STRLIT_FLAG, "opcSlurp" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_302 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_301};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_303 = { 8 | NIM_STRLIT_FLAG, "opcGorge" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_304 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_303};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_305 = { 17 | NIM_STRLIT_FLAG, "opcParseExprToAst" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_306 = {17, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_305};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_307 = { 17 | NIM_STRLIT_FLAG, "opcParseStmtToAst" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_308 = {17, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_307};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_309 = { 17 | NIM_STRLIT_FLAG, "opcQueryErrorFlag" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_310 = {17, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_309};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_311 = { 9 | NIM_STRLIT_FLAG, "opcNError" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_312 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_311};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_313 = { 11 | NIM_STRLIT_FLAG, "opcNWarning" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_314 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_313};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_315 = { 8 | NIM_STRLIT_FLAG, "opcNHint" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_316 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_315};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_317 = { 15 | NIM_STRLIT_FLAG, "opcNGetLineInfo" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_318 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_317};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_319 = { 16 | NIM_STRLIT_FLAG, "opcNCopyLineInfo" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_320 = {16, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_319};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_321 = { 19 | NIM_STRLIT_FLAG, "opcNSetLineInfoLine" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_322 = {19, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_321};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_323 = { 21 | NIM_STRLIT_FLAG, "opcNSetLineInfoColumn" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_324 = {21, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_323};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_325 = { 19 | NIM_STRLIT_FLAG, "opcNSetLineInfoFile" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_326 = {19, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_325};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_327 = { 10 | NIM_STRLIT_FLAG, "opcEqIdent" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_328 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_327};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_329 = { 13 | NIM_STRLIT_FLAG, "opcStrToIdent" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_330 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_329};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_331 = { 10 | NIM_STRLIT_FLAG, "opcGetImpl" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_332 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_331};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_333 = { 16 | NIM_STRLIT_FLAG, "opcGetImplTransf" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_334 = {16, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_333};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_335 = { 7 | NIM_STRLIT_FLAG, "opcEcho" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_336 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_335};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_337 = { 10 | NIM_STRLIT_FLAG, "opcIndCall" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_338 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_337};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_339 = { 14 | NIM_STRLIT_FLAG, "opcIndCallAsgn" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_340 = {14, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_339};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_341 = { 8 | NIM_STRLIT_FLAG, "opcRaise" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_342 = {8, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_341};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_343 = { 9 | NIM_STRLIT_FLAG, "opcNChild" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_344 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_343};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_345 = { 12 | NIM_STRLIT_FLAG, "opcNSetChild" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_346 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_345};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_347 = { 11 | NIM_STRLIT_FLAG, "opcCallSite" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_348 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_347};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_349 = { 9 | NIM_STRLIT_FLAG, "opcNewStr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_350 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_349};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_351 = { 7 | NIM_STRLIT_FLAG, "opcTJmp" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_352 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_351};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_353 = { 7 | NIM_STRLIT_FLAG, "opcFJmp" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_354 = {7, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_353};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_355 = { 6 | NIM_STRLIT_FLAG, "opcJmp" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_356 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_355};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_357 = { 10 | NIM_STRLIT_FLAG, "opcJmpBack" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_358 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_357};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_359 = { 9 | NIM_STRLIT_FLAG, "opcBranch" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_360 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_359};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_361 = { 6 | NIM_STRLIT_FLAG, "opcTry" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_362 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_361};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_363 = { 9 | NIM_STRLIT_FLAG, "opcExcept" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_364 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_363};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_365 = { 10 | NIM_STRLIT_FLAG, "opcFinally" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_366 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_365};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_367 = { 13 | NIM_STRLIT_FLAG, "opcFinallyEnd" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_368 = {13, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_367};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_369 = { 6 | NIM_STRLIT_FLAG, "opcNew" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_370 = {6, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_369};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_371 = { 9 | NIM_STRLIT_FLAG, "opcNewSeq" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_372 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_371};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_373 = { 9 | NIM_STRLIT_FLAG, "opcLdNull" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_374 = {9, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_373};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_375 = { 12 | NIM_STRLIT_FLAG, "opcLdNullReg" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_376 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_375};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_377 = { 10 | NIM_STRLIT_FLAG, "opcLdConst" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_378 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_377};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_379 = { 12 | NIM_STRLIT_FLAG, "opcAsgnConst" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_380 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_379};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_381 = { 11 | NIM_STRLIT_FLAG, "opcLdGlobal" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_382 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_381};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_383 = { 15 | NIM_STRLIT_FLAG, "opcLdGlobalAddr" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_384 = {15, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_383};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_385 = { 19 | NIM_STRLIT_FLAG, "opcLdGlobalDerefFFI" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_386 = {19, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_385};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_387 = { 23 | NIM_STRLIT_FLAG, "opcLdGlobalAddrDerefFFI" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_388 = {23, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_387};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_389 = { 11 | NIM_STRLIT_FLAG, "opcLdImmInt" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_390 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_389};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_391 = { 11 | NIM_STRLIT_FLAG, "opcNBindSym" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_392 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_391};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_393 = { 14 | NIM_STRLIT_FLAG, "opcNDynBindSym" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_394 = {14, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_393};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_395 = { 10 | NIM_STRLIT_FLAG, "opcSetType" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_396 = {10, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_395};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_397 = { 12 | NIM_STRLIT_FLAG, "opcTypeTrait" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_398 = {12, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_397};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_399 = { 11 | NIM_STRLIT_FLAG, "opcSymOwner" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_400 = {11, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_399};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__LKTmeQxNOMAggl6ESLJFSg_401 = { 23 | NIM_STRLIT_FLAG, "opcSymIsInstantiationOf" };
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_402 = {23, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_401};
static const NimStringV2 TM__LKTmeQxNOMAggl6ESLJFSg_403 = {0, (NimStrPayload*)&TM__LKTmeQxNOMAggl6ESLJFSg_17};
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
N_LIB_PRIVATE NIM_CONST tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg NoVmProcInfo__vmdef_u382 = {((NI32)0), ((NI32)-1)}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static NIM_CONST NU32 TM__LKTmeQxNOMAggl6ESLJFSg_2[3] = {3701606400, 62025216, 1927709952};
N_LIB_PRIVATE TNimTypeV2 NTIv2__FHLmhXedV9bg0OyLunsHRew_ = {.destructor = (void*)rttiDestroy__vmdef_u3600, .size = sizeof(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew), .align = (NI16) NIM_ALIGNOF(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew), .depth = 2, .display = TM__LKTmeQxNOMAggl6ESLJFSg_2, .traceImpl = (void*)eqtrace___vmdef_u1551, .flags = 0};
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		{
			if (!result) goto LA13_;
			{
				if (!(((NI)0) < (*cell_1).rootIdx)) goto LA17_;
				unregisterCycle__system_u3127(cell_1);
			}
LA17_: ;
		}
LA13_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1844)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			{
				NIM_BOOL T6_;
				T6_ = (NIM_BOOL)0;
				T6_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field0);
				if (!T6_) goto LA7_;
				eqdestroy___ast_u3469((&(*dest_p0.p->data[colontmp_].Field0)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field0, ((NI)8));
			}
LA7_: ;
			{
				NIM_BOOL T11_;
				T11_ = (NIM_BOOL)0;
				T11_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].Field1);
				if (!T11_) goto LA12_;
				eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].Field1)));
				nimRawDispose(dest_p0.p->data[colontmp_].Field1, ((NI)8));
			}
LA12_: ;
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ));
}
}
static N_INLINE(NIM_BOOL, nimDecRefIsLast)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((NI64)((*cell_1).rc) >> (NU64)(((NI)4) & (64 - 1))) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1620)(tySequence__9c9aWmheGsuf9aHtY7gTnUcPA dest_p0) {
	NI colontmp_;
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T3_;
			T3_ = dest_p0.len;
			if (!(colontmp_ < T3_)) goto LA2;
			switch (dest_p0.p->data[colontmp_].kind) {
			case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
			{
			}
			break;
			case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
			{
			}
			break;
			case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
			{
			}
			break;
			case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
			{
				{
					NIM_BOOL T10_;
					T10_ = (NIM_BOOL)0;
					T10_ = nimDecRefIsLastDyn(dest_p0.p->data[colontmp_].node);
					if (!T10_) goto LA11_;
					eqdestroy___ast_u3270((&(*dest_p0.p->data[colontmp_].node)));
					nimRawDispose(dest_p0.p->data[colontmp_].node, ((NI)8));
				}
LA11_: ;
			}
			break;
			case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
			{
			}
			break;
			case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
			{
			}
			break;
			default: __builtin_unreachable();
			}
			colontmp_ += ((NI)1);
		} LA2: ;
	}
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1600)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* dest_p0) {
	eqdestroy___pureZosproc_u474((*dest_p0).safePoints);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).next);
		if (!T3_) goto LA4_;
		eqdestroy___vmdef_u1600((&(*(*dest_p0).next)));
		nimRawDispose((*dest_p0).next, ((NI)8));
	}
LA4_: ;
	eqdestroy___vmdef_u1620((*dest_p0).slots);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn((*dest_p0).prc);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3469((&(*(*dest_p0).prc)));
		nimRawDispose((*dest_p0).prc, ((NI)8));
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1186)(tySequence__grdS5PdBBxkq9bxi4lFAdAw dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(tyTuple__9ap1MJ9bVBlP34AqrUq01n8w));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u883)(tySequence__qwqHTkRvwhrRyENtudHQ7g dest_p0) {
	if (dest_p0.p && !(dest_p0.p->cap & NIM_STRLIT_FLAG)) {
 alignedDealloc(dest_p0.p, NIM_ALIGNOF(NI));
}
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1165)(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* dest_p0) {
	eqdestroy___vmdef_u1186((*dest_p0).regInfo);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).sym);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*(*dest_p0).sym)));
		nimRawDispose((*dest_p0).sym, ((NI)8));
	}
LA4_: ;
	eqdestroy___vmdef_u862((*dest_p0).blocks);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1539)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* dest_p0) {
	eqdestroy___pureZcollectionsZintsets_u100((*dest_p0).locals.data);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).locals.head);
		if (!T3_) goto LA4_;
		eqdestroy___pureZcollectionsZintsets_u66((&(*(*dest_p0).locals.head)));
		nimRawDispose((*dest_p0).locals.head, ((NI)8));
	}
LA4_: ;
	eqdestroy___vmdef_u2010((*dest_p0).procToCodePos.data);
	eqdestroy___vmdef_u1844((*dest_p0).vmstateDiff);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLast((*dest_p0).templInstCounter);
		if (!T8_) goto LA9_;
		eqdestroy___system_u8092((*(*dest_p0).templInstCounter));
		nimRawDispose((*dest_p0).templInstCounter, ((NI)8));
	}
LA9_: ;
	{
		NIM_BOOL T13_;
		T13_ = (NIM_BOOL)0;
		T13_ = nimDecRefIsLastDyn((*dest_p0).profiler.tos);
		if (!T13_) goto LA14_;
		eqdestroy___vmdef_u1600((&(*(*dest_p0).profiler.tos)));
		nimRawDispose((*dest_p0).profiler.tos, ((NI)8));
	}
LA14_: ;
	{
		NIM_BOOL T18_;
		T18_ = (NIM_BOOL)0;
		T18_ = nimDecRefIsLastDyn((*dest_p0).graph);
		if (!T18_) goto LA19_;
		eqdestroy___modulegraphs_u13532((&(*(*dest_p0).graph)));
		nimRawDispose((*dest_p0).graph, ((NI)8));
	}
LA19_: ;
	{
		NIM_BOOL T23_;
		T23_ = (NIM_BOOL)0;
		T23_ = nimDecRefIsLastDyn((*dest_p0).config);
		if (!T23_) goto LA24_;
		eqdestroy___options_u1751((&(*(*dest_p0).config)));
		nimRawDispose((*dest_p0).config, ((NI)8));
	}
LA24_: ;
	{
		NIM_BOOL T28_;
		T28_ = (NIM_BOOL)0;
		T28_ = nimDecRefIsLast((*dest_p0).cache);
		if (!T28_) goto LA29_;
		eqdestroy___idents_u274((&(*(*dest_p0).cache)));
		nimRawDispose((*dest_p0).cache, ((NI)8));
	}
LA29_: ;
	eqdestroy___system_u2691((*dest_p0).errorFlag);
	eqdestroy___vmdef_u577((*dest_p0).callbackIndex.data);
	eqdestroy___vmdef_u1321((*dest_p0).callbacks);
	{
		NIM_BOOL T33_;
		T33_ = (NIM_BOOL)0;
		T33_ = nimDecRefIsLastDyn((*dest_p0).callsite);
		if (!T33_) goto LA34_;
		eqdestroy___ast_u3270((&(*(*dest_p0).callsite)));
		nimRawDispose((*dest_p0).callsite, ((NI)8));
	}
LA34_: ;
	{
		NIM_BOOL T38_;
		T38_ = (NIM_BOOL)0;
		T38_ = nimDecRefIsLastDyn((*dest_p0).module);
		if (!T38_) goto LA39_;
		eqdestroy___ast_u3469((&(*(*dest_p0).module)));
		nimRawDispose((*dest_p0).module, ((NI)8));
	}
LA39_: ;
	{
		NIM_BOOL T43_;
		T43_ = (NIM_BOOL)0;
		T43_ = nimDecRefIsLast((*dest_p0).prc);
		if (!T43_) goto LA44_;
		eqdestroy___vmdef_u1165((&(*(*dest_p0).prc)));
		nimRawDispose((*dest_p0).prc, ((NI)8));
	}
LA44_: ;
	{
		NIM_BOOL T48_;
		T48_ = (NIM_BOOL)0;
		T48_ = nimDecRefIsLastDyn((*dest_p0).currentExceptionB);
		if (!T48_) goto LA49_;
		eqdestroy___ast_u3270((&(*(*dest_p0).currentExceptionB)));
		nimRawDispose((*dest_p0).currentExceptionB, ((NI)8));
	}
LA49_: ;
	{
		NIM_BOOL T53_;
		T53_ = (NIM_BOOL)0;
		T53_ = nimDecRefIsLastDyn((*dest_p0).currentExceptionA);
		if (!T53_) goto LA54_;
		eqdestroy___ast_u3270((&(*(*dest_p0).currentExceptionA)));
		nimRawDispose((*dest_p0).currentExceptionA, ((NI)8));
	}
LA54_: ;
	eqdestroy___ast_u3311((*dest_p0).types);
	eqdestroy___ast_u6548((*dest_p0).contstantTab.data);
	{
		NIM_BOOL T58_;
		T58_ = (NIM_BOOL)0;
		T58_ = nimDecRefIsLastDyn((*dest_p0).constants);
		if (!T58_) goto LA59_;
		eqdestroy___ast_u3270((&(*(*dest_p0).constants)));
		nimRawDispose((*dest_p0).constants, ((NI)8));
	}
LA59_: ;
	{
		NIM_BOOL T63_;
		T63_ = (NIM_BOOL)0;
		T63_ = nimDecRefIsLastDyn((*dest_p0).globals);
		if (!T63_) goto LA64_;
		eqdestroy___ast_u3270((&(*(*dest_p0).globals)));
		nimRawDispose((*dest_p0).globals, ((NI)8));
	}
LA64_: ;
	eqdestroy___vmdef_u741((*dest_p0).debug);
	eqdestroy___vmdef_u620((*dest_p0).code);
	{
		NIM_BOOL T68_;
		T68_ = (NIM_BOOL)0;
		T68_ = nimDecRefIsLast((*dest_p0).Sup.idgen);
		if (!T68_) goto LA69_;
		eqdestroy___ast_u3074((&(*(*dest_p0).Sup.idgen)));
		nimRawDispose((*dest_p0).Sup.idgen, ((NI)8));
	}
LA69_: ;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__vmdef_u3600)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___vmdef_u1539((&(*((tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___vmdef_u1551)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* dest_p0, void* env_p1) {
	eqtrace___vmdef_u1333((&(*dest_p0).callbacks), env_p1);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*, newCtx__vmdef_u383)(tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p0, tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* cache_p1, tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* g_p2, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p3) {
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* result;
	tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* colontmpD_;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD__2;
	tyObject_IdentCachecolonObjectType___ieLwK4T49bbUIZTTVH9cycZA* colontmpD__3;
	tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* colontmpD__4;
	tyObject_ModuleGraphcolonObjectType___TuJBn0NOJllZfOUYECIyKw* colontmpD__5;
	tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* colontmpD__6;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* T1_;
	tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*) nimNewObj(sizeof(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew), NIM_ALIGNOF(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew));
	(*T1_).Sup.Sup.m_type = (&NTIv2__FHLmhXedV9bg0OyLunsHRew_);
	(*T1_).code.len = 0; (*T1_).code.p = (tySequence__YdLNCDKYeipzJx3I8Xw82Q_Content*) newSeqPayload(0, sizeof(NU64), NIM_ALIGNOF(NU64));
	(*T1_).debug.len = 0; (*T1_).debug.p = (tySequence__TLbZ2GqL3Zio1f8bNpj2NA_Content*) newSeqPayload(0, sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA), NIM_ALIGNOF(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
	(*T1_).globals = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)126));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).constants = newNode__ast_u4069(((tyEnum_TNodeKind__eZrq5BxQzEyOryCcwdj4Kw)115));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).types.len = 0; (*T1_).types.p = (tySequence__d8ZV4IMgHt9biik9cS9a0hrmg_Content*) newSeqPayload(0, sizeof(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*), NIM_ALIGNOF(tyObject_TType__8qAQZfpTDk89aeclTNn4d9cg*));
	T2_ = NIM_NIL;
	T2_ = (tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg*) nimNewObj(sizeof(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg), NIM_ALIGNOF(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg));
	(*T2_).blocks.len = 0; (*T2_).blocks.p = (tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content*) newSeqPayload(0, sizeof(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA), NIM_ALIGNOF(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA));
	(*T1_).prc = T2_;
	colontmpD_ = eqdup___ast_u4580(module_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).module = colontmpD_;
	(*T1_).loopIterations = (*(*g_p2).config).maxLoopIterationsVM;
	(*T1_).callDepth = (*(*g_p2).config).maxCallDepthVM;
	colontmpD__2 = eqdup___lineinfos_u2037(unknownLineInfo__lineinfos_u364);
	(*T1_).comesFromHeuristic = colontmpD__2;
	(*T1_).callbacks.len = 0; (*T1_).callbacks.p = (tySequence__TEgqV1E9aHqnwBUoeXjBI9aA_Content*) newSeqPayload(0, sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw), NIM_ALIGNOF(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	(*T1_).callbackIndex = initTable__vmdef_u421(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).errorFlag = TM__LKTmeQxNOMAggl6ESLJFSg_4;
	colontmpD__3 = eqdup___idents_u344(cache_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).cache = colontmpD__3;
	colontmpD__4 = eqdup___options_u2141((*g_p2).config);
	(*T1_).config = colontmpD__4;
	colontmpD__5 = eqdup___modulegraphs_u14759(g_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).graph = colontmpD__5;
	colontmpD__6 = eqdup___ast_u3106(idgen_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*T1_).Sup.idgen = colontmpD__6;
	initNodeTable__ast_u6397(NIM_TRUE, (&(*T1_).contstantTab));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = T1_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u2206)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0);
	}
LA4_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, nimIncRefCyclic)(void* p_p0, NIM_BOOL cyclic_p1) {
	tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* h_1;
	NI T1_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	h_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_));
	(*h_1).rc = pluspercent___system_u785((*h_1).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u2209)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew** dest_p0, tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* src_p1, NIM_BOOL cyclic_p2) {
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* colontmp_;
	colontmp_ = (*dest_p0);
	{
		if (!src_p1) goto LA3_;
		nimIncRefCyclic(src_p1, cyclic_p2);
	}
LA3_: ;
	(*dest_p0) = src_p1;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T7_) goto LA8_;
		nimDestroyAndDispose(colontmp_);
	}
LA8_: ;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdup___vmdef_u1392)(tyProc__c9bXGQkBnyyGGVw063jrwZw src_p0, NIM_BOOL cyclic_p1, tyProc__c9bXGQkBnyyGGVw063jrwZw* Result) {
	void* colontmp_;
	nimZeroMem((void*)Result, sizeof(tyProc__c9bXGQkBnyyGGVw063jrwZw));
	colontmp_ = (*Result).ClE_0;
	(*Result).ClE_0 = src_p0.ClE_0;
	(*Result).ClP_0 = src_p0.ClP_0;
	{
		if (!src_p0.ClE_0) goto LA3_;
		nimIncRefCyclic(src_p0.ClE_0, cyclic_p1);
	}
LA3_: ;
}
static N_INLINE(NimStringV2, X5BX5D___vmdef_u2247)(NimStringV2* s_p0, NI s_p0Len_0, NI i_p1) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), s_p0[(NI)(s_p0Len_0 - i_p1)]);
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, reverseName__vmdef_u2235)(NimStringV2 s_p0) {
	NimStringV2 result;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ y_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	y_1.len = 0; y_1.p = NIM_NIL;
	result = rawNewString((s_p0.len));
	y_1 = nsuSplitChar(s_p0, 46, ((NI)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = y_1.len;
		colontmp_ = T2_;
		res_1 = ((NI)1);
		{
			while (1) {
				NimStringV2 colontmpD_;
				if (!(res_1 <= colontmp_)) goto LA4;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				i_1 = ((NI) (res_1));
				colontmpD_ = X5BX5D___vmdef_u2247(((y_1).p) ? (y_1.p->data) : NIM_NIL, y_1.len, i_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
				{
					NI T7_;
					T7_ = y_1.len;
					if (!!((i_1 == T7_))) goto LA8_;
					nimAddCharV1((&result), 46);
				}
LA8_: ;
				res_1 += ((NI)1);
				eqdestroy___system_u2691(colontmpD_);
			} LA4: ;
		}
	}
	eqdestroy___system_u5506(y_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, registerCallback__vmdef_u2258)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, NimStringV2 name_p1, tyProc__c9bXGQkBnyyGGVw063jrwZw callback_p2) {
	NI result;
	tyProc__c9bXGQkBnyyGGVw063jrwZw colontmpD_;
	NimStringV2 colontmpD__2;
	NI T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T1_ = (*c_p0).callbacks.len;
	result = T1_;
	eqdup___vmdef_u1392(callback_p2, NIM_TRUE, (&colontmpD_));
	add__vmdef_u2266((&(*c_p0).callbacks), colontmpD_);
	colontmpD__2 = reverseName__vmdef_u2235(name_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	X5BX5Deq___vmdef_u2322((&(*c_p0).callbackIndex), colontmpD__2, result);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD__2);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vmdef_u1715)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch ((*dest_p0).kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		(*dest_p0).intVal = 0;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		(*dest_p0).floatVal = 0;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = nimDecRefIsLastDyn((*dest_p0).node);
			if (!T7_) goto LA8_;
			eqdestroy___ast_u3270((&(*(*dest_p0).node)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimZeroMem((void*)(&(*(*dest_p0).node)), sizeof(tyObject_TNode__eTSqWXWVL7LuzmZf0c6unQ));
			nimRawDispose((*dest_p0).node, ((NI)8));
		}
LA8_: ;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		(*dest_p0).regAddr = 0;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		(*dest_p0).nodeAddr = 0;
	}
	break;
	default: __builtin_unreachable();
	}
	(*dest_p0).kind = 0;
	(*dest_p0).kind = src_p1.kind;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		(*dest_p0).intVal = src_p1.intVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		(*dest_p0).floatVal = src_p1.floatVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		(*dest_p0).node = src_p1.node;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		(*dest_p0).regAddr = src_p1.regAddr;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		(*dest_p0).nodeAddr = src_p1.nodeAddr;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___vmdef_u304)(tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_6;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_8;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_10;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_12;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_14;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_16;
	}
	break;
	default:
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_18;
	}
	break;
	}
	return result;
}
static N_INLINE(void, nimIncRef)(void* p_p0) {
	NI T1_;
	NI T2_;
	T1_ = (NI)0;
	T1_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	T2_ = (NI)0;
	T2_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
	(*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T1_))).rc = pluspercent___system_u785((*((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T2_))).rc, ((NI)16));
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmprofiler_u22)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ** dest_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___vmdef_u1600((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmprofiler_u19)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___vmdef_u1600((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vmdef_u1305)(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg** dest_p0, tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___vmdef_u1165((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, refresh__vmdef_u2227)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* c_p0, tyObject_TSym__lYFc3T7YHHNBnaZR9at0NSg* module_p1, tyObject_IdGeneratorcolonObjectType___G9bSmxY5z1At9bXNKpE9bKuug* idgen_p2) {
	tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqcopy___ast_u4577(&(*c_p0).module, module_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T1_ = NIM_NIL;
	T1_ = (tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg*) nimNewObj(sizeof(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg), NIM_ALIGNOF(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg));
	(*T1_).blocks.len = 0; (*T1_).blocks.p = (tySequence__b9bG03Q6unwlMU0dM7uOPIA_Content*) newSeqPayload(0, sizeof(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA), NIM_ALIGNOF(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA));
	eqsink___vmdef_u1305(&(*c_p0).prc, T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	(*c_p0).loopIterations = (*(*c_p0).config).maxLoopIterationsVM;
	(*c_p0).callDepth = (*(*c_p0).config).maxCallDepthVM;
	eqcopy___ast_u3103(&(*c_p0).Sup.idgen, idgen_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vm_u14430)(NI** dest_p0, NI* src_p1) {
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLast((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___system_u8092((*(*dest_p0)));
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u3574)(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg* dest_p0) {
	(*dest_p0).pc = 0;
	(*dest_p0).usedRegisters = 0;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg, eqdup___vmdef_u3583)(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg src_p0) {
	tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg result;
	nimZeroMem((void*)(&result), sizeof(tyObject_VmProcInfo__Jux30icZSrOlvcFTG81Ljg));
	result.pc = src_p0.pc;
	result.usedRegisters = src_p0.usedRegisters;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u1299)(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg** dest_p0, tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!src_p1) goto LA3_;
		nimIncRef(src_p1);
	}
LA3_: ;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLast((*dest_p0));
		if (!T7_) goto LA8_;
		eqdestroy___vmdef_u1165((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA8_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u1293)(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1296)(tyObject_PProccolonObjectType___BUXHs9a6Ck9awUko3NbJ3Fyg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___vmdef_u1165((&(*dest_p0)));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1031)(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA dest_p0) {
	eqdestroy___vmdef_u883(dest_p0.fixups);
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.label);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.label)));
		nimRawDispose(dest_p0.label, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u1028)(tyObject_TBlock__jSiqQOXIz3L9a8VW9a9a3HAuA* dest_p0) {
	(*dest_p0).label = 0;
	(*dest_p0).fixups.len = 0; (*dest_p0).fixups.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1706)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A dest_p0) {
	switch (dest_p0.kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		{
			NIM_BOOL T7_;
			T7_ = (NIM_BOOL)0;
			T7_ = nimDecRefIsLastDyn(dest_p0.node);
			if (!T7_) goto LA8_;
			eqdestroy___ast_u3270((&(*dest_p0.node)));
			nimRawDispose(dest_p0.node, ((NI)8));
		}
LA8_: ;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
	}
	break;
	default: __builtin_unreachable();
	}
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u1703)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0) {
	(*dest_p0).kind = 0;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		(*dest_p0).intVal = 0;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		(*dest_p0).floatVal = 0;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		(*dest_p0).node = 0;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		(*dest_p0).regAddr = 0;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		(*dest_p0).nodeAddr = 0;
	}
	break;
	default: __builtin_unreachable();
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___vmdef_u267)(tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)0):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_20;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)1):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_22;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)2):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_24;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)3):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_26;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)4):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_28;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)5):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_30;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)6):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_32;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)7):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_34;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)8):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_36;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)9):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_38;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)10):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_40;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)11):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_42;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)12):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_44;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)13):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_46;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)14):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_48;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)15):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_50;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)16):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_52;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)17):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_54;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)18):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_56;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)19):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_58;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)20):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_60;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)21):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_62;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)22):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_64;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)23):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_66;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)24):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_68;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)25):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_70;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)26):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_72;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)27):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_74;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)28):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_76;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)29):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_78;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)30):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_80;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)31):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_82;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)32):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_84;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)33):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_86;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)34):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_88;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)35):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_90;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)36):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_92;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)37):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_94;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)38):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_96;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)39):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_98;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)40):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_100;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)41):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_102;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)42):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_104;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)43):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_106;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)44):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_108;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)45):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_110;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)46):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_112;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)47):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_114;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)48):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_116;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)49):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_118;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)50):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_120;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)51):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_122;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)52):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_124;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)53):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_126;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)54):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_128;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)55):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_130;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)56):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_132;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)57):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_134;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)58):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_136;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)59):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_138;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)60):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_140;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)61):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_142;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)62):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_144;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)63):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_146;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)64):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_148;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)65):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_150;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)66):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_152;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)67):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_154;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)68):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_156;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)69):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_158;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)70):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_160;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)71):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_162;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)72):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_164;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)73):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_166;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)74):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_168;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)75):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_170;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)76):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_172;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)77):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_174;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)78):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_176;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)79):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_178;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)80):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_180;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)81):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_182;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)82):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_184;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)83):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_186;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)84):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_188;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)85):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_190;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)86):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_192;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)87):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_194;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)88):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_196;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)89):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_198;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)90):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_200;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)91):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_202;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)92):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_204;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)93):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_206;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)94):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_208;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)95):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_210;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)96):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_212;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)97):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_214;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)98):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_216;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)99):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_218;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)100):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_220;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)101):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_222;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)102):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_224;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)103):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_226;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)104):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_228;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)105):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_230;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)106):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_232;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)107):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_234;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)108):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_236;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)109):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_238;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)110):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_240;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)111):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_242;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)112):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_244;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)113):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_246;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)114):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_248;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)115):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_250;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)116):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_252;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)117):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_254;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)118):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_256;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)119):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_258;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)120):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_260;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)121):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_262;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)122):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_264;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)123):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_266;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)124):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_268;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)125):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_270;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)126):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_272;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)127):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_274;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)128):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_276;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)129):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_278;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)130):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_280;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)131):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_282;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)132):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_284;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)133):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_286;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)134):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_288;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)135):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_290;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)136):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_292;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)137):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_294;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)138):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_296;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)139):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_298;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)140):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_300;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)141):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_302;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)142):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_304;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)143):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_306;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)144):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_308;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)145):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_310;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)146):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_312;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)147):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_314;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)148):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_316;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)149):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_318;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)150):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_320;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)151):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_322;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)152):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_324;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)153):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_326;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)154):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_328;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)155):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_330;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)156):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_332;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)157):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_334;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)158):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_336;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)159):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_338;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)160):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_340;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)161):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_342;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)162):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_344;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)163):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_346;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)164):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_348;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)165):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_350;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)166):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_352;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)167):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_354;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)168):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_356;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)169):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_358;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)170):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_360;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)171):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_362;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)172):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_364;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)173):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_366;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)174):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_368;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)175):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_370;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)176):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_372;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)177):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_374;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)178):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_376;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)179):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_378;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)180):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_380;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)181):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_382;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)182):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_384;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)183):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_386;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)184):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_388;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)185):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_390;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)186):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_392;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)187):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_394;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)188):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_396;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)189):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_398;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)190):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_400;
	}
	break;
	case ((tyEnum_TOpcode__k9bFo7ei5swCN5nWfFSgosA)191):
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_402;
	}
	break;
	default:
	{
		result = TM__LKTmeQxNOMAggl6ESLJFSg_403;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u1709)(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A* dest_p0, tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A src_p1) {
	tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&colontmp_), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	colontmp_ = (*dest_p0);
	nimZeroMem((void*)(&(*dest_p0)), sizeof(tyObject_TFullReg__kL8NONjyku1Uli8eXEVZ0A));
	(*dest_p0).kind = src_p1.kind;
	switch ((*dest_p0).kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
		(*dest_p0).intVal = 0;
		(*dest_p0).intVal = src_p1.intVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
		(*dest_p0).floatVal = 0;
		(*dest_p0).floatVal = src_p1.floatVal;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		(*dest_p0).node = 0;
		{
			if (!src_p1.node) goto LA7_;
			nimIncRef(src_p1.node);
		}
LA7_: ;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = nimDecRefIsLastDyn((*dest_p0).node);
			if (!T11_) goto LA12_;
			eqdestroy___ast_u3270((&(*(*dest_p0).node)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose((*dest_p0).node, ((NI)8));
		}
LA12_: ;
		(*dest_p0).node = src_p1.node;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
		(*dest_p0).regAddr = 0;
		(*dest_p0).regAddr = src_p1.regAddr;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
		(*dest_p0).nodeAddr = 0;
		(*dest_p0).nodeAddr = src_p1.nodeAddr;
	}
	break;
	default: __builtin_unreachable();
	}
	switch (colontmp_.kind) {
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)0):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)2):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)3):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)1):
	{
		{
			NIM_BOOL T22_;
			T22_ = (NIM_BOOL)0;
			T22_ = nimDecRefIsLastDyn(colontmp_.node);
			if (!T22_) goto LA23_;
			eqdestroy___ast_u3270((&(*colontmp_.node)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			nimRawDispose(colontmp_.node, ((NI)8));
		}
LA23_: ;
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)4):
	{
	}
	break;
	case ((tyEnum_TRegisterKind__2gkFU0hIZHaIAvsaFxbBdA)5):
	{
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ*, eqdup___vmprofiler_u25)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* src_p0) {
	tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRef(src_p0);
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vmprofiler_u28)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ** dest_p0, tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ* src_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___vmdef_u1600((&(*(*dest_p0))));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmprofiler_u16)(tyObject_TStackFrame__a20zU43j9cYHpYOOr1c2hZQ** dest_p0) {
	(*dest_p0) = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u1388)(tyProc__c9bXGQkBnyyGGVw063jrwZw* dest_p0, tyProc__c9bXGQkBnyyGGVw063jrwZw src_p1, NIM_BOOL cyclic_p2) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	{
		if (!src_p1.ClE_0) goto LA3_;
		nimIncRefCyclic(src_p1.ClE_0, cyclic_p2);
	}
LA3_: ;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T7_;
		T7_ = (NIM_BOOL)0;
		T7_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T7_) goto LA8_;
		nimDestroyAndDispose(colontmp_);
	}
LA8_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u12929)(tyObject_VmArgs__PuiloXB3J4yNffJquqRVvg* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn((*dest_p0).currentException);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3270((&(*(*dest_p0).currentException)));
		nimRawDispose((*dest_p0).currentException, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1385)(tyProc__c9bXGQkBnyyGGVw063jrwZw dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(dest_p0.ClE_0);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(dest_p0.ClE_0);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vm_u14436)(NI** dest_p0, NI* src_p1) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast((*dest_p0));
		if (!T3_) goto LA4_;
		eqdestroy___system_u8092((*(*dest_p0)));
		nimRawDispose((*dest_p0), ((NI)8));
	}
LA4_: ;
	(*dest_p0) = src_p1;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vm_u14427)(NI* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLast(dest_p0);
		if (!T3_) goto LA4_;
		eqdestroy___system_u8092((*dest_p0));
		nimRawDispose(dest_p0, ((NI)8));
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vm_u14424)(NI** dest_p0) {
	(*dest_p0) = 0;
}
static N_INLINE(NIM_BOOL, sameSeqPayload)(void* x_p0, void* y_p1) {
	NIM_BOOL result;
	result = ((*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (x_p0))).p == (*((tyObject_NimRawSeq__Tvl1urqmI1tXqzkHPbWVJQ*) (y_p1))).p);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u1912)(tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastDyn(dest_p0.Field0);
		if (!T3_) goto LA4_;
		eqdestroy___ast_u3469((&(*dest_p0.Field0)));
		nimRawDispose(dest_p0.Field0, ((NI)8));
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastDyn(dest_p0.Field1);
		if (!T8_) goto LA9_;
		eqdestroy___ast_u3270((&(*dest_p0.Field1)));
		nimRawDispose(dest_p0.Field1, ((NI)8));
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___vmdef_u1909)(tyTuple__ZQn9aE2eP9aC9aAInis8k8aDQ* dest_p0) {
	(*dest_p0).Field0 = 0;
	(*dest_p0).Field1 = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___vmdef_u1847)(tySequence__fnH5Zt4fsGx0AgDTOw8pKw* dest_p0, tySequence__fnH5Zt4fsGx0AgDTOw8pKw src_p1) {
	NI T6_;
	NI colontmp_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = sameSeqPayload(dest_p0, (&src_p1));
		if (!T3_) goto LA4_;
		goto BeforeRet_;
	}
LA4_: ;
	T6_ = src_p1.len;
	setLen__vmdef_u1867((&(*dest_p0)), T6_);
	colontmp_ = ((NI)0);
	{
		while (1) {
			NI T9_;
			T9_ = (*dest_p0).len;
			if (!(colontmp_ < T9_)) goto LA8;
			{
				if (!src_p1.p->data[colontmp_].Field0) goto LA12_;
				nimIncRef(src_p1.p->data[colontmp_].Field0);
			}
LA12_: ;
			{
				NIM_BOOL T16_;
				T16_ = (NIM_BOOL)0;
				T16_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_].Field0);
				if (!T16_) goto LA17_;
				eqdestroy___ast_u3469((&(*(*dest_p0).p->data[colontmp_].Field0)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_].Field0, ((NI)8));
			}
LA17_: ;
			(*dest_p0).p->data[colontmp_].Field0 = src_p1.p->data[colontmp_].Field0;
			{
				if (!src_p1.p->data[colontmp_].Field1) goto LA21_;
				nimIncRef(src_p1.p->data[colontmp_].Field1);
			}
LA21_: ;
			{
				NIM_BOOL T25_;
				T25_ = (NIM_BOOL)0;
				T25_ = nimDecRefIsLastDyn((*dest_p0).p->data[colontmp_].Field1);
				if (!T25_) goto LA26_;
				eqdestroy___ast_u3270((&(*(*dest_p0).p->data[colontmp_].Field1)));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				nimRawDispose((*dest_p0).p->data[colontmp_].Field1, ((NI)8));
			}
LA26_: ;
			(*dest_p0).p->data[colontmp_].Field1 = src_p1.p->data[colontmp_].Field1;
			colontmp_ += ((NI)1);
		} LA8: ;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew*, eqdup___vmdef_u2213)(tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* src_p0, NIM_BOOL cyclic_p1) {
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* result;
	tyObject_TCtx__FHLmhXedV9bg0OyLunsHRew* colontmp_;
	result = NIM_NIL;
	colontmp_ = result;
	result = src_p0;
	{
		if (!src_p0) goto LA3_;
		nimIncRefCyclic(src_p0, cyclic_p1);
	}
LA3_: ;
	return result;
}
