/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#include <dirent.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <time.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg;
typedef struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg tyTuple__7q7q3E6Oj24ZNVJb9aonhAg;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__LqZapiAqCFeXPQZdoIAUew tySequence__LqZapiAqCFeXPQZdoIAUew;
typedef struct tySequence__LqZapiAqCFeXPQZdoIAUew_Content tySequence__LqZapiAqCFeXPQZdoIAUew_Content;
typedef struct tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ tyObject_Table__tro5f9chxPVpES1mQpDwZtQ;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og tySequence__pUxI6Ljo6IKKHXKOZkQ7Og;
typedef struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content;
typedef struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g;
typedef struct tyTuple__dPNkpxgceTc63bP5seHZGw tyTuple__dPNkpxgceTc63bP5seHZGw;
typedef struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA;
typedef struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA;
typedef struct tyTuple__qsoB9cWzItmjtA8wRSiKBbA tyTuple__qsoB9cWzItmjtA8wRSiKBbA;
typedef struct tySequence__8Np6tlClE5az1CyqZdN19bQ tySequence__8Np6tlClE5az1CyqZdN19bQ;
typedef struct tySequence__8Np6tlClE5az1CyqZdN19bQ_Content tySequence__8Np6tlClE5az1CyqZdN19bQ_Content;
typedef struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ;
typedef struct tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw;
typedef struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig;
typedef struct tyTuple__UV3llMMYFckfui8YMBuUZA tyTuple__UV3llMMYFckfui8YMBuUZA;
typedef struct tyTuple__i2GOAy1W4iVZ1R13oxrTvA tyTuple__i2GOAy1W4iVZ1R13oxrTvA;
typedef struct tySequence__36jA1xDCIBAS29cySYLQ7kQ tySequence__36jA1xDCIBAS29cySYLQ7kQ;
typedef struct tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content;
typedef struct tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw;
typedef struct tySequence__mg32q50AXD9cQ6jovpBmgWA tySequence__mg32q50AXD9cQ6jovpBmgWA;
typedef struct tySequence__mg32q50AXD9cQ6jovpBmgWA_Content tySequence__mg32q50AXD9cQ6jovpBmgWA_Content;
typedef struct tyTuple__wjbnfGBIEcH6aaevyJWrgw tyTuple__wjbnfGBIEcH6aaevyJWrgw;
typedef struct tyTuple__mBPo6SdWuL2NLQ9aX5t1kTg tyTuple__mBPo6SdWuL2NLQ9aX5t1kTg;
typedef struct tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ;
typedef struct tyTuple__bvjw5f4vMpB9bESWLU7nvyA tyTuple__bvjw5f4vMpB9bESWLU7nvyA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ;
typedef NU8 tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef struct {
N_NIMCALL_PTR(NimStringV2, ClP_0) (NimStringV2 filename_p0, void* ClE_0);
void* ClE_0;
} tyProc__oFHfEKFsiYTMAy9a42cSiKw;
typedef NU8 tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 filename_p0, NI line_p1, NI col_p2, tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g msgKind_p3, NimStringV2 arg_p4, void* ClE_0);
void* ClE_0;
} tyProc__lsy8uLKFmavBA17NQuqO5g;
struct tyTuple__7q7q3E6Oj24ZNVJb9aonhAg {
	NimStringV2 Field0;
	NimStringV2 Field1;
	NimStringV2 Field2;
};
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__LqZapiAqCFeXPQZdoIAUew {
  NI len; tySequence__LqZapiAqCFeXPQZdoIAUew_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
struct tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg {
	tyObject_Table__5Vw74FRHMT0Qc2FBvLMNBQ filenameToIdx;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ idxToFilename;
};
typedef NimStringV2 tyArray__9cz2sUUdI81pQB2Ck7Scwnw[6];
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og {
  NI len; tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content* p;
};
struct tyObject_Table__tro5f9chxPVpES1mQpDwZtQ {
	tySequence__pUxI6Ljo6IKKHXKOZkQ7Og data;
	NI counter;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4, void* ClE_0);
void* ClE_0;
} tyProc__9bd86QnQPXw1dUoLzfDMOKg;
typedef NU8 tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA;
struct tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ {
	RootObj Sup;
	tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* config;
	NI splitAfter;
	NI listingCounter;
	tySequence__LqZapiAqCFeXPQZdoIAUew tocPart;
	NIM_BOOL hasToc;
	NimStringV2 theIndex;
	tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile;
	tyProc__lsy8uLKFmavBA17NQuqO5g msgHandler;
	NimStringV2 outDir;
	NimStringV2 destFile;
	tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg filenames;
	NimStringV2 filename;
	tyArray__9cz2sUUdI81pQB2Ck7Scwnw meta;
	NimStringV2 currentSection;
	tyObject_Table__tro5f9chxPVpES1mQpDwZtQ seenIndexTerms;
	NI id;
	tyProc__9bd86QnQPXw1dUoLzfDMOKg onTestSnippet;
	tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode;
	NI curQuotationDepth;
};
typedef NU8 tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA;
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
typedef NU8 tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA;
typedef NU8 tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA;
struct tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g {
	RootObj Sup;
	tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA kind;
	NI start;
	NI length;
	NCSTRING buf;
	NI pos;
	tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA state;
	tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA lang;
};
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef NimStringV2 tyArray__9amQAAkHuxu9cNghyKvw0urQ[37];
typedef NU8 tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ;
struct tyTuple__dPNkpxgceTc63bP5seHZGw {
	NimStringV2 Field0;
	NIM_BOOL Field1;
};
typedef NU8 tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w;
struct tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
struct tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA {
	tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w kind;
union{
	struct {
	NimStringV2 text;
} _kind_1;
	struct {
	NimStringV2 labelFmt;
} _kind_2;
	struct {
	NimStringV2 lineIndent;
} _kind_3;
	struct {
	NimStringV2 adType;
} _kind_4;
	struct {
	NI level;
} _kind_5;
	struct {
	NI order;
} _kind_6;
	struct {
	NI quotationDepth;
} _kind_7;
	struct {
	tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info;
} _kind_8;
	struct {
	NimStringV2 tooltip;
} _kind_9;
	struct {
	NI colCount;
} _kind_10;
	struct {
	NIM_BOOL endsHeader;
} _kind_11;
	struct {
	NI span;
} _kind_12;
};
	NimStringV2 anchor;
	tySequence__LqZapiAqCFeXPQZdoIAUew sons;
};
typedef NimStringV2 tyArray__A2YC0h9cZydgH7zGAndH9bLg[6];
typedef NimStringV2 tyArray__awn6UrBeChh9cVy9ccoluuYg[5];
struct tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA {
	NI a;
	NI b;
};
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
struct tyTuple__qsoB9cWzItmjtA8wRSiKBbA {
	NIM_CHAR Field0;
	NimStringV2 Field1;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tySequence__8Np6tlClE5az1CyqZdN19bQ {
  NI len; tySequence__8Np6tlClE5az1CyqZdN19bQ_Content* p;
};
struct tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ {
	NI Field0;
	NI Field1;
};
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
struct tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw {
	NIM_BOOL numberLines;
	NI startLine;
	NimStringV2 langStr;
	tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA lang;
	NimStringV2 filename;
	NimStringV2 testCmd;
	NI status;
};
struct tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig {
	NI a;
	NI b;
};
typedef N_CLOSURE_PTR(void, TM__vYBWrr780p7faFzauVMtPg_536) (tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NimStringV2 filename_p1, NimStringV2 cmd_p2, NI status_p3, NimStringV2 content_p4);
struct tyTuple__UV3llMMYFckfui8YMBuUZA {
	NimStringV2 Field0;
	NimStringV2 Field1;
};
typedef NimStringV2 tyArray__wVkbv9aOuop9cKsgoz0aezKQ[10];
typedef NimStringV2 tyArray__TonP9cxJgj8gXu71dWIyNlA[1];
struct tySequence__36jA1xDCIBAS29cySYLQ7kQ {
  NI len; tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content* p;
};
struct tySequence__mg32q50AXD9cQ6jovpBmgWA {
  NI len; tySequence__mg32q50AXD9cQ6jovpBmgWA_Content* p;
};
struct tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw {
	tySequence__mg32q50AXD9cQ6jovpBmgWA data;
	NI counter;
};
struct tyTuple__i2GOAy1W4iVZ1R13oxrTvA {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ Field0;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ Field1;
	tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw Field2;
};
typedef NU8 tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ;
typedef NIM_CHAR tyArray__bErjiHmvISNmC2iIqkq21Q[256];
struct tyTuple__wjbnfGBIEcH6aaevyJWrgw {
	tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ Field0;
	NIM_BOOL Field1;
};
struct tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ {
	tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ kind;
	NimStringV2 keyword;
	NimStringV2 link;
	NimStringV2 linkTitle;
	NimStringV2 linkDesc;
	NI line;
	NimStringV2 module;
	NimStringV2 aux;
};
struct tyTuple__mBPo6SdWuL2NLQ9aX5t1kTg {
	tySequence__36jA1xDCIBAS29cySYLQ7kQ Field0;
	tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ Field1;
};
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (NimStringV2 x_p0, NimStringV2 y_p1, void* ClE_0);
void* ClE_0;
} tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA;
typedef NU8 tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA;
typedef N_CLOSURE_PTR(NI, TM__vYBWrr780p7faFzauVMtPg_669) (NimStringV2 x_p0, NimStringV2 y_p1, void* ClE_0);
struct tyTuple__bvjw5f4vMpB9bESWLU7nvyA {
	NI Field0;
	tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ Field1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ Field2;
};
typedef struct {
N_NIMCALL_PTR(NI, ClP_0) (tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* x_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* y_p1, void* ClE_0);
void* ClE_0;
} tyProc__p4iTrPV9bLhWFNG1rpOIFgQ;
typedef N_CLOSURE_PTR(NI, TM__vYBWrr780p7faFzauVMtPg_673) (tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* x_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* y_p1, void* ClE_0);
struct tySequence__LqZapiAqCFeXPQZdoIAUew_Content { NI cap; tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ {
	NI Field0;
	NimStringV2 Field1;
	NI Field2;
};
struct tySequence__pUxI6Ljo6IKKHXKOZkQ7Og_Content { NI cap; tyTuple__sr3s7uVHpu9cEbbDnCSg8yQ data[SEQ_DECL_SIZE]; };
struct tySequence__8Np6tlClE5az1CyqZdN19bQ_Content { NI cap; tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ data[SEQ_DECL_SIZE]; };
struct tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content { NI cap; tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ data[SEQ_DECL_SIZE]; };
struct tySequence__mg32q50AXD9cQ6jovpBmgWA_Content { NI cap; tyTuple__bvjw5f4vMpB9bESWLU7nvyA data[SEQ_DECL_SIZE]; };
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZstrtabs_u528)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg** dest_p0, tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrstast_u161)(tySequence__LqZapiAqCFeXPQZdoIAUew* dest_p0, tySequence__LqZapiAqCFeXPQZdoIAUew src_p1);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrst_u17756)(tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg* dest_p0, tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg* src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___pureZunicode_u3788)(tyProc__oFHfEKFsiYTMAy9a42cSiKw* dest_p0, tyProc__oFHfEKFsiYTMAy9a42cSiKw src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(void, nossplitFile)(NimStringV2 path_p0, tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* Result);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1);
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___vmdef_u568)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* dest_p0, tyObject_Table__tro5f9chxPVpES1mQpDwZtQ src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ, initTable__vmdef_u421)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___vmdef_u559)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrst_u2468)(tyProc__lsy8uLKFmavBA17NQuqO5g* dest_p0, tyProc__lsy8uLKFmavBA17NQuqO5g src_p1, NIM_BOOL cyclic_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getOrDefault__pureZstrtabs_u390)(tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* t_p0, NimStringV2 key_p1, NimStringV2 default_p2);
N_LIB_PRIVATE N_NIMCALL(NI, nsuParseInt)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZos_u200)(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg* dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nextSplitPoint__packagesZdocutilsZrstgen_u246)(NimStringV2 s_p0, NI start_p1);
static N_INLINE(void, addSplitter__packagesZdocutilsZrstgen_u243)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2* dest_p1);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
static N_INLINE(void, escChar__packagesZdocutilsZrstgen_u238)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2* dest_p1, NIM_CHAR c_p2, tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode_p3);
N_LIB_PRIVATE N_NIMCALL(void, addHtmlChar__packagesZdocutilsZrstgen_u214)(NimStringV2* dest_p0, NIM_CHAR c_p1);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, addTexChar__packagesZdocutilsZrstgen_u217)(NimStringV2* dest_p0, NIM_CHAR c_p1, tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode_p2);
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderCodeLang__packagesZdocutilsZrstgen_u3809)(NimStringV2* result_p0, tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA lang_p1, NimStringV2 code_p2, tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p3);
N_LIB_PRIVATE N_NIMCALL(void, initGeneralTokenizer__packagesZdocutilsZhighlite_u154)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, NimStringV2 buf_p1);
N_LIB_PRIVATE N_NIMCALL(void, getNextToken__packagesZdocutilsZhighlite_u2142)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0, tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA lang_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, substr__system_u8651)(NimStringV2 s_p0, NI first_p1, NI last_p2);
N_LIB_PRIVATE N_NIMCALL(void, dispA__packagesZdocutilsZrstgen_u310)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2* dest_p1, NimStringV2 xml_p2, NimStringV2 tex_p3, NimStringV2* args_p4, NI args_p4Len_0);
N_LIB_PRIVATE N_NIMCALL(void, nsuAddf)(NimStringV2* s_p0, NimStringV2 formatstr_p1, NimStringV2* a_p2, NI a_p2Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, esc__packagesZdocutilsZrstgen_u264)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2 s_p1, NI splitAfter_p2, tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode_p3);
N_LIB_PRIVATE N_NIMCALL(void, deinitGeneralTokenizer__packagesZdocutilsZhighlite_u157)(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g* g_p0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__dPNkpxgceTc63bP5seHZGw, formatIndexEntry__packagesZdocutilsZrstidx_u76)(tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ kind_p0, NimStringV2 htmlFile_p1, NimStringV2 id_p2, NimStringV2 term_p3, NimStringV2 linkTitle_p4, NimStringV2 linkDesc_p5, NI line_p6);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, insert__system_u8268)(NimStringV2* x_p0, NimStringV2 item_p1, NI i_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___pureZstrutils_u2810)(tyTuple__dPNkpxgceTc63bP5seHZGw dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuReplaceStr)(NimStringV2 s_p0, NimStringV2 sub_p1, NimStringV2 by_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, noschangeFileExt)(NimStringV2 filename_p0, NimStringV2 ext_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderIndexTerm__packagesZdocutilsZrstgen_u380)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rstnodeToRefname__packagesZdocutilsZrst_u78)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__vmgen_u3190)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___vmdef_u2322)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ* t_p0, NimStringV2 key_p1, NI val_p2);
N_LIB_PRIVATE N_NIMCALL(NI, getOrDefault__packagesZdocutilsZrstgen_u506)(tyObject_Table__tro5f9chxPVpES1mQpDwZtQ t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(void, renderAux__packagesZdocutilsZrstgen_u328)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NI, len__packagesZdocutilsZrstast_u114)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, renderRstToOut__packagesZdocutilsZrstgen_u324)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, renderHeadline__packagesZdocutilsZrstgen_u3635)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, renderRstToText__packagesZdocutilsZrstast_u856)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* node_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrstast_u466)(tySequence__LqZapiAqCFeXPQZdoIAUew* x_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, eqdup___packagesZdocutilsZrstast_u291)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nimCharToStr)(NIM_CHAR x_p0);
N_LIB_PRIVATE N_NIMCALL(void, setIndexTerm__packagesZdocutilsZrstgen_u353)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ k_p1, NimStringV2 htmlFile_p2, NimStringV2 id_p3, NimStringV2 term_p4, NimStringV2 linkTitle_p5, NimStringV2 linkDesc_p6, NI line_p7);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, htmlFileRelPath__packagesZdocutilsZrstgen_u377)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosextractFilename)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosrelativePath)(NimStringV2 path_p0, NimStringV2 base_p1, NIM_CHAR sep_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, addNodes__packagesZdocutilsZrst_u80)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p0);
static N_INLINE(NimStringV2, spaces__pureZstrutils_u1139)(NI n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuRepeatChar)(NIM_CHAR c_p0, NI count_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderOverline__packagesZdocutilsZrstgen_u3660)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, renderAux__packagesZdocutilsZrstgen_u340)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2 html_p2, NimStringV2 tex_p3, NimStringV2* result_p4);
N_LIB_PRIVATE N_NIMCALL(void, renderEnumList__packagesZdocutilsZrstgen_u3909)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
static N_INLINE(NIM_CHAR*, X5BX5D___system_u8118)(NimStringV2* s_p0, NI i_p1);
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, nimPrepareStrMutationImpl__system_u2430)(NimStringV2* s_p0);
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuIsDigitChar)(NIM_CHAR c_p0);
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1286)(NimStringV2 s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1);
N_NIMCALL(NimStringV2, mnewString)(NI len_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuIsUpperAsciiChar)(NIM_CHAR c_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___cgen_u30646)(tyTuple__qsoB9cWzItmjtA8wRSiKBbA dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, renderField__packagesZdocutilsZrstgen_u3898)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuStrip)(NimStringV2 s_p0, NIM_BOOL leading_p1, NIM_BOOL trailing_p2, tySet_tyChar__nmiMWKVIe46vacnhAFrQvw chars_p3);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCmpIgnoreStyle)(NimStringV2 a_p0, NimStringV2 b_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuRepeatStr)(NimStringV2 s_p0, NI n_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___system_u4730)(NF x_p0);
static N_INLINE(NF, toFloat__system_u1695)(NI i_p0);
N_LIB_PRIVATE N_NIMCALL(void, renderAdmonition__packagesZdocutilsZrstgen_u4000)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NI, hashString)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuCapitalizeAscii)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrstgen_u4087)(tySequence__8Np6tlClE5az1CyqZdN19bQ* x_p0, tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___types_u1571)(tySequence__8Np6tlClE5az1CyqZdN19bQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, renderHyperlink__packagesZdocutilsZrstgen_u4009)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* text_p1, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* link_p2, NimStringV2* result_p3, NIM_BOOL external_p4, NIM_BOOL nimdoc_p5, NimStringV2 tooltip_p6);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, safeProtocol__packagesZdocutilsZrst_u10329)(NimStringV2* linkStr_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*, lastSon__packagesZdocutilsZrstast_u457)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstast_u285)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, renderImage__packagesZdocutilsZrstgen_u3713)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getArgument__packagesZdocutilsZrst_u85)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getFieldValue__packagesZdocutilsZrst_u82)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p0, NimStringV2 fieldname_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dispF__packagesZdocutilsZrstgen_u300)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2 xml_p1, NimStringV2 tex_p2, NimStringV2* args_p3, NI args_p3Len_0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, nsuEndsWith)(NimStringV2 s_p0, NimStringV2 suffix_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderCode__packagesZdocutilsZrstgen_u3819)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, parseCodeBlockParams__packagesZdocutilsZrstgen_u3759)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* Result);
N_LIB_PRIVATE N_NIMCALL(void, init__packagesZdocutilsZrstgen_u84)(tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, parseCodeBlockField__packagesZdocutilsZrstgen_u3755)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* params_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuToLowerAsciiStr)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NI, getField1Int__packagesZdocutilsZrstgen_u3727)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2 fieldName_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getFieldValue__packagesZdocutilsZrst_u11689)(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p0);
N_LIB_PRIVATE N_NIMCALL(NI, parseInt__pureZparseutils_u981)(NimStringV2 s_p0, NI* number_p1, NI start_p2);
N_LIB_PRIVATE N_NIMCALL(void, rstMessage__packagesZdocutilsZrst_u3806)(tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg* filenames_p0, tyProc__lsy8uLKFmavBA17NQuqO5g f_p1, tyObject_TLineInfo__BXRmDJv4YG3TQBaYGJdgNA info_p2, tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g msgKind_p3, NimStringV2 arg_p4);
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1314)(NimStringV2 s_p0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1);
static N_INLINE(tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig, dotdot___stdZenumutils_u106)(NI a_p0, NI b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuUnescape)(NimStringV2 s_p0, NimStringV2 prefix_p1, NimStringV2 suffix_p2);
N_LIB_PRIVATE N_NIMCALL(tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA, getSourceLanguage__packagesZdocutilsZhighlite_u72)(NimStringV2 name_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u3866)(tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, buildLinesHtmlTable__packagesZdocutilsZrstgen_u3780)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* params_p1, NimStringV2 code_p2, NimStringV2 idStr_p3, tyTuple__UV3llMMYFckfui8YMBuUZA* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCountLines)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(void, renderContainer__packagesZdocutilsZrstgen_u3892)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, renderSmiley__packagesZdocutilsZrstgen_u3723)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, traverseForIndex__packagesZdocutilsZrstgen_u4022)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1);
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntry__packagesZdocutilsZrstgen_u3687)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2);
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntries__packagesZdocutilsZrstgen_u3698)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NI* j_p1, NI lvl_p2, NimStringV2* result_p3);
N_LIB_PRIVATE N_NIMCALL(void, writeFile__stdZsyncio_u532)(NimStringV2 filename_p0, NimStringV2 content_p1);
N_LIB_PRIVATE N_NIMCALL(void, readIndexDir__packagesZdocutilsZrstgen_u2311)(NimStringV2 dir_p0, tyTuple__i2GOAy1W4iVZ1R13oxrTvA* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u5515)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0, tySequence__sM4lkSb7zS6F7OVMvW9cffQ src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrstgen_u2165)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* dest_p0, tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw src_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw, initTable__packagesZdocutilsZrstgen_u2333)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u2156)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, newSeq__packagesZdocutilsZrstidx_u119)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* s_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, setLen__packagesZdocutilsZrstidx_u127)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* s_p0, NI newlen_p1);
static N_INLINE(NimStringV2, pop__stdZprivateZosdirs_u415)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0);
N_LIB_PRIVATE N_NIMCALL(void, shrink__system_u5403)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NI newLen_p1);
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosjoinPath)(NimStringV2 head_p0, NimStringV2 tail_p1);
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NOINLINE(void, raiseOSError__stdZoserrors_u119)(NI32 errorCode_p0, NimStringV2 additionalInfo_p1);
N_LIB_PRIVATE N_NIMCALL(NI32, osLastError__stdZoserrors_u122)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, cstrToNimstr)(NCSTRING str_p0);
N_LIB_PRIVATE N_NIMCALL(tyTuple__wjbnfGBIEcH6aaevyJWrgw, getSymlinkFileKind__stdZprivateZoscommon_u20)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, parseIdxFile__packagesZdocutilsZrstidx_u113)(NimStringV2 path_p0, tyTuple__mBPo6SdWuL2NLQ9aX5t1kTg* Result);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstidx_u278)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstidx_u194)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___packagesZdocutilsZrstidx_u200)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(NI, nsuFindChar)(NimStringV2 s_p0, NIM_CHAR sub_p1, NI start_p2, NI last_p3);
N_LIB_PRIVATE N_NIMCALL(void, setLengthStrV2)(NimStringV2* s_p0, NI newLen_p1);
N_LIB_PRIVATE N_NIMCALL(NI, len__packagesZdocutilsZrstgen_u1417)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw t_p0);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___packagesZdocutilsZrstgen_u2549)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* t_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* key_p1, tySequence__36jA1xDCIBAS29cySYLQ7kQ val_p2);
N_LIB_PRIVATE N_NIMCALL(tySequence__36jA1xDCIBAS29cySYLQ7kQ, eqdup___packagesZdocutilsZrstidx_u287)(tySequence__36jA1xDCIBAS29cySYLQ7kQ src_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstidx_u197)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstidx_u281)(tySequence__36jA1xDCIBAS29cySYLQ7kQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrst_u16216)(tyTuple__mBPo6SdWuL2NLQ9aX5t1kTg* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u5506)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u5503)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___packagesZdocutilsZrstgen_u2153)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, sort__sem_u2565)(NimStringV2* a_p0, NI a_p0Len_0, tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA cmp_p1, tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA order_p2);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__system_u1563)(NimStringV2 x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, generateDocumentationJumps__packagesZdocutilsZrstgen_u2193)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw docs_p0);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0);
N_LIB_PRIVATE N_NIMCALL(void, add__packagesZdocutilsZrstgen_u1602)(tySequence__36jA1xDCIBAS29cySYLQ7kQ* x_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdup___packagesZdocutilsZrstidx_u203)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* src_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, sort__packagesZdocutilsZrstgen_u1625)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* a_p0, NI a_p0Len_0, tyProc__p4iTrPV9bLhWFNG1rpOIFgQ cmp_p1, tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA order_p2);
N_LIB_PRIVATE N_NIMCALL(NI, cmp__packagesZdocutilsZrstidx_u318)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* a_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuJoinSep)(NimStringV2* a_p0, NI a_p0Len_0, NimStringV2 sep_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, generateModuleJumps__packagesZdocutilsZrstgen_u2295)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ modules_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, prettyLink__packagesZdocutilsZrstgen_u81)(NimStringV2 file_p0);
N_LIB_PRIVATE N_NIMCALL(void, sortIndex__packagesZdocutilsZrstgen_u721)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* a_p0, NI a_p0Len_0);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___packagesZdocutilsZrstidx_u206)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* dest_p0, tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, generateSymbolIndex__packagesZdocutilsZrstgen_u765)(tySequence__36jA1xDCIBAS29cySYLQ7kQ symbols_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, escapeLink__packagesZdocutilsZrstgen_u750)(NimStringV2 s_p0);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toHex__pureZstrutils_u2114)(NI x_p0, NI len_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u3613)(tyTuple__i2GOAy1W4iVZ1R13oxrTvA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u1198)(tySequence__mg32q50AXD9cQ6jovpBmgWA dest_p0);
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__vYBWrr780p7faFzauVMtPg_2 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_3 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_4 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_5 = { 4 | NIM_STRLIT_FLAG, ".nim" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_6 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_5};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_7 = { 7 | NIM_STRLIT_FLAG, "Module " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_8 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_7};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_9 = { 14 | NIM_STRLIT_FLAG, "split.item.toc" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_10 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_9};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_11 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_12 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_13 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_14 = { 7 | NIM_STRLIT_FLAG, "<wbr />" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_15 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_14};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_16 = { 2 | NIM_STRLIT_FLAG, "\\-" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_17 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_16};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_18 = { 5 | NIM_STRLIT_FLAG, "&amp;" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_19 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_18};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_20 = { 4 | NIM_STRLIT_FLAG, "&lt;" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_21 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_20};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_22 = { 4 | NIM_STRLIT_FLAG, "&gt;" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_23 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_22};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_24 = { 6 | NIM_STRLIT_FLAG, "&quot;" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_25 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_24};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_26 = { 1 | NIM_STRLIT_FLAG, "\\" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_27 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_26};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_28 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_26};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_29 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_26};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_30 = { 2 | NIM_STRLIT_FLAG, "{}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_31 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_30};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__vYBWrr780p7faFzauVMtPg_32 = { 17 | NIM_STRLIT_FLAG, "\\textasciigrave{}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_33 = {17, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_32};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__vYBWrr780p7faFzauVMtPg_34 = { 16 | NIM_STRLIT_FLAG, "\\textbackslash{}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_35 = {16, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_34};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_36 = { 4 | NIM_STRLIT_FLAG, "\\%7B" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_37 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_36};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_38 = { 2 | NIM_STRLIT_FLAG, "\\{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_39 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_38};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_40 = { 4 | NIM_STRLIT_FLAG, "\\%7D" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_41 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_40};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_42 = { 2 | NIM_STRLIT_FLAG, "\\}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_43 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_42};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__vYBWrr780p7faFzauVMtPg_44 = { 8 | NIM_STRLIT_FLAG, "\\text{]}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_45 = {8, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_44};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_46 = { 1 | NIM_STRLIT_FLAG, "]" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_47 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_46};
extern TNimTypeV2 NTIv2__t8mWIshWZpNBbL0h6CSV0g_;
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__vYBWrr780p7faFzauVMtPg_48 = { 26 | NIM_STRLIT_FLAG, "<span class=\"$2\">$1</span>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_49 = {26, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_48};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_50 = { 11 | NIM_STRLIT_FLAG, "\\span$2{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_51 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_50};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_52 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vYBWrr780p7faFzauVMtPg_53 = { 3 | NIM_STRLIT_FLAG, "_._" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_54 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_53};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_55 = { 2 | NIM_STRLIT_FLAG, ".." };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_56 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_55};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_57 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_58 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[54+1];
} TM__vYBWrr780p7faFzauVMtPg_59 = { 54 | NIM_STRLIT_FLAG, "\012<h$1><a class=\"toc-backref\"$2 href=\"#$5\">$3</a></h$1>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_60 = {54, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_59};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__vYBWrr780p7faFzauVMtPg_61 = { 18 | NIM_STRLIT_FLAG, "\\rsth$4[$6]{$3}$2\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_62 = {18, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_61};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_63 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_64 = { 5 | NIM_STRLIT_FLAG, " id=\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_65 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_66 = { 1 | NIM_STRLIT_FLAG, "\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_67 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_68 = { 7 | NIM_STRLIT_FLAG, "\\label{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_69 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_70 = { 14 | NIM_STRLIT_FLAG, "}\\hypertarget{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_71 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vYBWrr780p7faFzauVMtPg_72 = { 3 | NIM_STRLIT_FLAG, "}{}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_73 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__vYBWrr780p7faFzauVMtPg_74 = { 16 | NIM_STRLIT_FLAG, "\012<h$1$2>$3</h$1>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_75 = {16, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_74};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__vYBWrr780p7faFzauVMtPg_76 = { 18 | NIM_STRLIT_FLAG, "\\rsth$4[$5]{$3}$2\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_77 = {18, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_76};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_78 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_79 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_80 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_81 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_82 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_83 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_84 = { 4 | NIM_STRLIT_FLAG, "html" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_85 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_84};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_86 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_87 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__vYBWrr780p7faFzauVMtPg_88 = { 32 | NIM_STRLIT_FLAG, "<h$1$2><center>$3</center></h$1>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_89 = {32, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_88};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__vYBWrr780p7faFzauVMtPg_90 = { 19 | NIM_STRLIT_FLAG, "\\rstov$4[$5]{$3}$2\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_91 = {19, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_90};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_92 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_93 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_94 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_95 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_96 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_97 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_98 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_99 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_100 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_101 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_102 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_103 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_104 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_105 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_106 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_107 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_108 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_109 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_110 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_111 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_112 = { 9 | NIM_STRLIT_FLAG, "<hr$2 />\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_113 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_112};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__vYBWrr780p7faFzauVMtPg_114 = { 25 | NIM_STRLIT_FLAG, "\012\012\\vspace{0.6em}\\hrule$2\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_115 = {25, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_114};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__vYBWrr780p7faFzauVMtPg_116 = { 12 | NIM_STRLIT_FLAG, "<p$2>$1</p>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_117 = {12, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_116};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_118 = { 9 | NIM_STRLIT_FLAG, "\012\012$2\012$1\012\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_119 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_118};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__vYBWrr780p7faFzauVMtPg_120 = { 29 | NIM_STRLIT_FLAG, "<ul$2 class=\"simple\">$1</ul>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_121 = {29, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_120};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__vYBWrr780p7faFzauVMtPg_122 = { 35 | NIM_STRLIT_FLAG, "\\begin{itemize}\012$2\012$1\\end{itemize}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_123 = {35, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_122};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_124 = { 14 | NIM_STRLIT_FLAG, "<li$2>$1</li>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_125 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_124};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_126 = { 11 | NIM_STRLIT_FLAG, "\\item $2$1\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_127 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_126};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_128 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_129 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_130 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_131 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_132 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_133 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_132};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_134 = { 2 | NIM_STRLIT_FLAG, "\012%" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_135 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_134};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_136 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_137 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_136};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_138 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_139 = { 6 | NIM_STRLIT_FLAG, "label=" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_140 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_139};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__vYBWrr780p7faFzauVMtPg_141 = { 8 | NIM_STRLIT_FLAG, "\\arabic*" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_142 = {8, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_141};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_143 = { 1 | NIM_STRLIT_FLAG, "," };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_144 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_143};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_145 = { 1 | NIM_STRLIT_FLAG, "1" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_146 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_145};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__vYBWrr780p7faFzauVMtPg_147 = { 8 | NIM_STRLIT_FLAG, "start=$1" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_148 = {8, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_147};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_149 = { 6 | NIM_STRLIT_FLAG, "[$1$2]" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_150 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_149};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_151 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_139};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_152 = { 6 | NIM_STRLIT_FLAG, "\\Alph*" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_153 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_152};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_154 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_139};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_155 = { 6 | NIM_STRLIT_FLAG, "\\alph*" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_156 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_155};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_157 = { 7 | NIM_STRLIT_FLAG, ",start=" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_158 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_157};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_159 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_149};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_160 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_145};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_161 = { 11 | NIM_STRLIT_FLAG, " start=\"$1\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_162 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_161};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_163 = { 14 | NIM_STRLIT_FLAG, "class=\"simple\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_164 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_163};
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__vYBWrr780p7faFzauVMtPg_166 = { 25 | NIM_STRLIT_FLAG, "class=\"upperalpha simple\"" };
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__vYBWrr780p7faFzauVMtPg_168 = { 25 | NIM_STRLIT_FLAG, "class=\"loweralpha simple\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_169 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_161};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_170 = { 6 | NIM_STRLIT_FLAG, "<ol$2 " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_171 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_170};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_172 = { 9 | NIM_STRLIT_FLAG, ">$1</ol>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_173 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_172};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__vYBWrr780p7faFzauVMtPg_174 = { 17 | NIM_STRLIT_FLAG, "\\begin{enumerate}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_175 = {17, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_174};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__vYBWrr780p7faFzauVMtPg_176 = { 20 | NIM_STRLIT_FLAG, "$2$1\\end{enumerate}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_177 = {20, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_176};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__vYBWrr780p7faFzauVMtPg_178 = { 31 | NIM_STRLIT_FLAG, "<dl$2 class=\"docutils\">$1</dl>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_179 = {31, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_178};
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__vYBWrr780p7faFzauVMtPg_180 = { 43 | NIM_STRLIT_FLAG, "\\begin{description}\012$2\012$1\\end{description}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_181 = {43, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_180};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_182 = { 14 | NIM_STRLIT_FLAG, "<dt$2>$1</dt>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_183 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_182};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_184 = { 14 | NIM_STRLIT_FLAG, "$2\\item[$1]\\  " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_185 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_184};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_186 = { 14 | NIM_STRLIT_FLAG, "<dd$2>$1</dd>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_187 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_186};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_188 = { 6 | NIM_STRLIT_FLAG, "$2\012$1\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_189 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_188};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_190 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[148+1];
} TM__vYBWrr780p7faFzauVMtPg_191 = { 148 | NIM_STRLIT_FLAG, "<table$2 class=\"docinfo\" frame=\"void\" rules=\"none\"><col class=\"docinfo-name\" /><col class=\"docinfo-content\" /><tbody valign=\"top\">$1</tbody></table>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_192 = {148, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_191};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_193 = {43, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_180};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_194 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_195 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_196 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_197 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_198 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_199 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static NIM_CONST tySet_tyChar__nmiMWKVIe46vacnhAFrQvw TM__vYBWrr780p7faFzauVMtPg_200 = {
0x00, 0x3e, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
;
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_201 = { 6 | NIM_STRLIT_FLAG, "author" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_202 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_201};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_203 = { 7 | NIM_STRLIT_FLAG, "authors" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_204 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_203};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_205 = { 7 | NIM_STRLIT_FLAG, "version" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_206 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_205};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__vYBWrr780p7faFzauVMtPg_207 = { 12 | NIM_STRLIT_FLAG, "<tr>$1</tr>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_208 = {12, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_207};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_209 = { 2 | NIM_STRLIT_FLAG, "$1" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_210 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_209};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__vYBWrr780p7faFzauVMtPg_211 = { 33 | NIM_STRLIT_FLAG, "<th class=\"docinfo-name\">$1:</th>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_212 = {33, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_211};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__vYBWrr780p7faFzauVMtPg_213 = { 10 | NIM_STRLIT_FLAG, "\\item[$1:]" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_214 = {10, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_213};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_215 = { 11 | NIM_STRLIT_FLAG, "<td>$1</td>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_216 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_215};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_217 = { 4 | NIM_STRLIT_FLAG, " $1\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_218 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_217};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__vYBWrr780p7faFzauVMtPg_219 = { 35 | NIM_STRLIT_FLAG, "<div$2 class=\"option-list\">$1</div>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_220 = {35, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_219};
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__vYBWrr780p7faFzauVMtPg_221 = { 39 | NIM_STRLIT_FLAG, "\\begin{rstoptlist}$2\012$1\\end{rstoptlist}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_222 = {39, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_221};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_223 = { 4 | NIM_STRLIT_FLAG, " odd" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_224 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_223};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_225 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__vYBWrr780p7faFzauVMtPg_226 = { 28 | NIM_STRLIT_FLAG, "<div class=\"option-list-item" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_227 = {28, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_226};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_228 = { 11 | NIM_STRLIT_FLAG, "\">$1</div>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_229 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_228};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_230 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_209};
static const struct {
  NI cap; NIM_CHAR data[76+1];
} TM__vYBWrr780p7faFzauVMtPg_231 = { 76 | NIM_STRLIT_FLAG, "<div class=\"option-list-label\"><tt><span class=\"option\">$1</span></tt></div>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_232 = {76, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_231};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__vYBWrr780p7faFzauVMtPg_233 = { 36 | NIM_STRLIT_FLAG, "\\item[\\rstcodeitem{\\spanoption{$1}}]" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_234 = {36, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_233};
static const struct {
  NI cap; NIM_CHAR data[45+1];
} TM__vYBWrr780p7faFzauVMtPg_235 = { 45 | NIM_STRLIT_FLAG, "<div class=\"option-list-description\">$1</div>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_236 = {45, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_235};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_237 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_217};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_238 = { 14 | NIM_STRLIT_FLAG, "renderRstToOut" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_239 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_238};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__vYBWrr780p7faFzauVMtPg_240 = { 16 | NIM_STRLIT_FLAG, "<pre$2>$1</pre>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_241 = {16, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_240};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__vYBWrr780p7faFzauVMtPg_242 = { 36 | NIM_STRLIT_FLAG, "\012\012$2\\begin{rstpre}\012$1\012\\end{rstpre}\012\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_243 = {36, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_242};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_244 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_245 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_209};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_246 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_209};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__vYBWrr780p7faFzauVMtPg_247 = { 13 | NIM_STRLIT_FLAG, "</blockquote>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_248 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_247};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_249 = { 14 | NIM_STRLIT_FLAG, "\\end{rstquote}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_250 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_249};
static const struct {
  NI cap; NIM_CHAR data[53+1];
} TM__vYBWrr780p7faFzauVMtPg_251 = { 53 | NIM_STRLIT_FLAG, "<blockquote$2 class=\"markdown-quote\">$1</blockquote>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_252 = {53, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_251};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__vYBWrr780p7faFzauVMtPg_253 = { 38 | NIM_STRLIT_FLAG, "\012\\begin{rstquote}\012$2\012$1\\end{rstquote}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_254 = {38, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_253};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_255 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_256 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_257 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_258 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_259 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_260 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__vYBWrr780p7faFzauVMtPg_261 = { 35 | NIM_STRLIT_FLAG, "<blockquote class=\"markdown-quote\">" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_262 = {35, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_261};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__vYBWrr780p7faFzauVMtPg_263 = { 16 | NIM_STRLIT_FLAG, "\\begin{rstquote}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_264 = {16, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_263};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_265 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_247};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_266 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_249};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_267 = { 9 | NIM_STRLIT_FLAG, "<p>$1</p>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_268 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_267};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vYBWrr780p7faFzauVMtPg_269 = { 3 | NIM_STRLIT_FLAG, "\012$1" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_270 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_269};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_271 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_136};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__vYBWrr780p7faFzauVMtPg_272 = { 12 | NIM_STRLIT_FLAG, "<p$2>$1</p> " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_273 = {12, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_272};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_274 = { 7 | NIM_STRLIT_FLAG, "\012\012$2\012$1" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_275 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_274};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_276 = { 11 | NIM_STRLIT_FLAG, "<p$2>$1</p>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_277 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_276};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__vYBWrr780p7faFzauVMtPg_278 = { 35 | NIM_STRLIT_FLAG, "\012\\vspace{0.5em}$2\012$1\\vspace{0.5em}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_279 = {35, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_278};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_280 = { 7 | NIM_STRLIT_FLAG, "$1<br/>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_281 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_280};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_282 = { 14 | NIM_STRLIT_FLAG, "\\noindent $1\012\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_283 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_282};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_284 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_136};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_285 = { 5 | NIM_STRLIT_FLAG, "<br/>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_286 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_285};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__vYBWrr780p7faFzauVMtPg_287 = { 13 | NIM_STRLIT_FLAG, "\\vspace{1em}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_288 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_287};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_289 = { 2 | NIM_STRLIT_FLAG, "em" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_290 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_289};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__vYBWrr780p7faFzauVMtPg_291 = { 26 | NIM_STRLIT_FLAG, "<span style=\"margin-left: " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_292 = {26, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_291};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__vYBWrr780p7faFzauVMtPg_293 = { 16 | NIM_STRLIT_FLAG, "\">$1</span><br/>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_294 = {16, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_293};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__vYBWrr780p7faFzauVMtPg_295 = { 17 | NIM_STRLIT_FLAG, "\\noindent\\hspace{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_296 = {17, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_295};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_297 = { 5 | NIM_STRLIT_FLAG, "}$1\012\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_298 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_297};
static const struct {
  NI cap; NIM_CHAR data[37+1];
} TM__vYBWrr780p7faFzauVMtPg_299 = { 37 | NIM_STRLIT_FLAG, "<blockquote$2><p>$1</p></blockquote>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_300 = {37, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_299};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__vYBWrr780p7faFzauVMtPg_301 = { 31 | NIM_STRLIT_FLAG, "\\begin{quote}\012$2\012$1\\end{quote}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_302 = {31, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_301};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__vYBWrr780p7faFzauVMtPg_303 = { 18 | NIM_STRLIT_FLAG, "admonition_warning" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_304 = {18, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_303};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_305 = { 6 | NIM_STRLIT_FLAG, "\\large" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_306 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_305};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_307 = { 6 | NIM_STRLIT_FLAG, "orange" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_308 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_307};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_309 = { 4 | NIM_STRLIT_FLAG, "hint" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_310 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_309};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_311 = { 4 | NIM_STRLIT_FLAG, "note" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_312 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_311};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vYBWrr780p7faFzauVMtPg_313 = { 3 | NIM_STRLIT_FLAG, "tip" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_314 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_313};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_315 = { 9 | NIM_STRLIT_FLAG, "attention" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_316 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_315};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__vYBWrr780p7faFzauVMtPg_317 = { 10 | NIM_STRLIT_FLAG, "admonition" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_318 = {10, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_317};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_319 = { 9 | NIM_STRLIT_FLAG, "important" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_320 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_319};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_321 = { 7 | NIM_STRLIT_FLAG, "warning" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_322 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_321};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_323 = { 7 | NIM_STRLIT_FLAG, "caution" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_324 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_323};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_325 = { 6 | NIM_STRLIT_FLAG, "danger" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_326 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_325};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_327 = { 5 | NIM_STRLIT_FLAG, "error" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_328 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_327};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__vYBWrr780p7faFzauVMtPg_329 = { 15 | NIM_STRLIT_FLAG, "admonition-info" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_330 = {15, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_329};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_331 = { 11 | NIM_STRLIT_FLAG, "\\normalsize" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_332 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_331};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_333 = { 5 | NIM_STRLIT_FLAG, "green" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_334 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_333};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__vYBWrr780p7faFzauVMtPg_335 = { 18 | NIM_STRLIT_FLAG, "admonition-warning" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_336 = {18, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_335};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_337 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_305};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_338 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_307};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__vYBWrr780p7faFzauVMtPg_339 = { 16 | NIM_STRLIT_FLAG, "admonition-error" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_340 = {16, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_339};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_341 = { 6 | NIM_STRLIT_FLAG, "\\Large" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_342 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_341};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vYBWrr780p7faFzauVMtPg_343 = { 3 | NIM_STRLIT_FLAG, "red" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_344 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_343};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__vYBWrr780p7faFzauVMtPg_345 = { 23 | NIM_STRLIT_FLAG, "<div class=\"admonition " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_346 = {23, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_345};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_347 = { 2 | NIM_STRLIT_FLAG, "\">" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_348 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_347};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__vYBWrr780p7faFzauVMtPg_349 = { 15 | NIM_STRLIT_FLAG, "<span$2 class=\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_350 = {15, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_349};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__vYBWrr780p7faFzauVMtPg_351 = { 10 | NIM_STRLIT_FLAG, "-text\"><b>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_352 = {10, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_351};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__vYBWrr780p7faFzauVMtPg_353 = { 22 | NIM_STRLIT_FLAG, ":</b></span>\012$1</div>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_354 = {22, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_353};
static const struct {
  NI cap; NIM_CHAR data[53+1];
} TM__vYBWrr780p7faFzauVMtPg_355 = { 53 | NIM_STRLIT_FLAG, "\012\012\\begin{rstadmonition}[borderline west={0.2em}{0pt}{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_356 = {53, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_355};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_357 = { 6 | NIM_STRLIT_FLAG, "}]$2\012{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_358 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_357};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_359 = { 7 | NIM_STRLIT_FLAG, "\\color{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_360 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_359};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__vYBWrr780p7faFzauVMtPg_361 = { 10 | NIM_STRLIT_FLAG, "}{\\textbf{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_362 = {10, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_361};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__vYBWrr780p7faFzauVMtPg_363 = { 28 | NIM_STRLIT_FLAG, ":}}} $1\012\\end{rstadmonition}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_364 = {28, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_363};
static const struct {
  NI cap; NIM_CHAR data[47+1];
} TM__vYBWrr780p7faFzauVMtPg_365 = { 47 | NIM_STRLIT_FLAG, "<table$2 border=\"1\" class=\"docutils\">$1</table>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_366 = {47, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_365};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__vYBWrr780p7faFzauVMtPg_367 = { 19 | NIM_STRLIT_FLAG, "\012$2\012\\begin{rsttab}{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_368 = {19, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_367};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_369 = { 1 | NIM_STRLIT_FLAG, "L" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_370 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_369};
static const struct {
  NI cap; NIM_CHAR data[57+1];
} TM__vYBWrr780p7faFzauVMtPg_371 = { 57 | NIM_STRLIT_FLAG, "}\012\\toprule\012$1\\addlinespace[0.1em]\\bottomrule\012\\end{rsttab}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_372 = {57, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_371};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_373 = { 4 | NIM_STRLIT_FLAG, "<tr>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_374 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_373};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_375 = { 6 | NIM_STRLIT_FLAG, "</tr>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_376 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_375};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__vYBWrr780p7faFzauVMtPg_377 = { 19 | NIM_STRLIT_FLAG, "\\rowcolor{gray!15} " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_378 = {19, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_377};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vYBWrr780p7faFzauVMtPg_379 = { 3 | NIM_STRLIT_FLAG, " & " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_380 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_379};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_381 = { 2 | NIM_STRLIT_FLAG, "\\\\" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_382 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_381};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_383 = { 9 | NIM_STRLIT_FLAG, "\\midrule\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_384 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_383};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__vYBWrr780p7faFzauVMtPg_385 = { 20 | NIM_STRLIT_FLAG, "\\cmidrule(lr){$1-$2}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_386 = {20, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_385};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_387 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_136};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_388 = { 2 | NIM_STRLIT_FLAG, "th" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_389 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_388};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_390 = { 2 | NIM_STRLIT_FLAG, "td" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_391 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_390};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_392 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__vYBWrr780p7faFzauVMtPg_393 = { 10 | NIM_STRLIT_FLAG, " colspan=\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_394 = {10, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_393};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__vYBWrr780p7faFzauVMtPg_395 = { 28 | NIM_STRLIT_FLAG, "\" style=\"text-align: center\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_396 = {28, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_395};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__vYBWrr780p7faFzauVMtPg_397 = { 14 | NIM_STRLIT_FLAG, "<$1$2>$$1</$1>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_398 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_397};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_399 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_400 = { 11 | NIM_STRLIT_FLAG, "\\textbf{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_401 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_400};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_402 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_209};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__vYBWrr780p7faFzauVMtPg_403 = { 13 | NIM_STRLIT_FLAG, "\\multicolumn{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_404 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_403};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_405 = { 5 | NIM_STRLIT_FLAG, "}{c}{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_406 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_405};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_407 = { 1 | NIM_STRLIT_FLAG, "}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_408 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_407};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_409 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[59+1];
} TM__vYBWrr780p7faFzauVMtPg_410 = { 59 | NIM_STRLIT_FLAG, "<hr class=\"footnote\"><div class=\"footnote-group\">\012$1</div>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_411 = {59, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_410};
static const struct {
  NI cap; NIM_CHAR data[80+1];
} TM__vYBWrr780p7faFzauVMtPg_412 = { 80 | NIM_STRLIT_FLAG, "\012\012\\noindent\\rule{0.25\\linewidth}{.4pt}\012\\begin{rstfootnote}\012$1\\end{rstfootnote}\012\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_413 = {80, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_412};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_414 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_415 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[109+1];
} TM__vYBWrr780p7faFzauVMtPg_416 = { 109 | NIM_STRLIT_FLAG, "<div$2><div class=\"footnote-label\"><sup><strong><a href=\"#$4\">[$3]</a></strong></sup></div> &ensp; $1\012</div>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_417 = {109, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_416};
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__vYBWrr780p7faFzauVMtPg_418 = { 35 | NIM_STRLIT_FLAG, "\\item[\\textsuperscript{[$3]}]$2 $1\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_419 = {35, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_418};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_420 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_421 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_422 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_423 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_424 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_425 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_426 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_427 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__vYBWrr780p7faFzauVMtPg_428 = { 7 | NIM_STRLIT_FLAG, " nimdoc" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_429 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_428};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_430 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_431 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_432 = { 11 | NIM_STRLIT_FLAG, " title=\"$1\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_433 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_432};
static const struct {
  NI cap; NIM_CHAR data[50+1];
} TM__vYBWrr780p7faFzauVMtPg_434 = { 50 | NIM_STRLIT_FLAG, "<a class=\"reference external$3\"$4 href=\"$2\">$1</a>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_435 = {50, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_434};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__vYBWrr780p7faFzauVMtPg_436 = { 13 | NIM_STRLIT_FLAG, "\\href{$2}{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_437 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_436};
static const struct {
  NI cap; NIM_CHAR data[51+1];
} TM__vYBWrr780p7faFzauVMtPg_438 = { 51 | NIM_STRLIT_FLAG, "<a class=\"reference internal$3\"$4 href=\"#$2\">$1</a>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_439 = {51, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_438};
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__vYBWrr780p7faFzauVMtPg_440 = { 36 | NIM_STRLIT_FLAG, "\\hyperlink{$2}{$1} (p.~\\pageref{$2})" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_441 = {36, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_440};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_442 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_443 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_444 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_445 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_446 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_447 = { 1 | NIM_STRLIT_FLAG, "[" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_448 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_447};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_449 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_46};
static const struct {
  NI cap; NIM_CHAR data[75+1];
} TM__vYBWrr780p7faFzauVMtPg_450 = { 75 | NIM_STRLIT_FLAG, "<sup><strong><a class=\"reference internal\" href=\"#$2\">$1</a></strong></sup>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_451 = {75, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_450};
static const struct {
  NI cap; NIM_CHAR data[45+1];
} TM__vYBWrr780p7faFzauVMtPg_452 = { 45 | NIM_STRLIT_FLAG, "\\textsuperscript{\\hyperlink{$2}{\\textbf{$1}}}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_453 = {45, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_452};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_454 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_455 = { 5 | NIM_STRLIT_FLAG, "scale" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_456 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_455};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_457 = { 11 | NIM_STRLIT_FLAG, " scale=\"$1\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_458 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_457};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_459 = { 9 | NIM_STRLIT_FLAG, " scale=$1" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_460 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_459};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_461 = { 6 | NIM_STRLIT_FLAG, "height" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_462 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_461};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__vYBWrr780p7faFzauVMtPg_463 = { 12 | NIM_STRLIT_FLAG, " height=\"$1\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_464 = {12, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_463};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__vYBWrr780p7faFzauVMtPg_465 = { 10 | NIM_STRLIT_FLAG, " height=$1" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_466 = {10, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_465};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_467 = { 5 | NIM_STRLIT_FLAG, "width" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_468 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_467};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_469 = { 11 | NIM_STRLIT_FLAG, " width=\"$1\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_470 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_469};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_471 = { 9 | NIM_STRLIT_FLAG, " width=$1" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_472 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_471};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__vYBWrr780p7faFzauVMtPg_473 = { 3 | NIM_STRLIT_FLAG, "alt" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_474 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_473};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_475 = { 9 | NIM_STRLIT_FLAG, " alt=\"$1\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_476 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_475};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_477 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_478 = { 5 | NIM_STRLIT_FLAG, "align" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_479 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_478};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_480 = { 11 | NIM_STRLIT_FLAG, " align=\"$1\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_481 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_480};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_482 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_483 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_209};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_484 = { 4 | NIM_STRLIT_FLAG, "[$1]" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_485 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_484};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_486 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_487 = { 4 | NIM_STRLIT_FLAG, ".mp4" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_488 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_487};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_489 = { 4 | NIM_STRLIT_FLAG, ".ogg" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_490 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_489};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_491 = { 5 | NIM_STRLIT_FLAG, ".webm" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_492 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_491};
static const struct {
  NI cap; NIM_CHAR data[145+1];
} TM__vYBWrr780p7faFzauVMtPg_493 = { 145 | NIM_STRLIT_FLAG, "      <video$3 src=\"$1\"$2 autoPlay=\'true\' loop=\'true\' muted=\'true\'>\012      Sorry, your browser doesn\'t support embedded videos\012      </video>\012    " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_494 = {145, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_493};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__vYBWrr780p7faFzauVMtPg_495 = { 19 | NIM_STRLIT_FLAG, "<img$3 src=\"$1\"$2/>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_496 = {19, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_495};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_497 = { 6 | NIM_STRLIT_FLAG, "target" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_498 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_497};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_499 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__vYBWrr780p7faFzauVMtPg_500 = { 46 | NIM_STRLIT_FLAG, "<a class=\"reference external\" href=\"$2\">$1</a>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_501 = {46, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_500};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_502 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_436};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__vYBWrr780p7faFzauVMtPg_503 = { 24 | NIM_STRLIT_FLAG, "$3\\includegraphics$2{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_504 = {24, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_503};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_505 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_506 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_507 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_508 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_509 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_510 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_511 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__vYBWrr780p7faFzauVMtPg_512 = { 12 | NIM_STRLIT_FLAG, "number-lines" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_513 = {12, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_512};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_514 = { 4 | NIM_STRLIT_FLAG, "file" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_515 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_514};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__vYBWrr780p7faFzauVMtPg_516 = { 8 | NIM_STRLIT_FLAG, "filename" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_517 = {8, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_516};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_518 = { 4 | NIM_STRLIT_FLAG, "test" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_519 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_518};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_520 = { 6 | NIM_STRLIT_FLAG, "status" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_521 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_520};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__vYBWrr780p7faFzauVMtPg_522 = { 8 | NIM_STRLIT_FLAG, "exitcode" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_523 = {8, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_522};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__vYBWrr780p7faFzauVMtPg_524 = { 16 | NIM_STRLIT_FLAG, "default-language" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_525 = {16, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_524};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__vYBWrr780p7faFzauVMtPg_526 = { 48 | NIM_STRLIT_FLAG, "field $1 requires an integer, but \'$2\' was given" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_527 = {48, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_526};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__vYBWrr780p7faFzauVMtPg_528 = { 38 | NIM_STRLIT_FLAG, "extra arguments were given to $1: \'$2\'" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_529 = {38, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_528};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_530 = {12, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_512};
static const struct {
  NI cap; NIM_CHAR data[57+1];
} TM__vYBWrr780p7faFzauVMtPg_531 = { 57 | NIM_STRLIT_FLAG, "$nim r --backend:$backend --lib:$libpath $docCmd $options" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_532 = {57, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_531};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_533 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_534 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static NIM_CONST tyProc__9bd86QnQPXw1dUoLzfDMOKg TM__vYBWrr780p7faFzauVMtPg_535 = {NIM_NIL,NIM_NIL};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__vYBWrr780p7faFzauVMtPg_537 = { 17 | NIM_STRLIT_FLAG, "doc.listing_start" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_538 = {17, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_537};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_539 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__vYBWrr780p7faFzauVMtPg_540 = { 15 | NIM_STRLIT_FLAG, "doc.listing_end" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_541 = {15, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_540};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_542 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[33+1];
} TM__vYBWrr780p7faFzauVMtPg_543 = { 33 | NIM_STRLIT_FLAG, "<table$1 class=\"line-nums-table\">" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_544 = {33, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_543};
static const struct {
  NI cap; NIM_CHAR data[61+1];
} TM__vYBWrr780p7faFzauVMtPg_545 = { 61 | NIM_STRLIT_FLAG, "<tbody><tr><td class=\"blob-line-nums\"><pre class=\"line-nums\">" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_546 = {61, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_545};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_547 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_136};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__vYBWrr780p7faFzauVMtPg_548 = { 15 | NIM_STRLIT_FLAG, "</pre></td><td>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_549 = {15, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_548};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_550 = {17, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_537};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_551 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_552 = {15, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_540};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_553 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__vYBWrr780p7faFzauVMtPg_554 = { 26 | NIM_STRLIT_FLAG, "</td></tr></tbody></table>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_555 = {26, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_554};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__vYBWrr780p7faFzauVMtPg_556 = { 18 | NIM_STRLIT_FLAG, "doc.listing_button" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_557 = {18, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_556};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_558 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_559 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_560 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_561 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_562 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_563 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_564 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const struct {
  NI cap; NIM_CHAR data[47+1];
} TM__vYBWrr780p7faFzauVMtPg_565 = { 47 | NIM_STRLIT_FLAG, "<tt class=\"docutils literal\"><span class=\"pre\">" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_566 = {47, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_565};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__vYBWrr780p7faFzauVMtPg_567 = { 12 | NIM_STRLIT_FLAG, "</span></tt>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_568 = {12, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_567};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_569 = { 2 | NIM_STRLIT_FLAG, "\012\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_570 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_569};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_571 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_572 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_64};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_573 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_66};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_574 = {7, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_68};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_575 = {14, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_70};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_576 = {3, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_72};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__vYBWrr780p7faFzauVMtPg_577 = { 15 | NIM_STRLIT_FLAG, "\\begin{rstpre}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_578 = {15, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_577};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__vYBWrr780p7faFzauVMtPg_579 = { 15 | NIM_STRLIT_FLAG, "\012\\end{rstpre}\012\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_580 = {15, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_579};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_581 = { 9 | NIM_STRLIT_FLAG, "\\rstcode{" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_582 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_581};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_583 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_407};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_584 = { 4 | NIM_STRLIT_FLAG, "none" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_585 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_584};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_586 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__vYBWrr780p7faFzauVMtPg_587 = { 13 | NIM_STRLIT_FLAG, "<div>$1</div>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_588 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_587};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_589 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_209};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__vYBWrr780p7faFzauVMtPg_590 = { 24 | NIM_STRLIT_FLAG, "<div class=\"$1\">$2</div>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_591 = {24, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_590};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_592 = { 2 | NIM_STRLIT_FLAG, "$2" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_593 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_592};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_594 = { 4 | NIM_STRLIT_FLAG, "|$1|" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_595 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_594};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_596 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_594};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_597 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_598 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_599 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_600 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_601 = { 5 | NIM_STRLIT_FLAG, "Other" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_602 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_601};
static const struct {
  NI cap; NIM_CHAR data[64+1];
} TM__vYBWrr780p7faFzauVMtPg_603 = { 64 | NIM_STRLIT_FLAG, "<tt class=\"docutils literal\"><span class=\"pre $2\">$1</span></tt>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_604 = {64, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_603};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__vYBWrr780p7faFzauVMtPg_605 = { 21 | NIM_STRLIT_FLAG, "\\rstcode{\\span$2{$1}}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_606 = {21, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_605};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_607 = {26, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_48};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_608 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_50};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__vYBWrr780p7faFzauVMtPg_609 = { 13 | NIM_STRLIT_FLAG, "<sub>$1</sub>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_610 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_609};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_611 = { 11 | NIM_STRLIT_FLAG, "\\rstsub{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_612 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_611};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__vYBWrr780p7faFzauVMtPg_613 = { 13 | NIM_STRLIT_FLAG, "<sup>$1</sup>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_614 = {13, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_613};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_615 = { 11 | NIM_STRLIT_FLAG, "\\rstsup{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_616 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_615};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_617 = { 11 | NIM_STRLIT_FLAG, "<em>$1</em>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_618 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_617};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_619 = { 9 | NIM_STRLIT_FLAG, "\\emph{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_620 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_619};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__vYBWrr780p7faFzauVMtPg_621 = { 19 | NIM_STRLIT_FLAG, "<strong>$1</strong>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_622 = {19, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_621};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_623 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_400};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__vYBWrr780p7faFzauVMtPg_624 = { 28 | NIM_STRLIT_FLAG, "<strong><em>$1</em></strong>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_625 = {28, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_624};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__vYBWrr780p7faFzauVMtPg_626 = { 17 | NIM_STRLIT_FLAG, "\\textbf{emph{$1}}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_627 = {17, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_626};
static const struct {
  NI cap; NIM_CHAR data[61+1];
} TM__vYBWrr780p7faFzauVMtPg_628 = { 61 | NIM_STRLIT_FLAG, "<tt class=\"docutils literal\"><span class=\"pre\">$1</span></tt>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_629 = {61, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_628};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__vYBWrr780p7faFzauVMtPg_630 = { 12 | NIM_STRLIT_FLAG, "\\rstcode{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_631 = {12, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_630};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_632 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__vYBWrr780p7faFzauVMtPg_633 = { 38 | NIM_STRLIT_FLAG, "<span class=\"target\" id=\"$2\">$1</span>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_634 = {38, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_633};
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__vYBWrr780p7faFzauVMtPg_635 = { 30 | NIM_STRLIT_FLAG, "\\label{$2}\\hypertarget{$2}{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_636 = {30, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_635};
static const struct {
  NI cap; NIM_CHAR data[84+1];
} TM__vYBWrr780p7faFzauVMtPg_637 = { 84 | NIM_STRLIT_FLAG, "<img src=\"$1\" width=\"15\"\012        height=\"17\" hspace=\"2\" vspace=\"2\" class=\"smiley\" />" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_638 = {84, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_637};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__vYBWrr780p7faFzauVMtPg_639 = { 20 | NIM_STRLIT_FLAG, "\\includegraphics{$1}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_640 = {20, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_639};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__vYBWrr780p7faFzauVMtPg_641 = { 17 | NIM_STRLIT_FLAG, "doc.smiley_format" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_642 = {17, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_641};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_643 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_644 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_645 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__vYBWrr780p7faFzauVMtPg_646 = { 23 | NIM_STRLIT_FLAG, "<span id=\"$1\">$2</span>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_647 = {23, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_646};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__vYBWrr780p7faFzauVMtPg_648 = { 21 | NIM_STRLIT_FLAG, "\\nimindexterm{$1}{$2}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_649 = {21, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_648};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_650 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_651 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[60+1];
} TM__vYBWrr780p7faFzauVMtPg_652 = { 60 | NIM_STRLIT_FLAG, "<li><a class=\"reference\" id=\"$1_toc\" href=\"#$1\">$2</a></li>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_653 = {60, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_652};
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__vYBWrr780p7faFzauVMtPg_654 = { 31 | NIM_STRLIT_FLAG, "\\item\\label{$1_toc} $2\\ref{$1}\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_655 = {31, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_654};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__vYBWrr780p7faFzauVMtPg_656 = { 26 | NIM_STRLIT_FLAG, "<ul class=\"simple\">$1</ul>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_657 = {26, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_656};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__vYBWrr780p7faFzauVMtPg_658 = { 34 | NIM_STRLIT_FLAG, "\\begin{enumerate}$1\\end{enumerate}" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_659 = {34, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_658};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_660 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_661 = { 1 | NIM_STRLIT_FLAG, "." };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_662 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_661};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_663 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_55};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_664 = { 4 | NIM_STRLIT_FLAG, ".idx" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_665 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_664};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_666 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__vYBWrr780p7faFzauVMtPg_667 = { 8 | NIM_STRLIT_FLAG, "doc_toc_" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_668 = {8, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_667};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_670 = {0, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_2};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_671 = { 11 | NIM_STRLIT_FLAG, "Documents: " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_672 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_671};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_674 = { 9 | NIM_STRLIT_FLAG, "<a href=\"" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_675 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_674};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_676 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_347};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_677 = { 4 | NIM_STRLIT_FLAG, "</a>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_678 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_677};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_679 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_680 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_679};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__vYBWrr780p7faFzauVMtPg_681 = { 6 | NIM_STRLIT_FLAG, ".<br/>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_682 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_681};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_683 = { 5 | NIM_STRLIT_FLAG, "<p />" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_684 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_683};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__vYBWrr780p7faFzauVMtPg_685 = { 9 | NIM_STRLIT_FLAG, "Modules: " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_686 = {9, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_685};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__vYBWrr780p7faFzauVMtPg_687 = { 24 | NIM_STRLIT_FLAG, "<a href=\"$1.html\">$2</a>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_688 = {24, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_687};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_689 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_679};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_690 = {6, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_681};
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_691 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_683};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__vYBWrr780p7faFzauVMtPg_692 = { 21 | NIM_STRLIT_FLAG, "<h2>API symbols</h2>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_693 = {21, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_692};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__vYBWrr780p7faFzauVMtPg_694 = { 4 | NIM_STRLIT_FLAG, "<dl>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_695 = {4, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_694};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__vYBWrr780p7faFzauVMtPg_696 = { 1 | NIM_STRLIT_FLAG, "%" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_697 = {1, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_696};
static const struct {
  NI cap; NIM_CHAR data[77+1];
} TM__vYBWrr780p7faFzauVMtPg_698 = { 77 | NIM_STRLIT_FLAG, "<dt><a name=\"$2\" href=\"#$2\"><span>$1:</span></a></dt><dd><ul class=\"simple\">\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_699 = {77, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_698};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__vYBWrr780p7faFzauVMtPg_700 = { 2 | NIM_STRLIT_FLAG, ": " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_701 = {2, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_700};
static const struct {
  NI cap; NIM_CHAR data[112+1];
} TM__vYBWrr780p7faFzauVMtPg_702 = { 112 | NIM_STRLIT_FLAG, "<li><a class=\"reference external\"\012          title=\"$3\" data-doc-search-tag=\"$2\" href=\"$1\">$2</a></li>\012          " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_703 = {112, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_702};
static const struct {
  NI cap; NIM_CHAR data[101+1];
} TM__vYBWrr780p7faFzauVMtPg_704 = { 101 | NIM_STRLIT_FLAG, "<li><a class=\"reference external\"\012          data-doc-search-tag=\"$2\" href=\"$1\">$2</a></li>\012          " };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_705 = {101, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_704};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__vYBWrr780p7faFzauVMtPg_706 = { 11 | NIM_STRLIT_FLAG, "</ul></dd>\012" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_707 = {11, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_706};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__vYBWrr780p7faFzauVMtPg_708 = { 5 | NIM_STRLIT_FLAG, "</dl>" };
static const NimStringV2 TM__vYBWrr780p7faFzauVMtPg_709 = {5, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_708};
extern NIM_CONST tyArray__9amQAAkHuxu9cNghyKvw0urQ tokenClassToStr__packagesZdocutilsZhighlite_u70;
static NIM_CONST tyTuple__qsoB9cWzItmjtA8wRSiKBbA TM__vYBWrr780p7faFzauVMtPg_165 = {65,
{25, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_166}}
;
static NIM_CONST tyTuple__qsoB9cWzItmjtA8wRSiKBbA TM__vYBWrr780p7faFzauVMtPg_167 = {97,
{25, (NimStrPayload*)&TM__vYBWrr780p7faFzauVMtPg_168}}
;
extern NIM_CONST tyArray__wVkbv9aOuop9cKsgoz0aezKQ sourceLanguageToStr__packagesZdocutilsZhighlite_u68;
extern NIM_BOOL nimInErrorMode__system_u4143;
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
static N_INLINE(int, nimCmpMem)(void* a_p0, void* b_p1, NI size_p2) {
	int result;
	result = memcmp(a_p0, b_p1, ((size_t) (size_p2)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_u1750)(void* a_p0, void* b_p1, NI size_p2) {
	NIM_BOOL result;
	int T1_;
	T1_ = (int)0;
	T1_ = nimCmpMem(a_p0, b_p1, size_p2);
	result = (T1_ == ((NI32)0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringV2 a_p0, NimStringV2 b_p1) {
	NIM_BOOL result;
	NI alen_1;
	NI blen_1;
{	result = NIM_FALSE;
	alen_1 = a_p0.len;
	blen_1 = b_p1.len;
	{
		if (!(alen_1 == blen_1)) goto LA3_;
		{
			if (!(alen_1 == ((NI)0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
LA7_: ;
		result = equalMem__system_u1750(((void*) ((&a_p0.p->data[((NI)0)]))), ((void*) ((&b_p1.p->data[((NI)0)]))), (alen_1));
		goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initRstGenerator__packagesZdocutilsZrstgen_u86)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* g_p0, tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p1, tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* config_p2, NimStringV2 filename_p3, tyProc__oFHfEKFsiYTMAy9a42cSiKw findFile_p4, tyProc__lsy8uLKFmavBA17NQuqO5g msgHandler_p5, tyObject_RstFileTable__bMrfWDt5AWDVM69bYucAdbg* filenames_p6, NIM_BOOL hasToc_p7) {
	tyTuple__7q7q3E6Oj24ZNVJb9aonhAg fileParts_1;
	NimStringV2 s_1;
	tySequence__LqZapiAqCFeXPQZdoIAUew T2_;
	tyObject_Table__tro5f9chxPVpES1mQpDwZtQ T8_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&fileParts_1), sizeof(tyTuple__7q7q3E6Oj24ZNVJb9aonhAg));
	s_1.len = 0; s_1.p = NIM_NIL;
	eqcopy___pureZstrtabs_u528(&(*g_p0).config, config_p2, NIM_TRUE);
	(*g_p0).target = target_p1;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_.len = 0; T2_.p = (tySequence__LqZapiAqCFeXPQZdoIAUew_Content*) newSeqPayload(0, sizeof(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*), NIM_ALIGNOF(tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*));
	eqsink___packagesZdocutilsZrstast_u161((&(*g_p0).tocPart), T2_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(*g_p0).hasToc = hasToc_p7;
	eqcopy___system_u2694((&(*g_p0).filename), filename_p3);
	eqcopy___packagesZdocutilsZrst_u17756((&(*g_p0).filenames), filenames_p6);
	(*g_p0).splitAfter = ((NI)20);
	eqsink___system_u2700((&(*g_p0).theIndex), TM__vYBWrr780p7faFzauVMtPg_3);
	eqcopy___pureZunicode_u3788((&(*g_p0).findFile), findFile_p4, NIM_TRUE);
	eqsink___system_u2700((&(*g_p0).currentSection), TM__vYBWrr780p7faFzauVMtPg_4);
	(*g_p0).id = ((NI)0);
	(*g_p0).escMode = ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0);
	(*g_p0).curQuotationDepth = ((NI)0);
	nossplitFile(filename_p3, (&fileParts_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 T7_;
		if (!eqStrings(fileParts_1.Field2, TM__vYBWrr780p7faFzauVMtPg_6)) goto LA5_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = rawNewString(fileParts_1.Field1.len + 7);
appendString((&T7_), TM__vYBWrr780p7faFzauVMtPg_8);
appendString((&T7_), fileParts_1.Field1);
		eqsink___system_u2700((&(*g_p0).currentSection), T7_);
	}
LA5_: ;
	T8_ = initTable__vmdef_u421(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___vmdef_u559(T8_); goto LA1_;}
	eqsink___vmdef_u568((&(*g_p0).seenIndexTerms), T8_);
	eqcopy___packagesZdocutilsZrst_u2468((&(*g_p0).msgHandler), msgHandler_p5, NIM_TRUE);
	s_1 = getOrDefault__pureZstrtabs_u390(config_p2, TM__vYBWrr780p7faFzauVMtPg_10, TM__vYBWrr780p7faFzauVMtPg_11);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T13_;
		if (!!((s_1.len == 0))) goto LA11_;
		T13_ = (NI)0;
		T13_ = nsuParseInt(s_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*g_p0).splitAfter = T13_;
	}
LA11_: ;
	{
		tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA i_1;
		NI res_1;
		i_1 = (tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)0;
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= ((NI)5))) goto LA16;
				i_1 = ((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA) (res_1));
				eqsink___system_u2700((&(*g_p0).meta[(i_1)- 0]), TM__vYBWrr780p7faFzauVMtPg_12);
				res_1 += ((NI)1);
			} LA16: ;
		}
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(s_1);
		eqdestroy___pureZos_u200((&fileParts_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqsink___docgen_u3501)(tyProc__9bd86QnQPXw1dUoLzfDMOKg* dest_p0, tyProc__9bd86QnQPXw1dUoLzfDMOKg src_p1) {
	void* colontmp_;
	colontmp_ = (*dest_p0).ClE_0;
	(*dest_p0).ClE_0 = src_p1.ClE_0;
	(*dest_p0).ClP_0 = src_p1.ClP_0;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn(colontmp_);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose(colontmp_);
	}
LA4_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, nextSplitPoint__packagesZdocutilsZrstgen_u246)(NimStringV2 s_p0, NI start_p1) {
	NI result;
{	result = start_p1;
	{
		while (1) {
			if (!(result < (NI)(s_p0.len + ((NI)0)))) goto LA2;
			switch (((NU8)(s_p0.p->data[result]))) {
			case 95:
			{
				goto BeforeRet_;
			}
			break;
			case 97 ... 122:
			{
				{
					if (!((NI)(result + ((NI)1)) < (NI)(s_p0.len + ((NI)0)))) goto LA7_;
					{
						if (!(((NU8)(s_p0.p->data[(NI)(result + ((NI)1))])) >= ((NU8)(65)) && ((NU8)(s_p0.p->data[(NI)(result + ((NI)1))])) <= ((NU8)(90)))) goto LA11_;
						goto BeforeRet_;
					}
LA11_: ;
				}
LA7_: ;
			}
			break;
			default:
			{
			}
			break;
			}
			result += ((NI)1);
		} LA2: ;
	}
	result -= ((NI)1);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addSplitter__packagesZdocutilsZrstgen_u243)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2* dest_p1) {
	switch (target_p0) {
	case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
	{
		prepareAdd((&(*dest_p1)), 7);
appendString((&(*dest_p1)), TM__vYBWrr780p7faFzauVMtPg_15);
	}
	break;
	case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
	{
		prepareAdd((&(*dest_p1)), 2);
appendString((&(*dest_p1)), TM__vYBWrr780p7faFzauVMtPg_17);
	}
	break;
	default: __builtin_unreachable();
	}
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, addHtmlChar__packagesZdocutilsZrstgen_u214)(NimStringV2* dest_p0, NIM_CHAR c_p1) {
	switch (((NU8)(c_p1))) {
	case 38:
	{
		prepareAdd((&(*dest_p0)), 5);
appendString((&(*dest_p0)), TM__vYBWrr780p7faFzauVMtPg_19);
	}
	break;
	case 60:
	{
		prepareAdd((&(*dest_p0)), 4);
appendString((&(*dest_p0)), TM__vYBWrr780p7faFzauVMtPg_21);
	}
	break;
	case 62:
	{
		prepareAdd((&(*dest_p0)), 4);
appendString((&(*dest_p0)), TM__vYBWrr780p7faFzauVMtPg_23);
	}
	break;
	case 34:
	{
		prepareAdd((&(*dest_p0)), 6);
appendString((&(*dest_p0)), TM__vYBWrr780p7faFzauVMtPg_25);
	}
	break;
	default:
	{
		nimAddCharV1((&(*dest_p0)), c_p1);
	}
	break;
	}
}
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1) {
	(*(*dest_p0).p).data[(*dest_p0).len] = c_p1;
	(*dest_p0).len += ((NI)1);
	(*(*dest_p0).p).data[(*dest_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, addTexChar__packagesZdocutilsZrstgen_u217)(NimStringV2* dest_p0, NIM_CHAR c_p1, tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode_p2) {
	switch (((NU8)(c_p1))) {
	case 95:
	case 38:
	case 35:
	case 37:
	{
		NimStringV2 colontmpD_;
		NimStringV2 T2_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T2_.len = 0; T2_.p = NIM_NIL;
		T2_ = rawNewString(2);
appendString((&T2_), TM__vYBWrr780p7faFzauVMtPg_27);
appendChar((&T2_), c_p1);
		colontmpD_ = T2_;
		prepareAdd((&(*dest_p0)), colontmpD_.len + 0);
appendString((&(*dest_p0)), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
	break;
	case 36:
	{
		{
			if (!(escMode_p2 == ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)2))) goto LA6_;
			nimAddCharV1((&(*dest_p0)), c_p1);
		}
		goto LA4_;
LA6_: ;
		{
			NimStringV2 colontmpD__2;
			NimStringV2 T9_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T9_.len = 0; T9_.p = NIM_NIL;
			T9_ = rawNewString(2);
appendString((&T9_), TM__vYBWrr780p7faFzauVMtPg_28);
appendChar((&T9_), c_p1);
			colontmpD__2 = T9_;
			prepareAdd((&(*dest_p0)), colontmpD__2.len + 0);
appendString((&(*dest_p0)), colontmpD__2);
			eqdestroy___system_u2691(colontmpD__2);
		}
LA4_: ;
	}
	break;
	case 126:
	case 94:
	{
		NimStringV2 colontmpD__3;
		NimStringV2 T11_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T11_.len = 0; T11_.p = NIM_NIL;
		T11_ = rawNewString(4);
appendString((&T11_), TM__vYBWrr780p7faFzauVMtPg_29);
appendChar((&T11_), c_p1);
appendString((&T11_), TM__vYBWrr780p7faFzauVMtPg_31);
		colontmpD__3 = T11_;
		prepareAdd((&(*dest_p0)), colontmpD__3.len + 0);
appendString((&(*dest_p0)), colontmpD__3);
		eqdestroy___system_u2691(colontmpD__3);
	}
	break;
	case 96:
	{
		prepareAdd((&(*dest_p0)), 17);
appendString((&(*dest_p0)), TM__vYBWrr780p7faFzauVMtPg_33);
	}
	break;
	case 92:
	{
		prepareAdd((&(*dest_p0)), 16);
appendString((&(*dest_p0)), TM__vYBWrr780p7faFzauVMtPg_35);
	}
	break;
	case 123:
	{
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 T15_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		T15_.len = 0; T15_.p = NIM_NIL;
		{
			if (!(escMode_p2 == ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)2))) goto LA18_;
			colontmpD__4 = TM__vYBWrr780p7faFzauVMtPg_37;
			T15_ = colontmpD__4;
		}
		goto LA16_;
LA18_: ;
		{
			colontmpD__5 = TM__vYBWrr780p7faFzauVMtPg_39;
			T15_ = colontmpD__5;
		}
LA16_: ;
		prepareAdd((&(*dest_p0)), T15_.len + 0);
appendString((&(*dest_p0)), T15_);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
	}
	break;
	case 125:
	{
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 T22_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		T22_.len = 0; T22_.p = NIM_NIL;
		{
			if (!(escMode_p2 == ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)2))) goto LA25_;
			colontmpD__6 = TM__vYBWrr780p7faFzauVMtPg_41;
			T22_ = colontmpD__6;
		}
		goto LA23_;
LA25_: ;
		{
			colontmpD__7 = TM__vYBWrr780p7faFzauVMtPg_43;
			T22_ = colontmpD__7;
		}
LA23_: ;
		prepareAdd((&(*dest_p0)), T22_.len + 0);
appendString((&(*dest_p0)), T22_);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
	}
	break;
	case 93:
	{
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 T29_;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		T29_.len = 0; T29_.p = NIM_NIL;
		{
			if (!(escMode_p2 == ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)1))) goto LA32_;
			colontmpD__8 = TM__vYBWrr780p7faFzauVMtPg_45;
			T29_ = colontmpD__8;
		}
		goto LA30_;
LA32_: ;
		{
			colontmpD__9 = TM__vYBWrr780p7faFzauVMtPg_47;
			T29_ = colontmpD__9;
		}
LA30_: ;
		prepareAdd((&(*dest_p0)), T29_.len + 0);
appendString((&(*dest_p0)), T29_);
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
	}
	break;
	default:
	{
		nimAddCharV1((&(*dest_p0)), c_p1);
	}
	break;
	}
}
static N_INLINE(void, escChar__packagesZdocutilsZrstgen_u238)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2* dest_p1, NIM_CHAR c_p2, tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch (target_p0) {
	case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
	{
		addHtmlChar__packagesZdocutilsZrstgen_u214(dest_p1, c_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
	{
		addTexChar__packagesZdocutilsZrstgen_u217(dest_p1, c_p2, escMode_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, esc__packagesZdocutilsZrstgen_u264)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2 s_p1, NI splitAfter_p2, tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA escMode_p3) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = TM__vYBWrr780p7faFzauVMtPg_13;
	{
		NI partLen_1;
		NI j_1;
		if (!(((NI)0) <= splitAfter_p2)) goto LA3_;
		partLen_1 = ((NI)0);
		j_1 = ((NI)0);
		{
			while (1) {
				NI k_1;
				if (!(j_1 < s_p1.len)) goto LA6;
				k_1 = nextSplitPoint__packagesZdocutilsZrstgen_u246(s_p1, j_1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				partLen_1 = ((NI)0);
				addSplitter__packagesZdocutilsZrstgen_u243(target_p0, (&result));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					NI i_1;
					NI res_1;
					i_1 = (NI)0;
					res_1 = j_1;
					{
						while (1) {
							if (!(res_1 <= k_1)) goto LA9;
							i_1 = ((NI) (res_1));
							escChar__packagesZdocutilsZrstgen_u238(target_p0, (&result), s_p1.p->data[i_1], escMode_p3);
							if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
							res_1 += ((NI)1);
						} LA9: ;
					}
				}
				partLen_1 += (NI)((NI)(k_1 - j_1) + ((NI)1));
				j_1 = (NI)(k_1 + ((NI)1));
			} LA6: ;
		}
	}
	goto LA1_;
LA3_: ;
	{
		{
			NI i_2;
			NI colontmp_;
			NI res_2;
			i_2 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = (NI)(s_p1.len - ((NI)1));
			res_2 = ((NI)0);
			{
				while (1) {
					if (!(res_2 <= colontmp_)) goto LA13;
					i_2 = ((NI) (res_2));
					escChar__packagesZdocutilsZrstgen_u238(target_p0, (&result), s_p1.p->data[i_2], escMode_p3);
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_2 += ((NI)1);
				} LA13: ;
			}
		}
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, dispA__packagesZdocutilsZrstgen_u310)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2* dest_p1, NimStringV2 xml_p2, NimStringV2 tex_p3, NimStringV2* args_p4, NI args_p4Len_0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!!((target_p0 == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1)))) goto LA3_;
		nsuAddf(dest_p1, xml_p2, args_p4, args_p4Len_0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		nsuAddf(dest_p1, tex_p3, args_p4, args_p4Len_0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderCodeLang__packagesZdocutilsZrstgen_u3809)(NimStringV2* result_p0, tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA lang_p1, NimStringV2 code_p2, tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p3) {
	tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g g_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&g_1), sizeof(tyObject_GeneralTokenizer__t8mWIshWZpNBbL0h6CSV0g));
	g_1.Sup.m_type = (&NTIv2__t8mWIshWZpNBbL0h6CSV0g_);
	initGeneralTokenizer__packagesZdocutilsZhighlite_u154((&g_1), code_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		while (1) {
			getNextToken__packagesZdocutilsZhighlite_u2142((&g_1), lang_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			switch (g_1.kind) {
			case ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)0):
			{
				goto LA1;
			}
			break;
			case ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)1):
			case ((tyEnum_TokenClass__uuIuZkdjy9cYGTn49aPJbZzA)2):
			{
				NimStringV2 colontmpD_;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD_ = substr__system_u8651(code_p2, g_1.start, (NI)((NI)(g_1.length + g_1.start) - ((NI)1)));
				prepareAdd((&(*result_p0)), colontmpD_.len + 0);
appendString((&(*result_p0)), colontmpD_);
				eqdestroy___system_u2691(colontmpD_);
			}
			break;
			default:
			{
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__2 = substr__system_u8651(code_p2, g_1.start, (NI)((NI)(g_1.length + g_1.start) - ((NI)1)));
				colontmpD__3 = esc__packagesZdocutilsZrstgen_u264(target_p3, colontmpD__2, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T7_[0] = colontmpD__3;
				T7_[1] = tokenClassToStr__packagesZdocutilsZhighlite_u70[(g_1.kind)- 0];
				dispA__packagesZdocutilsZrstgen_u310(target_p3, result_p0, TM__vYBWrr780p7faFzauVMtPg_49, TM__vYBWrr780p7faFzauVMtPg_51, T7_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				{
					LA6_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			}
		}
	} LA1: ;
	deinitGeneralTokenizer__packagesZdocutilsZhighlite_u157((&g_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderNimCode__packagesZdocutilsZrstgen_u3815)(NimStringV2* result_p0, NimStringV2 code_p1, tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	renderCodeLang__packagesZdocutilsZrstgen_u3809(result_p0, ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)1), code_p1, target_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, setIndexTerm__packagesZdocutilsZrstgen_u353)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ k_p1, NimStringV2 htmlFile_p2, NimStringV2 id_p3, NimStringV2 term_p4, NimStringV2 linkTitle_p5, NimStringV2 linkDesc_p6, NI line_p7) {
	tyTuple__dPNkpxgceTc63bP5seHZGw tmpTuple_1;
	NimStringV2 entry_1;
	NIM_BOOL isTitle_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__dPNkpxgceTc63bP5seHZGw));
	entry_1.len = 0; entry_1.p = NIM_NIL;
	tmpTuple_1 = formatIndexEntry__packagesZdocutilsZrstidx_u76(k_p1, htmlFile_p2, id_p3, term_p4, linkTitle_p5, linkDesc_p6, line_p7);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	entry_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u2688((&tmpTuple_1.Field0));
	isTitle_1 = tmpTuple_1.Field1;
	{
		if (!isTitle_1) goto LA3_;
		insert__system_u8268((&(*d_p0).theIndex), entry_1, ((NI)0));
	}
	goto LA1_;
LA3_: ;
	{
		prepareAdd((&(*d_p0).theIndex), entry_1.len + 0);
appendString((&(*d_p0).theIndex), entry_1);
	}
LA1_: ;
	eqdestroy___system_u2691(entry_1);
	eqdestroy___pureZstrutils_u2810(tmpTuple_1);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, prettyLink__packagesZdocutilsZrstgen_u81)(NimStringV2 file_p0) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = noschangeFileExt(file_p0, TM__vYBWrr780p7faFzauVMtPg_52);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	result = nsuReplaceStr(colontmpD_, TM__vYBWrr780p7faFzauVMtPg_54, TM__vYBWrr780p7faFzauVMtPg_56);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	eqdestroy___system_u2691(colontmpD_);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, htmlFileRelPath__packagesZdocutilsZrstgen_u377)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0) {
	NimStringV2 result;
	NimStringV2 T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		NimStringV2 colontmpD_;
		if (!((*d_p0).outDir.len == ((NI)0))) goto LA4_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = nosextractFilename((*d_p0).filename);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = noschangeFileExt(colontmpD_, TM__vYBWrr780p7faFzauVMtPg_85);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA2_;
LA4_: ;
	{
		result = nosrelativePath((*d_p0).destFile, (*d_p0).outDir, 47);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA2_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, spaces__pureZstrutils_u1139)(NI n_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nsuRepeatChar(32, n_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderHeadline__packagesZdocutilsZrstgen_u3635)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NimStringV2 tmp_1;
	NimStringV2 tocName_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 T39_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	tocName_1.len = 0; tocName_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	tmp_1 = TM__vYBWrr780p7faFzauVMtPg_58;
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__packagesZdocutilsZrstast_u114(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T3_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA5;
				i_1 = ((NI) (res_1));
				renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[i_1], (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				res_1 += ((NI)1);
			} LA5: ;
		}
	}
	eqcopy___system_u2694((&(*d_p0).currentSection), tmp_1);
	colontmpD_ = renderRstToText__packagesZdocutilsZrstast_u856(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	tocName_1 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD_, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		NimStringV2 colontmpD__10;
		tyArray__A2YC0h9cZydgH7zGAndH9bLg T11_;
		if (!(*d_p0).hasToc) goto LA8_;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmpD__6 = eqdup___packagesZdocutilsZrstast_u291(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		add__packagesZdocutilsZrstast_u466((&(*d_p0).tocPart), colontmpD__6);
		colontmpD__7 = dollar___systemZdollars_u9((*n_p1)._kind_5.level);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		T11_[0] = colontmpD__7;
		{
			if (!((*n_p1).anchor.len == 0)) goto LA14_;
			colontmpD__8 = TM__vYBWrr780p7faFzauVMtPg_63;
			T11_[1] = colontmpD__8;
		}
		goto LA12_;
LA14_: ;
		{
			NimStringV2 T17_;
			T17_.len = 0; T17_.p = NIM_NIL;
			switch ((*d_p0).target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				NimStringV2 T19_;
				T19_.len = 0; T19_.p = NIM_NIL;
				T19_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T19_), TM__vYBWrr780p7faFzauVMtPg_65);
appendString((&T19_), (*n_p1).anchor);
appendString((&T19_), TM__vYBWrr780p7faFzauVMtPg_67);
				colontmpD__9 = T19_;
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				NimStringV2 T21_;
				T21_.len = 0; T21_.p = NIM_NIL;
				T21_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T21_), TM__vYBWrr780p7faFzauVMtPg_69);
appendString((&T21_), (*n_p1).anchor);
appendString((&T21_), TM__vYBWrr780p7faFzauVMtPg_71);
appendString((&T21_), (*n_p1).anchor);
appendString((&T21_), TM__vYBWrr780p7faFzauVMtPg_73);
				colontmpD__9 = T21_;
			}
			break;
			default: __builtin_unreachable();
			}
			T11_[1] = colontmpD__9;
		}
LA12_: ;
		T11_[2] = tmp_1;
		colontmpD__10 = nimCharToStr(((NIM_CHAR) (((NI)((NI)((*n_p1)._kind_5.level - ((NI)1)) + ((NI)65))))));
		T11_[3] = colontmpD__10;
		T11_[4] = (*n_p1).anchor;
		T11_[5] = tocName_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_60, TM__vYBWrr780p7faFzauVMtPg_62, T11_, 6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
		{
			LA10_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA6_;
LA8_: ;
	{
		NimStringV2 colontmpD__11;
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 colontmpD__14;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T26_;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
		colontmpD__11 = dollar___systemZdollars_u9((*n_p1)._kind_5.level);
		if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		T26_[0] = colontmpD__11;
		{
			if (!((*n_p1).anchor.len == 0)) goto LA29_;
			colontmpD__12 = TM__vYBWrr780p7faFzauVMtPg_78;
			T26_[1] = colontmpD__12;
		}
		goto LA27_;
LA29_: ;
		{
			NimStringV2 T32_;
			T32_.len = 0; T32_.p = NIM_NIL;
			switch ((*d_p0).target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				NimStringV2 T34_;
				T34_.len = 0; T34_.p = NIM_NIL;
				T34_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T34_), TM__vYBWrr780p7faFzauVMtPg_79);
appendString((&T34_), (*n_p1).anchor);
appendString((&T34_), TM__vYBWrr780p7faFzauVMtPg_80);
				colontmpD__13 = T34_;
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				NimStringV2 T36_;
				T36_.len = 0; T36_.p = NIM_NIL;
				T36_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T36_), TM__vYBWrr780p7faFzauVMtPg_81);
appendString((&T36_), (*n_p1).anchor);
appendString((&T36_), TM__vYBWrr780p7faFzauVMtPg_82);
appendString((&T36_), (*n_p1).anchor);
appendString((&T36_), TM__vYBWrr780p7faFzauVMtPg_83);
				colontmpD__13 = T36_;
			}
			break;
			default: __builtin_unreachable();
			}
			T26_[1] = colontmpD__13;
		}
LA27_: ;
		T26_[2] = tmp_1;
		colontmpD__14 = nimCharToStr(((NIM_CHAR) (((NI)((NI)((*n_p1)._kind_5.level - ((NI)1)) + ((NI)65))))));
		T26_[3] = colontmpD__14;
		T26_[4] = tocName_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_75, TM__vYBWrr780p7faFzauVMtPg_77, T26_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		{
			LA25_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__14);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
			eqdestroy___system_u2691(colontmpD__11);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA6_: ;
	colontmpD__2 = htmlFileRelPath__packagesZdocutilsZrstgen_u377(d_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__3 = addNodes__packagesZdocutilsZrst_u80(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T39_.len = 0; T39_.p = NIM_NIL;
	colontmpD__4 = spaces__pureZstrutils_u1139((((((NI)0) >= (*n_p1)._kind_5.level) ? ((NI)0) : (*n_p1)._kind_5.level)));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T39_ = rawNewString(colontmpD__4.len + tmp_1.len + 0);
appendString((&T39_), colontmpD__4);
appendString((&T39_), tmp_1);
	colontmpD__5 = T39_;
	setIndexTerm__packagesZdocutilsZrstgen_u353(d_p0, ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)2), colontmpD__2, (*n_p1).anchor, colontmpD__3, colontmpD__5, TM__vYBWrr780p7faFzauVMtPg_86, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(tocName_1);
		eqdestroy___system_u2691(tmp_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderOverline__packagesZdocutilsZrstgen_u3660)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		NimStringV2 T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*n_p1)._kind_5.level == ((NI)0));
		if (!(T3_)) goto LA4_;
		T3_ = ((*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)2))- 0].len == ((NI)0));
LA4_: ;
		if (!T3_) goto LA5_;
		T7_.len = 0; T7_.p = NIM_NIL;
		T7_ = addNodes__packagesZdocutilsZrst_u80(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto BeforeRet_;}
		eqsink___system_u2700((&(*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)1))- 0]), T7_);
		{
			NI i_1;
			NI colontmp_;
			NI T9_;
			NI res_1;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T9_ = (NI)0;
			T9_ = len__packagesZdocutilsZrstast_u114(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmp_ = (NI)(T9_ - ((NI)1));
			res_1 = ((NI)0);
			{
				while (1) {
					tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* T12_;
					if (!(res_1 <= colontmp_)) goto LA11;
					i_1 = ((NI) (res_1));
					T12_ = (tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ*)0;
					T12_ = d_p0;
					renderRstToOut__packagesZdocutilsZrstgen_u324(T12_, (*n_p1).sons.p->data[i_1], (&(*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)2))- 0]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_1 += ((NI)1);
				} LA11: ;
			}
		}
		eqcopy___system_u2694((&(*d_p0).currentSection), (*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)2))- 0]);
	}
	goto LA1_;
LA5_: ;
	{
		NIM_BOOL T14_;
		T14_ = (NIM_BOOL)0;
		T14_ = ((*n_p1)._kind_5.level == ((NI)0));
		if (!(T14_)) goto LA15_;
		T14_ = ((*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)3))- 0].len == ((NI)0));
LA15_: ;
		if (!T14_) goto LA16_;
		{
			NI i_2;
			NI colontmp__2;
			NI T19_;
			NI res_2;
			i_2 = (NI)0;
			colontmp__2 = (NI)0;
			T19_ = (NI)0;
			T19_ = len__packagesZdocutilsZrstast_u114(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmp__2 = (NI)(T19_ - ((NI)1));
			res_2 = ((NI)0);
			{
				while (1) {
					tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* T22_;
					if (!(res_2 <= colontmp__2)) goto LA21;
					i_2 = ((NI) (res_2));
					T22_ = (tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ*)0;
					T22_ = d_p0;
					renderRstToOut__packagesZdocutilsZrstgen_u324(T22_, (*n_p1).sons.p->data[i_2], (&(*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)3))- 0]));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					res_2 += ((NI)1);
				} LA21: ;
			}
		}
		eqcopy___system_u2694((&(*d_p0).currentSection), (*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)3))- 0]);
	}
	goto LA1_;
LA16_: ;
	{
		NimStringV2 tmp_1;
		NimStringV2 tocName_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NimStringV2 colontmpD__9;
		tyArray__awn6UrBeChh9cVy9ccoluuYg T29_;
		NimStringV2 T40_;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		tocName_1.len = 0; tocName_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
		tmp_1 = TM__vYBWrr780p7faFzauVMtPg_87;
		{
			NI i_3;
			NI colontmp__3;
			NI T26_;
			NI res_3;
			i_3 = (NI)0;
			colontmp__3 = (NI)0;
			T26_ = (NI)0;
			T26_ = len__packagesZdocutilsZrstast_u114(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
			colontmp__3 = (NI)(T26_ - ((NI)1));
			res_3 = ((NI)0);
			{
				while (1) {
					if (!(res_3 <= colontmp__3)) goto LA28;
					i_3 = ((NI) (res_3));
					renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[i_3], (&tmp_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
					res_3 += ((NI)1);
				} LA28: ;
			}
		}
		eqcopy___system_u2694((&(*d_p0).currentSection), tmp_1);
		colontmpD_ = renderRstToText__packagesZdocutilsZrstast_u856(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		tocName_1 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD_, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		colontmpD__2 = dollar___systemZdollars_u9((*n_p1)._kind_5.level);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		T29_[0] = colontmpD__2;
		{
			if (!((*n_p1).anchor.len == 0)) goto LA32_;
			colontmpD__3 = TM__vYBWrr780p7faFzauVMtPg_92;
			T29_[1] = colontmpD__3;
		}
		goto LA30_;
LA32_: ;
		{
			NimStringV2 T35_;
			T35_.len = 0; T35_.p = NIM_NIL;
			switch ((*d_p0).target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				NimStringV2 T37_;
				T37_.len = 0; T37_.p = NIM_NIL;
				T37_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T37_), TM__vYBWrr780p7faFzauVMtPg_93);
appendString((&T37_), (*n_p1).anchor);
appendString((&T37_), TM__vYBWrr780p7faFzauVMtPg_94);
				colontmpD__4 = T37_;
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				NimStringV2 T39_;
				T39_.len = 0; T39_.p = NIM_NIL;
				T39_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T39_), TM__vYBWrr780p7faFzauVMtPg_95);
appendString((&T39_), (*n_p1).anchor);
appendString((&T39_), TM__vYBWrr780p7faFzauVMtPg_96);
appendString((&T39_), (*n_p1).anchor);
appendString((&T39_), TM__vYBWrr780p7faFzauVMtPg_97);
				colontmpD__4 = T39_;
			}
			break;
			default: __builtin_unreachable();
			}
			T29_[1] = colontmpD__4;
		}
LA30_: ;
		T29_[2] = tmp_1;
		colontmpD__5 = nimCharToStr(((NIM_CHAR) (((NI)((NI)((*n_p1)._kind_5.level - ((NI)1)) + ((NI)65))))));
		T29_[3] = colontmpD__5;
		T29_[4] = tocName_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_89, TM__vYBWrr780p7faFzauVMtPg_91, T29_, 5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		colontmpD__6 = htmlFileRelPath__packagesZdocutilsZrstgen_u377(d_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		colontmpD__7 = addNodes__packagesZdocutilsZrst_u80(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		T40_.len = 0; T40_.p = NIM_NIL;
		colontmpD__8 = spaces__pureZstrutils_u1139((((((NI)0) >= (*n_p1)._kind_5.level) ? ((NI)0) : (*n_p1)._kind_5.level)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		T40_ = rawNewString(colontmpD__8.len + tmp_1.len + 0);
appendString((&T40_), colontmpD__8);
appendString((&T40_), tmp_1);
		colontmpD__9 = T40_;
		setIndexTerm__packagesZdocutilsZrstgen_u353(d_p0, ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)2), colontmpD__6, (*n_p1).anchor, colontmpD__7, colontmpD__9, TM__vYBWrr780p7faFzauVMtPg_98, ((NI)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA24_;
		{
			LA24_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__9);
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
			eqdestroy___system_u2691(tocName_1);
			eqdestroy___system_u2691(tmp_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderAux__packagesZdocutilsZrstgen_u340)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2 html_p2, NimStringV2 tex_p3, NimStringV2* result_p4) {
	NimStringV2 tmp_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	tmp_1 = TM__vYBWrr780p7faFzauVMtPg_99;
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__packagesZdocutilsZrstast_u114(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T3_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA5;
				i_1 = ((NI) (res_1));
				renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[i_1], (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				res_1 += ((NI)1);
			} LA5: ;
		}
	}
	switch ((*d_p0).target) {
	case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		T8_[0] = tmp_1;
		{
			if (!((*n_p1).anchor.len == 0)) goto LA11_;
			colontmpD_ = TM__vYBWrr780p7faFzauVMtPg_100;
			T8_[1] = colontmpD_;
		}
		goto LA9_;
LA11_: ;
		{
			NimStringV2 T14_;
			T14_.len = 0; T14_.p = NIM_NIL;
			switch ((*d_p0).target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				NimStringV2 T16_;
				T16_.len = 0; T16_.p = NIM_NIL;
				T16_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T16_), TM__vYBWrr780p7faFzauVMtPg_101);
appendString((&T16_), (*n_p1).anchor);
appendString((&T16_), TM__vYBWrr780p7faFzauVMtPg_102);
				colontmpD__2 = T16_;
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				NimStringV2 T18_;
				T18_.len = 0; T18_.p = NIM_NIL;
				T18_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T18_), TM__vYBWrr780p7faFzauVMtPg_103);
appendString((&T18_), (*n_p1).anchor);
appendString((&T18_), TM__vYBWrr780p7faFzauVMtPg_104);
appendString((&T18_), (*n_p1).anchor);
appendString((&T18_), TM__vYBWrr780p7faFzauVMtPg_105);
				colontmpD__2 = T18_;
			}
			break;
			default: __builtin_unreachable();
			}
			T8_[1] = colontmpD__2;
		}
LA9_: ;
		nsuAddf(result_p4, html_p2, T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA7_;
		{
			LA7_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
			eqdestroy___system_u2691(colontmpD_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
	{
		NimStringV2 colontmpD__3;
		NimStringV2 colontmpD__4;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T23_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		T23_[0] = tmp_1;
		{
			if (!((*n_p1).anchor.len == 0)) goto LA26_;
			colontmpD__3 = TM__vYBWrr780p7faFzauVMtPg_106;
			T23_[1] = colontmpD__3;
		}
		goto LA24_;
LA26_: ;
		{
			NimStringV2 T29_;
			T29_.len = 0; T29_.p = NIM_NIL;
			switch ((*d_p0).target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				NimStringV2 T31_;
				T31_.len = 0; T31_.p = NIM_NIL;
				T31_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T31_), TM__vYBWrr780p7faFzauVMtPg_107);
appendString((&T31_), (*n_p1).anchor);
appendString((&T31_), TM__vYBWrr780p7faFzauVMtPg_108);
				colontmpD__4 = T31_;
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				NimStringV2 T33_;
				T33_.len = 0; T33_.p = NIM_NIL;
				T33_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T33_), TM__vYBWrr780p7faFzauVMtPg_109);
appendString((&T33_), (*n_p1).anchor);
appendString((&T33_), TM__vYBWrr780p7faFzauVMtPg_110);
appendString((&T33_), (*n_p1).anchor);
appendString((&T33_), TM__vYBWrr780p7faFzauVMtPg_111);
				colontmpD__4 = T33_;
			}
			break;
			default: __builtin_unreachable();
			}
			T23_[1] = colontmpD__4;
		}
LA24_: ;
		nsuAddf(result_p4, tex_p3, T23_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
		{
			LA22_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default: __builtin_unreachable();
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(tmp_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, nimPrepareStrMutationV2)(NimStringV2* s_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = !(((*s_p0).p == ((NimStrPayload*) NIM_NIL)));
		if (!(T3_)) goto LA4_;
		T3_ = ((NI)((*(*s_p0).p).cap & ((NI)IL64(4611686018427387904))) == ((NI)IL64(4611686018427387904)));
LA4_: ;
		if (!T3_) goto LA5_;
		nimPrepareStrMutationImpl__system_u2430(s_p0);
	}
LA5_: ;
}
static N_INLINE(NIM_CHAR*, X5BX5D___system_u8118)(NimStringV2* s_p0, NI i_p1) {
	NIM_CHAR* result;
	nimPrepareStrMutationV2((&(*s_p0)));
	result = (&(*s_p0).p->data[(NI)((*s_p0).len - i_p1)]);
	return result;
}
static N_INLINE(tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA, dotdot___stdZstrbasics_u49)(NI a_p0, NI b_p1) {
	tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1286)(NimStringV2 s_p0, tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA x_p1) {
	NimStringV2 result;
	NI a_1;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)(x_p1.b - a_1) + ((NI)1));
	result = mnewString((L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				nimPrepareStrMutationV2((&result));
				result.p->data[i_1] = s_p0.p->data[(NI)(i_1 + a_1)];
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderEnumList__packagesZdocutilsZrstgen_u3909)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NimStringV2 specifier_1;
	NimStringV2 specStart_1;
	NimStringV2 pre_1;
	NimStringV2 post_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NI i1_1;
	NI i2_1;
	tyObject_HSlice__OAVyDXS0QPw7LdXClfU2hA enumR_1;
	NimStringV2 T116_;
	NimStringV2 T117_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	specifier_1.len = 0; specifier_1.p = NIM_NIL;
	specStart_1.len = 0; specStart_1.p = NIM_NIL;
	pre_1.len = 0; pre_1.p = NIM_NIL;
	post_1.len = 0; post_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	specifier_1 = TM__vYBWrr780p7faFzauVMtPg_128;
	specStart_1 = TM__vYBWrr780p7faFzauVMtPg_129;
	i1_1 = ((NI)0);
	pre_1 = TM__vYBWrr780p7faFzauVMtPg_130;
	i2_1 = (NI)((*n_p1)._kind_2.labelFmt.len - ((NI)1));
	post_1 = TM__vYBWrr780p7faFzauVMtPg_131;
	{
		if (!((NU8)((*n_p1)._kind_2.labelFmt.p->data[((NI)0)]) == (NU8)(40))) goto LA4_;
		i1_1 = ((NI)1);
		pre_1 = TM__vYBWrr780p7faFzauVMtPg_133;
	}
LA4_: ;
	{
		NIM_BOOL T8_;
		NIM_CHAR* T9_;
		NIM_CHAR* T11_;
		NIM_CHAR* T14_;
		NimStringV2 T15_;
		T8_ = (NIM_BOOL)0;
		T9_ = (NIM_CHAR*)0;
		T9_ = X5BX5D___system_u8118((&(*n_p1)._kind_2.labelFmt), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_ = ((NU8)((*T9_)) == (NU8)(41));
		if (T8_) goto LA10_;
		T11_ = (NIM_CHAR*)0;
		T11_ = X5BX5D___system_u8118((&(*n_p1)._kind_2.labelFmt), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T8_ = ((NU8)((*T11_)) == (NU8)(46));
LA10_: ;
		if (!T8_) goto LA12_;
		i2_1 = (NI)((*n_p1)._kind_2.labelFmt.len - ((NI)2));
		T14_ = (NIM_CHAR*)0;
		T14_ = X5BX5D___system_u8118((&(*n_p1)._kind_2.labelFmt), ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = nimCharToStr((*T14_));
		eqsink___system_u2700((&post_1), T15_);
	}
LA12_: ;
	enumR_1 = dotdot___stdZstrbasics_u49(i1_1, i2_1);
	{
		NimStringV2 colontmpD__3;
		NimStringV2 T21_;
		if (!((*d_p0).target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1))) goto LA18_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T21_.len = 0; T21_.p = NIM_NIL;
		T21_ = rawNewString((*n_p1)._kind_2.labelFmt.len + 3);
appendString((&T21_), TM__vYBWrr780p7faFzauVMtPg_135);
appendString((&T21_), (*n_p1)._kind_2.labelFmt);
appendString((&T21_), TM__vYBWrr780p7faFzauVMtPg_137);
		colontmpD__3 = T21_;
		prepareAdd((&(*result_p2)), colontmpD__3.len + 0);
appendString((&(*result_p2)), colontmpD__3);
		{
			NIM_BOOL T24_;
			NimStringV2 labelDef_1;
			NimStringV2 colontmpD__4;
			T24_ = (NIM_BOOL)0;
			T24_ = nsuIsDigitChar((*n_p1)._kind_2.labelFmt.p->data[i1_1]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
			if (!T24_) goto LA25_;
			labelDef_1.len = 0; labelDef_1.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			labelDef_1 = TM__vYBWrr780p7faFzauVMtPg_138;
			{
				NIM_BOOL T30_;
				NimStringV2 T34_;
				T30_ = (NIM_BOOL)0;
				T30_ = !((pre_1.len == 0));
				if (T30_) goto LA31_;
				T30_ = !((post_1.len == 0));
LA31_: ;
				if (!T30_) goto LA32_;
				T34_.len = 0; T34_.p = NIM_NIL;
				T34_ = rawNewString(pre_1.len + post_1.len + 15);
appendString((&T34_), TM__vYBWrr780p7faFzauVMtPg_140);
appendString((&T34_), pre_1);
appendString((&T34_), TM__vYBWrr780p7faFzauVMtPg_142);
appendString((&T34_), post_1);
appendString((&T34_), TM__vYBWrr780p7faFzauVMtPg_144);
				eqsink___system_u2700((&labelDef_1), T34_);
			}
LA32_: ;
			{
				NimStringV2 colontmpD__5;
				tyArray__YgExxhfgKcesA5EOUj1MOA T40_;
				NimStringV2 T41_;
				colontmpD__4 = X5BX5D___pureZstrutils_u1286((*n_p1)._kind_2.labelFmt, enumR_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
				if (!!(eqStrings(colontmpD__4, TM__vYBWrr780p7faFzauVMtPg_146))) goto LA37_;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				colontmpD__5 = X5BX5D___pureZstrutils_u1286((*n_p1)._kind_2.labelFmt, enumR_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA39_;
				T40_[0] = colontmpD__5;
				T41_.len = 0; T41_.p = NIM_NIL;
				T41_ = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_148, T40_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T41_); goto LA39_;}
				eqsink___system_u2700((&specStart_1), T41_);
				{
					LA39_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__5);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			}
LA37_: ;
			{
				NIM_BOOL T46_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T50_;
				NimStringV2 T51_;
				T46_ = (NIM_BOOL)0;
				T46_ = !((labelDef_1.len == 0));
				if (T46_) goto LA47_;
				T46_ = !((specStart_1.len == 0));
LA47_: ;
				if (!T46_) goto LA48_;
				T50_[0] = labelDef_1;
				T50_[1] = specStart_1;
				T51_.len = 0; T51_.p = NIM_NIL;
				T51_ = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_150, T50_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T51_); goto LA27_;}
				eqsink___system_u2700((&specifier_1), T51_);
			}
LA48_: ;
			{
				LA27_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(labelDef_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		}
		goto LA22_;
LA25_: ;
		{
			tyTuple__qsoB9cWzItmjtA8wRSiKBbA tmpTuple_1;
			NimStringV2 labelDef_2;
			tyTuple__qsoB9cWzItmjtA8wRSiKBbA T56_;
			NIM_CHAR first_1;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T70_;
			NimStringV2 T71_;
			nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__qsoB9cWzItmjtA8wRSiKBbA));
			labelDef_2.len = 0; labelDef_2.p = NIM_NIL;
			{
				NIM_BOOL T59_;
				NimStringV2 T62_;
				T59_ = (NIM_BOOL)0;
				T59_ = nsuIsUpperAsciiChar((*n_p1)._kind_2.labelFmt.p->data[i1_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				if (!T59_) goto LA60_;
				tmpTuple_1.Field0 = 65;
				T62_.len = 0; T62_.p = NIM_NIL;
				T62_ = rawNewString(pre_1.len + post_1.len + 12);
appendString((&T62_), TM__vYBWrr780p7faFzauVMtPg_151);
appendString((&T62_), pre_1);
appendString((&T62_), TM__vYBWrr780p7faFzauVMtPg_153);
appendString((&T62_), post_1);
				tmpTuple_1.Field1 = T62_;
			}
			goto LA57_;
LA60_: ;
			{
				NimStringV2 T64_;
				tmpTuple_1.Field0 = 97;
				T64_.len = 0; T64_.p = NIM_NIL;
				T64_ = rawNewString(pre_1.len + post_1.len + 12);
appendString((&T64_), TM__vYBWrr780p7faFzauVMtPg_154);
appendString((&T64_), pre_1);
appendString((&T64_), TM__vYBWrr780p7faFzauVMtPg_156);
appendString((&T64_), post_1);
				tmpTuple_1.Field1 = T64_;
			}
LA57_: ;
			first_1 = tmpTuple_1.Field0;
			labelDef_2 = tmpTuple_1.Field1;
			eqwasMoved___system_u2688((&tmpTuple_1.Field1));
			{
				NimStringV2 colontmpD__6;
				NimStringV2 T69_;
				if (!!(((NU8)((*n_p1)._kind_2.labelFmt.p->data[i1_1]) == (NU8)(first_1)))) goto LA67_;
				colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
				T69_.len = 0; T69_.p = NIM_NIL;
				colontmpD__6 = dollar___systemZdollars_u9((NI)((NI)(((NU8)((*n_p1)._kind_2.labelFmt.p->data[i1_1])) - ((NU8)(first_1))) + ((NI)1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
				T69_ = rawNewString(colontmpD__6.len + 7);
appendString((&T69_), TM__vYBWrr780p7faFzauVMtPg_158);
appendString((&T69_), colontmpD__6);
				eqsink___system_u2700((&specStart_1), T69_);
				eqdestroy___system_u2691(colontmpD__6);
			}
LA67_: ;
			T70_[0] = labelDef_2;
			T70_[1] = specStart_1;
			T71_.len = 0; T71_.p = NIM_NIL;
			T71_ = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_159, T70_, 2);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T71_); goto LA55_;}
			eqsink___system_u2700((&specifier_1), T71_);
			{
				LA55_:;
			}
			{
				eqdestroy___system_u2691(labelDef_2);
				eqdestroy___cgen_u30646(tmpTuple_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA20_;
		}
LA22_: ;
		{
			LA20_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA16_;
LA18_: ;
	{
		{
			NIM_BOOL T79_;
			NimStringV2 colontmpD__7;
			NimStringV2 T92_;
			T79_ = (NIM_BOOL)0;
			T79_ = nsuIsDigitChar((*n_p1)._kind_2.labelFmt.p->data[i1_1]);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!T79_) goto LA80_;
			colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
			{
				NimStringV2 colontmpD__8;
				tyArray__YgExxhfgKcesA5EOUj1MOA T88_;
				NimStringV2 T89_;
				colontmpD__7 = X5BX5D___pureZstrutils_u1286((*n_p1)._kind_2.labelFmt, enumR_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
				if (!!(eqStrings(colontmpD__7, TM__vYBWrr780p7faFzauVMtPg_160))) goto LA85_;
				colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
				colontmpD__8 = X5BX5D___pureZstrutils_u1286((*n_p1)._kind_2.labelFmt, enumR_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA87_;
				T88_[0] = colontmpD__8;
				T89_.len = 0; T89_.p = NIM_NIL;
				T89_ = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_162, T88_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T89_); goto LA87_;}
				eqsink___system_u2700((&specStart_1), T89_);
				{
					LA87_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__8);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA82_;
			}
LA85_: ;
			T92_.len = 0; T92_.p = NIM_NIL;
			T92_ = rawNewString(specStart_1.len + 14);
appendString((&T92_), TM__vYBWrr780p7faFzauVMtPg_164);
appendString((&T92_), specStart_1);
			eqsink___system_u2700((&specifier_1), T92_);
			{
				LA82_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__7);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA77_;
LA80_: ;
		{
			tyTuple__qsoB9cWzItmjtA8wRSiKBbA tmpTuple_2;
			NimStringV2 labelDef_3;
			tyTuple__qsoB9cWzItmjtA8wRSiKBbA T97_;
			NIM_CHAR first_2;
			NimStringV2 T113_;
			nimZeroMem((void*)(&tmpTuple_2), sizeof(tyTuple__qsoB9cWzItmjtA8wRSiKBbA));
			labelDef_3.len = 0; labelDef_3.p = NIM_NIL;
			{
				NIM_BOOL T100_;
				T100_ = (NIM_BOOL)0;
				T100_ = nsuIsUpperAsciiChar((*n_p1)._kind_2.labelFmt.p->data[i1_1]);
				if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
				if (!T100_) goto LA101_;
				tmpTuple_2 = TM__vYBWrr780p7faFzauVMtPg_165;
			}
			goto LA98_;
LA101_: ;
			{
				tmpTuple_2 = TM__vYBWrr780p7faFzauVMtPg_167;
			}
LA98_: ;
			first_2 = tmpTuple_2.Field0;
			eqcopy___system_u2694((&labelDef_3), tmpTuple_2.Field1);
			{
				NimStringV2 colontmpD__9;
				tyArray__YgExxhfgKcesA5EOUj1MOA T109_;
				NimStringV2 T110_;
				if (!!(((NU8)((*n_p1)._kind_2.labelFmt.p->data[i1_1]) == (NU8)(first_2)))) goto LA106_;
				colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
				colontmpD__9 = dollar___systemZdollars_u9((NI)((NI)(((NU8)((*n_p1)._kind_2.labelFmt.p->data[i1_1])) - ((NU8)(first_2))) + ((NI)1)));
				if (NIM_UNLIKELY(*nimErr_)) goto LA108_;
				T109_[0] = colontmpD__9;
				T110_.len = 0; T110_.p = NIM_NIL;
				T110_ = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_169, T109_, 1);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T110_); goto LA108_;}
				eqsink___system_u2700((&specStart_1), T110_);
				{
					LA108_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__9);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA96_;
			}
LA106_: ;
			T113_.len = 0; T113_.p = NIM_NIL;
			T113_ = rawNewString(labelDef_3.len + specStart_1.len + 0);
appendString((&T113_), labelDef_3);
appendString((&T113_), specStart_1);
			eqsink___system_u2700((&specifier_1), T113_);
			{
				LA96_:;
			}
			{
				eqdestroy___system_u2691(labelDef_3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA77_: ;
	}
LA16_: ;
	T116_.len = 0; T116_.p = NIM_NIL;
	T116_ = rawNewString(specifier_1.len + 15);
appendString((&T116_), TM__vYBWrr780p7faFzauVMtPg_171);
appendString((&T116_), specifier_1);
appendString((&T116_), TM__vYBWrr780p7faFzauVMtPg_173);
	colontmpD_ = T116_;
	T117_.len = 0; T117_.p = NIM_NIL;
	T117_ = rawNewString(specifier_1.len + 37);
appendString((&T117_), TM__vYBWrr780p7faFzauVMtPg_175);
appendString((&T117_), specifier_1);
appendString((&T117_), TM__vYBWrr780p7faFzauVMtPg_177);
	colontmpD__2 = T117_;
	renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, colontmpD_, colontmpD__2, result_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(post_1);
		eqdestroy___system_u2691(specStart_1);
		eqdestroy___system_u2691(specifier_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderField__packagesZdocutilsZrstgen_u3898)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NIM_BOOL b_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	b_1 = NIM_FALSE;
	{
		NimStringV2 fieldname_1;
		NimStringV2 fieldval_1;
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		if (!((*d_p0).target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1))) goto LA3_;
		fieldname_1.len = 0; fieldname_1.p = NIM_NIL;
		fieldval_1.len = 0; fieldval_1.p = NIM_NIL;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		fieldname_1 = addNodes__packagesZdocutilsZrst_u80((*n_p1).sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD_ = addNodes__packagesZdocutilsZrst_u80((*n_p1).sons.p->data[((NI)1)]);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmpD__2 = nsuStrip(colontmpD_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		fieldval_1 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD__2, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NIM_BOOL T7_;
			NI T8_;
			NI T10_;
			T7_ = (NIM_BOOL)0;
			T8_ = (NI)0;
			T8_ = nsuCmpIgnoreStyle(fieldname_1, TM__vYBWrr780p7faFzauVMtPg_202);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T7_ = (T8_ == ((NI)0));
			if (T7_) goto LA9_;
			T10_ = (NI)0;
			T10_ = nsuCmpIgnoreStyle(fieldname_1, TM__vYBWrr780p7faFzauVMtPg_204);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T7_ = (T10_ == ((NI)0));
LA9_: ;
			if (!T7_) goto LA11_;
			{
				if (!((*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)4))- 0].len == ((NI)0))) goto LA15_;
				eqsink___system_u2700((&(*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)4))- 0]), fieldval_1);
				eqwasMoved___system_u2688((&fieldval_1));
				b_1 = NIM_TRUE;
			}
LA15_: ;
		}
		goto LA5_;
LA11_: ;
		{
			NI T18_;
			T18_ = (NI)0;
			T18_ = nsuCmpIgnoreStyle(fieldname_1, TM__vYBWrr780p7faFzauVMtPg_206);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(T18_ == ((NI)0))) goto LA19_;
			{
				if (!((*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)5))- 0].len == ((NI)0))) goto LA23_;
				eqsink___system_u2700((&(*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)5))- 0]), fieldval_1);
				eqwasMoved___system_u2688((&fieldval_1));
				b_1 = NIM_TRUE;
			}
LA23_: ;
		}
		goto LA5_;
LA19_: ;
LA5_: ;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(fieldval_1);
		eqdestroy___system_u2691(fieldname_1);
	}
LA3_: ;
	{
		if (!!(b_1)) goto LA27_;
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_208, TM__vYBWrr780p7faFzauVMtPg_210, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA27_: ;
	}BeforeRet_: ;
}
static N_INLINE(NF, toFloat__system_u1695)(NI i_p0) {
	NF result;
	result = ((NF) (i_p0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderAdmonition__packagesZdocutilsZrstgen_u4000)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NimStringV2 htmlCls_1;
	NimStringV2 texSz_1;
	NimStringV2 texColor_1;
	NimStringV2 txt_1;
	NimStringV2 htmlHead_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T11_;
	NimStringV2 T12_;
	NimStringV2 T13_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	htmlCls_1.len = 0; htmlCls_1.p = NIM_NIL;
	texSz_1.len = 0; texSz_1.p = NIM_NIL;
	texColor_1.len = 0; texColor_1.p = NIM_NIL;
	txt_1.len = 0; txt_1.p = NIM_NIL;
	htmlHead_1.len = 0; htmlHead_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	htmlCls_1 = TM__vYBWrr780p7faFzauVMtPg_304;
	texSz_1 = TM__vYBWrr780p7faFzauVMtPg_306;
	texColor_1 = TM__vYBWrr780p7faFzauVMtPg_308;
	switch (hashString((*n_p1)._kind_4.adType) & 15) {
	case 0: 
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_322)) goto LA3_;
break;
	case 4: 
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_328)) goto LA4_;
break;
	case 5: 
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_324)) goto LA3_;
break;
	case 7: 
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_312)) goto LA2_;
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_320)) goto LA3_;
break;
	case 8: 
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_314)) goto LA2_;
break;
	case 9: 
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_326)) goto LA4_;
break;
	case 10: 
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_318)) goto LA3_;
break;
	case 11: 
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_310)) goto LA2_;
if (eqStrings((*n_p1)._kind_4.adType, TM__vYBWrr780p7faFzauVMtPg_316)) goto LA3_;
break;
	}
	goto LA5_;
	LA2_: ;
	{
		htmlCls_1 = TM__vYBWrr780p7faFzauVMtPg_330;
		texSz_1 = TM__vYBWrr780p7faFzauVMtPg_332;
		texColor_1 = TM__vYBWrr780p7faFzauVMtPg_334;
	}
	goto LA6_;
	LA3_: ;
	{
		htmlCls_1 = TM__vYBWrr780p7faFzauVMtPg_336;
		texSz_1 = TM__vYBWrr780p7faFzauVMtPg_337;
		texColor_1 = TM__vYBWrr780p7faFzauVMtPg_338;
	}
	goto LA6_;
	LA4_: ;
	{
		htmlCls_1 = TM__vYBWrr780p7faFzauVMtPg_340;
		texSz_1 = TM__vYBWrr780p7faFzauVMtPg_342;
		texColor_1 = TM__vYBWrr780p7faFzauVMtPg_344;
	}
	goto LA6_;
	LA5_: ;
	{
	}
LA6_: ;
	txt_1 = nsuCapitalizeAscii((*n_p1)._kind_4.adType);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_.len = 0; T11_.p = NIM_NIL;
	T11_ = rawNewString(htmlCls_1.len + 25);
appendString((&T11_), TM__vYBWrr780p7faFzauVMtPg_346);
appendString((&T11_), htmlCls_1);
appendString((&T11_), TM__vYBWrr780p7faFzauVMtPg_348);
	htmlHead_1 = T11_;
	T12_.len = 0; T12_.p = NIM_NIL;
	T12_ = rawNewString(htmlHead_1.len + htmlCls_1.len + txt_1.len + 47);
appendString((&T12_), htmlHead_1);
appendString((&T12_), TM__vYBWrr780p7faFzauVMtPg_350);
appendString((&T12_), htmlCls_1);
appendString((&T12_), TM__vYBWrr780p7faFzauVMtPg_352);
appendString((&T12_), txt_1);
appendString((&T12_), TM__vYBWrr780p7faFzauVMtPg_354);
	colontmpD_ = T12_;
	T13_.len = 0; T13_.p = NIM_NIL;
	T13_ = rawNewString(texColor_1.len + texSz_1.len + texColor_1.len + txt_1.len + 104);
appendString((&T13_), TM__vYBWrr780p7faFzauVMtPg_356);
appendString((&T13_), texColor_1);
appendString((&T13_), TM__vYBWrr780p7faFzauVMtPg_358);
appendString((&T13_), texSz_1);
appendString((&T13_), TM__vYBWrr780p7faFzauVMtPg_360);
appendString((&T13_), texColor_1);
appendString((&T13_), TM__vYBWrr780p7faFzauVMtPg_362);
appendString((&T13_), txt_1);
appendString((&T13_), TM__vYBWrr780p7faFzauVMtPg_364);
	colontmpD__2 = T13_;
	renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, colontmpD_, colontmpD__2, result_p2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(htmlHead_1);
		eqdestroy___system_u2691(txt_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderHyperlink__packagesZdocutilsZrstgen_u4009)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* text_p1, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* link_p2, NimStringV2* result_p3, NIM_BOOL external_p4, NIM_BOOL nimdoc_p5, NimStringV2 tooltip_p6) {
	NimStringV2 linkStr_1;
	NimStringV2 colontmpD_;
	NimStringV2 textStr_1;
	NimStringV2 nimDocStr_1;
	NimStringV2 tooltipStr_1;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	linkStr_1.len = 0; linkStr_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	textStr_1.len = 0; textStr_1.p = NIM_NIL;
	nimDocStr_1.len = 0; nimDocStr_1.p = NIM_NIL;
	tooltipStr_1.len = 0; tooltipStr_1.p = NIM_NIL;
	linkStr_1 = TM__vYBWrr780p7faFzauVMtPg_426;
	{
		tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA mode_1;
		mode_1 = (*d_p0).escMode;
		(*d_p0).escMode = ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)2);
		renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, link_p2, (&linkStr_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*d_p0).escMode = mode_1;
	}
	colontmpD_ = safeProtocol__packagesZdocutilsZrst_u10329((&linkStr_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD_);
	textStr_1 = TM__vYBWrr780p7faFzauVMtPg_427;
	renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, text_p1, (&textStr_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T3_.len = 0; T3_.p = NIM_NIL;
	{
		if (!nimdoc_p5) goto LA6_;
		nimDocStr_1 = TM__vYBWrr780p7faFzauVMtPg_429;
	}
	goto LA4_;
LA6_: ;
	{
		nimDocStr_1 = TM__vYBWrr780p7faFzauVMtPg_430;
	}
LA4_: ;
	tooltipStr_1 = TM__vYBWrr780p7faFzauVMtPg_431;
	{
		NimStringV2 colontmpD__2;
		tyArray__YgExxhfgKcesA5EOUj1MOA T14_;
		NimStringV2 T15_;
		if (!!((tooltip_p6.len == 0))) goto LA11_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, tooltip_p6, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		T14_[0] = colontmpD__2;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_433, T14_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA13_;}
		eqsink___system_u2700((&tooltipStr_1), T15_);
		{
			LA13_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	{
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T22_;
		if (!external_p4) goto LA20_;
		T22_[0] = textStr_1;
		T22_[1] = linkStr_1;
		T22_[2] = nimDocStr_1;
		T22_[3] = tooltipStr_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p3, TM__vYBWrr780p7faFzauVMtPg_435, TM__vYBWrr780p7faFzauVMtPg_437, T22_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA18_;
LA20_: ;
	{
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T24_;
		T24_[0] = textStr_1;
		T24_[1] = linkStr_1;
		T24_[2] = nimDocStr_1;
		T24_[3] = tooltipStr_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p3, TM__vYBWrr780p7faFzauVMtPg_439, TM__vYBWrr780p7faFzauVMtPg_441, T24_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA18_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(tooltipStr_1);
		eqdestroy___system_u2691(textStr_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(linkStr_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dispF__packagesZdocutilsZrstgen_u300)(tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g target_p0, NimStringV2 xml_p1, NimStringV2 tex_p2, NimStringV2* args_p3, NI args_p3Len_0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!!((target_p0 == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1)))) goto LA3_;
		result = nsuFormatOpenArray(xml_p1, args_p3, args_p3Len_0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		result = nsuFormatOpenArray(tex_p2, args_p3, args_p3Len_0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, renderImage__packagesZdocutilsZrstgen_u3713)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NimStringV2 arg_1;
	NimStringV2 options_1;
	NimStringV2 s_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	NimStringV2 colontmpD__9;
	NimStringV2 colontmpD__10;
	NimStringV2 htmlOut_1;
	NimStringV2 target_1;
	NimStringV2 colontmpD__11;
	NimStringV2 colontmpD__12;
	NimStringV2 colontmpD__13;
	NimStringV2 colontmpD__14;
	NimStringV2 colontmpD__15;
	NimStringV2 colontmpD__16;
	NimStringV2 T7_;
	NimStringV2 T13_;
	NimStringV2 T19_;
	NimStringV2 T25_;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T54_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	arg_1.len = 0; arg_1.p = NIM_NIL;
	options_1.len = 0; options_1.p = NIM_NIL;
	s_1.len = 0; s_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
	colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
	colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
	htmlOut_1.len = 0; htmlOut_1.p = NIM_NIL;
	target_1.len = 0; target_1.p = NIM_NIL;
	colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
	colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
	colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
	colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
	colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
	colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
	arg_1 = getArgument__packagesZdocutilsZrst_u85(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	options_1 = TM__vYBWrr780p7faFzauVMtPg_454;
	colontmpD_ = getFieldValue__packagesZdocutilsZrst_u82(n_p1, TM__vYBWrr780p7faFzauVMtPg_456);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = nsuStrip(colontmpD_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	s_1 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD__2, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T6_;
		if (!(((NI)0) < s_1.len)) goto LA4_;
		T6_[0] = s_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, (&options_1), TM__vYBWrr780p7faFzauVMtPg_458, TM__vYBWrr780p7faFzauVMtPg_460, T6_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	colontmpD__3 = getFieldValue__packagesZdocutilsZrst_u82(n_p1, TM__vYBWrr780p7faFzauVMtPg_462);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__4 = nsuStrip(colontmpD__3, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T7_.len = 0; T7_.p = NIM_NIL;
	T7_ = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD__4, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T7_); goto LA1_;}
	eqsink___system_u2700((&s_1), T7_);
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T12_;
		if (!(((NI)0) < s_1.len)) goto LA10_;
		T12_[0] = s_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, (&options_1), TM__vYBWrr780p7faFzauVMtPg_464, TM__vYBWrr780p7faFzauVMtPg_466, T12_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	colontmpD__5 = getFieldValue__packagesZdocutilsZrst_u82(n_p1, TM__vYBWrr780p7faFzauVMtPg_468);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__6 = nsuStrip(colontmpD__5, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T13_.len = 0; T13_.p = NIM_NIL;
	T13_ = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD__6, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T13_); goto LA1_;}
	eqsink___system_u2700((&s_1), T13_);
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T18_;
		if (!(((NI)0) < s_1.len)) goto LA16_;
		T18_[0] = s_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, (&options_1), TM__vYBWrr780p7faFzauVMtPg_470, TM__vYBWrr780p7faFzauVMtPg_472, T18_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA16_: ;
	colontmpD__7 = getFieldValue__packagesZdocutilsZrst_u82(n_p1, TM__vYBWrr780p7faFzauVMtPg_474);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__8 = nsuStrip(colontmpD__7, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T19_.len = 0; T19_.p = NIM_NIL;
	T19_ = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD__8, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T19_); goto LA1_;}
	eqsink___system_u2700((&s_1), T19_);
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T24_;
		if (!(((NI)0) < s_1.len)) goto LA22_;
		T24_[0] = s_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, (&options_1), TM__vYBWrr780p7faFzauVMtPg_476, TM__vYBWrr780p7faFzauVMtPg_477, T24_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA22_: ;
	colontmpD__9 = getFieldValue__packagesZdocutilsZrst_u82(n_p1, TM__vYBWrr780p7faFzauVMtPg_479);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__10 = nsuStrip(colontmpD__9, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T25_.len = 0; T25_.p = NIM_NIL;
	T25_ = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD__10, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T25_); goto LA1_;}
	eqsink___system_u2700((&s_1), T25_);
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T30_;
		if (!(((NI)0) < s_1.len)) goto LA28_;
		T30_[0] = s_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, (&options_1), TM__vYBWrr780p7faFzauVMtPg_481, TM__vYBWrr780p7faFzauVMtPg_482, T30_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA28_: ;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T35_;
		NimStringV2 T36_;
		if (!(((NI)0) < options_1.len)) goto LA33_;
		T35_[0] = options_1;
		T36_.len = 0; T36_.p = NIM_NIL;
		T36_ = dispF__packagesZdocutilsZrstgen_u300((*d_p0).target, TM__vYBWrr780p7faFzauVMtPg_483, TM__vYBWrr780p7faFzauVMtPg_485, T35_, 1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T36_); goto LA1_;}
		eqsink___system_u2700((&options_1), T36_);
	}
LA33_: ;
	htmlOut_1 = TM__vYBWrr780p7faFzauVMtPg_486;
	{
		NIM_BOOL T39_;
		NIM_BOOL T40_;
		T39_ = (NIM_BOOL)0;
		T40_ = (NIM_BOOL)0;
		T40_ = nsuEndsWith(arg_1, TM__vYBWrr780p7faFzauVMtPg_488);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (T40_) goto LA41_;
		T40_ = nsuEndsWith(arg_1, TM__vYBWrr780p7faFzauVMtPg_490);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA41_: ;
		T39_ = T40_;
		if (T39_) goto LA42_;
		T39_ = nsuEndsWith(arg_1, TM__vYBWrr780p7faFzauVMtPg_492);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
LA42_: ;
		if (!T39_) goto LA43_;
		eqsink___system_u2700((&htmlOut_1), TM__vYBWrr780p7faFzauVMtPg_494);
	}
	goto LA37_;
LA43_: ;
	{
		eqsink___system_u2700((&htmlOut_1), TM__vYBWrr780p7faFzauVMtPg_496);
	}
LA37_: ;
	colontmpD__11 = getFieldValue__packagesZdocutilsZrst_u82(n_p1, TM__vYBWrr780p7faFzauVMtPg_498);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__12 = nsuStrip(colontmpD__11, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	target_1 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD__12, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)2));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__13 = safeProtocol__packagesZdocutilsZrst_u10329((&target_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	(void)(colontmpD__13);
	{
		NimStringV2 htmlOutWithLink_1;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T51_;
		if (!(((NI)0) < target_1.len)) goto LA48_;
		htmlOutWithLink_1.len = 0; htmlOutWithLink_1.p = NIM_NIL;
		htmlOutWithLink_1 = TM__vYBWrr780p7faFzauVMtPg_499;
		T51_[0] = htmlOut_1;
		T51_[1] = target_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, (&htmlOutWithLink_1), TM__vYBWrr780p7faFzauVMtPg_501, TM__vYBWrr780p7faFzauVMtPg_502, T51_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA50_;
		eqsink___system_u2700((&htmlOut_1), htmlOutWithLink_1);
		eqwasMoved___system_u2688((&htmlOutWithLink_1));
		{
			LA50_:;
		}
		{
			eqdestroy___system_u2691(htmlOutWithLink_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA48_: ;
	colontmpD__14 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, arg_1, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T54_[0] = colontmpD__14;
	T54_[1] = options_1;
	{
		if (!((*n_p1).anchor.len == 0)) goto LA57_;
		colontmpD__15 = TM__vYBWrr780p7faFzauVMtPg_505;
		T54_[2] = colontmpD__15;
	}
	goto LA55_;
LA57_: ;
	{
		NimStringV2 T60_;
		T60_.len = 0; T60_.p = NIM_NIL;
		switch ((*d_p0).target) {
		case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
		{
			NimStringV2 T62_;
			T62_.len = 0; T62_.p = NIM_NIL;
			T62_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T62_), TM__vYBWrr780p7faFzauVMtPg_506);
appendString((&T62_), (*n_p1).anchor);
appendString((&T62_), TM__vYBWrr780p7faFzauVMtPg_507);
			colontmpD__16 = T62_;
		}
		break;
		case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
		{
			NimStringV2 T64_;
			T64_.len = 0; T64_.p = NIM_NIL;
			T64_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T64_), TM__vYBWrr780p7faFzauVMtPg_508);
appendString((&T64_), (*n_p1).anchor);
appendString((&T64_), TM__vYBWrr780p7faFzauVMtPg_509);
appendString((&T64_), (*n_p1).anchor);
appendString((&T64_), TM__vYBWrr780p7faFzauVMtPg_510);
			colontmpD__16 = T64_;
		}
		break;
		default: __builtin_unreachable();
		}
		T54_[2] = colontmpD__16;
	}
LA55_: ;
	dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, htmlOut_1, TM__vYBWrr780p7faFzauVMtPg_504, T54_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NI T67_;
		T67_ = (NI)0;
		T67_ = len__packagesZdocutilsZrstast_u114(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)3) <= T67_)) goto LA68_;
		renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[((NI)2)], result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA68_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__16);
		eqdestroy___system_u2691(colontmpD__15);
		eqdestroy___system_u2691(colontmpD__14);
		eqdestroy___system_u2691(colontmpD__13);
		eqdestroy___system_u2691(colontmpD__12);
		eqdestroy___system_u2691(colontmpD__11);
		eqdestroy___system_u2691(target_1);
		eqdestroy___system_u2691(htmlOut_1);
		eqdestroy___system_u2691(colontmpD__10);
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(s_1);
		eqdestroy___system_u2691(options_1);
		eqdestroy___system_u2691(arg_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, init__packagesZdocutilsZrstgen_u84)(tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* p_p0) {
	(*p_p0).startLine = ((NI)1);
	(*p_p0).lang = ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)0);
	eqsink___system_u2700((&(*p_p0).langStr), TM__vYBWrr780p7faFzauVMtPg_511);
}
static N_INLINE(NimStringV2, X5BX5D___pureZstrutils_u1314)(NimStringV2 s_p0, tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig x_p1) {
	NimStringV2 result;
	NI a_1;
	NI L_1;
	result.len = 0; result.p = NIM_NIL;
	a_1 = x_p1.a;
	L_1 = (NI)((NI)((NI)(s_p0.len - x_p1.b) - a_1) + ((NI)1));
	result = mnewString((L_1));
	{
		NI i_1;
		NI i_2;
		i_1 = (NI)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < L_1)) goto LA3;
				i_1 = i_2;
				nimPrepareStrMutationV2((&result));
				result.p->data[i_1] = s_p0.p->data[(NI)(i_1 + a_1)];
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	return result;
}
static N_INLINE(tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig, dotdot___stdZenumutils_u106)(NI a_p0, NI b_p1) {
	tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getField1Int__packagesZdocutilsZrstgen_u3727)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2 fieldName_p2) {
	NI result;
	NimStringV2 value_1;
	NI number_1;
	NI nChars_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	value_1.len = 0; value_1.p = NIM_NIL;
	value_1 = getFieldValue__packagesZdocutilsZrst_u11689(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	number_1 = (NI)0;
	nChars_1 = parseInt__pureZparseutils_u981(value_1, (&number_1), ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(nChars_1 == ((NI)0))) goto LA4_;
		{
			if (!(value_1.len == ((NI)0))) goto LA8_;
			result = ((NI)1);
		}
		goto LA6_;
LA8_: ;
		{
			NimStringV2 colontmpD_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T12_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			T12_[0] = fieldName_p2;
			T12_[1] = value_1;
			colontmpD_ = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_527, T12_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			rstMessage__packagesZdocutilsZrst_u3806((&(*d_p0).filenames), (*d_p0).msgHandler, (*n_p1)._kind_8.info, ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)9), colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			{
				LA11_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA6_: ;
	}
	goto LA2_;
LA4_: ;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T19_;
		tyObject_HSlice__JgojxK65oMA6E0HRsL2Wig T20_;
		if (!(nChars_1 < value_1.len)) goto LA16_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T19_[0] = fieldName_p2;
		T20_ = dotdot___stdZenumutils_u106(nChars_1, ((NI)1));
		colontmpD__2 = X5BX5D___pureZstrutils_u1314(value_1, T20_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		T19_[1] = colontmpD__2;
		colontmpD__3 = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_529, T19_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		rstMessage__packagesZdocutilsZrst_u3806((&(*d_p0).filenames), (*d_p0).msgHandler, (*n_p1)._kind_8.info, ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)9), colontmpD__3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		{
			LA18_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA16_: ;
	{
		result = number_1;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(value_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, parseCodeBlockField__packagesZdocutilsZrstgen_u3755)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* params_p2) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getArgument__packagesZdocutilsZrst_u85(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = nsuToLowerAsciiStr(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	if (eqStrings(colontmpD__2, TM__vYBWrr780p7faFzauVMtPg_513)) goto LA2_;
	if (eqStrings(colontmpD__2, TM__vYBWrr780p7faFzauVMtPg_515)) goto LA3_;
	if (eqStrings(colontmpD__2, TM__vYBWrr780p7faFzauVMtPg_517)) goto LA3_;
	if (eqStrings(colontmpD__2, TM__vYBWrr780p7faFzauVMtPg_519)) goto LA4_;
	if (eqStrings(colontmpD__2, TM__vYBWrr780p7faFzauVMtPg_521)) goto LA5_;
	if (eqStrings(colontmpD__2, TM__vYBWrr780p7faFzauVMtPg_523)) goto LA5_;
	if (eqStrings(colontmpD__2, TM__vYBWrr780p7faFzauVMtPg_525)) goto LA6_;
	goto LA7_;
	LA2_: ;
	{
		NI T10_;
		(*params_p2).numberLines = NIM_TRUE;
		T10_ = (NI)0;
		T10_ = getField1Int__packagesZdocutilsZrstgen_u3727(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_530);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*params_p2).startLine = T10_;
	}
	goto LA8_;
	LA3_: ;
	{
		NimStringV2 colontmpD__3;
		NimStringV2 T12_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		colontmpD__3 = getFieldValue__packagesZdocutilsZrst_u11689(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T12_.len = 0; T12_.p = NIM_NIL;
		T12_ = nsuStrip(colontmpD__3, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T12_); goto LA1_;}
		eqsink___system_u2700((&(*params_p2).filename), T12_);
		eqdestroy___system_u2691(colontmpD__3);
	}
	goto LA8_;
	LA4_: ;
	{
		NimStringV2 colontmpD__4;
		NimStringV2 T15_;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__4 = getFieldValue__packagesZdocutilsZrst_u11689(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		T15_.len = 0; T15_.p = NIM_NIL;
		T15_ = nsuStrip(colontmpD__4, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T15_); goto LA14_;}
		eqsink___system_u2700((&(*params_p2).testCmd), T15_);
		{
			if (!((*params_p2).testCmd.len == ((NI)0))) goto LA18_;
			eqsink___system_u2700((&(*params_p2).testCmd), TM__vYBWrr780p7faFzauVMtPg_532);
		}
		goto LA16_;
LA18_: ;
		{
			NimStringV2 T21_;
			T21_.len = 0; T21_.p = NIM_NIL;
			T21_ = nsuUnescape((*params_p2).testCmd, TM__vYBWrr780p7faFzauVMtPg_533, TM__vYBWrr780p7faFzauVMtPg_534);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T21_); goto LA14_;}
			eqsink___system_u2700((&(*params_p2).testCmd), T21_);
		}
LA16_: ;
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
	LA5_: ;
	{
		NimStringV2 colontmpD__5;
		NI T26_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__5 = getArgument__packagesZdocutilsZrst_u85(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		T26_ = (NI)0;
		T26_ = getField1Int__packagesZdocutilsZrstgen_u3727(d_p0, n_p1, colontmpD__5);
		if (NIM_UNLIKELY(*nimErr_)) goto LA25_;
		(*params_p2).status = T26_;
		{
			LA25_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA8_;
	LA6_: ;
	{
		NimStringV2 colontmpD__6;
		NimStringV2 T30_;
		tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA T31_;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__6 = getFieldValue__packagesZdocutilsZrst_u11689(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T30_.len = 0; T30_.p = NIM_NIL;
		T30_ = nsuStrip(colontmpD__6, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T30_); goto LA1_;}
		eqsink___system_u2700((&(*params_p2).langStr), T30_);
		T31_ = (tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)0;
		T31_ = getSourceLanguage__packagesZdocutilsZhighlite_u72((*params_p2).langStr);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*params_p2).lang = T31_;
		eqdestroy___system_u2691(colontmpD__6);
	}
	goto LA8_;
	LA7_: ;
	{
		NimStringV2 colontmpD__7;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__7 = getArgument__packagesZdocutilsZrst_u85(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		rstMessage__packagesZdocutilsZrst_u3806((&(*d_p0).filenames), (*d_p0).msgHandler, (*n_p1)._kind_8.info, ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)16), colontmpD__7);
		if (NIM_UNLIKELY(*nimErr_)) goto LA33_;
		{
			LA33_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__7);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA8_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, parseCodeBlockParams__packagesZdocutilsZrstgen_u3759)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* Result) {
	NimStringV2 colontmpD_;
	NimStringV2 T14_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw));
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	init__packagesZdocutilsZrstgen_u84(Result);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!(n_p1 == 0)) goto LA4_;
		eqdestroy___system_u2691(colontmpD_);
		goto BeforeRet_;
	}
LA4_: ;
	{
		if (!!(((*n_p1).sons.p->data[((NI)1)] == 0))) goto LA8_;
		{
			tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA** son_1;
			tySequence__LqZapiAqCFeXPQZdoIAUew* colontmp_;
			NI i_1;
			NI L_1;
			NI T11_;
			son_1 = (tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA**)0;
			colontmp_ = (tySequence__LqZapiAqCFeXPQZdoIAUew*)0;
			colontmp_ = (&(*(*n_p1).sons.p->data[((NI)1)]).sons);
			i_1 = ((NI)0);
			T11_ = (*colontmp_).len;
			L_1 = T11_;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA13;
					son_1 = &(*colontmp_).p->data[i_1];
					parseCodeBlockField__packagesZdocutilsZrstgen_u3755(d_p0, (*son_1), Result);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					i_1 += ((NI)1);
				} LA13: ;
			}
		}
	}
LA8_: ;
	colontmpD_ = getArgument__packagesZdocutilsZrst_u85(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T14_.len = 0; T14_.p = NIM_NIL;
	T14_ = nsuStrip(colontmpD_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T14_); goto LA1_;}
	eqsink___system_u2700((&(*Result).langStr), T14_);
	{
		tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA T19_;
		if (!!(((*Result).langStr.len == 0))) goto LA17_;
		T19_ = (tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)0;
		T19_ = getSourceLanguage__packagesZdocutilsZhighlite_u72((*Result).langStr);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		(*Result).lang = T19_;
	}
LA17_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u3866)(tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* dest_p0) {
	eqdestroy___system_u2691((*dest_p0).testCmd);
	eqdestroy___system_u2691((*dest_p0).filename);
	eqdestroy___system_u2691((*dest_p0).langStr);
}
N_LIB_PRIVATE N_NIMCALL(void, buildLinesHtmlTable__packagesZdocutilsZrstgen_u3780)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw* params_p1, NimStringV2 code_p2, NimStringV2 idStr_p3, tyTuple__UV3llMMYFckfui8YMBuUZA* Result) {
	NimStringV2 id_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 colontmpD__3;
	NimStringV2 colontmpD__4;
	NimStringV2 colontmpD__5;
	NimStringV2 colontmpD__6;
	NimStringV2 colontmpD__7;
	NimStringV2 colontmpD__8;
	NimStringV2 colontmpD__9;
	NI codeLines_1;
	NimStringV2 T10_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T11_;
	NI line_1;
	NimStringV2 T15_;
	tyArray__dyW7vpmfeTYw8kX3EXuaJA T16_;
	NimStringV2 T17_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
	id_1.len = 0; id_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
	colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
	colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
	colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
	colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
	colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
	colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
	(*d_p0).listingCounter += ((NI)1);
	id_1 = dollar___systemZdollars_u9((*d_p0).listingCounter);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmp_;
		NimStringV2 colontmpD__10;
		NimStringV2 colontmp__2;
		NimStringV2 colontmpD__11;
		tyArray__dyW7vpmfeTYw8kX3EXuaJA T7_;
		NimStringV2 blitTmp_1;
		NimStringV2 blitTmp_2;
		if (!!((*params_p1).numberLines)) goto LA4_;
		colontmp_.len = 0; colontmp_.p = NIM_NIL;
		colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
		colontmp__2.len = 0; colontmp__2.p = NIM_NIL;
		colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
		colontmpD__10 = getOrDefault__pureZstrtabs_u390((*d_p0).config, TM__vYBWrr780p7faFzauVMtPg_538, TM__vYBWrr780p7faFzauVMtPg_539);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		T7_[0] = id_1;
		T7_[1] = sourceLanguageToStr__packagesZdocutilsZhighlite_u68[((*params_p1).lang)- 0];
		T7_[2] = idStr_p3;
		colontmp_ = nsuFormatOpenArray(colontmpD__10, T7_, 3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmpD__11 = getOrDefault__pureZstrtabs_u390((*d_p0).config, TM__vYBWrr780p7faFzauVMtPg_541, TM__vYBWrr780p7faFzauVMtPg_542);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		colontmp__2 = nsuFormatSingleElem(colontmpD__11, id_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		blitTmp_1 = colontmp_;
		eqwasMoved___system_u2688((&colontmp_));
		(*Result).Field0 = blitTmp_1;
		blitTmp_2 = colontmp__2;
		eqwasMoved___system_u2688((&colontmp__2));
		(*Result).Field1 = blitTmp_2;
		eqdestroy___system_u2691(colontmpD__11);
		eqdestroy___system_u2691(colontmp__2);
		eqdestroy___system_u2691(colontmpD__10);
		eqdestroy___system_u2691(colontmp_);
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(id_1);
		goto BeforeRet_;
		{
			LA6_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__11);
			eqdestroy___system_u2691(colontmp__2);
			eqdestroy___system_u2691(colontmpD__10);
			eqdestroy___system_u2691(colontmp_);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA4_: ;
	colontmpD_ = nsuStrip(code_p2, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	codeLines_1 = nsuCountLines(colontmpD_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_.len = 0; T10_.p = NIM_NIL;
	T11_[0] = idStr_p3;
	colontmpD__2 = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_544, T11_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T10_ = rawNewString(colontmpD__2.len + 61);
appendString((&T10_), colontmpD__2);
appendString((&T10_), TM__vYBWrr780p7faFzauVMtPg_546);
	eqsink___system_u2700((&(*Result).Field0), T10_);
	line_1 = (*params_p1).startLine;
	{
		while (1) {
			NimStringV2 colontmpD__12;
			NimStringV2 colontmpD__13;
			NimStringV2 T14_;
			if (!(((NI)0) < codeLines_1)) goto LA13;
			colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
			colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
			T14_.len = 0; T14_.p = NIM_NIL;
			colontmpD__12 = dollar___systemZdollars_u9(line_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T14_ = rawNewString(colontmpD__12.len + 1);
appendString((&T14_), colontmpD__12);
appendString((&T14_), TM__vYBWrr780p7faFzauVMtPg_547);
			colontmpD__13 = T14_;
			prepareAdd((&(*Result).Field0), colontmpD__13.len + 0);
appendString((&(*Result).Field0), colontmpD__13);
			line_1 += ((NI)1);
			codeLines_1 -= ((NI)1);
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
		} LA13: ;
	}
	T15_.len = 0; T15_.p = NIM_NIL;
	colontmpD__3 = getOrDefault__pureZstrtabs_u390((*d_p0).config, TM__vYBWrr780p7faFzauVMtPg_550, TM__vYBWrr780p7faFzauVMtPg_551);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T16_[0] = id_1;
	T16_[1] = sourceLanguageToStr__packagesZdocutilsZhighlite_u68[((*params_p1).lang)- 0];
	T16_[2] = idStr_p3;
	colontmpD__4 = nsuFormatOpenArray(colontmpD__3, T16_, 3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T15_ = rawNewString(colontmpD__4.len + 15);
appendString((&T15_), TM__vYBWrr780p7faFzauVMtPg_549);
appendString((&T15_), colontmpD__4);
	colontmpD__5 = T15_;
	prepareAdd((&(*Result).Field0), colontmpD__5.len + 0);
appendString((&(*Result).Field0), colontmpD__5);
	T17_.len = 0; T17_.p = NIM_NIL;
	colontmpD__6 = getOrDefault__pureZstrtabs_u390((*d_p0).config, TM__vYBWrr780p7faFzauVMtPg_552, TM__vYBWrr780p7faFzauVMtPg_553);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__7 = nsuFormatSingleElem(colontmpD__6, id_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__8 = getOrDefault__pureZstrtabs_u390((*d_p0).config, TM__vYBWrr780p7faFzauVMtPg_557, TM__vYBWrr780p7faFzauVMtPg_558);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__9 = nsuFormatSingleElem(colontmpD__8, id_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T17_ = rawNewString(colontmpD__7.len + colontmpD__9.len + 26);
appendString((&T17_), colontmpD__7);
appendString((&T17_), TM__vYBWrr780p7faFzauVMtPg_555);
appendString((&T17_), colontmpD__9);
	eqsink___system_u2700((&(*Result).Field1), T17_);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__9);
		eqdestroy___system_u2691(colontmpD__8);
		eqdestroy___system_u2691(colontmpD__7);
		eqdestroy___system_u2691(colontmpD__6);
		eqdestroy___system_u2691(colontmpD__5);
		eqdestroy___system_u2691(colontmpD__4);
		eqdestroy___system_u2691(colontmpD__3);
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(id_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderCode__packagesZdocutilsZrstgen_u3819)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw params_1;
	tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* m_1;
	NimStringV2 blockStart_1;
	NimStringV2 blockEnd_1;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T50_;
	tyArray__TonP9cxJgj8gXu71dWIyNlA T68_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)(&params_1), sizeof(tyObject_CodeBlockParams__KdgiHlpXzP4UnmU4Wxm2rw));
	m_1 = NIM_NIL;
	blockStart_1.len = 0; blockStart_1.p = NIM_NIL;
	blockEnd_1.len = 0; blockEnd_1.p = NIM_NIL;
	parseCodeBlockParams__packagesZdocutilsZrstgen_u3759(d_p0, n_p1, (&params_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		if (!((*n_p1).sons.p->data[((NI)2)] == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL))) goto LA4_;
		eqdestroy___system_u2691(blockEnd_1);
		eqdestroy___system_u2691(blockStart_1);
		eqdestroy___packagesZdocutilsZrstgen_u3866((&params_1));
		goto BeforeRet_;
	}
LA4_: ;
	m_1 = (*(*n_p1).sons.p->data[((NI)2)]).sons.p->data[((NI)0)];
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = (((NI)0) < params_1.testCmd.len);
		if (!(T8_)) goto LA9_;
		T8_ = !(((*d_p0).onTestSnippet.ClP_0 == TM__vYBWrr780p7faFzauVMtPg_535.ClP_0 && (*d_p0).onTestSnippet.ClE_0 == TM__vYBWrr780p7faFzauVMtPg_535.ClE_0));
LA9_: ;
		if (!T8_) goto LA10_;
		(*d_p0).onTestSnippet.ClE_0? (*d_p0).onTestSnippet.ClP_0(d_p0, params_1.filename, params_1.testCmd, params_1.status, (*m_1)._kind_1.text, (*d_p0).onTestSnippet.ClE_0):((TM__vYBWrr780p7faFzauVMtPg_536)((*d_p0).onTestSnippet.ClP_0))(d_p0, params_1.filename, params_1.testCmd, params_1.status, (*m_1)._kind_1.text);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA10_: ;
	switch ((*d_p0).target) {
	case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
	{
		{
			tyTuple__UV3llMMYFckfui8YMBuUZA tmpTupleAsgn;
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			NimStringV2 T18_;
			if (!((*n_p1).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)55))) goto LA15_;
			nimZeroMem((void*)(&tmpTupleAsgn), sizeof(tyTuple__UV3llMMYFckfui8YMBuUZA));
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T18_.len = 0; T18_.p = NIM_NIL;
			{
				if (!((*n_p1).anchor.len == 0)) goto LA21_;
				colontmpD_ = TM__vYBWrr780p7faFzauVMtPg_559;
				T18_ = colontmpD_;
			}
			goto LA19_;
LA21_: ;
			{
				NimStringV2 T24_;
				T24_.len = 0; T24_.p = NIM_NIL;
				switch ((*d_p0).target) {
				case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
				{
					NimStringV2 T26_;
					T26_.len = 0; T26_.p = NIM_NIL;
					T26_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T26_), TM__vYBWrr780p7faFzauVMtPg_560);
appendString((&T26_), (*n_p1).anchor);
appendString((&T26_), TM__vYBWrr780p7faFzauVMtPg_561);
					colontmpD__2 = T26_;
				}
				break;
				case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
				{
					NimStringV2 T28_;
					T28_.len = 0; T28_.p = NIM_NIL;
					T28_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T28_), TM__vYBWrr780p7faFzauVMtPg_562);
appendString((&T28_), (*n_p1).anchor);
appendString((&T28_), TM__vYBWrr780p7faFzauVMtPg_563);
appendString((&T28_), (*n_p1).anchor);
appendString((&T28_), TM__vYBWrr780p7faFzauVMtPg_564);
					colontmpD__2 = T28_;
				}
				break;
				default: __builtin_unreachable();
				}
				T18_ = colontmpD__2;
			}
LA19_: ;
			buildLinesHtmlTable__packagesZdocutilsZrstgen_u3780(d_p0, (&params_1), (*m_1)._kind_1.text, T18_, (&tmpTupleAsgn));
			if (NIM_UNLIKELY(*nimErr_)) goto LA17_;
			blockStart_1 = tmpTupleAsgn.Field0;
			blockEnd_1 = tmpTupleAsgn.Field1;
			{
				LA17_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA13_;
LA15_: ;
		{
			blockStart_1 = TM__vYBWrr780p7faFzauVMtPg_566;
			blockEnd_1 = TM__vYBWrr780p7faFzauVMtPg_568;
		}
LA13_: ;
	}
	break;
	case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
	{
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			NimStringV2 T37_;
			NimStringV2 T38_;
			if (!((*n_p1).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)55))) goto LA35_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			T37_.len = 0; T37_.p = NIM_NIL;
			T38_.len = 0; T38_.p = NIM_NIL;
			{
				if (!((*n_p1).anchor.len == 0)) goto LA41_;
				colontmpD__3 = TM__vYBWrr780p7faFzauVMtPg_571;
				T38_ = colontmpD__3;
			}
			goto LA39_;
LA41_: ;
			{
				NimStringV2 T44_;
				T44_.len = 0; T44_.p = NIM_NIL;
				switch ((*d_p0).target) {
				case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
				{
					NimStringV2 T46_;
					T46_.len = 0; T46_.p = NIM_NIL;
					T46_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T46_), TM__vYBWrr780p7faFzauVMtPg_572);
appendString((&T46_), (*n_p1).anchor);
appendString((&T46_), TM__vYBWrr780p7faFzauVMtPg_573);
					colontmpD__4 = T46_;
				}
				break;
				case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
				{
					NimStringV2 T48_;
					T48_.len = 0; T48_.p = NIM_NIL;
					T48_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T48_), TM__vYBWrr780p7faFzauVMtPg_574);
appendString((&T48_), (*n_p1).anchor);
appendString((&T48_), TM__vYBWrr780p7faFzauVMtPg_575);
appendString((&T48_), (*n_p1).anchor);
appendString((&T48_), TM__vYBWrr780p7faFzauVMtPg_576);
					colontmpD__4 = T48_;
				}
				break;
				default: __builtin_unreachable();
				}
				T38_ = colontmpD__4;
			}
LA39_: ;
			T37_ = rawNewString(T38_.len + 17);
appendString((&T37_), TM__vYBWrr780p7faFzauVMtPg_570);
appendString((&T37_), T38_);
appendString((&T37_), TM__vYBWrr780p7faFzauVMtPg_578);
			blockStart_1 = T37_;
			blockEnd_1 = TM__vYBWrr780p7faFzauVMtPg_580;
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(colontmpD__3);
		}
		goto LA33_;
LA35_: ;
		{
			blockStart_1 = TM__vYBWrr780p7faFzauVMtPg_582;
			blockEnd_1 = TM__vYBWrr780p7faFzauVMtPg_583;
		}
LA33_: ;
	}
	break;
	default: __builtin_unreachable();
	}
	dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, blockStart_1, blockStart_1, T50_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NimStringV2 colontmpD__5;
		if (!(params_1.lang == ((tyEnum_SourceLanguage__19c0ssteZ7RkUhs6XPCRBNA)0))) goto LA53_;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		{
			NIM_BOOL T58_;
			T58_ = (NIM_BOOL)0;
			T58_ = (((NI)0) < params_1.langStr.len);
			if (!(T58_)) goto LA59_;
			colontmpD__5 = nsuToLowerAsciiStr(params_1.langStr);
			if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
			T58_ = !(eqStrings(colontmpD__5, TM__vYBWrr780p7faFzauVMtPg_585));
LA59_: ;
			if (!T58_) goto LA60_;
			rstMessage__packagesZdocutilsZrst_u3806((&(*d_p0).filenames), (*d_p0).msgHandler, (*n_p1)._kind_8.info, ((tyEnum_MsgKind__ScHRGr082ewG9cWA8D9cim3g)15), params_1.langStr);
			if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
		}
LA60_: ;
		{
			NimStringV2 colontmp_;
			NIM_CHAR letter_1;
			NI i_1;
			NI L_1;
			colontmp_.len = 0; colontmp_.p = NIM_NIL;
			letter_1 = (NIM_CHAR)0;
			colontmp_ = (*m_1)._kind_1.text;
			i_1 = ((NI)0);
			L_1 = colontmp_.len;
			{
				while (1) {
					if (!(i_1 < L_1)) goto LA64;
					letter_1 = colontmp_.p->data[i_1];
					escChar__packagesZdocutilsZrstgen_u238((*d_p0).target, result_p2, letter_1, ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
					if (NIM_UNLIKELY(*nimErr_)) goto LA55_;
					i_1 += ((NI)1);
				} LA64: ;
			}
		}
		{
			LA55_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__5);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA51_;
LA53_: ;
	{
		renderCodeLang__packagesZdocutilsZrstgen_u3809(result_p2, params_1.lang, (*m_1)._kind_1.text, (*d_p0).target);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA51_: ;
	dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, blockEnd_1, blockEnd_1, T68_, 0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(blockEnd_1);
		eqdestroy___system_u2691(blockStart_1);
		eqdestroy___packagesZdocutilsZrstgen_u3866((&params_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderContainer__packagesZdocutilsZrstgen_u3892)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NimStringV2 tmp_1;
	NimStringV2 arg_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	arg_1.len = 0; arg_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	tmp_1 = TM__vYBWrr780p7faFzauVMtPg_586;
	renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[((NI)2)], (&tmp_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = getArgument__packagesZdocutilsZrst_u85(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = nsuStrip(colontmpD_, NIM_TRUE, NIM_TRUE, TM__vYBWrr780p7faFzauVMtPg_200);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	arg_1 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, colontmpD__2, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T6_;
		if (!(arg_1.len == 0)) goto LA4_;
		T6_[0] = tmp_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_588, TM__vYBWrr780p7faFzauVMtPg_589, T6_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA4_: ;
	{
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T8_;
		T8_[0] = arg_1;
		T8_[1] = tmp_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_591, TM__vYBWrr780p7faFzauVMtPg_593, T8_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(arg_1);
		eqdestroy___system_u2691(tmp_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderSmiley__packagesZdocutilsZrstgen_u3723)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	colontmpD_ = getOrDefault__pureZstrtabs_u390((*d_p0).config, TM__vYBWrr780p7faFzauVMtPg_642, TM__vYBWrr780p7faFzauVMtPg_643);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = nsuFormatSingleElem(colontmpD_, (*n_p1)._kind_1.text);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = colontmpD__2;
	dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_638, TM__vYBWrr780p7faFzauVMtPg_640, T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderRstToOut__packagesZdocutilsZrstgen_u324)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(n_p1 == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL))) goto LA3_;
		goto BeforeRet_;
	}
LA3_: ;
	switch ((*n_p1).kind) {
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)0):
	{
		renderAux__packagesZdocutilsZrstgen_u328(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)1):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)3):
	{
		renderHeadline__packagesZdocutilsZrstgen_u3635(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)2):
	{
		renderOverline__packagesZdocutilsZrstgen_u3660(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)4):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_113, TM__vYBWrr780p7faFzauVMtPg_115, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)5):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_117, TM__vYBWrr780p7faFzauVMtPg_119, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)6):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_121, TM__vYBWrr780p7faFzauVMtPg_123, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)7):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)9):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_125, TM__vYBWrr780p7faFzauVMtPg_127, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)8):
	{
		renderEnumList__packagesZdocutilsZrstgen_u3909(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)10):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)11):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_179, TM__vYBWrr780p7faFzauVMtPg_181, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)12):
	{
		renderAux__packagesZdocutilsZrstgen_u328(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)13):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_183, TM__vYBWrr780p7faFzauVMtPg_185, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)14):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_187, TM__vYBWrr780p7faFzauVMtPg_189, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)15):
	{
		NimStringV2 tmp_1;
		tmp_1.len = 0; tmp_1.p = NIM_NIL;
		tmp_1 = TM__vYBWrr780p7faFzauVMtPg_190;
		{
			NI i_1;
			NI colontmp_;
			NI T20_;
			NI res_1;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			T20_ = (NI)0;
			T20_ = len__packagesZdocutilsZrstast_u114(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
			colontmp_ = (NI)(T20_ - ((NI)1));
			res_1 = ((NI)0);
			{
				while (1) {
					if (!(res_1 <= colontmp_)) goto LA22;
					i_1 = ((NI) (res_1));
					renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[i_1], (&tmp_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
					res_1 += ((NI)1);
				} LA22: ;
			}
		}
		{
			NimStringV2 colontmpD_;
			NimStringV2 colontmpD__2;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T28_;
			if (!!((tmp_1.len == ((NI)0)))) goto LA25_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T28_[0] = tmp_1;
			{
				if (!((*n_p1).anchor.len == 0)) goto LA31_;
				colontmpD_ = TM__vYBWrr780p7faFzauVMtPg_194;
				T28_[1] = colontmpD_;
			}
			goto LA29_;
LA31_: ;
			{
				NimStringV2 T34_;
				T34_.len = 0; T34_.p = NIM_NIL;
				switch ((*d_p0).target) {
				case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
				{
					NimStringV2 T36_;
					T36_.len = 0; T36_.p = NIM_NIL;
					T36_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T36_), TM__vYBWrr780p7faFzauVMtPg_195);
appendString((&T36_), (*n_p1).anchor);
appendString((&T36_), TM__vYBWrr780p7faFzauVMtPg_196);
					colontmpD__2 = T36_;
				}
				break;
				case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
				{
					NimStringV2 T38_;
					T38_.len = 0; T38_.p = NIM_NIL;
					T38_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T38_), TM__vYBWrr780p7faFzauVMtPg_197);
appendString((&T38_), (*n_p1).anchor);
appendString((&T38_), TM__vYBWrr780p7faFzauVMtPg_198);
appendString((&T38_), (*n_p1).anchor);
appendString((&T38_), TM__vYBWrr780p7faFzauVMtPg_199);
					colontmpD__2 = T38_;
				}
				break;
				default: __builtin_unreachable();
				}
				T28_[1] = colontmpD__2;
			}
LA29_: ;
			dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_192, TM__vYBWrr780p7faFzauVMtPg_193, T28_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA27_;
			{
				LA27_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__2);
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA18_;
		}
LA25_: ;
		{
			LA18_:;
		}
		{
			eqdestroy___system_u2691(tmp_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)16):
	{
		renderField__packagesZdocutilsZrstgen_u3898(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)17):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_212, TM__vYBWrr780p7faFzauVMtPg_214, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)18):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_216, TM__vYBWrr780p7faFzauVMtPg_218, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)60):
	{
		renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[((NI)2)], result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)19):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_220, TM__vYBWrr780p7faFzauVMtPg_222, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)20):
	{
		NimStringV2 addclass_1;
		NimStringV2 colontmpD__3;
		NimStringV2 T50_;
		NimStringV2 T56_;
		addclass_1.len = 0; addclass_1.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		T50_.len = 0; T50_.p = NIM_NIL;
		{
			if (!((NI)((*n_p1)._kind_6.order % ((NI)2)) == ((NI)1))) goto LA53_;
			addclass_1 = TM__vYBWrr780p7faFzauVMtPg_224;
		}
		goto LA51_;
LA53_: ;
		{
			addclass_1 = TM__vYBWrr780p7faFzauVMtPg_225;
		}
LA51_: ;
		T56_.len = 0; T56_.p = NIM_NIL;
		T56_ = rawNewString(addclass_1.len + 39);
appendString((&T56_), TM__vYBWrr780p7faFzauVMtPg_227);
appendString((&T56_), addclass_1);
appendString((&T56_), TM__vYBWrr780p7faFzauVMtPg_229);
		colontmpD__3 = T56_;
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, colontmpD__3, TM__vYBWrr780p7faFzauVMtPg_230, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA49_;
		{
			LA49_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)21):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_232, TM__vYBWrr780p7faFzauVMtPg_234, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)25):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_236, TM__vYBWrr780p7faFzauVMtPg_237, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)22):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)23):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)24):
	{
		raiseAssert__stdZassertions_u15(TM__vYBWrr780p7faFzauVMtPg_239);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)26):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_241, TM__vYBWrr780p7faFzauVMtPg_243, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)27):
	{
		NimStringV2 tmp_2;
		NimStringV2 itemEnding_1;
		NimStringV2 colontmpD__4;
		NimStringV2 colontmpD__5;
		NimStringV2 colontmpD__6;
		NimStringV2 T65_;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T71_;
		tmp_2.len = 0; tmp_2.p = NIM_NIL;
		itemEnding_1.len = 0; itemEnding_1.p = NIM_NIL;
		colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
		colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		(*d_p0).curQuotationDepth = ((NI)1);
		tmp_2 = TM__vYBWrr780p7faFzauVMtPg_244;
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_245, TM__vYBWrr780p7faFzauVMtPg_246, (&tmp_2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
		T65_.len = 0; T65_.p = NIM_NIL;
		{
			if (!((*d_p0).target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0))) goto LA68_;
			itemEnding_1 = TM__vYBWrr780p7faFzauVMtPg_248;
		}
		goto LA66_;
LA68_: ;
		{
			itemEnding_1 = TM__vYBWrr780p7faFzauVMtPg_250;
		}
LA66_: ;
		colontmpD__4 = nsuRepeatStr(itemEnding_1, ((NI)((*d_p0).curQuotationDepth - ((NI)1))));
		if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
		prepareAdd((&tmp_2), colontmpD__4.len + 0);
appendString((&tmp_2), colontmpD__4);
		T71_[0] = tmp_2;
		{
			if (!((*n_p1).anchor.len == 0)) goto LA74_;
			colontmpD__5 = TM__vYBWrr780p7faFzauVMtPg_255;
			T71_[1] = colontmpD__5;
		}
		goto LA72_;
LA74_: ;
		{
			NimStringV2 T77_;
			T77_.len = 0; T77_.p = NIM_NIL;
			switch ((*d_p0).target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				NimStringV2 T79_;
				T79_.len = 0; T79_.p = NIM_NIL;
				T79_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T79_), TM__vYBWrr780p7faFzauVMtPg_256);
appendString((&T79_), (*n_p1).anchor);
appendString((&T79_), TM__vYBWrr780p7faFzauVMtPg_257);
				colontmpD__6 = T79_;
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				NimStringV2 T81_;
				T81_.len = 0; T81_.p = NIM_NIL;
				T81_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T81_), TM__vYBWrr780p7faFzauVMtPg_258);
appendString((&T81_), (*n_p1).anchor);
appendString((&T81_), TM__vYBWrr780p7faFzauVMtPg_259);
appendString((&T81_), (*n_p1).anchor);
appendString((&T81_), TM__vYBWrr780p7faFzauVMtPg_260);
				colontmpD__6 = T81_;
			}
			break;
			default: __builtin_unreachable();
			}
			T71_[1] = colontmpD__6;
		}
LA72_: ;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_252, TM__vYBWrr780p7faFzauVMtPg_254, T71_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA64_;
		{
			LA64_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
			eqdestroy___system_u2691(colontmpD__5);
			eqdestroy___system_u2691(colontmpD__4);
			eqdestroy___system_u2691(tmp_2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)28):
	{
		NimStringV2 itemPrefix_1;
		NimStringV2 colontmpD__7;
		NimStringV2 colontmpD__8;
		NI addQuotationDepth_1;
		NimStringV2 T103_;
		NimStringV2 T104_;
		itemPrefix_1.len = 0; itemPrefix_1.p = NIM_NIL;
		colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
		colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
		addQuotationDepth_1 = (NI)((*n_p1)._kind_7.quotationDepth - (*d_p0).curQuotationDepth);
		{
			NimStringV2 s_1;
			NimStringV2 T90_;
			if (!(((NI)0) <= addQuotationDepth_1)) goto LA88_;
			s_1.len = 0; s_1.p = NIM_NIL;
			T90_.len = 0; T90_.p = NIM_NIL;
			{
				if (!((*d_p0).target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0))) goto LA93_;
				s_1 = TM__vYBWrr780p7faFzauVMtPg_262;
			}
			goto LA91_;
LA93_: ;
			{
				s_1 = TM__vYBWrr780p7faFzauVMtPg_264;
			}
LA91_: ;
			itemPrefix_1 = nsuRepeatStr(s_1, (addQuotationDepth_1));
			if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
		}
		goto LA86_;
LA88_: ;
		{
			NimStringV2 s_2;
			NimStringV2 T97_;
			s_2.len = 0; s_2.p = NIM_NIL;
			T97_.len = 0; T97_.p = NIM_NIL;
			{
				if (!((*d_p0).target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0))) goto LA100_;
				s_2 = TM__vYBWrr780p7faFzauVMtPg_265;
			}
			goto LA98_;
LA100_: ;
			{
				s_2 = TM__vYBWrr780p7faFzauVMtPg_266;
			}
LA98_: ;
			itemPrefix_1 = nsuRepeatStr(s_2, (((NI64)-(addQuotationDepth_1))));
			if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
		}
LA86_: ;
		T103_.len = 0; T103_.p = NIM_NIL;
		T103_ = rawNewString(itemPrefix_1.len + 9);
appendString((&T103_), itemPrefix_1);
appendString((&T103_), TM__vYBWrr780p7faFzauVMtPg_268);
		colontmpD__7 = T103_;
		T104_.len = 0; T104_.p = NIM_NIL;
		T104_ = rawNewString(itemPrefix_1.len + 3);
appendString((&T104_), itemPrefix_1);
appendString((&T104_), TM__vYBWrr780p7faFzauVMtPg_270);
		colontmpD__8 = T104_;
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, colontmpD__7, colontmpD__8, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA85_;
		(*d_p0).curQuotationDepth = (*n_p1)._kind_7.quotationDepth;
		{
			LA85_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__8);
			eqdestroy___system_u2691(colontmpD__7);
			eqdestroy___system_u2691(itemPrefix_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)29):
	{
		{
			NIM_BOOL T110_;
			NI T111_;
			T110_ = (NIM_BOOL)0;
			T111_ = (*n_p1).sons.len;
			T110_ = (T111_ == ((NI)1));
			if (!(T110_)) goto LA112_;
			T110_ = eqStrings((*(*n_p1).sons.p->data[((NI)0)])._kind_3.lineIndent, TM__vYBWrr780p7faFzauVMtPg_271);
LA112_: ;
			if (!T110_) goto LA113_;
			renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_273, TM__vYBWrr780p7faFzauVMtPg_275, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA108_;
LA113_: ;
		{
			renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_277, TM__vYBWrr780p7faFzauVMtPg_279, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA108_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)30):
	{
		{
			if (!((*n_p1)._kind_3.lineIndent.len == ((NI)0))) goto LA119_;
			renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_281, TM__vYBWrr780p7faFzauVMtPg_283, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA117_;
LA119_: ;
		{
			if (!eqStrings((*n_p1)._kind_3.lineIndent, TM__vYBWrr780p7faFzauVMtPg_284)) goto LA122_;
			renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_286, TM__vYBWrr780p7faFzauVMtPg_288, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA117_;
LA122_: ;
		{
			NimStringV2 indent_1;
			NimStringV2 colontmpD__9;
			NimStringV2 colontmpD__10;
			NimStringV2 colontmpD__11;
			NimStringV2 T126_;
			NF T127_;
			NimStringV2 T128_;
			NimStringV2 T129_;
			indent_1.len = 0; indent_1.p = NIM_NIL;
			colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
			colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
			colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
			T126_.len = 0; T126_.p = NIM_NIL;
			T127_ = (NF)0;
			T127_ = toFloat__system_u1695((NI)((*n_p1)._kind_3.lineIndent.len - ((NI)1)));
			colontmpD__9 = dollar___system_u4730(((NF)(0.5) * (NF)(T127_)));
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			T126_ = rawNewString(colontmpD__9.len + 2);
appendString((&T126_), colontmpD__9);
appendString((&T126_), TM__vYBWrr780p7faFzauVMtPg_290);
			indent_1 = T126_;
			T128_.len = 0; T128_.p = NIM_NIL;
			T128_ = rawNewString(indent_1.len + 42);
appendString((&T128_), TM__vYBWrr780p7faFzauVMtPg_292);
appendString((&T128_), indent_1);
appendString((&T128_), TM__vYBWrr780p7faFzauVMtPg_294);
			colontmpD__10 = T128_;
			T129_.len = 0; T129_.p = NIM_NIL;
			T129_ = rawNewString(indent_1.len + 22);
appendString((&T129_), TM__vYBWrr780p7faFzauVMtPg_296);
appendString((&T129_), indent_1);
appendString((&T129_), TM__vYBWrr780p7faFzauVMtPg_298);
			colontmpD__11 = T129_;
			renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, colontmpD__10, colontmpD__11, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA125_;
			{
				LA125_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__11);
				eqdestroy___system_u2691(colontmpD__10);
				eqdestroy___system_u2691(colontmpD__9);
				eqdestroy___system_u2691(indent_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA117_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)31):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_300, TM__vYBWrr780p7faFzauVMtPg_302, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)56):
	{
		renderAdmonition__packagesZdocutilsZrstgen_u4000(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)32):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)33):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)34):
	{
		NimStringV2 colontmpD__12;
		NimStringV2 colontmpD__13;
		NimStringV2 T136_;
		colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
		colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
		T136_.len = 0; T136_.p = NIM_NIL;
		colontmpD__12 = nsuRepeatStr(TM__vYBWrr780p7faFzauVMtPg_370, ((*n_p1)._kind_10.colCount));
		if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
		T136_ = rawNewString(colontmpD__12.len + 76);
appendString((&T136_), TM__vYBWrr780p7faFzauVMtPg_368);
appendString((&T136_), colontmpD__12);
appendString((&T136_), TM__vYBWrr780p7faFzauVMtPg_372);
		colontmpD__13 = T136_;
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_366, colontmpD__13, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA135_;
		{
			LA135_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__13);
			eqdestroy___system_u2691(colontmpD__12);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)35):
	{
		{
			NI T142_;
			T142_ = (NI)0;
			T142_ = len__packagesZdocutilsZrstast_u114(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!(((NI)1) <= T142_)) goto LA143_;
			switch ((*d_p0).target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				prepareAdd((&(*result_p2)), 4);
appendString((&(*result_p2)), TM__vYBWrr780p7faFzauVMtPg_374);
				renderAux__packagesZdocutilsZrstgen_u328(d_p0, n_p1, result_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				prepareAdd((&(*result_p2)), 6);
appendString((&(*result_p2)), TM__vYBWrr780p7faFzauVMtPg_376);
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				tySequence__8Np6tlClE5az1CyqZdN19bQ spanLines_1;
				NI nCell_1;
				spanLines_1.len = 0; spanLines_1.p = NIM_NIL;
				{
					if (!((*(*n_p1).sons.p->data[((NI)0)]).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)36))) goto LA150_;
					prepareAdd((&(*result_p2)), 19);
appendString((&(*result_p2)), TM__vYBWrr780p7faFzauVMtPg_378);
				}
LA150_: ;
				nCell_1 = ((NI)0);
				{
					NI uCell_1;
					NI colontmp__2;
					NI T153_;
					NI res_2;
					uCell_1 = (NI)0;
					colontmp__2 = (NI)0;
					T153_ = (NI)0;
					T153_ = len__packagesZdocutilsZrstast_u114(n_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA147_;
					colontmp__2 = (NI)(T153_ - ((NI)1));
					res_2 = ((NI)0);
					{
						while (1) {
							if (!(res_2 <= colontmp__2)) goto LA155;
							uCell_1 = ((NI) (res_2));
							renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[uCell_1], result_p2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA147_;
							{
								tyTuple__1v9bKyksXWMsm0vNwmZ4EuQ T160_;
								if (!(((NI)0) < (*(*n_p1).sons.p->data[uCell_1])._kind_12.span)) goto LA158_;
								T160_.Field0 = (NI)(nCell_1 + ((NI)1));
								T160_.Field1 = (NI)(nCell_1 + (*(*n_p1).sons.p->data[uCell_1])._kind_12.span);
								add__packagesZdocutilsZrstgen_u4087((&spanLines_1), T160_);
								nCell_1 += (*(*n_p1).sons.p->data[uCell_1])._kind_12.span;
							}
							goto LA156_;
LA158_: ;
							{
								nCell_1 += ((NI)1);
							}
LA156_: ;
							{
								NI T164_;
								T164_ = (NI)0;
								T164_ = len__packagesZdocutilsZrstast_u114(n_p1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA147_;
								if (!!((uCell_1 == (NI)(T164_ - ((NI)1))))) goto LA165_;
								prepareAdd((&(*result_p2)), 3);
appendString((&(*result_p2)), TM__vYBWrr780p7faFzauVMtPg_380);
							}
LA165_: ;
							res_2 += ((NI)1);
						} LA155: ;
					}
				}
				prepareAdd((&(*result_p2)), 2);
appendString((&(*result_p2)), TM__vYBWrr780p7faFzauVMtPg_382);
				{
					if (!(*n_p1)._kind_11.endsHeader) goto LA169_;
					prepareAdd((&(*result_p2)), 9);
appendString((&(*result_p2)), TM__vYBWrr780p7faFzauVMtPg_384);
				}
LA169_: ;
				{
					NI* start_1;
					NI* stop_1;
					NI i_2;
					NI L_1;
					NI T172_;
					start_1 = (NI*)0;
					stop_1 = (NI*)0;
					i_2 = ((NI)0);
					T172_ = spanLines_1.len;
					L_1 = T172_;
					{
						while (1) {
							NimStringV2 colontmpD__14;
							NimStringV2 colontmpD__15;
							NimStringV2 colontmpD__16;
							tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T176_;
							if (!(i_2 < L_1)) goto LA174;
							colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
							colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
							colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
							start_1 = (&spanLines_1.p->data[i_2].Field0);
							stop_1 = (&spanLines_1.p->data[i_2].Field1);
							colontmpD__14 = dollar___systemZdollars_u9((*start_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA175_;
							T176_[0] = colontmpD__14;
							colontmpD__15 = dollar___systemZdollars_u9((*stop_1));
							if (NIM_UNLIKELY(*nimErr_)) goto LA175_;
							T176_[1] = colontmpD__15;
							colontmpD__16 = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_386, T176_, 2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA175_;
							prepareAdd((&(*result_p2)), colontmpD__16.len + 0);
appendString((&(*result_p2)), colontmpD__16);
							i_2 += ((NI)1);
							{
								LA175_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__16);
								eqdestroy___system_u2691(colontmpD__15);
								eqdestroy___system_u2691(colontmpD__14);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA147_;
						} LA174: ;
					}
				}
				prepareAdd((&(*result_p2)), 1);
appendString((&(*result_p2)), TM__vYBWrr780p7faFzauVMtPg_387);
				{
					LA147_:;
				}
				{
					eqdestroy___types_u1571(spanLines_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			break;
			default: __builtin_unreachable();
			}
		}
LA143_: ;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)36):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)37):
	{
		switch ((*d_p0).target) {
		case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
		{
			NimStringV2 tag_1;
			NimStringV2 spanSpec_1;
			NimStringV2 colontmpD__17;
			NimStringV2 T184_;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T196_;
			tag_1.len = 0; tag_1.p = NIM_NIL;
			spanSpec_1.len = 0; spanSpec_1.p = NIM_NIL;
			colontmpD__17.len = 0; colontmpD__17.p = NIM_NIL;
			T184_.len = 0; T184_.p = NIM_NIL;
			{
				if (!((*n_p1).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)36))) goto LA187_;
				tag_1 = TM__vYBWrr780p7faFzauVMtPg_389;
			}
			goto LA185_;
LA187_: ;
			{
				tag_1 = TM__vYBWrr780p7faFzauVMtPg_391;
			}
LA185_: ;
			{
				if (!((*n_p1)._kind_12.span <= ((NI)1))) goto LA192_;
				spanSpec_1 = TM__vYBWrr780p7faFzauVMtPg_392;
			}
			goto LA190_;
LA192_: ;
			{
				NimStringV2 colontmpD__18;
				NimStringV2 T195_;
				colontmpD__18.len = 0; colontmpD__18.p = NIM_NIL;
				T195_.len = 0; T195_.p = NIM_NIL;
				colontmpD__18 = dollar___systemZdollars_u9((*n_p1)._kind_12.span);
				if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
				T195_ = rawNewString(colontmpD__18.len + 38);
appendString((&T195_), TM__vYBWrr780p7faFzauVMtPg_394);
appendString((&T195_), colontmpD__18);
appendString((&T195_), TM__vYBWrr780p7faFzauVMtPg_396);
				spanSpec_1 = T195_;
				eqdestroy___system_u2691(colontmpD__18);
			}
LA190_: ;
			T196_[0] = tag_1;
			T196_[1] = spanSpec_1;
			colontmpD__17 = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_398, T196_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
			renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, colontmpD__17, TM__vYBWrr780p7faFzauVMtPg_399, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA183_;
			{
				LA183_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__17);
				eqdestroy___system_u2691(spanSpec_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
		{
			NimStringV2 text_1;
			NimStringV2 latexStr_1;
			NimStringV2 T201_;
			text_1.len = 0; text_1.p = NIM_NIL;
			latexStr_1.len = 0; latexStr_1.p = NIM_NIL;
			T201_.len = 0; T201_.p = NIM_NIL;
			{
				if (!((*n_p1).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)36))) goto LA204_;
				text_1 = TM__vYBWrr780p7faFzauVMtPg_401;
			}
			goto LA202_;
LA204_: ;
			{
				text_1 = TM__vYBWrr780p7faFzauVMtPg_402;
			}
LA202_: ;
			{
				if (!((*n_p1)._kind_12.span <= ((NI)1))) goto LA209_;
				eqcopy___system_u2694((&latexStr_1), text_1);
			}
			goto LA207_;
LA209_: ;
			{
				NimStringV2 colontmpD__19;
				NimStringV2 T212_;
				colontmpD__19.len = 0; colontmpD__19.p = NIM_NIL;
				T212_.len = 0; T212_.p = NIM_NIL;
				colontmpD__19 = dollar___systemZdollars_u9((*n_p1)._kind_12.span);
				if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
				T212_ = rawNewString(colontmpD__19.len + text_1.len + 19);
appendString((&T212_), TM__vYBWrr780p7faFzauVMtPg_404);
appendString((&T212_), colontmpD__19);
appendString((&T212_), TM__vYBWrr780p7faFzauVMtPg_406);
appendString((&T212_), text_1);
appendString((&T212_), TM__vYBWrr780p7faFzauVMtPg_408);
				latexStr_1 = T212_;
				eqdestroy___system_u2691(colontmpD__19);
			}
LA207_: ;
			renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_409, latexStr_1, result_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA200_;
			{
				LA200_:;
			}
			{
				eqdestroy___system_u2691(latexStr_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		break;
		default: __builtin_unreachable();
		}
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)40):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_411, TM__vYBWrr780p7faFzauVMtPg_413, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)38):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)39):
	{
		NimStringV2 mark_1;
		NimStringV2 body_1;
		NimStringV2 colontmpD__20;
		NimStringV2 colontmpD__21;
		tyArray__Seu7uK9aaOSN0BK3EAjjSHw T218_;
		mark_1.len = 0; mark_1.p = NIM_NIL;
		body_1.len = 0; body_1.p = NIM_NIL;
		colontmpD__20.len = 0; colontmpD__20.p = NIM_NIL;
		colontmpD__21.len = 0; colontmpD__21.p = NIM_NIL;
		mark_1 = TM__vYBWrr780p7faFzauVMtPg_414;
		renderAux__packagesZdocutilsZrstgen_u328(d_p0, (*n_p1).sons.p->data[((NI)0)], (&mark_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
		body_1 = TM__vYBWrr780p7faFzauVMtPg_415;
		renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[((NI)1)], (&body_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
		T218_[0] = body_1;
		{
			if (!((*n_p1).anchor.len == 0)) goto LA221_;
			colontmpD__20 = TM__vYBWrr780p7faFzauVMtPg_420;
			T218_[1] = colontmpD__20;
		}
		goto LA219_;
LA221_: ;
		{
			NimStringV2 T224_;
			T224_.len = 0; T224_.p = NIM_NIL;
			switch ((*d_p0).target) {
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0):
			{
				NimStringV2 T226_;
				T226_.len = 0; T226_.p = NIM_NIL;
				T226_ = rawNewString((*n_p1).anchor.len + 6);
appendString((&T226_), TM__vYBWrr780p7faFzauVMtPg_421);
appendString((&T226_), (*n_p1).anchor);
appendString((&T226_), TM__vYBWrr780p7faFzauVMtPg_422);
				colontmpD__21 = T226_;
			}
			break;
			case ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1):
			{
				NimStringV2 T228_;
				T228_.len = 0; T228_.p = NIM_NIL;
				T228_ = rawNewString((*n_p1).anchor.len + (*n_p1).anchor.len + 24);
appendString((&T228_), TM__vYBWrr780p7faFzauVMtPg_423);
appendString((&T228_), (*n_p1).anchor);
appendString((&T228_), TM__vYBWrr780p7faFzauVMtPg_424);
appendString((&T228_), (*n_p1).anchor);
appendString((&T228_), TM__vYBWrr780p7faFzauVMtPg_425);
				colontmpD__21 = T228_;
			}
			break;
			default: __builtin_unreachable();
			}
			T218_[1] = colontmpD__21;
		}
LA219_: ;
		T218_[2] = mark_1;
		T218_[3] = (*n_p1).anchor;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_417, TM__vYBWrr780p7faFzauVMtPg_419, T218_, 4);
		if (NIM_UNLIKELY(*nimErr_)) goto LA217_;
		{
			LA217_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__21);
			eqdestroy___system_u2691(colontmpD__20);
			eqdestroy___system_u2691(body_1);
			eqdestroy___system_u2691(mark_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)44):
	{
		renderHyperlink__packagesZdocutilsZrstgen_u4009(d_p0, (*n_p1).sons.p->data[((NI)0)], (*n_p1).sons.p->data[((NI)1)], result_p2, NIM_FALSE, NIM_FALSE, TM__vYBWrr780p7faFzauVMtPg_442);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)43):
	{
		renderHyperlink__packagesZdocutilsZrstgen_u4009(d_p0, (*n_p1).sons.p->data[((NI)0)], (*n_p1).sons.p->data[((NI)0)], result_p2, NIM_FALSE, NIM_FALSE, TM__vYBWrr780p7faFzauVMtPg_443);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)41):
	{
		renderHyperlink__packagesZdocutilsZrstgen_u4009(d_p0, (*n_p1).sons.p->data[((NI)0)], (*n_p1).sons.p->data[((NI)0)], result_p2, NIM_TRUE, NIM_FALSE, TM__vYBWrr780p7faFzauVMtPg_444);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)45):
	{
		renderHyperlink__packagesZdocutilsZrstgen_u4009(d_p0, (*n_p1).sons.p->data[((NI)0)], (*n_p1).sons.p->data[((NI)1)], result_p2, NIM_FALSE, NIM_FALSE, TM__vYBWrr780p7faFzauVMtPg_445);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)47):
	{
		renderHyperlink__packagesZdocutilsZrstgen_u4009(d_p0, (*n_p1).sons.p->data[((NI)0)], (*n_p1).sons.p->data[((NI)1)], result_p2, NIM_FALSE, NIM_TRUE, (*n_p1)._kind_9.tooltip);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)42):
	{
		renderHyperlink__packagesZdocutilsZrstgen_u4009(d_p0, (*n_p1).sons.p->data[((NI)0)], (*n_p1).sons.p->data[((NI)1)], result_p2, NIM_TRUE, NIM_FALSE, TM__vYBWrr780p7faFzauVMtPg_446);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)46):
	{
		NimStringV2 tmp_3;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T239_;
		tmp_3.len = 0; tmp_3.p = NIM_NIL;
		tmp_3 = TM__vYBWrr780p7faFzauVMtPg_448;
		renderAux__packagesZdocutilsZrstgen_u328(d_p0, (*n_p1).sons.p->data[((NI)0)], (&tmp_3));
		if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
		prepareAdd((&tmp_3), 1);
appendString((&tmp_3), TM__vYBWrr780p7faFzauVMtPg_449);
		T239_[0] = tmp_3;
		T239_[1] = (*(*n_p1).sons.p->data[((NI)1)])._kind_1.text;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_451, TM__vYBWrr780p7faFzauVMtPg_453, T239_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA238_;
		{
			LA238_:;
		}
		{
			eqdestroy___system_u2691(tmp_3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)49):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)50):
	{
		renderAux__packagesZdocutilsZrstgen_u328(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)57):
	{
		tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD__22;
		colontmpD__22 = NIM_NIL;
		{
			NIM_BOOL T246_;
			tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD__23;
			NimStringV2 colontmpD__24;
			T246_ = (NIM_BOOL)0;
			T246_ = !(((*d_p0).target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1)));
			if (!(T246_)) goto LA247_;
			colontmpD__22 = lastSon__packagesZdocutilsZrstast_u457(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T246_ = !((colontmpD__22 == 0));
LA247_: ;
			if (!T246_) goto LA248_;
			colontmpD__23 = NIM_NIL;
			colontmpD__24.len = 0; colontmpD__24.p = NIM_NIL;
			colontmpD__23 = lastSon__packagesZdocutilsZrstast_u457(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__24 = addNodes__packagesZdocutilsZrst_u80(colontmpD__23);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*result_p2)), colontmpD__24.len + 0);
appendString((&(*result_p2)), colontmpD__24);
			eqdestroy___system_u2691(colontmpD__24);
			eqdestroy___packagesZdocutilsZrstast_u285(colontmpD__23);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA248_: ;
		eqdestroy___packagesZdocutilsZrstast_u285(colontmpD__22);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)58):
	{
		tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD__25;
		colontmpD__25 = NIM_NIL;
		{
			NIM_BOOL T253_;
			tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* colontmpD__26;
			NimStringV2 colontmpD__27;
			T253_ = (NIM_BOOL)0;
			T253_ = ((*d_p0).target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1));
			if (!(T253_)) goto LA254_;
			colontmpD__25 = lastSon__packagesZdocutilsZrstast_u457(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T253_ = !((colontmpD__25 == 0));
LA254_: ;
			if (!T253_) goto LA255_;
			colontmpD__26 = NIM_NIL;
			colontmpD__27.len = 0; colontmpD__27.p = NIM_NIL;
			colontmpD__26 = lastSon__packagesZdocutilsZrstast_u457(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			colontmpD__27 = addNodes__packagesZdocutilsZrst_u80(colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			prepareAdd((&(*result_p2)), colontmpD__27.len + 0);
appendString((&(*result_p2)), colontmpD__27);
			eqdestroy___system_u2691(colontmpD__27);
			eqdestroy___packagesZdocutilsZrstast_u285(colontmpD__26);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA255_: ;
		eqdestroy___packagesZdocutilsZrstast_u285(colontmpD__25);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)53):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)54):
	{
		renderImage__packagesZdocutilsZrstgen_u3713(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)55):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)62):
	{
		renderCode__packagesZdocutilsZrstgen_u3819(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)59):
	{
		renderContainer__packagesZdocutilsZrstgen_u3892(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)74):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)61):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_595, TM__vYBWrr780p7faFzauVMtPg_596, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)48):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_597, TM__vYBWrr780p7faFzauVMtPg_598, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)64):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)63):
	{
		NimStringV2 tmp0_1;
		NimStringV2 tmp1_1;
		NimStringV2 class_1;
		tmp0_1.len = 0; tmp0_1.p = NIM_NIL;
		tmp1_1.len = 0; tmp1_1.p = NIM_NIL;
		class_1.len = 0; class_1.p = NIM_NIL;
		tmp0_1 = TM__vYBWrr780p7faFzauVMtPg_599;
		tmp1_1 = TM__vYBWrr780p7faFzauVMtPg_600;
		renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[((NI)0)], (&tmp0_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
		renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[((NI)1)], (&tmp1_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
		class_1 = tmp1_1;
		eqwasMoved___system_u2688((&tmp1_1));
		{
			NIM_BOOL T266_;
			T266_ = (NIM_BOOL)0;
			T266_ = ((*d_p0).target == ((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)1));
			if (!(T266_)) goto LA267_;
			T266_ = ((*n_p1).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)64));
LA267_: ;
			if (!T266_) goto LA268_;
			eqsink___system_u2700((&class_1), TM__vYBWrr780p7faFzauVMtPg_602);
		}
LA268_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T274_;
			if (!((*n_p1).kind == ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)63))) goto LA272_;
			T274_[0] = tmp0_1;
			T274_[1] = class_1;
			dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_604, TM__vYBWrr780p7faFzauVMtPg_606, T274_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
		}
		goto LA270_;
LA272_: ;
		{
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T276_;
			T276_[0] = tmp0_1;
			T276_[1] = class_1;
			dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_607, TM__vYBWrr780p7faFzauVMtPg_608, T276_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA263_;
		}
LA270_: ;
		{
			LA263_:;
		}
		{
			eqdestroy___system_u2691(class_1);
			eqdestroy___system_u2691(tmp1_1);
			eqdestroy___system_u2691(tmp0_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)65):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_610, TM__vYBWrr780p7faFzauVMtPg_612, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)66):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_614, TM__vYBWrr780p7faFzauVMtPg_616, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)68):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_618, TM__vYBWrr780p7faFzauVMtPg_620, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)69):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_622, TM__vYBWrr780p7faFzauVMtPg_623, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)70):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_625, TM__vYBWrr780p7faFzauVMtPg_627, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)67):
	{
		renderIndexTerm__packagesZdocutilsZrstgen_u380(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)72):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)71):
	{
		renderAux__packagesZdocutilsZrstgen_u340(d_p0, n_p1, TM__vYBWrr780p7faFzauVMtPg_629, TM__vYBWrr780p7faFzauVMtPg_631, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)73):
	{
		NimStringV2 tmp_4;
		NimStringV2 colontmpD__28;
		tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T288_;
		tmp_4.len = 0; tmp_4.p = NIM_NIL;
		colontmpD__28.len = 0; colontmpD__28.p = NIM_NIL;
		tmp_4 = TM__vYBWrr780p7faFzauVMtPg_632;
		renderAux__packagesZdocutilsZrstgen_u328(d_p0, n_p1, (&tmp_4));
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		T288_[0] = tmp_4;
		colontmpD__28 = rstnodeToRefname__packagesZdocutilsZrst_u78(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		T288_[1] = colontmpD__28;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_634, TM__vYBWrr780p7faFzauVMtPg_636, T288_, 2);
		if (NIM_UNLIKELY(*nimErr_)) goto LA287_;
		{
			LA287_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__28);
			eqdestroy___system_u2691(tmp_4);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)75):
	{
		renderSmiley__packagesZdocutilsZrstgen_u3723(d_p0, n_p1, result_p2);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)77):
	{
		NimStringV2 colontmpD__29;
		colontmpD__29.len = 0; colontmpD__29.p = NIM_NIL;
		colontmpD__29 = esc__packagesZdocutilsZrstgen_u264((*d_p0).target, (*n_p1)._kind_1.text, ((NI)-1), (*d_p0).escMode);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p2)), colontmpD__29.len + 0);
appendString((&(*result_p2)), colontmpD__29);
		eqdestroy___system_u2691(colontmpD__29);
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)52):
	{
		(*d_p0).hasToc = NIM_TRUE;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)76):
	{
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)51):
	{
		tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* T296_;
		NimStringV2 T297_;
		eqsink___system_u2700((&(*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)2))- 0]), TM__vYBWrr780p7faFzauVMtPg_644);
		T296_ = (tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ*)0;
		T296_ = d_p0;
		renderRstToOut__packagesZdocutilsZrstgen_u324(T296_, (*n_p1).sons.p->data[((NI)0)], (&(*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)2))- 0]));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T297_.len = 0; T297_.p = NIM_NIL;
		T297_ = addNodes__packagesZdocutilsZrst_u80((*n_p1).sons.p->data[((NI)0)]);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T297_); goto BeforeRet_;}
		eqsink___system_u2700((&(*d_p0).meta[(((tyEnum_MetaEnum__cUBpWOSSkrgtToqzNjoPSA)1))- 0]), T297_);
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderAux__packagesZdocutilsZrstgen_u328)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (NI)0;
		T2_ = len__packagesZdocutilsZrstast_u114(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		colontmp_ = (NI)(T2_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA4;
				i_1 = ((NI) (res_1));
				renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[i_1], result_p2);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				res_1 += ((NI)1);
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderIndexTerm__packagesZdocutilsZrstgen_u380)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NimStringV2 refname_1;
	NimStringV2 id_1;
	NimStringV2 colontmpD_;
	NimStringV2 term_1;
	NimStringV2 colontmpD__2;
	NimStringV2 T9_;
	NI T10_;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	refname_1.len = 0; refname_1.p = NIM_NIL;
	id_1.len = 0; id_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	term_1.len = 0; term_1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	refname_1 = rstnodeToRefname__packagesZdocutilsZrst_u78(n_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T4_;
		NI T7_;
		T4_ = (NIM_BOOL)0;
		T4_ = hasKey__vmgen_u3190((*d_p0).seenIndexTerms, refname_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		T7_ = (NI)0;
		T7_ = getOrDefault__packagesZdocutilsZrstgen_u506((*d_p0).seenIndexTerms, refname_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		X5BX5Deq___vmdef_u2322((&(*d_p0).seenIndexTerms), refname_1, (NI)(T7_ + ((NI)1)));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA2_;
LA5_: ;
	{
		X5BX5Deq___vmdef_u2322((&(*d_p0).seenIndexTerms), refname_1, ((NI)1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA2_: ;
	T9_.len = 0; T9_.p = NIM_NIL;
	T10_ = (NI)0;
	T10_ = getOrDefault__packagesZdocutilsZrstgen_u506((*d_p0).seenIndexTerms, refname_1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = dollar___systemZdollars_u9(T10_);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T9_ = rawNewString(refname_1.len + colontmpD_.len + 1);
appendString((&T9_), refname_1);
appendChar((&T9_), 95);
appendString((&T9_), colontmpD_);
	id_1 = T9_;
	term_1 = TM__vYBWrr780p7faFzauVMtPg_57;
	renderAux__packagesZdocutilsZrstgen_u328(d_p0, n_p1, (&term_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = htmlFileRelPath__packagesZdocutilsZrstgen_u377(d_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	setIndexTerm__packagesZdocutilsZrstgen_u353(d_p0, ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)3), colontmpD__2, id_1, term_1, (*d_p0).currentSection, TM__vYBWrr780p7faFzauVMtPg_645, ((NI)0));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_[0] = id_1;
	T11_[1] = term_1;
	dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_647, TM__vYBWrr780p7faFzauVMtPg_649, T11_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(term_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(id_1);
		eqdestroy___system_u2691(refname_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, traverseForIndex__packagesZdocutilsZrstgen_u4022)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1) {
	NimStringV2 discarded_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	discarded_1.len = 0; discarded_1.p = NIM_NIL;
	{
		if (!(n_p1 == ((tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA*) NIM_NIL))) goto LA4_;
		eqdestroy___system_u2691(discarded_1);
		goto BeforeRet_;
	}
LA4_: ;
	switch ((*n_p1).kind) {
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)67):
	{
		renderIndexTerm__packagesZdocutilsZrstgen_u380(d_p0, n_p1, (&discarded_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)1):
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)3):
	{
		renderHeadline__packagesZdocutilsZrstgen_u3635(d_p0, n_p1, (&discarded_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	case ((tyEnum_RstNodeKind__jZ5Fhlprzu8cLzCUcoxF3w)2):
	{
		renderOverline__packagesZdocutilsZrstgen_u3660(d_p0, n_p1, (&discarded_1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	break;
	default:
	{
		{
			NI i_1;
			NI colontmp_;
			NI i_2;
			i_1 = (NI)0;
			colontmp_ = (NI)0;
			colontmp_ = len__packagesZdocutilsZrstast_u114(n_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			i_2 = ((NI)0);
			{
				while (1) {
					if (!(i_2 < colontmp_)) goto LA12;
					i_1 = i_2;
					traverseForIndex__packagesZdocutilsZrstgen_u4022(d_p0, (*n_p1).sons.p->data[i_1]);
					if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
					i_2 += ((NI)1);
				} LA12: ;
			}
		}
	}
	break;
	}
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(discarded_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntry__packagesZdocutilsZrstgen_u3687)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, tyObject_RstNode__MwWo0WeOohi1r0R1XZBjdA* n_p1, NimStringV2* result_p2) {
	NimStringV2 header_1;
	tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	header_1.len = 0; header_1.p = NIM_NIL;
	header_1 = TM__vYBWrr780p7faFzauVMtPg_651;
	{
		NI i_1;
		NI colontmp_;
		NI T3_;
		NI res_1;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T3_ = (NI)0;
		T3_ = len__packagesZdocutilsZrstast_u114(n_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmp_ = (NI)(T3_ - ((NI)1));
		res_1 = ((NI)0);
		{
			while (1) {
				if (!(res_1 <= colontmp_)) goto LA5;
				i_1 = ((NI) (res_1));
				renderRstToOut__packagesZdocutilsZrstgen_u324(d_p0, (*n_p1).sons.p->data[i_1], (&header_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				res_1 += ((NI)1);
			} LA5: ;
		}
	}
	T6_[0] = (*n_p1).anchor;
	T6_[1] = header_1;
	dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p2, TM__vYBWrr780p7faFzauVMtPg_653, TM__vYBWrr780p7faFzauVMtPg_655, T6_, 2);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(header_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, renderTocEntries__packagesZdocutilsZrstgen_u3698)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* d_p0, NI* j_p1, NI lvl_p2, NimStringV2* result_p3) {
	NimStringV2 tmp_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	tmp_1.len = 0; tmp_1.p = NIM_NIL;
	tmp_1 = TM__vYBWrr780p7faFzauVMtPg_650;
	{
		while (1) {
			NI T4_;
			NI a_1;
			T4_ = ((*d_p0).tocPart.len-1);
			if (!((*j_p1) <= T4_)) goto LA3;
			a_1 = ((*(*d_p0).tocPart.p->data[(*j_p1)])._kind_5.level > 0? ((*(*d_p0).tocPart.p->data[(*j_p1)])._kind_5.level) : -((*(*d_p0).tocPart.p->data[(*j_p1)])._kind_5.level));
			{
				if (!(a_1 == lvl_p2)) goto LA7_;
				renderTocEntry__packagesZdocutilsZrstgen_u3687(d_p0, (*d_p0).tocPart.p->data[(*j_p1)], (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				(*j_p1) += ((NI)1);
			}
			goto LA5_;
LA7_: ;
			{
				if (!(lvl_p2 < a_1)) goto LA10_;
				renderTocEntries__packagesZdocutilsZrstgen_u3698(d_p0, j_p1, a_1, (&tmp_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			}
			goto LA5_;
LA10_: ;
			{
				goto LA2;
			}
LA5_: ;
		} LA3: ;
	} LA2: ;
	{
		tyArray__YgExxhfgKcesA5EOUj1MOA T17_;
		if (!(((NI)1) < lvl_p2)) goto LA15_;
		T17_[0] = tmp_1;
		dispA__packagesZdocutilsZrstgen_u310((*d_p0).target, result_p3, TM__vYBWrr780p7faFzauVMtPg_657, TM__vYBWrr780p7faFzauVMtPg_659, T17_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA13_;
LA15_: ;
	{
		prepareAdd((&(*result_p3)), tmp_1.len + 0);
appendString((&(*result_p3)), tmp_1);
	}
LA13_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(tmp_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeIndexFile__packagesZdocutilsZrstgen_u211)(tyObject_RstGenerator__Lwz3PMSYJgupRflH4ZFokQ* g_p0, NimStringV2 outfile_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(((NI)0) < (*g_p0).theIndex.len)) goto LA3_;
		writeFile__stdZsyncio_u532(outfile_p1, (*g_p0).theIndex);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA3_: ;
	}BeforeRet_: ;
}
static N_INLINE(NimStringV2, pop__stdZprivateZosdirs_u415)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0) {
	NimStringV2 result;
	NI L_1;
	NI T1_;
	T1_ = (*s_p0).len;
	L_1 = (NI)(T1_ - ((NI)1));
	result = (*s_p0).p->data[L_1];
	eqwasMoved___system_u2688((&(*s_p0).p->data[L_1]));
	shrink__system_u5403(s_p0, (L_1));
	return result;
}
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosjoinPath(head_p0, tail_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NCSTRING, nimToCStringConv)(NimStringV2 s_p0) {
	NCSTRING result;
	{
		if (!(s_p0.len == ((NI)0))) goto LA3_;
		result = "";
	}
	goto LA1_;
LA3_: ;
	{
		result = ((NCSTRING) ((*s_p0.p).data));
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, readIndexDir__packagesZdocutilsZrstgen_u2311)(NimStringV2 dir_p0, tyTuple__i2GOAy1W4iVZ1R13oxrTvA* Result) {
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ T1_;
	tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw T2_;
	NI L_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyTuple__i2GOAy1W4iVZ1R13oxrTvA));
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_.len = 0; T1_.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	eqsink___system_u5515((&(*Result).Field0), T1_);
	T2_ = initTable__packagesZdocutilsZrstgen_u2333(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___packagesZdocutilsZrstgen_u2156(T2_); goto BeforeRet_;}
	eqsink___packagesZdocutilsZrstgen_u2165((&(*Result).Field2), T2_);
	newSeq__packagesZdocutilsZrstidx_u119((&(*Result).Field1), ((NI)15000));
	setLen__packagesZdocutilsZrstidx_u127((&(*Result).Field1), ((NI)0));
	L_1 = ((NI)0);
	{
		NimStringV2 path_1;
		tySequence__sM4lkSb7zS6F7OVMvW9cffQ stack_1;
		NIM_BOOL checkDir_1;
		path_1.len = 0; path_1.p = NIM_NIL;
		stack_1.len = 0; stack_1.p = NIM_NIL;
		stack_1.len = 1; stack_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(1, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
		stack_1.p->data[0] = TM__vYBWrr780p7faFzauVMtPg_660;
		checkDir_1 = NIM_FALSE;
		{
			while (1) {
				NI T7_;
				NimStringV2 d_1;
				T7_ = stack_1.len;
				if (!(((NI)0) < T7_)) goto LA6;
				d_1.len = 0; d_1.p = NIM_NIL;
				d_1 = pop__stdZprivateZosdirs_u415((&stack_1));
				{
					NimStringV2 p_1;
					NimStringV2 colontmp_;
					tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ k_1;
					NimStringV2 T11_;
					DIR* d_2;
					p_1.len = 0; p_1.p = NIM_NIL;
					colontmp_.len = 0; colontmp_.p = NIM_NIL;
					k_1 = (tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)0;
					p_1.len = 0; p_1.p = NIM_NIL;
					colontmp_.len = 0; colontmp_.p = NIM_NIL;
					T11_.len = 0; T11_.p = NIM_NIL;
					T11_ = slash___stdZprivateZospaths2_u91(dir_p0, d_1);
					if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T11_); goto LA10_;}
					eqsink___system_u2700((&colontmp_), T11_);
					d_2 = opendir(nimToCStringConv(colontmp_));
					{
						if (!(d_2 == ((DIR*) NIM_NIL))) goto LA14_;
						{
							NI32 T20_;
							if (!checkDir_1) goto LA18_;
							T20_ = (NI32)0;
							T20_ = osLastError__stdZoserrors_u122();
							if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
							raiseOSError__stdZoserrors_u119(T20_, colontmp_);
							if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
						}
LA18_: ;
					}
					goto LA12_;
LA14_: ;
					{
						{
							while (1) {
								{
									NimStringV2 y_1;
									struct dirent* x_1;
									y_1.len = 0; y_1.p = NIM_NIL;
									x_1 = readdir(d_2);
									{
										if (!(x_1 == ((struct dirent*) NIM_NIL))) goto LA29_;
										eqdestroy___system_u2691(y_1);
										goto LA23;
									}
LA29_: ;
									y_1 = cstrToNimstr(((NCSTRING) ((*x_1).d_name)));
									{
										NIM_BOOL T33_;
										NimStringV2 path_2;
										NimStringV2 rel_1;
										struct stat s_1;
										tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ k_2;
										T33_ = (NIM_BOOL)0;
										T33_ = !(eqStrings(y_1, TM__vYBWrr780p7faFzauVMtPg_662));
										if (!(T33_)) goto LA34_;
										T33_ = !(eqStrings(y_1, TM__vYBWrr780p7faFzauVMtPg_663));
LA34_: ;
										if (!T33_) goto LA35_;
										path_2.len = 0; path_2.p = NIM_NIL;
										rel_1.len = 0; rel_1.p = NIM_NIL;
										nimZeroMem((void*)(&s_1), sizeof(struct stat));
										path_2 = slash___stdZprivateZospaths2_u91(colontmp_, y_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
										{
											if (!NIM_FALSE) goto LA40_;
											eqcopy___system_u2694((&y_1), path_2);
										}
LA40_: ;
										k_2 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)0);
										switch ((*x_1).d_type) {
										case ((NI8)4):
										{
											k_2 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)2);
										}
										break;
										case ((NI8)10):
										{
											NIM_BOOL isSpecialX60gensym19__1;
											tyTuple__wjbnfGBIEcH6aaevyJWrgw tmpTupleAsgn;
											isSpecialX60gensym19__1 = (NIM_BOOL)0;
											tmpTupleAsgn = getSymlinkFileKind__stdZprivateZoscommon_u20(path_2);
											if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
											k_2 = tmpTupleAsgn.Field0;
											isSpecialX60gensym19__1 = tmpTupleAsgn.Field1;
											{
												NIM_BOOL T46_;
												T46_ = (NIM_BOOL)0;
												T46_ = NIM_FALSE;
												if (!(T46_)) goto LA47_;
												T46_ = isSpecialX60gensym19__1;
LA47_: ;
												if (!T46_) goto LA48_;
												eqdestroy___system_u2691(rel_1);
												eqdestroy___system_u2691(path_2);
												eqdestroy___system_u2691(y_1);
												goto LA25;
											}
LA48_: ;
										}
										break;
										case ((NI8)0):
										{
											{
												int T53_;
												T53_ = (int)0;
												T53_ = lstat(nimToCStringConv(path_2), (&s_1));
												if (!(T53_ < ((NI32)0))) goto LA54_;
												eqdestroy___system_u2691(rel_1);
												eqdestroy___system_u2691(path_2);
												eqdestroy___system_u2691(y_1);
												goto LA25;
											}
											goto LA51_;
LA54_: ;
											{
												NIM_BOOL T57_;
												T57_ = (NIM_BOOL)0;
												T57_ = S_ISDIR(s_1.st_mode);
												if (!T57_) goto LA58_;
												k_2 = ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)2);
											}
											goto LA51_;
LA58_: ;
											{
												NIM_BOOL T61_;
												NIM_BOOL isSpecialX60gensym21__1;
												tyTuple__wjbnfGBIEcH6aaevyJWrgw tmpTupleAsgn_2;
												T61_ = (NIM_BOOL)0;
												T61_ = S_ISLNK(s_1.st_mode);
												if (!T61_) goto LA62_;
												isSpecialX60gensym21__1 = (NIM_BOOL)0;
												tmpTupleAsgn_2 = getSymlinkFileKind__stdZprivateZoscommon_u20(path_2);
												if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
												k_2 = tmpTupleAsgn_2.Field0;
												isSpecialX60gensym21__1 = tmpTupleAsgn_2.Field1;
												{
													NIM_BOOL T66_;
													T66_ = (NIM_BOOL)0;
													T66_ = NIM_FALSE;
													if (!(T66_)) goto LA67_;
													T66_ = isSpecialX60gensym21__1;
LA67_: ;
													if (!T66_) goto LA68_;
													eqdestroy___system_u2691(rel_1);
													eqdestroy___system_u2691(path_2);
													eqdestroy___system_u2691(y_1);
													goto LA25;
												}
LA68_: ;
											}
											goto LA51_;
LA62_: ;
											{
												NIM_BOOL T71_;
												NIM_BOOL T73_;
												T71_ = (NIM_BOOL)0;
												T71_ = NIM_FALSE;
												if (!(T71_)) goto LA72_;
												T73_ = (NIM_BOOL)0;
												T73_ = S_ISREG(s_1.st_mode);
												T71_ = !(T73_);
LA72_: ;
												if (!T71_) goto LA74_;
												eqdestroy___system_u2691(rel_1);
												eqdestroy___system_u2691(path_2);
												eqdestroy___system_u2691(y_1);
												goto LA25;
											}
											goto LA51_;
LA74_: ;
LA51_: ;
										}
										break;
										default:
										{
											{
												NIM_BOOL T79_;
												T79_ = (NIM_BOOL)0;
												T79_ = NIM_FALSE;
												if (!(T79_)) goto LA80_;
												T79_ = !(((*x_1).d_type == ((NI8)8)));
LA80_: ;
												if (!T79_) goto LA81_;
												eqdestroy___system_u2691(rel_1);
												eqdestroy___system_u2691(path_2);
												eqdestroy___system_u2691(y_1);
												goto LA25;
											}
											goto LA77_;
LA81_: ;
											{
											}
LA77_: ;
										}
										break;
										}
										k_1 = k_2;
										eqsink___system_u2700((&p_1), y_1);
										eqwasMoved___system_u2688((&y_1));
										rel_1 = slash___stdZprivateZospaths2_u91(d_1, p_1);
										if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
										{
											NIM_BOOL T86_;
											NimStringV2 colontmpD_;
											T86_ = (NIM_BOOL)0;
											T86_ = (k_1 == ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)2) || k_1 == ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)3));
											if (!(T86_)) goto LA87_;
											T86_ = (k_1 == ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)2));
LA87_: ;
											if (!T86_) goto LA88_;
											colontmpD_ = eqdup___system_u2697(rel_1);
											add__stdZenumutils_u71((&stack_1), colontmpD_);
										}
LA88_: ;
										{
											NimStringV2 T94_;
											if (!(k_1 == ((tyEnum_PathComponent__daMOTwam9cW3AQtl6fxq4sQ)0))) goto LA92_;
											T94_.len = 0; T94_.p = NIM_NIL;
											{
												if (!NIM_FALSE) goto LA97_;
												eqsink___system_u2700((&path_1), rel_1);
												eqwasMoved___system_u2688((&rel_1));
											}
											goto LA95_;
LA97_: ;
											{
												NimStringV2 T100_;
												T100_.len = 0; T100_.p = NIM_NIL;
												T100_ = slash___stdZprivateZospaths2_u91(dir_p0, rel_1);
												if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T100_); goto LA37_;}
												eqsink___system_u2700((&path_1), T100_);
											}
LA95_: ;
											{
												NIM_BOOL T103_;
												tyTuple__mBPo6SdWuL2NLQ9aX5t1kTg tmpTuple_1;
												tySequence__36jA1xDCIBAS29cySYLQ7kQ fileEntries_1;
												tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ title_1;
												T103_ = (NIM_BOOL)0;
												T103_ = nsuEndsWith(path_1, TM__vYBWrr780p7faFzauVMtPg_665);
												if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
												if (!T103_) goto LA104_;
												nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__mBPo6SdWuL2NLQ9aX5t1kTg));
												fileEntries_1.len = 0; fileEntries_1.p = NIM_NIL;
												nimZeroMem((void*)(&title_1), sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
												parseIdxFile__packagesZdocutilsZrstidx_u113(path_1, (&tmpTuple_1));
												if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
												fileEntries_1 = tmpTuple_1.Field0;
												eqwasMoved___packagesZdocutilsZrstidx_u278((&tmpTuple_1.Field0));
												title_1 = tmpTuple_1.Field1;
												eqwasMoved___packagesZdocutilsZrstidx_u194((&tmpTuple_1.Field1));
												{
													if (!(title_1.kind == ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)1))) goto LA109_;
													{
														NI i_1;
														NI colontmp__2;
														NI T112_;
														NI i_2;
														i_1 = (NI)0;
														colontmp__2 = (NI)0;
														T112_ = fileEntries_1.len;
														colontmp__2 = T112_;
														i_2 = ((NI)0);
														{
															while (1) {
																if (!(i_2 < colontmp__2)) goto LA114;
																i_1 = i_2;
																{
																	{
																		if (!!((fileEntries_1.p->data[i_1].kind == ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)4)))) goto LA118_;
																		goto LA115;
																	}
LA118_: ;
																	setLen__packagesZdocutilsZrstidx_u127((&(*Result).Field1), ((NI)(L_1 + ((NI)1))));
																	eqcopy___packagesZdocutilsZrstidx_u200((&(*Result).Field1.p->data[L_1]), (&fileEntries_1.p->data[i_1]));
																	L_1 += ((NI)1);
																} LA115: ;
																i_2 += ((NI)1);
															} LA114: ;
														}
													}
													{
														NI T122_;
														NimStringV2 x_2;
														NI i_3;
														T122_ = fileEntries_1.len;
														if (!(((NI)0) < T122_)) goto LA123_;
														x_2.len = 0; x_2.p = NIM_NIL;
														eqcopy___system_u2694((&x_2), fileEntries_1.p->data[((NI)0)].link);
														i_3 = nsuFindChar(x_2, 35, ((NI)0), ((NI)-1));
														if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
														{
															if (!(((NI)0) < i_3)) goto LA127_;
															setLengthStrV2((&x_2), (i_3));
														}
LA127_: ;
														{
															NimStringV2 T133_;
															if (!!((i_3 == ((NI)0)))) goto LA131_;
															T133_.len = 0; T133_.p = NIM_NIL;
															T133_ = noschangeFileExt(x_2, TM__vYBWrr780p7faFzauVMtPg_666);
															if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T133_); goto LA106_;}
															add__stdZenumutils_u71((&(*Result).Field0), T133_);
														}
LA131_: ;
														eqdestroy___system_u2691(x_2);
													}
LA123_: ;
												}
												goto LA107_;
LA109_: ;
												{
													NimStringV2 colontmpD__2;
													tySequence__36jA1xDCIBAS29cySYLQ7kQ colontmpD__3;
													NimStringV2 T135_;
													NI T136_;
													colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
													T135_.len = 0; T135_.p = NIM_NIL;
													T136_ = (NI)0;
													T136_ = len__packagesZdocutilsZrstgen_u1417((*Result).Field2);
													if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
													colontmpD__2 = dollar___systemZdollars_u9(T136_);
													if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
													T135_ = rawNewString(colontmpD__2.len + 8);
appendString((&T135_), TM__vYBWrr780p7faFzauVMtPg_668);
appendString((&T135_), colontmpD__2);
													eqsink___system_u2700((&title_1.aux), T135_);
													colontmpD__3 = eqdup___packagesZdocutilsZrstidx_u287(fileEntries_1);
													X5BX5Deq___packagesZdocutilsZrstgen_u2549((&(*Result).Field2), (&title_1), colontmpD__3);
													if (NIM_UNLIKELY(*nimErr_)) goto LA106_;
													eqdestroy___system_u2691(colontmpD__2);
												}
LA107_: ;
												{
													NI i_4;
													NI colontmp__3;
													NI T138_;
													NI i_5;
													i_4 = (NI)0;
													colontmp__3 = (NI)0;
													T138_ = fileEntries_1.len;
													colontmp__3 = T138_;
													i_5 = ((NI)0);
													{
														while (1) {
															if (!(i_5 < colontmp__3)) goto LA140;
															i_4 = i_5;
															{
																{
																	if (!!((fileEntries_1.p->data[i_4].kind == ((tyEnum_IndexEntryKind__bp7boVnNZivfjr9au9bLARfQ)3)))) goto LA144_;
																	goto LA141;
																}
LA144_: ;
																setLen__packagesZdocutilsZrstidx_u127((&(*Result).Field1), ((NI)(L_1 + ((NI)1))));
																eqcopy___packagesZdocutilsZrstidx_u200((&(*Result).Field1.p->data[L_1]), (&fileEntries_1.p->data[i_4]));
																L_1 += ((NI)1);
															} LA141: ;
															i_5 += ((NI)1);
														} LA140: ;
													}
												}
												{
													LA106_:;
												}
												{
													eqdestroy___packagesZdocutilsZrstidx_u197((&title_1));
													eqdestroy___packagesZdocutilsZrstidx_u281(fileEntries_1);
													eqdestroy___packagesZdocutilsZrst_u16216((&tmpTuple_1));
												}
												if (NIM_UNLIKELY(*nimErr_)) goto LA37_;
											}
LA104_: ;
										}
LA92_: ;
										{
											LA37_:;
										}
										{
											eqdestroy___system_u2691(rel_1);
											eqdestroy___system_u2691(path_2);
										}
										if (NIM_UNLIKELY(*nimErr_)) goto LA26_;
									}
LA35_: ;
									{
										LA26_:;
									}
									{
										eqdestroy___system_u2691(y_1);
									}
									if (NIM_UNLIKELY(*nimErr_)) goto LA22_;
								} LA25: ;
							}
						} LA23: ;
						{
							LA22_:;
						}
						{
							int T154_;
							T154_ = (int)0;
							T154_ = closedir(d_2);
							(void)(T154_);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA10_;
					}
LA12_: ;
					{
						LA10_:;
					}
					{
						eqdestroy___system_u2691(colontmp_);
						eqdestroy___system_u2691(p_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				}
				checkDir_1 = NIM_FALSE;
				{
					LA8_:;
				}
				{
					eqdestroy___system_u2691(d_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
			} LA6: ;
		}
		{
			LA4_:;
		}
		{
			eqdestroy___system_u5506(stack_1);
			eqdestroy___system_u2691(path_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_u32)(NI hcode_p0) {
	NIM_BOOL result;
	result = !((hcode_p0 == ((NI)0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, generateDocumentationJumps__packagesZdocutilsZrstgen_u2193)(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw docs_p0) {
	NimStringV2 result;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ titles_1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ resultX60gensym33__1;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ chunks_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	tyProc__p4iTrPV9bLhWFNG1rpOIFgQ T12_;
	NimStringV2 T18_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	titles_1.len = 0; titles_1.p = NIM_NIL;
	resultX60gensym33__1.len = 0; resultX60gensym33__1.p = NIM_NIL;
	chunks_1.len = 0; chunks_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	result = TM__vYBWrr780p7faFzauVMtPg_672;
	resultX60gensym33__1.len = 0; resultX60gensym33__1.p = (tySequence__36jA1xDCIBAS29cySYLQ7kQ_Content*) newSeqPayload(0, sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ), NIM_ALIGNOF(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
	{
		tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* xX60gensym33__1;
		NI L_1;
		xX60gensym33__1 = (tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ*)0;
		L_1 = len__packagesZdocutilsZrstgen_u1417(docs_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		{
			NI h_1;
			NI colontmp_;
			NI T3_;
			NI res_1;
			h_1 = (NI)0;
			colontmp_ = (NI)0;
			T3_ = (docs_p0.data.len-1);
			colontmp_ = T3_;
			res_1 = ((NI)0);
			{
				while (1) {
					if (!(res_1 <= colontmp_)) goto LA5;
					h_1 = ((NI) (res_1));
					{
						NIM_BOOL T8_;
						tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ colontmpD__3;
						tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ T11_;
						T8_ = (NIM_BOOL)0;
						T8_ = isFilled__pureZcollectionsZtables_u32(docs_p0.data.p->data[h_1].Field0);
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
						if (!T8_) goto LA9_;
						xX60gensym33__1 = (&docs_p0.data.p->data[h_1].Field1);
						nimZeroMem((void*)(&T11_), sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
						eqdup___packagesZdocutilsZrstidx_u203((&(*xX60gensym33__1)), (&T11_));
						colontmpD__3 = T11_;
						add__packagesZdocutilsZrstgen_u1602((&resultX60gensym33__1), (&colontmpD__3));
					}
LA9_: ;
					res_1 += ((NI)1);
				} LA5: ;
			}
		}
	}
	titles_1 = resultX60gensym33__1;
	nimZeroMem((void*)(&T12_), sizeof(tyProc__p4iTrPV9bLhWFNG1rpOIFgQ));
	T12_.ClP_0 = ((TM__vYBWrr780p7faFzauVMtPg_673) (cmp__packagesZdocutilsZrstidx_u318)); T12_.ClE_0 = NIM_NIL;
	sort__packagesZdocutilsZrstgen_u1625(((titles_1).p) ? (titles_1.p->data) : NIM_NIL, titles_1.len, T12_, ((tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	chunks_1.len = 0; chunks_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	{
		tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* title_1;
		NI i_1;
		NI L_2;
		NI T14_;
		title_1 = (tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ*)0;
		i_1 = ((NI)0);
		T14_ = titles_1.len;
		L_2 = T14_;
		{
			while (1) {
				NimStringV2 T17_;
				if (!(i_1 < L_2)) goto LA16;
				title_1 = (&titles_1.p->data[i_1]);
				T17_.len = 0; T17_.p = NIM_NIL;
				T17_ = rawNewString((*title_1).link.len + (*title_1).linkTitle.len + 15);
appendString((&T17_), TM__vYBWrr780p7faFzauVMtPg_675);
appendString((&T17_), (*title_1).link);
appendString((&T17_), TM__vYBWrr780p7faFzauVMtPg_676);
appendString((&T17_), (*title_1).linkTitle);
appendString((&T17_), TM__vYBWrr780p7faFzauVMtPg_678);
				add__stdZenumutils_u71((&chunks_1), T17_);
				i_1 += ((NI)1);
			} LA16: ;
		}
	}
	T18_.len = 0; T18_.p = NIM_NIL;
	colontmpD_ = nsuJoinSep(((chunks_1).p) ? (chunks_1.p->data) : NIM_NIL, chunks_1.len, TM__vYBWrr780p7faFzauVMtPg_680);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	T18_ = rawNewString(colontmpD_.len + 6);
appendString((&T18_), colontmpD_);
appendString((&T18_), TM__vYBWrr780p7faFzauVMtPg_682);
	colontmpD__2 = T18_;
	prepareAdd((&result), colontmpD__2.len + 0);
appendString((&result), colontmpD__2);
	eqdestroy___system_u2691(colontmpD__2);
	eqdestroy___system_u2691(colontmpD_);
	eqdestroy___system_u5506(chunks_1);
	eqdestroy___packagesZdocutilsZrstidx_u281(titles_1);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, generateModuleJumps__packagesZdocutilsZrstgen_u2295)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ modules_p0) {
	NimStringV2 result;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ chunks_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	chunks_1.len = 0; chunks_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	result = TM__vYBWrr780p7faFzauVMtPg_686;
	chunks_1.len = 0; chunks_1.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	{
		NimStringV2* name_1;
		NI i_1;
		NI L_1;
		NI T3_;
		name_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		T3_ = modules_p0.len;
		L_1 = T3_;
		{
			while (1) {
				NimStringV2 colontmpD__3;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T7_;
				NimStringV2 T8_;
				if (!(i_1 < L_1)) goto LA5;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				name_1 = (&modules_p0.p->data[i_1]);
				T7_[0] = (*name_1);
				colontmpD__3 = prettyLink__packagesZdocutilsZrstgen_u81((*name_1));
				if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
				T7_[1] = colontmpD__3;
				T8_.len = 0; T8_.p = NIM_NIL;
				T8_ = nsuFormatOpenArray(TM__vYBWrr780p7faFzauVMtPg_688, T7_, 2);
				if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T8_); goto LA6_;}
				add__stdZenumutils_u71((&chunks_1), T8_);
				i_1 += ((NI)1);
				{
					LA6_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			} LA5: ;
		}
	}
	T11_.len = 0; T11_.p = NIM_NIL;
	colontmpD_ = nsuJoinSep(((chunks_1).p) ? (chunks_1.p->data) : NIM_NIL, chunks_1.len, TM__vYBWrr780p7faFzauVMtPg_689);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T11_ = rawNewString(colontmpD_.len + 6);
appendString((&T11_), colontmpD_);
appendString((&T11_), TM__vYBWrr780p7faFzauVMtPg_690);
	colontmpD__2 = T11_;
	prepareAdd((&result), colontmpD__2.len + 0);
appendString((&result), colontmpD__2);
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u5506(chunks_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, sortIndex__packagesZdocutilsZrstgen_u721)(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ* a_p0, NI a_p0Len_0) {
	NI n_1;
	NI h_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	n_1 = a_p0Len_0;
	h_1 = ((NI)1);
	{
		while (1) {
			h_1 = (NI)((NI)(((NI)3) * h_1) + ((NI)1));
			{
				if (!(n_1 < h_1)) goto LA5_;
				goto LA1;
			}
LA5_: ;
		}
	} LA1: ;
	{
		while (1) {
			h_1 = (NI)(h_1 / ((NI)3));
			{
				NI i_1;
				NI colontmp_;
				NI res_1;
				i_1 = (NI)0;
				colontmp_ = (NI)0;
				colontmp_ = (NI)(n_1 - ((NI)1));
				res_1 = h_1;
				{
					while (1) {
						tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ v_1;
						NI j_1;
						tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ T21_;
						if (!(res_1 <= colontmp_)) goto LA11;
						nimZeroMem((void*)(&v_1), sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
						i_1 = ((NI) (res_1));
						nimZeroMem((void*)(&v_1), sizeof(tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ));
						v_1 = a_p0[i_1];
						eqwasMoved___packagesZdocutilsZrstidx_u194((&a_p0[i_1]));
						j_1 = i_1;
						{
							while (1) {
								NI T15_;
								tyObject_IndexEntry__r4FGmtl4yhJtHvFotaeMmQ T16_;
								T15_ = (NI)0;
								T15_ = cmp__packagesZdocutilsZrstidx_u318((&a_p0[(NI)(j_1 - h_1)]), (&v_1));
								if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
								if (!(((NI)0) <= T15_)) goto LA14;
								T16_ = a_p0[(NI)(j_1 - h_1)];
								eqwasMoved___packagesZdocutilsZrstidx_u194((&a_p0[(NI)(j_1 - h_1)]));
								eqsink___packagesZdocutilsZrstidx_u206((&a_p0[j_1]), (&T16_));
								j_1 = (NI)(j_1 - h_1);
								{
									if (!(j_1 < h_1)) goto LA19_;
									goto LA13;
								}
LA19_: ;
							} LA14: ;
						} LA13: ;
						T21_ = v_1;
						eqwasMoved___packagesZdocutilsZrstidx_u194((&v_1));
						eqsink___packagesZdocutilsZrstidx_u206((&a_p0[j_1]), (&T21_));
						res_1 += ((NI)1);
						{
							LA12_:;
						}
						{
							eqdestroy___packagesZdocutilsZrstidx_u197((&v_1));
						}
						if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					} LA11: ;
				}
			}
			{
				if (!(h_1 == ((NI)1))) goto LA26_;
				goto LA7;
			}
LA26_: ;
		}
	} LA7: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, escapeLink__packagesZdocutilsZrstgen_u750)(NimStringV2 s_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = rawNewString(((NI)(s_p0.len + (NI)((NI64)(s_p0.len) >> (NU64)(((NI)2) & (64 - 1))))));
	{
		NIM_CHAR c_1;
		NI i_1;
		NI L_1;
		c_1 = (NIM_CHAR)0;
		i_1 = ((NI)0);
		L_1 = s_p0.len;
		{
			while (1) {
				if (!(i_1 < L_1)) goto LA3;
				c_1 = s_p0.p->data[i_1];
				switch (((NU8)(c_1))) {
				case 97 ... 122:
				case 65 ... 90:
				case 48 ... 57:
				case 45:
				case 46:
				case 95:
				case 126:
				{
					nimAddCharV1((&result), c_1);
				}
				break;
				case 35:
				case 47:
				{
					nimAddCharV1((&result), c_1);
				}
				break;
				default:
				{
					NimStringV2 colontmpD_;
					colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
					prepareAdd((&result), 1);
appendString((&result), TM__vYBWrr780p7faFzauVMtPg_697);
					colontmpD_ = toHex__pureZstrutils_u2114(((NU8)(c_1)), ((NI)2));
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
					prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
					eqdestroy___system_u2691(colontmpD_);
				}
				break;
				}
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, generateSymbolIndex__packagesZdocutilsZrstgen_u765)(tySequence__36jA1xDCIBAS29cySYLQ7kQ symbols_p0) {
	NimStringV2 result;
	NI i_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = TM__vYBWrr780p7faFzauVMtPg_695;
	i_1 = ((NI)0);
	{
		while (1) {
			NI T3_;
			NimStringV2 keyword_1;
			NimStringV2 cleanedKeyword_1;
			tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T5_;
			NI j_1;
			T3_ = symbols_p0.len;
			if (!(i_1 < T3_)) goto LA2;
			keyword_1.len = 0; keyword_1.p = NIM_NIL;
			cleanedKeyword_1.len = 0; cleanedKeyword_1.p = NIM_NIL;
			keyword_1 = esc__packagesZdocutilsZrstgen_u264(((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0), symbols_p0.p->data[i_1].keyword, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
			if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
			cleanedKeyword_1 = escapeLink__packagesZdocutilsZrstgen_u750(keyword_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
			T5_[0] = keyword_1;
			T5_[1] = cleanedKeyword_1;
			nsuAddf((&result), TM__vYBWrr780p7faFzauVMtPg_699, T5_, 2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
			j_1 = i_1;
			{
				while (1) {
					NIM_BOOL T8_;
					NI T9_;
					NimStringV2 url_1;
					NimStringV2 module_1;
					NimStringV2 text_1;
					NimStringV2 desc_1;
					NimStringV2 T12_;
					T8_ = (NIM_BOOL)0;
					T9_ = symbols_p0.len;
					T8_ = (j_1 < T9_);
					if (!(T8_)) goto LA10_;
					T8_ = eqStrings(symbols_p0.p->data[i_1].keyword, symbols_p0.p->data[j_1].keyword);
LA10_: ;
					if (!T8_) goto LA7;
					url_1.len = 0; url_1.p = NIM_NIL;
					module_1.len = 0; module_1.p = NIM_NIL;
					text_1.len = 0; text_1.p = NIM_NIL;
					desc_1.len = 0; desc_1.p = NIM_NIL;
					url_1 = escapeLink__packagesZdocutilsZrstgen_u750(symbols_p0.p->data[j_1].link);
					if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					module_1 = symbols_p0.p->data[j_1].module;
					T12_.len = 0; T12_.p = NIM_NIL;
					{
						NimStringV2 colontmpD_;
						NimStringV2 T17_;
						if (!(((NI)0) < symbols_p0.p->data[j_1].linkTitle.len)) goto LA15_;
						colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
						T17_.len = 0; T17_.p = NIM_NIL;
						T17_ = rawNewString(module_1.len + symbols_p0.p->data[j_1].linkTitle.len + 2);
appendString((&T17_), module_1);
appendString((&T17_), TM__vYBWrr780p7faFzauVMtPg_701);
appendString((&T17_), symbols_p0.p->data[j_1].linkTitle);
						colontmpD_ = T17_;
						text_1 = esc__packagesZdocutilsZrstgen_u264(((tyEnum_OutputTarget__rJTSKSJRxqqfNpYVLuax6g)0), colontmpD_, ((NI)-1), ((tyEnum_EscapeMode__I9cvwrO3LJLr9bFEuurLKwKA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
						eqdestroy___system_u2691(colontmpD_);
					}
					goto LA13_;
LA15_: ;
					{
						eqcopy___system_u2694((&text_1), url_1);
					}
LA13_: ;
					desc_1 = symbols_p0.p->data[j_1].linkDesc;
					{
						tyArray__dyW7vpmfeTYw8kX3EXuaJA T23_;
						if (!(((NI)0) < desc_1.len)) goto LA21_;
						T23_[0] = url_1;
						T23_[1] = text_1;
						T23_[2] = desc_1;
						nsuAddf((&result), TM__vYBWrr780p7faFzauVMtPg_703, T23_, 3);
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					}
					goto LA19_;
LA21_: ;
					{
						tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T25_;
						T25_[0] = url_1;
						T25_[1] = text_1;
						nsuAddf((&result), TM__vYBWrr780p7faFzauVMtPg_705, T25_, 2);
						if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
					}
LA19_: ;
					j_1 += ((NI)1);
					{
						LA11_:;
					}
					{
						eqdestroy___system_u2691(text_1);
						eqdestroy___system_u2691(url_1);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				} LA7: ;
			}
			prepareAdd((&result), 11);
appendString((&result), TM__vYBWrr780p7faFzauVMtPg_707);
			i_1 = j_1;
			{
				LA4_:;
			}
			{
				eqdestroy___system_u2691(cleanedKeyword_1);
				eqdestroy___system_u2691(keyword_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		} LA2: ;
	}
	prepareAdd((&result), 5);
appendString((&result), TM__vYBWrr780p7faFzauVMtPg_709);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___packagesZdocutilsZrstgen_u3613)(tyTuple__i2GOAy1W4iVZ1R13oxrTvA* dest_p0) {
	eqdestroy___system_u5506((*dest_p0).Field0);
	eqdestroy___packagesZdocutilsZrstidx_u281((*dest_p0).Field1);
	eqdestroy___packagesZdocutilsZrstgen_u1198((*dest_p0).Field2.data);
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, mergeIndexes__packagesZdocutilsZrstgen_u3543)(NimStringV2 dir_p0) {
	NimStringV2 result;
	tyTuple__i2GOAy1W4iVZ1R13oxrTvA tmpTuple_1;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ modules_1;
	tySequence__36jA1xDCIBAS29cySYLQ7kQ symbols_1;
	tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw docs_1;
	tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	nimZeroMem((void*)(&tmpTuple_1), sizeof(tyTuple__i2GOAy1W4iVZ1R13oxrTvA));
	modules_1.len = 0; modules_1.p = NIM_NIL;
	symbols_1.len = 0; symbols_1.p = NIM_NIL;
	nimZeroMem((void*)(&docs_1), sizeof(tyObject_Table__A7x6FghBNmM6UtLJ9c6MpOw));
	readIndexDir__packagesZdocutilsZrstgen_u2311(dir_p0, (&tmpTuple_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	modules_1 = tmpTuple_1.Field0;
	eqwasMoved___system_u5503((&tmpTuple_1.Field0));
	symbols_1 = tmpTuple_1.Field1;
	eqwasMoved___packagesZdocutilsZrstidx_u278((&tmpTuple_1.Field1));
	docs_1 = tmpTuple_1.Field2;
	eqwasMoved___packagesZdocutilsZrstgen_u2153((&tmpTuple_1.Field2));
	nimZeroMem((void*)(&T2_), sizeof(tyProc__3pmh9bG9bLpdxUjFu9cDtbZaA));
	T2_.ClP_0 = ((TM__vYBWrr780p7faFzauVMtPg_669) (cmp__system_u1563)); T2_.ClE_0 = NIM_NIL;
	sort__sem_u2565(((modules_1).p) ? (modules_1.p->data) : NIM_NIL, modules_1.len, T2_, ((tyEnum_SortOrder__wt7l6Gbd8C9c61b6I621QeA)1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = TM__vYBWrr780p7faFzauVMtPg_670;
	{
		NI T5_;
		NimStringV2 colontmpD_;
		T5_ = (NI)0;
		T5_ = len__packagesZdocutilsZrstgen_u1417(docs_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(((NI)0) < T5_)) goto LA6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = generateDocumentationJumps__packagesZdocutilsZrstgen_u2193(docs_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
		prepareAdd((&result), 5);
appendString((&result), TM__vYBWrr780p7faFzauVMtPg_684);
		eqdestroy___system_u2691(colontmpD_);
	}
LA6_: ;
	{
		NI T10_;
		NimStringV2 colontmpD__2;
		T10_ = modules_1.len;
		if (!(((NI)0) < T10_)) goto LA11_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__2 = generateModuleJumps__packagesZdocutilsZrstgen_u2295(modules_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA13_;
		prepareAdd((&result), colontmpD__2.len + 0);
appendString((&result), colontmpD__2);
		prepareAdd((&result), 5);
appendString((&result), TM__vYBWrr780p7faFzauVMtPg_691);
		{
			LA13_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA11_: ;
	{
		NI T18_;
		NimStringV2 colontmpD__3;
		T18_ = symbols_1.len;
		if (!(((NI)0) < T18_)) goto LA19_;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		sortIndex__packagesZdocutilsZrstgen_u721(((symbols_1).p) ? (symbols_1.p->data) : NIM_NIL, symbols_1.len);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&result), 21);
appendString((&result), TM__vYBWrr780p7faFzauVMtPg_693);
		colontmpD__3 = generateSymbolIndex__packagesZdocutilsZrstgen_u765(symbols_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA21_;
		prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
		{
			LA21_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA19_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___packagesZdocutilsZrstgen_u2156(docs_1);
		eqdestroy___packagesZdocutilsZrstidx_u281(symbols_1);
		eqdestroy___system_u5506(modules_1);
		eqdestroy___packagesZdocutilsZrstgen_u3613((&tmpTuple_1));
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
